(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3063835,     137575]*)
(*NotebookOutlinePosition[   3064565,     137601]*)
(*  CellTagsIndexPosition[   3064521,     137597]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["Trinoids",
          FontFamily->"Charter",
          FontSize->24,
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontFamily->"Charter",
          FontSize->24,
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["Mathematica",
          FontFamily->"Charter",
          FontSize->24,
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontFamily->"Charter",
          FontSize->24,
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["Notebook",
          FontFamily->"Charter",
          FontSize->24,
          FontColor->RGBColor[1, 0, 0]]}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["by",
        FontSize->14,
        FontWeight->"Plain"], 
      StyleBox["  ",
        FontWeight->"Plain"], 
      StyleBox["Tatyana",
        FontSize->14,
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontSize->14,
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[\(V . \ Pavlyukevich\),
        FontSize->14,
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["E",
          FontWeight->"Plain"], 
        StyleBox["-",
          FontWeight->"Plain"], 
        RowBox[{
          StyleBox["mail",
            FontWeight->"Plain"], 
          StyleBox[":",
            FontFamily->"Times",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontFamily->"New century schoolbook",
            FontWeight->"Plain"], 
          StyleBox[\(tatiana@sfb288 . math . tu - berlin . de\),
            FontWeight->"Plain"]}]}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(For\ details\ see\),
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["   ",
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}]}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(A . I . Bobenko, 
        T . V . Pavlyukevich\ and\ B . A . Springborn, 
        Hyperbolic\ constant\ mean\ curvature\ one\),
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}]}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(surfaces : 
          Spinor\ representation\ and\ trinoids\ in\ hypergeometric\ \
functions\),
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[",",
        FontWeight->"Plain",
        FontVariations->{"CompatibilityType"->0}], 
      ButtonBox[
        StyleBox[\(math . DG/0206021\),
          FontWeight->"Plain",
          FontVariations->{"CompatibilityType"->0}],
        ButtonData:>{
          URL[ "http://xxx.lanl.gov/abs/math.DG/0206021"], "math.DG/0206021"},
        
        ButtonStyle->"Hyperlink"], "\[IndentingNewLine]"}]}], "Input",
  Editable->False,
  Evaluatable->False],

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"         ", 
          StyleBox["  ",
            FontWeight->"Bold"]}]], 
      StyleBox[\(Representation\ of\ CMC - 1\ trinoids\ \[IndentingNewLine]
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ in\ the\ Poincare\^\[Prime]\ model\ \
of\ \(\(\[DoubleStruckCapitalH]\^3\)\(.\)\)\),
        FontFamily->"Charter",
        FontSize->16,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.470588, 0.0627451, 0]]}]], "Input",
  Editable->False,
  Evaluatable->False,
  FontFamily->"Times",
  FontWeight->"Plain",
  Background->RGBColor[0.964706, 0.690196, 0.443137],
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{\(CMC - 
      1\ trinoids\ with\ fixed\ points\ on\ the\ absolute\ build\ a\ three - 
      parameter\), "\[IndentingNewLine]", \(family\ characterized\ by\ the\ \
parameters\ \ d\_0, 
    d\_1\ and\ d\_\[Infinity] . \ The\ condition\ \ d\_0 = \(d\_1\  = \ 
        d\_\[Infinity]\)\), "\[IndentingNewLine]", \(defines\ the\ symmetric\ \
trinoids . \ If\ d\_0 < \ D\_0 \[TildeTilde] 0, 
    2332\ \ the\ trinoid\ is\ embedded, \ 
    if\ d\_0 > \ 
      D\_0\  - \ non - 
        embedded . \ 
            To\ get\ the\ closed\ trinoid\ \ these\ parameters\), "\
\[IndentingNewLine]", \(must\ satisfy\ \ the\ following\ \(conditions : \
\[IndentingNewLine]1.  d\_0\), 
    d\_1\ , \ \(d\_\[Infinity]\  \[GreaterEqual] 
        0;\)\), "\[IndentingNewLine]", 
    RowBox[{
      "     ", \(2. \ \((\(\(|\)\({\@d\_0}\)\(|\)\), \(\(|\)\({\@d\_1}\)\(|\)\
\), \(\(|\)\({\@d\_\[Infinity]}\)\(|\)\))\) \[Element] \[ScriptCapitalD], \ \
{} : \[DoubleStruckCapitalR]\ \[LongRightArrow]\ \((\(-1\)/2, 
              1/2)\) \[Union] {\(-1\)/2}\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(where\ \ \[ScriptCapitalD]\), "=", 
        TagBox[
          RowBox[{" ", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      TagBox["",
                        (#&)], \((\[CapitalDelta]\_0, \[CapitalDelta]\_1, \
\[CapitalDelta]\_\[Infinity])\)}], 
                    "\[Element]", \(\[DoubleStruckCapitalR]\^3\)}], 
                  ";", \(\[CapitalDelta]\_0\)}], ",", \(\[CapitalDelta]\_1\), 
                ",", \(\[CapitalDelta]\_\[Infinity] \[GreaterEqual] 0\), ",", 
                "  ", GridBox[{
                    {GridBox[{
                          {
                            RowBox[{" ", 
                              
                              StyleBox[\(\(\[CapitalDelta]\_0 + \
\[CapitalDelta]\_1 + \[CapitalDelta]\_\[Infinity] > 1\/2\)\(,\)\),
                                ShowAutoStyles->True]}]},
                          {
                            
                            StyleBox[\(\(\[CapitalDelta]\_0 + \[CapitalDelta]\
\_1 - \[CapitalDelta]\_\[Infinity] < 1\/2\)\(,\)\),
                              ShowAutoStyles->True]}
                          }]},
                    {GridBox[{
                          {
                            
                            StyleBox[\(\(\[CapitalDelta]\_0 - \[CapitalDelta]\
\_1 + \[CapitalDelta]\_\[Infinity] < 1\/2\)\(,\)\),
                              ShowAutoStyles->True]},
                          {
                            RowBox[{
                              RowBox[{
                                RowBox[{"-", 
                                  StyleBox[\(\[CapitalDelta]\_0\),
                                    ShowAutoStyles->True]}], 
                                StyleBox["+",
                                  ShowAutoStyles->True], 
                                StyleBox[\(\[CapitalDelta]\_1\),
                                  ShowAutoStyles->True], 
                                StyleBox["+",
                                  ShowAutoStyles->True], 
                                StyleBox[\(\[CapitalDelta]\_\[Infinity]\),
                                  ShowAutoStyles->True]}], 
                              StyleBox["<",
                                ShowAutoStyles->True], 
                              StyleBox[\(1\/2\),
                                ShowAutoStyles->True]}]}
                          }]}
                    }]}], "}"}], "\[IndentingNewLine]"}],
          (#&)]}], 
      ";"}], "\[IndentingNewLine]", \(Thus\ we\ can\ take\ \((d\_0, d\_1\ , \ 
          d\_\[Infinity])\) = \((\((\(\[PlusMinus]\[CapitalDelta]\_0\) + \
k\_0)\)\^2, \((\(\[PlusMinus]\[CapitalDelta]\_1\) + k\_1)\)\^2, \((\(\
\[PlusMinus]\[CapitalDelta]\_\[Infinity]\) + k\_\[Infinity])\)\^2)\), \
\[IndentingNewLine]\ k\_0, k\_1, 
    k\_\[Infinity]\  \[Element] \[DoubleStruckCapitalZ] . \ \
\[IndentingNewLine]The\ parameters\ \[CapitalDelta]\_0, \[CapitalDelta]\_1, \
\(\[CapitalDelta]\_\[Infinity]\ could\ be\ chosen\ as\ \(follows\  : \
\[IndentingNewLine]\[CapitalDelta]\_0 \[Element] \((0, 
              1\/2)\)\);\)\), "\[IndentingNewLine]", 
    RowBox[{
      "       ", \(\(\[CapitalDelta]\_1\) \[Epsilon] \((0, 
            1\/2)\);\)}], "\[IndentingNewLine]", 
    RowBox[{
      "       ", \(\(\[CapitalDelta]\_\[Infinity]\) \[Epsilon] \
\((\(\(|\)\(1\/2 - \[CapitalDelta]\_0 - \[CapitalDelta]\_1\)\(|\)\), 
            min {1\/2 - \[CapitalDelta]\_0 + \[CapitalDelta]\_1, 
                1\/2 + \[CapitalDelta]\_0 - \[CapitalDelta]\_1})\);\)}]}], \
"Input",
  Editable->False,
  CellDingbat->"\[GraySquare]",
  FontWeight->"Plain",
  Background->RGBColor[0.956863, 0.658824, 0],
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    StyleBox[\(Trinoids\ are\ represented\ as\ three\[Hyphen]dimensional\ \
surfaces\ with\),
      FontWeight->"Plain",
      FontColor->GrayLevel[0],
      FontVariations->{"CompatibilityType"->0}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["Graphics3D",
          "MR",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          "MR",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["by",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["giving",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["explicit",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["lists",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["of",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["polygons",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["with",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["adjacent",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[\(edges . In\),
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["the",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}]}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["cell",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["below",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["Mathematica",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["evaluates",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["the",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["coordinates",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["of",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["the",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["vertices",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["of",
          FontWeight->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"CompatibilityType"->0}]}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}]}], "\[IndentingNewLine]", 
    StyleBox[\(\(these\ polygons . The\ computation\ is\ highly\ complex, 
      and\ on\ most\)\(\ \)\),
      FontWeight->"Plain",
      FontColor->GrayLevel[0],
      FontVariations->{"CompatibilityType"->0}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["computers",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["takes",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["Mathematica",
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["several",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["  ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[\(minutes . \ You\),
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["need",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["to",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["define",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox[" ",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}], 
      StyleBox["the",
        FontWeight->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"CompatibilityType"->0}]}], "\[IndentingNewLine]", 
    StyleBox[\(\(values\ of\ the\ parameters\ \[CapitalDelta]\_0, \
\[CapitalDelta]\_1, \[CapitalDelta]\_\[Infinity]\ and\ k\_embeddness\ and\ \
start\ the\)\(\ \)\),
      FontWeight->"Plain",
      FontColor->GrayLevel[0],
      FontVariations->{"CompatibilityType"->0}], "\[IndentingNewLine]", 
    StyleBox[\(\(cell\)\(.\)\),
      FontWeight->"Plain",
      FontColor->GrayLevel[0],
      FontVariations->{"CompatibilityType"->0}]}], "Input",
  Editable->False,
  CellDingbat->"\[GraySquare]",
  Evaluatable->False,
  FontColor->RGBColor[0.0470588, 0.94902, 1],
  Background->RGBColor[0.94902, 0.423529, 0.411765]],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\
*) \),
          FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]",
         
        StyleBox[\( (*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\ \ \ \[CapitalDelta]\_0 \
\[Element] \((0, 1\/2)\)\ \ %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
          FontColor->RGBColor[0.862745, 0.0784314, 0]], 
        StyleBox["\[IndentingNewLine]",
          FontColor->RGBColor[0.862745, 0.0784314, 0]], 
        StyleBox[\(\[CapitalDelta]0 = 0.4;\),
          FontColor->RGBColor[0.862745, 0.0784314, 0]], 
        StyleBox["      ",
          FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]",
         
        StyleBox[" ",
          FontColor->RGBColor[0.862745, 0.0784314, 0]], 
        StyleBox[\( (*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\ \ \ \(\[CapitalDelta]\_1\
\) \[Epsilon] \((0, 1\/2)\)\ \ %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
          FontColor->RGBColor[0.862745, 0.0784314, 0]]}], 
      StyleBox[
        RowBox[{
          StyleBox["       ",
            FontColor->RGBColor[0.862745, 0.0784314, 0]], 
          " "}]]}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(\[CapitalDelta]1 = 0.4;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["      ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
      StyleBox[" ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox[\( (*%%%%%%%%%%%%%%%%%%%\ \ \ \(\[CapitalDelta]\_\[Infinity]\) \
\[Epsilon] \((\(\(|\)\(1\/2 - \[CapitalDelta]\_0 - \
\[CapitalDelta]\_1\)\(|\)\), 
              min {1\/2 - \[CapitalDelta]\_0 + \[CapitalDelta]\_1, 
                  1\/2 + \[CapitalDelta]\_0 - \[CapitalDelta]\_1})\)\ \
%%%%%%%%%%%%%%*) \),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["     ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        StyleBox[\(\[CapitalDelta]8 = 0.4;\),
          FontColor->RGBColor[0.862745, 0.0784314, 0]], 
        StyleBox["    ",
          FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]",
         
        StyleBox[" ",
          FontColor->RGBColor[0.862745, 0.0784314, 0]], 
        StyleBox[\( (*%%%%%%%%%%%%%%%%%%%\ 0\  - \ 
                embedded\ if\ \[CapitalDelta]0\  < \ 0, 
            4829\ %%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
          FontColor->RGBColor[0.862745, 0.0784314, 0]]}], 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox[" ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox[\( (*%%%%%%%%%%%%%%%%%%%%\ arbitrary\ k \[Element] \
\[DoubleStruckCapitalZ]\\{0}\  - \ non - 
              embedded\ %%%%%%%%%%%%%%%%%%%%%%*) \),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["           ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    RowBox[{
      StyleBox[\(kembed = 0;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["        ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\
%*) \),
        FontColor->RGBColor[0.862745, 0.0784314, 
        0]]}], "\[IndentingNewLine]", \(Off[
        General::spell];\), "\[IndentingNewLine]", 
    RowBox[{\(Off[General::spell1];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \
\(frpart[\[CapitalDelta]_] := 
        FractionalPart[\[CapitalDelta]] /; 
          FractionalPart[\[CapitalDelta]] < 
            1\/2;\), "\[IndentingNewLine]", \(frpart[\[CapitalDelta]_] := 
        FractionalPart[\[CapitalDelta]] - 1 /; 
          FractionalPart[\[CapitalDelta]] \[GreaterEqual] 
            1\/2;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"If", "[", 
        RowBox[{\(\((\((Abs[frpart[\[CapitalDelta]0]] + 
                    Abs[frpart[\[CapitalDelta]1]] + 
                    Abs[frpart[\[CapitalDelta]8]])\) > 
                1\/2)\) && \((\((Abs[frpart[\[CapitalDelta]0]] + 
                    Abs[frpart[\[CapitalDelta]1]] - 
                    Abs[frpart[\[CapitalDelta]8]])\) < 
                1\/2)\) && \[IndentingNewLine]\((\((Abs[
                      frpart[\[CapitalDelta]0]] - 
                    Abs[frpart[\[CapitalDelta]1]] + 
                    Abs[frpart[\[CapitalDelta]8]])\) < 
                1\/2)\) && \[IndentingNewLine]\((\((\(-Abs[
                        frpart[\[CapitalDelta]0]]\) + 
                    Abs[frpart[\[CapitalDelta]1]] + 
                    Abs[frpart[\[CapitalDelta]8]])\) < 1\/2)\)\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"StylePrint", "[", 
                RowBox[{
                "\"\<The parameters \!\(\[CapitalDelta]\_0\),\!\(\
\[CapitalDelta]\_1\),\!\(\[CapitalDelta]\_\[Infinity]\) define a closed \
trinoid. Please wait a few minutes before \!\(\*
StyleBox[\\\"Mathematica\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\!\(\*
StyleBox[\\\" \\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"Italic\\\",\
\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\!\(\*
StyleBox[\\\"evaluates\\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\
\)\!\(\*
StyleBox[\\\" \\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\!\(\*
StyleBox[\\\"the\\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\!\(\
\*
StyleBox[\\\" \\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\!\(\*
StyleBox[\\\"surface\\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\
\!\(\*
StyleBox[\\\".\\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\>\"", 
                  ",", "\[IndentingNewLine]", "\t\t", "\"\<Output\>\"", ",", 
                  "\[IndentingNewLine]", "\t\t", \(FontSize \[Rule] 12\), ",",
                   "\[IndentingNewLine]", 
                  "\t\t", \(FontWeight \[Rule] "\<Bold\>"\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(FontSlant \[Rule] "\<Plain\>"\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(FontFamily \[Rule] "\<Courier\>"\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(FontColor \[Rule] RGBColor[1, 0, 0]\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(Background -> RGBColor[1, 1, 0]\)}], "]"}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(d0 = \((\[CapitalDelta]0 + \
kembed)\)\^2\), ";", 
              "\[IndentingNewLine]", \(d1 = \((\[CapitalDelta]1 + \
kembed)\)\^2\), ";", 
              "\[IndentingNewLine]", \(d8 = \((\[CapitalDelta]8 + \
kembed)\)\^2\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(Print["\<d0= \>", 
                d0 // N, \ "\<, d1= \>", d1 // N, \ "\<, d8= \>", \ 
                d8\  // N]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*%%%%%%%%%%%%%%%%%%%%%%%\ \ WEIERSTRASS\ DATA\ \
%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(q0 = \(\@\(1 + 2\/\@3\)\ \((1 - 4\ d0 \
- 4\ d1 + 4\ d8)\)\ \@\(\(-1\) + 4\ d0 - 4\ d1 + 4\ d8\)\)\/\(4\ \@\(\((1 + 4\
\ d0 - 4\ d1 - 4\ d8)\)\ \((\(-1\) + 4\ d0 + 4\ d1 - 4\ d8)\)\)\)\), 
              ";", \(q8 = \(\@\(\(-1\) + 2\/\@3\)\ \((1 + 4\ d0 - 4\ d1 - 4\ \
d8)\)\ \@\(\(-1\) + 4\ d0 - 4\ d1 + 4\ d8\)\)\/\(4\ \@\(\((1 + 4\ d0 - 4\ d1 \
- 4\ d8)\)\ \((\(-1\) + 4\ d0 + 4\ d1 - 4\ d8)\)\)\)\), 
              ";", \(q1 = \@\(\((1 + 4\ d0 - 4\ d1 - 4\ d8)\)\ \((\(-1\) + 4\ \
d0 + 4\ d1 - 4\ d8)\)\)\/\(2\ \@2\ 3\^\(1/4\)\ \@\(\(-1\) + 4\ d0 - 4\ d1 + 4\
\ d8\)\)\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(p0\  = \ \((2\  - \@3)\)\ q0\), " ", 
              ";", "\[IndentingNewLine]", \(p8\  = \((2 + \ \@3\ )\) q8\), 
              ";", "\[IndentingNewLine]", \(p1 = \(-q1\)\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(P = p0\/z + p1\/\(z - 1\) + p8\), ";", 
              "\n", "    ", \(Q = q0\/z + q1\/\(z - 1\) + q8\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*%%%%%%%%%%%%%%%%%%%\ \ GAUGE\ CONSTANTS\ \
%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(pq10 = p1\ q0 - p0\ q1 // N\), ";", 
              "\[IndentingNewLine]", \(\(pq08 = 
                  p0\ q8 - p8\ q0 // N;\)\[IndentingNewLine]
              \(pq18 = p1\ q8 - p8\ q1 // N;\)\[IndentingNewLine]
              \(\[CapitalDelta] = 
                  pq10\ pq08 + pq10\ pq18 + pq08\ pq18 // 
                    N;\)\[IndentingNewLine]
              \(\[Alpha] = \(1\/2\) \((1 - \@\(1 + 4  pq08 + 4  pq10\))\) // 
                    N;\)\[IndentingNewLine]
              \(\[Beta] = \(1\/2\) \(pq10 \((1 - 2  \[Alpha])\) - \
pq08\)\/\(pq08 + pq10\) // N;\)\[IndentingNewLine]
              \(\[Gamma] = 
                  pq08 \((pq18\/\[CapitalDelta] + 1\/\[Alpha])\) // 
                    N;\)\[IndentingNewLine]
              \(\[Delta] = \(\[CapitalDelta]\/pq08\) \(\[CapitalDelta] + pq18\
\ \[Alpha]\)\/\(\[CapitalDelta] - pq08\ pq10 + \((\[CapitalDelta] + pq18)\) \
\[Alpha]\) // N;\)\[IndentingNewLine]
              \(k = \[CapitalDelta] \( pq08\ pq10 - \[CapitalDelta]\ \[Alpha]\
\)\/\(\[CapitalDelta]\^2 + pq10\ pq08\ pq18\) // N;\)\[IndentingNewLine]
              \(\[Mu] = 
                  2  pq08 \((1 - k  pq18\/\[CapitalDelta])\) // 
                    N;\)\[IndentingNewLine]
              \(\[Alpha]1 = \(-\(\(p8\ pq10\)\/\[CapitalDelta]\)\) // 
                    N;\)\[IndentingNewLine]
              \(\[Alpha]2 = \(q8\ pq10\)\/\[CapitalDelta] // 
                    N;\)\[IndentingNewLine]
              \(\[Beta]2 = \(-\(\(q0\ pq18\)\/\[CapitalDelta]\)\) // 
                    N;\)\[IndentingNewLine]
              \[Beta]1 = \(p0\ pq18\)\/\[CapitalDelta] // N\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*\ %%%%%%%%%%%%%%%%%%%%%%\ \ GAUGE\ MATRICES\ \
%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              RowBox[{"B", "=", 
                RowBox[{"(", GridBox[{
                      {"P", \(\[Alpha]1\ z + \[Beta]1\)},
                      {\(-Q\), \(\[Alpha]2\ z + \[Beta]2\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"CC", "=", 
                RowBox[{"(", GridBox[{
                      {\(\@\(z - 1\)\), "0"},
                      {\(k\/\(z \@\( z - 1\)\)\), \(1\/\@\(z - 1\)\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"M", "=", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {\(\(2\ \[Alpha]\)\/\[Mu]\), "0"},
                        {"1", "1"}
                        }], ")"}],
                  (MatrixForm[ #]&)]}], ";", "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(\[Tau] = \@\(\[Beta]\^2 + \[Gamma]\ \
\[Delta]\) // N\), ";", "\n", 
              "       ", \(\[Rho] = \@\(\((\[Alpha] + \[Beta])\)\^2 + \
\[Gamma]\ \[Delta]\) // N\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(a = \[Alpha] + \[Tau] + \[Rho] // N\), 
              ";", "\[IndentingNewLine]", \(b = \[Alpha] + \[Tau] - \[Rho] // 
                  N\), ";", "\[IndentingNewLine]", \(c = 2  \[Alpha] // N\), 
              ";", "\[IndentingNewLine]", \(\[Epsilon] = \((\((\[Gamma] \((1 \
+ 2  \[Alpha])\)\^2\ \(Gamma[c]\^2\) Gamma[\(-a\)] Gamma[\(-b\)] Gamma[a - c] 
                            Gamma[b - 
                                c])\)/\((\[Delta] \((2  \[Alpha] - 1)\)\^2\ \
Gamma[\(-c\)]\^2\ Gamma[a] Gamma[b] Gamma[c - a] 
                            Gamma[c - b])\))\)^\((1\/4)\) // N\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"eps", "=", 
                RowBox[{"(", GridBox[{
                      {\(\[Epsilon]\^\(-1\)\), "0"},
                      {"0", "\[Epsilon]"}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*%%%%%%%%%%%%%%%%%\ \ CONECTION\ \
MATRICES\ \ %%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              RowBox[{"conect", "=", 
                RowBox[{"(", GridBox[{
                      {\(\(-\(\(1 + 
                                  2  \[Alpha]\)\/\(\[Beta] + \[Tau]\)\)\) \
\(Gamma[c] Gamma[c - a - b]\)\/\(Gamma[c - b] Gamma[c - a]\)\), \(\(\(2  \
\[Alpha] - 
                                1\)\/\[Gamma]\) \(Gamma[\(-c\)] Gamma[c - a - \
b]\)\/\(Gamma[\(-a\)] Gamma[\(-b\)]\)\)},
                      {\(\(-\((\[ExponentialE]\^\(2\ \[Pi]\ \[ImaginaryI]\ \
\[Tau]\))\)\) \(\(1 + 
                                2  \[Alpha]\)\/\[Delta]\) \(Gamma[c] Gamma[a \
+ b - c]\)\/\(Gamma[a] Gamma[b]\)\), \(\(-\((\[ExponentialE]\^\(2\ \[Pi]\ \
\[ImaginaryI]\ \[Tau]\))\)\) \(\(2  \[Alpha] - 
                                1\)\/\(\[Beta] + \[Tau]\)\) \(Gamma[\(-c\)] \
Gamma[a + b - c]\)\/\(Gamma[a - c] Gamma[b - c]\)\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"conect8", "=", 
                RowBox[{"(", GridBox[{
                      {\(\(\(1 + 
                                2  \[Alpha]\)\/\(\(\[Delta]\)\(\ \)\)\) \(\(a \
\((\[Tau] + \[Beta])\)\)\/\(\[Gamma] \((a - 
                                    c)\)\)\) \((\[ExponentialE]\^\(\(\ \)\(\
\[Pi]\ \[ImaginaryI]\ a\)\))\) \(Gamma[c] Gamma[b - a]\)\/\(Gamma[b] Gamma[c \
- a]\)\), \(\(\(a \((\[Tau] + \[Beta])\)\)\/\(\[Gamma] \((a - 
                                    c)\)\)\) \((\[ExponentialE]\^\(\(\ \)\(\
\[Pi]\ \[ImaginaryI]\ \((a - c)\)\)\))\) \(Gamma[2 - c] Gamma[b - \
a]\)\/\(Gamma[b - c + 1] Gamma[1 - a]\)\)},
                      {\(\(-\((\(1 + 2  \[Alpha]\)\/\(\(\[Delta]\)\(\ \ \)\))\
\)\) \((\[ExponentialE]\^\(\(\ \)\(\[Pi]\ \[ImaginaryI]\ b\)\))\) \(Gamma[c] \
Gamma[a - b]\)\/\(Gamma[a] Gamma[c - b]\)\), \(\(-\((\[ExponentialE]\^\(\(\ \
\)\(\[Pi]\ \[ImaginaryI]\ \((b - c)\)\)\))\)\) \(Gamma[2 - c] Gamma[a - \
b]\)\/\(Gamma[a - c + 1] Gamma[1 - b]\)\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*%%%%%%%%%%%%%%%%%%%\ HYPERGEOMETRIC\ \
FUNCTION\ \ %%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              RowBox[{\(F[a_, b_, c_, z_]\), ":=", " ", 
                RowBox[{
                  StyleBox["Hypergeometric2F1",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  RowBox[{
                    StyleBox["a",
                      "TI"], 
                    StyleBox[",",
                      "MR"], " ", 
                    StyleBox["b",
                      "TI"], 
                    StyleBox[",",
                      "MR"], " ", 
                    StyleBox["c",
                      "TI"], 
                    StyleBox[",",
                      "MR"], " ", 
                    StyleBox["z",
                      "TI"]}], 
                  StyleBox["]",
                    "MR"]}]}], 
              StyleBox[";",
                "MR"], "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*%%%%%%%%%%%%%%%%%%%\ THE\ CANONICAL\ \
SOLUTIONS\ \ %%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], "\n", 
              RowBox[{"\[CapitalGamma]0", "=", 
                RowBox[{"(", GridBox[{
                      {\(\(-\(\(1 + 
                                  2  \[Alpha]\)\/\(\(\[Delta]\)\(\ \)\)\)\) \
\(z\^\[Alpha]\) \(\((z - 1)\)\^\[Tau]\) 
                          F[a, b, c, 
                            z]\), \(\(z\^\(1 - \[Alpha]\)\) \(\((z - 
                                  1)\)\^\[Tau]\) 
                          F[a - c + 1, b - c + 1, 2 - c, z]\)},
                      {\(\(z\^\(1 + \[Alpha]\)\) \(\((z - 1)\)\^\[Tau]\) 
                          F[a + 1, b + 1, c + 2, 
                            z]\), \(\(\(\(-1\) + 
                                2  \[Alpha]\)\/\[Gamma]\) \
\(z\^\(-\[Alpha]\)\) \(\((z - 1)\)\^\[Tau]\) F[a - c, b - c, \(-c\), z]\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              RowBox[{"\[CapitalGamma]1", "=", 
                RowBox[{"(", GridBox[{
                      {\(\(\(\[Tau] + \[Beta]\)\/\(\(\[Delta]\)\(\ \)\)\) \(z\
\^\[Alpha]\) \(\((z - 1)\)\^\[Tau]\) 
                          F[a, b, a + b - c + 1, 
                            1 - z]\), \(\(z\^\[Alpha]\) \(\((z - 
                                  1)\)\^\(-\[Tau]\)\) 
                          F[c - a, c - b, c - a - b + 1, 1 - z]\)},
                      {\(\(z\^\(-\[Alpha]\)\) \(\((z - 1)\)\^\[Tau]\) 
                          F[a - c, b - c, a + b - c + 1, 
                            1 - z]\), \(\(-\(\(\[Tau] + \[Beta]\)\/\[Gamma]\)\
\) \(z\^\(-\[Alpha]\)\) \(\((z - 1)\)\^\(-\[Tau]\)\) 
                          F[\(-a\), \(-b\), c - a - b + 1, 1 - z]\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              RowBox[{"\[CapitalGamma]8", "=", 
                RowBox[{"(", GridBox[{
                      {\(\(-\(\(\[Gamma] \((a - 
                                      c)\)\)\/\(a \((\[Tau] + \
\[Beta])\)\)\)\) \(\((z)\)\^\(\(-\[Tau]\) - \[Rho]\)\) \(\((z - 
                                  1)\)\^\[Tau]\) 
                          F[a, a - c + 1, a - b + 1, 
                            1\/z]\), \(\(\((z)\)\^\(\(-\[Tau]\) + \[Rho]\)\) \
\(\((z - 1)\)\^\[Tau]\) F[b, b - c + 1, b - a + 1, 1\/z]\)},
                      {\(\(\((z)\)\^\(\(-\[Tau]\) - \[Rho]\)\) \(\((z - 
                                  1)\)\^\[Tau]\) 
                          F[a - c, a + 1, a - b + 1, 
                            1\/z]\), \(\(-\(\(b \((\[Tau] + \[Beta])\)\)\/\(\
\[Gamma] \((b - c)\)\)\)\) \(\((z)\)\^\(\(-\[Tau]\) + \[Rho]\)\) \(\((z - 
                                  1)\)\^\[Tau]\) 
                          F[b - c, b + 1, b - a + 1, 1\/z]\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(determ = \(-\(\(2\ \[Alpha] \((4  \
\[Alpha]\^2 - 1)\)\)\/\(\[Mu]\ \[Gamma]\ \[Delta]\)\)\)\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*%%%%%%%%%%%%%%  
                    IMMERSION\ FORMULAS\ AND\ COORDINATES  %%%%%%%%%%%%%%*) \
\),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(\(==\)\(\ \)\(end\ z\)\)\) = 
                    0\  ===  ===  ===  ===  ===  ===  ===  ===  == *) \),
                FontColor->RGBColor[0, 0, 1]], " ", "\n", "     ", 
              RowBox[{"\[CapitalPsi]0", "=", 
                RowBox[{\(1\/\@determ\), 
                  RowBox[{"B", ".", "CC", ".", "M", ".", "\[CapitalGamma]0", 
                    StyleBox[".",
                      FontColor->GrayLevel[0]], 
                    StyleBox["eps",
                      FontColor->GrayLevel[0]]}]}]}], ";", "\n", 
              "\[IndentingNewLine]", \(F0 = \[CapitalPsi]0 . 
                  Conjugate[Transpose[\[CapitalPsi]0]]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\(==\)\(\(==\)\(coordinates\ in\
\ \[DoubleStruckCapitalH]\^3\)\)\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
\(==\)\(==\)\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(t0 = \(F0[\([1, 1]\)] + F0[\([2, 2]\)]\
\)\/2\), ";", 
              "\[IndentingNewLine]", \(x01 = \(F0[\([1, 2]\)] + F0[\([2, \
1]\)]\)\/2\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(x02 = \((\(F0[\([2, 1]\)] - F0[\([1, \
2]\)]\)\/2)\) \[ImaginaryI]\), ";", 
              "\[IndentingNewLine]", \(x03 = \(F0[\([1, 1]\)] - F0[\([2, \
2]\)]\)\/2\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\(==\)\(coordinates\ in\ \
\[DoubleStruckCapitalR]\^3\)\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\)\(=\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(u0 = \(\(x01\)\(\ \)\)\/\(t0 + 1\)\), 
              ";", "\[IndentingNewLine]", \(v0 = x02\/\(t0 + 1\)\), ";", 
              "\[IndentingNewLine]", \(w0 = \(\(x03\)\(\ \)\)\/\(t0 + 1\)\), 
              ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(\(==\)\(\(==\)\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\(===\)\)\)\)\)\(=\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\) = \ \(end\ z = 
                      1\  ===  ===  ===  ===  ===  ===  === \
\(\(==\)\(==\)\)\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(\[CapitalPsi]1 = \(1\/\@determ\) 
                  B . CC . M . \[CapitalGamma]1 . conect . eps\), ";", "\n", 
              "\[IndentingNewLine]", \(F1 = \[CapitalPsi]1 . 
                  Conjugate[Transpose[\[CapitalPsi]1]]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\) = 
                    coordinates\ in\ \[DoubleStruckCapitalH]\^3 ===  ===  ===  \
===  === \(\(==\)\(\(===\)\(==\)\)\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(t1 = \(F1[\([1, 1]\)] + F1[\([2, 2]\)]\
\)\/2\), ";", 
              "\[IndentingNewLine]", \(x11 = \(F1[\([1, 2]\)] + F1[\([2, \
1]\)]\)\/2\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(x12 = \((\(F1[\([2, 1]\)] - F1[\([1, \
2]\)]\)\/2)\) \[ImaginaryI]\), ";", 
              "\[IndentingNewLine]", \(x13 = \(F1[\([1, 1]\)] - F1[\([2, \
2]\)]\)\/2\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(==\)\) = 
                    coordinates\ in\ \[DoubleStruckCapitalR]\^3 ===  ===  ===  \
===  ===  ===  ===  == *) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(u1 = \(\(x11\)\(\ \)\)\/\(t1 + 1\)\), 
              ";", "\[IndentingNewLine]", \(v1 = x12\/\(t1 + 1\)\), ";", 
              "\[IndentingNewLine]", \(w1 = \(\(x13\)\(\ \)\)\/\(t1 + 1\)\), 
              ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\)\(=\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\) = \
\(\(\(===\)\(===\)\(\ \)\(end\ z\)\) = \[Infinity]\  ===  ===  ===  ===  ===  \
===  ===  ===  == \)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(\[CapitalPsi]8 = \(1\/\@determ\) 
                  B . CC . M . \[CapitalGamma]8 . conect8 . eps\), ";", "\n", 
              "\[IndentingNewLine]", \(F8 = \[CapitalPsi]8 . 
                  Conjugate[Transpose[\[CapitalPsi]8]]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\
\(\(==\)\(coordinates\ in\ \
\[DoubleStruckCapitalH]\^3\)\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(==\)*) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(t8 = \(F8[\([1, 1]\)] + F8[\([2, 2]\)]\
\)\/2\), ";", 
              "\[IndentingNewLine]", \(x81 = \(F8[\([1, 2]\)] + F8[\([2, \
1]\)]\)\/2\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(x82 = \((\(F8[\([2, 1]\)] - F8[\([1, \
2]\)]\)\/2)\) \[ImaginaryI]\), ";", 
              
              "\[IndentingNewLine]", \(x83 = \(F8[\([1, 1]\)] - F8[\([2, \
2]\)]\)\/2\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(==\)\) = 
                    coordinates\ in\ \[DoubleStruckCapitalR]\^3 ===  ===  ===  \
===  ===  ===  ===  == *) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(u8 = \(\(x81\)\(\ \)\)\/\(t8 + 1\)\), 
              ";", "\[IndentingNewLine]", \(v8 = x82\/\(t8 + 1\)\), ";", 
              "\[IndentingNewLine]", \(w8 = \(\(x83\)\(\ \)\)\/\(t8 + 1\)\), 
              ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\)\(=\)*) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*\ %%%%%%%%%%%%%%%%%%%%%%\ \ MONODROMY\ MATRICES\ \
%%%%%%%%%%%%%%%%%%%%\ *) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"M0", "=", 
                RowBox[{\(Inverse[eps]\), ".", 
                  RowBox[{"(", GridBox[{
                        {\(\[ExponentialE]\^\(2  \[Pi]\ \[ImaginaryI]\ \
\[Alpha]\)\), "0"},
                        {
                          "0", \(\[ExponentialE]\^\(\(-2\) \[Pi]\ \
\[ImaginaryI]\ \[Alpha]\)\)}
                        }], ")"}], ".", "eps"}]}], ";", "\[IndentingNewLine]",
               
              RowBox[{"M1", "=", 
                RowBox[{\(Inverse[eps]\), ".", \(Inverse[conect]\), ".", 
                  RowBox[{"(", GridBox[{
                        {\(\[ExponentialE]\^\(2  \[Pi]\ \[ImaginaryI]\ \[Tau]\
\)\), "0"},
                        {
                          "0", \(\[ExponentialE]\^\(\(-2\) \[Pi]\ \
\[ImaginaryI]\ \[Tau]\)\)}
                        }], ")"}], ".", "conect", ".", "eps"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"M8", "=", 
                RowBox[{\(Inverse[eps]\), ".", \(Inverse[conect8]\), ".", 
                  RowBox[{"(", GridBox[{
                        {\(\[ExponentialE]\^\(2  \[Pi]\ \[ImaginaryI]\ \[Rho]\
\)\), "0"},
                        {
                          "0", \(\[ExponentialE]\^\(\(-2\) \[Pi]\ \
\[ImaginaryI]\ \[Rho]\)\)}
                        }], ")"}], ".", "conect8", ".", "eps"}]}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(Print[\*"\"\<M0.\!\(\(M0\^\[Star]\)\)=\
\>\"", Chop[N[M0 . Conjugate[Transpose[M0]]]]]\), ";", 
              "\[IndentingNewLine]", \(Print[\*"\"\<M1.\!\(\(M1\^\[Star]\)\)=\
\>\"", Chop[N[M1 . Conjugate[Transpose[M1]]]]]\), ";", 
              "\[IndentingNewLine]", \(Print[\*"\"\<M8.\!\(\(M8\^\[Star]\)\)=\
\>\"", Chop[N[M8 . Conjugate[Transpose[M8]]]]]\), ";", "\[IndentingNewLine]", 
              
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*\ %%%%%%%%%%%%%%%\ \ PARAMETRIZATION\ OF\ THE\ z \
- PLANE\ %%%%%%%%%%%%%%%\ *) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(a0 = \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\/2\)\), ";", "\n", 
              "    ", \(ww0[
                  r_, \[CurlyPhi]_] := \(\((\(\(r\ \(\[ExponentialE]\^\(\
\[ImaginaryI]\ \[CurlyPhi]\)\) Conjugate[a0]\)\(-\)\(a0\)\(\ \)\)\/\(r\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\) - 1\))\)\^\(2\/3\)\) \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]\/6\)\), ";", "\n", 
              "    ", \(ww1[
                  r_, \[CurlyPhi]_] := \(\((\(\(r\ \(\[ExponentialE]\^\(\
\[ImaginaryI]\ \[CurlyPhi]\)\) Conjugate[a0]\)\(-\)\(a0\)\(\ \)\)\/\(r\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\) - 1\))\)\^\(2\/3\)\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/2\)\), ";", "\n", 
              "    ", \(ww8[
                  r_, \[CurlyPhi]_] := \(\((\(\(r\ \(\[ExponentialE]\^\(\
\[ImaginaryI]\ \[CurlyPhi]\)\) Conjugate[a0]\)\(-\)\(a0\)\(\ \)\)\/\(r\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\) - 1\))\)\^\(2\/3\)\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \(7  \[Pi]\)\/6\)\), ";", 
              "\[IndentingNewLine]", \(z0 = \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\/6\)\), ";", 
              "\[IndentingNewLine]", \(z1 = \[ExponentialE]\^\(\[ImaginaryI]\ \
\(5  \[Pi]\)\/6\)\), ";", 
              "\[IndentingNewLine]", \(z8 = \[ExponentialE]\^\(\[ImaginaryI]\ \
\(9  \[Pi]\)\/6\)\), ";", 
              "\[IndentingNewLine]", \(zz[
                  ww_] := \(\(z1 - z8\)\/\(z1 - 
                        z0\)\) \(ww - z0\)\/\(ww - z8\)\), ";", "\n", "    ", 
              
              
              StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[0, 0, 1]], 
              
              StyleBox[\( (*\ %%%%%%%%%%%%%%%%%%%\ \ THE\ ENDS\ OF\ THE\ \
TRINOID\ %%%%%%%%%%%%%%%%%\ *) \),
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(part1 = 
                Table[{Re[u0 /. {z \[Rule] zz[ww0[r\^4, \[CurlyPhi]]]}], 
                    Re[v0 /. {z \[Rule] zz[ww0[r\^4, \[CurlyPhi]]]}], 
                    Re[w0 /. {z \[Rule] zz[ww0[r\^4, \[CurlyPhi]]]}]}, {r, 
                    10\^\(-4\), 
                    0.99999, \(0.99999 - 10\^\(-4\)\)\/30}, {\[CurlyPhi], \(0 \
 \[Pi]\)\/2, \(4  \[Pi]\)\/2, \(2  \[Pi]\)\/30}]\), ";", 
              "\[IndentingNewLine]", \(part2 = 
                Table[{Re[u1 /. {z \[Rule] zz[ww1[r\^4, \[CurlyPhi]]]}], 
                    Re[v1 /. {z \[Rule] zz[ww1[r\^4, \[CurlyPhi]]]}], 
                    Re[w1 /. {z \[Rule] zz[ww1[r\^4, \[CurlyPhi]]]}]}, {r, 
                    10\^\(-4\), 
                    0.99999, \(0.99999 - 10\^\(-4\)\)\/30}, {\[CurlyPhi], \(0 \
 \[Pi]\)\/2, \(4  \[Pi]\)\/2, \(2  \[Pi]\)\/30}]\), ";", 
              "\[IndentingNewLine]", \(part3 = 
                Table[{Re[u8 /. {z \[Rule] zz[ww8[r\^4, \[CurlyPhi]]]}], 
                    Re[v8 /. {z \[Rule] zz[ww8[r\^4, \[CurlyPhi]]]}], 
                    Re[w8 /. {z \[Rule] zz[ww8[r\^4, \[CurlyPhi]]]}]}, {r, 
                    10\^\(-4\), 
                    0.99999, \(0.99999 - 10\^\(-4\)\)\/30}, {\[CurlyPhi], \(0 \
 \[Pi]\)\/2, \(4  \[Pi]\)\/2, \(2  \[Pi]\)\/30}]\), ";"}], " ", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( \
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*) \),
              FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", "}"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"StylePrint", "[", 
                RowBox[{
                "\"\<The parameters \!\(\[CapitalDelta]\_0\),\!\(\
\[CapitalDelta]\_1\),\!\(\[CapitalDelta]\_\[Infinity]\) define a non-closed \
trinoid! Try another values\!\(\*
StyleBox[\\\".\\\",\\nFontVariations->{\\\"CompatibilityType\\\"->0}]\)\>\"", 
                  ",", "\n", "\t\t\t", "\"\<Output\>\"", ",", 
                  "\[IndentingNewLine]", "\t\t", \(FontSize \[Rule] 12\), ",",
                   "\[IndentingNewLine]", 
                  "\t\t", \(FontWeight \[Rule] "\<Bold\>"\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(FontSlant \[Rule] "\<Plain\>"\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(FontFamily \[Rule] "\<Courier\>"\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(FontColor \[Rule] RGBColor[1, 0, 0]\), ",", 
                  "\[IndentingNewLine]", 
                  "\t\t", \(Background -> RGBColor[1, 1, 0]\)}], "]"}], ";"}],
             "}"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
  CellDingbat->None,
  Background->RGBColor[0.972549, 0.815686, 0.568627]],

Cell[BoxData[{
    \(Starting\ the\ next\ cell\ you\ obtain\ the\ image\ of\ the\ surface\ \
evaluated\ above . \ In\ \ case\ of\ \), "\[IndentingNewLine]", 
    \(a\ non - embedded\ trinoid\ the\ cross - 
      cut\ is\ displayed\ to\ show\ inner\ self - \
\(\(intersections\)\(.\)\)\)}], "Input",
  Editable->False,
  CellDingbat->"\[GraySquare]",
  Evaluatable->False,
  FontWeight->"Plain",
  Background->RGBColor[0.94902, 0.423529, 0.411765]],

Cell[BoxData[{
    \(\(ViewP[kembed_] := {\(-1.200\), \ \(-4.000\), \ 0.000} /; 
          kembed == 0;\)\), "\[IndentingNewLine]", 
    \(\(ViewP[kembed_] := {1.200, \ 4.000, \ 0.000} /; 
          kembed != 0;\)\), "\[IndentingNewLine]", 
    \(\(cut[
          kembed_, \[CapitalDelta]0_, \[CapitalDelta]1_, \[CapitalDelta]8_] := \
{8, 23} /; \((\((kembed != 
                  0)\) || \((kembed == 
                    0)\) && \((\[CapitalDelta]0 \[Equal] \[CapitalDelta]1)\) && \
\((\[CapitalDelta]0 \[Equal] \[CapitalDelta]8)\) && \((\[CapitalDelta]0 > 
                    0.4829)\))\);\)\), "\[IndentingNewLine]", 
    \(\(cut[
          kembed_, \[CapitalDelta]0_, \[CapitalDelta]1_, \[CapitalDelta]8_] := \
{1, 30} /; \((\((kembed == 
                  0)\) && \((\((\[CapitalDelta]0 != \[CapitalDelta]1)\) || \
\((\[CapitalDelta]0 != \[CapitalDelta]8)\) || \((\[CapitalDelta]0 \
\[LessEqual] 0.4829)\))\))\);\)\), "\[IndentingNewLine]", 
    \(\(kview0 = \(cut[
            kembed, \[CapitalDelta]0, \[CapitalDelta]1, \
\[CapitalDelta]8]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(kview1 = \(cut[
            kembed, \[CapitalDelta]0, \[CapitalDelta]1, \
\[CapitalDelta]8]\)[\([2]\)];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      Graphics3D[{\[IndentingNewLine]Table[
            Polygon[{part1[\([i, j]\)], part1[\([i + 1, j]\)], 
                part1[\([i + 1, j + 1]\)], 
                part1[\([i, j + 1]\)]}], \[IndentingNewLine]{i, 1, 30}, {j, 
              kview0, kview1}], \[IndentingNewLine]Table[
            Polygon[{part2[\([i, j]\)], part2[\([i + 1, j]\)], 
                part2[\([i + 1, j + 1]\)], 
                part2[\([i, j + 1]\)]}], \[IndentingNewLine]{i, 1, 30}, {j, 
              kview0, kview1}], \[IndentingNewLine]Table[
            Polygon[{part3[\([i, j]\)], part3[\([i + 1, j]\)], 
                part3[\([i + 1, j + 1]\)], 
                part3[\([i, j + 1]\)]}], \[IndentingNewLine]{i, 1, 30}, {j, 
              kview0, kview1}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-1\), 1}}, 
        Axes \[Rule] False, Boxed \[Rule] False, 
        ImageSize \[Rule] {288, 288}, 
        ViewPoint \[Rule] ViewP[kembed]]]\)}], "Input",
  Background->RGBColor[0.972549, 0.815686, 0.568627]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"                                                     ", 
          StyleBox["   ",
            FontSize->24], 
          StyleBox[" ",
            FontSize->36], "                     "}]], 
      StyleBox["Examples",
        FontFamily->"Charter",
        FontSize->24,
        FontWeight->"Plain",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        FontVariations->{"CompatibilityType"->0}]}]], "Input",
  Editable->False,
  CellDingbat->"\[GraySquare]",
  Background->RGBColor[0.431373, 0.901961, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(Symmetric\ embedded\ trinoid\),
        FontSize->14,
        FontTracking->"Plain",
        FontColor->RGBColor[0, 0, 1],
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Masked"->False,
        "CompatibilityType"->0,
        "RotationAngle"->0}]}]], "Input",
  Editable->False,
  CellDingbat->None],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.4;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    StyleBox[\(\(\[CapitalDelta]1 = 0.4;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(\[CapitalDelta]8 = 0.4;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(kembed = 0;\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.6079 .31311 m .62586 .28201 L .64903 .29514 L p .707 .546 .668 r
F P
0 g
s
.58612 .30033 m .6029 .26851 L .62586 .28201 L p .738 .587 .686 r
F P
0 g
s
.62586 .28201 m .6079 .31311 L .58612 .30033 L p .738 .587 .686 r
F P
0 g
s
.62586 .28201 m .64639 .24644 L .66946 .25949 L p .69 .558 .7 r
F P
0 g
s
.66946 .25949 m .64903 .29514 L .62586 .28201 L p .69 .558 .7 r
F P
0 g
s
.64639 .24644 m .62586 .28201 L .6029 .26851 L p .721 .598 .718 r
F P
0 g
s
.2842 .5 m .24829 .5 L .24808 .47337 L p .673 .564 .724 r
F P
0 g
s
.28402 .52525 m .24808 .52663 L .24829 .5 L p .673 .535 .688 r
F P
0 g
s
.24829 .5 m .2842 .5 L .28402 .52525 L p .673 .535 .688 r
F P
0 g
s
.24829 .5 m .20722 .5 L .20698 .4735 L p .709 .594 .725 r
F P
0 g
s
.20698 .4735 m .24808 .47337 L .24829 .5 L p .709 .594 .725 r
F P
0 g
s
.20722 .5 m .24829 .5 L .24808 .52663 L p .709 .565 .689 r
F P
0 g
s
.6079 .68689 m .62586 .71799 L .6029 .73149 L p .738 .619 .726 r
F P
0 g
s
.62986 .67442 m .64903 .70486 L .62586 .71799 L p .707 .608 .744 r
F P
0 g
s
.62586 .71799 m .6079 .68689 L .62986 .67442 L p .707 .608 .744 r
F P
0 g
s
.62586 .71799 m .64639 .75356 L .62356 .76701 L p .721 .58 .696 r
F P
0 g
s
.62356 .76701 m .6029 .73149 L .62586 .71799 L p .721 .58 .696 r
F P
0 g
s
.64639 .75356 m .62586 .71799 L .64903 .70486 L p .69 .569 .714 r
F P
0 g
s
.6029 .26851 m .62356 .23299 L .64639 .24644 L p .721 .598 .718 r
F P
0 g
s
.64639 .24644 m .6675 .20988 L .68867 .22182 L p .669 .57 .735 r
F P
0 g
s
.68867 .22182 m .66946 .25949 L .64639 .24644 L p .669 .57 .735 r
F P
0 g
s
.6675 .20988 m .64639 .24644 L .62356 .23299 L p .699 .609 .752 r
F P
0 g
s
.64903 .70486 m .66946 .74051 L .64639 .75356 L p .69 .569 .714 r
F P
0 g
s
.64639 .75356 m .6675 .79012 L .64657 .80248 L p .699 .533 .659 r
F P
0 g
s
.64657 .80248 m .62356 .76701 L .64639 .75356 L p .699 .533 .659 r
F P
0 g
s
.6675 .79012 m .64639 .75356 L .66946 .74051 L p .669 .522 .676 r
F P
0 g
s
.24808 .52663 m .20698 .5265 L .20722 .5 L p .709 .565 .689 r
F P
0 g
s
.20722 .5 m .165 .5 L .16476 .47569 L p .749 .626 .723 r
F P
0 g
s
.16476 .47569 m .20698 .4735 L .20722 .5 L p .749 .626 .723 r
F P
0 g
s
.165 .5 m .20722 .5 L .20698 .5265 L p .749 .597 .688 r
F P
0 g
s
.64903 .29514 m .62986 .32558 L .6079 .31311 L p .707 .546 .668 r
F P
0 g
s
.62986 .32558 m .64903 .29514 L .67149 .3074 L p .673 .502 .646 r
F P
0 g
s
.64903 .29514 m .66946 .25949 L .69185 .27161 L p .656 .515 .68 r
F P
0 g
s
.69185 .27161 m .67149 .3074 L .64903 .29514 L p .656 .515 .68 r
F P
0 g
s
.56539 .28776 m .58105 .25518 L .6029 .26851 L p .77 .627 .702 r
F P
0 g
s
.6029 .26851 m .58612 .30033 L .56539 .28776 L p .77 .627 .702 r
F P
0 g
s
.62356 .23299 m .6029 .26851 L .58105 .25518 L p .751 .638 .735 r
F P
0 g
s
.6029 .73149 m .58612 .69967 L .6079 .68689 L p .738 .619 .726 r
F P
0 g
s
.58612 .69967 m .6029 .73149 L .58105 .74482 L p .77 .63 .706 r
F P
0 g
s
.6029 .73149 m .62356 .76701 L .60187 .78035 L p .751 .589 .675 r
F P
0 g
s
.60187 .78035 m .58105 .74482 L .6029 .73149 L p .751 .589 .675 r
F P
0 g
s
.65112 .66275 m .67149 .6926 L .64903 .70486 L p .673 .597 .762 r
F P
0 g
s
.64903 .70486 m .62986 .67442 L .65112 .66275 L p .673 .597 .762 r
F P
0 g
s
.66946 .74051 m .64903 .70486 L .67149 .6926 L p .656 .556 .73 r
F P
0 g
s
.2835 .5495 m .24746 .55221 L .24808 .52663 L p .669 .501 .648 r
F P
0 g
s
.24808 .52663 m .28402 .52525 L .2835 .5495 L p .669 .501 .648 r
F P
0 g
s
.20698 .5265 m .24808 .52663 L .24746 .55221 L p .707 .533 .65 r
F P
0 g
s
.24808 .47337 m .28402 .47475 L .2842 .5 L p .673 .564 .724 r
F P
0 g
s
.28402 .47475 m .24808 .47337 L .24746 .44779 L p .669 .592 .76 r
F P
0 g
s
.24808 .47337 m .20698 .4735 L .20628 .44805 L p .707 .623 .76 r
F P
0 g
s
.20628 .44805 m .24746 .44779 L .24808 .47337 L p .707 .623 .76 r
F P
0 g
s
.66946 .25949 m .68867 .22182 L .70926 .23286 L p .634 .528 .716 r
F P
0 g
s
.70926 .23286 m .69185 .27161 L .66946 .25949 L p .634 .528 .716 r
F P
0 g
s
.67149 .6926 m .69185 .72839 L .66946 .74051 L p .656 .556 .73 r
F P
0 g
s
.68867 .77818 m .66946 .74051 L .69185 .72839 L p .634 .508 .691 r
F P
0 g
s
.66946 .74051 m .68867 .77818 L .6675 .79012 L p .669 .522 .676 r
F P
0 g
s
.20698 .4735 m .16476 .47569 L .16403 .45235 L p .749 .656 .757 r
F P
0 g
s
.16403 .45235 m .20628 .44805 L .20698 .4735 L p .749 .656 .757 r
F P
0 g
s
.58105 .25518 m .60187 .21965 L .62356 .23299 L p .751 .638 .735 r
F P
0 g
s
.64657 .19752 m .62356 .23299 L .60187 .21965 L p .727 .648 .77 r
F P
0 g
s
.62356 .23299 m .64657 .19752 L .6675 .20988 L p .699 .609 .752 r
F P
0 g
s
.62356 .76701 m .64657 .80248 L .62672 .81479 L p .727 .54 .637 r
F P
0 g
s
.62672 .81479 m .60187 .78035 L .62356 .76701 L p .727 .54 .637 r
F P
0 g
s
.24746 .55221 m .20628 .55195 L .20698 .5265 L p .707 .533 .65 r
F P
0 g
s
.16476 .52431 m .20698 .5265 L .20628 .55195 L p .749 .568 .65 r
F P
0 g
s
.20698 .5265 m .16476 .52431 L .165 .5 L p .749 .597 .688 r
F P
0 g
s
.59313 .33869 m .6079 .31311 L .62986 .32558 L p .72 .536 .64 r
F P
0 g
s
.57322 .32702 m .58612 .30033 L .6079 .31311 L p .751 .576 .659 r
F P
0 g
s
.6079 .31311 m .59313 .33869 L .57322 .32702 L p .751 .576 .659 r
F P
0 g
s
.59313 .66131 m .6079 .68689 L .58612 .69967 L p .751 .651 .75 r
F P
0 g
s
.6132 .6499 m .62986 .67442 L .6079 .68689 L p .72 .64 .768 r
F P
0 g
s
.6079 .68689 m .59313 .66131 L .6132 .6499 L p .72 .64 .768 r
F P
0 g
s
.31373 .5 m .2842 .5 L .28402 .47475 L p .641 .538 .722 r
F P
0 g
s
.31359 .52308 m .28402 .52525 L .2842 .5 L p .641 .508 .686 r
F P
0 g
s
.2842 .5 m .31373 .5 L .31359 .52308 L p .641 .508 .686 r
F P
0 g
s
.62986 .32558 m .6132 .3501 L .59313 .33869 L p .72 .536 .64 r
F P
0 g
s
.6132 .3501 m .62986 .32558 L .65112 .33725 L p .686 .49 .617 r
F P
0 g
s
.67149 .3074 m .65112 .33725 L .62986 .32558 L p .673 .502 .646 r
F P
0 g
s
.55425 .31557 m .56539 .28776 L .58612 .30033 L p .783 .616 .673 r
F P
0 g
s
.58612 .30033 m .57322 .32702 L .55425 .31557 L p .783 .616 .673 r
F P
0 g
s
.6326 .6392 m .65112 .66275 L .62986 .67442 L p .686 .629 .787 r
F P
0 g
s
.62986 .67442 m .6132 .6499 L .6326 .6392 L p .686 .629 .787 r
F P
0 g
s
.58612 .69967 m .57322 .67298 L .59313 .66131 L p .751 .651 .75 r
F P
0 g
s
.57322 .67298 m .58612 .69967 L .56539 .71224 L p .783 .663 .731 r
F P
0 g
s
.58105 .74482 m .56539 .71224 L .58612 .69967 L p .77 .63 .706 r
F P
0 g
s
.31315 .54524 m .2835 .5495 L .28402 .52525 L p .636 .473 .645 r
F P
0 g
s
.28402 .52525 m .31359 .52308 L .31315 .54524 L p .636 .473 .645 r
F P
0 g
s
.28402 .47475 m .31359 .47692 L .31373 .5 L p .641 .538 .722 r
F P
0 g
s
.31359 .47692 m .28402 .47475 L .2835 .4505 L p .636 .565 .758 r
F P
0 g
s
.24746 .44779 m .2835 .4505 L .28402 .47475 L p .669 .592 .76 r
F P
0 g
s
.65112 .33725 m .67149 .3074 L .69236 .31828 L p .633 .45 .617 r
F P
0 g
s
.67149 .3074 m .69185 .27161 L .71269 .28232 L p .615 .465 .654 r
F P
0 g
s
.71269 .28232 m .69236 .31828 L .67149 .3074 L p .615 .465 .654 r
F P
0 g
s
.54652 .27589 m .56119 .24255 L .58105 .25518 L p .803 .669 .716 r
F P
0 g
s
.58105 .25518 m .56539 .28776 L .54652 .27589 L p .803 .669 .716 r
F P
0 g
s
.60187 .21965 m .58105 .25518 L .56119 .24255 L p .783 .681 .751 r
F P
0 g
s
.67083 .65234 m .69236 .68172 L .67149 .6926 L p .633 .583 .781 r
F P
0 g
s
.67149 .6926 m .65112 .66275 L .67083 .65234 L p .633 .583 .781 r
F P
0 g
s
.69185 .72839 m .67149 .6926 L .69236 .68172 L p .615 .54 .746 r
F P
0 g
s
.56539 .71224 m .58105 .74482 L .56119 .75745 L p .803 .642 .683 r
F P
0 g
s
.58105 .74482 m .60187 .78035 L .58217 .79304 L p .783 .598 .65 r
F P
0 g
s
.58217 .79304 m .56119 .75745 L .58105 .74482 L p .783 .598 .65 r
F P
0 g
s
.2835 .4505 m .24746 .44779 L .24645 .42427 L p .662 .621 .798 r
F P
0 g
s
.24746 .44779 m .20628 .44805 L .20513 .42465 L p .703 .653 .797 r
F P
0 g
s
.20513 .42465 m .24645 .42427 L .24746 .44779 L p .703 .653 .797 r
F P
0 g
s
.28266 .57177 m .24645 .57573 L .24746 .55221 L p .662 .46 .601 r
F P
0 g
s
.24746 .55221 m .2835 .5495 L .28266 .57177 L p .662 .46 .601 r
F P
0 g
s
.20628 .55195 m .24746 .55221 L .24645 .57573 L p .703 .495 .604 r
F P
0 g
s
.6675 .79012 m .68625 .8226 L .66886 .83291 L p .67 .475 .613 r
F P
0 g
s
.66886 .83291 m .64657 .80248 L .6675 .79012 L p .67 .475 .613 r
F P
0 g
s
.68625 .8226 m .6675 .79012 L .68867 .77818 L p .64 .465 .63 r
F P
0 g
s
.165 .5 m .12749 .5 L .12726 .47979 L p .793 .661 .718 r
F P
0 g
s
.12726 .47979 m .16476 .47569 L .165 .5 L p .793 .661 .718 r
F P
0 g
s
.12749 .5 m .165 .5 L .16476 .52431 L p .793 .633 .684 r
F P
0 g
s
.6675 .20988 m .68625 .1774 L .70387 .18731 L p .64 .581 .772 r
F P
0 g
s
.70387 .18731 m .68867 .22182 L .6675 .20988 L p .64 .581 .772 r
F P
0 g
s
.68625 .1774 m .6675 .20988 L .64657 .19752 L p .67 .619 .789 r
F P
0 g
s
.69185 .27161 m .70926 .23286 L .72842 .24256 L p .593 .48 .695 r
F P
0 g
s
.72842 .24256 m .71269 .28232 L .69185 .27161 L p .593 .48 .695 r
F P
0 g
s
.69236 .68172 m .71269 .71768 L .69185 .72839 L p .615 .54 .746 r
F P
0 g
s
.70926 .76714 m .69185 .72839 L .71269 .71768 L p .593 .488 .704 r
F P
0 g
s
.69185 .72839 m .70926 .76714 L .68867 .77818 L p .634 .508 .691 r
F P
0 g
s
.60187 .78035 m .62672 .81479 L .60874 .82654 L p .756 .544 .609 r
F P
0 g
s
.60874 .82654 m .58217 .79304 L .60187 .78035 L p .756 .544 .609 r
F P
0 g
s
.56119 .24255 m .58217 .20696 L .60187 .21965 L p .783 .681 .751 r
F P
0 g
s
.62672 .18521 m .60187 .21965 L .58217 .20696 L p .756 .691 .789 r
F P
0 g
s
.60187 .21965 m .62672 .18521 L .64657 .19752 L p .727 .648 .77 r
F P
0 g
s
.20628 .44805 m .16403 .45235 L .16284 .4309 L p .748 .688 .793 r
F P
0 g
s
.16284 .4309 m .20513 .42465 L .20628 .44805 L p .748 .688 .793 r
F P
0 g
s
.24645 .57573 m .20513 .57535 L .20628 .55195 L p .703 .495 .604 r
F P
0 g
s
.16403 .54765 m .20628 .55195 L .20513 .57535 L p .748 .534 .605 r
F P
0 g
s
.20628 .55195 m .16403 .54765 L .16476 .52431 L p .749 .568 .65 r
F P
0 g
s
.12726 .52021 m .16476 .52431 L .16403 .54765 L p .794 .606 .647 r
F P
0 g
s
.16476 .52431 m .12726 .52021 L .12749 .5 L p .793 .633 .684 r
F P
0 g
s
.70387 .81269 m .68867 .77818 L .70926 .76714 L p .606 .449 .642 r
F P
0 g
s
.68867 .77818 m .70387 .81269 L .68625 .8226 L p .64 .465 .63 r
F P
0 g
s
.64657 .80248 m .66886 .83291 L .6524 .84319 L p .696 .48 .59 r
F P
0 g
s
.6524 .84319 m .62672 .81479 L .64657 .80248 L p .696 .48 .59 r
F P
0 g
s
.16476 .47569 m .12726 .47979 L .12659 .46039 L p .794 .691 .751 r
F P
0 g
s
.12659 .46039 m .16403 .45235 L .16476 .47569 L p .794 .691 .751 r
F P
0 g
s
.68867 .22182 m .70387 .18731 L .72101 .19642 L p .606 .541 .755 r
F P
0 g
s
.72101 .19642 m .70926 .23286 L .68867 .22182 L p .606 .541 .755 r
F P
0 g
s
.66886 .16709 m .64657 .19752 L .62672 .18521 L p .696 .657 .807 r
F P
0 g
s
.64657 .19752 m .66886 .16709 L .68625 .1774 L p .67 .619 .789 r
F P
0 g
s
.65112 .33725 m .6326 .3608 L .6132 .3501 L p .686 .49 .617 r
F P
0 g
s
.6326 .3608 m .65112 .33725 L .67083 .34766 L p .646 .437 .585 r
F P
0 g
s
.69236 .31828 m .67083 .34766 L .65112 .33725 L p .633 .45 .617 r
F P
0 g
s
.53699 .3048 m .54652 .27589 L .56539 .28776 L p .818 .658 .684 r
F P
0 g
s
.56539 .28776 m .55425 .31557 L .53699 .3048 L p .818 .658 .684 r
F P
0 g
s
.56539 .71224 m .55425 .68443 L .57322 .67298 L p .783 .663 .731 r
F P
0 g
s
.55425 .68443 m .56539 .71224 L .54652 .72411 L p .818 .678 .709 r
F P
0 g
s
.56119 .75745 m .54652 .72411 L .56539 .71224 L p .803 .642 .683 r
F P
0 g
s
.65055 .62964 m .67083 .65234 L .65112 .66275 L p .646 .619 .808 r
F P
0 g
s
.65112 .66275 m .6326 .6392 L .65055 .62964 L p .646 .619 .808 r
F P
0 g
s
.2835 .4505 m .31315 .45476 L .31359 .47692 L p .636 .565 .758 r
F P
0 g
s
.31315 .45476 m .2835 .4505 L .28266 .42823 L p .625 .591 .796 r
F P
0 g
s
.24645 .42427 m .28266 .42823 L .2835 .4505 L p .662 .621 .798 r
F P
0 g
s
.31245 .56557 m .28266 .57177 L .2835 .5495 L p .625 .429 .597 r
F P
0 g
s
.2835 .5495 m .31315 .54524 L .31245 .56557 L p .625 .429 .597 r
F P
0 g
s
.58125 .35927 m .59313 .33869 L .6132 .3501 L p .729 .527 .618 r
F P
0 g
s
.56338 .34881 m .57322 .32702 L .59313 .33869 L p .761 .568 .636 r
F P
0 g
s
.59313 .33869 m .58125 .35927 L .56338 .34881 L p .761 .568 .636 r
F P
0 g
s
.58125 .64073 m .59313 .66131 L .57322 .67298 L p .761 .674 .767 r
F P
0 g
s
.59924 .63049 m .6132 .6499 L .59313 .66131 L p .729 .663 .785 r
F P
0 g
s
.59313 .66131 m .58125 .64073 L .59924 .63049 L p .729 .663 .785 r
F P
0 g
s
.3375 .5 m .31373 .5 L .31359 .47692 L p .615 .518 .72 r
F P
0 g
s
.33737 .5207 m .31359 .52308 L .31373 .5 L p .615 .487 .683 r
F P
0 g
s
.31373 .5 m .3375 .5 L .33737 .5207 L p .615 .487 .683 r
F P
0 g
s
.6132 .3501 m .59924 .36951 L .58125 .35927 L p .729 .527 .618 r
F P
0 g
s
.59924 .36951 m .6132 .3501 L .6326 .3608 L p .695 .481 .593 r
F P
0 g
s
.54637 .33856 m .55425 .31557 L .57322 .32702 L p .793 .607 .65 r
F P
0 g
s
.57322 .32702 m .56338 .34881 L .54637 .33856 L p .793 .607 .65 r
F P
0 g
s
.57322 .67298 m .56338 .65119 L .58125 .64073 L p .761 .674 .767 r
F P
0 g
s
.56338 .65119 m .57322 .67298 L .55425 .68443 L p .793 .688 .748 r
F P
0 g
s
.61663 .62088 m .6326 .6392 L .6132 .6499 L p .695 .654 .805 r
F P
0 g
s
.6132 .6499 m .59924 .63049 L .61663 .62088 L p .695 .654 .805 r
F P
0 g
s
.337 .54056 m .31315 .54524 L .31359 .52308 L p .609 .451 .642 r
F P
0 g
s
.31359 .52308 m .33737 .5207 L .337 .54056 L p .609 .451 .642 r
F P
0 g
s
.31359 .47692 m .33737 .4793 L .3375 .5 L p .615 .518 .72 r
F P
0 g
s
.33737 .4793 m .31359 .47692 L .31315 .45476 L p .609 .544 .756 r
F P
0 g
s
.20513 .57535 m .16284 .5691 L .16403 .54765 L p .748 .534 .605 r
F P
0 g
s
.12659 .53961 m .16403 .54765 L .16284 .5691 L p .797 .576 .603 r
F P
0 g
s
.16403 .54765 m .12659 .53961 L .12726 .52021 L p .794 .606 .647 r
F P
0 g
s
.71269 .71768 m .72842 .75744 L .70926 .76714 L p .593 .488 .704 r
F P
0 g
s
.72101 .80358 m .70926 .76714 L .72842 .75744 L p .564 .424 .65 r
F P
0 g
s
.70926 .76714 m .72101 .80358 L .70387 .81269 L p .606 .449 .642 r
F P
0 g
s
.16403 .45235 m .12659 .46039 L .1255 .44259 L p .797 .725 .784 r
F P
0 g
s
.1255 .44259 m .16284 .4309 L .16403 .45235 L p .797 .725 .784 r
F P
0 g
s
.62672 .81479 m .6524 .84319 L .63753 .85303 L p .721 .479 .559 r
F P
0 g
s
.63753 .85303 m .60874 .82654 L .62672 .81479 L p .721 .479 .559 r
F P
0 g
s
.70926 .23286 m .72101 .19642 L .73697 .20438 L p .564 .496 .738 r
F P
0 g
s
.73697 .20438 m .72842 .24256 L .70926 .23286 L p .564 .496 .738 r
F P
0 g
s
.58217 .20696 m .60874 .17346 L .62672 .18521 L p .756 .691 .789 r
F P
0 g
s
.6524 .15681 m .62672 .18521 L .60874 .17346 L p .721 .698 .828 r
F P
0 g
s
.62672 .18521 m .6524 .15681 L .66886 .16709 L p .696 .657 .807 r
F P
0 g
s
.67083 .34766 m .69236 .31828 L .71078 .32736 L p .581 .382 .577 r
F P
0 g
s
.69236 .31828 m .71269 .28232 L .73112 .29118 L p .562 .4 .62 r
F P
0 g
s
.73112 .29118 m .71078 .32736 L .69236 .31828 L p .562 .4 .62 r
F P
0 g
s
.5303 .26522 m .54412 .23114 L .56119 .24255 L p .842 .718 .728 r
F P
0 g
s
.56119 .24255 m .54652 .27589 L .5303 .26522 L p .842 .718 .728 r
F P
0 g
s
.58217 .20696 m .56119 .24255 L .54412 .23114 L p .818 .731 .768 r
F P
0 g
s
.54652 .72411 m .56119 .75745 L .54412 .76886 L p .842 .656 .651 r
F P
0 g
s
.56119 .75745 m .58217 .79304 L .56528 .80457 L p .818 .605 .615 r
F P
0 g
s
.56528 .80457 m .54412 .76886 L .56119 .75745 L p .818 .605 .615 r
F P
0 g
s
.68818 .64363 m .71078 .67264 L .69236 .68172 L p .581 .566 .802 r
F P
0 g
s
.69236 .68172 m .67083 .65234 L .68818 .64363 L p .581 .566 .802 r
F P
0 g
s
.71269 .71768 m .69236 .68172 L .71078 .67264 L p .562 .517 .763 r
F P
0 g
s
.28266 .42823 m .24645 .42427 L .2451 .40378 L p .647 .651 .84 r
F P
0 g
s
.24645 .42427 m .20513 .42465 L .2036 .40425 L p .695 .688 .839 r
F P
0 g
s
.2036 .40425 m .2451 .40378 L .24645 .42427 L p .695 .688 .839 r
F P
0 g
s
.28153 .59115 m .2451 .59622 L .24645 .57573 L p .647 .405 .539 r
F P
0 g
s
.24645 .57573 m .28266 .57177 L .28153 .59115 L p .647 .405 .539 r
F P
0 g
s
.20513 .57535 m .24645 .57573 L .2451 .59622 L p .695 .446 .543 r
F P
0 g
s
.71078 .67264 m .73112 .70882 L .71269 .71768 L p .562 .517 .763 r
F P
0 g
s
.72842 .75744 m .71269 .71768 L .73112 .70882 L p .537 .458 .713 r
F P
0 g
s
.2451 .59622 m .2036 .59575 L .20513 .57535 L p .695 .446 .543 r
F P
0 g
s
.16284 .5691 m .20513 .57535 L .2036 .59575 L p .746 .492 .546 r
F P
0 g
s
.54412 .23114 m .56528 .19543 L .58217 .20696 L p .818 .731 .768 r
F P
0 g
s
.60874 .17346 m .58217 .20696 L .56528 .19543 L p .786 .741 .811 r
F P
0 g
s
.71269 .28232 m .72842 .24256 L .74539 .25051 L p .537 .42 .667 r
F P
0 g
s
.74539 .25051 m .73112 .29118 L .71269 .28232 L p .537 .42 .667 r
F P
0 g
s
.58217 .79304 m .60874 .82654 L .59337 .83726 L p .786 .544 .57 r
F P
0 g
s
.59337 .83726 m .56528 .80457 L .58217 .79304 L p .786 .544 .57 r
F P
0 g
s
.20513 .42465 m .16284 .4309 L .16124 .41223 L p .746 .727 .834 r
F P
0 g
s
.16124 .41223 m .2036 .40425 L .20513 .42465 L p .746 .727 .834 r
F P
0 g
s
.6326 .3608 m .61663 .37912 L .59924 .36951 L p .695 .481 .593 r
F P
0 g
s
.61663 .37912 m .6326 .3608 L .65055 .37036 L p .656 .426 .559 r
F P
0 g
s
.67083 .34766 m .65055 .37036 L .6326 .3608 L p .646 .437 .585 r
F P
0 g
s
.5309 .32895 m .53699 .3048 L .55425 .31557 L p .828 .648 .659 r
F P
0 g
s
.55425 .31557 m .54637 .33856 L .5309 .32895 L p .828 .648 .659 r
F P
0 g
s
.63269 .61229 m .65055 .62964 L .6326 .6392 L p .656 .645 .828 r
F P
0 g
s
.6326 .6392 m .61663 .62088 L .63269 .61229 L p .656 .645 .828 r
F P
0 g
s
.55425 .68443 m .54637 .66144 L .56338 .65119 L p .793 .688 .748 r
F P
0 g
s
.54637 .66144 m .55425 .68443 L .53699 .6952 L p .828 .705 .728 r
F P
0 g
s
.54652 .72411 m .53699 .6952 L .55425 .68443 L p .818 .678 .709 r
F P
0 g
s
.33641 .55877 m .31245 .56557 L .31315 .54524 L p .596 .405 .593 r
F P
0 g
s
.31315 .54524 m .337 .54056 L .33641 .55877 L p .596 .405 .593 r
F P
0 g
s
.31315 .45476 m .337 .45944 L .33737 .4793 L p .609 .544 .756 r
F P
0 g
s
.337 .45944 m .31315 .45476 L .31245 .43443 L p .596 .568 .793 r
F P
0 g
s
.28266 .42823 m .31245 .43443 L .31315 .45476 L p .625 .591 .796 r
F P
0 g
s
.57164 .37591 m .58125 .35927 L .59924 .36951 L p .734 .52 .602 r
F P
0 g
s
.55572 .36659 m .56338 .34881 L .58125 .35927 L p .766 .561 .621 r
F P
0 g
s
.58125 .35927 m .57164 .37591 L .55572 .36659 L p .766 .561 .621 r
F P
0 g
s
.57164 .62409 m .58125 .64073 L .56338 .65119 L p .766 .69 .778 r
F P
0 g
s
.58767 .61496 m .59924 .63049 L .58125 .64073 L p .734 .679 .797 r
F P
0 g
s
.58125 .64073 m .57164 .62409 L .58767 .61496 L p .734 .679 .797 r
F P
0 g
s
.35672 .5 m .3375 .5 L .33737 .4793 L p .598 .503 .718 r
F P
0 g
s
.35661 .51845 m .33737 .5207 L .3375 .5 L p .598 .473 .681 r
F P
0 g
s
.3375 .5 m .35672 .5 L .35661 .51845 L p .598 .473 .681 r
F P
0 g
s
.65055 .37036 m .67083 .34766 L .68818 .35637 L p .595 .366 .539 r
F P
0 g
s
.71078 .32736 m .68818 .35637 L .67083 .34766 L p .581 .382 .577 r
F P
0 g
s
.52216 .29516 m .5303 .26522 L .54652 .27589 L p .858 .705 .691 r
F P
0 g
s
.54652 .27589 m .53699 .3048 L .52216 .29516 L p .858 .705 .691 r
F P
0 g
s
.66632 .62161 m .68818 .64363 L .67083 .65234 L p .595 .605 .832 r
F P
0 g
s
.67083 .65234 m .65055 .62964 L .66632 .62161 L p .595 .605 .832 r
F P
0 g
s
.53699 .6952 m .54652 .72411 L .5303 .73478 L p .858 .696 .68 r
F P
0 g
s
.54412 .76886 m .5303 .73478 L .54652 .72411 L p .842 .656 .651 r
F P
0 g
s
.31245 .43443 m .28266 .42823 L .28153 .40885 L p .604 .617 .838 r
F P
0 g
s
.2451 .40378 m .28153 .40885 L .28266 .42823 L p .647 .651 .84 r
F P
0 g
s
.31153 .58323 m .28153 .59115 L .28266 .57177 L p .604 .369 .534 r
F P
0 g
s
.28266 .57177 m .31245 .56557 L .31153 .58323 L p .604 .369 .534 r
F P
0 g
s
.12749 .5 m .09926 .5 L .09907 .48486 L p .84 .699 .707 r
F P
0 g
s
.09907 .48486 m .12726 .47979 L .12749 .5 L p .84 .699 .707 r
F P
0 g
s
.09926 .5 m .12749 .5 L .12726 .52021 L p .84 .673 .675 r
F P
0 g
s
.68625 .8226 m .70037 .84705 L .68735 .85478 L p .63 .403 .554 r
F P
0 g
s
.68735 .85478 m .66886 .83291 L .68625 .8226 L p .63 .403 .554 r
F P
0 g
s
.70037 .84705 m .68625 .8226 L .70387 .81269 L p .603 .393 .57 r
F P
0 g
s
.68625 .1774 m .70037 .15295 L .71357 .16036 L p .603 .591 .812 r
F P
0 g
s
.71357 .16036 m .70387 .18731 L .68625 .1774 L p .603 .591 .812 r
F P
0 g
s
.70037 .15295 m .68625 .1774 L .66886 .16709 L p .63 .627 .828 r
F P
0 g
s
.54057 .35747 m .54637 .33856 L .56338 .34881 L p .799 .601 .634 r
F P
0 g
s
.56338 .34881 m .55572 .36659 L .54057 .35747 L p .799 .601 .634 r
F P
0 g
s
.59924 .36951 m .58767 .38504 L .57164 .37591 L p .734 .52 .602 r
F P
0 g
s
.58767 .38504 m .59924 .36951 L .61663 .37912 L p .701 .474 .577 r
F P
0 g
s
.60315 .6064 m .61663 .62088 L .59924 .63049 L p .701 .67 .817 r
F P
0 g
s
.59924 .63049 m .58767 .61496 L .60315 .6064 L p .701 .67 .817 r
F P
0 g
s
.56338 .65119 m .55572 .63341 L .57164 .62409 L p .766 .69 .778 r
F P
0 g
s
.55572 .63341 m .56338 .65119 L .54637 .66144 L p .799 .704 .76 r
F P
0 g
s
.33737 .4793 m .35661 .48155 L .35672 .5 L p .598 .503 .718 r
F P
0 g
s
.35661 .48155 m .33737 .4793 L .337 .45944 L p .591 .529 .754 r
F P
0 g
s
.35628 .53614 m .337 .54056 L .33737 .5207 L p .591 .436 .64 r
F P
0 g
s
.33737 .5207 m .35661 .51845 L .35628 .53614 L p .591 .436 .64 r
F P
0 g
s
.12726 .47979 m .09907 .48486 L .09853 .47035 L p .843 .728 .737 r
F P
0 g
s
.09853 .47035 m .12659 .46039 L .12726 .47979 L p .843 .728 .737 r
F P
0 g
s
.09907 .51514 m .12726 .52021 L .12659 .53961 L p .843 .648 .639 r
F P
0 g
s
.12726 .52021 m .09907 .51514 L .09926 .5 L p .84 .673 .675 r
F P
0 g
s
.71357 .83964 m .70387 .81269 L .72101 .80358 L p .569 .375 .579 r
F P
0 g
s
.70387 .81269 m .71357 .83964 L .70037 .84705 L p .603 .393 .57 r
F P
0 g
s
.66886 .83291 m .68735 .85478 L .67506 .8625 L p .653 .404 .53 r
F P
0 g
s
.67506 .8625 m .6524 .84319 L .66886 .83291 L p .653 .404 .53 r
F P
0 g
s
.70387 .18731 m .71357 .16036 L .72641 .16715 L p .569 .554 .798 r
F P
0 g
s
.72641 .16715 m .72101 .19642 L .70387 .18731 L p .569 .554 .798 r
F P
0 g
s
.68735 .14522 m .66886 .16709 L .6524 .15681 L p .653 .663 .847 r
F P
0 g
s
.66886 .16709 m .68735 .14522 L .70037 .15295 L p .63 .627 .828 r
F P
0 g
s
.2036 .59575 m .16124 .58777 L .16284 .5691 L p .746 .492 .546 r
F P
0 g
s
.1255 .55741 m .16284 .5691 L .16124 .58777 L p .8 .541 .547 r
F P
0 g
s
.16284 .5691 m .1255 .55741 L .12659 .53961 L p .797 .576 .603 r
F P
0 g
s
.73112 .70882 m .74539 .74949 L .72842 .75744 L p .537 .458 .713 r
F P
0 g
s
.73697 .79562 m .72842 .75744 L .74539 .74949 L p .507 .387 .651 r
F P
0 g
s
.72842 .75744 m .73697 .79562 L .72101 .80358 L p .564 .424 .65 r
F P
0 g
s
.16284 .4309 m .1255 .44259 L .12403 .42714 L p .8 .766 .821 r
F P
0 g
s
.12403 .42714 m .16124 .41223 L .16284 .4309 L p .8 .766 .821 r
F P
0 g
s
.56528 .19543 m .59337 .16274 L .60874 .17346 L p .786 .741 .811 r
F P
0 g
s
.63753 .14697 m .60874 .17346 L .59337 .16274 L p .744 .746 .853 r
F P
0 g
s
.60874 .17346 m .63753 .14697 L .6524 .15681 L p .721 .698 .828 r
F P
0 g
s
.60874 .82654 m .63753 .85303 L .62489 .86203 L p .744 .469 .514 r
F P
0 g
s
.62489 .86203 m .59337 .83726 L .60874 .82654 L p .744 .469 .514 r
F P
0 g
s
.72842 .24256 m .73697 .20438 L .75108 .21083 L p .507 .44 .716 r
F P
0 g
s
.75108 .21083 m .74539 .25051 L .72842 .24256 L p .507 .44 .716 r
F P
0 g
s
.61663 .37912 m .60315 .3936 L .58767 .38504 L p .701 .474 .577 r
F P
0 g
s
.60315 .3936 m .61663 .37912 L .63269 .38771 L p .661 .418 .541 r
F P
0 g
s
.65055 .37036 m .63269 .38771 L .61663 .37912 L p .656 .426 .559 r
F P
0 g
s
.5268 .34893 m .5309 .32895 L .54637 .33856 L p .834 .641 .641 r
F P
0 g
s
.54637 .33856 m .54057 .35747 L .5268 .34893 L p .834 .641 .641 r
F P
0 g
s
.61743 .59875 m .63269 .61229 L .61663 .62088 L p .661 .662 .84 r
F P
0 g
s
.61663 .62088 m .60315 .6064 L .61743 .59875 L p .661 .662 .84 r
F P
0 g
s
.54637 .66144 m .54057 .64253 L .55572 .63341 L p .799 .704 .76 r
F P
0 g
s
.54057 .64253 m .54637 .66144 L .5309 .67105 L p .834 .722 .74 r
F P
0 g
s
.53699 .6952 m .5309 .67105 L .54637 .66144 L p .828 .705 .728 r
F P
0 g
s
.337 .45944 m .35628 .46386 L .35661 .48155 L p .591 .529 .754 r
F P
0 g
s
.35628 .46386 m .337 .45944 L .33641 .44123 L p .576 .552 .79 r
F P
0 g
s
.31245 .43443 m .33641 .44123 L .337 .45944 L p .596 .568 .793 r
F P
0 g
s
.35577 .55233 m .33641 .55877 L .337 .54056 L p .576 .389 .591 r
F P
0 g
s
.337 .54056 m .35628 .53614 L .35577 .55233 L p .576 .389 .591 r
F P
0 g
s
.63269 .38771 m .65055 .37036 L .66632 .37839 L p .605 .353 .509 r
F P
0 g
s
.68818 .35637 m .66632 .37839 L .65055 .37036 L p .595 .366 .539 r
F P
0 g
s
.51761 .32038 m .52216 .29516 L .53699 .3048 L p .869 .693 .661 r
F P
0 g
s
.53699 .3048 m .5309 .32895 L .51761 .32038 L p .869 .693 .661 r
F P
0 g
s
.5309 .67105 m .53699 .6952 L .52216 .70484 L p .869 .726 .701 r
F P
0 g
s
.5303 .73478 m .52216 .70484 L .53699 .6952 L p .858 .696 .68 r
F P
0 g
s
.64674 .60506 m .66632 .62161 L .65055 .62964 L p .605 .635 .854 r
F P
0 g
s
.65055 .62964 m .63269 .61229 L .64674 .60506 L p .605 .635 .854 r
F P
0 g
s
.33641 .44123 m .31245 .43443 L .31153 .41677 L p .57 .59 .834 r
F P
0 g
s
.28153 .40885 m .31153 .41677 L .31245 .43443 L p .604 .617 .838 r
F P
0 g
s
.33564 .57455 m .31153 .58323 L .31245 .56557 L p .57 .341 .529 r
F P
0 g
s
.31245 .56557 m .33641 .55877 L .33564 .57455 L p .57 .341 .529 r
F P
0 g
s
.09853 .52965 m .12659 .53961 L .1255 .55741 L p .848 .623 .597 r
F P
0 g
s
.12659 .53961 m .09853 .52965 L .09907 .51514 L p .843 .648 .639 r
F P
0 g
s
.12659 .46039 m .09853 .47035 L .09766 .45706 L p .848 .762 .767 r
F P
0 g
s
.09766 .45706 m .1255 .44259 L .12659 .46039 L p .848 .762 .767 r
F P
0 g
s
.72641 .83285 m .72101 .80358 L .73697 .79562 L p .525 .346 .581 r
F P
0 g
s
.72101 .80358 m .72641 .83285 L .71357 .83964 L p .569 .375 .579 r
F P
0 g
s
.72101 .19642 m .72641 .16715 L .73836 .17303 L p .525 .512 .783 r
F P
0 g
s
.73836 .17303 m .73697 .20438 L .72101 .19642 L p .525 .512 .783 r
F P
0 g
s
.6524 .84319 m .67506 .8625 L .66398 .86991 L p .673 .397 .496 r
F P
0 g
s
.66398 .86991 m .63753 .85303 L .6524 .84319 L p .673 .397 .496 r
F P
0 g
s
.67506 .1375 m .6524 .15681 L .63753 .14697 L p .673 .701 .868 r
F P
0 g
s
.6524 .15681 m .67506 .1375 L .68735 .14522 L p .653 .663 .847 r
F P
0 g
s
.5637 .38967 m .57164 .37591 L .58767 .38504 L p .737 .517 .595 r
F P
0 g
s
.54949 .38134 m .55572 .36659 L .57164 .37591 L p .769 .558 .613 r
F P
0 g
s
.57164 .37591 m .5637 .38967 L .54949 .38134 L p .769 .558 .613 r
F P
0 g
s
.5637 .61033 m .57164 .62409 L .55572 .63341 L p .769 .697 .783 r
F P
0 g
s
.57802 .60219 m .58767 .61496 L .57164 .62409 L p .737 .686 .802 r
F P
0 g
s
.57164 .62409 m .5637 .61033 L .57802 .60219 L p .737 .686 .802 r
F P
0 g
s
.3726 .5 m .35672 .5 L .35661 .48155 L p .59 .496 .717 r
F P
0 g
s
.37249 .51647 m .35661 .51845 L .35672 .5 L p .59 .466 .68 r
F P
0 g
s
.35672 .5 m .3726 .5 L .37249 .51647 L p .59 .466 .68 r
F P
0 g
s
.68818 .35637 m .71078 .32736 L .72597 .33423 L p .503 .284 .513 r
F P
0 g
s
.71078 .32736 m .73112 .29118 L .74636 .29781 L p .483 .308 .568 r
F P
0 g
s
.74636 .29781 m .72597 .33423 L .71078 .32736 L p .483 .308 .568 r
F P
0 g
s
.70243 .63697 m .72597 .66577 L .71078 .67264 L p .503 .539 .826 r
F P
0 g
s
.71078 .67264 m .68818 .64363 L .70243 .63697 L p .503 .539 .826 r
F P
0 g
s
.73112 .70882 m .71078 .67264 L .72597 .66577 L p .483 .48 .778 r
F P
0 g
s
.5174 .25621 m .53058 .22142 L .54412 .23114 L p .888 .778 .735 r
F P
0 g
s
.54412 .23114 m .5303 .26522 L .5174 .25621 L p .888 .778 .735 r
F P
0 g
s
.56528 .19543 m .54412 .23114 L .53058 .22142 L p .859 .793 .785 r
F P
0 g
s
.28017 .60682 m .24346 .61281 L .2451 .59622 L p .617 .323 .448 r
F P
0 g
s
.2451 .59622 m .28153 .59115 L .28017 .60682 L p .617 .323 .448 r
F P
0 g
s
.2036 .59575 m .2451 .59622 L .24346 .61281 L p .677 .375 .456 r
F P
0 g
s
.28153 .40885 m .2451 .40378 L .24346 .38719 L p .617 .685 .891 r
F P
0 g
s
.2451 .40378 m .2036 .40425 L .20172 .38774 L p .677 .73 .89 r
F P
0 g
s
.20172 .38774 m .24346 .38719 L .2451 .40378 L p .677 .73 .89 r
F P
0 g
s
.5303 .73478 m .54412 .76886 L .53058 .77858 L p .888 .671 .604 r
F P
0 g
s
.54412 .76886 m .56528 .80457 L .55192 .81445 L p .859 .61 .561 r
F P
0 g
s
.55192 .81445 m .53058 .77858 L .54412 .76886 L p .859 .61 .561 r
F P
0 g
s
.73112 .29118 m .74539 .25051 L .75943 .25636 L p .456 .335 .626 r
F P
0 g
s
.75943 .25636 m .74636 .29781 L .73112 .29118 L p .456 .335 .626 r
F P
0 g
s
.72597 .66577 m .74636 .70219 L .73112 .70882 L p .483 .48 .778 r
F P
0 g
s
.74539 .74949 m .73112 .70882 L .74636 .70219 L p .456 .41 .718 r
F P
0 g
s
.24346 .61281 m .20172 .61226 L .2036 .59575 L p .677 .375 .456 r
F P
0 g
s
.16124 .58777 m .2036 .59575 L .20172 .61226 L p .74 .433 .462 r
F P
0 g
s
.53058 .22142 m .55192 .18555 L .56528 .19543 L p .859 .793 .785 r
F P
0 g
s
.59337 .16274 m .56528 .19543 L .55192 .18555 L p .82 .803 .836 r
F P
0 g
s
.56528 .80457 m .59337 .83726 L .58128 .8465 L p .82 .536 .508 r
F P
0 g
s
.58128 .8465 m .55192 .81445 L .56528 .80457 L p .82 .536 .508 r
F P
0 g
s
.2036 .40425 m .16124 .41223 L .15928 .39714 L p .74 .775 .882 r
F P
0 g
s
.15928 .39714 m .20172 .38774 L .2036 .40425 L p .74 .775 .882 r
F P
0 g
s
.53597 .37319 m .54057 .35747 L .55572 .36659 L p .801 .598 .626 r
F P
0 g
s
.55572 .36659 m .54949 .38134 L .53597 .37319 L p .801 .598 .626 r
F P
0 g
s
.58767 .38504 m .57802 .39781 L .5637 .38967 L p .737 .517 .595 r
F P
0 g
s
.57802 .39781 m .58767 .38504 L .60315 .3936 L p .703 .471 .569 r
F P
0 g
s
.59184 .59456 m .60315 .6064 L .58767 .61496 L p .703 .677 .822 r
F P
0 g
s
.58767 .61496 m .57802 .60219 L .59184 .59456 L p .703 .677 .822 r
F P
0 g
s
.55572 .63341 m .54949 .61866 L .5637 .61033 L p .769 .697 .783 r
F P
0 g
s
.54949 .61866 m .55572 .63341 L .54057 .64253 L p .801 .711 .765 r
F P
0 g
s
.35661 .48155 m .37249 .48353 L .3726 .5 L p .59 .496 .717 r
F P
0 g
s
.37249 .48353 m .35661 .48155 L .35628 .46386 L p .583 .522 .752 r
F P
0 g
s
.37219 .53226 m .35628 .53614 L .35661 .51845 L p .583 .429 .639 r
F P
0 g
s
.35661 .51845 m .37249 .51647 L .37219 .53226 L p .583 .429 .639 r
F P
0 g
s
.66632 .37839 m .68818 .35637 L .70243 .36303 L p .519 .262 .465 r
F P
0 g
s
.72597 .33423 m .70243 .36303 L .68818 .35637 L p .503 .284 .513 r
F P
0 g
s
.51037 .28708 m .5174 .25621 L .5303 .26522 L p .907 .762 .689 r
F P
0 g
s
.5303 .26522 m .52216 .29516 L .51037 .28708 L p .907 .762 .689 r
F P
0 g
s
.67921 .61544 m .70243 .63697 L .68818 .64363 L p .519 .585 .861 r
F P
0 g
s
.68818 .64363 m .66632 .62161 L .67921 .61544 L p .519 .585 .861 r
F P
0 g
s
.31153 .41677 m .28153 .40885 L .28017 .39318 L p .564 .643 .887 r
F P
0 g
s
.24346 .38719 m .28017 .39318 L .28153 .40885 L p .617 .685 .891 r
F P
0 g
s
.52216 .70484 m .5303 .73478 L .5174 .74379 L p .907 .719 .637 r
F P
0 g
s
.53058 .77858 m .5174 .74379 L .5303 .73478 L p .888 .671 .604 r
F P
0 g
s
.31042 .59748 m .28017 .60682 L .28153 .59115 L p .564 .278 .439 r
F P
0 g
s
.28153 .59115 m .31153 .58323 L .31042 .59748 L p .564 .278 .439 r
F P
0 g
s
.63269 .38771 m .61743 .40125 L .60315 .3936 L p .661 .418 .541 r
F P
0 g
s
.61743 .40125 m .63269 .38771 L .64674 .39494 L p .611 .344 .488 r
F P
0 g
s
.66632 .37839 m .64674 .39494 L .63269 .38771 L p .605 .353 .509 r
F P
0 g
s
.515 .34134 m .51761 .32038 L .5309 .32895 L p .876 .685 .641 r
F P
0 g
s
.5309 .32895 m .5268 .34893 L .515 .34134 L p .876 .685 .641 r
F P
0 g
s
.6299 .59232 m .64674 .60506 L .63269 .61229 L p .611 .654 .868 r
F P
0 g
s
.63269 .61229 m .61743 .59875 L .6299 .59232 L p .611 .654 .868 r
F P
0 g
s
.5309 .67105 m .5268 .65107 L .54057 .64253 L p .834 .722 .74 r
F P
0 g
s
.5268 .65107 m .5309 .67105 L .51761 .67962 L p .876 .745 .715 r
F P
0 g
s
.52216 .70484 m .51761 .67962 L .5309 .67105 L p .869 .726 .701 r
F P
0 g
s
.33641 .44123 m .35577 .44767 L .35628 .46386 L p .576 .552 .79 r
F P
0 g
s
.35577 .44767 m .33641 .44123 L .33564 .42545 L p .547 .572 .831 r
F P
0 g
s
.31153 .41677 m .33564 .42545 L .33641 .44123 L p .57 .59 .834 r
F P
0 g
s
.3551 .56634 m .33564 .57455 L .33641 .55877 L p .547 .322 .525 r
F P
0 g
s
.33641 .55877 m .35577 .55233 L .3551 .56634 L p .547 .322 .525 r
F P
0 g
s
.52371 .36556 m .5268 .34893 L .54057 .35747 L p .837 .638 .633 r
F P
0 g
s
.54057 .35747 m .53597 .37319 L .52371 .36556 L p .837 .638 .633 r
F P
0 g
s
.60315 .3936 m .59184 .40544 L .57802 .39781 L p .703 .471 .569 r
F P
0 g
s
.59184 .40544 m .60315 .3936 L .61743 .40125 L p .664 .415 .533 r
F P
0 g
s
.60457 .58775 m .61743 .59875 L .60315 .6064 L p .664 .67 .845 r
F P
0 g
s
.60315 .6064 m .59184 .59456 L .60457 .58775 L p .664 .67 .845 r
F P
0 g
s
.54057 .64253 m .53597 .62681 L .54949 .61866 L p .801 .711 .765 r
F P
0 g
s
.53597 .62681 m .54057 .64253 L .5268 .65107 L p .837 .729 .745 r
F P
0 g
s
.37172 .54669 m .35577 .55233 L .35628 .53614 L p .566 .381 .589 r
F P
0 g
s
.35628 .53614 m .37219 .53226 L .37172 .54669 L p .566 .381 .589 r
F P
0 g
s
.35628 .46386 m .37219 .46774 L .37249 .48353 L p .583 .522 .752 r
F P
0 g
s
.37219 .46774 m .35628 .46386 L .35577 .44767 L p .566 .544 .789 r
F P
0 g
s
.74539 .74949 m .75108 .78917 L .73697 .79562 L p .507 .387 .651 r
F P
0 g
s
.73836 .82697 m .73697 .79562 L .75108 .78917 L p .467 .301 .573 r
F P
0 g
s
.73697 .79562 m .73836 .82697 L .72641 .83285 L p .525 .346 .581 r
F P
0 g
s
.16124 .58777 m .12403 .57286 L .1255 .55741 L p .8 .541 .547 r
F P
0 g
s
.09766 .54294 m .1255 .55741 L .12403 .57286 L p .856 .595 .542 r
F P
0 g
s
.1255 .55741 m .09766 .54294 L .09853 .52965 L p .848 .623 .597 r
F P
0 g
s
.1255 .44259 m .09766 .45706 L .09648 .44555 L p .856 .803 .798 r
F P
0 g
s
.09648 .44555 m .12403 .42714 L .1255 .44259 L p .856 .803 .798 r
F P
0 g
s
.59337 .16274 m .62489 .13797 L .63753 .14697 L p .744 .746 .853 r
F P
0 g
s
.66398 .13009 m .63753 .14697 L .62489 .13797 L p .688 .745 .895 r
F P
0 g
s
.63753 .14697 m .66398 .13009 L .67506 .1375 L p .673 .701 .868 r
F P
0 g
s
.63753 .85303 m .66398 .86991 L .65461 .87668 L p .688 .378 .445 r
F P
0 g
s
.65461 .87668 m .62489 .86203 L .63753 .85303 L p .688 .378 .445 r
F P
0 g
s
.73697 .20438 m .73836 .17303 L .74891 .17776 L p .467 .46 .767 r
F P
0 g
s
.74891 .17776 m .75108 .21083 L .73697 .20438 L p .467 .46 .767 r
F P
0 g
s
.20172 .61226 m .15928 .60286 L .16124 .58777 L p .74 .433 .462 r
F P
0 g
s
.12403 .57286 m .16124 .58777 L .15928 .60286 L p .804 .494 .466 r
F P
0 g
s
.74539 .25051 m .75108 .21083 L .76276 .2155 L p .423 .363 .686 r
F P
0 g
s
.76276 .2155 m .75943 .25636 L .74539 .25051 L p .423 .363 .686 r
F P
0 g
s
.74636 .70219 m .75943 .74364 L .74539 .74949 L p .456 .41 .718 r
F P
0 g
s
.75108 .78917 m .74539 .74949 L .75943 .74364 L p .423 .328 .643 r
F P
0 g
s
.59337 .83726 m .62489 .86203 L .615 .86981 L p .766 .446 .445 r
F P
0 g
s
.615 .86981 m .58128 .8465 L .59337 .83726 L p .766 .446 .445 r
F P
0 g
s
.55192 .18555 m .58128 .1535 L .59337 .16274 L p .82 .803 .836 r
F P
0 g
s
.62489 .13797 m .59337 .16274 L .58128 .1535 L p .766 .805 .884 r
F P
0 g
s
.16124 .41223 m .12403 .42714 L .12224 .41469 L p .804 .818 .862 r
F P
0 g
s
.12224 .41469 m .15928 .39714 L .16124 .41223 L p .804 .818 .862 r
F P
0 g
s
.55695 .40136 m .5637 .38967 L .57802 .39781 L p .737 .517 .595 r
F P
0 g
s
.54416 .39385 m .54949 .38134 L .5637 .38967 L p .769 .558 .613 r
F P
0 g
s
.5637 .38967 m .55695 .40136 L .54416 .39385 L p .769 .558 .613 r
F P
0 g
s
.55695 .59864 m .5637 .61033 L .54949 .61866 L p .769 .697 .783 r
F P
0 g
s
.56985 .59132 m .57802 .60219 L .5637 .61033 L p .737 .686 .802 r
F P
0 g
s
.5637 .61033 m .55695 .59864 L .56985 .59132 L p .737 .686 .802 r
F P
0 g
s
.3861 .5 m .3726 .5 L .37249 .48353 L p .59 .496 .717 r
F P
0 g
s
.38599 .51483 m .37249 .51647 L .3726 .5 L p .59 .466 .68 r
F P
0 g
s
.3726 .5 m .3861 .5 L .38599 .51483 L p .59 .466 .68 r
F P
0 g
s
.53201 .38649 m .53597 .37319 L .54949 .38134 L p .801 .598 .626 r
F P
0 g
s
.54949 .38134 m .54416 .39385 L .53201 .38649 L p .801 .598 .626 r
F P
0 g
s
.57802 .39781 m .56985 .40868 L .55695 .40136 L p .737 .517 .595 r
F P
0 g
s
.56985 .40868 m .57802 .39781 L .59184 .40544 L p .703 .471 .569 r
F P
0 g
s
.54949 .61866 m .54416 .60615 L .55695 .59864 L p .769 .697 .783 r
F P
0 g
s
.54416 .60615 m .54949 .61866 L .53597 .62681 L p .801 .711 .765 r
F P
0 g
s
.58229 .58448 m .59184 .59456 L .57802 .60219 L p .703 .677 .822 r
F P
0 g
s
.57802 .60219 m .56985 .59132 L .58229 .58448 L p .703 .677 .822 r
F P
0 g
s
.38569 .52903 m .37219 .53226 L .37249 .51647 L p .583 .429 .639 r
F P
0 g
s
.37249 .51647 m .38599 .51483 L .38569 .52903 L p .583 .429 .639 r
F P
0 g
s
.37249 .48353 m .38599 .48517 L .3861 .5 L p .59 .496 .717 r
F P
0 g
s
.38599 .48517 m .37249 .48353 L .37219 .46774 L p .583 .522 .752 r
F P
0 g
s
.64674 .39494 m .66632 .37839 L .67921 .38456 L p .53 .245 .427 r
F P
0 g
s
.70243 .36303 m .67921 .38456 L .66632 .37839 L p .519 .262 .465 r
F P
0 g
s
.50707 .31325 m .51037 .28708 L .52216 .29516 L p .919 .746 .652 r
F P
0 g
s
.52216 .29516 m .51761 .32038 L .50707 .31325 L p .919 .746 .652 r
F P
0 g
s
.6582 .5995 m .67921 .61544 L .66632 .62161 L p .53 .62 .886 r
F P
0 g
s
.66632 .62161 m .64674 .60506 L .6582 .5995 L p .53 .62 .886 r
F P
0 g
s
.51761 .67962 m .52216 .70484 L .51037 .71292 L p .919 .754 .662 r
F P
0 g
s
.5174 .74379 m .51037 .71292 L .52216 .70484 L p .907 .719 .637 r
F P
0 g
s
.33473 .58726 m .31042 .59748 L .31153 .58323 L p .522 .243 .432 r
F P
0 g
s
.31153 .58323 m .33564 .57455 L .33473 .58726 L p .522 .243 .432 r
F P
0 g
s
.33564 .42545 m .31153 .41677 L .31042 .40252 L p .522 .609 .881 r
F P
0 g
s
.28017 .39318 m .31042 .40252 L .31153 .41677 L p .564 .643 .887 r
F P
0 g
s
.09926 .5 m .08119 .5 L .08106 .48977 L p .891 .74 .687 r
F P
0 g
s
.08106 .48977 m .09907 .48486 L .09926 .5 L p .891 .74 .687 r
F P
0 g
s
.08119 .5 m .09926 .5 L .09907 .51514 L p .891 .716 .657 r
F P
0 g
s
.70037 .84705 m .70941 .8627 L .70061 .86793 L p .575 .309 .475 r
F P
0 g
s
.70061 .86793 m .68735 .85478 L .70037 .84705 L p .575 .309 .475 r
F P
0 g
s
.70941 .8627 m .70037 .84705 L .71357 .83964 L p .55 .3 .49 r
F P
0 g
s
.70037 .15295 m .70941 .1373 L .71833 .1423 L p .55 .598 .855 r
F P
0 g
s
.71833 .1423 m .71357 .16036 L .70037 .15295 L p .55 .598 .855 r
F P
0 g
s
.70941 .1373 m .70037 .15295 L .68735 .14522 L p .575 .631 .869 r
F P
0 g
s
.08106 .51023 m .09907 .51514 L .09853 .52965 L p .895 .694 .624 r
F P
0 g
s
.09907 .51514 m .08106 .51023 L .08119 .5 L p .891 .716 .657 r
F P
0 g
s
.68735 .85478 m .70061 .86793 L .69231 .87316 L p .594 .307 .45 r
F P
0 g
s
.69231 .87316 m .67506 .8625 L .68735 .85478 L p .594 .307 .45 r
F P
0 g
s
.71833 .8577 m .71357 .83964 L .72641 .83285 L p .517 .28 .495 r
F P
0 g
s
.71357 .83964 m .71833 .8577 L .70941 .8627 L p .55 .3 .49 r
F P
0 g
s
.09907 .48486 m .08106 .48977 L .08068 .47997 L p .895 .767 .713 r
F P
0 g
s
.08068 .47997 m .09853 .47035 L .09907 .48486 L p .895 .767 .713 r
F P
0 g
s
.71357 .16036 m .71833 .1423 L .72701 .14687 L p .517 .564 .842 r
F P
0 g
s
.72701 .14687 m .72641 .16715 L .71357 .16036 L p .517 .564 .842 r
F P
0 g
s
.70061 .13207 m .68735 .14522 L .67506 .1375 L p .594 .663 .887 r
F P
0 g
s
.68735 .14522 m .70061 .13207 L .70941 .1373 L p .575 .631 .869 r
F P
0 g
s
.61743 .40125 m .60457 .41225 L .59184 .40544 L p .664 .415 .533 r
F P
0 g
s
.60457 .41225 m .61743 .40125 L .6299 .40768 L p .614 .34 .479 r
F P
0 g
s
.64674 .39494 m .6299 .40768 L .61743 .40125 L p .611 .344 .488 r
F P
0 g
s
.51321 .35881 m .515 .34134 L .5268 .34893 L p .878 .681 .631 r
F P
0 g
s
.5268 .34893 m .52371 .36556 L .51321 .35881 L p .878 .681 .631 r
F P
0 g
s
.61567 .58204 m .6299 .59232 L .61743 .59875 L p .614 .662 .874 r
F P
0 g
s
.61743 .59875 m .60457 .58775 L .61567 .58204 L p .614 .662 .874 r
F P
0 g
s
.5268 .65107 m .52371 .63444 L .53597 .62681 L p .837 .729 .745 r
F P
0 g
s
.52371 .63444 m .5268 .65107 L .515 .65866 L p .878 .754 .721 r
F P
0 g
s
.51761 .67962 m .515 .65866 L .5268 .65107 L p .876 .745 .715 r
F P
0 g
s
.37112 .55916 m .3551 .56634 L .35577 .55233 L p .536 .313 .523 r
F P
0 g
s
.35577 .55233 m .37172 .54669 L .37112 .55916 L p .536 .313 .523 r
F P
0 g
s
.35577 .44767 m .37172 .45331 L .37219 .46774 L p .566 .544 .789 r
F P
0 g
s
.37172 .45331 m .35577 .44767 L .3551 .43366 L p .536 .563 .829 r
F P
0 g
s
.33564 .42545 m .3551 .43366 L .35577 .44767 L p .547 .572 .831 r
F P
0 g
s
.59184 .40544 m .58229 .41552 L .56985 .40868 L p .703 .471 .569 r
F P
0 g
s
.58229 .41552 m .59184 .40544 L .60457 .41225 L p .664 .415 .533 r
F P
0 g
s
.52102 .37961 m .52371 .36556 L .53597 .37319 L p .837 .638 .633 r
F P
0 g
s
.53597 .37319 m .53201 .38649 L .52102 .37961 L p .837 .638 .633 r
F P
0 g
s
.59375 .5784 m .60457 .58775 L .59184 .59456 L p .664 .669 .845 r
F P
0 g
s
.59184 .59456 m .58229 .58448 L .59375 .5784 L p .664 .669 .845 r
F P
0 g
s
.53597 .62681 m .53201 .61351 L .54416 .60615 L p .801 .711 .765 r
F P
0 g
s
.53201 .61351 m .53597 .62681 L .52371 .63444 L p .837 .729 .745 r
F P
0 g
s
.38523 .54199 m .37172 .54669 L .37219 .53226 L p .567 .381 .589 r
F P
0 g
s
.37219 .53226 m .38569 .52903 L .38523 .54199 L p .567 .381 .589 r
F P
0 g
s
.37219 .46774 m .38569 .47097 L .38599 .48517 L p .583 .522 .752 r
F P
0 g
s
.38569 .47097 m .37219 .46774 L .37172 .45331 L p .567 .544 .789 r
F P
0 g
s
.55105 .41159 m .55695 .40136 L .56985 .40868 L p .735 .52 .601 r
F P
0 g
s
.53939 .40473 m .54416 .39385 L .55695 .40136 L p .767 .561 .619 r
F P
0 g
s
.55695 .40136 m .55105 .41159 L .53939 .40473 L p .767 .561 .619 r
F P
0 g
s
.55105 .58841 m .55695 .59864 L .54416 .60615 L p .767 .691 .779 r
F P
0 g
s
.56281 .58175 m .56985 .59132 L .55695 .59864 L p .735 .68 .798 r
F P
0 g
s
.55695 .59864 m .55105 .58841 L .56281 .58175 L p .735 .68 .798 r
F P
0 g
s
.39791 .5 m .3861 .5 L .38599 .48517 L p .596 .502 .718 r
F P
0 g
s
.3978 .51352 m .38599 .51483 L .3861 .5 L p .596 .472 .681 r
F P
0 g
s
.3861 .5 m .39791 .5 L .3978 .51352 L p .596 .472 .681 r
F P
0 g
s
.52835 .39799 m .53201 .38649 L .54416 .39385 L p .799 .6 .633 r
F P
0 g
s
.54416 .39385 m .53939 .40473 L .52835 .39799 L p .799 .6 .633 r
F P
0 g
s
.56985 .40868 m .56281 .41825 L .55105 .41159 L p .735 .52 .601 r
F P
0 g
s
.56281 .41825 m .56985 .40868 L .58229 .41552 L p .701 .474 .576 r
F P
0 g
s
.54416 .60615 m .53939 .59527 L .55105 .58841 L p .767 .691 .779 r
F P
0 g
s
.53939 .59527 m .54416 .60615 L .53201 .61351 L p .799 .705 .761 r
F P
0 g
s
.57417 .57556 m .58229 .58448 L .56985 .59132 L p .701 .671 .818 r
F P
0 g
s
.56985 .59132 m .56281 .58175 L .57417 .57556 L p .701 .671 .818 r
F P
0 g
s
.38599 .48517 m .3978 .48648 L .39791 .5 L p .596 .502 .718 r
F P
0 g
s
.3978 .48648 m .38599 .48517 L .38569 .47097 L p .59 .528 .753 r
F P
0 g
s
.39748 .52645 m .38569 .52903 L .38599 .51483 L p .59 .435 .64 r
F P
0 g
s
.38599 .51483 m .3978 .51352 L .39748 .52645 L p .59 .435 .64 r
F P
0 g
s
.6299 .40768 m .64674 .39494 L .6582 .4005 L p .536 .234 .402 r
F P
0 g
s
.67921 .38456 m .6582 .4005 L .64674 .39494 L p .53 .245 .427 r
F P
0 g
s
.50564 .33505 m .50707 .31325 L .51761 .32038 L p .925 .735 .627 r
F P
0 g
s
.51761 .32038 m .515 .34134 L .50564 .33505 L p .925 .735 .627 r
F P
0 g
s
.515 .65866 m .51761 .67962 L .50707 .68675 L p .925 .776 .676 r
F P
0 g
s
.64003 .58736 m .6582 .5995 L .64674 .60506 L p .536 .642 .901 r
F P
0 g
s
.64674 .60506 m .6299 .59232 L .64003 .58736 L p .536 .642 .901 r
F P
0 g
s
.51037 .71292 m .50707 .68675 L .51761 .67962 L p .919 .754 .662 r
F P
0 g
s
.3551 .43366 m .33564 .42545 L .33473 .41274 L p .493 .586 .876 r
F P
0 g
s
.31042 .40252 m .33473 .41274 L .33564 .42545 L p .522 .609 .881 r
F P
0 g
s
.35433 .57759 m .33473 .58726 L .33564 .57455 L p .493 .219 .427 r
F P
0 g
s
.33564 .57455 m .3551 .56634 L .35433 .57759 L p .493 .219 .427 r
F P
0 g
s
.08068 .52003 m .09853 .52965 L .09766 .54294 L p .901 .673 .583 r
F P
0 g
s
.09853 .52965 m .08068 .52003 L .08106 .51023 L p .895 .694 .624 r
F P
0 g
s
.72701 .85313 m .72641 .83285 L .73836 .82697 L p .473 .247 .49 r
F P
0 g
s
.72641 .83285 m .72701 .85313 L .71833 .8577 L p .517 .28 .495 r
F P
0 g
s
.69231 .12684 m .67506 .1375 L .66398 .13009 L p .606 .697 .908 r
F P
0 g
s
.67506 .1375 m .69231 .12684 L .70061 .13207 L p .594 .663 .887 r
F P
0 g
s
.67506 .8625 m .69231 .87316 L .68487 .87817 L p .606 .293 .413 r
F P
0 g
s
.68487 .87817 m .66398 .86991 L .67506 .8625 L p .606 .293 .413 r
F P
0 g
s
.09853 .47035 m .08068 .47997 L .08006 .47101 L p .901 .799 .737 r
F P
0 g
s
.08006 .47101 m .09766 .45706 L .09853 .47035 L p .901 .799 .737 r
F P
0 g
s
.72641 .16715 m .72701 .14687 L .73507 .15082 L p .473 .525 .831 r
F P
0 g
s
.73507 .15082 m .73836 .17303 L .72641 .16715 L p .473 .525 .831 r
F P
0 g
s
.12403 .42714 m .09648 .44555 L .09504 .43633 L p .866 .855 .829 r
F P
0 g
s
.09504 .43633 m .12224 .41469 L .12403 .42714 L p .866 .855 .829 r
F P
0 g
s
.62489 .86203 m .65461 .87668 L .64734 .88254 L p .695 .339 .368 r
F P
0 g
s
.64734 .88254 m .615 .86981 L .62489 .86203 L p .695 .339 .368 r
F P
0 g
s
.15928 .60286 m .12224 .58531 L .12403 .57286 L p .804 .494 .466 r
F P
0 g
s
.09648 .55445 m .12403 .57286 L .12224 .58531 L p .866 .559 .466 r
F P
0 g
s
.12403 .57286 m .09648 .55445 L .09766 .54294 L p .856 .595 .542 r
F P
0 g
s
.75108 .21083 m .74891 .17776 L .75762 .18113 L p .381 .392 .746 r
F P
0 g
s
.75762 .18113 m .76276 .2155 L .75108 .21083 L p .381 .392 .746 r
F P
0 g
s
.75943 .74364 m .76276 .7845 L .75108 .78917 L p .423 .328 .643 r
F P
0 g
s
.74891 .82224 m .75108 .78917 L .76276 .7845 L p .381 .231 .549 r
F P
0 g
s
.75108 .78917 m .74891 .82224 L .73836 .82697 L p .467 .301 .573 r
F P
0 g
s
.58128 .1535 m .615 .13019 L .62489 .13797 L p .766 .805 .884 r
F P
0 g
s
.65461 .12332 m .62489 .13797 L .615 .13019 L p .695 .796 .927 r
F P
0 g
s
.62489 .13797 m .65461 .12332 L .66398 .13009 L p .688 .745 .895 r
F P
0 g
s
.70243 .36303 m .72597 .33423 L .73724 .33859 L p .37 .118 .397 r
F P
0 g
s
.72597 .33423 m .74636 .29781 L .75772 .3019 L p .347 .155 .472 r
F P
0 g
s
.75772 .3019 m .73724 .33859 L .72597 .33423 L p .347 .155 .472 r
F P
0 g
s
.71294 .63267 m .73724 .66141 L .72597 .66577 L p .37 .485 .846 r
F P
0 g
s
.72597 .66577 m .70243 .63697 L .71294 .63267 L p .37 .485 .846 r
F P
0 g
s
.74636 .70219 m .72597 .66577 L .73724 .66141 L p .347 .411 .786 r
F P
0 g
s
.28017 .39318 m .24346 .38719 L .24159 .37525 L p .553 .721 .952 r
F P
0 g
s
.24346 .38719 m .20172 .38774 L .19958 .37586 L p .634 .782 .952 r
F P
0 g
s
.19958 .37586 m .24159 .37525 L .24346 .38719 L p .634 .782 .952 r
F P
0 g
s
.50842 .24926 m .52117 .21384 L .53058 .22142 L p .942 .855 .727 r
F P
0 g
s
.53058 .22142 m .5174 .25621 L .50842 .24926 L p .942 .855 .727 r
F P
0 g
s
.55192 .18555 m .53058 .22142 L .52117 .21384 L p .906 .875 .795 r
F P
0 g
s
.5174 .74379 m .53058 .77858 L .52117 .78616 L p .942 .683 .516 r
F P
0 g
s
.53058 .77858 m .55192 .81445 L .5427 .82224 L p .906 .604 .463 r
F P
0 g
s
.5427 .82224 m .52117 .78616 L .53058 .77858 L p .906 .604 .463 r
F P
0 g
s
.27864 .61808 m .24159 .62475 L .24346 .61281 L p .553 .182 .291 r
F P
0 g
s
.24346 .61281 m .28017 .60682 L .27864 .61808 L p .553 .182 .291 r
F P
0 g
s
.20172 .61226 m .24346 .61281 L .24159 .62475 L p .634 .255 .306 r
F P
0 g
s
.74636 .29781 m .75943 .25636 L .76992 .25984 L p .319 .197 .553 r
F P
0 g
s
.76992 .25984 m .75772 .3019 L .74636 .29781 L p .319 .197 .553 r
F P
0 g
s
.55192 .81445 m .58128 .8465 L .57302 .85384 L p .853 .508 .4 r
F P
0 g
s
.57302 .85384 m .5427 .82224 L .55192 .81445 L p .853 .508 .4 r
F P
0 g
s
.20172 .38774 m .15928 .39714 L .15705 .38632 L p .719 .838 .939 r
F P
0 g
s
.15705 .38632 m .19958 .37586 L .20172 .38774 L p .719 .838 .939 r
F P
0 g
s
.52117 .21384 m .5427 .17776 L .55192 .18555 L p .906 .875 .795 r
F P
0 g
s
.58128 .1535 m .55192 .18555 L .5427 .17776 L p .853 .885 .861 r
F P
0 g
s
.73724 .66141 m .75772 .6981 L .74636 .70219 L p .347 .411 .786 r
F P
0 g
s
.75943 .74364 m .74636 .70219 L .75772 .6981 L p .319 .324 .708 r
F P
0 g
s
.24159 .62475 m .19958 .62414 L .20172 .61226 L p .634 .255 .306 r
F P
0 g
s
.15928 .60286 m .20172 .61226 L .19958 .62414 L p .719 .335 .322 r
F P
0 g
s
.58229 .41552 m .57417 .42444 L .56281 .41825 L p .701 .474 .576 r
F P
0 g
s
.57417 .42444 m .58229 .41552 L .59375 .4216 L p .662 .418 .541 r
F P
0 g
s
.60457 .41225 m .59375 .4216 L .58229 .41552 L p .664 .415 .533 r
F P
0 g
s
.51839 .39168 m .52102 .37961 L .53201 .38649 L p .835 .641 .64 r
F P
0 g
s
.53201 .38649 m .52835 .39799 L .51839 .39168 L p .835 .641 .64 r
F P
0 g
s
.53201 .61351 m .52835 .60201 L .53939 .59527 L p .799 .705 .761 r
F P
0 g
s
.52835 .60201 m .53201 .61351 L .52102 .62039 L p .835 .722 .74 r
F P
0 g
s
.52371 .63444 m .52102 .62039 L .53201 .61351 L p .837 .729 .745 r
F P
0 g
s
.58462 .57009 m .59375 .5784 L .58229 .58448 L p .662 .663 .84 r
F P
0 g
s
.58229 .58448 m .57417 .57556 L .58462 .57009 L p .662 .663 .84 r
F P
0 g
s
.39699 .53824 m .38523 .54199 L .38569 .52903 L p .575 .388 .591 r
F P
0 g
s
.38569 .52903 m .39748 .52645 L .39699 .53824 L p .575 .388 .591 r
F P
0 g
s
.38569 .47097 m .39748 .47355 L .3978 .48648 L p .59 .528 .753 r
F P
0 g
s
.39748 .47355 m .38569 .47097 L .38523 .45801 L p .575 .551 .79 r
F P
0 g
s
.37172 .45331 m .38523 .45801 L .38569 .47097 L p .567 .544 .789 r
F P
0 g
s
.59375 .4216 m .60457 .41225 L .61567 .41796 L p .613 .34 .479 r
F P
0 g
s
.6299 .40768 m .61567 .41796 L .60457 .41225 L p .614 .34 .479 r
F P
0 g
s
.51162 .37352 m .51321 .35881 L .52371 .36556 L p .878 .681 .632 r
F P
0 g
s
.52371 .36556 m .52102 .37961 L .51162 .37352 L p .878 .681 .632 r
F P
0 g
s
.60372 .57331 m .61567 .58204 L .60457 .58775 L p .613 .662 .873 r
F P
0 g
s
.60457 .58775 m .59375 .5784 L .60372 .57331 L p .613 .662 .873 r
F P
0 g
s
.52102 .62039 m .52371 .63444 L .51321 .64119 L p .878 .753 .72 r
F P
0 g
s
.515 .65866 m .51321 .64119 L .52371 .63444 L p .878 .754 .721 r
F P
0 g
s
.38465 .55317 m .37112 .55916 L .37172 .54669 L p .537 .314 .523 r
F P
0 g
s
.37172 .54669 m .38523 .54199 L .38465 .55317 L p .537 .314 .523 r
F P
0 g
s
.38523 .45801 m .37172 .45331 L .37112 .44084 L p .537 .563 .829 r
F P
0 g
s
.3551 .43366 m .37112 .44084 L .37172 .45331 L p .536 .563 .829 r
F P
0 g
s
.54574 .42078 m .55105 .41159 L .56281 .41825 L p .731 .524 .611 r
F P
0 g
s
.53495 .41441 m .53939 .40473 L .55105 .41159 L p .763 .565 .63 r
F P
0 g
s
.55105 .41159 m .54574 .42078 L .53495 .41441 L p .763 .565 .63 r
F P
0 g
s
.54574 .57922 m .55105 .58841 L .53939 .59527 L p .763 .681 .772 r
F P
0 g
s
.55665 .57307 m .56281 .58175 L .55105 .58841 L p .731 .67 .79 r
F P
0 g
s
.55105 .58841 m .54574 .57922 L .55665 .57307 L p .731 .67 .79 r
F P
0 g
s
.40853 .5 m .39791 .5 L .3978 .48648 L p .608 .511 .719 r
F P
0 g
s
.4084 .51252 m .3978 .51352 L .39791 .5 L p .608 .481 .682 r
F P
0 g
s
.39791 .5 m .40853 .5 L .4084 .51252 L p .608 .481 .682 r
F P
0 g
s
.67921 .38456 m .70243 .36303 L .71294 .36733 L p .387 .088 .331 r
F P
0 g
s
.73724 .33859 m .71294 .36733 L .70243 .36303 L p .37 .118 .397 r
F P
0 g
s
.50216 .28091 m .50842 .24926 L .5174 .25621 L p .964 .83 .663 r
F P
0 g
s
.5174 .25621 m .51037 .28708 L .50216 .28091 L p .964 .83 .663 r
F P
0 g
s
.68866 .61141 m .71294 .63267 L .70243 .63697 L p .387 .544 .889 r
F P
0 g
s
.70243 .63697 m .67921 .61544 L .68866 .61141 L p .387 .544 .889 r
F P
0 g
s
.51037 .71292 m .5174 .74379 L .50842 .75074 L p .964 .743 .557 r
F P
0 g
s
.52117 .78616 m .50842 .75074 L .5174 .74379 L p .942 .683 .516 r
F P
0 g
s
.30919 .60768 m .27864 .61808 L .28017 .60682 L p .48 .12 .277 r
F P
0 g
s
.28017 .60682 m .31042 .59748 L .30919 .60768 L p .48 .12 .277 r
F P
0 g
s
.31042 .40252 m .28017 .39318 L .27864 .38192 L p .48 .663 .943 r
F P
0 g
s
.24159 .37525 m .27864 .38192 L .28017 .39318 L p .553 .721 .952 r
F P
0 g
s
.52478 .40812 m .52835 .39799 L .53939 .40473 L p .795 .604 .643 r
F P
0 g
s
.53939 .40473 m .53495 .41441 L .52478 .40812 L p .795 .604 .643 r
F P
0 g
s
.56281 .41825 m .55665 .42693 L .54574 .42078 L p .731 .524 .611 r
F P
0 g
s
.55665 .42693 m .56281 .41825 L .57417 .42444 L p .697 .478 .587 r
F P
0 g
s
.56718 .5674 m .57417 .57556 L .56281 .58175 L p .697 .66 .81 r
F P
0 g
s
.56281 .58175 m .55665 .57307 L .56718 .5674 L p .697 .66 .81 r
F P
0 g
s
.53939 .59527 m .53495 .58559 L .54574 .57922 L p .763 .681 .772 r
F P
0 g
s
.53495 .58559 m .53939 .59527 L .52835 .60201 L p .795 .694 .753 r
F P
0 g
s
.40804 .52448 m .39748 .52645 L .3978 .51352 L p .602 .445 .642 r
F P
0 g
s
.3978 .51352 m .4084 .51252 L .40804 .52448 L p .602 .445 .642 r
F P
0 g
s
.3978 .48648 m .4084 .48748 L .40853 .5 L p .608 .511 .719 r
F P
0 g
s
.4084 .48748 m .3978 .48648 L .39748 .47355 L p .602 .538 .755 r
F P
0 g
s
.75943 .25636 m .76276 .2155 L .77147 .21817 L p .286 .242 .633 r
F P
0 g
s
.77147 .21817 m .76992 .25984 L .75943 .25636 L p .286 .242 .633 r
F P
0 g
s
.15928 .39714 m .12224 .41469 L .12019 .40581 L p .8 .886 .908 r
F P
0 g
s
.12019 .40581 m .15705 .38632 L .15928 .39714 L p .8 .886 .908 r
F P
0 g
s
.75772 .6981 m .76992 .74016 L .75943 .74364 L p .319 .324 .708 r
F P
0 g
s
.76276 .7845 m .75943 .74364 L .76992 .74016 L p .286 .224 .611 r
F P
0 g
s
.58128 .8465 m .615 .86981 L .60834 .87602 L p .78 .395 .325 r
F P
0 g
s
.60834 .87602 m .57302 .85384 L .58128 .8465 L p .78 .395 .325 r
F P
0 g
s
.19958 .62414 m .15705 .61368 L .15928 .60286 L p .719 .335 .322 r
F P
0 g
s
.12224 .58531 m .15928 .60286 L .15705 .61368 L p .8 .42 .336 r
F P
0 g
s
.5427 .17776 m .57302 .14616 L .58128 .1535 L p .853 .885 .861 r
F P
0 g
s
.615 .13019 m .58128 .1535 L .57302 .14616 L p .78 .88 .919 r
F P
0 g
s
.08006 .52899 m .09766 .54294 L .09648 .55445 L p .911 .651 .531 r
F P
0 g
s
.09766 .54294 m .08006 .52899 L .08068 .52003 L p .901 .673 .583 r
F P
0 g
s
.73507 .84918 m .73836 .82697 L .74891 .82224 L p .413 .196 .471 r
F P
0 g
s
.73836 .82697 m .73507 .84918 L .72701 .85313 L p .473 .247 .49 r
F P
0 g
s
.09766 .45706 m .08006 .47101 L .07923 .46328 L p .911 .837 .759 r
F P
0 g
s
.07923 .46328 m .09648 .44555 L .09766 .45706 L p .911 .837 .759 r
F P
0 g
s
.68487 .12183 m .66398 .13009 L .65461 .12332 L p .611 .733 .933 r
F P
0 g
s
.66398 .13009 m .68487 .12183 L .69231 .12684 L p .606 .697 .908 r
F P
0 g
s
.66398 .86991 m .68487 .87817 L .67858 .88276 L p .611 .264 .357 r
F P
0 g
s
.67858 .88276 m .65461 .87668 L .66398 .86991 L p .611 .264 .357 r
F P
0 g
s
.73836 .17303 m .73507 .15082 L .74219 .15396 L p .413 .479 .819 r
F P
0 g
s
.74219 .15396 m .74891 .17776 L .73836 .17303 L p .413 .479 .819 r
F P
0 g
s
.50491 .35323 m .50564 .33505 L .515 .34134 L p .928 .73 .615 r
F P
0 g
s
.515 .34134 m .51321 .35881 L .50491 .35323 L p .928 .73 .615 r
F P
0 g
s
.61567 .41796 m .6299 .40768 L .64003 .41264 L p .539 .229 .39 r
F P
0 g
s
.6582 .4005 m .64003 .41264 L .6299 .40768 L p .536 .234 .402 r
F P
0 g
s
.62466 .57763 m .64003 .58736 L .6299 .59232 L p .539 .651 .907 r
F P
0 g
s
.6299 .59232 m .61567 .58204 L .62466 .57763 L p .539 .651 .907 r
F P
0 g
s
.51321 .64119 m .515 .65866 L .50564 .66495 L p .928 .785 .683 r
F P
0 g
s
.50707 .68675 m .50564 .66495 L .515 .65866 L p .925 .776 .676 r
F P
0 g
s
.37044 .56914 m .35433 .57759 L .3551 .56634 L p .48 .209 .425 r
F P
0 g
s
.3551 .56634 m .37112 .55916 L .37044 .56914 L p .48 .209 .425 r
F P
0 g
s
.37112 .44084 m .3551 .43366 L .35433 .42241 L p .48 .575 .873 r
F P
0 g
s
.33473 .41274 m .35433 .42241 L .3551 .43366 L p .493 .586 .876 r
F P
0 g
s
.57417 .42444 m .56718 .4326 L .55665 .42693 L p .697 .478 .587 r
F P
0 g
s
.56718 .4326 m .57417 .42444 L .58462 .42991 L p .658 .423 .553 r
F P
0 g
s
.59375 .4216 m .58462 .42991 L .57417 .42444 L p .662 .418 .541 r
F P
0 g
s
.51563 .40221 m .51839 .39168 L .52835 .39799 L p .83 .646 .653 r
F P
0 g
s
.52835 .39799 m .52478 .40812 L .51563 .40221 L p .83 .646 .653 r
F P
0 g
s
.57687 .56243 m .58462 .57009 L .57417 .57556 L p .658 .651 .832 r
F P
0 g
s
.57417 .57556 m .56718 .5674 L .57687 .56243 L p .658 .651 .832 r
F P
0 g
s
.52835 .60201 m .52478 .59188 L .53495 .58559 L p .795 .694 .753 r
F P
0 g
s
.52478 .59188 m .52835 .60201 L .51839 .60832 L p .83 .71 .732 r
F P
0 g
s
.52102 .62039 m .51839 .60832 L .52835 .60201 L p .835 .722 .74 r
F P
0 g
s
.39748 .47355 m .40804 .47552 L .4084 .48748 L p .602 .538 .755 r
F P
0 g
s
.40804 .47552 m .39748 .47355 L .39699 .46176 L p .589 .562 .792 r
F P
0 g
s
.38523 .45801 m .39699 .46176 L .39748 .47355 L p .575 .551 .79 r
F P
0 g
s
.4075 .53536 m .39699 .53824 L .39748 .52645 L p .589 .4 .593 r
F P
0 g
s
.39748 .52645 m .40804 .52448 L .4075 .53536 L p .589 .4 .593 r
F P
0 g
s
.54085 .42925 m .54574 .42078 L .55665 .42693 L p .727 .529 .624 r
F P
0 g
s
.5307 .42321 m .53495 .41441 L .54574 .42078 L p .758 .57 .642 r
F P
0 g
s
.54574 .42078 m .54085 .42925 L .5307 .42321 L p .758 .57 .642 r
F P
0 g
s
.54085 .57075 m .54574 .57922 L .53495 .58559 L p .758 .668 .763 r
F P
0 g
s
.55116 .56498 m .55665 .57307 L .54574 .57922 L p .727 .657 .781 r
F P
0 g
s
.54574 .57922 m .54085 .57075 L .55116 .56498 L p .727 .657 .781 r
F P
0 g
s
.4183 .5 m .40853 .5 L .4084 .48748 L p .622 .523 .721 r
F P
0 g
s
.41815 .51181 m .4084 .51252 L .40853 .5 L p .622 .493 .684 r
F P
0 g
s
.40853 .5 m .4183 .5 L .41815 .51181 L p .622 .493 .684 r
F P
0 g
s
.58462 .42991 m .59375 .4216 L .60372 .42669 L p .611 .344 .488 r
F P
0 g
s
.61567 .41796 m .60372 .42669 L .59375 .4216 L p .613 .34 .479 r
F P
0 g
s
.5099 .3861 m .51162 .37352 L .52102 .37961 L p .876 .685 .641 r
F P
0 g
s
.52102 .37961 m .51839 .39168 L .5099 .3861 L p .876 .685 .641 r
F P
0 g
s
.59369 .56553 m .60372 .57331 L .59375 .5784 L p .611 .654 .868 r
F P
0 g
s
.59375 .5784 m .58462 .57009 L .59369 .56553 L p .611 .654 .868 r
F P
0 g
s
.51839 .60832 m .52102 .62039 L .51162 .62648 L p .876 .745 .715 r
F P
0 g
s
.51321 .64119 m .51162 .62648 L .52102 .62039 L p .878 .753 .72 r
F P
0 g
s
.39699 .46176 m .38523 .45801 L .38465 .44683 L p .547 .571 .831 r
F P
0 g
s
.37112 .44084 m .38465 .44683 L .38523 .45801 L p .537 .563 .829 r
F P
0 g
s
.39641 .54838 m .38465 .55317 L .38523 .54199 L p .547 .322 .525 r
F P
0 g
s
.38523 .54199 m .39699 .53824 L .39641 .54838 L p .547 .322 .525 r
F P
0 g
s
.6582 .4005 m .67921 .38456 L .68866 .38859 L p .399 .065 .279 r
F P
0 g
s
.71294 .36733 m .68866 .38859 L .67921 .38456 L p .387 .088 .331 r
F P
0 g
s
.49972 .30785 m .50216 .28091 L .51037 .28708 L p .975 .807 .612 r
F P
0 g
s
.51037 .28708 m .50707 .31325 L .49972 .30785 L p .975 .807 .612 r
F P
0 g
s
.66654 .59583 m .68866 .61141 L .67921 .61544 L p .399 .587 .918 r
F P
0 g
s
.67921 .61544 m .6582 .5995 L .66654 .59583 L p .399 .587 .918 r
F P
0 g
s
.50707 .68675 m .51037 .71292 L .50216 .71909 L p .975 .785 .585 r
F P
0 g
s
.50842 .75074 m .50216 .71909 L .51037 .71292 L p .964 .743 .557 r
F P
0 g
s
.33473 .41274 m .31042 .40252 L .30919 .39232 L p .422 .616 .931 r
F P
0 g
s
.27864 .38192 m .30919 .39232 L .31042 .40252 L p .48 .663 .943 r
F P
0 g
s
.33374 .59631 m .30919 .60768 L .31042 .59748 L p .422 .073 .266 r
F P
0 g
s
.31042 .59748 m .33473 .58726 L .33374 .59631 L p .422 .073 .266 r
F P
0 g
s
.52116 .4172 m .52478 .40812 L .53495 .41441 L p .79 .61 .657 r
F P
0 g
s
.53495 .41441 m .5307 .42321 L .52116 .4172 L p .79 .61 .657 r
F P
0 g
s
.55665 .42693 m .55116 .43502 L .54085 .42925 L p .727 .529 .624 r
F P
0 g
s
.55116 .43502 m .55665 .42693 L .56718 .4326 L p .693 .484 .6 r
F P
0 g
s
.53495 .58559 m .5307 .57679 L .54085 .57075 L p .758 .668 .763 r
F P
0 g
s
.5307 .57679 m .53495 .58559 L .52478 .59188 L p .79 .68 .743 r
F P
0 g
s
.56113 .55973 m .56718 .5674 L .55665 .57307 L p .693 .647 .8 r
F P
0 g
s
.55665 .57307 m .55116 .56498 L .56113 .55973 L p .693 .647 .8 r
F P
0 g
s
.41771 .52307 m .40804 .52448 L .4084 .51252 L p .617 .458 .644 r
F P
0 g
s
.4084 .51252 m .41815 .51181 L .41771 .52307 L p .617 .458 .644 r
F P
0 g
s
.4084 .48748 m .41815 .48819 L .4183 .5 L p .622 .523 .721 r
F P
0 g
s
.41815 .48819 m .4084 .48748 L .40804 .47552 L p .617 .55 .756 r
F P
0 g
s
.60372 .42669 m .61567 .41796 L .62466 .42237 L p .539 .23 .392 r
F P
0 g
s
.64003 .41264 m .62466 .42237 L .61567 .41796 L p .539 .229 .39 r
F P
0 g
s
.50421 .36851 m .50491 .35323 L .51321 .35881 L p .927 .73 .616 r
F P
0 g
s
.51321 .35881 m .51162 .37352 L .50421 .36851 L p .927 .73 .616 r
F P
0 g
s
.61177 .56939 m .62466 .57763 L .61567 .58204 L p .539 .65 .907 r
F P
0 g
s
.61567 .58204 m .60372 .57331 L .61177 .56939 L p .539 .65 .907 r
F P
0 g
s
.51162 .62648 m .51321 .64119 L .50491 .64677 L p .927 .784 .682 r
F P
0 g
s
.50564 .66495 m .50491 .64677 L .51321 .64119 L p .928 .785 .683 r
F P
0 g
s
.38402 .5621 m .37044 .56914 L .37112 .55916 L p .481 .21 .425 r
F P
0 g
s
.37112 .55916 m .38465 .55317 L .38402 .5621 L p .481 .21 .425 r
F P
0 g
s
.38465 .44683 m .37112 .44084 L .37044 .43086 L p .481 .576 .874 r
F P
0 g
s
.35433 .42241 m .37044 .43086 L .37112 .44084 L p .48 .575 .873 r
F P
0 g
s
.53626 .4372 m .54085 .42925 L .55116 .43502 L p .721 .535 .638 r
F P
0 g
s
.5265 .43135 m .5307 .42321 L .54085 .42925 L p .752 .575 .656 r
F P
0 g
s
.54085 .42925 m .53626 .4372 L .5265 .43135 L p .752 .575 .656 r
F P
0 g
s
.53626 .5628 m .54085 .57075 L .5307 .57679 L p .752 .654 .752 r
F P
0 g
s
.54621 .55728 m .55116 .56498 L .54085 .57075 L p .721 .643 .77 r
F P
0 g
s
.54085 .57075 m .53626 .5628 L .54621 .55728 L p .721 .643 .77 r
F P
0 g
s
.42749 .5 m .4183 .5 L .41815 .48819 L p .638 .536 .722 r
F P
0 g
s
.42729 .51138 m .41815 .51181 L .4183 .5 L p .638 .506 .686 r
F P
0 g
s
.4183 .5 m .42749 .5 L .42729 .51138 L p .638 .506 .686 r
F P
0 g
s
.56718 .4326 m .56113 .44027 L .55116 .43502 L p .693 .484 .6 r
F P
0 g
s
.56113 .44027 m .56718 .4326 L .57687 .43757 L p .653 .43 .569 r
F P
0 g
s
.58462 .42991 m .57687 .43757 L .56718 .4326 L p .658 .423 .553 r
F P
0 g
s
.51264 .41155 m .51563 .40221 L .52478 .40812 L p .825 .651 .668 r
F P
0 g
s
.52478 .40812 m .52116 .4172 L .51264 .41155 L p .825 .651 .668 r
F P
0 g
s
.57028 .55518 m .57687 .56243 L .56718 .5674 L p .653 .636 .821 r
F P
0 g
s
.56718 .5674 m .56113 .55973 L .57028 .55518 L p .653 .636 .821 r
F P
0 g
s
.52478 .59188 m .52116 .5828 L .5307 .57679 L p .79 .68 .743 r
F P
0 g
s
.52116 .5828 m .52478 .59188 L .51563 .59779 L p .825 .695 .721 r
F P
0 g
s
.51839 .60832 m .51563 .59779 L .52478 .59188 L p .83 .71 .732 r
F P
0 g
s
.40804 .47552 m .41771 .47693 L .41815 .48819 L p .617 .55 .756 r
F P
0 g
s
.41771 .47693 m .40804 .47552 L .4075 .46464 L p .606 .576 .794 r
F P
0 g
s
.39699 .46176 m .4075 .46464 L .40804 .47552 L p .589 .562 .792 r
F P
0 g
s
.41708 .53328 m .4075 .53536 L .40804 .52448 L p .606 .414 .595 r
F P
0 g
s
.40804 .52448 m .41771 .52307 L .41708 .53328 L p .606 .414 .595 r
F P
0 g
s
.55116 .43502 m .54621 .44272 L .53626 .4372 L p .721 .535 .638 r
F P
0 g
s
.54621 .44272 m .55116 .43502 L .56113 .44027 L p .687 .49 .615 r
F P
0 g
s
.51742 .42547 m .52116 .4172 L .5307 .42321 L p .784 .615 .671 r
F P
0 g
s
.5307 .42321 m .5265 .43135 L .51742 .42547 L p .784 .615 .671 r
F P
0 g
s
.55584 .55235 m .56113 .55973 L .55116 .56498 L p .687 .632 .788 r
F P
0 g
s
.55116 .56498 m .54621 .55728 L .55584 .55235 L p .687 .632 .788 r
F P
0 g
s
.5307 .57679 m .5265 .56865 L .53626 .5628 L p .752 .654 .752 r
F P
0 g
s
.5265 .56865 m .5307 .57679 L .52116 .5828 L p .784 .665 .732 r
F P
0 g
s
.42674 .52218 m .41771 .52307 L .41815 .51181 L p .634 .472 .646 r
F P
0 g
s
.41815 .51181 m .42729 .51138 L .42674 .52218 L p .634 .472 .646 r
F P
0 g
s
.41815 .48819 m .42729 .48862 L .42749 .5 L p .638 .536 .722 r
F P
0 g
s
.42729 .48862 m .41815 .48819 L .41771 .47693 L p .634 .563 .757 r
F P
0 g
s
.57687 .43757 m .58462 .42991 L .59369 .43447 L p .607 .351 .503 r
F P
0 g
s
.60372 .42669 m .59369 .43447 L .58462 .42991 L p .611 .344 .488 r
F P
0 g
s
.50787 .39699 m .5099 .3861 L .51839 .39168 L p .871 .691 .656 r
F P
0 g
s
.51839 .39168 m .51563 .40221 L .50787 .39699 L p .871 .691 .656 r
F P
0 g
s
.58527 .55832 m .59369 .56553 L .58462 .57009 L p .607 .64 .858 r
F P
0 g
s
.58462 .57009 m .57687 .56243 L .58527 .55832 L p .607 .64 .858 r
F P
0 g
s
.51563 .59779 m .51839 .60832 L .5099 .6139 L p .871 .731 .705 r
F P
0 g
s
.51162 .62648 m .5099 .6139 L .51839 .60832 L p .876 .745 .715 r
F P
0 g
s
.4075 .46464 m .39699 .46176 L .39641 .45162 L p .564 .585 .833 r
F P
0 g
s
.38465 .44683 m .39641 .45162 L .39699 .46176 L p .547 .571 .831 r
F P
0 g
s
.40686 .54469 m .39641 .54838 L .39699 .53824 L p .564 .336 .528 r
F P
0 g
s
.39699 .53824 m .4075 .53536 L .40686 .54469 L p .564 .336 .528 r
F P
0 g
s
.64003 .41264 m .6582 .4005 L .66654 .40417 L p .406 .051 .245 r
F P
0 g
s
.68866 .38859 m .66654 .40417 L .6582 .4005 L p .399 .065 .279 r
F P
0 g
s
.49913 .33034 m .49972 .30785 L .50707 .31325 L p .98 .789 .576 r
F P
0 g
s
.50707 .31325 m .50564 .33505 L .49913 .33034 L p .98 .789 .576 r
F P
0 g
s
.50564 .66495 m .50707 .68675 L .49972 .69215 L p .98 .811 .603 r
F P
0 g
s
.50216 .71909 m .49972 .69215 L .50707 .68675 L p .975 .785 .585 r
F P
0 g
s
.64736 .58408 m .66654 .59583 L .6582 .5995 L p .406 .613 .934 r
F P
0 g
s
.6582 .5995 m .64003 .58736 L .64736 .58408 L p .406 .613 .934 r
F P
0 g
s
.35433 .42241 m .33473 .41274 L .33374 .40369 L p .383 .583 .921 r
F P
0 g
s
.30919 .39232 m .33374 .40369 L .33473 .41274 L p .422 .616 .931 r
F P
0 g
s
.35351 .58558 m .33374 .59631 L .33473 .58726 L p .383 .043 .259 r
F P
0 g
s
.33473 .58726 m .35433 .57759 L .35351 .58558 L p .383 .043 .259 r
F P
0 g
s
.12224 .41469 m .09504 .43633 L .09341 .4298 L p .873 .92 .856 r
F P
0 g
s
.09341 .4298 m .12019 .40581 L .12224 .41469 L p .873 .92 .856 r
F P
0 g
s
.15705 .61368 m .12019 .59419 L .12224 .58531 L p .8 .42 .336 r
F P
0 g
s
.09504 .56367 m .12224 .58531 L .12019 .59419 L p .873 .506 .348 r
F P
0 g
s
.12224 .58531 m .09504 .56367 L .09648 .55445 L p .866 .559 .466 r
F P
0 g
s
.615 .86981 m .64734 .88254 L .6425 .88722 L p .686 .265 .24 r
F P
0 g
s
.6425 .88722 m .60834 .87602 L .615 .86981 L p .686 .265 .24 r
F P
0 g
s
.76992 .74016 m .77147 .78183 L .76276 .7845 L p .286 .224 .611 r
F P
0 g
s
.75762 .81887 m .76276 .7845 L .77147 .78183 L p .247 .113 .494 r
F P
0 g
s
.76276 .7845 m .75762 .81887 L .74891 .82224 L p .381 .231 .549 r
F P
0 g
s
.76276 .2155 m .75762 .18113 L .76409 .18299 L p .247 .289 .71 r
F P
0 g
s
.76409 .18299 m .77147 .21817 L .76276 .2155 L p .247 .289 .71 r
F P
0 g
s
.57302 .14616 m .60834 .12398 L .615 .13019 L p .78 .88 .919 r
F P
0 g
s
.64734 .11746 m .615 .13019 L .60834 .12398 L p .686 .855 .963 r
F P
0 g
s
.615 .13019 m .64734 .11746 L .65461 .12332 L p .695 .796 .927 r
F P
0 g
s
.08119 .5 m .07115 .5 L .07107 .49374 L p .942 .78 .651 r
F P
0 g
s
.07107 .49374 m .08106 .48977 L .08119 .5 L p .942 .78 .651 r
F P
0 g
s
.07115 .5 m .08119 .5 L .08106 .51023 L p .942 .759 .626 r
F P
0 g
s
.70941 .8627 m .71443 .8714 L .70905 .8746 L p .498 .187 .369 r
F P
0 g
s
.70905 .8746 m .70061 .86793 L .70941 .8627 L p .498 .187 .369 r
F P
0 g
s
.71443 .8714 m .70941 .8627 L .71833 .8577 L p .476 .179 .382 r
F P
0 g
s
.70941 .1373 m .71443 .1286 L .71989 .13166 L p .476 .598 .895 r
F P
0 g
s
.71989 .13166 m .71833 .1423 L .70941 .1373 L p .476 .598 .895 r
F P
0 g
s
.71443 .1286 m .70941 .1373 L .70061 .13207 L p .498 .626 .908 r
F P
0 g
s
.65461 .87668 m .67858 .88276 L .67374 .88672 L p .602 .211 .275 r
F P
0 g
s
.67374 .88672 m .64734 .88254 L .65461 .87668 L p .602 .211 .275 r
F P
0 g
s
.09648 .44555 m .07923 .46328 L .07822 .4571 L p .923 .883 .776 r
F P
0 g
s
.07822 .4571 m .09504 .43633 L .09648 .44555 L p .923 .883 .776 r
F P
0 g
s
.74891 .17776 m .74219 .15396 L .74804 .15618 L p .329 .42 .803 r
F P
0 g
s
.74804 .15618 m .75762 .18113 L .74891 .17776 L p .329 .42 .803 r
F P
0 g
s
.07923 .53672 m .09648 .55445 L .09504 .56367 L p .923 .625 .46 r
F P
0 g
s
.09648 .55445 m .07923 .53672 L .08006 .52899 L p .911 .651 .531 r
F P
0 g
s
.74219 .84604 m .74891 .82224 L .75762 .81887 L p .329 .117 .433 r
F P
0 g
s
.74891 .82224 m .74219 .84604 L .73507 .84918 L p .413 .196 .471 r
F P
0 g
s
.67858 .11724 m .65461 .12332 L .64734 .11746 L p .602 .772 .961 r
F P
0 g
s
.65461 .12332 m .67858 .11724 L .68487 .12183 L p .611 .733 .933 r
F P
0 g
s
.53185 .44483 m .53626 .4372 L .54621 .44272 L p .715 .54 .651 r
F P
0 g
s
.52228 .43901 m .5265 .43135 L .53626 .4372 L p .746 .58 .669 r
F P
0 g
s
.53626 .4372 m .53185 .44483 L .52228 .43901 L p .746 .58 .669 r
F P
0 g
s
.53185 .55517 m .53626 .5628 L .5265 .56865 L p .746 .638 .741 r
F P
0 g
s
.54168 .54979 m .54621 .55728 L .53626 .5628 L p .715 .628 .759 r
F P
0 g
s
.53626 .5628 m .53185 .55517 L .54168 .54979 L p .715 .628 .759 r
F P
0 g
s
.4363 .5 m .42749 .5 L .42729 .48862 L p .654 .548 .723 r
F P
0 g
s
.43604 .5112 m .42729 .51138 L .42749 .5 L p .654 .519 .687 r
F P
0 g
s
.42749 .5 m .4363 .5 L .43604 .5112 L p .654 .519 .687 r
F P
0 g
s
.08106 .48977 m .07107 .49374 L .07083 .48775 L p .945 .803 .672 r
F P
0 g
s
.07083 .48775 m .08068 .47997 L .08106 .48977 L p .945 .803 .672 r
F P
0 g
s
.07107 .50626 m .08106 .51023 L .08068 .52003 L p .945 .74 .595 r
F P
0 g
s
.08106 .51023 m .07107 .50626 L .07115 .5 L p .942 .759 .626 r
F P
0 g
s
.71989 .86834 m .71833 .8577 L .72701 .85313 L p .444 .158 .383 r
F P
0 g
s
.71833 .8577 m .71989 .86834 L .71443 .8714 L p .476 .179 .382 r
F P
0 g
s
.70061 .86793 m .70905 .8746 L .70398 .8778 L p .511 .181 .345 r
F P
0 g
s
.70398 .8778 m .69231 .87316 L .70061 .86793 L p .511 .181 .345 r
F P
0 g
s
.71833 .1423 m .71989 .13166 L .72519 .13445 L p .444 .567 .884 r
F P
0 g
s
.72519 .13445 m .72701 .14687 L .71833 .1423 L p .444 .567 .884 r
F P
0 g
s
.70905 .1254 m .70061 .13207 L .69231 .12684 L p .511 .654 .923 r
F P
0 g
s
.70061 .13207 m .70905 .1254 L .71443 .1286 L p .498 .626 .908 r
F P
0 g
s
.54621 .44272 m .54168 .45021 L .53185 .44483 L p .715 .54 .651 r
F P
0 g
s
.54168 .45021 m .54621 .44272 L .55584 .44765 L p .681 .497 .63 r
F P
0 g
s
.56113 .44027 m .55584 .44765 L .54621 .44272 L p .687 .49 .615 r
F P
0 g
s
.51348 .43309 m .51742 .42547 L .5265 .43135 L p .777 .62 .686 r
F P
0 g
s
.5265 .43135 m .52228 .43901 L .51348 .43309 L p .777 .62 .686 r
F P
0 g
s
.5265 .56865 m .52228 .56099 L .53185 .55517 L p .746 .638 .741 r
F P
0 g
s
.52228 .56099 m .5265 .56865 L .51742 .57453 L p .777 .649 .721 r
F P
0 g
s
.52116 .5828 m .51742 .57453 L .5265 .56865 L p .784 .665 .732 r
F P
0 g
s
.55121 .54513 m .55584 .55235 L .54621 .55728 L p .681 .616 .776 r
F P
0 g
s
.54621 .55728 m .54168 .54979 L .55121 .54513 L p .681 .616 .776 r
F P
0 g
s
.43532 .52179 m .42674 .52218 L .42729 .51138 L p .651 .487 .648 r
F P
0 g
s
.42729 .51138 m .43604 .5112 L .43532 .52179 L p .651 .487 .648 r
F P
0 g
s
.42729 .48862 m .43604 .4888 L .4363 .5 L p .654 .548 .723 r
F P
0 g
s
.43604 .4888 m .42729 .48862 L .42674 .47782 L p .651 .577 .758 r
F P
0 g
s
.41771 .47693 m .42674 .47782 L .42729 .48862 L p .634 .563 .757 r
F P
0 g
s
.50937 .41992 m .51264 .41155 L .52116 .4172 L p .817 .657 .684 r
F P
0 g
s
.52116 .4172 m .51742 .42547 L .50937 .41992 L p .817 .657 .684 r
F P
0 g
s
.55584 .44765 m .56113 .44027 L .57028 .44482 L p .647 .438 .586 r
F P
0 g
s
.57687 .43757 m .57028 .44482 L .56113 .44027 L p .653 .43 .569 r
F P
0 g
s
.56467 .54816 m .57028 .55518 L .56113 .55973 L p .647 .619 .807 r
F P
0 g
s
.56113 .55973 m .55584 .55235 L .56467 .54816 L p .647 .619 .807 r
F P
0 g
s
.51742 .57453 m .52116 .5828 L .51264 .58845 L p .817 .678 .709 r
F P
0 g
s
.51563 .59779 m .51264 .58845 L .52116 .5828 L p .825 .695 .721 r
F P
0 g
s
.42674 .47782 m .41771 .47693 L .41708 .46672 L p .625 .591 .795 r
F P
0 g
s
.4075 .46464 m .41708 .46672 L .41771 .47693 L p .606 .576 .794 r
F P
0 g
s
.42596 .53192 m .41708 .53328 L .41771 .52307 L p .625 .43 .598 r
F P
0 g
s
.41771 .52307 m .42674 .52218 L .42596 .53192 L p .625 .43 .598 r
F P
0 g
s
.59369 .43447 m .60372 .42669 L .61177 .43061 L p .536 .235 .403 r
F P
0 g
s
.62466 .42237 m .61177 .43061 L .60372 .42669 L p .539 .23 .392 r
F P
0 g
s
.50322 .38152 m .50421 .36851 L .51162 .37352 L p .925 .735 .628 r
F P
0 g
s
.51162 .37352 m .5099 .3861 L .50322 .38152 L p .925 .735 .628 r
F P
0 g
s
.601 .56203 m .61177 .56939 L .60372 .57331 L p .536 .641 .9 r
F P
0 g
s
.60372 .57331 m .59369 .56553 L .601 .56203 L p .536 .641 .9 r
F P
0 g
s
.5099 .6139 m .51162 .62648 L .50421 .63149 L p .925 .775 .676 r
F P
0 g
s
.50491 .64677 m .50421 .63149 L .51162 .62648 L p .927 .784 .682 r
F P
0 g
s
.39578 .55645 m .38402 .5621 L .38465 .55317 L p .494 .22 .427 r
F P
0 g
s
.38465 .55317 m .39641 .54838 L .39578 .55645 L p .494 .22 .427 r
F P
0 g
s
.39641 .45162 m .38465 .44683 L .38402 .4379 L p .494 .587 .876 r
F P
0 g
s
.37044 .43086 m .38402 .4379 L .38465 .44683 L p .481 .576 .874 r
F P
0 g
s
.52754 .45229 m .53185 .44483 L .54168 .45021 L p .709 .546 .665 r
F P
0 g
s
.51795 .44632 m .52228 .43901 L .53185 .44483 L p .74 .585 .682 r
F P
0 g
s
.53185 .44483 m .52754 .45229 L .51795 .44632 L p .74 .585 .682 r
F P
0 g
s
.52754 .54771 m .53185 .55517 L .52228 .56099 L p .74 .623 .729 r
F P
0 g
s
.53751 .54238 m .54168 .54979 L .53185 .55517 L p .709 .613 .747 r
F P
0 g
s
.53185 .55517 m .52754 .54771 L .53751 .54238 L p .709 .613 .747 r
F P
0 g
s
.44491 .5 m .4363 .5 L .43604 .4888 L p .669 .56 .723 r
F P
0 g
s
.44454 .5113 m .43604 .5112 L .4363 .5 L p .669 .531 .688 r
F P
0 g
s
.4363 .5 m .44491 .5 L .44454 .5113 L p .669 .531 .688 r
F P
0 g
s
.57028 .44482 m .57687 .43757 L .58527 .44168 L p .601 .359 .522 r
F P
0 g
s
.59369 .43447 m .58527 .44168 L .57687 .43757 L p .607 .351 .503 r
F P
0 g
s
.50546 .40655 m .50787 .39699 L .51563 .40221 L p .864 .698 .674 r
F P
0 g
s
.51563 .40221 m .51264 .41155 L .50546 .40655 L p .864 .698 .674 r
F P
0 g
s
.51264 .58845 m .51563 .59779 L .50787 .60301 L p .864 .713 .693 r
F P
0 g
s
.5099 .6139 m .50787 .60301 L .51563 .59779 L p .871 .731 .705 r
F P
0 g
s
.5782 .55146 m .58527 .55832 L .57687 .56243 L p .601 .623 .845 r
F P
0 g
s
.57687 .56243 m .57028 .55518 L .5782 .55146 L p .601 .623 .845 r
F P
0 g
s
.41634 .54199 m .40686 .54469 L .4075 .53536 L p .585 .354 .532 r
F P
0 g
s
.4075 .53536 m .41708 .53328 L .41634 .54199 L p .585 .354 .532 r
F P
0 g
s
.41708 .46672 m .4075 .46464 L .40686 .45531 L p .585 .602 .835 r
F P
0 g
s
.39641 .45162 m .40686 .45531 L .4075 .46464 L p .564 .585 .833 r
F P
0 g
s
.54168 .45021 m .53751 .45762 L .52754 .45229 L p .709 .546 .665 r
F P
0 g
s
.53751 .45762 m .54168 .45021 L .55121 .45487 L p .676 .503 .645 r
F P
0 g
s
.55584 .44765 m .55121 .45487 L .54168 .45021 L p .681 .497 .63 r
F P
0 g
s
.50927 .44018 m .51348 .43309 L .52228 .43901 L p .769 .624 .699 r
F P
0 g
s
.52228 .43901 m .51795 .44632 L .50927 .44018 L p .769 .624 .699 r
F P
0 g
s
.52228 .56099 m .51795 .55368 L .52754 .54771 L p .74 .623 .729 r
F P
0 g
s
.51795 .55368 m .52228 .56099 L .51348 .56691 L p .769 .632 .709 r
F P
0 g
s
.51742 .57453 m .51348 .56691 L .52228 .56099 L p .777 .649 .721 r
F P
0 g
s
.43604 .4888 m .44454 .4887 L .44491 .5 L p .669 .56 .723 r
F P
0 g
s
.44454 .4887 m .43604 .4888 L .43532 .47821 L p .667 .589 .758 r
F P
0 g
s
.42674 .47782 m .43532 .47821 L .43604 .4888 L p .651 .577 .758 r
F P
0 g
s
.54717 .53794 m .55121 .54513 L .54168 .54979 L p .676 .6 .763 r
F P
0 g
s
.54168 .54979 m .53751 .54238 L .54717 .53794 L p .676 .6 .763 r
F P
0 g
s
.44356 .52188 m .43532 .52179 L .43604 .5112 L p .667 .501 .65 r
F P
0 g
s
.43604 .5112 m .44454 .5113 L .44356 .52188 L p .667 .501 .65 r
F P
0 g
s
.08068 .47997 m .07083 .48775 L .07044 .48228 L p .951 .83 .689 r
F P
0 g
s
.07044 .48228 m .08006 .47101 L .08068 .47997 L p .951 .83 .689 r
F P
0 g
s
.72519 .86555 m .72701 .85313 L .73507 .84918 L p .402 .123 .372 r
F P
0 g
s
.72701 .85313 m .72519 .86555 L .71989 .86834 L p .444 .158 .383 r
F P
0 g
s
.69231 .87316 m .70398 .8778 L .69943 .88087 L p .516 .162 .306 r
F P
0 g
s
.69943 .88087 m .68487 .87817 L .69231 .87316 L p .516 .162 .306 r
F P
0 g
s
.07083 .51225 m .08068 .52003 L .08006 .52899 L p .951 .723 .557 r
F P
0 g
s
.08068 .52003 m .07083 .51225 L .07107 .50626 L p .945 .74 .595 r
F P
0 g
s
.70398 .1222 m .69231 .12684 L .68487 .12183 L p .516 .68 .94 r
F P
0 g
s
.69231 .12684 m .70398 .1222 L .70905 .1254 L p .511 .654 .923 r
F P
0 g
s
.72701 .14687 m .72519 .13445 L .73012 .13685 L p .402 .533 .874 r
F P
0 g
s
.73012 .13685 m .73507 .15082 L .72701 .14687 L p .402 .533 .874 r
F P
0 g
s
.55121 .45487 m .55584 .44765 L .56467 .45184 L p .641 .446 .603 r
F P
0 g
s
.57028 .44482 m .56467 .45184 L .55584 .44765 L p .647 .438 .586 r
F P
0 g
s
.50578 .42748 m .50937 .41992 L .51742 .42547 L p .809 .662 .7 r
F P
0 g
s
.51742 .42547 m .51348 .43309 L .50578 .42748 L p .809 .662 .7 r
F P
0 g
s
.51348 .56691 m .51742 .57453 L .50937 .58008 L p .809 .659 .696 r
F P
0 g
s
.51264 .58845 m .50937 .58008 L .51742 .57453 L p .817 .678 .709 r
F P
0 g
s
.55991 .54127 m .56467 .54816 L .55584 .55235 L p .641 .601 .793 r
F P
0 g
s
.55584 .55235 m .55121 .54513 L .55991 .54127 L p .641 .601 .793 r
F P
0 g
s
.43532 .47821 m .42674 .47782 L .42596 .46808 L p .645 .606 .795 r
F P
0 g
s
.41708 .46672 m .42596 .46808 L .42674 .47782 L p .625 .591 .795 r
F P
0 g
s
.43431 .53125 m .42596 .53192 L .42674 .52218 L p .645 .447 .601 r
F P
0 g
s
.42674 .52218 m .43532 .52179 L .43431 .53125 L p .645 .447 .601 r
F P
0 g
s
.52325 .45974 m .52754 .45229 L .53751 .45762 L p .704 .55 .677 r
F P
0 g
s
.51339 .45342 m .51795 .44632 L .52754 .45229 L p .733 .589 .694 r
F P
0 g
s
.52754 .45229 m .52325 .45974 L .51339 .45342 L p .733 .589 .694 r
F P
0 g
s
.52325 .54026 m .52754 .54771 L .51795 .55368 L p .733 .609 .719 r
F P
0 g
s
.53365 .53488 m .53751 .54238 L .52754 .54771 L p .704 .599 .736 r
F P
0 g
s
.52754 .54771 m .52325 .54026 L .53365 .53488 L p .704 .599 .736 r
F P
0 g
s
.45351 .5 m .44491 .5 L .44454 .4887 L p .682 .571 .724 r
F P
0 g
s
.45297 .5117 m .44454 .5113 L .44491 .5 L p .682 .543 .689 r
F P
0 g
s
.44491 .5 m .45351 .5 L .45297 .5117 L p .682 .543 .689 r
F P
0 g
s
.62466 .42237 m .64003 .41264 L .64736 .41592 L p .409 .044 .23 r
F P
0 g
s
.66654 .40417 m .64736 .41592 L .64003 .41264 L p .406 .051 .245 r
F P
0 g
s
.49914 .34908 m .49913 .33034 L .50564 .33505 L p .981 .781 .561 r
F P
0 g
s
.50564 .33505 m .50491 .35323 L .49914 .34908 L p .981 .781 .561 r
F P
0 g
s
.50491 .64677 m .50564 .66495 L .49913 .66966 L p .981 .822 .61 r
F P
0 g
s
.49972 .69215 m .49913 .66966 L .50564 .66495 L p .98 .811 .603 r
F P
0 g
s
.63113 .57471 m .64736 .58408 L .64003 .58736 L p .409 .624 .941 r
F P
0 g
s
.64003 .58736 m .62466 .57763 L .63113 .57471 L p .409 .624 .941 r
F P
0 g
s
.37044 .43086 m .35433 .42241 L .35351 .41442 L p .366 .568 .916 r
F P
0 g
s
.33374 .40369 m .35351 .41442 L .35433 .42241 L p .383 .583 .921 r
F P
0 g
s
.36973 .5762 m .35351 .58558 L .35433 .57759 L p .366 .029 .255 r
F P
0 g
s
.35433 .57759 m .37044 .56914 L .36973 .5762 L p .366 .029 .255 r
F P
0 g
s
.50474 .44683 m .50927 .44018 L .51795 .44632 L p .762 .628 .712 r
F P
0 g
s
.51795 .44632 m .51339 .45342 L .50474 .44683 L p .762 .628 .712 r
F P
0 g
s
.53751 .45762 m .53365 .46512 L .52325 .45974 L p .704 .55 .677 r
F P
0 g
s
.53365 .46512 m .53751 .45762 L .54717 .46206 L p .67 .51 .659 r
F P
0 g
s
.55121 .45487 m .54717 .46206 L .53751 .45762 L p .676 .503 .645 r
F P
0 g
s
.54368 .53069 m .54717 .53794 L .53751 .54238 L p .67 .585 .751 r
F P
0 g
s
.53751 .54238 m .53365 .53488 L .54368 .53069 L p .67 .585 .751 r
F P
0 g
s
.51795 .55368 m .51339 .54658 L .52325 .54026 L p .733 .609 .719 r
F P
0 g
s
.51339 .54658 m .51795 .55368 L .50927 .55982 L p .762 .616 .698 r
F P
0 g
s
.51348 .56691 m .50927 .55982 L .51795 .55368 L p .769 .632 .709 r
F P
0 g
s
.44454 .4887 m .45297 .4883 L .45351 .5 L p .682 .571 .724 r
F P
0 g
s
.45297 .4883 m .44454 .4887 L .44356 .47812 L p .682 .6 .758 r
F P
0 g
s
.43532 .47821 m .44356 .47812 L .44454 .4887 L p .667 .589 .758 r
F P
0 g
s
.45158 .52248 m .44356 .52188 L .44454 .5113 L p .682 .514 .652 r
F P
0 g
s
.44454 .5113 m .45297 .5117 L .45158 .52248 L p .682 .514 .652 r
F P
0 g
s
.51884 .46737 m .52325 .45974 L .53365 .46512 L p .699 .555 .688 r
F P
0 g
s
.50845 .46039 m .51339 .45342 L .52325 .45974 L p .728 .592 .704 r
F P
0 g
s
.52325 .45974 m .51884 .46737 L .50845 .46039 L p .728 .592 .704 r
F P
0 g
s
.51884 .53263 m .52325 .54026 L .51339 .54658 L p .727 .596 .709 r
F P
0 g
s
.53008 .52712 m .53365 .53488 L .52325 .54026 L p .699 .586 .726 r
F P
0 g
s
.52325 .54026 m .51884 .53263 L .53008 .52712 L p .699 .586 .726 r
F P
0 g
s
.46232 .5 m .45351 .5 L .45297 .4883 L p .694 .58 .723 r
F P
0 g
s
.46147 .51249 m .45297 .5117 L .45351 .5 L p .694 .553 .69 r
F P
0 g
s
.45351 .5 m .46232 .5 L .46147 .51249 L p .694 .553 .69 r
F P
0 g
s
.50004 .50007 m .5088 .51524 L .4963 .52604 L p .714 .574 .696 r
F P
0 g
s
.4963 .52604 m .48832 .52024 L .50004 .50007 L p .714 .574 .696 r
F P
0 g
s
.5088 .51524 m .50004 .50007 L .52337 .5 L p .694 .569 .71 r
F P
0 g
s
.49992 .5 m .48241 .5 L .4793 .48378 L p .713 .592 .719 r
F P
0 g
s
.4793 .48378 m .48831 .47976 L .49992 .5 L p .713 .592 .719 r
F P
0 g
s
.48241 .5 m .49992 .5 L .48831 .52024 L p .711 .57 .694 r
F P
0 g
s
.50004 .49993 m .5088 .48476 L .5244 .49018 L p .694 .566 .706 r
F P
0 g
s
.5244 .49018 m .52337 .5 L .50004 .49993 L p .694 .566 .706 r
F P
0 g
s
.5088 .48476 m .50004 .49993 L .48832 .47976 L p .716 .593 .717 r
F P
0 g
s
.48832 .47976 m .4963 .47396 L .5088 .48476 L p .716 .593 .717 r
F P
0 g
s
.5088 .48476 m .51415 .47549 L .5269 .48114 L p .692 .562 .703 r
F P
0 g
s
.5269 .48114 m .5244 .49018 L .5088 .48476 L p .692 .562 .703 r
F P
0 g
s
.51415 .47549 m .5088 .48476 L .4963 .47396 L p .718 .595 .717 r
F P
0 g
s
.52337 .5 m .5244 .50982 L .5088 .51524 L p .694 .569 .71 r
F P
0 g
s
.5088 .51524 m .51415 .52451 L .50289 .53273 L p .718 .578 .696 r
F P
0 g
s
.50289 .53273 m .4963 .52604 L .5088 .51524 L p .718 .578 .696 r
F P
0 g
s
.51415 .52451 m .5088 .51524 L .5244 .50982 L p .692 .569 .712 r
F P
0 g
s
.48831 .52024 m .4793 .51622 L .48241 .5 L p .711 .57 .694 r
F P
0 g
s
.48241 .5 m .47169 .5 L .47022 .48614 L p .711 .592 .722 r
F P
0 g
s
.47022 .48614 m .4793 .48378 L .48241 .5 L p .711 .592 .722 r
F P
0 g
s
.47169 .5 m .48241 .5 L .4793 .51622 L p .71 .568 .692 r
F P
0 g
s
.51415 .47549 m .51884 .46737 L .53008 .47288 L p .695 .559 .696 r
F P
0 g
s
.50289 .46727 m .50845 .46039 L .51884 .46737 L p .722 .594 .712 r
F P
0 g
s
.51884 .46737 m .51415 .47549 L .50289 .46727 L p .722 .594 .712 r
F P
0 g
s
.53365 .46512 m .53008 .47288 L .51884 .46737 L p .699 .555 .688 r
F P
0 g
s
.51415 .52451 m .51884 .53263 L .50845 .53961 L p .722 .585 .702 r
F P
0 g
s
.5269 .51886 m .53008 .52712 L .51884 .53263 L p .695 .576 .718 r
F P
0 g
s
.51884 .53263 m .51415 .52451 L .5269 .51886 L p .695 .576 .718 r
F P
0 g
s
.51339 .54658 m .50845 .53961 L .51884 .53263 L p .727 .596 .709 r
F P
0 g
s
.47169 .5 m .46232 .5 L .46147 .48751 L p .704 .588 .723 r
F P
0 g
s
.47022 .51386 m .46147 .51249 L .46232 .5 L p .704 .562 .691 r
F P
0 g
s
.46232 .5 m .47169 .5 L .47022 .51386 L p .704 .562 .691 r
F P
0 g
s
.45297 .4883 m .46147 .48751 L .46232 .5 L p .694 .58 .723 r
F P
0 g
s
.4963 .47396 m .50289 .46727 L .51415 .47549 L p .718 .595 .717 r
F P
0 g
s
.53008 .47288 m .5269 .48114 L .51415 .47549 L p .695 .559 .696 r
F P
0 g
s
.5244 .50982 m .5269 .51886 L .51415 .52451 L p .692 .569 .712 r
F P
0 g
s
.50845 .53961 m .50289 .53273 L .51415 .52451 L p .722 .585 .702 r
F P
0 g
s
.4793 .51622 m .47022 .51386 L .47169 .5 L p .71 .568 .692 r
F P
0 g
s
.46147 .48751 m .47022 .48614 L .47169 .5 L p .704 .588 .723 r
F P
0 g
s
.56467 .45184 m .57028 .44482 L .5782 .44854 L p .595 .369 .543 r
F P
0 g
s
.58527 .44168 m .5782 .44854 L .57028 .44482 L p .601 .359 .522 r
F P
0 g
s
.50265 .41501 m .50546 .40655 L .51264 .41155 L p .856 .705 .694 r
F P
0 g
s
.51264 .41155 m .50937 .41992 L .50265 .41501 L p .856 .705 .694 r
F P
0 g
s
.50937 .58008 m .51264 .58845 L .50546 .59345 L p .856 .693 .679 r
F P
0 g
s
.50787 .60301 m .50546 .59345 L .51264 .58845 L p .864 .713 .693 r
F P
0 g
s
.57228 .54479 m .5782 .55146 L .57028 .55518 L p .595 .603 .83 r
F P
0 g
s
.57028 .55518 m .56467 .54816 L .57228 .54479 L p .595 .603 .83 r
F P
0 g
s
.42507 .5402 m .41634 .54199 L .41708 .53328 L p .608 .373 .536 r
F P
0 g
s
.41708 .53328 m .42596 .53192 L .42507 .5402 L p .608 .373 .536 r
F P
0 g
s
.42596 .46808 m .41708 .46672 L .41634 .45801 L p .608 .62 .837 r
F P
0 g
s
.40686 .45531 m .41634 .45801 L .41708 .46672 L p .585 .602 .835 r
F P
0 g
s
.49979 .45305 m .50474 .44683 L .51339 .45342 L p .754 .63 .723 r
F P
0 g
s
.51339 .45342 m .50845 .46039 L .49979 .45305 L p .754 .63 .723 r
F P
0 g
s
.53008 .47288 m .53365 .46512 L .54368 .46931 L p .666 .516 .672 r
F P
0 g
s
.54717 .46206 m .54368 .46931 L .53365 .46512 L p .67 .51 .659 r
F P
0 g
s
.54076 .52329 m .54368 .53069 L .53365 .53488 L p .666 .571 .739 r
F P
0 g
s
.53365 .53488 m .53008 .52712 L .54076 .52329 L p .666 .571 .739 r
F P
0 g
s
.50845 .53961 m .51339 .54658 L .50474 .55317 L p .754 .601 .688 r
F P
0 g
s
.50927 .55982 m .50474 .55317 L .51339 .54658 L p .762 .616 .698 r
F P
0 g
s
.45945 .52366 m .45158 .52248 L .45297 .5117 L p .696 .526 .654 r
F P
0 g
s
.45297 .5117 m .46147 .51249 L .45945 .52366 L p .696 .526 .654 r
F P
0 g
s
.46147 .48751 m .45297 .4883 L .45158 .47752 L p .696 .61 .756 r
F P
0 g
s
.44356 .47812 m .45158 .47752 L .45297 .4883 L p .682 .6 .758 r
F P
0 g
s
.50185 .43437 m .50578 .42748 L .51348 .43309 L p .8 .667 .716 r
F P
0 g
s
.51348 .43309 m .50927 .44018 L .50185 .43437 L p .8 .667 .716 r
F P
0 g
s
.54717 .46206 m .55121 .45487 L .55991 .45873 L p .635 .454 .621 r
F P
0 g
s
.56467 .45184 m .55991 .45873 L .55121 .45487 L p .641 .446 .603 r
F P
0 g
s
.55591 .53442 m .55991 .54127 L .55121 .54513 L p .635 .583 .779 r
F P
0 g
s
.55121 .54513 m .54717 .53794 L .55591 .53442 L p .635 .583 .779 r
F P
0 g
s
.44224 .53121 m .43431 .53125 L .43532 .52179 L p .664 .464 .604 r
F P
0 g
s
.43532 .52179 m .44356 .52188 L .44224 .53121 L p .664 .464 .604 r
F P
0 g
s
.50927 .55982 m .51348 .56691 L .50578 .57252 L p .8 .64 .683 r
F P
0 g
s
.50937 .58008 m .50578 .57252 L .51348 .56691 L p .809 .659 .696 r
F P
0 g
s
.44356 .47812 m .43532 .47821 L .43431 .46875 L p .664 .62 .795 r
F P
0 g
s
.42596 .46808 m .43431 .46875 L .43532 .47821 L p .645 .606 .795 r
F P
0 g
s
.58527 .44168 m .59369 .43447 L .601 .43797 L p .531 .244 .423 r
F P
0 g
s
.61177 .43061 m .601 .43797 L .59369 .43447 L p .536 .235 .403 r
F P
0 g
s
.50179 .39272 m .50322 .38152 L .5099 .3861 L p .92 .744 .647 r
F P
0 g
s
.5099 .3861 m .50787 .39699 L .50179 .39272 L p .92 .744 .647 r
F P
0 g
s
.59201 .55519 m .601 .56203 L .59369 .56553 L p .531 .624 .889 r
F P
0 g
s
.59369 .56553 m .58527 .55832 L .59201 .55519 L p .531 .624 .889 r
F P
0 g
s
.50787 .60301 m .5099 .6139 L .50322 .61848 L p .92 .758 .665 r
F P
0 g
s
.50421 .63149 m .50322 .61848 L .5099 .6139 L p .925 .775 .676 r
F P
0 g
s
.40686 .45531 m .39641 .45162 L .39578 .44355 L p .516 .605 .88 r
F P
0 g
s
.38402 .4379 m .39578 .44355 L .39641 .45162 L p .494 .587 .876 r
F P
0 g
s
.4062 .55209 m .39578 .55645 L .39641 .54838 L p .516 .238 .432 r
F P
0 g
s
.39641 .54838 m .40686 .54469 L .4062 .55209 L p .516 .238 .432 r
F P
0 g
s
.5269 .48114 m .53008 .47288 L .54076 .47671 L p .662 .522 .683 r
F P
0 g
s
.54368 .46931 m .54076 .47671 L .53008 .47288 L p .666 .516 .672 r
F P
0 g
s
.49432 .45882 m .49979 .45305 L .50845 .46039 L p .747 .631 .732 r
F P
0 g
s
.50845 .46039 m .50289 .46727 L .49432 .45882 L p .747 .631 .732 r
F P
0 g
s
.50289 .53273 m .50845 .53961 L .49979 .54695 L p .747 .588 .679 r
F P
0 g
s
.50474 .55317 m .49979 .54695 L .50845 .53961 L p .754 .601 .688 r
F P
0 g
s
.46718 .52551 m .45945 .52366 L .46147 .51249 L p .707 .538 .656 r
F P
0 g
s
.46147 .51249 m .47022 .51386 L .46718 .52551 L p .707 .538 .656 r
F P
0 g
s
.5385 .51567 m .54076 .52329 L .53008 .52712 L p .662 .559 .728 r
F P
0 g
s
.53008 .52712 m .5269 .51886 L .5385 .51567 L p .662 .559 .728 r
F P
0 g
s
.47022 .48614 m .46147 .48751 L .45945 .47634 L p .708 .618 .754 r
F P
0 g
s
.45158 .47752 m .45945 .47634 L .46147 .48751 L p .696 .61 .756 r
F P
0 g
s
.5244 .50982 m .52337 .5 L .53655 .5 L p .658 .541 .71 r
F P
0 g
s
.48831 .47976 m .4793 .48378 L .47467 .47184 L p .726 .628 .749 r
F P
0 g
s
.47467 .47184 m .48172 .46835 L .48831 .47976 L p .726 .628 .749 r
F P
0 g
s
.52337 .5 m .5244 .49018 L .53705 .49215 L p .658 .534 .701 r
F P
0 g
s
.53705 .49215 m .53655 .5 L .52337 .5 L p .658 .534 .701 r
F P
0 g
s
.48832 .52024 m .4963 .52604 L .48828 .53601 L p .733 .566 .667 r
F P
0 g
s
.48828 .53601 m .48173 .53165 L .48832 .52024 L p .733 .566 .667 r
F P
0 g
s
.4963 .47396 m .48832 .47976 L .48173 .46835 L p .733 .63 .744 r
F P
0 g
s
.4793 .51622 m .48831 .52024 L .48172 .53165 L p .726 .557 .662 r
F P
0 g
s
.48828 .46399 m .49432 .45882 L .50289 .46727 L p .74 .631 .739 r
F P
0 g
s
.50289 .46727 m .4963 .47396 L .48828 .46399 L p .74 .631 .739 r
F P
0 g
s
.5244 .49018 m .5269 .48114 L .5385 .48433 L p .659 .528 .693 r
F P
0 g
s
.54076 .47671 m .5385 .48433 L .5269 .48114 L p .662 .522 .683 r
F P
0 g
s
.4793 .48378 m .47022 .48614 L .46718 .47449 L p .717 .624 .752 r
F P
0 g
s
.45945 .47634 m .46718 .47449 L .47022 .48614 L p .708 .618 .754 r
F P
0 g
s
.4963 .52604 m .50289 .53273 L .49432 .54118 L p .74 .576 .672 r
F P
0 g
s
.49979 .54695 m .49432 .54118 L .50289 .53273 L p .747 .588 .679 r
F P
0 g
s
.53705 .50785 m .5385 .51567 L .5269 .51886 L p .659 .549 .718 r
F P
0 g
s
.5269 .51886 m .5244 .50982 L .53705 .50785 L p .659 .549 .718 r
F P
0 g
s
.47467 .52816 m .46718 .52551 L .47022 .51386 L p .717 .548 .659 r
F P
0 g
s
.47022 .51386 m .4793 .51622 L .47467 .52816 L p .717 .548 .659 r
F P
0 g
s
.5385 .48433 m .53705 .49215 L .5244 .49018 L p .659 .528 .693 r
F P
0 g
s
.48173 .46835 m .48828 .46399 L .4963 .47396 L p .733 .63 .744 r
F P
0 g
s
.53655 .5 m .53705 .50785 L .5244 .50982 L p .658 .541 .71 r
F P
0 g
s
.46718 .47449 m .47467 .47184 L .4793 .48378 L p .717 .624 .752 r
F P
0 g
s
.48172 .53165 m .47467 .52816 L .4793 .51622 L p .726 .557 .662 r
F P
0 g
s
.49432 .54118 m .48828 .53601 L .4963 .52604 L p .74 .576 .672 r
F P
0 g
s
.50381 .2447 m .51638 .20875 L .52117 .21384 L p .971 .931 .65 r
F P
0 g
s
.52117 .21384 m .50842 .24926 L .50381 .2447 L p .971 .931 .65 r
F P
0 g
s
.5427 .17776 m .52117 .21384 L .51638 .20875 L p .929 .968 .758 r
F P
0 g
s
.277 .62436 m .23958 .63144 L .24159 .62475 L p .382 0 0 r
F P
0 g
s
.24159 .62475 m .27864 .61808 L .277 .62436 L p .382 0 0 r
F P
0 g
s
.19958 .62414 m .24159 .62475 L .23958 .63144 L p .51 .01 .004 r
F P
0 g
s
.71294 .36733 m .73724 .33859 L .74404 .34019 L p .09 0 .141 r
F P
0 g
s
.73724 .33859 m .75772 .3019 L .76465 .30322 L p .067 0 .26 r
F P
0 g
s
.76465 .30322 m .74404 .34019 L .73724 .33859 L p .067 0 .26 r
F P
0 g
s
.50842 .75074 m .52117 .78616 L .51638 .79125 L p .971 .655 .312 r
F P
0 g
s
.52117 .78616 m .5427 .82224 L .53809 .82758 L p .929 .55 .246 r
F P
0 g
s
.53809 .82758 m .51638 .79125 L .52117 .78616 L p .929 .55 .246 r
F P
0 g
s
.7192 .63095 m .74404 .65981 L .73724 .66141 L p .09 .351 .821 r
F P
0 g
s
.73724 .66141 m .71294 .63267 L .7192 .63095 L p .09 .351 .821 r
F P
0 g
s
.75772 .6981 m .73724 .66141 L .74404 .65981 L p .067 .253 .744 r
F P
0 g
s
.27864 .38192 m .24159 .37525 L .23958 .36856 L p .382 .727 .99 r
F P
0 g
s
.24159 .37525 m .19958 .37586 L .19726 .3692 L p .51 .823 1 r
F P
0 g
s
.19726 .3692 m .23958 .36856 L .24159 .37525 L p .51 .823 1 r
F P
0 g
s
.54368 .46931 m .54717 .46206 L .55591 .46558 L p .63 .463 .638 r
F P
0 g
s
.55991 .45873 m .55591 .46558 L .54717 .46206 L p .635 .454 .621 r
F P
0 g
s
.49754 .44064 m .50185 .43437 L .50927 .44018 L p .791 .67 .731 r
F P
0 g
s
.50927 .44018 m .50474 .44683 L .49754 .44064 L p .791 .67 .731 r
F P
0 g
s
.50474 .55317 m .50927 .55982 L .50185 .56563 L p .791 .621 .671 r
F P
0 g
s
.50578 .57252 m .50185 .56563 L .50927 .55982 L p .8 .64 .683 r
F P
0 g
s
.55264 .52756 m .55591 .53442 L .54717 .53794 L p .63 .566 .764 r
F P
0 g
s
.54717 .53794 m .54368 .53069 L .55264 .52756 L p .63 .566 .764 r
F P
0 g
s
.44982 .53181 m .44224 .53121 L .44356 .52188 L p .681 .48 .608 r
F P
0 g
s
.44356 .52188 m .45158 .52248 L .44982 .53181 L p .681 .48 .608 r
F P
0 g
s
.45158 .47752 m .44356 .47812 L .44224 .46879 L p .681 .632 .794 r
F P
0 g
s
.43431 .46875 m .44224 .46879 L .44356 .47812 L p .664 .62 .795 r
F P
0 g
s
.75772 .3019 m .76992 .25984 L .77635 .26076 L p .045 0 .388 r
F P
0 g
s
.77635 .26076 m .76465 .30322 L .75772 .3019 L p .045 0 .388 r
F P
0 g
s
.5427 .82224 m .57302 .85384 L .56901 .85895 L p .857 .42 .171 r
F P
0 g
s
.56901 .85895 m .53809 .82758 L .5427 .82224 L p .857 .42 .171 r
F P
0 g
s
.19958 .37586 m .15705 .38632 L .15464 .38029 L p .64 .905 .983 r
F P
0 g
s
.15464 .38029 m .19726 .3692 L .19958 .37586 L p .64 .905 .983 r
F P
0 g
s
.51638 .20875 m .53809 .17242 L .5427 .17776 L p .929 .968 .758 r
F P
0 g
s
.57302 .14616 m .5427 .17776 L .53809 .17242 L p .857 .98 .857 r
F P
0 g
s
.74404 .65981 m .76465 .69678 L .75772 .6981 L p .067 .253 .744 r
F P
0 g
s
.76992 .74016 m .75772 .6981 L .76465 .69678 L p .045 .14 .64 r
F P
0 g
s
.23958 .63144 m .19726 .6308 L .19958 .62414 L p .51 .01 .004 r
F P
0 g
s
.15705 .61368 m .19958 .62414 L .19726 .6308 L p .64 .139 .045 r
F P
0 g
s
.07044 .51772 m .08006 .52899 L .07923 .53672 L p .959 .705 .509 r
F P
0 g
s
.08006 .52899 m .07044 .51772 L .07083 .51225 L p .951 .723 .557 r
F P
0 g
s
.73012 .86315 m .73507 .84918 L .74219 .84604 L p .344 .069 .344 r
F P
0 g
s
.73507 .84918 m .73012 .86315 L .72519 .86555 L p .402 .123 .372 r
F P
0 g
s
.08006 .47101 m .07044 .48228 L .06993 .47757 L p .959 .861 .699 r
F P
0 g
s
.06993 .47757 m .07923 .46328 L .08006 .47101 L p .959 .861 .699 r
F P
0 g
s
.69943 .11913 m .68487 .12183 L .67858 .11724 L p .509 .706 .959 r
F P
0 g
s
.68487 .12183 m .69943 .11913 L .70398 .1222 L p .516 .68 .94 r
F P
0 g
s
.73507 .15082 m .73012 .13685 L .73446 .13876 L p .344 .493 .864 r
F P
0 g
s
.73446 .13876 m .74219 .15396 L .73507 .15082 L p .344 .493 .864 r
F P
0 g
s
.68487 .87817 m .69943 .88087 L .69561 .88367 L p .509 .125 .249 r
F P
0 g
s
.69561 .88367 m .67858 .88276 L .68487 .87817 L p .509 .125 .249 r
F P
0 g
s
.55991 .45873 m .56467 .45184 L .57228 .45521 L p .588 .379 .565 r
F P
0 g
s
.49943 .42255 m .50265 .41501 L .50937 .41992 L p .846 .712 .714 r
F P
0 g
s
.50937 .41992 m .50578 .42748 L .49943 .42255 L p .846 .712 .714 r
F P
0 g
s
.5782 .44854 m .57228 .45521 L .56467 .45184 L p .595 .369 .543 r
F P
0 g
s
.50578 .57252 m .50937 .58008 L .50265 .58499 L p .846 .671 .664 r
F P
0 g
s
.50546 .59345 m .50265 .58499 L .50937 .58008 L p .856 .693 .679 r
F P
0 g
s
.56736 .53823 m .57228 .54479 L .56467 .54816 L p .588 .582 .813 r
F P
0 g
s
.56467 .54816 m .55991 .54127 L .56736 .53823 L p .588 .582 .813 r
F P
0 g
s
.43431 .46875 m .42596 .46808 L .42507 .4598 L p .632 .637 .838 r
F P
0 g
s
.41634 .45801 m .42507 .4598 L .42596 .46808 L p .608 .62 .837 r
F P
0 g
s
.43321 .53922 m .42507 .5402 L .42596 .53192 L p .632 .394 .54 r
F P
0 g
s
.42596 .53192 m .43431 .53125 L .43321 .53922 L p .632 .394 .54 r
F P
0 g
s
.61177 .43061 m .62466 .42237 L .63113 .42529 L p .409 .045 .232 r
F P
0 g
s
.64736 .41592 m .63113 .42529 L .62466 .42237 L p .409 .044 .23 r
F P
0 g
s
.49908 .36482 m .49914 .34908 L .50491 .35323 L p .981 .782 .563 r
F P
0 g
s
.50491 .35323 m .50421 .36851 L .49908 .36482 L p .981 .782 .563 r
F P
0 g
s
.50421 .63149 m .50491 .64677 L .49914 .65092 L p .981 .82 .61 r
F P
0 g
s
.49913 .66966 m .49914 .65092 L .50491 .64677 L p .981 .822 .61 r
F P
0 g
s
.61753 .56679 m .63113 .57471 L .62466 .57763 L p .409 .623 .94 r
F P
0 g
s
.62466 .57763 m .61177 .56939 L .61753 .56679 L p .409 .623 .94 r
F P
0 g
s
.38339 .56839 m .36973 .5762 L .37044 .56914 L p .368 .031 .256 r
F P
0 g
s
.37044 .56914 m .38402 .5621 L .38339 .56839 L p .368 .031 .256 r
F P
0 g
s
.38402 .4379 m .37044 .43086 L .36973 .4238 L p .368 .57 .916 r
F P
0 g
s
.35351 .41442 m .36973 .4238 L .37044 .43086 L p .366 .568 .916 r
F P
0 g
s
.49285 .44631 m .49754 .44064 L .50474 .44683 L p .781 .672 .743 r
F P
0 g
s
.50474 .44683 m .49979 .45305 L .49285 .44631 L p .781 .672 .743 r
F P
0 g
s
.54076 .47671 m .54368 .46931 L .55264 .47244 L p .625 .471 .653 r
F P
0 g
s
.55591 .46558 m .55264 .47244 L .54368 .46931 L p .63 .463 .638 r
F P
0 g
s
.49979 .54695 m .50474 .55317 L .49754 .55936 L p .781 .603 .659 r
F P
0 g
s
.50185 .56563 m .49754 .55936 L .50474 .55317 L p .791 .621 .671 r
F P
0 g
s
.55007 .52066 m .55264 .52756 L .54368 .53069 L p .625 .549 .749 r
F P
0 g
s
.54368 .53069 m .54076 .52329 L .55007 .52066 L p .625 .549 .749 r
F P
0 g
s
.45945 .47634 m .45158 .47752 L .44982 .46819 L p .698 .643 .791 r
F P
0 g
s
.44224 .46879 m .44982 .46819 L .45158 .47752 L p .681 .632 .794 r
F P
0 g
s
.45708 .53303 m .44982 .53181 L .45158 .52248 L p .698 .496 .611 r
F P
0 g
s
.45158 .52248 m .45945 .52366 L .45708 .53303 L p .698 .496 .611 r
F P
0 g
s
.48778 .45138 m .49285 .44631 L .49979 .45305 L p .771 .673 .755 r
F P
0 g
s
.49979 .45305 m .49432 .45882 L .48778 .45138 L p .771 .673 .755 r
F P
0 g
s
.5385 .48433 m .54076 .47671 L .55007 .47934 L p .621 .48 .668 r
F P
0 g
s
.55264 .47244 m .55007 .47934 L .54076 .47671 L p .625 .471 .653 r
F P
0 g
s
.54822 .51372 m .55007 .52066 L .54076 .52329 L p .621 .535 .735 r
F P
0 g
s
.54076 .52329 m .5385 .51567 L .54822 .51372 L p .621 .535 .735 r
F P
0 g
s
.49432 .54118 m .49979 .54695 L .49285 .55369 L p .771 .586 .649 r
F P
0 g
s
.49754 .55936 m .49285 .55369 L .49979 .54695 L p .781 .603 .659 r
F P
0 g
s
.46718 .47449 m .45945 .47634 L .45708 .46697 L p .713 .653 .788 r
F P
0 g
s
.44982 .46819 m .45708 .46697 L .45945 .47634 L p .698 .643 .791 r
F P
0 g
s
.464 .5349 m .45708 .53303 L .45945 .52366 L p .713 .512 .615 r
F P
0 g
s
.45945 .52366 m .46718 .52551 L .464 .5349 L p .713 .512 .615 r
F P
0 g
s
.68866 .38859 m .71294 .36733 L .7192 .36905 L p .11 0 .043 r
F P
0 g
s
.74404 .34019 m .7192 .36905 L .71294 .36733 L p .09 0 .141 r
F P
0 g
s
.49792 .27696 m .50381 .2447 L .50842 .24926 L p .988 .883 .55 r
F P
0 g
s
.50842 .24926 m .50216 .28091 L .49792 .27696 L p .988 .883 .55 r
F P
0 g
s
.6942 .60971 m .7192 .63095 L .71294 .63267 L p .11 .428 .871 r
F P
0 g
s
.71294 .63267 m .68866 .61141 L .6942 .60971 L p .11 .428 .871 r
F P
0 g
s
.50216 .71909 m .50842 .75074 L .50381 .7553 L p .988 .731 .364 r
F P
0 g
s
.51638 .79125 m .50381 .7553 L .50842 .75074 L p .971 .655 .312 r
F P
0 g
s
.30919 .39232 m .27864 .38192 L .277 .37564 L p .271 .635 .964 r
F P
0 g
s
.23958 .36856 m .277 .37564 L .27864 .38192 L p .382 .727 .99 r
F P
0 g
s
.30789 .61332 m .277 .62436 L .27864 .61808 L p .271 0 0 r
F P
0 g
s
.27864 .61808 m .30919 .60768 L .30789 .61332 L p .271 0 0 r
F P
0 g
s
.48234 .4558 m .48778 .45138 L .49432 .45882 L p .761 .672 .764 r
F P
0 g
s
.49432 .45882 m .48828 .46399 L .48234 .4558 L p .761 .672 .764 r
F P
0 g
s
.53705 .49215 m .5385 .48433 L .54822 .48628 L p .619 .489 .682 r
F P
0 g
s
.55007 .47934 m .54822 .48628 L .5385 .48433 L p .621 .48 .668 r
F P
0 g
s
.54711 .50681 m .54822 .51372 L .5385 .51567 L p .619 .521 .722 r
F P
0 g
s
.5385 .51567 m .53705 .50785 L .54711 .50681 L p .619 .521 .722 r
F P
0 g
s
.48828 .53601 m .49432 .54118 L .48778 .54862 L p .76 .57 .64 r
F P
0 g
s
.49285 .55369 m .48778 .54862 L .49432 .54118 L p .771 .586 .649 r
F P
0 g
s
.47467 .47184 m .46718 .47449 L .464 .4651 L p .727 .66 .784 r
F P
0 g
s
.45708 .46697 m .464 .4651 L .46718 .47449 L p .713 .653 .788 r
F P
0 g
s
.47055 .5374 m .464 .5349 L .46718 .52551 L p .727 .526 .62 r
F P
0 g
s
.46718 .52551 m .47467 .52816 L .47055 .5374 L p .727 .526 .62 r
F P
0 g
s
.5782 .44854 m .58527 .44168 L .59201 .44481 L p .525 .255 .447 r
F P
0 g
s
.601 .43797 m .59201 .44481 L .58527 .44168 L p .531 .244 .423 r
F P
0 g
s
.49987 .40247 m .50179 .39272 L .50787 .39699 L p .913 .754 .671 r
F P
0 g
s
.50787 .39699 m .50546 .40655 L .49987 .40247 L p .913 .754 .671 r
F P
0 g
s
.58453 .54865 m .59201 .55519 L .58527 .55832 L p .525 .603 .874 r
F P
0 g
s
.58527 .55832 m .5782 .55146 L .58453 .54865 L p .525 .603 .874 r
F P
0 g
s
.50546 .59345 m .50787 .60301 L .50179 .60728 L p .913 .737 .65 r
F P
0 g
s
.50322 .61848 m .50179 .60728 L .50787 .60301 L p .92 .758 .665 r
F P
0 g
s
.41634 .45801 m .40686 .45531 L .4062 .44791 L p .543 .626 .884 r
F P
0 g
s
.39578 .44355 m .4062 .44791 L .40686 .45531 L p .516 .605 .88 r
F P
0 g
s
.41561 .54888 m .4062 .55209 L .40686 .54469 L p .543 .261 .437 r
F P
0 g
s
.40686 .54469 m .41634 .54199 L .41561 .54888 L p .543 .261 .437 r
F P
0 g
s
.53655 .5 m .53705 .49215 L .54711 .49319 L p .617 .499 .696 r
F P
0 g
s
.54822 .48628 m .54711 .49319 L .53705 .49215 L p .619 .489 .682 r
F P
0 g
s
.54675 .5 m .54711 .50681 L .53705 .50785 L p .617 .509 .708 r
F P
0 g
s
.53705 .50785 m .53655 .5 L .54675 .5 L p .617 .509 .708 r
F P
0 g
s
.48172 .46835 m .47467 .47184 L .47055 .4626 L p .739 .666 .778 r
F P
0 g
s
.464 .4651 m .47055 .4626 L .47467 .47184 L p .727 .66 .784 r
F P
0 g
s
.47663 .45951 m .48234 .4558 L .48828 .46399 L p .75 .669 .772 r
F P
0 g
s
.48828 .46399 m .48173 .46835 L .47663 .45951 L p .75 .669 .772 r
F P
0 g
s
.47662 .54048 m .47055 .5374 L .47467 .52816 L p .739 .541 .626 r
F P
0 g
s
.47467 .52816 m .48172 .53165 L .47662 .54048 L p .739 .541 .626 r
F P
0 g
s
.48173 .53165 m .48828 .53601 L .48234 .5442 L p .75 .555 .632 r
F P
0 g
s
.48778 .54862 m .48234 .5442 L .48828 .53601 L p .76 .57 .64 r
F P
0 g
s
.54711 .49319 m .54675 .5 L .53655 .5 L p .617 .499 .696 r
F P
0 g
s
.47055 .4626 m .47662 .45952 L .48172 .46835 L p .739 .666 .778 r
F P
0 g
s
.48234 .5442 m .47663 .54049 L .48173 .53165 L p .75 .555 .632 r
F P
0 g
s
.55591 .46558 m .55991 .45873 L .56736 .46177 L p .582 .39 .587 r
F P
0 g
s
.57228 .45521 m .56736 .46177 L .55991 .45873 L p .588 .379 .565 r
F P
0 g
s
.49581 .42928 m .49943 .42255 L .50578 .42748 L p .836 .717 .733 r
F P
0 g
s
.50578 .42748 m .50185 .43437 L .49581 .42928 L p .836 .717 .733 r
F P
0 g
s
.50185 .56563 m .50578 .57252 L .49943 .57745 L p .836 .648 .649 r
F P
0 g
s
.50265 .58499 m .49943 .57745 L .50578 .57252 L p .846 .671 .664 r
F P
0 g
s
.56334 .53173 m .56736 .53823 L .55991 .54127 L p .582 .56 .795 r
F P
0 g
s
.55991 .54127 m .55591 .53442 L .56334 .53173 L p .582 .56 .795 r
F P
0 g
s
.44224 .46879 m .43431 .46875 L .43321 .46078 L p .655 .654 .837 r
F P
0 g
s
.42507 .4598 m .43321 .46078 L .43431 .46875 L p .632 .637 .838 r
F P
0 g
s
.44085 .53899 m .43321 .53922 L .43431 .53125 L p .655 .415 .544 r
F P
0 g
s
.43431 .53125 m .44224 .53121 L .44085 .53899 L p .655 .415 .544 r
F P
0 g
s
.15705 .38632 m .12019 .40581 L .11798 .40094 L p .758 .962 .934 r
F P
0 g
s
.11798 .40094 m .15464 .38029 L .15705 .38632 L p .758 .962 .934 r
F P
0 g
s
.76465 .69678 m .77635 .73924 L .76992 .74016 L p .045 .14 .64 r
F P
0 g
s
.77147 .78183 m .76992 .74016 L .77635 .73924 L p .027 .021 .512 r
F P
0 g
s
.19726 .6308 m .15464 .61971 L .15705 .61368 L p .64 .139 .045 r
F P
0 g
s
.12019 .59419 m .15705 .61368 L .15464 .61971 L p .758 .275 .093 r
F P
0 g
s
.76992 .25984 m .77147 .21817 L .7768 .21869 L p .027 .023 .515 r
F P
0 g
s
.7768 .21869 m .77635 .26076 L .76992 .25984 L p .027 .023 .515 r
F P
0 g
s
.53809 .17242 m .56901 .14105 L .57302 .14616 L p .857 .98 .857 r
F P
0 g
s
.60834 .12398 m .57302 .14616 L .56901 .14105 L p .755 .961 .935 r
F P
0 g
s
.57302 .85384 m .60834 .87602 L .60522 .88037 L p .755 .272 .091 r
F P
0 g
s
.60522 .88037 m .56901 .85895 L .57302 .85384 L p .755 .272 .091 r
F P
0 g
s
.09504 .43633 m .07822 .4571 L .07708 .45277 L p .932 .934 .78 r
F P
0 g
s
.07708 .45277 m .09341 .4298 L .09504 .43633 L p .932 .934 .78 r
F P
0 g
s
.64734 .88254 m .67374 .88672 L .67055 .88988 L p .57 .122 .147 r
F P
0 g
s
.67055 .88988 m .6425 .88722 L .64734 .88254 L p .57 .122 .147 r
F P
0 g
s
.77147 .78183 m .76409 .81701 L .75762 .81887 L p .247 .113 .494 r
F P
0 g
s
.74804 .84382 m .75762 .81887 L .76409 .81701 L p .202 0 .359 r
F P
0 g
s
.75762 .81887 m .74804 .84382 L .74219 .84604 L p .329 .117 .433 r
F P
0 g
s
.12019 .59419 m .09341 .5702 L .09504 .56367 L p .873 .506 .348 r
F P
0 g
s
.07822 .5429 m .09504 .56367 L .09341 .5702 L p .932 .587 .356 r
F P
0 g
s
.09504 .56367 m .07822 .5429 L .07923 .53672 L p .923 .625 .46 r
F P
0 g
s
.75762 .18113 m .74804 .15618 L .75237 .15736 L p .202 .336 .777 r
F P
0 g
s
.75237 .15736 m .76409 .18299 L .75762 .18113 L p .202 .336 .777 r
F P
0 g
s
.60834 .12398 m .6425 .11278 L .64734 .11746 L p .686 .855 .963 r
F P
0 g
s
.67374 .11328 m .64734 .11746 L .6425 .11278 L p .57 .809 .989 r
F P
0 g
s
.64734 .11746 m .67374 .11328 L .67858 .11724 L p .602 .772 .961 r
F P
0 g
s
.55264 .47244 m .55591 .46558 L .56334 .46827 L p .576 .401 .608 r
F P
0 g
s
.56736 .46177 m .56334 .46827 L .55591 .46558 L p .582 .39 .587 r
F P
0 g
s
.49181 .43529 m .49581 .42928 L .50185 .43437 L p .824 .72 .751 r
F P
0 g
s
.50185 .43437 m .49754 .44064 L .49181 .43529 L p .824 .72 .751 r
F P
0 g
s
.56014 .52526 m .56334 .53173 L .55591 .53442 L p .576 .539 .777 r
F P
0 g
s
.55591 .53442 m .55264 .52756 L .56014 .52526 L p .576 .539 .777 r
F P
0 g
s
.49754 .55936 m .50185 .56563 L .49581 .57072 L p .824 .625 .634 r
F P
0 g
s
.49943 .57745 m .49581 .57072 L .50185 .56563 L p .836 .648 .649 r
F P
0 g
s
.44982 .46819 m .44224 .46879 L .44085 .46101 L p .677 .67 .835 r
F P
0 g
s
.43321 .46078 m .44085 .46101 L .44224 .46879 L p .655 .654 .837 r
F P
0 g
s
.44805 .53945 m .44085 .53899 L .44224 .53121 L p .677 .436 .549 r
F P
0 g
s
.44224 .53121 m .44982 .53181 L .44805 .53945 L p .677 .436 .549 r
F P
0 g
s
.57228 .45521 m .5782 .44854 L .58453 .45135 L p .518 .267 .474 r
F P
0 g
s
.59201 .44481 m .58453 .45135 L .5782 .44854 L p .525 .255 .447 r
F P
0 g
s
.49745 .41103 m .49987 .40247 L .50546 .40655 L p .903 .764 .697 r
F P
0 g
s
.50546 .40655 m .50265 .41501 L .49745 .41103 L p .903 .764 .697 r
F P
0 g
s
.57833 .54228 m .58453 .54865 L .5782 .55146 L p .518 .579 .855 r
F P
0 g
s
.5782 .55146 m .57228 .54479 L .57833 .54228 L p .518 .579 .855 r
F P
0 g
s
.50265 .58499 m .50546 .59345 L .49987 .59753 L p .903 .712 .633 r
F P
0 g
s
.50179 .60728 m .49987 .59753 L .50546 .59345 L p .913 .737 .65 r
F P
0 g
s
.42422 .5467 m .41561 .54888 L .41634 .54199 L p .573 .286 .442 r
F P
0 g
s
.41634 .54199 m .42507 .5402 L .42422 .5467 L p .573 .286 .442 r
F P
0 g
s
.42507 .4598 m .41634 .45801 L .41561 .45112 L p .573 .65 .887 r
F P
0 g
s
.4062 .44791 m .41561 .45112 L .41634 .45801 L p .543 .626 .884 r
F P
0 g
s
.49861 .37816 m .49908 .36482 L .50421 .36851 L p .979 .791 .579 r
F P
0 g
s
.50421 .36851 m .50322 .38152 L .49861 .37816 L p .979 .791 .579 r
F P
0 g
s
.601 .43797 m .61177 .43061 L .61753 .43321 L p .406 .052 .248 r
F P
0 g
s
.63113 .42529 m .61753 .43321 L .61177 .43061 L p .409 .045 .232 r
F P
0 g
s
.50322 .61848 m .50421 .63149 L .49908 .63518 L p .979 .809 .602 r
F P
0 g
s
.49914 .65092 m .49908 .63518 L .50421 .63149 L p .981 .82 .61 r
F P
0 g
s
.60621 .55971 m .61753 .56679 L .61177 .56939 L p .406 .611 .933 r
F P
0 g
s
.61177 .56939 m .601 .56203 L .60621 .55971 L p .406 .611 .933 r
F P
0 g
s
.39578 .44355 m .38402 .4379 L .38339 .43161 L p .387 .586 .922 r
F P
0 g
s
.36973 .4238 m .38339 .43161 L .38402 .4379 L p .368 .57 .916 r
F P
0 g
s
.39518 .56212 m .38339 .56839 L .38402 .5621 L p .387 .045 .259 r
F P
0 g
s
.38402 .5621 m .39578 .55645 L .39518 .56212 L p .387 .045 .259 r
F P
0 g
s
.66654 .40417 m .68866 .38859 L .6942 .39029 L p .126 0 0 r
F P
0 g
s
.7192 .36905 m .6942 .39029 L .68866 .38859 L p .11 0 .043 r
F P
0 g
s
.49593 .30447 m .49792 .27696 L .50216 .28091 L p .991 .838 .47 r
F P
0 g
s
.50216 .28091 m .49972 .30785 L .49593 .30447 L p .991 .838 .47 r
F P
0 g
s
.49972 .69215 m .50216 .71909 L .49792 .72304 L p .991 .781 .4 r
F P
0 g
s
.50381 .7553 m .49792 .72304 L .50216 .71909 L p .988 .731 .364 r
F P
0 g
s
.33374 .40369 m .30919 .39232 L .30789 .38668 L p .187 .56 .934 r
F P
0 g
s
.277 .37564 m .30789 .38668 L .30919 .39232 L p .271 .635 .964 r
F P
0 g
s
.3327 .60129 m .30789 .61332 L .30919 .60768 L p .187 0 0 r
F P
0 g
s
.30919 .60768 m .33374 .59631 L .3327 .60129 L p .187 0 0 r
F P
0 g
s
.67136 .59424 m .6942 .60971 L .68866 .61141 L p .126 .482 .899 r
F P
0 g
s
.68866 .61141 m .66654 .59583 L .67136 .59424 L p .126 .482 .899 r
F P
0 g
s
.55007 .47934 m .55264 .47244 L .56014 .47474 L p .571 .413 .629 r
F P
0 g
s
.56334 .46827 m .56014 .47474 L .55264 .47244 L p .576 .401 .608 r
F P
0 g
s
.48745 .44061 m .49181 .43529 L .49754 .44064 L p .811 .722 .767 r
F P
0 g
s
.49754 .44064 m .49285 .44631 L .48745 .44061 L p .811 .722 .767 r
F P
0 g
s
.55771 .51883 m .56014 .52526 L .55264 .52756 L p .571 .519 .758 r
F P
0 g
s
.55264 .52756 m .55007 .52066 L .55771 .51883 L p .571 .519 .758 r
F P
0 g
s
.49285 .55369 m .49754 .55936 L .49181 .56471 L p .811 .602 .62 r
F P
0 g
s
.49581 .57072 m .49181 .56471 L .49754 .55936 L p .824 .625 .634 r
F P
0 g
s
.45708 .46697 m .44982 .46819 L .44805 .46055 L p .698 .683 .832 r
F P
0 g
s
.44085 .46101 m .44805 .46055 L .44982 .46819 L p .677 .67 .835 r
F P
0 g
s
.45484 .54057 m .44805 .53945 L .44982 .53181 L p .698 .457 .555 r
F P
0 g
s
.44982 .53181 m .45708 .53303 L .45484 .54057 L p .698 .457 .555 r
F P
0 g
s
.54822 .48628 m .55007 .47934 L .55771 .48117 L p .567 .426 .648 r
F P
0 g
s
.56014 .47474 m .55771 .48117 L .55007 .47934 L p .571 .413 .629 r
F P
0 g
s
.48276 .44526 m .48745 .44061 L .49285 .44631 L p .797 .722 .781 r
F P
0 g
s
.49285 .44631 m .48778 .45138 L .48276 .44526 L p .797 .722 .781 r
F P
0 g
s
.55602 .51244 m .55771 .51883 L .55007 .52066 L p .567 .5 .74 r
F P
0 g
s
.55007 .52066 m .54822 .51372 L .55602 .51244 L p .567 .5 .74 r
F P
0 g
s
.48778 .54862 m .49285 .55369 L .48745 .55939 L p .797 .58 .607 r
F P
0 g
s
.49181 .56471 m .48745 .55939 L .49285 .55369 L p .811 .602 .62 r
F P
0 g
s
.464 .4651 m .45708 .46697 L .45484 .45943 L p .718 .695 .827 r
F P
0 g
s
.46121 .5423 m .45484 .54057 L .45708 .53303 L p .718 .478 .561 r
F P
0 g
s
.45708 .53303 m .464 .5349 L .46121 .5423 L p .718 .478 .561 r
F P
0 g
s
.44805 .46055 m .45484 .45943 L .45708 .46697 L p .698 .683 .832 r
F P
0 g
s
.54711 .49319 m .54822 .48628 L .55602 .48756 L p .564 .439 .667 r
F P
0 g
s
.55771 .48117 m .55602 .48756 L .54822 .48628 L p .567 .426 .648 r
F P
0 g
s
.4778 .44926 m .48276 .44526 L .48778 .45138 L p .783 .72 .794 r
F P
0 g
s
.48778 .45138 m .48234 .4558 L .4778 .44926 L p .783 .72 .794 r
F P
0 g
s
.55504 .50615 m .55602 .51244 L .54822 .51372 L p .564 .483 .722 r
F P
0 g
s
.54822 .51372 m .54711 .50681 L .55504 .50615 L p .564 .483 .722 r
F P
0 g
s
.46715 .54459 m .46121 .5423 L .464 .5349 L p .736 .498 .568 r
F P
0 g
s
.464 .5349 m .47055 .5374 L .46715 .54459 L p .736 .498 .568 r
F P
0 g
s
.48234 .5442 m .48778 .54862 L .48276 .55474 L p .783 .558 .595 r
F P
0 g
s
.48745 .55939 m .48276 .55474 L .48778 .54862 L p .797 .58 .607 r
F P
0 g
s
.47055 .4626 m .464 .4651 L .46121 .4577 L p .736 .704 .821 r
F P
0 g
s
.45484 .45943 m .46121 .4577 L .464 .4651 L p .718 .695 .827 r
F P
0 g
s
.07923 .46328 m .06993 .47757 L .0693 .47382 L p .967 .894 .701 r
F P
0 g
s
.0693 .47382 m .07822 .4571 L .07923 .46328 L p .967 .894 .701 r
F P
0 g
s
.06993 .52243 m .07923 .53672 L .07822 .5429 L p .967 .685 .445 r
F P
0 g
s
.07923 .53672 m .06993 .52243 L .07044 .51772 L p .959 .705 .509 r
F P
0 g
s
.73446 .86124 m .74219 .84604 L .74804 .84382 L p .264 0 .295 r
F P
0 g
s
.74219 .84604 m .73446 .86124 L .73012 .86315 L p .344 .069 .344 r
F P
0 g
s
.67858 .88276 m .69561 .88367 L .69268 .88609 L p .486 .066 .167 r
F P
0 g
s
.69268 .88609 m .67374 .88672 L .67858 .88276 L p .486 .066 .167 r
F P
0 g
s
.69561 .11633 m .67858 .11724 L .67374 .11328 L p .486 .728 .978 r
F P
0 g
s
.67858 .11724 m .69561 .11633 L .69943 .11913 L p .509 .706 .959 r
F P
0 g
s
.74219 .15396 m .73446 .13876 L .73802 .14009 L p .264 .443 .85 r
F P
0 g
s
.73802 .14009 m .74804 .15618 L .74219 .15396 L p .264 .443 .85 r
F P
0 g
s
.47264 .45261 m .4778 .44926 L .48234 .4558 L p .768 .717 .804 r
F P
0 g
s
.48234 .4558 m .47663 .45951 L .47264 .45261 L p .768 .717 .804 r
F P
0 g
s
.54675 .5 m .54711 .49319 L .55504 .49385 L p .563 .452 .686 r
F P
0 g
s
.55602 .48756 m .55504 .49385 L .54711 .49319 L p .564 .439 .667 r
F P
0 g
s
.55473 .5 m .55504 .50615 L .54711 .50681 L p .563 .467 .704 r
F P
0 g
s
.54711 .50681 m .54675 .5 L .55473 .5 L p .563 .467 .704 r
F P
0 g
s
.47264 .54739 m .46715 .54459 L .47055 .5374 L p .753 .518 .576 r
F P
0 g
s
.47055 .5374 m .47662 .54048 L .47264 .54739 L p .753 .518 .576 r
F P
0 g
s
.47662 .45952 m .47055 .4626 L .46715 .45541 L p .753 .712 .813 r
F P
0 g
s
.46121 .4577 m .46715 .45541 L .47055 .4626 L p .736 .704 .821 r
F P
0 g
s
.47663 .54049 m .48234 .5442 L .4778 .55074 L p .768 .538 .585 r
F P
0 g
s
.48276 .55474 m .4778 .55074 L .48234 .5442 L p .783 .558 .595 r
F P
0 g
s
.55504 .49385 m .55473 .5 L .54675 .5 L p .563 .452 .686 r
F P
0 g
s
.46715 .45541 m .47264 .45261 L .47662 .45952 L p .753 .712 .813 r
F P
0 g
s
.4778 .55074 m .47264 .54739 L .47663 .54049 L p .768 .538 .585 r
F P
0 g
s
.56736 .46177 m .57228 .45521 L .57833 .45772 L p .511 .281 .503 r
F P
0 g
s
.58453 .45135 m .57833 .45772 L .57228 .45521 L p .518 .267 .474 r
F P
0 g
s
.49456 .41856 m .49745 .41103 L .50265 .41501 L p .892 .772 .723 r
F P
0 g
s
.50265 .41501 m .49943 .42255 L .49456 .41856 L p .892 .772 .723 r
F P
0 g
s
.49943 .57745 m .50265 .58499 L .49745 .58897 L p .892 .684 .615 r
F P
0 g
s
.49987 .59753 m .49745 .58897 L .50265 .58499 L p .903 .712 .633 r
F P
0 g
s
.57325 .53601 m .57833 .54228 L .57228 .54479 L p .511 .552 .835 r
F P
0 g
s
.57228 .54479 m .56736 .53823 L .57325 .53601 L p .511 .552 .835 r
F P
0 g
s
.43219 .54544 m .42422 .5467 L .42507 .5402 L p .604 .314 .449 r
F P
0 g
s
.42507 .5402 m .43321 .53922 L .43219 .54544 L p .604 .314 .449 r
F P
0 g
s
.43321 .46078 m .42507 .4598 L .42422 .4533 L p .604 .673 .889 r
F P
0 g
s
.41561 .45112 m .42422 .4533 L .42507 .4598 L p .573 .65 .887 r
F P
0 g
s
.59201 .44481 m .601 .43797 L .60621 .44029 L p .4 .063 .275 r
F P
0 g
s
.61753 .43321 m .60621 .44029 L .601 .43797 L p .406 .052 .248 r
F P
0 g
s
.4976 .38961 m .49861 .37816 L .50322 .38152 L p .976 .804 .607 r
F P
0 g
s
.50322 .38152 m .50179 .39272 L .4976 .38961 L p .976 .804 .607 r
F P
0 g
s
.50179 .60728 m .50322 .61848 L .49861 .62184 L p .976 .789 .588 r
F P
0 g
s
.49908 .63518 m .49861 .62184 L .50322 .61848 L p .979 .809 .602 r
F P
0 g
s
.5968 .55312 m .60621 .55971 L .601 .56203 L p .4 .59 .92 r
F P
0 g
s
.601 .56203 m .59201 .55519 L .5968 .55312 L p .4 .59 .92 r
F P
0 g
s
.4062 .44791 m .39578 .44355 L .39518 .43788 L p .417 .612 .93 r
F P
0 g
s
.38339 .43161 m .39518 .43788 L .39578 .44355 L p .387 .586 .922 r
F P
0 g
s
.4056 .55727 m .39518 .56212 L .39578 .55645 L p .417 .069 .265 r
F P
0 g
s
.39578 .55645 m .4062 .55209 L .4056 .55727 L p .417 .069 .265 r
F P
0 g
s
.64736 .41592 m .66654 .40417 L .67136 .40576 L p .137 0 0 r
F P
0 g
s
.6942 .39029 m .67136 .40576 L .66654 .40417 L p .126 0 0 r
F P
0 g
s
.49578 .32745 m .49593 .30447 L .49972 .30785 L p .989 .806 .418 r
F P
0 g
s
.49972 .30785 m .49913 .33034 L .49578 .32745 L p .989 .806 .418 r
F P
0 g
s
.49913 .66966 m .49972 .69215 L .49593 .69553 L p .989 .809 .422 r
F P
0 g
s
.49792 .72304 m .49593 .69553 L .49972 .69215 L p .991 .781 .4 r
F P
0 g
s
.65154 .58262 m .67136 .59424 L .66654 .59583 L p .137 .515 .914 r
F P
0 g
s
.66654 .59583 m .64736 .58408 L .65154 .58262 L p .137 .515 .914 r
F P
0 g
s
.35268 .58993 m .3327 .60129 L .33374 .59631 L p .134 0 0 r
F P
0 g
s
.33374 .59631 m .35351 .58558 L .35268 .58993 L p .134 0 0 r
F P
0 g
s
.35351 .41442 m .33374 .40369 L .3327 .39871 L p .134 .511 .912 r
F P
0 g
s
.30789 .38668 m .3327 .39871 L .33374 .40369 L p .187 .56 .934 r
F P
0 g
s
.60834 .87602 m .6425 .88722 L .64032 .8905 L p .629 .118 .014 r
F P
0 g
s
.64032 .8905 m .60522 .88037 L .60834 .87602 L p .629 .118 .014 r
F P
0 g
s
.12019 .40581 m .09341 .4298 L .09165 .42627 L p .853 .986 .853 r
F P
0 g
s
.09165 .42627 m .11798 .40094 L .12019 .40581 L p .853 .986 .853 r
F P
0 g
s
.77147 .21817 m .76409 .18299 L .76803 .18322 L p .014 .117 .628 r
F P
0 g
s
.76803 .18322 m .7768 .21869 L .77147 .21817 L p .014 .117 .628 r
F P
0 g
s
.77635 .73924 m .7768 .78131 L .77147 .78183 L p .027 .021 .512 r
F P
0 g
s
.76409 .81701 m .77147 .78183 L .7768 .78131 L p .014 0 .369 r
F P
0 g
s
.15464 .61971 m .11798 .59906 L .12019 .59419 L p .758 .275 .093 r
F P
0 g
s
.09341 .5702 m .12019 .59419 L .11798 .59906 L p .853 .406 .143 r
F P
0 g
s
.56901 .14105 m .60522 .11963 L .60834 .12398 L p .755 .961 .935 r
F P
0 g
s
.6425 .11278 m .60834 .12398 L .60522 .11963 L p .629 .909 .983 r
F P
0 g
s
.56334 .46827 m .56736 .46177 L .57325 .46399 L p .503 .296 .532 r
F P
0 g
s
.57833 .45772 m .57325 .46399 L .56736 .46177 L p .511 .281 .503 r
F P
0 g
s
.49123 .4252 m .49456 .41856 L .49943 .42255 L p .878 .779 .748 r
F P
0 g
s
.49943 .42255 m .49581 .42928 L .49123 .4252 L p .878 .779 .748 r
F P
0 g
s
.56916 .5298 m .57325 .53601 L .56736 .53823 L p .503 .525 .813 r
F P
0 g
s
.56736 .53823 m .56334 .53173 L .56916 .5298 L p .503 .525 .813 r
F P
0 g
s
.49581 .57072 m .49943 .57745 L .49456 .58144 L p .878 .655 .596 r
F P
0 g
s
.49745 .58897 m .49456 .58144 L .49943 .57745 L p .892 .684 .615 r
F P
0 g
s
.44085 .46101 m .43321 .46078 L .43219 .45456 L p .635 .695 .889 r
F P
0 g
s
.42422 .4533 m .43219 .45456 L .43321 .46078 L p .604 .673 .889 r
F P
0 g
s
.43961 .54499 m .43219 .54544 L .43321 .53922 L p .635 .342 .456 r
F P
0 g
s
.43321 .53922 m .44085 .53899 L .43961 .54499 L p .635 .342 .456 r
F P
0 g
s
.71443 .8714 m .71691 .8757 L .71395 .87747 L p .395 .038 .236 r
F P
0 g
s
.71395 .87747 m .70905 .8746 L .71443 .8714 L p .395 .038 .236 r
F P
0 g
s
.71691 .8757 m .71443 .8714 L .71989 .86834 L p .377 .031 .246 r
F P
0 g
s
.71443 .1286 m .71691 .1243 L .71992 .12598 L p .377 .585 .924 r
F P
0 g
s
.71992 .12598 m .71989 .13166 L .71443 .1286 L p .377 .585 .924 r
F P
0 g
s
.71691 .1243 m .71443 .1286 L .70905 .1254 L p .395 .608 .934 r
F P
0 g
s
.07115 .5 m .06618 .5 L .06613 .49655 L p .982 .81 .595 r
F P
0 g
s
.06613 .49655 m .07107 .49374 L .07115 .5 L p .982 .81 .595 r
F P
0 g
s
.06618 .5 m .07115 .5 L .07107 .50626 L p .982 .794 .575 r
F P
0 g
s
.06613 .50345 m .07107 .50626 L .07083 .51225 L p .984 .778 .548 r
F P
0 g
s
.07107 .50626 m .06613 .50345 L .06618 .5 L p .982 .794 .575 r
F P
0 g
s
.70905 .8746 m .71395 .87747 L .71115 .87923 L p .403 .03 .213 r
F P
0 g
s
.71115 .87923 m .70398 .8778 L .70905 .8746 L p .403 .03 .213 r
F P
0 g
s
.71992 .87402 m .71989 .86834 L .72519 .86555 L p .35 .012 .244 r
F P
0 g
s
.71989 .86834 m .71992 .87402 L .71691 .8757 L p .377 .031 .246 r
F P
0 g
s
.71395 .12253 m .70905 .1254 L .70398 .1222 L p .403 .628 .945 r
F P
0 g
s
.70905 .1254 m .71395 .12253 L .71691 .1243 L p .395 .608 .934 r
F P
0 g
s
.71989 .13166 m .71992 .12598 L .72285 .12752 L p .35 .56 .914 r
F P
0 g
s
.72285 .12752 m .72519 .13445 L .71989 .13166 L p .35 .56 .914 r
F P
0 g
s
.07107 .49374 m .06613 .49655 L .066 .49325 L p .984 .828 .609 r
F P
0 g
s
.066 .49325 m .07083 .48775 L .07107 .49374 L p .984 .828 .609 r
F P
0 g
s
.56014 .47474 m .56334 .46827 L .56916 .4702 L p .496 .312 .56 r
F P
0 g
s
.57325 .46399 m .56916 .4702 L .56334 .46827 L p .503 .296 .532 r
F P
0 g
s
.48751 .43105 m .49123 .4252 L .49581 .42928 L p .863 .784 .772 r
F P
0 g
s
.49581 .42928 m .49181 .43529 L .48751 .43105 L p .863 .784 .772 r
F P
0 g
s
.49181 .56471 m .49581 .57072 L .49123 .5748 L p .863 .625 .577 r
F P
0 g
s
.49456 .58144 m .49123 .5748 L .49581 .57072 L p .878 .655 .596 r
F P
0 g
s
.44805 .46055 m .44085 .46101 L .43961 .45501 L p .665 .716 .886 r
F P
0 g
s
.43219 .45456 m .43961 .45501 L .44085 .46101 L p .635 .695 .889 r
F P
0 g
s
.56596 .52366 m .56916 .5298 L .56334 .53173 L p .496 .499 .789 r
F P
0 g
s
.56334 .53173 m .56014 .52526 L .56596 .52366 L p .496 .499 .789 r
F P
0 g
s
.44653 .5453 m .43961 .54499 L .44085 .53899 L p .665 .37 .463 r
F P
0 g
s
.44085 .53899 m .44805 .53945 L .44653 .5453 L p .665 .37 .463 r
F P
0 g
s
.58453 .45135 m .59201 .44481 L .5968 .44688 L p .392 .078 .308 r
F P
0 g
s
.60621 .44029 m .5968 .44688 L .59201 .44481 L p .4 .063 .275 r
F P
0 g
s
.49602 .39952 m .4976 .38961 L .50179 .39272 L p .969 .82 .641 r
F P
0 g
s
.50179 .39272 m .49987 .40247 L .49602 .39952 L p .969 .82 .641 r
F P
0 g
s
.49987 .59753 m .50179 .60728 L .4976 .61039 L p .969 .762 .57 r
F P
0 g
s
.49861 .62184 m .4976 .61039 L .50179 .60728 L p .976 .789 .588 r
F P
0 g
s
.589 .5468 m .5968 .55312 L .59201 .55519 L p .392 .563 .902 r
F P
0 g
s
.59201 .55519 m .58453 .54865 L .589 .5468 L p .392 .563 .902 r
F P
0 g
s
.41497 .55368 m .4056 .55727 L .4062 .55209 L p .454 .099 .272 r
F P
0 g
s
.4062 .55209 m .41561 .54888 L .41497 .55368 L p .454 .099 .272 r
F P
0 g
s
.41561 .45112 m .4062 .44791 L .4056 .44273 L p .454 .643 .938 r
F P
0 g
s
.39518 .43788 m .4056 .44273 L .4062 .44791 L p .417 .612 .93 r
F P
0 g
s
.55771 .48117 m .56014 .47474 L .56596 .47634 L p .49 .328 .588 r
F P
0 g
s
.56916 .4702 m .56596 .47634 L .56014 .47474 L p .496 .312 .56 r
F P
0 g
s
.48344 .43615 m .48751 .43105 L .49181 .43529 L p .846 .786 .793 r
F P
0 g
s
.49181 .43529 m .48745 .44061 L .48344 .43615 L p .846 .786 .793 r
F P
0 g
s
.56358 .51758 m .56596 .52366 L .56014 .52526 L p .49 .472 .765 r
F P
0 g
s
.56014 .52526 m .55771 .51883 L .56358 .51758 L p .49 .472 .765 r
F P
0 g
s
.48745 .55939 m .49181 .56471 L .48751 .56895 L p .846 .595 .559 r
F P
0 g
s
.49123 .5748 m .48751 .56895 L .49181 .56471 L p .863 .625 .577 r
F P
0 g
s
.45484 .45943 m .44805 .46055 L .44653 .4547 L p .693 .733 .882 r
F P
0 g
s
.43961 .45501 m .44653 .4547 L .44805 .46055 L p .665 .716 .886 r
F P
0 g
s
.45299 .54627 m .44653 .5453 L .44805 .53945 L p .693 .398 .471 r
F P
0 g
s
.44805 .53945 m .45484 .54057 L .45299 .54627 L p .693 .398 .471 r
F P
0 g
s
.72285 .87248 m .72519 .86555 L .73012 .86315 L p .312 0 .228 r
F P
0 g
s
.72519 .86555 m .72285 .87248 L .71992 .87402 L p .35 .012 .244 r
F P
0 g
s
.70398 .8778 m .71115 .87923 L .70866 .88092 L p .4 .009 .177 r
F P
0 g
s
.70866 .88092 m .69943 .88087 L .70398 .8778 L p .4 .009 .177 r
F P
0 g
s
.07083 .48775 m .066 .49325 L .06578 .49024 L p .987 .847 .617 r
F P
0 g
s
.06578 .49024 m .07044 .48228 L .07083 .48775 L p .987 .847 .617 r
F P
0 g
s
.72519 .13445 m .72285 .12752 L .72556 .12884 L p .312 .531 .905 r
F P
0 g
s
.72556 .12884 m .73012 .13685 L .72519 .13445 L p .312 .531 .905 r
F P
0 g
s
.71115 .12077 m .70398 .1222 L .69943 .11913 L p .4 .645 .956 r
F P
0 g
s
.70398 .1222 m .71115 .12077 L .71395 .12253 L p .403 .628 .945 r
F P
0 g
s
.066 .50675 m .07083 .51225 L .07044 .51772 L p .987 .764 .515 r
F P
0 g
s
.07083 .51225 m .066 .50675 L .06613 .50345 L p .984 .778 .548 r
F P
0 g
s
.55602 .48756 m .55771 .48117 L .56358 .48242 L p .486 .346 .615 r
F P
0 g
s
.47907 .44056 m .48344 .43615 L .48745 .44061 L p .828 .786 .813 r
F P
0 g
s
.48745 .44061 m .48276 .44526 L .47907 .44056 L p .828 .786 .813 r
F P
0 g
s
.56596 .47634 m .56358 .48242 L .55771 .48117 L p .49 .328 .588 r
F P
0 g
s
.48276 .55474 m .48745 .55939 L .48344 .56385 L p .828 .566 .543 r
F P
0 g
s
.48751 .56895 m .48344 .56385 L .48745 .55939 L p .846 .595 .559 r
F P
0 g
s
.56194 .51159 m .56358 .51758 L .55771 .51883 L p .486 .448 .74 r
F P
0 g
s
.55771 .51883 m .55602 .51244 L .56194 .51159 L p .486 .448 .74 r
F P
0 g
s
.45899 .54785 m .45299 .54627 L .45484 .54057 L p .72 .426 .48 r
F P
0 g
s
.45484 .54057 m .46121 .5423 L .45899 .54785 L p .72 .426 .48 r
F P
0 g
s
.46121 .4577 m .45484 .45943 L .45299 .45373 L p .72 .749 .875 r
F P
0 g
s
.44653 .4547 m .45299 .45373 L .45484 .45943 L p .693 .733 .882 r
F P
0 g
s
.63113 .42529 m .64736 .41592 L .65154 .41738 L p .142 0 0 r
F P
0 g
s
.67136 .40576 m .65154 .41738 L .64736 .41592 L p .137 0 0 r
F P
0 g
s
.49617 .34658 m .49578 .32745 L .49913 .33034 L p .987 .791 .395 r
F P
0 g
s
.49913 .33034 m .49914 .34908 L .49617 .34658 L p .987 .791 .395 r
F P
0 g
s
.63478 .57339 m .65154 .58262 L .64736 .58408 L p .142 .529 .919 r
F P
0 g
s
.64736 .58408 m .63113 .57471 L .63478 .57339 L p .142 .529 .919 r
F P
0 g
s
.49914 .65092 m .49913 .66966 L .49578 .67255 L p .987 .82 .431 r
F P
0 g
s
.49593 .69553 m .49578 .67255 L .49913 .66966 L p .989 .809 .422 r
F P
0 g
s
.36973 .4238 m .35351 .41442 L .35268 .41007 L p .111 .489 .901 r
F P
0 g
s
.36905 .58002 m .35268 .58993 L .35351 .58558 L p .111 0 0 r
F P
0 g
s
.35351 .58558 m .36973 .5762 L .36905 .58002 L p .111 0 0 r
F P
0 g
s
.3327 .39871 m .35268 .41007 L .35351 .41442 L p .134 .511 .912 r
F P
0 g
s
.55504 .49385 m .55602 .48756 L .56194 .48841 L p .483 .364 .641 r
F P
0 g
s
.56358 .48242 m .56194 .48841 L .55602 .48756 L p .486 .346 .615 r
F P
0 g
s
.47445 .44431 m .47907 .44056 L .48276 .44526 L p .808 .783 .829 r
F P
0 g
s
.48276 .44526 m .4778 .44926 L .47445 .44431 L p .808 .783 .829 r
F P
0 g
s
.561 .50572 m .56194 .51159 L .55602 .51244 L p .483 .424 .716 r
F P
0 g
s
.55602 .51244 m .55504 .50615 L .561 .50572 L p .483 .424 .716 r
F P
0 g
s
.46455 .54997 m .45899 .54785 L .46121 .5423 L p .744 .454 .49 r
F P
0 g
s
.46121 .5423 m .46715 .54459 L .46455 .54997 L p .744 .454 .49 r
F P
0 g
s
.46715 .45541 m .46121 .4577 L .45899 .45215 L p .744 .761 .867 r
F P
0 g
s
.45299 .45373 m .45899 .45215 L .46121 .4577 L p .72 .749 .875 r
F P
0 g
s
.4778 .55074 m .48276 .55474 L .47907 .55944 L p .808 .537 .527 r
F P
0 g
s
.48344 .56385 m .47907 .55944 L .48276 .55474 L p .828 .566 .543 r
F P
0 g
s
.5607 .5 m .561 .50572 L .55504 .50615 L p .481 .403 .691 r
F P
0 g
s
.55504 .50615 m .55473 .5 L .5607 .5 L p .481 .403 .691 r
F P
0 g
s
.55473 .5 m .55504 .49385 L .561 .49428 L p .481 .383 .667 r
F P
0 g
s
.56194 .48841 m .561 .49428 L .55504 .49385 L p .483 .364 .641 r
F P
0 g
s
.46965 .44743 m .47445 .44431 L .4778 .44926 L p .788 .778 .844 r
F P
0 g
s
.4778 .44926 m .47264 .45261 L .46965 .44743 L p .788 .778 .844 r
F P
0 g
s
.47264 .45261 m .46715 .45541 L .46455 .45003 L p .767 .771 .856 r
F P
0 g
s
.45899 .45215 m .46455 .45003 L .46715 .45541 L p .744 .761 .867 r
F P
0 g
s
.47264 .54739 m .4778 .55074 L .47445 .55569 L p .788 .509 .514 r
F P
0 g
s
.47907 .55944 m .47445 .55569 L .4778 .55074 L p .808 .537 .527 r
F P
0 g
s
.46965 .55257 m .46455 .54997 L .46715 .54459 L p .767 .482 .501 r
F P
0 g
s
.46715 .54459 m .47264 .54739 L .46965 .55257 L p .767 .482 .501 r
F P
0 g
s
.46455 .45003 m .46965 .44743 L .47264 .45261 L p .767 .771 .856 r
F P
0 g
s
.561 .49428 m .5607 .5 L .55473 .5 L p .481 .383 .667 r
F P
0 g
s
.47445 .55569 m .46965 .55257 L .47264 .54739 L p .788 .509 .514 r
F P
0 g
s
.49389 .40816 m .49602 .39952 L .49987 .40247 L p .959 .836 .678 r
F P
0 g
s
.49987 .40247 m .49745 .41103 L .49389 .40816 L p .959 .836 .678 r
F P
0 g
s
.57833 .45772 m .58453 .45135 L .589 .4532 L p .384 .095 .346 r
F P
0 g
s
.5968 .44688 m .589 .4532 L .58453 .45135 L p .392 .078 .308 r
F P
0 g
s
.58259 .54063 m .589 .5468 L .58453 .54865 L p .384 .531 .88 r
F P
0 g
s
.58453 .54865 m .57833 .54228 L .58259 .54063 L p .384 .531 .88 r
F P
0 g
s
.42352 .55121 m .41497 .55368 L .41561 .54888 L p .496 .134 .281 r
F P
0 g
s
.41561 .54888 m .42422 .5467 L .42352 .55121 L p .496 .134 .281 r
F P
0 g
s
.49745 .58897 m .49987 .59753 L .49602 .60048 L p .959 .73 .548 r
F P
0 g
s
.4976 .61039 m .49602 .60048 L .49987 .59753 L p .969 .762 .57 r
F P
0 g
s
.42422 .4533 m .41561 .45112 L .41497 .44632 L p .496 .677 .946 r
F P
0 g
s
.4056 .44273 m .41497 .44632 L .41561 .45112 L p .454 .643 .938 r
F P
0 g
s
.07822 .4571 m .0693 .47382 L .06859 .47121 L p .97 .926 .686 r
F P
0 g
s
.06859 .47121 m .07708 .45277 L .07822 .4571 L p .97 .926 .686 r
F P
0 g
s
.67374 .88672 m .69268 .88609 L .69077 .88801 L p .439 0 .05 r
F P
0 g
s
.69077 .88801 m .67055 .88988 L .67374 .88672 L p .439 0 .05 r
F P
0 g
s
.76409 .81701 m .75237 .84264 L .74804 .84382 L p .202 0 .359 r
F P
0 g
s
.73802 .85991 m .74804 .84382 L .75237 .84264 L p .154 0 .215 r
F P
0 g
s
.74804 .84382 m .73802 .85991 L .73446 .86124 L p .264 0 .295 r
F P
0 g
s
.74804 .15618 m .73802 .14009 L .74064 .14078 L p .154 .376 .828 r
F P
0 g
s
.74064 .14078 m .75237 .15736 L .74804 .15618 L p .154 .376 .828 r
F P
0 g
s
.6425 .11278 m .67055 .11012 L .67374 .11328 L p .57 .809 .989 r
F P
0 g
s
.69268 .11391 m .67374 .11328 L .67055 .11012 L p .439 .743 .992 r
F P
0 g
s
.67374 .11328 m .69268 .11391 L .69561 .11633 L p .486 .728 .978 r
F P
0 g
s
.09341 .5702 m .07708 .54723 L .07822 .5429 L p .932 .587 .356 r
F P
0 g
s
.0693 .52618 m .07822 .5429 L .07708 .54723 L p .97 .658 .357 r
F P
0 g
s
.07822 .5429 m .0693 .52618 L .06993 .52243 L p .967 .685 .445 r
F P
0 g
s
.69943 .88087 m .70866 .88092 L .70656 .88247 L p .386 0 .124 r
F P
0 g
s
.70656 .88247 m .69561 .88367 L .69943 .88087 L p .386 0 .124 r
F P
0 g
s
.07044 .48228 m .06578 .49024 L .0655 .48765 L p .99 .867 .618 r
F P
0 g
s
.0655 .48765 m .06993 .47757 L .07044 .48228 L p .99 .867 .618 r
F P
0 g
s
.73012 .13685 m .72556 .12884 L .72795 .12988 L p .26 .497 .894 r
F P
0 g
s
.72795 .12988 m .73446 .13876 L .73012 .13685 L p .26 .497 .894 r
F P
0 g
s
.72556 .87116 m .73012 .86315 L .73446 .86124 L p .26 0 .197 r
F P
0 g
s
.73012 .86315 m .72556 .87116 L .72285 .87248 L p .312 0 .228 r
F P
0 g
s
.06578 .50976 m .07044 .51772 L .06993 .52243 L p .99 .749 .473 r
F P
0 g
s
.07044 .51772 m .06578 .50976 L .066 .50675 L p .987 .764 .515 r
F P
0 g
s
.70866 .11908 m .69943 .11913 L .69561 .11633 L p .386 .659 .966 r
F P
0 g
s
.69943 .11913 m .70866 .11908 L .71115 .12077 L p .4 .645 .956 r
F P
0 g
s
.61753 .43321 m .63113 .42529 L .63478 .42661 L p .141 0 0 r
F P
0 g
s
.65154 .41738 m .63478 .42661 L .63113 .42529 L p .142 0 0 r
F P
0 g
s
.49644 .36262 m .49617 .34658 L .49914 .34908 L p .987 .793 .399 r
F P
0 g
s
.49914 .34908 m .49908 .36482 L .49644 .36262 L p .987 .793 .399 r
F P
0 g
s
.49908 .63518 m .49914 .65092 L .49617 .65342 L p .987 .819 .43 r
F P
0 g
s
.49578 .67255 m .49617 .65342 L .49914 .65092 L p .987 .82 .431 r
F P
0 g
s
.62075 .5656 m .63478 .57339 L .63113 .57471 L p .141 .527 .918 r
F P
0 g
s
.63113 .57471 m .61753 .56679 L .62075 .5656 L p .141 .527 .918 r
F P
0 g
s
.38339 .43161 m .36973 .4238 L .36905 .41998 L p .115 .492 .903 r
F P
0 g
s
.35268 .41007 m .36905 .41998 L .36973 .4238 L p .111 .489 .901 r
F P
0 g
s
.38281 .57177 m .36905 .58002 L .36973 .5762 L p .115 0 0 r
F P
0 g
s
.36973 .5762 m .38339 .56839 L .38281 .57177 L p .115 0 0 r
F P
0 g
s
.57325 .46399 m .57833 .45772 L .58259 .45937 L p .374 .114 .386 r
F P
0 g
s
.589 .4532 m .58259 .45937 L .57833 .45772 L p .384 .095 .346 r
F P
0 g
s
.49125 .41571 m .49389 .40816 L .49745 .41103 L p .946 .851 .716 r
F P
0 g
s
.49745 .41103 m .49456 .41856 L .49125 .41571 L p .946 .851 .716 r
F P
0 g
s
.49456 .58144 m .49745 .58897 L .49389 .59184 L p .946 .694 .524 r
F P
0 g
s
.49602 .60048 m .49389 .59184 L .49745 .58897 L p .959 .73 .548 r
F P
0 g
s
.57738 .53456 m .58259 .54063 L .57833 .54228 L p .374 .497 .854 r
F P
0 g
s
.57833 .54228 m .57325 .53601 L .57738 .53456 L p .374 .497 .854 r
F P
0 g
s
.43138 .54973 m .42352 .55121 L .42422 .5467 L p .54 .172 .29 r
F P
0 g
s
.42422 .5467 m .43219 .54544 L .43138 .54973 L p .54 .172 .29 r
F P
0 g
s
.43219 .45456 m .42422 .4533 L .42352 .44879 L p .54 .711 .95 r
F P
0 g
s
.41497 .44632 m .42352 .44879 L .42422 .4533 L p .496 .677 .946 r
F P
0 g
s
.09341 .4298 m .07708 .45277 L .07585 .45046 L p .918 .978 .751 r
F P
0 g
s
.07585 .45046 m .09165 .42627 L .09341 .4298 L p .918 .978 .751 r
F P
0 g
s
.11798 .59906 m .09165 .57373 L .09341 .5702 L p .853 .406 .143 r
F P
0 g
s
.07708 .54723 m .09341 .5702 L .09165 .57373 L p .918 .521 .191 r
F P
0 g
s
.7768 .78131 m .76803 .81678 L .76409 .81701 L p .014 0 .369 r
F P
0 g
s
.6425 .88722 m .67055 .88988 L .66917 .89209 L p .49 0 0 r
F P
0 g
s
.66917 .89209 m .64032 .8905 L .6425 .88722 L p .49 0 0 r
F P
0 g
s
.75237 .84264 m .76409 .81701 L .76803 .81678 L p .005 0 .224 r
F P
0 g
s
.60522 .11963 m .64032 .1095 L .6425 .11278 L p .629 .909 .983 r
F P
0 g
s
.67055 .11012 m .6425 .11278 L .64032 .1095 L p .49 .83 .998 r
F P
0 g
s
.76409 .18299 m .75237 .15736 L .75497 .15744 L p .005 .206 .718 r
F P
0 g
s
.75497 .15744 m .76803 .18322 L .76409 .18299 L p .005 .206 .718 r
F P
0 g
s
.56916 .4702 m .57325 .46399 L .57738 .46544 L p .365 .135 .427 r
F P
0 g
s
.58259 .45937 m .57738 .46544 L .57325 .46399 L p .374 .114 .386 r
F P
0 g
s
.48814 .42231 m .49125 .41571 L .49456 .41856 L p .929 .862 .753 r
F P
0 g
s
.49456 .41856 m .49123 .4252 L .48814 .42231 L p .929 .862 .753 r
F P
0 g
s
.57321 .52857 m .57738 .53456 L .57325 .53601 L p .365 .461 .825 r
F P
0 g
s
.57325 .53601 m .56916 .5298 L .57321 .52857 L p .365 .461 .825 r
F P
0 g
s
.49123 .5748 m .49456 .58144 L .49125 .58429 L p .929 .655 .499 r
F P
0 g
s
.49389 .59184 m .49125 .58429 L .49456 .58144 L p .946 .694 .524 r
F P
0 g
s
.43865 .54912 m .43138 .54973 L .43219 .54544 L p .584 .211 .3 r
F P
0 g
s
.43219 .54544 m .43961 .54499 L .43865 .54912 L p .584 .211 .3 r
F P
0 g
s
.43961 .45501 m .43219 .45456 L .43138 .45027 L p .584 .743 .952 r
F P
0 g
s
.42352 .44879 m .43138 .45027 L .43219 .45456 L p .54 .711 .95 r
F P
0 g
s
.56596 .47634 m .56916 .4702 L .57321 .47143 L p .356 .158 .468 r
F P
0 g
s
.57738 .46544 m .57321 .47143 L .56916 .4702 L p .365 .135 .427 r
F P
0 g
s
.48462 .42808 m .48814 .42231 L .49123 .4252 L p .909 .87 .787 r
F P
0 g
s
.49123 .4252 m .48751 .43105 L .48462 .42808 L p .909 .87 .787 r
F P
0 g
s
.56998 .52264 m .57321 .52857 L .56916 .5298 L p .356 .424 .794 r
F P
0 g
s
.56916 .5298 m .56596 .52366 L .56998 .52264 L p .356 .424 .794 r
F P
0 g
s
.48751 .56895 m .49123 .5748 L .48814 .57769 L p .909 .615 .474 r
F P
0 g
s
.49125 .58429 m .48814 .57769 L .49123 .5748 L p .929 .655 .499 r
F P
0 g
s
.4454 .54928 m .43865 .54912 L .43961 .54499 L p .627 .251 .311 r
F P
0 g
s
.43961 .54499 m .44653 .5453 L .4454 .54928 L p .627 .251 .311 r
F P
0 g
s
.44653 .4547 m .43961 .45501 L .43865 .45088 L p .627 .773 .95 r
F P
0 g
s
.43138 .45027 m .43865 .45088 L .43961 .45501 L p .584 .743 .952 r
F P
0 g
s
.60621 .44029 m .61753 .43321 L .62075 .4344 L p .136 0 0 r
F P
0 g
s
.63478 .42661 m .62075 .4344 L .61753 .43321 L p .141 0 0 r
F P
0 g
s
.49624 .3762 m .49644 .36262 L .49908 .36482 L p .989 .81 .424 r
F P
0 g
s
.49908 .36482 m .49861 .37816 L .49624 .3762 L p .989 .81 .424 r
F P
0 g
s
.60909 .55864 m .62075 .5656 L .61753 .56679 L p .136 .511 .912 r
F P
0 g
s
.61753 .56679 m .60621 .55971 L .60909 .55864 L p .136 .511 .912 r
F P
0 g
s
.49861 .62184 m .49908 .63518 L .49644 .63738 L p .989 .806 .419 r
F P
0 g
s
.49617 .65342 m .49644 .63738 L .49908 .63518 L p .987 .819 .43 r
F P
0 g
s
.39518 .43788 m .38339 .43161 L .38281 .42823 L p .14 .516 .914 r
F P
0 g
s
.36905 .41998 m .38281 .42823 L .38339 .43161 L p .115 .492 .903 r
F P
0 g
s
.39467 .56515 m .38281 .57177 L .38339 .56839 L p .14 0 0 r
F P
0 g
s
.38339 .56839 m .39518 .56212 L .39467 .56515 L p .14 0 0 r
F P
0 g
s
.56358 .48242 m .56596 .47634 L .56998 .47736 L p .349 .182 .508 r
F P
0 g
s
.57321 .47143 m .56998 .47736 L .56596 .47634 L p .356 .158 .468 r
F P
0 g
s
.48076 .43307 m .48462 .42808 L .48751 .43105 L p .887 .874 .819 r
F P
0 g
s
.48751 .43105 m .48344 .43615 L .48076 .43307 L p .887 .874 .819 r
F P
0 g
s
.56759 .5168 m .56998 .52264 L .56596 .52366 L p .349 .388 .761 r
F P
0 g
s
.56596 .52366 m .56358 .51758 L .56759 .5168 L p .349 .388 .761 r
F P
0 g
s
.45166 .55013 m .4454 .54928 L .44653 .5453 L p .668 .292 .324 r
F P
0 g
s
.44653 .5453 m .45299 .54627 L .45166 .55013 L p .668 .292 .324 r
F P
0 g
s
.48344 .56385 m .48751 .56895 L .48462 .57192 L p .887 .574 .45 r
F P
0 g
s
.48814 .57769 m .48462 .57192 L .48751 .56895 L p .909 .615 .474 r
F P
0 g
s
.45299 .45373 m .44653 .4547 L .4454 .45072 L p .668 .799 .945 r
F P
0 g
s
.43865 .45088 m .4454 .45072 L .44653 .4547 L p .627 .773 .95 r
F P
0 g
s
.4766 .43734 m .48076 .43307 L .48344 .43615 L p .861 .875 .847 r
F P
0 g
s
.48344 .43615 m .47907 .44056 L .4766 .43734 L p .861 .875 .847 r
F P
0 g
s
.56194 .48841 m .56358 .48242 L .56759 .4832 L p .343 .207 .547 r
F P
0 g
s
.56998 .47736 m .56759 .4832 L .56358 .48242 L p .349 .182 .508 r
F P
0 g
s
.56596 .51106 m .56759 .5168 L .56358 .51758 L p .343 .353 .727 r
F P
0 g
s
.56358 .51758 m .56194 .51159 L .56596 .51106 L p .343 .353 .727 r
F P
0 g
s
.45899 .45215 m .45299 .45373 L .45166 .44987 L p .706 .821 .936 r
F P
0 g
s
.4454 .45072 m .45166 .44987 L .45299 .45373 L p .668 .799 .945 r
F P
0 g
s
.47907 .55944 m .48344 .56385 L .48076 .56693 L p .861 .532 .427 r
F P
0 g
s
.48462 .57192 m .48076 .56693 L .48344 .56385 L p .887 .574 .45 r
F P
0 g
s
.45744 .55159 m .45166 .55013 L .45299 .54627 L p .706 .332 .337 r
F P
0 g
s
.45299 .54627 m .45899 .54785 L .45744 .55159 L p .706 .332 .337 r
F P
0 g
s
.73446 .13876 m .72795 .12988 L .7299 .13061 L p .193 .457 .879 r
F P
0 g
s
.7299 .13061 m .73802 .14009 L .73446 .13876 L p .193 .457 .879 r
F P
0 g
s
.70656 .11753 m .69561 .11633 L .69268 .11391 L p .356 .667 .974 r
F P
0 g
s
.69561 .11633 m .70656 .11753 L .70866 .11908 L p .386 .659 .966 r
F P
0 g
s
.72795 .87012 m .73446 .86124 L .73802 .85991 L p .193 0 .147 r
F P
0 g
s
.73446 .86124 m .72795 .87012 L .72556 .87116 L p .26 0 .197 r
F P
0 g
s
.69561 .88367 m .70656 .88247 L .70495 .88379 L p .356 0 .053 r
F P
0 g
s
.70495 .88379 m .69268 .88609 L .69561 .88367 L p .356 0 .053 r
F P
0 g
s
.0655 .51235 m .06993 .52243 L .0693 .52618 L p .99 .732 .419 r
F P
0 g
s
.06993 .52243 m .0655 .51235 L .06578 .50976 L p .99 .749 .473 r
F P
0 g
s
.06993 .47757 m .0655 .48765 L .06515 .4856 L p .99 .886 .607 r
F P
0 g
s
.06515 .4856 m .0693 .47382 L .06993 .47757 L p .99 .886 .607 r
F P
0 g
s
.561 .49428 m .56194 .48841 L .56596 .48894 L p .339 .233 .585 r
F P
0 g
s
.56759 .4832 m .56596 .48894 L .56194 .48841 L p .343 .207 .547 r
F P
0 g
s
.47221 .44095 m .4766 .43734 L .47907 .44056 L p .834 .871 .871 r
F P
0 g
s
.47907 .44056 m .47445 .44431 L .47221 .44095 L p .834 .871 .871 r
F P
0 g
s
.56503 .50545 m .56596 .51106 L .56194 .51159 L p .339 .32 .692 r
F P
0 g
s
.56194 .51159 m .561 .50572 L .56503 .50545 L p .339 .32 .692 r
F P
0 g
s
.47445 .55569 m .47907 .55944 L .4766 .56266 L p .834 .491 .406 r
F P
0 g
s
.48076 .56693 m .4766 .56266 L .47907 .55944 L p .861 .532 .427 r
F P
0 g
s
.46276 .55359 m .45744 .55159 L .45899 .54785 L p .742 .372 .352 r
F P
0 g
s
.45899 .54785 m .46455 .54997 L .46276 .55359 L p .742 .372 .352 r
F P
0 g
s
.46455 .45003 m .45899 .45215 L .45744 .44841 L p .742 .839 .924 r
F P
0 g
s
.45166 .44987 m .45744 .44841 L .45899 .45215 L p .706 .821 .936 r
F P
0 g
s
.5607 .5 m .561 .49428 L .56503 .49455 L p .337 .261 .621 r
F P
0 g
s
.56596 .48894 m .56503 .49455 L .561 .49428 L p .339 .233 .585 r
F P
0 g
s
.56474 .5 m .56503 .50545 L .561 .50572 L p .337 .29 .657 r
F P
0 g
s
.561 .50572 m .5607 .5 L .56474 .5 L p .337 .29 .657 r
F P
0 g
s
.46763 .44394 m .47221 .44095 L .47445 .44431 L p .805 .864 .892 r
F P
0 g
s
.47445 .44431 m .46965 .44743 L .46763 .44394 L p .805 .864 .892 r
F P
0 g
s
.46965 .44743 m .46455 .45003 L .46276 .44641 L p .775 .853 .909 r
F P
0 g
s
.45744 .44841 m .46276 .44641 L .46455 .45003 L p .742 .839 .924 r
F P
0 g
s
.46965 .55257 m .47445 .55569 L .47221 .55905 L p .805 .451 .386 r
F P
0 g
s
.4766 .56266 m .47221 .55905 L .47445 .55569 L p .834 .491 .406 r
F P
0 g
s
.46763 .55606 m .46276 .55359 L .46455 .54997 L p .775 .412 .369 r
F P
0 g
s
.46455 .54997 m .46965 .55257 L .46763 .55606 L p .775 .412 .369 r
F P
0 g
s
.56503 .49455 m .56474 .5 L .5607 .5 L p .337 .261 .621 r
F P
0 g
s
.46276 .44641 m .46763 .44394 L .46965 .44743 L p .775 .853 .909 r
F P
0 g
s
.47221 .55905 m .46763 .55606 L .46965 .55257 L p .805 .451 .386 r
F P
0 g
s
.5968 .44688 m .60621 .44029 L .60909 .44136 L p .126 0 0 r
F P
0 g
s
.62075 .4344 m .60909 .44136 L .60621 .44029 L p .136 0 0 r
F P
0 g
s
.49546 .38782 m .49624 .3762 L .49861 .37816 L p .991 .835 .465 r
F P
0 g
s
.49861 .37816 m .4976 .38961 L .49546 .38782 L p .991 .835 .465 r
F P
0 g
s
.59942 .55216 m .60909 .55864 L .60621 .55971 L p .126 .485 .9 r
F P
0 g
s
.60621 .55971 m .5968 .55312 L .59942 .55216 L p .126 .485 .9 r
F P
0 g
s
.4976 .61039 m .49861 .62184 L .49624 .6238 L p .991 .783 .401 r
F P
0 g
s
.49644 .63738 m .49624 .6238 L .49861 .62184 L p .989 .806 .419 r
F P
0 g
s
.40512 .56003 m .39467 .56515 L .39518 .56212 L p .181 0 0 r
F P
0 g
s
.39518 .56212 m .4056 .55727 L .40512 .56003 L p .181 0 0 r
F P
0 g
s
.4056 .44273 m .39518 .43788 L .39467 .43485 L p .181 .556 .932 r
F P
0 g
s
.38281 .42823 m .39467 .43485 L .39518 .43788 L p .14 .516 .914 r
F P
0 g
s
.49406 .39784 m .49546 .38782 L .4976 .38961 L p .99 .866 .516 r
F P
0 g
s
.4976 .38961 m .49602 .39952 L .49406 .39784 L p .99 .866 .516 r
F P
0 g
s
.589 .4532 m .5968 .44688 L .59942 .44784 L p .113 0 .01 r
F P
0 g
s
.60909 .44136 m .59942 .44784 L .5968 .44688 L p .126 0 0 r
F P
0 g
s
.59144 .54593 m .59942 .55216 L .5968 .55312 L p .113 .448 .882 r
F P
0 g
s
.5968 .55312 m .589 .5468 L .59144 .54593 L p .113 .448 .882 r
F P
0 g
s
.49602 .60048 m .4976 .61039 L .49546 .61218 L p .99 .751 .376 r
F P
0 g
s
.49624 .6238 m .49546 .61218 L .4976 .61039 L p .991 .783 .401 r
F P
0 g
s
.41497 .44632 m .4056 .44273 L .40512 .43997 L p .235 .605 .952 r
F P
0 g
s
.39467 .43485 m .40512 .43997 L .4056 .44273 L p .181 .556 .932 r
F P
0 g
s
.4145 .55622 m .40512 .56003 L .4056 .55727 L p .235 0 0 r
F P
0 g
s
.4056 .55727 m .41497 .55368 L .4145 .55622 L p .235 0 0 r
F P
0 g
s
.71691 .8757 m .71803 .87764 L .71659 .8785 L p .276 0 .088 r
F P
0 g
s
.71659 .8785 m .71395 .87747 L .71691 .8757 L p .276 0 .088 r
F P
0 g
s
.71803 .87764 m .71691 .8757 L .71992 .87402 L p .264 0 .095 r
F P
0 g
s
.71691 .1243 m .71803 .12236 L .7195 .12318 L p .264 .556 .931 r
F P
0 g
s
.7195 .12318 m .71992 .12598 L .71691 .1243 L p .264 .556 .931 r
F P
0 g
s
.71803 .12236 m .71691 .1243 L .71395 .12253 L p .276 .572 .938 r
F P
0 g
s
.06618 .5 m .06393 .5 L .06391 .49832 L p 1 .822 .52 r
F P
0 g
s
.06391 .49832 m .06613 .49655 L .06618 .5 L p 1 .822 .52 r
F P
0 g
s
.06393 .5 m .06618 .5 L .06613 .50345 L p 1 .81 .506 r
F P
0 g
s
.71395 .87747 m .71659 .8785 L .71523 .87936 L p .279 0 .07 r
F P
0 g
s
.71523 .87936 m .71115 .87923 L .71395 .87747 L p .279 0 .07 r
F P
0 g
s
.71992 .12598 m .7195 .12318 L .72092 .12392 L p .243 .538 .923 r
F P
0 g
s
.72092 .12392 m .72285 .12752 L .71992 .12598 L p .243 .538 .923 r
F P
0 g
s
.06613 .49655 m .06391 .49832 L .06385 .49671 L p .999 .833 .528 r
F P
0 g
s
.06385 .49671 m .066 .49325 L .06613 .49655 L p .999 .833 .528 r
F P
0 g
s
.7195 .87682 m .71992 .87402 L .72285 .87248 L p .243 0 .091 r
F P
0 g
s
.71992 .87402 m .7195 .87682 L .71803 .87764 L p .264 0 .095 r
F P
0 g
s
.71659 .1215 m .71395 .12253 L .71115 .12077 L p .279 .585 .944 r
F P
0 g
s
.71395 .12253 m .71659 .1215 L .71803 .12236 L p .276 .572 .938 r
F P
0 g
s
.06391 .50168 m .06613 .50345 L .066 .50675 L p .999 .799 .486 r
F P
0 g
s
.06613 .50345 m .06391 .50168 L .06393 .5 L p 1 .81 .506 r
F P
0 g
s
.5849 .53986 m .59144 .54593 L .589 .5468 L p .098 .405 .857 r
F P
0 g
s
.589 .5468 m .58259 .54063 L .5849 .53986 L p .098 .405 .857 r
F P
0 g
s
.58259 .45937 m .589 .4532 L .59144 .45407 L p .098 0 .062 r
F P
0 g
s
.59942 .44784 m .59144 .45407 L .589 .4532 L p .113 0 .01 r
F P
0 g
s
.49208 .40655 m .49406 .39784 L .49602 .39952 L p .985 .897 .574 r
F P
0 g
s
.49602 .39952 m .49389 .40816 L .49208 .40655 L p .985 .897 .574 r
F P
0 g
s
.49389 .59184 m .49602 .60048 L .49406 .60216 L p .985 .711 .345 r
F P
0 g
s
.49546 .61218 m .49406 .60216 L .49602 .60048 L p .99 .751 .376 r
F P
0 g
s
.42303 .55359 m .4145 .55622 L .41497 .55368 L p .296 0 0 r
F P
0 g
s
.41497 .55368 m .42352 .55121 L .42303 .55359 L p .296 0 0 r
F P
0 g
s
.42352 .44879 m .41497 .44632 L .4145 .44378 L p .296 .66 .972 r
F P
0 g
s
.40512 .43997 m .4145 .44378 L .41497 .44632 L p .235 .605 .952 r
F P
0 g
s
.64032 .1095 m .66917 .10791 L .67055 .11012 L p .49 .83 .998 r
F P
0 g
s
.69077 .11199 m .67055 .11012 L .66917 .10791 L p .353 .738 .986 r
F P
0 g
s
.67055 .11012 m .69077 .11199 L .69268 .11391 L p .439 .743 .992 r
F P
0 g
s
.09165 .57373 m .07585 .54954 L .07708 .54723 L p .918 .521 .191 r
F P
0 g
s
.06859 .52879 m .07708 .54723 L .07585 .54954 L p .954 .613 .233 r
F P
0 g
s
.07708 .54723 m .06859 .52879 L .0693 .52618 L p .97 .658 .357 r
F P
0 g
s
.76803 .81678 m .75497 .84256 L .75237 .84264 L p .005 0 .224 r
F P
0 g
s
.74064 .85922 m .75237 .84264 L .75497 .84256 L p .001 0 .089 r
F P
0 g
s
.75237 .84264 m .74064 .85922 L .73802 .85991 L p .154 0 .215 r
F P
0 g
s
.67055 .88988 m .69077 .88801 L .68997 .88936 L p .353 0 0 r
F P
0 g
s
.68997 .88936 m .66917 .89209 L .67055 .88988 L p .353 0 0 r
F P
0 g
s
.75237 .15736 m .74064 .14078 L .74221 .1408 L p .001 .284 .783 r
F P
0 g
s
.74221 .1408 m .75497 .15744 L .75237 .15736 L p .001 .284 .783 r
F P
0 g
s
.07708 .45277 m .06859 .47121 L .06782 .46984 L p .954 .945 .639 r
F P
0 g
s
.06782 .46984 m .07585 .45046 L .07708 .45277 L p .954 .945 .639 r
F P
0 g
s
.71115 .87923 m .71523 .87936 L .71402 .88019 L p .273 0 .041 r
F P
0 g
s
.71402 .88019 m .70866 .88092 L .71115 .87923 L p .273 0 .041 r
F P
0 g
s
.72285 .12752 m .72092 .12392 L .72224 .12456 L p .213 .516 .914 r
F P
0 g
s
.72224 .12456 m .72556 .12884 L .72285 .12752 L p .213 .516 .914 r
F P
0 g
s
.72092 .87608 m .72285 .87248 L .72556 .87116 L p .213 0 .076 r
F P
0 g
s
.72285 .87248 m .72092 .87608 L .7195 .87682 L p .243 0 .091 r
F P
0 g
s
.066 .49325 m .06385 .49671 L .06374 .49525 L p .999 .844 .53 r
F P
0 g
s
.06374 .49525 m .06578 .49024 L .066 .49325 L p .999 .844 .53 r
F P
0 g
s
.71523 .12064 m .71115 .12077 L .70866 .11908 L p .273 .594 .949 r
F P
0 g
s
.71115 .12077 m .71523 .12064 L .71659 .1215 L p .279 .585 .944 r
F P
0 g
s
.06385 .50329 m .066 .50675 L .06578 .50976 L p .999 .787 .46 r
F P
0 g
s
.066 .50675 m .06385 .50329 L .06391 .50168 L p .999 .799 .486 r
F P
0 g
s
.73802 .14009 m .7299 .13061 L .73133 .13098 L p .107 .407 .858 r
F P
0 g
s
.73133 .13098 m .74064 .14078 L .73802 .14009 L p .107 .407 .858 r
F P
0 g
s
.7299 .86939 m .73802 .85991 L .74064 .85922 L p .107 0 .075 r
F P
0 g
s
.73802 .85991 m .7299 .86939 L .72795 .87012 L p .193 0 .147 r
F P
0 g
s
.69268 .88609 m .70495 .88379 L .70391 .88485 L p .307 0 0 r
F P
0 g
s
.70391 .88485 m .69077 .88801 L .69268 .88609 L p .307 0 0 r
F P
0 g
s
.0693 .47382 m .06515 .4856 L .06475 .48417 L p .985 .899 .582 r
F P
0 g
s
.06475 .48417 m .06859 .47121 L .0693 .47382 L p .985 .899 .582 r
F P
0 g
s
.06515 .5144 m .0693 .52618 L .06859 .52879 L p .985 .71 .351 r
F P
0 g
s
.0693 .52618 m .06515 .5144 L .0655 .51235 L p .99 .732 .419 r
F P
0 g
s
.70495 .11621 m .69268 .11391 L .69077 .11199 L p .307 .665 .973 r
F P
0 g
s
.69268 .11391 m .70495 .11621 L .70656 .11753 L p .356 .667 .974 r
F P
0 g
s
.48956 .41413 m .49208 .40655 L .49389 .40816 L p .973 .926 .634 r
F P
0 g
s
.49389 .40816 m .49125 .41571 L .48956 .41413 L p .973 .926 .634 r
F P
0 g
s
.57738 .46544 m .58259 .45937 L .5849 .46014 L p .082 0 .12 r
F P
0 g
s
.59144 .45407 m .5849 .46014 L .58259 .45937 L p .098 0 .062 r
F P
0 g
s
.57959 .53389 m .5849 .53986 L .58259 .54063 L p .082 .355 .825 r
F P
0 g
s
.58259 .54063 m .57738 .53456 L .57959 .53389 L p .082 .355 .825 r
F P
0 g
s
.49125 .58429 m .49389 .59184 L .49208 .59345 L p .973 .663 .311 r
F P
0 g
s
.49406 .60216 m .49208 .59345 L .49389 .59184 L p .985 .711 .345 r
F P
0 g
s
.43138 .45027 m .42352 .44879 L .42303 .44641 L p .362 .716 .987 r
F P
0 g
s
.4145 .44378 m .42303 .44641 L .42352 .44879 L p .296 .66 .972 r
F P
0 g
s
.43085 .55198 m .42303 .55359 L .42352 .55121 L p .362 0 0 r
F P
0 g
s
.42352 .55121 m .43138 .54973 L .43085 .55198 L p .362 0 0 r
F P
0 g
s
.48656 .42073 m .48956 .41413 L .49125 .41571 L p .955 .951 .693 r
F P
0 g
s
.49125 .41571 m .48814 .42231 L .48656 .42073 L p .955 .951 .693 r
F P
0 g
s
.57321 .47143 m .57738 .46544 L .57959 .46611 L p .067 0 .18 r
F P
0 g
s
.5849 .46014 m .57959 .46611 L .57738 .46544 L p .082 0 .12 r
F P
0 g
s
.57536 .528 m .57959 .53389 L .57738 .53456 L p .067 .302 .787 r
F P
0 g
s
.57738 .53456 m .57321 .52857 L .57536 .528 L p .067 .302 .787 r
F P
0 g
s
.48814 .57769 m .49125 .58429 L .48956 .58587 L p .955 .609 .274 r
F P
0 g
s
.49208 .59345 m .48956 .58587 L .49125 .58429 L p .973 .663 .311 r
F P
0 g
s
.43807 .55127 m .43085 .55198 L .43138 .54973 L p .43 0 0 r
F P
0 g
s
.43138 .54973 m .43865 .54912 L .43807 .55127 L p .43 0 0 r
F P
0 g
s
.43865 .45088 m .43138 .45027 L .43085 .44802 L p .43 .769 .997 r
F P
0 g
s
.42303 .44641 m .43085 .44802 L .43138 .45027 L p .362 .716 .987 r
F P
0 g
s
.72084 .63193 m .74598 .66108 L .74404 .65981 L p 0 0 .525 r
F P
0 g
s
.74404 .65981 m .7192 .63095 L .72084 .63193 L p 0 0 .525 r
F P
0 g
s
.76465 .69678 m .74404 .65981 L .74598 .66108 L p 0 0 .449 r
F P
0 g
s
.7192 .36905 m .74404 .34019 L .74598 .33892 L p 0 0 0 r
F P
0 g
s
.74404 .34019 m .76465 .30322 L .76674 .30167 L p 0 0 0 r
F P
0 g
s
.76674 .30167 m .74598 .33892 L .74404 .34019 L p 0 0 0 r
F P
0 g
s
.277 .37564 m .23958 .36856 L .23752 .36751 L p 0 .511 .757 r
F P
0 g
s
.23958 .36856 m .19726 .3692 L .19487 .36816 L p .119 .668 .807 r
F P
0 g
s
.19487 .36816 m .23752 .36751 L .23958 .36856 L p .119 .668 .807 r
F P
0 g
s
.50381 .7553 m .51638 .79125 L .51651 .79356 L p .73 .406 0 r
F P
0 g
s
.51638 .79125 m .53809 .82758 L .53839 .83017 L p .708 .286 0 r
F P
0 g
s
.53839 .83017 m .51651 .79356 L .51638 .79125 L p .708 .286 0 r
F P
0 g
s
.50383 .24278 m .51651 .20644 L .51638 .20875 L p .73 .785 .297 r
F P
0 g
s
.51638 .20875 m .50381 .2447 L .50383 .24278 L p .73 .785 .297 r
F P
0 g
s
.53809 .17242 m .51638 .20875 L .51651 .20644 L p .708 .871 .467 r
F P
0 g
s
.27532 .62529 m .23752 .63249 L .23958 .63144 L p 0 0 0 r
F P
0 g
s
.23958 .63144 m .277 .62436 L .27532 .62529 L p 0 0 0 r
F P
0 g
s
.19726 .6308 m .23958 .63144 L .23752 .63249 L p .119 0 0 r
F P
0 g
s
.53809 .82758 m .56901 .85895 L .56951 .86154 L p .65 .136 0 r
F P
0 g
s
.56951 .86154 m .53839 .83017 L .53809 .82758 L p .65 .136 0 r
F P
0 g
s
.76465 .30322 m .77635 .26076 L .77835 .25903 L p 0 0 0 r
F P
0 g
s
.77835 .25903 m .76674 .30167 L .76465 .30322 L p 0 0 0 r
F P
0 g
s
.19726 .3692 m .15464 .38029 L .15214 .37942 L p .335 .818 .827 r
F P
0 g
s
.15214 .37942 m .19487 .36816 L .19726 .3692 L p .335 .818 .827 r
F P
0 g
s
.74598 .66108 m .76674 .69833 L .76465 .69678 L p 0 0 .449 r
F P
0 g
s
.77635 .73924 m .76465 .69678 L .76674 .69833 L p 0 0 .343 r
F P
0 g
s
.51651 .20644 m .53839 .16983 L .53809 .17242 L p .708 .871 .467 r
F P
0 g
s
.56901 .14105 m .53809 .17242 L .53839 .16983 L p .65 .926 .645 r
F P
0 g
s
.23752 .63249 m .19487 .63184 L .19726 .6308 L p .119 0 0 r
F P
0 g
s
.15464 .61971 m .19726 .6308 L .19487 .63184 L p .335 0 0 r
F P
0 g
s
.72224 .87544 m .72556 .87116 L .72795 .87012 L p .174 0 .049 r
F P
0 g
s
.72556 .87116 m .72224 .87544 L .72092 .87608 L p .213 0 .076 r
F P
0 g
s
.72556 .12884 m .72224 .12456 L .7234 .12507 L p .174 .49 .903 r
F P
0 g
s
.7234 .12507 m .72795 .12988 L .72556 .12884 L p .174 .49 .903 r
F P
0 g
s
.70866 .88092 m .71402 .88019 L .713 .88094 L p .258 0 .001 r
F P
0 g
s
.713 .88094 m .70656 .88247 L .70866 .88092 L p .258 0 .001 r
F P
0 g
s
.06578 .49024 m .06374 .49525 L .0636 .49399 L p .997 .853 .524 r
F P
0 g
s
.0636 .49399 m .0655 .48765 L .06578 .49024 L p .997 .853 .524 r
F P
0 g
s
.06374 .50475 m .06578 .50976 L .0655 .51235 L p .997 .774 .428 r
F P
0 g
s
.06578 .50976 m .06374 .50475 L .06385 .50329 L p .999 .787 .46 r
F P
0 g
s
.71402 .11981 m .70866 .11908 L .70656 .11753 L p .258 .598 .951 r
F P
0 g
s
.70866 .11908 m .71402 .11981 L .71523 .12064 L p .273 .594 .949 r
F P
0 g
s
.56998 .47736 m .57321 .47143 L .57536 .472 L p .053 0 .243 r
F P
0 g
s
.57959 .46611 m .57536 .472 L .57321 .47143 L p .067 0 .18 r
F P
0 g
s
.48315 .42647 m .48656 .42073 L .48814 .42231 L p .93 .969 .749 r
F P
0 g
s
.48814 .42231 m .48462 .42808 L .48315 .42647 L p .93 .969 .749 r
F P
0 g
s
.5721 .52217 m .57536 .528 L .57321 .52857 L p .053 .248 .744 r
F P
0 g
s
.57321 .52857 m .56998 .52264 L .5721 .52217 L p .053 .248 .744 r
F P
0 g
s
.48462 .57192 m .48814 .57769 L .48656 .57927 L p .93 .551 .237 r
F P
0 g
s
.48956 .58587 m .48656 .57927 L .48814 .57769 L p .955 .609 .274 r
F P
0 g
s
.4454 .45072 m .43865 .45088 L .43807 .44873 L p .496 .819 1 r
F P
0 g
s
.43085 .44802 m .43807 .44873 L .43865 .45088 L p .43 .769 .997 r
F P
0 g
s
.44475 .55135 m .43807 .55127 L .43865 .54912 L p .496 0 0 r
F P
0 g
s
.43865 .54912 m .4454 .54928 L .44475 .55135 L p .496 0 0 r
F P
0 g
s
.69552 .61046 m .72084 .63193 L .7192 .63095 L p 0 .094 .573 r
F P
0 g
s
.7192 .63095 m .6942 .60971 L .69552 .61046 L p 0 .094 .573 r
F P
0 g
s
.6942 .39029 m .7192 .36905 L .72084 .36807 L p 0 0 0 r
F P
0 g
s
.74598 .33892 m .72084 .36807 L .7192 .36905 L p 0 0 0 r
F P
0 g
s
.4979 .27544 m .50383 .24278 L .50381 .2447 L p .729 .698 .161 r
F P
0 g
s
.50381 .2447 m .49792 .27696 L .4979 .27544 L p .729 .698 .161 r
F P
0 g
s
.49792 .72304 m .50381 .7553 L .50383 .75722 L p .729 .492 0 r
F P
0 g
s
.51651 .79356 m .50383 .75722 L .50381 .7553 L p .73 .406 0 r
F P
0 g
s
.30658 .6141 m .27532 .62529 L .277 .62436 L p 0 0 0 r
F P
0 g
s
.277 .62436 m .30789 .61332 L .30658 .6141 L p 0 0 0 r
F P
0 g
s
.30789 .38668 m .277 .37564 L .27532 .37471 L p 0 .377 .699 r
F P
0 g
s
.23752 .36751 m .27532 .37471 L .277 .37564 L p 0 .511 .757 r
F P
0 g
s
.56759 .4832 m .56998 .47736 L .5721 .47783 L p .041 0 .305 r
F P
0 g
s
.57536 .472 m .5721 .47783 L .56998 .47736 L p .053 0 .243 r
F P
0 g
s
.47939 .43142 m .48315 .42647 L .48462 .42808 L p .9 .98 .801 r
F P
0 g
s
.48462 .42808 m .48076 .43307 L .47939 .43142 L p .9 .98 .801 r
F P
0 g
s
.48076 .56693 m .48462 .57192 L .48315 .57353 L p .9 .489 .2 r
F P
0 g
s
.48656 .57927 m .48315 .57353 L .48462 .57192 L p .93 .551 .237 r
F P
0 g
s
.5697 .51644 m .5721 .52217 L .56998 .52264 L p .041 .193 .696 r
F P
0 g
s
.56998 .52264 m .56759 .5168 L .5697 .51644 L p .041 .193 .696 r
F P
0 g
s
.45091 .55214 m .44475 .55135 L .4454 .54928 L p .561 .053 .004 r
F P
0 g
s
.4454 .54928 m .45166 .55013 L .45091 .55214 L p .561 .053 .004 r
F P
0 g
s
.45166 .44987 m .4454 .45072 L .44475 .44865 L p .561 .863 .996 r
F P
0 g
s
.43807 .44873 m .44475 .44865 L .4454 .45072 L p .496 .819 1 r
F P
0 g
s
.15464 .38029 m .11798 .40094 L .11569 .40035 L p .546 .924 .799 r
F P
0 g
s
.11569 .40035 m .15214 .37942 L .15464 .38029 L p .546 .924 .799 r
F P
0 g
s
.56901 .85895 m .60522 .88037 L .60585 .88264 L p .554 0 0 r
F P
0 g
s
.60585 .88264 m .56951 .86154 L .56901 .85895 L p .554 0 0 r
F P
0 g
s
.76674 .69833 m .77835 .74097 L .77635 .73924 L p 0 0 .343 r
F P
0 g
s
.7768 .78131 m .77635 .73924 L .77835 .74097 L p 0 0 .217 r
F P
0 g
s
.77635 .26076 m .7768 .21869 L .77845 .21701 L p 0 0 .208 r
F P
0 g
s
.77845 .21701 m .77835 .25903 L .77635 .26076 L p 0 0 .208 r
F P
0 g
s
.19487 .63184 m .15214 .62058 L .15464 .61971 L p .335 0 0 r
F P
0 g
s
.11798 .59906 m .15464 .61971 L .15214 .62058 L p .546 0 0 r
F P
0 g
s
.53839 .16983 m .56951 .13846 L .56901 .14105 L p .65 .926 .645 r
F P
0 g
s
.60522 .11963 m .56901 .14105 L .56951 .13846 L p .554 .927 .794 r
F P
0 g
s
.56596 .48894 m .56759 .4832 L .5697 .48356 L p .031 0 .366 r
F P
0 g
s
.5721 .47783 m .5697 .48356 L .56759 .4832 L p .041 0 .305 r
F P
0 g
s
.47534 .43564 m .47939 .43142 L .48076 .43307 L p .863 .983 .847 r
F P
0 g
s
.48076 .43307 m .4766 .43734 L .47534 .43564 L p .863 .983 .847 r
F P
0 g
s
.56807 .51082 m .5697 .51644 L .56759 .5168 L p .031 .139 .645 r
F P
0 g
s
.56759 .5168 m .56596 .51106 L .56807 .51082 L p .031 .139 .645 r
F P
0 g
s
.4766 .56266 m .48076 .56693 L .47939 .56858 L p .863 .427 .164 r
F P
0 g
s
.48315 .57353 m .47939 .56858 L .48076 .56693 L p .9 .489 .2 r
F P
0 g
s
.45659 .55353 m .45091 .55214 L .45166 .55013 L p .622 .116 .025 r
F P
0 g
s
.45166 .55013 m .45744 .55159 L .45659 .55353 L p .622 .116 .025 r
F P
0 g
s
.45744 .44841 m .45166 .44987 L .45091 .44786 L p .622 .9 .986 r
F P
0 g
s
.44475 .44865 m .45091 .44786 L .45166 .44987 L p .561 .863 .996 r
F P
0 g
s
.56503 .49455 m .56596 .48894 L .56807 .48918 L p .025 0 .426 r
F P
0 g
s
.5697 .48356 m .56807 .48918 L .56596 .48894 L p .031 0 .366 r
F P
0 g
s
.56713 .50533 m .56807 .51082 L .56596 .51106 L p .025 .088 .592 r
F P
0 g
s
.56596 .51106 m .56503 .50545 L .56713 .50533 L p .025 .088 .592 r
F P
0 g
s
.47105 .43919 m .47534 .43564 L .4766 .43734 L p .823 .98 .886 r
F P
0 g
s
.4766 .43734 m .47221 .44095 L .47105 .43919 L p .823 .98 .886 r
F P
0 g
s
.47221 .55905 m .4766 .56266 L .47534 .56436 L p .823 .364 .131 r
F P
0 g
s
.47939 .56858 m .47534 .56436 L .4766 .56266 L p .863 .427 .164 r
F P
0 g
s
.46181 .55547 m .45659 .55353 L .45744 .55159 L p .679 .178 .048 r
F P
0 g
s
.45744 .55159 m .46276 .55359 L .46181 .55547 L p .679 .178 .048 r
F P
0 g
s
.46276 .44641 m .45744 .44841 L .45659 .44647 L p .679 .93 .969 r
F P
0 g
s
.45091 .44786 m .45659 .44647 L .45744 .44841 L p .622 .9 .986 r
F P
0 g
s
.56684 .5 m .56713 .50533 L .56503 .50545 L p .022 .04 .538 r
F P
0 g
s
.56503 .50545 m .56474 .5 L .56684 .5 L p .022 .04 .538 r
F P
0 g
s
.46763 .44394 m .46276 .44641 L .46181 .44453 L p .731 .953 .947 r
F P
0 g
s
.45659 .44647 m .46181 .44453 L .46276 .44641 L p .679 .93 .969 r
F P
0 g
s
.56474 .5 m .56503 .49455 L .56713 .49467 L p .022 0 .483 r
F P
0 g
s
.56807 .48918 m .56713 .49467 L .56503 .49455 L p .025 0 .426 r
F P
0 g
s
.46763 .55606 m .47221 .55905 L .47105 .56081 L p .779 .301 .101 r
F P
0 g
s
.47534 .56436 m .47105 .56081 L .47221 .55905 L p .823 .364 .131 r
F P
0 g
s
.46658 .44212 m .47105 .43919 L .47221 .44095 L p .779 .97 .92 r
F P
0 g
s
.47221 .44095 m .46763 .44394 L .46658 .44212 L p .779 .97 .92 r
F P
0 g
s
.46658 .55788 m .46181 .55547 L .46276 .55359 L p .731 .24 .074 r
F P
0 g
s
.46276 .55359 m .46763 .55606 L .46658 .55788 L p .731 .24 .074 r
F P
0 g
s
.46181 .44453 m .46658 .44212 L .46763 .44394 L p .731 .953 .947 r
F P
0 g
s
.56713 .49467 m .56684 .5 L .56474 .5 L p .022 0 .483 r
F P
0 g
s
.47105 .56081 m .46658 .55788 L .46763 .55606 L p .779 .301 .101 r
F P
0 g
s
.49591 .30329 m .4979 .27544 L .49792 .27696 L p .72 .629 .065 r
F P
0 g
s
.49792 .27696 m .49593 .30447 L .49591 .30329 L p .72 .629 .065 r
F P
0 g
s
.67136 .40576 m .6942 .39029 L .69552 .38954 L p 0 0 0 r
F P
0 g
s
.72084 .36807 m .69552 .38954 L .6942 .39029 L p 0 0 0 r
F P
0 g
s
.6724 .59481 m .69552 .61046 L .6942 .60971 L p 0 .166 .6 r
F P
0 g
s
.6942 .60971 m .67136 .59424 L .6724 .59481 L p 0 .166 .6 r
F P
0 g
s
.49593 .69553 m .49792 .72304 L .4979 .72456 L p .72 .546 0 r
F P
0 g
s
.50383 .75722 m .4979 .72456 L .49792 .72304 L p .729 .492 0 r
F P
0 g
s
.33169 .6019 m .30658 .6141 L .30789 .61332 L p 0 0 0 r
F P
0 g
s
.30789 .61332 m .3327 .60129 L .33169 .6019 L p 0 0 0 r
F P
0 g
s
.3327 .39871 m .30789 .38668 L .30658 .3859 L p 0 .279 .651 r
F P
0 g
s
.27532 .37471 m .30658 .3859 L .30789 .38668 L p 0 .377 .699 r
F P
0 g
s
.7234 .87493 m .72795 .87012 L .7299 .86939 L p .125 0 .01 r
F P
0 g
s
.72795 .87012 m .7234 .87493 L .72224 .87544 L p .174 0 .049 r
F P
0 g
s
.72795 .12988 m .7234 .12507 L .72435 .12542 L p .125 .461 .889 r
F P
0 g
s
.72435 .12542 m .7299 .13061 L .72795 .12988 L p .125 .461 .889 r
F P
0 g
s
.713 .11906 m .70656 .11753 L .70495 .11621 L p .231 .597 .95 r
F P
0 g
s
.70656 .11753 m .713 .11906 L .71402 .11981 L p .258 .598 .951 r
F P
0 g
s
.0655 .48765 m .0636 .49399 L .06343 .493 L p .992 .86 .51 r
F P
0 g
s
.06343 .493 m .06515 .4856 L .0655 .48765 L p .992 .86 .51 r
F P
0 g
s
.70656 .88247 m .713 .88094 L .71222 .88158 L p .231 0 0 r
F P
0 g
s
.71222 .88158 m .70495 .88379 L .70656 .88247 L p .231 0 0 r
F P
0 g
s
.0636 .50601 m .0655 .51235 L .06515 .5144 L p .992 .76 .388 r
F P
0 g
s
.0655 .51235 m .0636 .50601 L .06374 .50475 L p .997 .774 .428 r
F P
0 g
s
.65154 .41738 m .67136 .40576 L .6724 .40519 L p 0 0 0 r
F P
0 g
s
.69552 .38954 m .6724 .40519 L .67136 .40576 L p 0 0 0 r
F P
0 g
s
.35268 .41007 m .3327 .39871 L .33169 .3981 L p 0 .22 .619 r
F P
0 g
s
.30658 .3859 m .33169 .3981 L .3327 .39871 L p 0 .279 .651 r
F P
0 g
s
.49578 .67255 m .49593 .69553 L .49591 .69671 L p .711 .577 0 r
F P
0 g
s
.4979 .72456 m .49591 .69671 L .49593 .69553 L p .72 .546 0 r
F P
0 g
s
.65236 .58306 m .6724 .59481 L .67136 .59424 L p 0 .21 .614 r
F P
0 g
s
.67136 .59424 m .65154 .58262 L .65236 .58306 L p 0 .21 .614 r
F P
0 g
s
.49575 .32652 m .49591 .30329 L .49593 .30447 L p .711 .585 .009 r
F P
0 g
s
.49593 .30447 m .49578 .32745 L .49575 .32652 L p .711 .585 .009 r
F P
0 g
s
.35189 .59042 m .33169 .6019 L .3327 .60129 L p 0 0 0 r
F P
0 g
s
.3327 .60129 m .35268 .58993 L .35189 .59042 L p 0 0 0 r
F P
0 g
s
.11798 .40094 m .09165 .42627 L .08984 .42594 L p .716 .97 .727 r
F P
0 g
s
.08984 .42594 m .11569 .40035 L .11798 .40094 L p .716 .97 .727 r
F P
0 g
s
.7768 .21869 m .76803 .18322 L .76922 .18182 L p 0 0 .418 r
F P
0 g
s
.76922 .18182 m .77845 .21701 L .7768 .21869 L p 0 0 .418 r
F P
0 g
s
.60522 .88037 m .64032 .8905 L .64095 .89224 L p .434 0 0 r
F P
0 g
s
.64095 .89224 m .60585 .88264 L .60522 .88037 L p .434 0 0 r
F P
0 g
s
.77835 .74097 m .77845 .78299 L .7768 .78131 L p 0 0 .217 r
F P
0 g
s
.76803 .81678 m .7768 .78131 L .77845 .78299 L p 0 0 .092 r
F P
0 g
s
.56951 .13846 m .60585 .11736 L .60522 .11963 L p .554 .927 .794 r
F P
0 g
s
.64032 .1095 m .60522 .11963 L .60585 .11736 L p .434 .872 .89 r
F P
0 g
s
.15214 .62058 m .11569 .59965 L .11798 .59906 L p .546 0 0 r
F P
0 g
s
.09165 .57373 m .11798 .59906 L .11569 .59965 L p .716 .199 0 r
F P
0 g
s
.66917 .10791 m .68997 .11064 L .69077 .11199 L p .353 .738 .986 r
F P
0 g
s
.70391 .11515 m .69077 .11199 L .68997 .11064 L p .234 .647 .959 r
F P
0 g
s
.69077 .11199 m .70391 .11515 L .70495 .11621 L p .307 .665 .973 r
F P
0 g
s
.69077 .88801 m .70391 .88485 L .70349 .88559 L p .234 0 0 r
F P
0 g
s
.70349 .88559 m .68997 .88936 L .69077 .88801 L p .234 0 0 r
F P
0 g
s
.75497 .84256 m .74221 .8592 L .74064 .85922 L p .001 0 .089 r
F P
0 g
s
.73133 .86902 m .74064 .85922 L .74221 .8592 L p 0 0 0 r
F P
0 g
s
.74064 .85922 m .73133 .86902 L .7299 .86939 L p .107 0 .075 r
F P
0 g
s
.74064 .14078 m .73133 .13098 L .73219 .13098 L p 0 .345 .824 r
F P
0 g
s
.73219 .13098 m .74221 .1408 L .74064 .14078 L p 0 .345 .824 r
F P
0 g
s
.07585 .54954 m .06782 .53016 L .06859 .52879 L p .954 .613 .233 r
F P
0 g
s
.06475 .51583 m .06859 .52879 L .06782 .53016 L p .967 .679 .265 r
F P
0 g
s
.06859 .52879 m .06475 .51583 L .06515 .5144 L p .985 .71 .351 r
F P
0 g
s
.06859 .47121 m .06475 .48417 L .06433 .48343 L p .967 .9 .535 r
F P
0 g
s
.06433 .48343 m .06782 .46984 L .06859 .47121 L p .967 .9 .535 r
F P
0 g
s
.49616 .34586 m .49575 .32652 L .49578 .32745 L p .707 .566 0 r
F P
0 g
s
.49578 .32745 m .49617 .34658 L .49616 .34586 L p .707 .566 0 r
F P
0 g
s
.63478 .42661 m .65154 .41738 L .65234 .41695 L p 0 0 0 r
F P
0 g
s
.65189 .41719 m .63478 .42661 L .65234 .41695 L 0 0 0 r
F
.65236 .41694 m .63541 .42626 L .63478 .42661 L p F P
0 g
s
.63541 .42626 m .63297 .42423 L p .62153 .43389 L .687 .973 .918 r
F P
0 g
s
.62075 .4344 m .63478 .42661 L .63531 .42631 L p 0 0 0 r
F P
0 g
s
.63531 .42631 m .63541 .42626 L p .63311 .42754 L 0 0 0 r
F P
0 g
s
.63311 .42754 m .62075 .4344 L .63531 .42631 L 0 0 0 r
F
.63541 .42626 m .62126 .43412 L .62075 .4344 L p F P
0 g
s
.62126 .43412 m .619 .43237 L p .61082 .43992 L .704 .978 .91 r
F P
0 g
s
.60909 .44136 m .62075 .4344 L .62113 .43419 L p 0 0 0 r
F P
0 g
s
.62113 .43419 m .62126 .43412 L p .61851 .43576 L 0 0 0 r
F P
0 g
s
.61851 .43576 m .60909 .44136 L .62113 .43419 L 0 0 0 r
F
.59942 .44784 m .60909 .44136 L .60937 .44121 L p F P
0 g
s
.60937 .44121 m .6095 .44113 L p .60685 .4429 L 0 0 0 r
F P
0 g
s
.60685 .4429 m .59942 .44784 L .60937 .44121 L 0 0 0 r
F
.59144 .45407 m .59942 .44784 L .59964 .44773 L p F P
0 g
s
.59964 .44773 m .59976 .44767 L p .59742 .44947 L 0 0 0 r
F P
0 g
s
.59742 .44947 m .59144 .45407 L .59964 .44773 L 0 0 0 r
F
.5849 .46014 m .59144 .45407 L .59162 .45398 L p F P
0 g
s
.59162 .45398 m .59173 .45392 L p .58976 .45571 L 0 0 0 r
F P
0 g
s
.58976 .45571 m .5849 .46014 L .59162 .45398 L 0 0 0 r
F
.57959 .46611 m .5849 .46014 L .58505 .46006 L p F P
0 g
s
.58505 .46006 m .58514 .46002 L p .58355 .46177 L 0 0 0 r
F P
0 g
s
.58355 .46177 m .57959 .46611 L .58505 .46006 L 0 0 0 r
F
.57536 .472 m .57959 .46611 L .57972 .46605 L p F P
0 g
s
.57972 .46605 m .57981 .46602 L p .57855 .46771 L 0 0 0 r
F P
0 g
s
.57855 .46771 m .57536 .472 L .57972 .46605 L 0 0 0 r
F
.5721 .47783 m .57536 .472 L .57549 .47196 L p F P
0 g
s
.57549 .47196 m .57556 .47193 L p .57461 .47355 L 0 0 0 r
F P
0 g
s
.57461 .47355 m .5721 .47783 L .57549 .47196 L 0 0 0 r
F
.5697 .48356 m .5721 .47783 L .57222 .47779 L p F P
0 g
s
.57222 .47779 m .57228 .47777 L p .5716 .4793 L 0 0 0 r
F P
0 g
s
.5716 .4793 m .5697 .48356 L .57222 .47779 L 0 0 0 r
F
.56807 .48918 m .5697 .48356 L .56987 .48352 L p F P
0 g
s
.57228 .47777 m .56987 .48352 L .5697 .48356 L p 0 0 0 r
F P
0 g
s
.56987 .48352 m .56808 .48308 L p .56819 .4876 L .976 .92 .616 r
F P
0 g
s
.56987 .48352 m .56823 .48915 L .56807 .48918 L p 0 0 0 r
F P
0 g
s
.56823 .48915 m .56987 .48352 L p .56819 .4876 L .976 .92 .616 r
F P
0 g
s
.57556 .47193 m .57228 .47777 L .5721 .47783 L p 0 0 0 r
F P
0 g
s
.57228 .47777 m .5705 .47719 L p .57003 .48184 L .955 .95 .672 r
F P
0 g
s
.56987 .48352 m .57228 .47777 L p .57003 .48184 L .955 .95 .672 r
F P
0 g
s
.57981 .46602 m .57556 .47193 L .57536 .472 L p 0 0 0 r
F P
0 g
s
.57556 .47193 m .57377 .47121 L p .57269 .47599 L .926 .974 .725 r
F P
0 g
s
.57228 .47777 m .57556 .47193 L p .57269 .47599 L .926 .974 .725 r
F P
0 g
s
.58514 .46002 m .57981 .46602 L .57959 .46611 L p 0 0 0 r
F P
0 g
s
.57981 .46602 m .578 .46516 L p .57623 .47007 L .892 .989 .772 r
F P
0 g
s
.57556 .47193 m .57981 .46602 L p .57623 .47007 L .892 .989 .772 r
F P
0 g
s
.59173 .45392 m .58514 .46002 L .5849 .46014 L p 0 0 0 r
F P
0 g
s
.58514 .46002 m .58331 .45902 L p .58076 .46411 L .853 .997 .814 r
F P
0 g
s
.57981 .46602 m .58514 .46002 L p .58076 .46411 L .853 .997 .814 r
F P
0 g
s
.59976 .44767 m .59173 .45392 L .59144 .45407 L p 0 0 0 r
F P
0 g
s
.59173 .45392 m .58983 .45277 L p .58638 .45811 L .812 .998 .849 r
F P
0 g
s
.58514 .46002 m .59173 .45392 L p .58638 .45811 L .812 .998 .849 r
F P
0 g
s
.6095 .44113 m .59976 .44767 L .59942 .44784 L p 0 0 0 r
F P
0 g
s
.59976 .44767 m .59778 .44634 L p .5932 .45208 L .771 .994 .876 r
F P
0 g
s
.59173 .45392 m .59976 .44767 L p .5932 .45208 L .771 .994 .876 r
F P
0 g
s
.62126 .43412 m .6095 .44113 L .60909 .44136 L p 0 0 0 r
F P
0 g
s
.6095 .44113 m .6074 .43962 L p .60133 .44602 L .734 .986 .897 r
F P
0 g
s
.59976 .44767 m .6095 .44113 L p .60133 .44602 L .734 .986 .897 r
F P
0 g
s
.6095 .44113 m .62126 .43412 L p .61082 .43992 L .704 .978 .91 r
F P
0 g
s
.62126 .43412 m .63541 .42626 L p .62153 .43389 L .687 .973 .918 r
F P
0 g
s
.65234 .41695 m .65236 .41694 L p .65189 .41719 L 0 0 0 r
F P
0 g
s
.6724 .40519 m .65236 .41694 L .65154 .41738 L p 0 0 0 r
F P
0 g
s
.49617 .65342 m .49578 .67255 L .49575 .67345 L p .707 .59 .015 r
F P
0 g
s
.49576 .67295 m .49617 .65342 L .49575 .67345 L .707 .59 .015 r
F
.49575 .67348 m .49616 .65414 L .49617 .65342 L p F P
0 g
s
.49616 .65414 m .49913 .65304 L p .49649 .6383 L 0 0 .398 r
F P
0 g
s
.49644 .63738 m .49617 .65342 L .49616 .65402 L p .708 .588 .013 r
F P
0 g
s
.49616 .65402 m .49616 .65414 L p .4962 .65151 L .708 .588 .013 r
F P
0 g
s
.4962 .65151 m .49644 .63738 L .49616 .65402 L .708 .588 .013 r
F
.49616 .65414 m .49642 .63796 L .49644 .63738 L p F P
0 g
s
.49642 .63796 m .49907 .63687 L p .49662 .62601 L 0 0 .419 r
F P
0 g
s
.49624 .6238 m .49644 .63738 L .49643 .6378 L p .712 .573 0 r
F P
0 g
s
.49643 .6378 m .49642 .63796 L p .49638 .63475 L .712 .573 0 r
F P
0 g
s
.49638 .63475 m .49624 .6238 L .49643 .6378 L .712 .573 0 r
F
.49546 .61218 m .49624 .6238 L .49623 .62411 L p .715 .545 0 r
F P
0 g
s
.49623 .62411 m .49623 .62427 L p .49603 .62109 L .715 .545 0 r
F P
0 g
s
.49603 .62109 m .49546 .61218 L .49623 .62411 L .715 .545 0 r
F
.49406 .60216 m .49546 .61218 L .49545 .61243 L p .716 .505 0 r
F P
0 g
s
.49545 .61243 m .49544 .61257 L p .49505 .60964 L .716 .505 0 r
F P
0 g
s
.49505 .60964 m .49406 .60216 L .49545 .61243 L .716 .505 0 r
F
.49208 .59345 m .49406 .60216 L .49405 .60236 L p .712 .453 0 r
F P
0 g
s
.49405 .60236 m .49404 .60248 L p .49348 .59988 L .712 .453 0 r
F P
0 g
s
.49348 .59988 m .49208 .59345 L .49405 .60236 L .712 .453 0 r
F
.48956 .58587 m .49208 .59345 L .49206 .59362 L p .7 .39 0 r
F P
0 g
s
.49206 .59362 m .49205 .59373 L p .49134 .59147 L .7 .39 0 r
F P
0 g
s
.49134 .59147 m .48956 .58587 L .49206 .59362 L .7 .39 0 r
F
.48656 .57927 m .48956 .58587 L .48954 .58602 L p .68 .317 0 r
F P
0 g
s
.48954 .58602 m .48953 .58611 L p .48869 .58418 L .68 .317 0 r
F P
0 g
s
.48869 .58418 m .48656 .57927 L .48954 .58602 L .68 .317 0 r
F
.48315 .57353 m .48656 .57927 L .48654 .5794 L p .649 .236 0 r
F P
0 g
s
.48654 .5794 m .48653 .57947 L p .4856 .57784 L .649 .236 0 r
F P
0 g
s
.4856 .57784 m .48315 .57353 L .48654 .5794 L .649 .236 0 r
F
.47939 .56858 m .48315 .57353 L .48313 .57365 L p .609 .148 0 r
F P
0 g
s
.48313 .57365 m .48311 .57371 L p .48213 .57236 L .609 .148 0 r
F P
0 g
s
.48213 .57236 m .47939 .56858 L .48313 .57365 L .609 .148 0 r
F
.47534 .56436 m .47939 .56858 L .47934 .56875 L p .559 .058 0 r
F P
0 g
s
.48311 .57371 m .47934 .56875 L .47939 .56858 L p .609 .148 0 r
F P
0 g
s
.47934 .56875 m .48062 .56742 L p .47665 .56525 L .082 .366 .833 r
F P
0 g
s
.47934 .56875 m .47528 .56451 L .47534 .56436 L p .559 .058 0 r
F P
0 g
s
.47528 .56451 m .47934 .56875 L p .47665 .56525 L .082 .366 .833 r
F P
0 g
s
.48653 .57947 m .48311 .57371 L .48315 .57353 L p .649 .236 0 r
F P
0 g
s
.48311 .57371 m .48451 .57246 L p .48071 .56973 L .036 .292 .784 r
F P
0 g
s
.47934 .56875 m .48311 .57371 L p .48071 .56973 L .036 .292 .784 r
F P
0 g
s
.48953 .58611 m .48653 .57947 L .48656 .57927 L p .68 .317 0 r
F P
0 g
s
.48653 .57947 m .48805 .57828 L p .48445 .57495 L 0 .218 .731 r
F P
0 g
s
.48311 .57371 m .48653 .57947 L p .48445 .57495 L 0 .218 .731 r
F P
0 g
s
.49205 .59373 m .48953 .58611 L .48956 .58587 L p .7 .39 0 r
F P
0 g
s
.48953 .58611 m .49117 .58498 L p .4878 .58098 L 0 .145 .673 r
F P
0 g
s
.48653 .57947 m .48953 .58611 L p .4878 .58098 L 0 .145 .673 r
F P
0 g
s
.49404 .60248 m .49205 .59373 L .49208 .59345 L p .712 .453 0 r
F P
0 g
s
.49205 .59373 m .49384 .59264 L p .4907 .58789 L 0 .075 .615 r
F P
0 g
s
.48953 .58611 m .49205 .59373 L p .4907 .58789 L 0 .075 .615 r
F P
0 g
s
.49544 .61257 m .49404 .60248 L .49406 .60216 L p .716 .505 0 r
F P
0 g
s
.49404 .60248 m .49599 .60141 L p .49309 .59575 L 0 .012 .557 r
F P
0 g
s
.49205 .59373 m .49404 .60248 L p .49309 .59575 L 0 .012 .557 r
F P
0 g
s
.49623 .62427 m .49544 .61257 L .49546 .61218 L p .715 .545 0 r
F P
0 g
s
.49544 .61257 m .49758 .61151 L p .4949 .60467 L 0 0 .502 r
F P
0 g
s
.49404 .60248 m .49544 .61257 L p .4949 .60467 L 0 0 .502 r
F P
0 g
s
.49642 .63796 m .49623 .62427 L .49624 .6238 L p .712 .573 0 r
F P
0 g
s
.49623 .62427 m .49859 .6232 L p .49609 .61474 L 0 0 .455 r
F P
0 g
s
.49544 .61257 m .49623 .62427 L p .49609 .61474 L 0 0 .455 r
F P
0 g
s
.49623 .62427 m .49642 .63796 L p .49662 .62601 L 0 0 .419 r
F P
0 g
s
.49642 .63796 m .49616 .65414 L p .49649 .6383 L 0 0 .398 r
F P
0 g
s
.49575 .67345 m .49575 .67348 L p .49576 .67295 L .707 .59 .015 r
F P
0 g
s
.49591 .69671 m .49575 .67348 L .49578 .67255 L p .711 .577 0 r
F P
0 g
s
.36843 .5804 m .35189 .59042 L .35268 .58993 L p 0 0 0 r
F P
0 g
s
.35268 .58993 m .36905 .58002 L .36843 .5804 L p 0 0 0 r
F P
0 g
s
.63541 .57374 m .65236 .58306 L .65154 .58262 L p 0 .228 .62 r
F P
0 g
s
.65154 .58262 m .63478 .57339 L .63541 .57374 L p 0 .228 .62 r
F P
0 g
s
.36905 .41998 m .35268 .41007 L .35191 .4096 L p 0 .195 .605 r
F P
0 g
s
.35234 .40986 m .36905 .41998 L .35191 .4096 L 0 .195 .605 r
F
.35189 .40958 m .36843 .4196 L .36905 .41998 L p F P
0 g
s
.36843 .4196 m .3679 .42273 L p .38198 .42781 L .713 .183 0 r
F P
0 g
s
.38281 .42823 m .36905 .41998 L .36853 .41966 L p 0 .199 .608 r
F P
0 g
s
.36853 .41966 m .36843 .4196 L p .37069 .42095 L 0 .199 .608 r
F P
0 g
s
.37069 .42095 m .38281 .42823 L .36853 .41966 L 0 .199 .608 r
F
.36843 .4196 m .38231 .42792 L .38281 .42823 L p F P
0 g
s
.38231 .42792 m .38193 .43075 L p .39256 .43407 L .7 .167 0 r
F P
0 g
s
.39467 .43485 m .38281 .42823 L .38244 .428 L p 0 .226 .622 r
F P
0 g
s
.38244 .428 m .38231 .42792 L p .38511 .42949 L 0 .226 .622 r
F P
0 g
s
.38511 .42949 m .39467 .43485 L .38244 .428 L 0 .226 .622 r
F
.40512 .43997 m .39467 .43485 L .3944 .43468 L p 0 .272 .644 r
F P
0 g
s
.3944 .43468 m .39427 .4346 L p .39712 .43602 L 0 .272 .644 r
F P
0 g
s
.39712 .43602 m .40512 .43997 L .3944 .43468 L 0 .272 .644 r
F
.4145 .44378 m .40512 .43997 L .40491 .43984 L p 0 .331 .671 r
F P
0 g
s
.40491 .43984 m .40479 .43977 L p .40752 .4409 L 0 .331 .671 r
F P
0 g
s
.40752 .4409 m .4145 .44378 L .40491 .43984 L 0 .331 .671 r
F
.42303 .44641 m .4145 .44378 L .41433 .44367 L p 0 .4 .698 r
F P
0 g
s
.41433 .44367 m .41423 .4436 L p .41676 .44441 L 0 .4 .698 r
F P
0 g
s
.41676 .44441 m .42303 .44641 L .41433 .44367 L 0 .4 .698 r
F
.43085 .44802 m .42303 .44641 L .42289 .44631 L p 0 .473 .722 r
F P
0 g
s
.42289 .44631 m .4228 .44626 L p .42512 .44676 L 0 .473 .722 r
F P
0 g
s
.42512 .44676 m .43085 .44802 L .42289 .44631 L 0 .473 .722 r
F
.43807 .44873 m .43085 .44802 L .43074 .44793 L p 0 .547 .739 r
F P
0 g
s
.43074 .44793 m .43067 .44788 L p .43276 .44812 L 0 .547 .739 r
F P
0 g
s
.43276 .44812 m .43807 .44873 L .43074 .44793 L 0 .547 .739 r
F
.44475 .44865 m .43807 .44873 L .43797 .44865 L p .051 .618 .748 r
F P
0 g
s
.43797 .44865 m .43791 .4486 L p .43979 .44861 L .051 .618 .748 r
F P
0 g
s
.43979 .44861 m .44475 .44865 L .43797 .44865 L .051 .618 .748 r
F
.45091 .44786 m .44475 .44865 L .44466 .44856 L p .135 .682 .747 r
F P
0 g
s
.44466 .44856 m .44461 .44852 L p .44627 .44834 L .135 .682 .747 r
F P
0 g
s
.44627 .44834 m .45091 .44786 L .44466 .44856 L .135 .682 .747 r
F
.45659 .44647 m .45091 .44786 L .45079 .44774 L p .219 .738 .735 r
F P
0 g
s
.44461 .44852 m .45079 .44774 L .45091 .44786 L p .135 .682 .747 r
F P
0 g
s
.45079 .44774 m .45131 .44951 L p .45517 .44715 L .341 0 0 r
F P
0 g
s
.45079 .44774 m .45649 .44634 L .45659 .44647 L p .219 .738 .735 r
F P
0 g
s
.45649 .44634 m .45079 .44774 L p .45517 .44715 L .341 0 0 r
F P
0 g
s
.43791 .4486 m .44461 .44852 L .44475 .44865 L p .051 .618 .748 r
F P
0 g
s
.44461 .44852 m .445 .45035 L p .44926 .44843 L .399 0 0 r
F P
0 g
s
.45079 .44774 m .44461 .44852 L p .44926 .44843 L .399 0 0 r
F P
0 g
s
.43067 .44788 m .43791 .4486 L .43807 .44873 L p 0 .547 .739 r
F P
0 g
s
.43791 .4486 m .43818 .4505 L p .44287 .44906 L .455 0 0 r
F P
0 g
s
.44461 .44852 m .43791 .4486 L p .44287 .44906 L .455 0 0 r
F P
0 g
s
.4228 .44626 m .43067 .44788 L .43085 .44802 L p 0 .473 .722 r
F P
0 g
s
.43067 .44788 m .43082 .44987 L p .43597 .44895 L .51 0 0 r
F P
0 g
s
.43791 .4486 m .43067 .44788 L p .43597 .44895 L .51 0 0 r
F P
0 g
s
.41423 .4436 m .4228 .44626 L .42303 .44641 L p 0 .4 .698 r
F P
0 g
s
.4228 .44626 m .42286 .44835 L p .42854 .44801 L .561 .02 0 r
F P
0 g
s
.43067 .44788 m .4228 .44626 L p .42854 .44801 L .561 .02 0 r
F P
0 g
s
.40479 .43977 m .41423 .4436 L .4145 .44378 L p 0 .331 .671 r
F P
0 g
s
.41423 .4436 m .41418 .44582 L p .42053 .44614 L .607 .064 0 r
F P
0 g
s
.4228 .44626 m .41423 .4436 L p .42053 .44614 L .607 .064 0 r
F P
0 g
s
.39427 .4346 m .40479 .43977 L .40512 .43997 L p 0 .272 .644 r
F P
0 g
s
.40479 .43977 m .40464 .44215 L p .4119 .44325 L .646 .105 0 r
F P
0 g
s
.41423 .4436 m .40479 .43977 L p .4119 .44325 L .646 .105 0 r
F P
0 g
s
.38231 .42792 m .39427 .4346 L .39467 .43485 L p 0 .226 .622 r
F P
0 g
s
.39427 .4346 m .39401 .43718 L p .40258 .43924 L .678 .14 0 r
F P
0 g
s
.40479 .43977 m .39427 .4346 L p .40258 .43924 L .678 .14 0 r
F P
0 g
s
.39427 .4346 m .38231 .42792 L p .39256 .43407 L .7 .167 0 r
F P
0 g
s
.38231 .42792 m .36843 .4196 L p .38198 .42781 L .713 .183 0 r
F P
0 g
s
.35191 .4096 m .35189 .40958 L p .35234 .40986 L 0 .195 .605 r
F P
0 g
s
.33169 .3981 m .35189 .40958 L .35268 .41007 L p 0 .22 .619 r
F P
0 g
s
.71222 .11842 m .70495 .11621 L .70391 .11515 L p .192 .588 .943 r
F P
0 g
s
.70495 .11621 m .71222 .11842 L .713 .11906 L p .231 .597 .95 r
F P
0 g
s
.06343 .507 m .06515 .5144 L .06475 .51583 L p .983 .743 .341 r
F P
0 g
s
.06515 .5144 m .06343 .507 L .0636 .50601 L p .992 .76 .388 r
F P
0 g
s
.06515 .4856 m .06343 .493 L .06324 .49231 L p .983 .861 .486 r
F P
0 g
s
.06324 .49231 m .06475 .48417 L .06515 .4856 L p .983 .861 .486 r
F P
0 g
s
.72435 .87458 m .7299 .86939 L .73133 .86902 L p .067 0 0 r
F P
0 g
s
.7299 .86939 m .72435 .87458 L .7234 .87493 L p .125 0 .01 r
F P
0 g
s
.7299 .13061 m .72435 .12542 L .72504 .1256 L p .067 .427 .87 r
F P
0 g
s
.72504 .1256 m .73133 .13098 L .7299 .13061 L p .067 .427 .87 r
F P
0 g
s
.70495 .88379 m .71222 .88158 L .71172 .88209 L p .192 0 0 r
F P
0 g
s
.71172 .88209 m .70391 .88485 L .70495 .88379 L p .192 0 0 r
F P
0 g
s
.62126 .56588 m .63541 .57374 L .63478 .57339 L p 0 .225 .619 r
F P
0 g
s
.63478 .57339 m .62075 .5656 L .62126 .56588 L p 0 .225 .619 r
F P
0 g
s
.49642 .36204 m .49616 .34586 L .49617 .34658 L p .708 .569 0 r
F P
0 g
s
.49617 .34658 m .49644 .36262 L .49642 .36204 L p .708 .569 0 r
F P
0 g
s
.38231 .57208 m .36843 .5804 L .36905 .58002 L p 0 0 0 r
F P
0 g
s
.36905 .58002 m .38281 .57177 L .38231 .57208 L p 0 0 0 r
F P
0 g
s
.71803 .87764 m .7185 .87845 L .71791 .87881 L p .163 0 0 r
F P
0 g
s
.71791 .87881 m .71659 .8785 L .71803 .87764 L p .163 0 0 r
F P
0 g
s
.7185 .87845 m .71803 .87764 L .7195 .87682 L p .156 0 0 r
F P
0 g
s
.71803 .12236 m .7185 .12155 L .7191 .12188 L p .156 .518 .916 r
F P
0 g
s
.7191 .12188 m .7195 .12318 L .71803 .12236 L p .156 .518 .916 r
F P
0 g
s
.7185 .12155 m .71803 .12236 L .71659 .1215 L p .163 .528 .921 r
F P
0 g
s
.06393 .5 m .063 .5 L .06299 .49931 L p .993 .814 .441 r
F P
0 g
s
.06299 .49931 m .06391 .49832 L .06393 .5 L p .993 .814 .441 r
F P
0 g
s
.063 .5 m .06393 .5 L .06391 .50168 L p .993 .807 .433 r
F P
0 g
s
.7191 .87812 m .7195 .87682 L .72092 .87608 L p .143 0 0 r
F P
0 g
s
.7195 .87682 m .7191 .87812 L .7185 .87845 L p .156 0 0 r
F P
0 g
s
.71791 .12119 m .71659 .1215 L .71523 .12064 L p .164 .534 .923 r
F P
0 g
s
.71659 .1215 m .71791 .12119 L .7185 .12155 L p .163 .528 .921 r
F P
0 g
s
.06299 .50069 m .06391 .50168 L .06385 .50329 L p .992 .8 .42 r
F P
0 g
s
.06391 .50168 m .06299 .50069 L .063 .5 L p .993 .807 .433 r
F P
0 g
s
.7195 .12318 m .7191 .12188 L .71969 .12219 L p .143 .507 .911 r
F P
0 g
s
.71969 .12219 m .72092 .12392 L .7195 .12318 L p .143 .507 .911 r
F P
0 g
s
.71659 .8785 m .71791 .87881 L .71735 .87916 L p .164 0 0 r
F P
0 g
s
.71735 .87916 m .71523 .87936 L .71659 .8785 L p .164 0 0 r
F P
0 g
s
.06391 .49832 m .06299 .49931 L .06296 .49865 L p .992 .82 .445 r
F P
0 g
s
.06296 .49865 m .06385 .49671 L .06391 .49832 L p .992 .82 .445 r
F P
0 g
s
.09165 .42627 m .07585 .45046 L .07458 .45032 L p .83 .962 .633 r
F P
0 g
s
.07458 .45032 m .08984 .42594 L .09165 .42627 L p .83 .962 .633 r
F P
0 g
s
.76803 .18322 m .75497 .15744 L .75574 .15642 L p 0 .006 .582 r
F P
0 g
s
.75574 .15642 m .76922 .18182 L .76803 .18322 L p 0 .006 .582 r
F P
0 g
s
.64032 .8905 m .66917 .89209 L .66968 .89326 L p .314 0 0 r
F P
0 g
s
.66968 .89326 m .64095 .89224 L .64032 .8905 L p .314 0 0 r
F P
0 g
s
.77845 .78299 m .76922 .81818 L .76803 .81678 L p 0 0 .092 r
F P
0 g
s
.75497 .84256 m .76803 .81678 L .76922 .81818 L p 0 0 0 r
F P
0 g
s
.11569 .59965 m .08984 .57406 L .09165 .57373 L p .716 .199 0 r
F P
0 g
s
.07585 .54954 m .09165 .57373 L .08984 .57406 L p .83 .393 0 r
F P
0 g
s
.60585 .11736 m .64095 .10776 L .64032 .1095 L p .434 .872 .89 r
F P
0 g
s
.66917 .10791 m .64032 .1095 L .64095 .10776 L p .314 .784 .931 r
F P
0 g
s
.06296 .50135 m .06385 .50329 L .06374 .50475 L p .99 .791 .404 r
F P
0 g
s
.06385 .50329 m .06296 .50135 L .06299 .50069 L p .992 .8 .42 r
F P
0 g
s
.71735 .12084 m .71523 .12064 L .71402 .11981 L p .159 .538 .924 r
F P
0 g
s
.71523 .12064 m .71735 .12084 L .71791 .12119 L p .164 .534 .923 r
F P
0 g
s
.72092 .12392 m .71969 .12219 L .72023 .12245 L p .124 .492 .904 r
F P
0 g
s
.72023 .12245 m .72224 .12456 L .72092 .12392 L p .124 .492 .904 r
F P
0 g
s
.71523 .87936 m .71735 .87916 L .71685 .8795 L p .159 0 0 r
F P
0 g
s
.71685 .8795 m .71402 .88019 L .71523 .87936 L p .159 0 0 r
F P
0 g
s
.06385 .49671 m .06296 .49865 L .06292 .49805 L p .99 .825 .444 r
F P
0 g
s
.06292 .49805 m .06374 .49525 L .06385 .49671 L p .99 .825 .444 r
F P
0 g
s
.71969 .87781 m .72092 .87608 L .72224 .87544 L p .124 0 0 r
F P
0 g
s
.72092 .87608 m .71969 .87781 L .7191 .87812 L p .143 0 0 r
F P
0 g
s
.49623 .37573 m .49642 .36204 L .49644 .36262 L p .712 .589 .015 r
F P
0 g
s
.49644 .36262 m .49624 .3762 L .49623 .37573 L p .712 .589 .015 r
F P
0 g
s
.6095 .55887 m .62126 .56588 L .62075 .5656 L p 0 .204 .612 r
F P
0 g
s
.62075 .5656 m .60909 .55864 L .6095 .55887 L p 0 .204 .612 r
F P
0 g
s
.39427 .5654 m .38231 .57208 L .38281 .57177 L p 0 0 0 r
F P
0 g
s
.38281 .57177 m .39467 .56515 L .39427 .5654 L p 0 0 0 r
F P
0 g
s
.49544 .38743 m .49623 .37573 L .49624 .3762 L p .715 .623 .057 r
F P
0 g
s
.49624 .3762 m .49546 .38782 L .49544 .38743 L p .715 .623 .057 r
F P
0 g
s
.59976 .55233 m .6095 .55887 L .60909 .55864 L p 0 .166 .597 r
F P
0 g
s
.60909 .55864 m .59942 .55216 L .59976 .55233 L p 0 .166 .597 r
F P
0 g
s
.40479 .56023 m .39427 .5654 L .39467 .56515 L p 0 0 0 r
F P
0 g
s
.39467 .56515 m .40512 .56003 L .40479 .56023 L p 0 0 0 r
F P
0 g
s
.06292 .50195 m .06374 .50475 L .0636 .50601 L p .986 .782 .383 r
F P
0 g
s
.06374 .50475 m .06292 .50195 L .06296 .50135 L p .99 .791 .404 r
F P
0 g
s
.72023 .87755 m .72224 .87544 L .7234 .87493 L p .099 0 0 r
F P
0 g
s
.72224 .87544 m .72023 .87755 L .71969 .87781 L p .124 0 0 r
F P
0 g
s
.06374 .49525 m .06292 .49805 L .06286 .49753 L p .986 .827 .438 r
F P
0 g
s
.06286 .49753 m .0636 .49399 L .06374 .49525 L p .986 .827 .438 r
F P
0 g
s
.71685 .1205 m .71402 .11981 L .713 .11906 L p .147 .538 .922 r
F P
0 g
s
.71402 .11981 m .71685 .1205 L .71735 .12084 L p .159 .538 .924 r
F P
0 g
s
.71402 .88019 m .71685 .8795 L .71643 .87981 L p .147 0 0 r
F P
0 g
s
.71643 .87981 m .713 .88094 L .71402 .88019 L p .147 0 0 r
F P
0 g
s
.72224 .12456 m .72023 .12245 L .72071 .12266 L p .099 .476 .895 r
F P
0 g
s
.72071 .12266 m .7234 .12507 L .72224 .12456 L p .099 .476 .895 r
F P
0 g
s
.49404 .39752 m .49544 .38743 L .49546 .38782 L p .716 .664 .114 r
F P
0 g
s
.49546 .38782 m .49406 .39784 L .49404 .39752 L p .716 .664 .114 r
F P
0 g
s
.41423 .5564 m .40479 .56023 L .40512 .56003 L p 0 0 0 r
F P
0 g
s
.40512 .56003 m .4145 .55622 L .41423 .5564 L p 0 0 0 r
F P
0 g
s
.59173 .54608 m .59976 .55233 L .59942 .55216 L p 0 .114 .574 r
F P
0 g
s
.59942 .55216 m .59144 .54593 L .59173 .54608 L p 0 .114 .574 r
F P
0 g
s
.58514 .53998 m .59173 .54608 L .59144 .54593 L p 0 .05 .541 r
F P
0 g
s
.59144 .54593 m .5849 .53986 L .58514 .53998 L p 0 .05 .541 r
F P
0 g
s
.49205 .40627 m .49404 .39752 L .49406 .39784 L p .712 .709 .18 r
F P
0 g
s
.49406 .39784 m .49208 .40655 L .49205 .40627 L p .712 .709 .18 r
F P
0 g
s
.4228 .55374 m .41423 .5564 L .4145 .55622 L p 0 0 0 r
F P
0 g
s
.4145 .55622 m .42303 .55359 L .4228 .55374 L p 0 0 0 r
F P
0 g
s
.72071 .87734 m .7234 .87493 L .72435 .87458 L p .07 0 0 r
F P
0 g
s
.7234 .87493 m .72071 .87734 L .72023 .87755 L p .099 0 0 r
F P
0 g
s
.06286 .50247 m .0636 .50601 L .06343 .507 L p .98 .772 .359 r
F P
0 g
s
.0636 .50601 m .06286 .50247 L .06292 .50195 L p .986 .782 .383 r
F P
0 g
s
.71643 .12019 m .713 .11906 L .71222 .11842 L p .129 .534 .918 r
F P
0 g
s
.713 .11906 m .71643 .12019 L .71685 .1205 L p .147 .538 .922 r
F P
0 g
s
.0636 .49399 m .06286 .49753 L .06279 .49712 L p .98 .828 .427 r
F P
0 g
s
.06279 .49712 m .06343 .493 L .0636 .49399 L p .98 .828 .427 r
F P
0 g
s
.713 .88094 m .71643 .87981 L .71611 .88007 L p .129 0 0 r
F P
0 g
s
.71611 .88007 m .71222 .88158 L .713 .88094 L p .129 0 0 r
F P
0 g
s
.7234 .12507 m .72071 .12266 L .7211 .1228 L p .07 .458 .884 r
F P
0 g
s
.7211 .1228 m .72435 .12542 L .7234 .12507 L p .07 .458 .884 r
F P
0 g
s
.08984 .57406 m .07458 .54968 L .07585 .54954 L p .83 .393 0 r
F P
0 g
s
.06782 .53016 m .07585 .54954 L .07458 .54968 L p .895 .537 .064 r
F P
0 g
s
.75497 .15744 m .74221 .1408 L .74265 .14015 L p 0 .158 .697 r
F P
0 g
s
.74265 .14015 m .75574 .15642 L .75497 .15744 L p 0 .158 .697 r
F P
0 g
s
.64095 .10776 m .66968 .10674 L .66917 .10791 L p .314 .784 .931 r
F P
0 g
s
.68997 .11064 m .66917 .10791 L .66968 .10674 L p .211 .689 .935 r
F P
0 g
s
.76922 .81818 m .75574 .84358 L .75497 .84256 L p 0 0 0 r
F P
0 g
s
.74221 .8592 m .75497 .84256 L .75574 .84358 L p 0 0 0 r
F P
0 g
s
.66917 .89209 m .68997 .88936 L .69031 .89007 L p .211 0 0 r
F P
0 g
s
.69031 .89007 m .66968 .89326 L .66917 .89209 L p .211 0 0 r
F P
0 g
s
.07585 .45046 m .06782 .46984 L .06704 .46978 L p .895 .925 .54 r
F P
0 g
s
.06704 .46978 m .07458 .45032 L .07585 .45046 L p .895 .925 .54 r
F P
0 g
s
.68997 .11064 m .70349 .11441 L .70391 .11515 L p .234 .647 .959 r
F P
0 g
s
.71172 .11791 m .70391 .11515 L .70349 .11441 L p .14 .57 .927 r
F P
0 g
s
.70391 .11515 m .71172 .11791 L .71222 .11842 L p .192 .588 .943 r
F P
0 g
s
.06475 .48417 m .06324 .49231 L .06303 .49195 L p .967 .856 .45 r
F P
0 g
s
.06303 .49195 m .06433 .48343 L .06475 .48417 L p .967 .856 .45 r
F P
0 g
s
.74221 .8592 m .73219 .86902 L .73133 .86902 L p 0 0 0 r
F P
0 g
s
.72504 .8744 m .73133 .86902 L .73219 .86902 L p 0 0 0 r
F P
0 g
s
.73133 .86902 m .72504 .8744 L .72435 .87458 L p .067 0 0 r
F P
0 g
s
.70391 .88485 m .71172 .88209 L .71151 .88245 L p .14 0 0 r
F P
0 g
s
.71151 .88245 m .70349 .88559 L .70391 .88485 L p .14 0 0 r
F P
0 g
s
.73133 .13098 m .72504 .1256 L .72546 .1256 L p 0 .389 .846 r
F P
0 g
s
.72546 .1256 m .73219 .13098 L .73133 .13098 L p 0 .389 .846 r
F P
0 g
s
.06782 .53016 m .06433 .51657 L .06475 .51583 L p .967 .679 .265 r
F P
0 g
s
.06324 .50769 m .06475 .51583 L .06433 .51657 L p .967 .723 .287 r
F P
0 g
s
.06475 .51583 m .06324 .50769 L .06343 .507 L p .983 .743 .341 r
F P
0 g
s
.57981 .53398 m .58514 .53998 L .5849 .53986 L p 0 0 .499 r
F P
0 g
s
.5849 .53986 m .57959 .53389 L .57981 .53398 L p 0 0 .499 r
F P
0 g
s
.48953 .41389 m .49205 .40627 L .49208 .40655 L p .7 .754 .252 r
F P
0 g
s
.49208 .40655 m .48956 .41413 L .48953 .41389 L p .7 .754 .252 r
F P
0 g
s
.43067 .55212 m .4228 .55374 L .42303 .55359 L p 0 0 0 r
F P
0 g
s
.42303 .55359 m .43085 .55198 L .43067 .55212 L p 0 0 0 r
F P
0 g
s
.48653 .42053 m .48953 .41389 L .48956 .41413 L p .68 .793 .328 r
F P
0 g
s
.48956 .41413 m .48656 .42073 L .48653 .42053 L p .68 .793 .328 r
F P
0 g
s
.57556 .52807 m .57981 .53398 L .57959 .53389 L p 0 0 .448 r
F P
0 g
s
.57959 .53389 m .57536 .528 L .57556 .52807 L p 0 0 .448 r
F P
0 g
s
.43791 .5514 m .43067 .55212 L .43085 .55198 L p 0 0 0 r
F P
0 g
s
.43085 .55198 m .43807 .55127 L .43791 .5514 L p 0 0 0 r
F P
0 g
s
.48311 .42629 m .48653 .42053 L .48656 .42073 L p .649 .824 .402 r
F P
0 g
s
.48656 .42073 m .48315 .42647 L .48311 .42629 L p .649 .824 .402 r
F P
0 g
s
.44461 .55148 m .43791 .5514 L .43807 .55127 L p .051 0 0 r
F P
0 g
s
.43807 .55127 m .44475 .55135 L .44461 .55148 L p .051 0 0 r
F P
0 g
s
.57228 .52223 m .57556 .52807 L .57536 .528 L p 0 0 .387 r
F P
0 g
s
.57536 .528 m .5721 .52217 L .57228 .52223 L p 0 0 .387 r
F P
0 g
s
.47934 .43125 m .48311 .42629 L .48315 .42647 L p .609 .845 .473 r
F P
0 g
s
.48315 .42647 m .47939 .43142 L .47934 .43125 L p .609 .845 .473 r
F P
0 g
s
.56987 .51648 m .57228 .52223 L .5721 .52217 L p 0 0 .32 r
F P
0 g
s
.5721 .52217 m .5697 .51644 L .56987 .51648 L p 0 0 .32 r
F P
0 g
s
.45079 .55226 m .44461 .55148 L .44475 .55135 L p .135 0 0 r
F P
0 g
s
.44475 .55135 m .45091 .55214 L .45079 .55226 L p .135 0 0 r
F P
0 g
s
.56823 .51085 m .56987 .51648 L .5697 .51644 L p 0 0 .247 r
F P
0 g
s
.5697 .51644 m .56807 .51082 L .56823 .51085 L p 0 0 .247 r
F P
0 g
s
.47528 .43549 m .47934 .43125 L .47939 .43142 L p .559 .855 .539 r
F P
0 g
s
.47939 .43142 m .47534 .43564 L .47528 .43549 L p .559 .855 .539 r
F P
0 g
s
.45649 .55366 m .45079 .55226 L .45091 .55214 L p .219 0 0 r
F P
0 g
s
.45091 .55214 m .45659 .55353 L .45649 .55366 L p .219 0 0 r
F P
0 g
s
.56713 .49467 m .56807 .48918 L .56823 .48915 L p 0 0 0 r
F P
0 g
s
.56729 .50535 m .56823 .51085 L .56807 .51082 L p 0 0 .171 r
F P
0 g
s
.56807 .51082 m .56713 .50533 L .56729 .50535 L p 0 0 .171 r
F P
0 g
s
.47098 .43905 m .47528 .43549 L .47534 .43564 L p .502 .854 .596 r
F P
0 g
s
.47534 .43564 m .47105 .43919 L .47098 .43905 L p .502 .854 .596 r
F P
0 g
s
.47105 .56081 m .47534 .56436 L .47528 .56451 L p .502 0 0 r
F P
0 g
s
.46172 .5556 m .45649 .55366 L .45659 .55353 L p .298 0 0 r
F P
0 g
s
.45659 .55353 m .46181 .55547 L .46172 .5556 L p .298 0 0 r
F P
0 g
s
.46181 .44453 m .45659 .44647 L .45649 .44634 L p .298 .783 .714 r
F P
0 g
s
.56684 .5 m .56713 .49467 L .56729 .49465 L p 0 0 .015 r
F P
0 g
s
.56823 .48915 m .56729 .49465 L .56713 .49467 L p 0 0 0 r
F P
0 g
s
.56699 .5 m .56729 .50535 L .56713 .50533 L p 0 0 .093 r
F P
0 g
s
.56713 .50533 m .56684 .5 L .56699 .5 L p 0 0 .093 r
F P
0 g
s
.46658 .44212 m .46181 .44453 L .46172 .4444 L p .372 .817 .683 r
F P
0 g
s
.45649 .44634 m .46172 .4444 L .46181 .44453 L p .298 .783 .714 r
F P
0 g
s
.46658 .55788 m .47105 .56081 L .47098 .56095 L p .44 0 0 r
F P
0 g
s
.47528 .56451 m .47098 .56095 L .47105 .56081 L p .502 0 0 r
F P
0 g
s
.4665 .55802 m .46172 .5556 L .46181 .55547 L p .372 0 0 r
F P
0 g
s
.46181 .55547 m .46658 .55788 L .4665 .55802 L p .372 0 0 r
F P
0 g
s
.4665 .44198 m .47098 .43905 L .47105 .43919 L p .44 .841 .644 r
F P
0 g
s
.47105 .43919 m .46658 .44212 L .4665 .44198 L p .44 .841 .644 r
F P
0 g
s
.46172 .4444 m .4665 .44198 L .46658 .44212 L p .372 .817 .683 r
F P
0 g
s
.56729 .49465 m .56699 .5 L .56684 .5 L p 0 0 .015 r
F P
0 g
s
.47098 .56095 m .4665 .55802 L .46658 .55788 L p .44 0 0 r
F P
0 g
s
.06343 .493 m .06279 .49712 L .06271 .49684 L p .972 .826 .41 r
F P
0 g
s
.06271 .49684 m .06324 .49231 L .06343 .493 L p .972 .826 .41 r
F P
0 g
s
.71222 .88158 m .71611 .88007 L .71591 .88028 L p .105 0 0 r
F P
0 g
s
.71591 .88028 m .71172 .88209 L .71222 .88158 L p .105 0 0 r
F P
0 g
s
.7211 .8772 m .72435 .87458 L .72504 .8744 L p .036 0 0 r
F P
0 g
s
.72435 .87458 m .7211 .8772 L .72071 .87734 L p .07 0 0 r
F P
0 g
s
.06279 .50288 m .06343 .507 L .06324 .50769 L p .972 .761 .331 r
F P
0 g
s
.06343 .507 m .06279 .50288 L .06286 .50247 L p .98 .772 .359 r
F P
0 g
s
.72435 .12542 m .7211 .1228 L .72138 .12288 L p .036 .438 .871 r
F P
0 g
s
.72138 .12288 m .72504 .1256 L .72435 .12542 L p .036 .438 .871 r
F P
0 g
s
.71611 .11993 m .71222 .11842 L .71172 .11791 L p .105 .526 .911 r
F P
0 g
s
.71222 .11842 m .71611 .11993 L .71643 .12019 L p .129 .534 .918 r
F P
0 g
s
.7185 .87845 m .71868 .87876 L .71849 .87888 L p .079 0 0 r
F P
0 g
s
.71849 .87888 m .71791 .87881 L .7185 .87845 L p .079 0 0 r
F P
0 g
s
.71868 .87876 m .7185 .87845 L .7191 .87812 L p .075 0 0 r
F P
0 g
s
.7185 .12155 m .71868 .12124 L .71887 .12134 L p .075 .484 .894 r
F P
0 g
s
.71887 .12134 m .7191 .12188 L .7185 .12155 L p .075 .484 .894 r
F P
0 g
s
.71868 .12124 m .7185 .12155 L .71791 .12119 L p .079 .488 .896 r
F P
0 g
s
.063 .5 m .06264 .5 L .06264 .49978 L p .975 .798 .378 r
F P
0 g
s
.06264 .49978 m .06299 .49931 L .063 .5 L p .975 .798 .378 r
F P
0 g
s
.06264 .5 m .063 .5 L .06299 .50069 L p .975 .794 .374 r
F P
0 g
s
.7191 .12188 m .71887 .12134 L .71906 .12144 L p .069 .478 .891 r
F P
0 g
s
.71906 .12144 m .71969 .12219 L .7191 .12188 L p .069 .478 .891 r
F P
0 g
s
.06299 .49931 m .06264 .49978 L .06263 .49957 L p .974 .8 .38 r
F P
0 g
s
.06263 .49957 m .06296 .49865 L .06299 .49931 L p .974 .8 .38 r
F P
0 g
s
.71791 .87881 m .71849 .87888 L .71831 .87899 L p .079 0 0 r
F P
0 g
s
.71831 .87899 m .71735 .87916 L .71791 .87881 L p .079 0 0 r
F P
0 g
s
.71849 .12112 m .71791 .12119 L .71735 .12084 L p .079 .491 .897 r
F P
0 g
s
.71791 .12119 m .71849 .12112 L .71868 .12124 L p .079 .488 .896 r
F P
0 g
s
.71887 .87866 m .7191 .87812 L .71969 .87781 L p .069 0 0 r
F P
0 g
s
.7191 .87812 m .71887 .87866 L .71868 .87876 L p .075 0 0 r
F P
0 g
s
.06264 .50022 m .06299 .50069 L .06296 .50135 L p .974 .79 .368 r
F P
0 g
s
.06299 .50069 m .06264 .50022 L .06264 .5 L p .975 .794 .374 r
F P
0 g
s
.06782 .46984 m .06433 .48343 L .06389 .48341 L p .928 .88 .461 r
F P
0 g
s
.06389 .48341 m .06704 .46978 L .06782 .46984 L p .928 .88 .461 r
F P
0 g
s
.07458 .54968 m .06704 .53022 L .06782 .53016 L p .895 .537 .064 r
F P
0 g
s
.06433 .51657 m .06782 .53016 L .06704 .53022 L p .928 .635 .16 r
F P
0 g
s
.74221 .1408 m .73219 .13098 L .73242 .13061 L p 0 .27 .77 r
F P
0 g
s
.73242 .13061 m .74265 .14015 L .74221 .1408 L p 0 .27 .77 r
F P
0 g
s
.68997 .88936 m .70349 .88559 L .70369 .88597 L p .132 0 0 r
F P
0 g
s
.70369 .88597 m .69031 .89007 L .68997 .88936 L p .132 0 0 r
F P
0 g
s
.75574 .84358 m .74265 .85985 L .74221 .8592 L p 0 0 0 r
F P
0 g
s
.73219 .86902 m .74221 .8592 L .74265 .85985 L p 0 0 0 r
F P
0 g
s
.66968 .10674 m .69031 .10993 L .68997 .11064 L p .211 .689 .935 r
F P
0 g
s
.70349 .11441 m .68997 .11064 L .69031 .10993 L p .132 .606 .92 r
F P
0 g
s
.71906 .87856 m .71969 .87781 L .72023 .87755 L p .059 0 0 r
F P
0 g
s
.71969 .87781 m .71906 .87856 L .71887 .87866 L p .069 0 0 r
F P
0 g
s
.71831 .12101 m .71735 .12084 L .71685 .1205 L p .076 .492 .896 r
F P
0 g
s
.71735 .12084 m .71831 .12101 L .71849 .12112 L p .079 .491 .897 r
F P
0 g
s
.71735 .87916 m .71831 .87899 L .71816 .87909 L p .076 0 0 r
F P
0 g
s
.71816 .87909 m .71685 .8795 L .71735 .87916 L p .076 0 0 r
F P
0 g
s
.71969 .12219 m .71906 .12144 L .71923 .12152 L p .059 .471 .886 r
F P
0 g
s
.71923 .12152 m .72023 .12245 L .71969 .12219 L p .059 .471 .886 r
F P
0 g
s
.06263 .50043 m .06296 .50135 L .06292 .50195 L p .972 .786 .359 r
F P
0 g
s
.06296 .50135 m .06263 .50043 L .06264 .50022 L p .974 .79 .368 r
F P
0 g
s
.06296 .49865 m .06263 .49957 L .06262 .49938 L p .972 .802 .379 r
F P
0 g
s
.06262 .49938 m .06292 .49805 L .06296 .49865 L p .972 .802 .379 r
F P
0 g
s
.72023 .12245 m .71923 .12152 L .71938 .12159 L p .047 .462 .881 r
F P
0 g
s
.71938 .12159 m .72071 .12266 L .72023 .12245 L p .047 .462 .881 r
F P
0 g
s
.71685 .8795 m .71816 .87909 L .71802 .87919 L p .07 0 0 r
F P
0 g
s
.71802 .87919 m .71643 .87981 L .71685 .8795 L p .07 0 0 r
F P
0 g
s
.71816 .12091 m .71685 .1205 L .71643 .12019 L p .07 .492 .894 r
F P
0 g
s
.71685 .1205 m .71816 .12091 L .71831 .12101 L p .076 .492 .896 r
F P
0 g
s
.06262 .50062 m .06292 .50195 L .06286 .50247 L p .969 .781 .349 r
F P
0 g
s
.06292 .50195 m .06262 .50062 L .06263 .50043 L p .972 .786 .359 r
F P
0 g
s
.71923 .87848 m .72023 .87755 L .72071 .87734 L p .047 0 0 r
F P
0 g
s
.72023 .87755 m .71923 .87848 L .71906 .87856 L p .059 0 0 r
F P
0 g
s
.06292 .49805 m .06262 .49938 L .0626 .49922 L p .969 .802 .375 r
F P
0 g
s
.0626 .49922 m .06286 .49753 L .06292 .49805 L p .969 .802 .375 r
F P
0 g
s
.73219 .86902 m .72546 .8744 L .72504 .8744 L p 0 0 0 r
F P
0 g
s
.72138 .87712 m .72504 .8744 L .72546 .8744 L p 0 0 0 r
F P
0 g
s
.72504 .8744 m .72138 .87712 L .7211 .8772 L p .036 0 0 r
F P
0 g
s
.70349 .11441 m .71151 .11755 L .71172 .11791 L p .14 .57 .927 r
F P
0 g
s
.71591 .11972 m .71172 .11791 L .71151 .11755 L p .075 .514 .9 r
F P
0 g
s
.71172 .11791 m .71591 .11972 L .71611 .11993 L p .105 .526 .911 r
F P
0 g
s
.06324 .49231 m .06271 .49684 L .06263 .49669 L p .961 .82 .388 r
F P
0 g
s
.06263 .49669 m .06303 .49195 L .06324 .49231 L p .961 .82 .388 r
F P
0 g
s
.06433 .51657 m .06303 .50805 L .06324 .50769 L p .967 .723 .287 r
F P
0 g
s
.06271 .50316 m .06324 .50769 L .06303 .50805 L p .961 .749 .301 r
F P
0 g
s
.06324 .50769 m .06271 .50316 L .06279 .50288 L p .972 .761 .331 r
F P
0 g
s
.72504 .1256 m .72138 .12288 L .72155 .12288 L p 0 .417 .856 r
F P
0 g
s
.72155 .12288 m .72546 .1256 L .72504 .1256 L p 0 .417 .856 r
F P
0 g
s
.71172 .88209 m .71591 .88028 L .71582 .88043 L p .075 0 0 r
F P
0 g
s
.71582 .88043 m .71151 .88245 L .71172 .88209 L p .075 0 0 r
F P
0 g
s
.71938 .87841 m .72071 .87734 L .7211 .8772 L p .033 0 0 r
F P
0 g
s
.72071 .87734 m .71938 .87841 L .71923 .87848 L p .047 0 0 r
F P
0 g
s
.71802 .12081 m .71643 .12019 L .71611 .11993 L p .06 .489 .891 r
F P
0 g
s
.71643 .12019 m .71802 .12081 L .71816 .12091 L p .07 .492 .894 r
F P
0 g
s
.0626 .50078 m .06286 .50247 L .06279 .50288 L p .965 .775 .337 r
F P
0 g
s
.06286 .50247 m .0626 .50078 L .06262 .50062 L p .969 .781 .349 r
F P
0 g
s
.71643 .87981 m .71802 .87919 L .71792 .87928 L p .06 0 0 r
F P
0 g
s
.71792 .87928 m .71611 .88007 L .71643 .87981 L p .06 0 0 r
F P
0 g
s
.72071 .12266 m .71938 .12159 L .7195 .12164 L p .033 .453 .875 r
F P
0 g
s
.7195 .12164 m .7211 .1228 L .72071 .12266 L p .033 .453 .875 r
F P
0 g
s
.06286 .49753 m .0626 .49922 L .06258 .49909 L p .965 .801 .369 r
F P
0 g
s
.06258 .49909 m .06279 .49712 L .06286 .49753 L p .965 .801 .369 r
F P
0 g
s
.70349 .88559 m .71151 .88245 L .71162 .88264 L p .076 0 0 r
F P
0 g
s
.71162 .88264 m .70369 .88597 L .70349 .88559 L p .076 0 0 r
F P
0 g
s
.73219 .13098 m .72546 .1256 L .72556 .12542 L p 0 .347 .814 r
F P
0 g
s
.72556 .12542 m .73242 .13061 L .73219 .13098 L p 0 .347 .814 r
F P
0 g
s
.06433 .48343 m .06303 .49195 L .06282 .49195 L p .942 .84 .401 r
F P
0 g
s
.06282 .49195 m .06389 .48341 L .06433 .48343 L p .942 .84 .401 r
F P
0 g
s
.74265 .85985 m .73242 .86939 L .73219 .86902 L p 0 0 0 r
F P
0 g
s
.72546 .8744 m .73219 .86902 L .73242 .86939 L p 0 0 0 r
F P
0 g
s
.06704 .53022 m .06389 .51659 L .06433 .51657 L p .928 .635 .16 r
F P
0 g
s
.06303 .50805 m .06433 .51657 L .06389 .51659 L p .942 .698 .227 r
F P
0 g
s
.69031 .10993 m .70369 .11403 L .70349 .11441 L p .132 .606 .92 r
F P
0 g
s
.71151 .11755 m .70349 .11441 L .70369 .11403 L p .076 .541 .901 r
F P
0 g
s
.7195 .87836 m .7211 .8772 L .72138 .87712 L p .017 0 0 r
F P
0 g
s
.7211 .8772 m .7195 .87836 L .71938 .87841 L p .033 0 0 r
F P
0 g
s
.06258 .50091 m .06279 .50288 L .06271 .50316 L p .961 .769 .324 r
F P
0 g
s
.06279 .50288 m .06258 .50091 L .0626 .50078 L p .965 .775 .337 r
F P
0 g
s
.71792 .12072 m .71611 .11993 L .71591 .11972 L p .048 .484 .887 r
F P
0 g
s
.71611 .11993 m .71792 .12072 L .71802 .12081 L p .06 .489 .891 r
F P
0 g
s
.7211 .1228 m .7195 .12164 L .71959 .12166 L p .017 .444 .869 r
F P
0 g
s
.71959 .12166 m .72138 .12288 L .7211 .1228 L p .017 .444 .869 r
F P
0 g
s
.71611 .88007 m .71792 .87928 L .71786 .87934 L p .048 0 0 r
F P
0 g
s
.71786 .87934 m .71591 .88028 L .71611 .88007 L p .048 0 0 r
F P
0 g
s
.06279 .49712 m .06258 .49909 L .06255 .499 L p .961 .799 .36 r
F P
0 g
s
.06255 .499 m .06271 .49684 L .06279 .49712 L p .961 .799 .36 r
F P
0 g
s
.71868 .12124 m .71874 .12114 L .71877 .12116 L p .028 .461 .876 r
F P
0 g
s
.71877 .12116 m .71887 .12134 L .71868 .12124 L p .028 .461 .876 r
F P
0 g
s
.71874 .12114 m .71868 .12124 L .71849 .12112 L p .029 .463 .877 r
F P
0 g
s
.71868 .87876 m .71874 .87886 L .7187 .87889 L p .029 0 0 r
F P
0 g
s
.7187 .87889 m .71849 .87888 L .71868 .87876 L p .029 0 0 r
F P
0 g
s
.71874 .87886 m .71868 .87876 L .71887 .87866 L p .028 0 0 r
F P
0 g
s
.06264 .5 m .06253 .5 L .06253 .49996 L p .959 .784 .339 r
F P
0 g
s
.06253 .49996 m .06264 .49978 L .06264 .5 L p .959 .784 .339 r
F P
0 g
s
.06253 .5 m .06264 .5 L .06264 .50022 L p .959 .783 .338 r
F P
0 g
s
.71849 .87888 m .7187 .87889 L .71866 .87891 L p .029 0 0 r
F P
0 g
s
.71866 .87891 m .71831 .87899 L .71849 .87888 L p .029 0 0 r
F P
0 g
s
.06264 .49978 m .06253 .49996 L .06252 .49992 L p .959 .785 .34 r
F P
0 g
s
.06252 .49992 m .06263 .49957 L .06264 .49978 L p .959 .785 .34 r
F P
0 g
s
.71887 .12134 m .71877 .12116 L .71881 .12118 L p .025 .459 .875 r
F P
0 g
s
.71881 .12118 m .71906 .12144 L .71887 .12134 L p .025 .459 .875 r
F P
0 g
s
.71877 .87884 m .71887 .87866 L .71906 .87856 L p .025 0 0 r
F P
0 g
s
.71887 .87866 m .71877 .87884 L .71874 .87886 L p .028 0 0 r
F P
0 g
s
.7187 .12111 m .71849 .12112 L .71831 .12101 L p .029 .464 .877 r
F P
0 g
s
.71849 .12112 m .7187 .12111 L .71874 .12114 L p .029 .463 .877 r
F P
0 g
s
.06253 .50004 m .06264 .50022 L .06263 .50043 L p .959 .781 .336 r
F P
0 g
s
.06264 .50022 m .06253 .50004 L .06253 .5 L p .959 .783 .338 r
F P
0 g
s
.71591 .88028 m .71786 .87934 L .71783 .87939 L p .034 0 0 r
F P
0 g
s
.71783 .87939 m .71582 .88043 L .71591 .88028 L p .034 0 0 r
F P
0 g
s
.06271 .49684 m .06255 .499 L .06252 .49895 L p .955 .796 .349 r
F P
0 g
s
.06252 .49895 m .06263 .49669 L .06271 .49684 L p .955 .796 .349 r
F P
0 g
s
.72138 .12288 m .71959 .12166 L .71965 .12166 L p 0 .434 .861 r
F P
0 g
s
.71965 .12166 m .72155 .12288 L .72138 .12288 L p 0 .434 .861 r
F P
0 g
s
.72546 .8744 m .72155 .87712 L .72138 .87712 L p 0 0 0 r
F P
0 g
s
.71959 .87834 m .72138 .87712 L .72155 .87712 L p 0 0 0 r
F P
0 g
s
.72138 .87712 m .71959 .87834 L .7195 .87836 L p .017 0 0 r
F P
0 g
s
.71151 .11755 m .71582 .11957 L .71591 .11972 L p .075 .514 .9 r
F P
0 g
s
.71786 .12066 m .71591 .11972 L .71582 .11957 L p .034 .478 .881 r
F P
0 g
s
.71591 .11972 m .71786 .12066 L .71792 .12072 L p .048 .484 .887 r
F P
0 g
s
.06303 .50805 m .06263 .50331 L .06271 .50316 L p .961 .749 .301 r
F P
0 g
s
.06255 .501 m .06271 .50316 L .06263 .50331 L p .955 .763 .31 r
F P
0 g
s
.06271 .50316 m .06255 .501 L .06258 .50091 L p .961 .769 .324 r
F P
0 g
s
.71831 .87899 m .71866 .87891 L .71863 .87893 L p .028 0 0 r
F P
0 g
s
.71863 .87893 m .71816 .87909 L .71831 .87899 L p .028 0 0 r
F P
0 g
s
.06263 .49957 m .06252 .49992 L .06252 .49988 L p .958 .785 .339 r
F P
0 g
s
.06252 .49988 m .06262 .49938 L .06263 .49957 L p .958 .785 .339 r
F P
0 g
s
.71906 .12144 m .71881 .12118 L .71885 .12119 L p .022 .456 .873 r
F P
0 g
s
.71885 .12119 m .71923 .12152 L .71906 .12144 L p .022 .456 .873 r
F P
0 g
s
.71881 .87882 m .71906 .87856 L .71923 .87848 L p .022 0 0 r
F P
0 g
s
.71906 .87856 m .71881 .87882 L .71877 .87884 L p .025 0 0 r
F P
0 g
s
.71866 .12109 m .71831 .12101 L .71816 .12091 L p .028 .464 .877 r
F P
0 g
s
.71831 .12101 m .71866 .12109 L .7187 .12111 L p .029 .464 .877 r
F P
0 g
s
.06252 .50008 m .06263 .50043 L .06262 .50062 L p .958 .779 .332 r
F P
0 g
s
.06263 .50043 m .06252 .50008 L .06253 .50004 L p .959 .781 .336 r
F P
0 g
s
.71816 .87909 m .71863 .87893 L .71861 .87895 L p .025 0 0 r
F P
0 g
s
.71861 .87895 m .71802 .87919 L .71816 .87909 L p .025 0 0 r
F P
0 g
s
.71885 .87881 m .71923 .87848 L .71938 .87841 L p .017 0 0 r
F P
0 g
s
.71923 .87848 m .71885 .87881 L .71881 .87882 L p .022 0 0 r
F P
0 g
s
.71863 .12107 m .71816 .12091 L .71802 .12081 L p .025 .464 .876 r
F P
0 g
s
.71816 .12091 m .71863 .12107 L .71866 .12109 L p .028 .464 .877 r
F P
0 g
s
.71923 .12152 m .71885 .12119 L .71888 .12121 L p .017 .453 .871 r
F P
0 g
s
.71888 .12121 m .71938 .12159 L .71923 .12152 L p .017 .453 .871 r
F P
0 g
s
.06262 .49938 m .06252 .49988 L .06252 .49985 L p .957 .785 .338 r
F P
0 g
s
.06252 .49985 m .0626 .49922 L .06262 .49938 L p .957 .785 .338 r
F P
0 g
s
.06252 .50012 m .06262 .50062 L .0626 .50078 L p .957 .777 .328 r
F P
0 g
s
.06262 .50062 m .06252 .50012 L .06252 .50008 L p .958 .779 .332 r
F P
0 g
s
.73242 .86939 m .72556 .87458 L .72546 .8744 L p 0 0 0 r
F P
0 g
s
.72155 .87712 m .72546 .8744 L .72556 .87458 L p 0 0 0 r
F P
0 g
s
.06303 .49195 m .06263 .49669 L .06254 .49669 L p .947 .81 .361 r
F P
0 g
s
.06254 .49669 m .06282 .49195 L .06303 .49195 L p .947 .81 .361 r
F P
0 g
s
.72546 .1256 m .72155 .12288 L .72159 .1228 L p 0 .396 .839 r
F P
0 g
s
.72159 .1228 m .72556 .12542 L .72546 .1256 L p 0 .396 .839 r
F P
0 g
s
.70369 .11403 m .71162 .11736 L .71151 .11755 L p .076 .541 .901 r
F P
0 g
s
.71582 .11957 m .71151 .11755 L .71162 .11736 L p .04 .497 .885 r
F P
0 g
s
.06389 .51659 m .06282 .50805 L .06303 .50805 L p .942 .698 .227 r
F P
0 g
s
.06263 .50331 m .06303 .50805 L .06282 .50805 L p .947 .736 .27 r
F P
0 g
s
.71151 .88245 m .71582 .88043 L .71587 .88051 L p .04 0 0 r
F P
0 g
s
.71587 .88051 m .71162 .88264 L .71151 .88245 L p .04 0 0 r
F P
0 g
s
.71802 .87919 m .71861 .87895 L .71859 .87896 L p .022 0 0 r
F P
0 g
s
.71859 .87896 m .71792 .87928 L .71802 .87919 L p .022 0 0 r
F P
0 g
s
.0626 .49922 m .06252 .49985 L .06251 .49982 L p .955 .785 .335 r
F P
0 g
s
.06251 .49982 m .06258 .49909 L .0626 .49922 L p .955 .785 .335 r
F P
0 g
s
.06252 .50015 m .0626 .50078 L .06258 .50091 L p .955 .775 .324 r
F P
0 g
s
.0626 .50078 m .06252 .50015 L .06252 .50012 L p .957 .777 .328 r
F P
0 g
s
.71861 .12105 m .71802 .12081 L .71792 .12072 L p .022 .463 .874 r
F P
0 g
s
.71802 .12081 m .71861 .12105 L .71863 .12107 L p .025 .464 .876 r
F P
0 g
s
.71938 .12159 m .71888 .12121 L .7189 .12122 L p .012 .45 .868 r
F P
0 g
s
.7189 .12122 m .7195 .12164 L .71938 .12159 L p .012 .45 .868 r
F P
0 g
s
.71888 .87879 m .71938 .87841 L .7195 .87836 L p .012 0 0 r
F P
0 g
s
.71938 .87841 m .71888 .87879 L .71885 .87881 L p .017 0 0 r
F P
0 g
s
.06251 .50018 m .06258 .50091 L .06255 .501 L p .953 .773 .319 r
F P
0 g
s
.06258 .50091 m .06251 .50018 L .06252 .50015 L p .955 .775 .324 r
F P
0 g
s
.06258 .49909 m .06251 .49982 L .06251 .4998 L p .953 .784 .332 r
F P
0 g
s
.06251 .4998 m .06255 .499 L .06258 .49909 L p .953 .784 .332 r
F P
0 g
s
.71859 .12104 m .71792 .12072 L .71786 .12066 L p .017 .461 .872 r
F P
0 g
s
.71792 .12072 m .71859 .12104 L .71861 .12105 L p .022 .463 .874 r
F P
0 g
s
.7189 .87878 m .7195 .87836 L .71959 .87834 L p .006 0 0 r
F P
0 g
s
.7195 .87836 m .7189 .87878 L .71888 .87879 L p .012 0 0 r
F P
0 g
s
.7195 .12164 m .7189 .12122 L .71892 .12122 L p .006 .446 .866 r
F P
0 g
s
.71892 .12122 m .71959 .12166 L .7195 .12164 L p .006 .446 .866 r
F P
0 g
s
.71792 .87928 m .71859 .87896 L .71857 .87898 L p .017 0 0 r
F P
0 g
s
.71857 .87898 m .71786 .87934 L .71792 .87928 L p .017 0 0 r
F P
0 g
s
.71582 .88043 m .71783 .87939 L .71784 .87941 L p .018 0 0 r
F P
0 g
s
.71784 .87941 m .71587 .88051 L .71582 .88043 L p .018 0 0 r
F P
0 g
s
.72556 .87458 m .72159 .8772 L .72155 .87712 L p 0 0 0 r
F P
0 g
s
.71965 .87834 m .72155 .87712 L .72159 .8772 L p 0 0 0 r
F P
0 g
s
.72155 .87712 m .71965 .87834 L .71959 .87834 L p 0 0 0 r
F P
0 g
s
.06263 .49669 m .06252 .49895 L .0625 .49895 L p .948 .791 .337 r
F P
0 g
s
.0625 .49895 m .06254 .49669 L .06263 .49669 L p .948 .791 .337 r
F P
0 g
s
.71162 .11736 m .71587 .11949 L .71582 .11957 L p .04 .497 .885 r
F P
0 g
s
.71783 .12061 m .71582 .11957 L .71587 .11949 L p .018 .47 .874 r
F P
0 g
s
.71582 .11957 m .71783 .12061 L .71786 .12066 L p .034 .478 .881 r
F P
0 g
s
.72155 .12288 m .71965 .12166 L .71966 .12163 L p 0 .424 .853 r
F P
0 g
s
.71966 .12163 m .72159 .1228 L .72155 .12288 L p 0 .424 .853 r
F P
0 g
s
.06282 .50805 m .06254 .50331 L .06263 .50331 L p .947 .736 .27 r
F P
0 g
s
.06252 .50105 m .06263 .50331 L .06254 .50331 L p .948 .758 .296 r
F P
0 g
s
.06263 .50331 m .06252 .50105 L .06255 .501 L p .955 .763 .31 r
F P
0 g
s
.71959 .12166 m .71892 .12122 L .71893 .12122 L p 0 .443 .863 r
F P
0 g
s
.71893 .12122 m .71965 .12166 L .71959 .12166 L p 0 .443 .863 r
F P
0 g
s
.71857 .12102 m .71786 .12066 L .71783 .12061 L p .012 .458 .87 r
F P
0 g
s
.71786 .12066 m .71857 .12102 L .71859 .12104 L p .017 .461 .872 r
F P
0 g
s
.71892 .87878 m .71959 .87834 L .71965 .87834 L p 0 0 0 r
F P
0 g
s
.71959 .87834 m .71892 .87878 L .7189 .87878 L p .006 0 0 r
F P
0 g
s
.06255 .499 m .06251 .4998 L .0625 .49979 L p .951 .782 .328 r
F P
0 g
s
.0625 .49979 m .06252 .49895 L .06255 .499 L p .951 .782 .328 r
F P
0 g
s
.71786 .87934 m .71857 .87898 L .71857 .87899 L p .012 0 0 r
F P
0 g
s
.71857 .87899 m .71783 .87939 L .71786 .87934 L p .012 0 0 r
F P
0 g
s
.06251 .5002 m .06255 .501 L .06252 .50105 L p .951 .771 .314 r
F P
0 g
s
.06255 .501 m .06251 .5002 L .06251 .50018 L p .953 .773 .319 r
F P
0 g
s
.71874 .87886 m .71875 .87888 L .71875 .87889 L p .007 0 0 r
F P
0 g
s
.71875 .87889 m .7187 .87889 L .71874 .87886 L p .007 0 0 r
F P
0 g
s
.71875 .87888 m .71874 .87886 L .71877 .87884 L p .007 0 0 r
F P
0 g
s
.71874 .12114 m .71875 .12112 L .71875 .12112 L p .007 .451 .867 r
F P
0 g
s
.71875 .12112 m .71877 .12116 L .71874 .12114 L p .007 .451 .867 r
F P
0 g
s
.71875 .12112 m .71874 .12114 L .7187 .12111 L p .007 .451 .867 r
F P
0 g
s
.06253 .5 m .0625 .5 L .0625 .5 L p .951 .777 .322 r
F P
0 g
s
.0625 .5 m .06253 .49996 L .06253 .5 L p .951 .777 .322 r
F P
0 g
s
.0625 .5 m .06253 .5 L .06253 .50004 L p .951 .777 .321 r
F P
0 g
s
.71875 .87888 m .71877 .87884 L .71881 .87882 L p .006 0 0 r
F P
0 g
s
.71877 .87884 m .71875 .87888 L .71875 .87888 L p .007 0 0 r
F P
0 g
s
.0625 .5 m .06253 .50004 L .06252 .50008 L p .951 .776 .321 r
F P
0 g
s
.06253 .50004 m .0625 .5 L .0625 .5 L p .951 .777 .321 r
F P
0 g
s
.71875 .12111 m .7187 .12111 L .71866 .12109 L p .007 .451 .867 r
F P
0 g
s
.7187 .12111 m .71875 .12111 L .71875 .12112 L p .007 .451 .867 r
F P
0 g
s
.71877 .12116 m .71875 .12112 L .71875 .12112 L p .006 .45 .867 r
F P
0 g
s
.71875 .12112 m .71881 .12118 L .71877 .12116 L p .006 .45 .867 r
F P
0 g
s
.06253 .49996 m .0625 .5 L .0625 .49999 L p .951 .777 .322 r
F P
0 g
s
.0625 .49999 m .06252 .49992 L .06253 .49996 L p .951 .777 .322 r
F P
0 g
s
.7187 .87889 m .71875 .87889 L .71874 .87889 L p .007 0 0 r
F P
0 g
s
.71874 .87889 m .71866 .87891 L .7187 .87889 L p .007 0 0 r
F P
0 g
s
.0625 .50001 m .06252 .50008 L .06252 .50012 L p .951 .776 .32 r
F P
0 g
s
.06252 .50008 m .0625 .50001 L .0625 .5 L p .951 .776 .321 r
F P
0 g
s
.71874 .12111 m .71866 .12109 L .71863 .12107 L p .007 .451 .867 r
F P
0 g
s
.71866 .12109 m .71874 .12111 L .71875 .12111 L p .007 .451 .867 r
F P
0 g
s
.71881 .12118 m .71875 .12112 L .71876 .12112 L p .005 .449 .866 r
F P
0 g
s
.71876 .12112 m .71885 .12119 L .71881 .12118 L p .005 .449 .866 r
F P
0 g
s
.06252 .49992 m .0625 .49999 L .0625 .49999 L p .951 .777 .322 r
F P
0 g
s
.0625 .49999 m .06252 .49988 L .06252 .49992 L p .951 .777 .322 r
F P
0 g
s
.71866 .87891 m .71874 .87889 L .71874 .87889 L p .007 0 0 r
F P
0 g
s
.71874 .87889 m .71863 .87893 L .71866 .87891 L p .007 0 0 r
F P
0 g
s
.71875 .87888 m .71881 .87882 L .71885 .87881 L p .005 0 0 r
F P
0 g
s
.71881 .87882 m .71875 .87888 L .71875 .87888 L p .006 0 0 r
F P
0 g
s
.0625 .50001 m .06252 .50012 L .06252 .50015 L p .951 .775 .319 r
F P
0 g
s
.06252 .50012 m .0625 .50001 L .0625 .50001 L p .951 .776 .32 r
F P
0 g
s
.71874 .12111 m .71863 .12107 L .71861 .12105 L p .006 .451 .867 r
F P
0 g
s
.71863 .12107 m .71874 .12111 L .71874 .12111 L p .007 .451 .867 r
F P
0 g
s
.71876 .87888 m .71885 .87881 L .71888 .87879 L p .004 0 0 r
F P
0 g
s
.71885 .87881 m .71876 .87888 L .71875 .87888 L p .005 0 0 r
F P
0 g
s
.06252 .49988 m .0625 .49999 L .0625 .49999 L p .951 .777 .321 r
F P
0 g
s
.0625 .49999 m .06252 .49985 L .06252 .49988 L p .951 .777 .321 r
F P
0 g
s
.71863 .87893 m .71874 .87889 L .71874 .87889 L p .006 0 0 r
F P
0 g
s
.71874 .87889 m .71861 .87895 L .71863 .87893 L p .006 0 0 r
F P
0 g
s
.71885 .12119 m .71876 .12112 L .71876 .12112 L p .004 .449 .866 r
F P
0 g
s
.71876 .12112 m .71888 .12121 L .71885 .12119 L p .004 .449 .866 r
F P
0 g
s
.71874 .12111 m .71861 .12105 L .71859 .12104 L p .005 .451 .866 r
F P
0 g
s
.71861 .12105 m .71874 .12111 L .71874 .12111 L p .006 .451 .867 r
F P
0 g
s
.06252 .49985 m .0625 .49999 L .0625 .49999 L p .95 .777 .321 r
F P
0 g
s
.0625 .49999 m .06251 .49982 L .06252 .49985 L p .95 .777 .321 r
F P
0 g
s
.71876 .87888 m .71888 .87879 L .7189 .87878 L p .003 0 0 r
F P
0 g
s
.71888 .87879 m .71876 .87888 L .71876 .87888 L p .004 0 0 r
F P
0 g
s
.71888 .12121 m .71876 .12112 L .71876 .12112 L p .003 .448 .865 r
F P
0 g
s
.71876 .12112 m .7189 .12122 L .71888 .12121 L p .003 .448 .865 r
F P
0 g
s
.71861 .87895 m .71874 .87889 L .71874 .87889 L p .005 0 0 r
F P
0 g
s
.71874 .87889 m .71859 .87896 L .71861 .87895 L p .005 0 0 r
F P
0 g
s
.0625 .50001 m .06252 .50015 L .06251 .50018 L p .95 .775 .318 r
F P
0 g
s
.06252 .50015 m .0625 .50001 L .0625 .50001 L p .951 .775 .319 r
F P
0 g
s
.06254 .50331 m .0625 .50105 L .06252 .50105 L p .948 .758 .296 r
F P
0 g
s
.0625 .50021 m .06252 .50105 L .0625 .50105 L p .949 .769 .309 r
F P
0 g
s
.06252 .50105 m .0625 .50021 L .06251 .5002 L p .951 .771 .314 r
F P
0 g
s
.71965 .12166 m .71893 .12122 L .71893 .12122 L p 0 .439 .86 r
F P
0 g
s
.71893 .12122 m .71966 .12163 L .71965 .12166 L p 0 .439 .86 r
F P
0 g
s
.06252 .49895 m .0625 .49979 L .0625 .49979 L p .949 .78 .323 r
F P
0 g
s
.0625 .49979 m .0625 .49895 L .06252 .49895 L p .949 .78 .323 r
F P
0 g
s
.72159 .8772 m .71966 .87837 L .71965 .87834 L p 0 0 0 r
F P
0 g
s
.71893 .87878 m .71965 .87834 L .71966 .87837 L p 0 0 0 r
F P
0 g
s
.71965 .87834 m .71893 .87878 L .71892 .87878 L p 0 0 0 r
F P
0 g
s
.71783 .87939 m .71857 .87899 L .71857 .87899 L p .006 0 0 r
F P
0 g
s
.71857 .87899 m .71784 .87941 L .71783 .87939 L p .006 0 0 r
F P
0 g
s
.71587 .11949 m .71784 .12059 L .71783 .12061 L p .018 .47 .874 r
F P
0 g
s
.71857 .12101 m .71783 .12061 L .71784 .12059 L p .006 .455 .868 r
F P
0 g
s
.71783 .12061 m .71857 .12101 L .71857 .12102 L p .012 .458 .87 r
F P
0 g
s
.71859 .87896 m .71874 .87889 L .71874 .87889 L p .004 0 0 r
F P
0 g
s
.71874 .87889 m .71857 .87898 L .71859 .87896 L p .004 0 0 r
F P
0 g
s
.06251 .49982 m .0625 .49999 L .0625 .49999 L p .95 .777 .32 r
F P
0 g
s
.0625 .49999 m .06251 .4998 L .06251 .49982 L p .95 .777 .32 r
F P
0 g
s
.7189 .12122 m .71876 .12112 L .71876 .12112 L p .001 .447 .864 r
F P
0 g
s
.71876 .12112 m .71892 .12122 L .7189 .12122 L p .001 .447 .864 r
F P
0 g
s
.71876 .87888 m .7189 .87878 L .71892 .87878 L p .001 0 0 r
F P
0 g
s
.7189 .87878 m .71876 .87888 L .71876 .87888 L p .003 0 0 r
F P
0 g
s
.71874 .12111 m .71859 .12104 L .71857 .12102 L p .004 .45 .866 r
F P
0 g
s
.71859 .12104 m .71874 .12111 L .71874 .12111 L p .005 .451 .866 r
F P
0 g
s
.0625 .50001 m .06251 .50018 L .06251 .5002 L p .95 .774 .317 r
F P
0 g
s
.06251 .50018 m .0625 .50001 L .0625 .50001 L p .95 .775 .318 r
F P
0 g
s
.71857 .87898 m .71874 .87889 L .71874 .87889 L p .003 0 0 r
F P
0 g
s
.71874 .87889 m .71857 .87899 L .71857 .87898 L p .003 0 0 r
F P
0 g
s
.06251 .4998 m .0625 .49999 L .0625 .49999 L p .949 .776 .319 r
F P
0 g
s
.0625 .49999 m .0625 .49979 L .06251 .4998 L p .949 .776 .319 r
F P
0 g
s
.71892 .12122 m .71876 .12112 L .71876 .12112 L p 0 .446 .864 r
F P
0 g
s
.71876 .12112 m .71893 .12122 L .71892 .12122 L p 0 .446 .864 r
F P
0 g
s
.71874 .12111 m .71857 .12102 L .71857 .12101 L p .003 .45 .865 r
F P
0 g
s
.71857 .12102 m .71874 .12111 L .71874 .12111 L p .004 .45 .866 r
F P
0 g
s
.71876 .87888 m .71892 .87878 L .71893 .87878 L p 0 0 0 r
F P
0 g
s
.71892 .87878 m .71876 .87888 L .71876 .87888 L p .001 0 0 r
F P
0 g
s
.0625 .50001 m .06251 .5002 L .0625 .50021 L p .949 .774 .316 r
F P
0 g
s
.06251 .5002 m .0625 .50001 L .0625 .50001 L p .95 .774 .317 r
F P
0 g
s
.0625 .49979 m .0625 .49999 L .0625 .49999 L p .949 .776 .318 r
F P
0 g
s
.0625 .49999 m .0625 .49979 L .0625 .49979 L p .949 .776 .318 r
F P
0 g
s
.71857 .87899 m .71874 .87889 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71857 .87899 L .71857 .87899 L p .001 0 0 r
F P
0 g
s
.71893 .12122 m .71876 .12112 L .71876 .12112 L p 0 .445 .863 r
F P
0 g
s
.71876 .12112 m .71893 .12122 L .71893 .12122 L p 0 .445 .863 r
F P
0 g
s
.0625 .50105 m .0625 .50021 L .0625 .50021 L p .949 .769 .309 r
F P
0 g
s
.0625 .50001 m .0625 .50021 L .0625 .50021 L p .949 .773 .315 r
F P
0 g
s
.0625 .50021 m .0625 .50001 L .0625 .50001 L p .949 .774 .316 r
F P
0 g
s
.71966 .87837 m .71893 .87878 L .71893 .87878 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71893 .87878 L .71893 .87878 L p 0 0 0 r
F P
0 g
s
.71893 .87878 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71784 .12059 m .71857 .12101 L .71857 .12101 L p .006 .455 .868 r
F P
0 g
s
.71874 .12111 m .71857 .12101 L .71857 .12101 L p .001 .449 .865 r
F P
0 g
s
.71857 .12101 m .71874 .12111 L .71874 .12111 L p .003 .45 .865 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71875 .87888 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71875 .87888 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71875 .87889 L closepath p .001 0 0 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p .001 .448 .864 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71875 .87888 L closepath p .001 0 0 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71874 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .50001 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71876 .87888 L closepath p .001 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p .001 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71875 .12112 L closepath p .001 .447 .864 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p .001 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p .001 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .448 .864 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71893 .87878 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.0625 .50021 m .0625 .50001 L .0625 .50001 L p .949 .773 .315 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .774 .316 r
F P
0 g
s
.71857 .12101 m .71874 .12111 L .71874 .12111 L p .001 .449 .865 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71875 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71875 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71875 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.45427 .9351 m
.5 .9375 L
s
.40904 .92794 m
.45427 .9351 L
s
.36481 .91609 m
.40904 .92794 L
s
.32205 .89968 m
.36481 .91609 L
s
.28125 .87889 m
.32205 .89968 L
s
.24284 .85394 m
.28125 .87889 L
s
.20726 .82513 m
.24284 .85394 L
s
.17487 .79274 m
.20726 .82513 L
s
.14606 .75716 m
.17487 .79274 L
s
.12111 .71875 m
.14606 .75716 L
s
.10032 .67795 m
.12111 .71875 L
s
.08391 .63519 m
.10032 .67795 L
s
.07206 .59096 m
.08391 .63519 L
s
.0649 .54573 m
.07206 .59096 L
s
.063 .50945 m
.06317 .5127 L
s
.06317 .5127 m
.0649 .54573 L
s
.063 .49055 m
.06317 .4873 L
s
.06317 .4873 m
.0649 .45427 L
s
.0649 .45427 m
.07206 .40904 L
s
.08391 .36481 m
.07206 .40904 L
s
.10032 .32205 m
.08391 .36481 L
s
.12111 .28125 m
.10032 .32205 L
s
.14606 .24284 m
.12111 .28125 L
s
.17487 .20726 m
.14606 .24284 L
s
.20726 .17487 m
.17487 .20726 L
s
.24284 .14606 m
.20726 .17487 L
s
.28125 .12111 m
.24284 .14606 L
s
.32205 .10032 m
.28125 .12111 L
s
.36481 .08391 m
.32205 .10032 L
s
.40904 .07206 m
.36481 .08391 L
s
.45427 .0649 m
.40904 .07206 L
s
.5 .0625 m
.45427 .0649 L
s
.54573 .9351 m
.5 .9375 L
s
.59096 .92794 m
.54573 .9351 L
s
.63519 .91609 m
.59096 .92794 L
s
.67795 .89968 m
.63519 .91609 L
s
.70742 .88466 m
.71032 .88318 L
s
.70038 .88825 m
.70742 .88466 L
s
.67795 .89968 m
.70038 .88825 L
s
.72669 .87373 m
.72941 .87196 L
s
.72941 .87196 m
.73604 .86765 L
s
.73604 .86765 m
.75716 .85394 L
s
.75716 .85394 m
.79274 .82513 L
s
.82513 .79274 m
.79274 .82513 L
s
.85394 .75716 m
.82513 .79274 L
s
.87889 .71875 m
.85394 .75716 L
s
.89968 .67795 m
.87889 .71875 L
s
.91609 .63519 m
.89968 .67795 L
s
.92794 .59096 m
.91609 .63519 L
s
.9351 .54573 m
.92794 .59096 L
s
.9375 .5 m
.9351 .54573 L
s
.9351 .45427 m
.9375 .5 L
s
.92794 .40904 m
.9351 .45427 L
s
.91609 .36481 m
.92794 .40904 L
s
.89968 .32205 m
.91609 .36481 L
s
.87889 .28125 m
.89968 .32205 L
s
.85394 .24284 m
.87889 .28125 L
s
.82513 .20726 m
.85394 .24284 L
s
.79274 .17487 m
.82513 .20726 L
s
.75716 .14606 m
.79274 .17487 L
s
.71875 .12111 m
.72538 .12542 L
s
.72669 .12627 m
.72941 .12804 L
s
.72941 .12804 m
.73604 .13235 L
s
.73604 .13235 m
.75716 .14606 L
s
.71171 .11752 m
.71875 .12111 L
s
.70742 .11534 m
.71032 .11682 L
s
.70038 .11175 m
.70742 .11534 L
s
.67795 .10032 m
.70038 .11175 L
s
.63519 .08391 m
.67795 .10032 L
s
.59096 .07206 m
.63519 .08391 L
s
.54573 .0649 m
.59096 .07206 L
s
.5 .0625 m
.54573 .0649 L
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71875 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71171 .88248 m
.71875 .87889 L
s
.71875 .87889 m
.72538 .87458 L
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .948 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .49999 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m
.06291 .5079 L
s
.0625 .5 m
.06291 .4921 L
s
.71858 .12101 m .71874 .12111 L .71874 .12111 L p 0 .448 .864 r
F P
0 g
s
.71874 .12111 m .71857 .12101 L .71858 .12101 L p 0 .448 .864 r
F P
0 g
s
.71893 .87879 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71893 .87878 L .71893 .87879 L p 0 0 0 r
F P
0 g
s
.06249 .5002 m .0625 .50001 L .0625 .50001 L p .948 .773 .313 r
F P
0 g
s
.0625 .50001 m .0625 .50021 L .06249 .5002 L p .948 .773 .313 r
F P
0 g
s
.71893 .12122 m .71876 .12112 L .71876 .12112 L p 0 .445 .862 r
F P
0 g
s
.0625 .49979 m .0625 .49999 L .0625 .49999 L p .948 .775 .317 r
F P
0 g
s
.71857 .87899 m .71874 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71874 .87889 m .71858 .87899 L .71857 .87899 L p 0 0 0 r
F P
0 g
s
.71858 .87899 m .71874 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .12112 m .71893 .12121 L .71893 .12122 L p 0 .445 .862 r
F P
0 g
s
.71893 .12121 m .71876 .12112 L .71876 .12112 L p 0 .444 .862 r
F P
0 g
s
.0625 .49999 m .06249 .4998 L .0625 .49979 L p .948 .775 .317 r
F P
0 g
s
.06249 .4998 m .0625 .49999 L .0625 .49999 L p .948 .775 .316 r
F P
0 g
s
.71891 .87881 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71893 .87879 L .71891 .87881 L p 0 0 0 r
F P
0 g
s
.7186 .12101 m .71874 .12111 L .71874 .12111 L p 0 .447 .863 r
F P
0 g
s
.71874 .12111 m .71858 .12101 L .7186 .12101 L p 0 .447 .863 r
F P
0 g
s
.06249 .50018 m .0625 .50001 L .0625 .50001 L p .948 .772 .312 r
F P
0 g
s
.0625 .50001 m .06249 .5002 L .06249 .50018 L p .948 .772 .312 r
F P
0 g
s
.71889 .87882 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71891 .87881 L .71889 .87882 L p 0 0 0 r
F P
0 g
s
.06248 .50015 m .0625 .50001 L .0625 .50001 L p .947 .772 .312 r
F P
0 g
s
.0625 .50001 m .06249 .50018 L .06248 .50015 L p .947 .772 .312 r
F P
0 g
s
.71862 .12102 m .71874 .12111 L .71874 .12111 L p 0 .447 .863 r
F P
0 g
s
.71874 .12111 m .7186 .12101 L .71862 .12102 L p 0 .447 .863 r
F P
0 g
s
.71874 .87889 m .7186 .87899 L .71858 .87899 L p 0 0 0 r
F P
0 g
s
.7186 .87899 m .71874 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .12112 m .71891 .12119 L .71893 .12121 L p 0 .444 .862 r
F P
0 g
s
.71891 .12119 m .71876 .12112 L .71876 .12112 L p 0 .443 .861 r
F P
0 g
s
.0625 .49999 m .06249 .49982 L .06249 .4998 L p .948 .775 .316 r
F P
0 g
s
.06249 .49982 m .0625 .49999 L .0625 .49999 L p .947 .774 .314 r
F P
0 g
s
.0625 .49999 m .06248 .49985 L .06249 .49982 L p .947 .774 .314 r
F P
0 g
s
.06248 .49985 m .0625 .49999 L .0625 .49999 L p .947 .774 .313 r
F P
0 g
s
.71887 .87884 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71889 .87882 L .71887 .87884 L p 0 0 0 r
F P
0 g
s
.71876 .12112 m .71889 .12118 L .71891 .12119 L p 0 .443 .861 r
F P
0 g
s
.71889 .12118 m .71876 .12112 L .71876 .12112 L p 0 .443 .861 r
F P
0 g
s
.71874 .87889 m .71862 .87898 L .7186 .87899 L p 0 0 0 r
F P
0 g
s
.71862 .87898 m .71874 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71865 .12103 m .71874 .12111 L .71874 .12111 L p 0 .446 .862 r
F P
0 g
s
.71874 .12111 m .71862 .12102 L .71865 .12103 L p 0 .446 .862 r
F P
0 g
s
.06248 .50012 m .0625 .50001 L .0625 .50001 L p .947 .772 .311 r
F P
0 g
s
.0625 .50001 m .06248 .50015 L .06248 .50012 L p .947 .772 .311 r
F P
0 g
s
.71874 .87889 m .71865 .87897 L .71862 .87898 L p 0 0 0 r
F P
0 g
s
.71865 .87897 m .71874 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .12112 m .71887 .12116 L .71889 .12118 L p 0 .443 .861 r
F P
0 g
s
.71887 .12116 m .71876 .12112 L .71876 .12112 L p 0 .443 .861 r
F P
0 g
s
.06248 .50008 m .0625 .50001 L .0625 .50001 L p .946 .772 .311 r
F P
0 g
s
.0625 .50001 m .06248 .50012 L .06248 .50008 L p .946 .772 .311 r
F P
0 g
s
.0625 .49999 m .06248 .49988 L .06248 .49985 L p .947 .774 .313 r
F P
0 g
s
.06248 .49988 m .0625 .49999 L .0625 .49999 L p .946 .773 .312 r
F P
0 g
s
.71869 .12105 m .71875 .12111 L .71874 .12111 L p 0 .445 .862 r
F P
0 g
s
.71874 .12111 m .71865 .12103 L .71869 .12105 L p 0 .445 .862 r
F P
0 g
s
.71884 .87886 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71887 .87884 L .71884 .87886 L p 0 0 0 r
F P
0 g
s
.06248 .50004 m .0625 .5 L .0625 .50001 L p .946 .772 .31 r
F P
0 g
s
.0625 .50001 m .06248 .50008 L .06248 .50004 L p .946 .772 .31 r
F P
0 g
s
.71872 .12107 m .71875 .12111 L .71875 .12111 L p 0 .444 .861 r
F P
0 g
s
.71875 .12111 m .71869 .12105 L .71872 .12107 L p 0 .444 .861 r
F P
0 g
s
.7188 .87889 m .71875 .87889 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71884 .87886 L .7188 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .12112 m .71884 .12114 L .71887 .12116 L p 0 .443 .861 r
F P
0 g
s
.71884 .12114 m .71876 .12112 L .71875 .12111 L p 0 .443 .861 r
F P
0 g
s
.0625 .49999 m .06248 .49992 L .06248 .49988 L p .946 .773 .312 r
F P
0 g
s
.06248 .49992 m .0625 .49999 L .0625 .5 L p .946 .773 .312 r
F P
0 g
s
.71875 .87889 m .71869 .87895 L .71865 .87897 L p 0 0 0 r
F P
0 g
s
.71869 .87895 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.0625 .5 m .06248 .49996 L .06248 .49992 L p .946 .773 .312 r
F P
0 g
s
.06248 .49996 m .0625 .5 L .0625 .5 L p .946 .772 .311 r
F P
0 g
s
.06247 .5 m .0625 .5 L .0625 .5 L p .946 .772 .311 r
F P
0 g
s
.0625 .5 m .06248 .50004 L .06247 .5 L p .946 .772 .311 r
F P
0 g
s
.71875 .87889 m .71872 .87893 L .71869 .87895 L p 0 0 0 r
F P
0 g
s
.71872 .87893 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .12111 m .7188 .12111 L .71884 .12114 L p 0 .443 .861 r
F P
0 g
s
.7188 .12111 m .71875 .12111 L .71875 .12111 L p 0 .443 .861 r
F P
0 g
s
.71876 .87891 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .7188 .87889 L .71876 .87891 L p 0 0 0 r
F P
0 g
s
.71876 .12109 m .71875 .12111 L .71875 .12111 L p 0 .444 .861 r
F P
0 g
s
.71875 .12111 m .71872 .12107 L .71876 .12109 L p 0 .444 .861 r
F P
0 g
s
.0625 .5 m .06247 .5 L .06248 .49996 L p .946 .772 .311 r
F P
0 g
s
.71875 .87889 m .71876 .87891 L .71872 .87893 L p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12109 L .7188 .12111 L p 0 .443 .861 r
F P
0 g
s
.71784 .87941 m .71857 .87899 L .71858 .87899 L p 0 0 0 r
F P
0 g
s
.71966 .12163 m .71893 .12122 L .71893 .12121 L p 0 .436 .858 r
F P
0 g
s
.0625 .49895 m .0625 .49979 L .06249 .4998 L p .946 .778 .318 r
F P
0 g
s
.71963 .87841 m .71893 .87879 L .71893 .87878 L p 0 0 0 r
F P
0 g
s
.71893 .87878 m .71966 .87837 L .71963 .87841 L p 0 0 0 r
F P
0 g
s
.7179 .12059 m .71858 .12101 L .71857 .12101 L p 0 .452 .865 r
F P
0 g
s
.71857 .12101 m .71784 .12059 L .7179 .12059 L p 0 .452 .865 r
F P
0 g
s
.06247 .501 m .06249 .5002 L .0625 .50021 L p .946 .767 .304 r
F P
0 g
s
.0625 .50021 m .0625 .50105 L .06247 .501 L p .946 .767 .304 r
F P
0 g
s
.71799 .12061 m .7186 .12101 L .71858 .12101 L p 0 .448 .862 r
F P
0 g
s
.71858 .12101 m .7179 .12059 L .71799 .12061 L p 0 .448 .862 r
F P
0 g
s
.71957 .87848 m .71891 .87881 L .71893 .87879 L p 0 0 0 r
F P
0 g
s
.71893 .87879 m .71963 .87841 L .71957 .87848 L p 0 0 0 r
F P
0 g
s
.06249 .4998 m .06247 .499 L .0625 .49895 L p .946 .778 .318 r
F P
0 g
s
.06247 .499 m .06249 .4998 L .06249 .49982 L p .944 .776 .313 r
F P
0 g
s
.71858 .87899 m .7179 .87941 L .71784 .87941 L p 0 0 0 r
F P
0 g
s
.7179 .87941 m .71858 .87899 L .7186 .87899 L p 0 0 0 r
F P
0 g
s
.71893 .12121 m .71963 .12159 L .71966 .12163 L p 0 .436 .858 r
F P
0 g
s
.71963 .12159 m .71893 .12121 L .71891 .12119 L p 0 .433 .855 r
F P
0 g
s
.06244 .50091 m .06249 .50018 L .06249 .5002 L p .944 .765 .3 r
F P
0 g
s
.06249 .5002 m .06247 .501 L .06244 .50091 L p .944 .765 .3 r
F P
0 g
s
.06249 .49982 m .06244 .49909 L .06247 .499 L p .944 .776 .313 r
F P
0 g
s
.06244 .49909 m .06249 .49982 L .06248 .49985 L p .942 .774 .308 r
F P
0 g
s
.7186 .87899 m .71799 .87939 L .7179 .87941 L p 0 0 0 r
F P
0 g
s
.71799 .87939 m .7186 .87899 L .71862 .87898 L p 0 0 0 r
F P
0 g
s
.71891 .12119 m .71957 .12152 L .71963 .12159 L p 0 .433 .855 r
F P
0 g
s
.71957 .12152 m .71891 .12119 L .71889 .12118 L p 0 .431 .853 r
F P
0 g
s
.71947 .87856 m .71889 .87882 L .71891 .87881 L p 0 0 0 r
F P
0 g
s
.71891 .87881 m .71957 .87848 L .71947 .87856 L p 0 0 0 r
F P
0 g
s
.71811 .12065 m .71862 .12102 L .7186 .12101 L p 0 .445 .859 r
F P
0 g
s
.7186 .12101 m .71799 .12061 L .71811 .12065 L p 0 .445 .859 r
F P
0 g
s
.06242 .50078 m .06248 .50015 L .06249 .50018 L p .942 .764 .296 r
F P
0 g
s
.06249 .50018 m .06244 .50091 L .06242 .50078 L p .942 .764 .296 r
F P
0 g
s
.06254 .49669 m .0625 .49895 L .06247 .499 L p .941 .785 .322 r
F P
0 g
s
.71587 .88051 m .71784 .87941 L .7179 .87941 L p 0 0 0 r
F P
0 g
s
.72159 .1228 m .71966 .12163 L .71963 .12159 L p 0 .415 .846 r
F P
0 g
s
.06245 .50316 m .06247 .501 L .0625 .50105 L p .941 .752 .282 r
F P
0 g
s
.0625 .50105 m .06254 .50331 L .06245 .50316 L p .941 .752 .282 r
F P
0 g
s
.72151 .87734 m .71963 .87841 L .71966 .87837 L p 0 0 0 r
F P
0 g
s
.71966 .87837 m .72159 .8772 L .72151 .87734 L p 0 0 0 r
F P
0 g
s
.71603 .11949 m .7179 .12059 L .71784 .12059 L p 0 .46 .866 r
F P
0 g
s
.71784 .12059 m .71587 .11949 L .71603 .11949 L p 0 .46 .866 r
F P
0 g
s
.71862 .87898 m .71811 .87935 L .71799 .87939 L p 0 0 0 r
F P
0 g
s
.71811 .87935 m .71862 .87898 L .71865 .87897 L p 0 0 0 r
F P
0 g
s
.71889 .12118 m .71947 .12144 L .71957 .12152 L p 0 .431 .853 r
F P
0 g
s
.71947 .12144 m .71889 .12118 L .71887 .12116 L p 0 .43 .851 r
F P
0 g
s
.06248 .49985 m .06242 .49922 L .06244 .49909 L p .942 .774 .308 r
F P
0 g
s
.06242 .49922 m .06248 .49985 L .06248 .49988 L p .94 .771 .304 r
F P
0 g
s
.71826 .12072 m .71865 .12103 L .71862 .12102 L p 0 .441 .856 r
F P
0 g
s
.71862 .12102 m .71811 .12065 L .71826 .12072 L p 0 .441 .856 r
F P
0 g
s
.71933 .87866 m .71887 .87884 L .71889 .87882 L p 0 0 0 r
F P
0 g
s
.71889 .87882 m .71947 .87856 L .71933 .87866 L p 0 0 0 r
F P
0 g
s
.0624 .50062 m .06248 .50012 L .06248 .50015 L p .94 .763 .294 r
F P
0 g
s
.06248 .50015 m .06242 .50078 L .0624 .50062 L p .94 .763 .294 r
F P
0 g
s
.71918 .87877 m .71884 .87886 L .71887 .87884 L p 0 0 0 r
F P
0 g
s
.71887 .87884 m .71933 .87866 L .71918 .87877 L p 0 0 0 r
F P
0 g
s
.71843 .1208 m .71869 .12105 L .71865 .12103 L p 0 .437 .854 r
F P
0 g
s
.71865 .12103 m .71826 .12072 L .71843 .1208 L p 0 .437 .854 r
F P
0 g
s
.06239 .50043 m .06248 .50008 L .06248 .50012 L p .938 .763 .292 r
F P
0 g
s
.06248 .50012 m .0624 .50062 L .06239 .50043 L p .938 .763 .292 r
F P
0 g
s
.06248 .49988 m .0624 .49938 L .06242 .49922 L p .94 .771 .304 r
F P
0 g
s
.0624 .49938 m .06248 .49988 L .06248 .49992 L p .938 .769 .299 r
F P
0 g
s
.71865 .87897 m .71826 .87928 L .71811 .87935 L p 0 0 0 r
F P
0 g
s
.71826 .87928 m .71865 .87897 L .71869 .87895 L p 0 0 0 r
F P
0 g
s
.71887 .12116 m .71933 .12134 L .71947 .12144 L p 0 .43 .851 r
F P
0 g
s
.71933 .12134 m .71887 .12116 L .71884 .12114 L p 0 .429 .85 r
F P
0 g
s
.06248 .49992 m .06239 .49957 L .0624 .49938 L p .938 .769 .299 r
F P
0 g
s
.06239 .49957 m .06248 .49992 L .06248 .49996 L p .937 .767 .296 r
F P
0 g
s
.06238 .50022 m .06248 .50004 L .06248 .50008 L p .937 .763 .291 r
F P
0 g
s
.06248 .50008 m .06239 .50043 L .06238 .50022 L p .937 .763 .291 r
F P
0 g
s
.719 .87888 m .7188 .87889 L .71884 .87886 L p 0 0 0 r
F P
0 g
s
.71884 .87886 m .71918 .87877 L .719 .87888 L p 0 0 0 r
F P
0 g
s
.71869 .87895 m .71843 .8792 L .71826 .87928 L p 0 0 0 r
F P
0 g
s
.71843 .8792 m .71869 .87895 L .71872 .87893 L p 0 0 0 r
F P
0 g
s
.71862 .1209 m .71872 .12107 L .71869 .12105 L p 0 .435 .852 r
F P
0 g
s
.71869 .12105 m .71843 .1208 L .71862 .1209 L p 0 .435 .852 r
F P
0 g
s
.71884 .12114 m .71918 .12123 L .71933 .12134 L p 0 .429 .85 r
F P
0 g
s
.71918 .12123 m .71884 .12114 L .7188 .12111 L p 0 .429 .85 r
F P
0 g
s
.71881 .87899 m .71876 .87891 L .7188 .87889 L p 0 0 0 r
F P
0 g
s
.7188 .87889 m .719 .87888 L .71881 .87899 L p 0 0 0 r
F P
0 g
s
.71881 .12101 m .71876 .12109 L .71872 .12107 L p 0 .432 .85 r
F P
0 g
s
.71872 .12107 m .71862 .1209 L .71881 .12101 L p 0 .432 .85 r
F P
0 g
s
.71872 .87893 m .71862 .8791 L .71843 .8792 L p 0 0 0 r
F P
0 g
s
.71862 .8791 m .71872 .87893 L .71876 .87891 L p 0 0 0 r
F P
0 g
s
.7188 .12111 m .719 .12112 L .71918 .12123 L p 0 .429 .85 r
F P
0 g
s
.719 .12112 m .7188 .12111 L .71876 .12109 L p 0 .43 .85 r
F P
0 g
s
.06238 .5 m .06247 .5 L .06248 .50004 L p .936 .764 .292 r
F P
0 g
s
.06248 .50004 m .06238 .50022 L .06238 .5 L p .936 .764 .292 r
F P
0 g
s
.06248 .49996 m .06238 .49978 L .06239 .49957 L p .937 .767 .296 r
F P
0 g
s
.06238 .49978 m .06248 .49996 L .06247 .5 L p .936 .765 .293 r
F P
0 g
s
.71876 .87891 m .71881 .87899 L .71862 .8791 L p 0 0 0 r
F P
0 g
s
.71876 .12109 m .71881 .12101 L .719 .12112 L p 0 .43 .85 r
F P
0 g
s
.06247 .5 m .06238 .5 L .06238 .49978 L p .936 .765 .293 r
F P
0 g
s
.7179 .87941 m .71603 .88051 L .71587 .88051 L p 0 0 0 r
F P
0 g
s
.71603 .88051 m .7179 .87941 L .71799 .87939 L p 0 0 0 r
F P
0 g
s
.72131 .87755 m .71957 .87848 L .71963 .87841 L p 0 0 0 r
F P
0 g
s
.71963 .87841 m .72151 .87734 L .72131 .87755 L p 0 0 0 r
F P
0 g
s
.71963 .12159 m .72151 .12266 L .72159 .1228 L p 0 .415 .846 r
F P
0 g
s
.72151 .12266 m .71963 .12159 L .71957 .12152 L p 0 .407 .838 r
F P
0 g
s
.71632 .11957 m .71799 .12061 L .7179 .12059 L p 0 .45 .857 r
F P
0 g
s
.7179 .12059 m .71603 .11949 L .71632 .11957 L p 0 .45 .857 r
F P
0 g
s
.06238 .50288 m .06244 .50091 L .06247 .501 L p .934 .747 .27 r
F P
0 g
s
.06247 .501 m .06245 .50316 L .06238 .50288 L p .934 .747 .27 r
F P
0 g
s
.06247 .499 m .06245 .49684 L .06254 .49669 L p .941 .785 .322 r
F P
0 g
s
.06245 .49684 m .06247 .499 L .06244 .49909 L p .934 .778 .308 r
F P
0 g
s
.06282 .49195 m .06254 .49669 L .06245 .49684 L p .93 .797 .33 r
F P
0 g
s
.06261 .5077 m .06245 .50316 L .06254 .50331 L p .93 .722 .239 r
F P
0 g
s
.06254 .50331 m .06282 .50805 L .06261 .5077 L p .93 .722 .239 r
F P
0 g
s
.71162 .88264 m .71587 .88051 L .71603 .88051 L p .001 0 0 r
F P
0 g
s
.72537 .87494 m .72151 .87734 L .72159 .8772 L p 0 0 0 r
F P
0 g
s
.72159 .8772 m .72556 .87458 L .72537 .87494 L p 0 0 0 r
F P
0 g
s
.72556 .12542 m .72159 .1228 L .72151 .12266 L p 0 .374 .821 r
F P
0 g
s
.71202 .11736 m .71603 .11949 L .71587 .11949 L p .001 .476 .866 r
F P
0 g
s
.71587 .11949 m .71162 .11736 L .71202 .11736 L p .001 .476 .866 r
F P
0 g
s
.0623 .50247 m .06242 .50078 L .06244 .50091 L p .927 .743 .259 r
F P
0 g
s
.06244 .50091 m .06238 .50288 L .0623 .50247 L p .927 .743 .259 r
F P
0 g
s
.71799 .87939 m .71632 .88043 L .71603 .88051 L p 0 0 0 r
F P
0 g
s
.71632 .88043 m .71799 .87939 L .71811 .87935 L p 0 0 0 r
F P
0 g
s
.71957 .12152 m .72131 .12245 L .72151 .12266 L p 0 .407 .838 r
F P
0 g
s
.72131 .12245 m .71957 .12152 L .71947 .12144 L p 0 .401 .831 r
F P
0 g
s
.72099 .87782 m .71947 .87856 L .71957 .87848 L p 0 0 0 r
F P
0 g
s
.71957 .87848 m .72131 .87755 L .72099 .87782 L p 0 0 0 r
F P
0 g
s
.06244 .49909 m .06238 .49712 L .06245 .49684 L p .934 .778 .308 r
F P
0 g
s
.06238 .49712 m .06244 .49909 L .06242 .49922 L p .927 .771 .293 r
F P
0 g
s
.71671 .11971 m .71811 .12065 L .71799 .12061 L p 0 .439 .848 r
F P
0 g
s
.71799 .12061 m .71632 .11957 L .71671 .11971 L p 0 .439 .848 r
F P
0 g
s
.06225 .50196 m .0624 .50062 L .06242 .50078 L p .92 .74 .251 r
F P
0 g
s
.06242 .50078 m .0623 .50247 L .06225 .50196 L p .92 .74 .251 r
F P
0 g
s
.06242 .49922 m .0623 .49753 L .06238 .49712 L p .927 .771 .293 r
F P
0 g
s
.0623 .49753 m .06242 .49922 L .0624 .49938 L p .92 .763 .279 r
F P
0 g
s
.71718 .11992 m .71826 .12072 L .71811 .12065 L p 0 .428 .84 r
F P
0 g
s
.71811 .12065 m .71671 .11971 L .71718 .11992 L p 0 .428 .84 r
F P
0 g
s
.71811 .87935 m .71671 .88029 L .71632 .88043 L p 0 0 0 r
F P
0 g
s
.71671 .88029 m .71811 .87935 L .71826 .87928 L p 0 0 0 r
F P
0 g
s
.71947 .12144 m .72099 .12218 L .72131 .12245 L p 0 .401 .831 r
F P
0 g
s
.72099 .12218 m .71947 .12144 L .71933 .12134 L p 0 .396 .825 r
F P
0 g
s
.72057 .87813 m .71933 .87866 L .71947 .87856 L p 0 0 0 r
F P
0 g
s
.71947 .87856 m .72099 .87782 L .72057 .87813 L p 0 0 0 r
F P
0 g
s
.06347 .51588 m .06261 .5077 L .06282 .50805 L p .907 .668 .163 r
F P
0 g
s
.06282 .50805 m .06389 .51659 L .06347 .51588 L p .907 .668 .163 r
F P
0 g
s
.70452 .11401 m .71202 .11736 L .71162 .11736 L p .002 .501 .864 r
F P
0 g
s
.71162 .11736 m .70369 .11403 L .70452 .11401 L p .002 .501 .864 r
F P
0 g
s
.73202 .87011 m .72537 .87494 L .72556 .87458 L p 0 0 0 r
F P
0 g
s
.72556 .87458 m .73242 .86939 L .73202 .87011 L p 0 0 0 r
F P
0 g
s
.70369 .88597 m .71162 .88264 L .71202 .88264 L p .002 0 0 r
F P
0 g
s
.71603 .88051 m .71202 .88264 L .71162 .88264 L p .001 0 0 r
F P
0 g
s
.73242 .13061 m .72556 .12542 L .72537 .12506 L p 0 .302 .774 r
F P
0 g
s
.72151 .12266 m .72537 .12506 L .72556 .12542 L p 0 .374 .821 r
F P
0 g
s
.06389 .48341 m .06282 .49195 L .06261 .4923 L p .907 .813 .341 r
F P
0 g
s
.06245 .49684 m .06261 .4923 L .06282 .49195 L p .93 .797 .33 r
F P
0 g
s
.71826 .87928 m .71718 .88008 L .71671 .88029 L p 0 0 0 r
F P
0 g
s
.71718 .88008 m .71826 .87928 L .71843 .8792 L p 0 0 0 r
F P
0 g
s
.71933 .12134 m .72057 .12187 L .72099 .12218 L p 0 .396 .825 r
F P
0 g
s
.72057 .12187 m .71933 .12134 L .71918 .12123 L p 0 .394 .821 r
F P
0 g
s
.0624 .49938 m .06225 .49804 L .0623 .49753 L p .92 .763 .279 r
F P
0 g
s
.06225 .49804 m .0624 .49938 L .06239 .49957 L p .915 .756 .267 r
F P
0 g
s
.71773 .12018 m .71843 .1208 L .71826 .12072 L p 0 .418 .832 r
F P
0 g
s
.71826 .12072 m .71718 .11992 L .71773 .12018 L p 0 .418 .832 r
F P
0 g
s
.72007 .87847 m .71918 .87877 L .71933 .87866 L p 0 0 0 r
F P
0 g
s
.71933 .87866 m .72057 .87813 L .72007 .87847 L p 0 0 0 r
F P
0 g
s
.0622 .50135 m .06239 .50043 L .0624 .50062 L p .915 .738 .245 r
F P
0 g
s
.0624 .50062 m .06225 .50196 L .0622 .50135 L p .915 .738 .245 r
F P
0 g
s
.71843 .8792 m .71773 .87982 L .71718 .88008 L p 0 0 0 r
F P
0 g
s
.71773 .87982 m .71843 .8792 L .71862 .8791 L p 0 0 0 r
F P
0 g
s
.06218 .50069 m .06238 .50022 L .06239 .50043 L p .911 .739 .243 r
F P
0 g
s
.06239 .50043 m .0622 .50135 L .06218 .50069 L p .911 .739 .243 r
F P
0 g
s
.71831 .12049 m .71862 .1209 L .71843 .1208 L p 0 .409 .826 r
F P
0 g
s
.71843 .1208 m .71773 .12018 L .71831 .12049 L p 0 .409 .826 r
F P
0 g
s
.71918 .12123 m .72007 .12153 L .72057 .12187 L p 0 .394 .821 r
F P
0 g
s
.72007 .12153 m .71918 .12123 L .719 .12112 L p 0 .394 .819 r
F P
0 g
s
.71951 .87882 m .719 .87888 L .71918 .87877 L p 0 0 0 r
F P
0 g
s
.71918 .87877 m .72007 .87847 L .71951 .87882 L p 0 0 0 r
F P
0 g
s
.06239 .49957 m .0622 .49865 L .06225 .49804 L p .915 .756 .267 r
F P
0 g
s
.0622 .49865 m .06239 .49957 L .06238 .49978 L p .911 .749 .256 r
F P
0 g
s
.72487 .87545 m .72131 .87755 L .72151 .87734 L p 0 0 0 r
F P
0 g
s
.72151 .87734 m .72537 .87494 L .72487 .87545 L p 0 0 0 r
F P
0 g
s
.71202 .88264 m .71603 .88051 L .71632 .88043 L p 0 0 0 r
F P
0 g
s
.06242 .50702 m .06238 .50288 L .06245 .50316 L p .911 .709 .209 r
F P
0 g
s
.06245 .50316 m .06261 .5077 L .06242 .50702 L p .911 .709 .209 r
F P
0 g
s
.71271 .11753 m .71632 .11957 L .71603 .11949 L p 0 .451 .845 r
F P
0 g
s
.71603 .11949 m .71202 .11736 L .71271 .11753 L p 0 .451 .845 r
F P
0 g
s
.06261 .4923 m .06245 .49684 L .06238 .49712 L p .911 .78 .296 r
F P
0 g
s
.72537 .12506 m .72151 .12266 L .72131 .12245 L p 0 .355 .801 r
F P
0 g
s
.06217 .5 m .06238 .5 L .06238 .50022 L p .909 .74 .244 r
F P
0 g
s
.06238 .50022 m .06218 .50069 L .06217 .5 L p .909 .74 .244 r
F P
0 g
s
.06238 .49978 m .06218 .49931 L .0622 .49865 L p .911 .749 .256 r
F P
0 g
s
.06218 .49931 m .06238 .49978 L .06238 .5 L p .909 .744 .249 r
F P
0 g
s
.71892 .87917 m .71881 .87899 L .719 .87888 L p 0 0 0 r
F P
0 g
s
.719 .87888 m .71951 .87882 L .71892 .87917 L p 0 0 0 r
F P
0 g
s
.71892 .12083 m .71881 .12101 L .71862 .1209 L p 0 .402 .821 r
F P
0 g
s
.71862 .1209 m .71831 .12049 L .71892 .12083 L p 0 .402 .821 r
F P
0 g
s
.719 .12112 m .71951 .12118 L .72007 .12153 L p 0 .394 .819 r
F P
0 g
s
.71951 .12118 m .719 .12112 L .71881 .12101 L p 0 .397 .819 r
F P
0 g
s
.71862 .8791 m .71831 .87951 L .71773 .87982 L p 0 0 0 r
F P
0 g
s
.71831 .87951 m .71862 .8791 L .71881 .87899 L p 0 0 0 r
F P
0 g
s
.06238 .5 m .06217 .5 L .06218 .49931 L p .909 .744 .249 r
F P
0 g
s
.71881 .87899 m .71892 .87917 L .71831 .87951 L p 0 0 0 r
F P
0 g
s
.71881 .12101 m .71892 .12083 L .71951 .12118 L p 0 .397 .819 r
F P
0 g
s
.72409 .87609 m .72099 .87782 L .72131 .87755 L p 0 0 0 r
F P
0 g
s
.72131 .87755 m .72487 .87545 L .72409 .87609 L p 0 0 0 r
F P
0 g
s
.71366 .11788 m .71671 .11971 L .71632 .11957 L p 0 .425 .822 r
F P
0 g
s
.71632 .11957 m .71271 .11753 L .71366 .11788 L p 0 .425 .822 r
F P
0 g
s
.06225 .50603 m .0623 .50247 L .06238 .50288 L p .892 .696 .183 r
F P
0 g
s
.06238 .50288 m .06242 .50702 L .06225 .50603 L p .892 .696 .183 r
F P
0 g
s
.72131 .12245 m .72487 .12455 L .72537 .12506 L p 0 .355 .801 r
F P
0 g
s
.72487 .12455 m .72131 .12245 L .72099 .12218 L p 0 .338 .783 r
F P
0 g
s
.71632 .88043 m .71271 .88247 L .71202 .88264 L p 0 0 0 r
F P
0 g
s
.71271 .88247 m .71632 .88043 L .71671 .88029 L p 0 0 0 r
F P
0 g
s
.06238 .49712 m .06242 .49298 L .06261 .4923 L p .911 .78 .296 r
F P
0 g
s
.06242 .49298 m .06238 .49712 L .0623 .49753 L p .892 .76 .261 r
F P
0 g
s
.74265 .14015 m .73242 .13061 L .73202 .12989 L p 0 .184 .691 r
F P
0 g
s
.72537 .12506 m .73202 .12989 L .73242 .13061 L p 0 .302 .774 r
F P
0 g
s
.69031 .89007 m .70369 .88597 L .70452 .88599 L p .004 0 0 r
F P
0 g
s
.71202 .88264 m .70452 .88599 L .70369 .88597 L p .002 0 0 r
F P
0 g
s
.06704 .46978 m .06389 .48341 L .06347 .48412 L p .858 .829 .356 r
F P
0 g
s
.06261 .4923 m .06347 .48412 L .06389 .48341 L p .907 .813 .341 r
F P
0 g
s
.74194 .86115 m .73202 .87011 L .73242 .86939 L p 0 0 0 r
F P
0 g
s
.73242 .86939 m .74265 .85985 L .74194 .86115 L p 0 0 0 r
F P
0 g
s
.6918 .1099 m .70452 .11401 L .70369 .11403 L p .004 .535 .849 r
F P
0 g
s
.70369 .11403 m .69031 .10993 L .6918 .1099 L p .004 .535 .849 r
F P
0 g
s
.06627 .52895 m .06347 .51588 L .06389 .51659 L p .858 .572 .041 r
F P
0 g
s
.06389 .51659 m .06704 .53022 L .06627 .52895 L p .858 .572 .041 r
F P
0 g
s
.06211 .50477 m .06225 .50196 L .0623 .50247 L p .873 .686 .161 r
F P
0 g
s
.0623 .50247 m .06225 .50603 L .06211 .50477 L p .873 .686 .161 r
F P
0 g
s
.72308 .87684 m .72057 .87813 L .72099 .87782 L p 0 0 0 r
F P
0 g
s
.72099 .87782 m .72409 .87609 L .72308 .87684 L p 0 0 0 r
F P
0 g
s
.71482 .11839 m .71718 .11992 L .71671 .11971 L p 0 .398 .799 r
F P
0 g
s
.71671 .11971 m .71366 .11788 L .71482 .11839 L p 0 .398 .799 r
F P
0 g
s
.71671 .88029 m .71366 .88212 L .71271 .88247 L p 0 0 0 r
F P
0 g
s
.71366 .88212 m .71671 .88029 L .71718 .88008 L p 0 0 0 r
F P
0 g
s
.72099 .12218 m .72409 .12391 L .72487 .12455 L p 0 .338 .783 r
F P
0 g
s
.72409 .12391 m .72099 .12218 L .72057 .12187 L p 0 .325 .766 r
F P
0 g
s
.0623 .49753 m .06225 .49397 L .06242 .49298 L p .892 .76 .261 r
F P
0 g
s
.06225 .49397 m .0623 .49753 L .06225 .49804 L p .873 .74 .227 r
F P
0 g
s
.70452 .88599 m .71202 .88264 L .71271 .88247 L p 0 0 0 r
F P
0 g
s
.731 .87116 m .72487 .87545 L .72537 .87494 L p 0 0 0 r
F P
0 g
s
.72537 .87494 m .73202 .87011 L .731 .87116 L p 0 0 0 r
F P
0 g
s
.73202 .12989 m .72537 .12506 L .72487 .12455 L p 0 .258 .729 r
F P
0 g
s
.70593 .11437 m .71271 .11753 L .71202 .11736 L p 0 .45 .815 r
F P
0 g
s
.71202 .11736 m .70452 .11401 L .70593 .11437 L p 0 .45 .815 r
F P
0 g
s
.06347 .48412 m .06261 .4923 L .06242 .49298 L p .863 .775 .272 r
F P
0 g
s
.06307 .51447 m .06242 .50702 L .06261 .5077 L p .863 .634 .1 r
F P
0 g
s
.06261 .5077 m .06347 .51588 L .06307 .51447 L p .863 .634 .1 r
F P
0 g
s
.71614 .11903 m .71773 .12018 L .71718 .11992 L p 0 .373 .778 r
F P
0 g
s
.71718 .11992 m .71482 .11839 L .71614 .11903 L p 0 .373 .778 r
F P
0 g
s
.72186 .87767 m .72007 .87847 L .72057 .87813 L p 0 0 0 r
F P
0 g
s
.72057 .87813 m .72308 .87684 L .72186 .87767 L p 0 0 0 r
F P
0 g
s
.06225 .49804 m .06211 .49523 L .06225 .49397 L p .873 .74 .227 r
F P
0 g
s
.06211 .49523 m .06225 .49804 L .0622 .49865 L p .857 .72 .196 r
F P
0 g
s
.71718 .88008 m .71482 .88161 L .71366 .88212 L p 0 0 0 r
F P
0 g
s
.71482 .88161 m .71718 .88008 L .71773 .87982 L p 0 0 0 r
F P
0 g
s
.062 .5033 m .0622 .50135 L .06225 .50196 L p .857 .68 .147 r
F P
0 g
s
.06225 .50196 m .06211 .50477 L .062 .5033 L p .857 .68 .147 r
F P
0 g
s
.72057 .12187 m .72308 .12316 L .72409 .12391 L p 0 .325 .766 r
F P
0 g
s
.72308 .12316 m .72057 .12187 L .72007 .12153 L p 0 .318 .753 r
F P
0 g
s
.06193 .50169 m .06218 .50069 L .0622 .50135 L p .845 .678 .14 r
F P
0 g
s
.0622 .50135 m .062 .5033 L .06193 .50169 L p .845 .678 .14 r
F P
0 g
s
.71757 .11978 m .71831 .12049 L .71773 .12018 L p 0 .35 .761 r
F P
0 g
s
.71773 .12018 m .71614 .11903 L .71757 .11978 L p 0 .35 .761 r
F P
0 g
s
.72049 .87853 m .71951 .87882 L .72007 .87847 L p 0 0 0 r
F P
0 g
s
.72007 .87847 m .72186 .87767 L .72049 .87853 L p 0 0 0 r
F P
0 g
s
.71773 .87982 m .71614 .88097 L .71482 .88161 L p 0 0 0 r
F P
0 g
s
.71614 .88097 m .71773 .87982 L .71831 .87951 L p 0 0 0 r
F P
0 g
s
.72007 .12153 m .72186 .12233 L .72308 .12316 L p 0 .318 .753 r
F P
0 g
s
.72186 .12233 m .72007 .12153 L .71951 .12118 L p 0 .316 .745 r
F P
0 g
s
.0622 .49865 m .062 .4967 L .06211 .49523 L p .857 .72 .196 r
F P
0 g
s
.062 .4967 m .0622 .49865 L .06218 .49931 L p .845 .703 .171 r
F P
0 g
s
.66968 .89326 m .69031 .89007 L .6918 .8901 L p .009 0 0 r
F P
0 g
s
.70452 .88599 m .6918 .8901 L .69031 .89007 L p .004 0 0 r
F P
0 g
s
.75574 .15642 m .74265 .14015 L .74194 .13885 L p 0 .002 .549 r
F P
0 g
s
.73202 .12989 m .74194 .13885 L .74265 .14015 L p 0 .184 .691 r
F P
0 g
s
.07334 .54765 m .06627 .52895 L .06704 .53022 L p .763 .415 0 r
F P
0 g
s
.06704 .53022 m .07458 .54968 L .07334 .54765 L p .763 .415 0 r
F P
0 g
s
.06347 .51588 m .06627 .52895 L .06554 .5264 L p .759 .495 0 r
F P
0 g
s
.06242 .50702 m .06307 .51447 L .06272 .51243 L p .813 .6 .042 r
F P
0 g
s
.06554 .5264 m .06307 .51447 L .06347 .51588 L p .759 .495 0 r
F P
0 g
s
.0649 .52269 m .06272 .51243 L .06307 .51447 L p 0 0 .185 r
F P
0 g
s
.07217 .54351 m .06554 .5264 L .06627 .52895 L p 0 0 .336 r
F P
0 g
s
.07458 .45032 m .06704 .46978 L .06627 .47105 L p .763 .831 .368 r
F P
0 g
s
.06347 .48412 m .06627 .47105 L .06704 .46978 L p .858 .829 .356 r
F P
0 g
s
.67206 .10667 m .6918 .1099 L .69031 .10993 L p .009 .571 .804 r
F P
0 g
s
.69031 .10993 m .66968 .10674 L .67206 .10667 L p .009 .571 .804 r
F P
0 g
s
.70452 .11401 m .6918 .1099 L .69436 .11055 L p 0 .435 .744 r
F P
0 g
s
.71271 .11753 m .70593 .11437 L .70788 .11509 L p 0 .392 .759 r
F P
0 g
s
.69436 .11055 m .70593 .11437 L .70452 .11401 L p 0 .435 .744 r
F P
0 g
s
.6979 .11185 m .70788 .11509 L .70593 .11437 L p .276 0 0 r
F P
0 g
s
.67623 .10773 m .69436 .11055 L .6918 .1099 L p .215 0 0 r
F P
0 g
s
.7546 .84567 m .74194 .86115 L .74265 .85985 L p 0 0 0 r
F P
0 g
s
.74265 .85985 m .75574 .84358 L .7546 .84567 L p 0 0 0 r
F P
0 g
s
.73202 .87011 m .74194 .86115 L .74009 .86305 L p 0 0 0 r
F P
0 g
s
.72487 .87545 m .731 .87116 L .7294 .87248 L p 0 0 0 r
F P
0 g
s
.74009 .86305 m .731 .87116 L .73202 .87011 L p 0 0 0 r
F P
0 g
s
.7372 .86546 m .7294 .87248 L .731 .87116 L p .513 .852 .58 r
F P
0 g
s
.7516 .84876 m .74009 .86305 L .74194 .86115 L p .633 .883 .544 r
F P
0 g
s
.06218 .49931 m .06193 .49831 L .062 .4967 L p .845 .703 .171 r
F P
0 g
s
.06193 .49831 m .06218 .49931 L .06217 .5 L p .839 .689 .153 r
F P
0 g
s
.71831 .87951 m .71757 .88022 L .71614 .88097 L p 0 0 0 r
F P
0 g
s
.71757 .88022 m .71831 .87951 L .71892 .87917 L p 0 0 0 r
F P
0 g
s
.71951 .12118 m .72049 .12147 L .72186 .12233 L p 0 .316 .745 r
F P
0 g
s
.72049 .12147 m .71951 .12118 L .71892 .12083 L p 0 .321 .744 r
F P
0 g
s
.71904 .8794 m .71892 .87917 L .71951 .87882 L p 0 0 0 r
F P
0 g
s
.71951 .87882 m .72049 .87853 L .71904 .8794 L p 0 0 0 r
F P
0 g
s
.71904 .1206 m .71892 .12083 L .71831 .12049 L p 0 .333 .749 r
F P
0 g
s
.71831 .12049 m .71757 .11978 L .71904 .1206 L p 0 .333 .749 r
F P
0 g
s
.06191 .5 m .06217 .5 L .06218 .50069 L p .839 .681 .142 r
F P
0 g
s
.06218 .50069 m .06193 .50169 L .06191 .5 L p .839 .681 .142 r
F P
0 g
s
.71892 .12083 m .71904 .1206 L .72049 .12147 L p 0 .321 .744 r
F P
0 g
s
.71892 .87917 m .71904 .8794 L .71757 .88022 L p 0 0 0 r
F P
0 g
s
.06217 .5 m .06191 .5 L .06193 .49831 L p .839 .689 .153 r
F P
0 g
s
.7294 .87248 m .72409 .87609 L .72487 .87545 L p 0 0 0 r
F P
0 g
s
.06272 .51243 m .06225 .50603 L .06242 .50702 L p .813 .6 .042 r
F P
0 g
s
.70788 .11509 m .71366 .11788 L .71271 .11753 L p 0 .392 .759 r
F P
0 g
s
.71271 .88247 m .70593 .88563 L .70452 .88599 L p 0 0 0 r
F P
0 g
s
.70593 .88563 m .71271 .88247 L .71366 .88212 L p 0 0 0 r
F P
0 g
s
.72487 .12455 m .731 .12884 L .73202 .12989 L p 0 .258 .729 r
F P
0 g
s
.731 .12884 m .72487 .12455 L .72409 .12391 L p 0 .218 .681 r
F P
0 g
s
.06242 .49298 m .06307 .48553 L .06347 .48412 L p .863 .775 .272 r
F P
0 g
s
.06307 .48553 m .06242 .49298 L .06225 .49397 L p .813 .727 .198 r
F P
0 g
s
.4665 .55802 m .47098 .56095 L .47201 .55946 L p .18 .508 .912 r
F P
0 g
s
.47201 .55946 m .46741 .55646 L .4665 .55802 L p .18 .508 .912 r
F P
0 g
s
.56699 .5 m .56729 .49465 L .56549 .49451 L p .997 .839 .499 r
F P
0 g
s
.56549 .49451 m .56519 .5 L .56699 .5 L p .997 .839 .499 r
F P
0 g
s
.46172 .5556 m .4665 .55802 L .4674 .55645 L p .231 .574 .942 r
F P
0 g
s
.4665 .44198 m .46172 .4444 L .4625 .44603 L p .231 0 0 r
F P
0 g
s
.4625 .44603 m .4674 .44355 L .4665 .44198 L p .231 0 0 r
F P
0 g
s
.47098 .43905 m .4665 .44198 L .46741 .44354 L p .18 0 .027 r
F P
0 g
s
.56729 .50535 m .56699 .5 L .56519 .5 L p .997 .79 .44 r
F P
0 g
s
.47098 .56095 m .47528 .56451 L .47643 .5631 L p .13 .439 .876 r
F P
0 g
s
.47643 .5631 m .47201 .55946 L .47098 .56095 L p .13 .439 .876 r
F P
0 g
s
.46741 .44354 m .47201 .44054 L .47098 .43905 L p .18 0 .027 r
F P
0 g
s
.47528 .43549 m .47098 .43905 L .47201 .44054 L p .13 0 .061 r
F P
0 g
s
.56519 .5 m .56549 .50549 L .56729 .50535 L p .997 .79 .44 r
F P
0 g
s
.56823 .51085 m .56729 .50535 L .56549 .50549 L p .99 .736 .379 r
F P
0 g
s
.4674 .55645 m .4625 .55397 L .46172 .5556 L p .231 .574 .942 r
F P
0 g
s
.45649 .55366 m .46172 .5556 L .4625 .55397 L p .285 .639 .965 r
F P
0 g
s
.46172 .4444 m .45649 .44634 L .45714 .44804 L p .285 0 0 r
F P
0 g
s
.45714 .44804 m .4625 .44603 L .46172 .4444 L p .285 0 0 r
F P
0 g
s
.56729 .49465 m .56823 .48915 L .56643 .48886 L p .99 .882 .558 r
F P
0 g
s
.56643 .48886 m .56549 .49451 L .56729 .49465 L p .99 .882 .558 r
F P
0 g
s
.45131 .44951 m .45714 .44804 L .45649 .44634 L p .341 0 0 r
F P
0 g
s
.56549 .50549 m .56643 .51114 L .56823 .51085 L p .99 .736 .379 r
F P
0 g
s
.56987 .51648 m .56823 .51085 L .56643 .51114 L p .976 .675 .317 r
F P
0 g
s
.48062 .56742 m .47643 .5631 L .47528 .56451 L p .082 .366 .833 r
F P
0 g
s
.47201 .44054 m .47643 .4369 L .47528 .43549 L p .13 0 .061 r
F P
0 g
s
.47934 .43125 m .47528 .43549 L .47643 .4369 L p .082 0 .1 r
F P
0 g
s
.4625 .55397 m .45714 .55196 L .45649 .55366 L p .285 .639 .965 r
F P
0 g
s
.45079 .55226 m .45649 .55366 L .45714 .55196 L p .341 .7 .983 r
F P
0 g
s
.56808 .48308 m .56643 .48886 L .56823 .48915 L p .976 .92 .616 r
F P
0 g
s
.45714 .55196 m .45131 .55049 L .45079 .55226 L p .341 .7 .983 r
F P
0 g
s
.44461 .55148 m .45079 .55226 L .45131 .55049 L p .399 .758 .994 r
F P
0 g
s
.56643 .51114 m .56808 .51692 L .56987 .51648 L p .976 .675 .317 r
F P
0 g
s
.57228 .52223 m .56987 .51648 L .56808 .51692 L p .955 .609 .254 r
F P
0 g
s
.48451 .57246 m .48062 .56742 L .47934 .56875 L p .036 .292 .784 r
F P
0 g
s
.445 .45035 m .45131 .44951 L .45079 .44774 L p .399 0 0 r
F P
0 g
s
.47643 .4369 m .48062 .43258 L .47934 .43125 L p .082 0 .1 r
F P
0 g
s
.48311 .42629 m .47934 .43125 L .48062 .43258 L p .036 0 .142 r
F P
0 g
s
.5705 .47719 m .56808 .48308 L .56987 .48352 L p .955 .95 .672 r
F P
0 g
s
.43818 .4505 m .445 .45035 L .44461 .44852 L p .455 0 0 r
F P
0 g
s
.45131 .55049 m .445 .54965 L .44461 .55148 L p .399 .758 .994 r
F P
0 g
s
.43791 .5514 m .44461 .55148 L .445 .54965 L p .455 .811 .997 r
F P
0 g
s
.48805 .57828 m .48451 .57246 L .48311 .57371 L p 0 .218 .731 r
F P
0 g
s
.48062 .43258 m .48451 .42754 L .48311 .42629 L p .036 0 .142 r
F P
0 g
s
.48653 .42053 m .48311 .42629 L .48451 .42754 L p 0 0 .187 r
F P
0 g
s
.57377 .47121 m .5705 .47719 L .57228 .47777 L p .926 .974 .725 r
F P
0 g
s
.56808 .51692 m .5705 .52281 L .57228 .52223 L p .955 .609 .254 r
F P
0 g
s
.57556 .52807 m .57228 .52223 L .5705 .52281 L p .926 .539 .193 r
F P
0 g
s
.43082 .44987 m .43818 .4505 L .43791 .4486 L p .51 0 0 r
F P
0 g
s
.445 .54965 m .43818 .5495 L .43791 .5514 L p .455 .811 .997 r
F P
0 g
s
.43067 .55212 m .43791 .5514 L .43818 .5495 L p .51 .857 .993 r
F P
0 g
s
.49117 .58498 m .48805 .57828 L .48653 .57947 L p 0 .145 .673 r
F P
0 g
s
.5705 .52281 m .57377 .52879 L .57556 .52807 L p .926 .539 .193 r
F P
0 g
s
.57981 .53398 m .57556 .52807 L .57377 .52879 L p .892 .468 .134 r
F P
0 g
s
.48451 .42754 m .48805 .42172 L .48653 .42053 L p 0 0 .187 r
F P
0 g
s
.48953 .41389 m .48653 .42053 L .48805 .42172 L p 0 0 .233 r
F P
0 g
s
.578 .46516 m .57377 .47121 L .57556 .47193 L p .892 .989 .772 r
F P
0 g
s
.43818 .5495 m .43082 .55013 L .43067 .55212 L p .51 .857 .993 r
F P
0 g
s
.4228 .55374 m .43067 .55212 L .43082 .55013 L p .561 .896 .983 r
F P
0 g
s
.57377 .52879 m .578 .53484 L .57981 .53398 L p .892 .468 .134 r
F P
0 g
s
.58514 .53998 m .57981 .53398 L .578 .53484 L p .853 .396 .078 r
F P
0 g
s
.42286 .44835 m .43082 .44987 L .43067 .44788 L p .561 .02 0 r
F P
0 g
s
.49384 .59264 m .49117 .58498 L .48953 .58611 L p 0 .075 .615 r
F P
0 g
s
.48805 .42172 m .49117 .41502 L .48953 .41389 L p 0 0 .233 r
F P
0 g
s
.49205 .40627 m .48953 .41389 L .49117 .41502 L p 0 0 .278 r
F P
0 g
s
.58331 .45902 m .578 .46516 L .57981 .46602 L p .853 .997 .814 r
F P
0 g
s
.43082 .55013 m .42286 .55165 L .4228 .55374 L p .561 .896 .983 r
F P
0 g
s
.41423 .5564 m .4228 .55374 L .42286 .55165 L p .607 .927 .967 r
F P
0 g
s
.41418 .44582 m .42286 .44835 L .4228 .44626 L p .607 .064 0 r
F P
0 g
s
.49599 .60141 m .49384 .59264 L .49205 .59373 L p 0 .012 .557 r
F P
0 g
s
.49117 .41502 m .49384 .40736 L .49205 .40627 L p 0 0 .278 r
F P
0 g
s
.49404 .39752 m .49205 .40627 L .49384 .40736 L p 0 0 .32 r
F P
0 g
s
.578 .53484 m .58331 .54098 L .58514 .53998 L p .853 .396 .078 r
F P
0 g
s
.59173 .54608 m .58514 .53998 L .58331 .54098 L p .812 .328 .028 r
F P
0 g
s
.58983 .45277 m .58331 .45902 L .58514 .46002 L p .812 .998 .849 r
F P
0 g
s
.6918 .8901 m .70452 .88599 L .70593 .88563 L p 0 0 0 r
F P
0 g
s
.74194 .13885 m .73202 .12989 L .731 .12884 L p 0 .094 .591 r
F P
0 g
s
.06627 .47105 m .06347 .48412 L .06307 .48553 L p .759 .745 .226 r
F P
0 g
s
.64438 .10767 m .67206 .10667 L .66968 .10674 L p 0 0 0 r
F P
0 g
s
.66968 .10674 m .64095 .10776 L .64438 .10767 L p 0 0 0 r
F P
0 g
s
.74194 .13885 m .7546 .15433 L .75574 .15642 L p 0 .002 .549 r
F P
0 g
s
.76922 .18182 m .75574 .15642 L .7546 .15433 L p .63 .244 0 r
F P
0 g
s
.6918 .8901 m .67206 .89333 L .66968 .89326 L p .009 0 0 r
F P
0 g
s
.64095 .89224 m .66968 .89326 L .67206 .89333 L p 0 .561 .713 r
F P
0 g
s
.76758 .8212 m .7546 .84567 L .75574 .84358 L p .63 .786 .338 r
F P
0 g
s
.75574 .84358 m .76922 .81818 L .76758 .8212 L p .63 .786 .338 r
F P
0 g
s
.06627 .47105 m .07334 .45235 L .07458 .45032 L p .763 .831 .368 r
F P
0 g
s
.08984 .42594 m .07458 .45032 L .07334 .45235 L p 0 0 0 r
F P
0 g
s
.08804 .57113 m .07334 .54765 L .07458 .54968 L p 0 0 .381 r
F P
0 g
s
.07458 .54968 m .08984 .57406 L .08804 .57113 L p 0 0 .381 r
F P
0 g
s
.71366 .88212 m .70788 .88491 L .70593 .88563 L p 0 0 0 r
F P
0 g
s
.70788 .88491 m .71366 .88212 L .71482 .88161 L p 0 0 0 r
F P
0 g
s
.06225 .49397 m .06272 .48757 L .06307 .48553 L p .813 .727 .198 r
F P
0 g
s
.06272 .48757 m .06225 .49397 L .06211 .49523 L p .763 .676 .127 r
F P
0 g
s
.72409 .12391 m .7294 .12752 L .731 .12884 L p 0 .218 .681 r
F P
0 g
s
.7294 .12752 m .72409 .12391 L .72308 .12316 L p 0 .187 .636 r
F P
0 g
s
.71027 .11613 m .71482 .11839 L .71366 .11788 L p 0 .332 .701 r
F P
0 g
s
.71366 .11788 m .70788 .11509 L .71027 .11613 L p 0 .332 .701 r
F P
0 g
s
.72731 .87403 m .72308 .87684 L .72409 .87609 L p 0 0 0 r
F P
0 g
s
.72409 .87609 m .7294 .87248 L .72731 .87403 L p 0 0 0 r
F P
0 g
s
.06243 .50984 m .06211 .50477 L .06225 .50603 L p .763 .569 0 r
F P
0 g
s
.06225 .50603 m .06272 .51243 L .06243 .50984 L p .763 .569 0 r
F P
0 g
s
.40464 .44215 m .41418 .44582 L .41423 .4436 L p .646 .105 0 r
F P
0 g
s
.42286 .55165 m .41418 .55418 L .41423 .5564 L p .607 .927 .967 r
F P
0 g
s
.40479 .56023 m .41423 .5564 L .41418 .55418 L p .646 .951 .948 r
F P
0 g
s
.49758 .61151 m .49599 .60141 L .49404 .60248 L p 0 0 .502 r
F P
0 g
s
.58331 .54098 m .58983 .54723 L .59173 .54608 L p .812 .328 .028 r
F P
0 g
s
.59976 .55233 m .59173 .54608 L .58983 .54723 L p .771 .265 0 r
F P
0 g
s
.49384 .40736 m .49599 .39859 L .49404 .39752 L p 0 0 .32 r
F P
0 g
s
.49544 .38743 m .49404 .39752 L .49599 .39859 L p 0 0 .358 r
F P
0 g
s
.59778 .44634 m .58983 .45277 L .59173 .45392 L p .771 .994 .876 r
F P
0 g
s
.39401 .43718 m .40464 .44215 L .40479 .43977 L p .678 .14 0 r
F P
0 g
s
.58983 .54723 m .59778 .55366 L .59976 .55233 L p .771 .265 0 r
F P
0 g
s
.6095 .55887 m .59976 .55233 L .59778 .55366 L p .734 .212 0 r
F P
0 g
s
.41418 .55418 m .40464 .55785 L .40479 .56023 L p .646 .951 .948 r
F P
0 g
s
.39427 .5654 m .40479 .56023 L .40464 .55785 L p .678 .967 .929 r
F P
0 g
s
.49859 .6232 m .49758 .61151 L .49544 .61257 L p 0 0 .455 r
F P
0 g
s
.49599 .39859 m .49758 .38849 L .49544 .38743 L p 0 0 .358 r
F P
0 g
s
.49623 .37573 m .49544 .38743 L .49758 .38849 L p 0 0 .39 r
F P
0 g
s
.6074 .43962 m .59778 .44634 L .59976 .44767 L p .734 .986 .897 r
F P
0 g
s
.71482 .88161 m .71027 .88387 L .70788 .88491 L p 0 0 0 r
F P
0 g
s
.71027 .88387 m .71482 .88161 L .71614 .88097 L p 0 0 0 r
F P
0 g
s
.72308 .12316 m .72731 .12597 L .7294 .12752 L p 0 .187 .636 r
F P
0 g
s
.72731 .12597 m .72308 .12316 L .72186 .12233 L p 0 .167 .6 r
F P
0 g
s
.06211 .49523 m .06243 .49016 L .06272 .48757 L p .763 .676 .127 r
F P
0 g
s
.06243 .49016 m .06211 .49523 L .062 .4967 L p .719 .627 .062 r
F P
0 g
s
.713 .11745 m .71614 .11903 L .71482 .11839 L p 0 .276 .649 r
F P
0 g
s
.71482 .11839 m .71027 .11613 L .713 .11745 L p 0 .276 .649 r
F P
0 g
s
.72479 .87574 m .72186 .87767 L .72308 .87684 L p 0 0 0 r
F P
0 g
s
.72308 .87684 m .72731 .87403 L .72479 .87574 L p 0 0 0 r
F P
0 g
s
.06221 .50681 m .062 .5033 L .06211 .50477 L p .719 .547 0 r
F P
0 g
s
.06211 .50477 m .06243 .50984 L .06221 .50681 L p .719 .547 0 r
F P
0 g
s
.40464 .55785 m .39401 .56282 L .39427 .5654 L p .678 .967 .929 r
F P
0 g
s
.38231 .57208 m .39427 .5654 L .39401 .56282 L p .7 .977 .913 r
F P
0 g
s
.49907 .63687 m .49859 .6232 L .49623 .62427 L p 0 0 .419 r
F P
0 g
s
.38193 .43075 m .39401 .43718 L .39427 .4346 L p .7 .167 0 r
F P
0 g
s
.49758 .38849 m .49859 .3768 L .49623 .37573 L p 0 0 .39 r
F P
0 g
s
.49642 .36204 m .49623 .37573 L .49859 .3768 L p 0 0 .415 r
F P
0 g
s
.59778 .55366 m .6074 .56038 L .6095 .55887 L p .734 .212 0 r
F P
0 g
s
.62126 .56588 m .6095 .55887 L .6074 .56038 L p .704 .172 0 r
F P
0 g
s
.619 .43237 m .6074 .43962 L .6095 .44113 L p .704 .978 .91 r
F P
0 g
s
.3679 .42273 m .38193 .43075 L .38231 .42792 L p .713 .183 0 r
F P
0 g
s
.39401 .56282 m .38193 .56925 L .38231 .57208 L p .7 .977 .913 r
F P
0 g
s
.36843 .5804 m .38231 .57208 L .38193 .56925 L p .713 .982 .902 r
F P
0 g
s
.49913 .65304 m .49907 .63687 L .49642 .63796 L p 0 0 .398 r
F P
0 g
s
.63297 .42423 m .619 .43237 L .62126 .43412 L p .687 .973 .918 r
F P
0 g
s
.49859 .3768 m .49907 .36313 L .49642 .36204 L p 0 0 .415 r
F P
0 g
s
.49616 .34586 m .49642 .36204 L .49907 .36313 L p 0 0 .429 r
F P
0 g
s
.6074 .56038 m .619 .56763 L .62126 .56588 L p .704 .172 0 r
F P
0 g
s
.63541 .57374 m .62126 .56588 L .619 .56763 L p .687 .149 0 r
F P
0 g
s
.71595 .119 m .71757 .11978 L .71614 .11903 L p .347 0 0 r
F P
0 g
s
.71614 .11903 m .713 .11745 L .71595 .119 L p .347 0 0 r
F P
0 g
s
.72198 .87752 m .72049 .87853 L .72186 .87767 L p .399 .813 .616 r
F P
0 g
s
.72186 .87767 m .72479 .87574 L .72198 .87752 L p .399 .813 .616 r
F P
0 g
s
.72186 .12233 m .72479 .12426 L .72731 .12597 L p 0 .167 .6 r
F P
0 g
s
.72479 .12426 m .72186 .12233 L .72049 .12147 L p .399 0 0 r
F P
0 g
s
.71614 .88097 m .713 .88255 L .71027 .88387 L p 0 0 0 r
F P
0 g
s
.713 .88255 m .71614 .88097 L .71757 .88022 L p .347 .795 .647 r
F P
0 g
s
.062 .4967 m .06221 .49319 L .06243 .49016 L p .719 .627 .062 r
F P
0 g
s
.06221 .49319 m .062 .4967 L .06193 .49831 L p 0 0 0 r
F P
0 g
s
.06207 .50348 m .06193 .50169 L .062 .5033 L p 0 0 .05 r
F P
0 g
s
.062 .5033 m .06221 .50681 L .06207 .50348 L p 0 0 .05 r
F P
0 g
s
.77845 .21701 m .76922 .18182 L .76758 .1788 L p .814 .519 0 r
F P
0 g
s
.7546 .15433 m .76758 .1788 L .76922 .18182 L p .63 .244 0 r
F P
0 g
s
.60585 .88264 m .64095 .89224 L .64438 .89233 L p 0 .518 .814 r
F P
0 g
s
.67206 .89333 m .64438 .89233 L .64095 .89224 L p 0 .561 .713 r
F P
0 g
s
.7763 .78685 m .76758 .8212 L .76922 .81818 L p .814 .81 .324 r
F P
0 g
s
.76922 .81818 m .77845 .78299 L .7763 .78685 L p .814 .81 .324 r
F P
0 g
s
.61026 .11729 m .64438 .10767 L .64095 .10776 L p 0 0 0 r
F P
0 g
s
.64095 .10776 m .60585 .11736 L .61026 .11729 L p 0 0 0 r
F P
0 g
s
.11569 .40035 m .08984 .42594 L .08804 .42887 L p 0 0 0 r
F P
0 g
s
.07334 .45235 m .08804 .42887 L .08984 .42594 L p 0 0 0 r
F P
0 g
s
.11343 .59586 m .08804 .57113 L .08984 .57406 L p 0 .12 .635 r
F P
0 g
s
.08984 .57406 m .11569 .59965 L .11343 .59586 L p 0 .12 .635 r
F P
0 g
s
.72049 .12147 m .72198 .12248 L .72479 .12426 L p .399 0 0 r
F P
0 g
s
.72198 .12248 m .72049 .12147 L .71904 .1206 L p .399 0 0 r
F P
0 g
s
.71757 .88022 m .71595 .881 L .713 .88255 L p .347 .795 .647 r
F P
0 g
s
.71595 .881 m .71757 .88022 L .71904 .8794 L p .381 .815 .654 r
F P
0 g
s
.71899 .8793 m .71904 .8794 L .72049 .87853 L p .399 .821 .643 r
F P
0 g
s
.72049 .87853 m .72198 .87752 L .71899 .8793 L p .399 .821 .643 r
F P
0 g
s
.06203 .5 m .06191 .5 L .06193 .50169 L p 0 0 .047 r
F P
0 g
s
.06193 .50169 m .06207 .50348 L .06203 .5 L p 0 0 .047 r
F P
0 g
s
.71899 .1207 m .71904 .1206 L .71757 .11978 L p .381 0 0 r
F P
0 g
s
.71757 .11978 m .71595 .119 L .71899 .1207 L p .381 0 0 r
F P
0 g
s
.06193 .49831 m .06207 .49652 L .06221 .49319 L p 0 0 0 r
F P
0 g
s
.06207 .49652 m .06193 .49831 L .06191 .5 L p 0 0 .027 r
F P
0 g
s
.06191 .5 m .06203 .5 L .06207 .49652 L p 0 0 .027 r
F P
0 g
s
.71904 .8794 m .71899 .8793 L .71595 .881 L p .381 .815 .654 r
F P
0 g
s
.71904 .1206 m .71899 .1207 L .72198 .12248 L p .399 0 0 r
F P
0 g
s
.38193 .56925 m .3679 .57727 L .36843 .5804 L p .713 .982 .902 r
F P
0 g
s
.35189 .59042 m .36843 .5804 L .3679 .57727 L p .715 .982 .901 r
F P
0 g
s
.49616 .65414 m .49575 .67348 L .49912 .67236 L p 0 0 .395 r
F P
0 g
s
.49912 .67236 m .49913 .65304 L .49616 .65414 L p 0 0 .395 r
F P
0 g
s
.36843 .4196 m .35189 .40958 L .35117 .41306 L p .715 .185 0 r
F P
0 g
s
.35117 .41306 m .3679 .42273 L .36843 .4196 L p .715 .185 0 r
F P
0 g
s
.619 .56763 m .63297 .57577 L .63541 .57374 L p .687 .149 0 r
F P
0 g
s
.65236 .58306 m .63541 .57374 L .63297 .57577 L p .684 .146 0 r
F P
0 g
s
.49907 .36313 m .49913 .34696 L .49616 .34586 L p 0 0 .429 r
F P
0 g
s
.49575 .32652 m .49616 .34586 L .49913 .34696 L p 0 0 .431 r
F P
0 g
s
.63541 .42626 m .65236 .41694 L .64971 .41458 L p .684 .972 .919 r
F P
0 g
s
.64971 .41458 m .63297 .42423 L .63541 .42626 L p .684 .972 .919 r
F P
0 g
s
.731 .87116 m .74009 .86305 L .7372 .86546 L p .513 .852 .58 r
F P
0 g
s
.70593 .11437 m .69436 .11055 L .6979 .11185 L p .276 0 0 r
F P
0 g
s
.06307 .51447 m .06554 .5264 L .0649 .52269 L p 0 0 .185 r
F P
0 g
s
.70593 .88563 m .69436 .88945 L .6918 .8901 L p 0 0 0 r
F P
0 g
s
.69436 .88945 m .70593 .88563 L .70788 .88491 L p .276 .771 .716 r
F P
0 g
s
.731 .12884 m .74009 .13695 L .74194 .13885 L p 0 .094 .591 r
F P
0 g
s
.74009 .13695 m .731 .12884 L .7294 .12752 L p .513 0 0 r
F P
0 g
s
.06307 .48553 m .06554 .4736 L .06627 .47105 L p .759 .745 .226 r
F P
0 g
s
.06554 .4736 m .06307 .48553 L .06272 .48757 L p 0 0 0 r
F P
0 g
s
.35189 .40958 m .33169 .3981 L .33073 .40195 L p .703 .17 0 r
F P
0 g
s
.33073 .40195 m .35117 .41306 L .35189 .40958 L p .703 .17 0 r
F P
0 g
s
.3679 .57727 m .35117 .58694 L .35189 .59042 L p .715 .982 .901 r
F P
0 g
s
.33169 .6019 m .35189 .59042 L .35117 .58694 L p .703 .978 .91 r
F P
0 g
s
.63297 .57577 m .64971 .58542 L .65236 .58306 L p .684 .146 0 r
F P
0 g
s
.6724 .59481 m .65236 .58306 L .64971 .58542 L p .7 .166 0 r
F P
0 g
s
.49575 .67348 m .49591 .69671 L .49972 .69562 L p 0 0 .414 r
F P
0 g
s
.49972 .69562 m .49912 .67236 L .49575 .67348 L p 0 0 .414 r
F P
0 g
s
.65236 .41694 m .6724 .40519 L .66955 .40243 L p .7 .977 .912 r
F P
0 g
s
.66955 .40243 m .64971 .41458 L .65236 .41694 L p .7 .977 .912 r
F P
0 g
s
.49913 .34696 m .49912 .32764 L .49575 .32652 L p 0 0 .431 r
F P
0 g
s
.49591 .30329 m .49575 .32652 L .49912 .32764 L p 0 0 .417 r
F P
0 g
s
.67206 .89333 m .6918 .8901 L .69436 .88945 L p .215 .739 .785 r
F P
0 g
s
.6918 .1099 m .67206 .10667 L .67623 .10773 L p .215 0 0 r
F P
0 g
s
.74194 .86115 m .7546 .84567 L .7516 .84876 L p .633 .883 .544 r
F P
0 g
s
.7546 .15433 m .74194 .13885 L .74009 .13695 L p .633 .15 0 r
F P
0 g
s
.06627 .52895 m .07334 .54765 L .07217 .54351 L p 0 0 .336 r
F P
0 g
s
.07334 .45235 m .06627 .47105 L .06554 .4736 L p 0 0 0 r
F P
0 g
s
.56951 .86154 m .60585 .88264 L .61026 .88271 L p 0 .418 .837 r
F P
0 g
s
.64438 .89233 m .61026 .88271 L .60585 .88264 L p 0 .518 .814 r
F P
0 g
s
.77835 .25903 m .77845 .21701 L .7763 .21315 L p .924 .753 .269 r
F P
0 g
s
.76758 .1788 m .7763 .21315 L .77845 .21701 L p .814 .519 0 r
F P
0 g
s
.14966 .61613 m .11343 .59586 L .11569 .59965 L p 0 .414 .835 r
F P
0 g
s
.11569 .59965 m .15214 .62058 L .14966 .61613 L p 0 .414 .835 r
F P
0 g
s
.15214 .37942 m .11569 .40035 L .11343 .40414 L p 0 0 0 r
F P
0 g
s
.08804 .42887 m .11343 .40414 L .11569 .40035 L p 0 0 0 r
F P
0 g
s
.57459 .13853 m .61026 .11729 L .60585 .11736 L p 0 0 0 r
F P
0 g
s
.60585 .11736 m .56951 .13846 L .57459 .13853 L p 0 0 0 r
F P
0 g
s
.77574 .74533 m .7763 .78685 L .77845 .78299 L p .924 .756 .273 r
F P
0 g
s
.77845 .78299 m .77835 .74097 L .77574 .74533 L p .924 .756 .273 r
F P
0 g
s
.33169 .3981 m .30658 .3859 L .30531 .39014 L p .673 .133 0 r
F P
0 g
s
.30531 .39014 m .33073 .40195 L .33169 .3981 L p .673 .133 0 r
F P
0 g
s
.35117 .58694 m .33073 .59805 L .33169 .6019 L p .703 .978 .91 r
F P
0 g
s
.30658 .6141 m .33169 .6019 L .33073 .59805 L p .673 .965 .93 r
F P
0 g
s
.49591 .69671 m .4979 .72456 L .5022 .72354 L p 0 0 .456 r
F P
0 g
s
.5022 .72354 m .49972 .69562 L .49591 .69671 L p 0 0 .456 r
F P
0 g
s
.64971 .58542 m .66955 .59757 L .6724 .59481 L p .7 .166 0 r
F P
0 g
s
.69552 .61046 m .6724 .59481 L .66955 .59757 L p .735 .213 0 r
F P
0 g
s
.49912 .32764 m .49972 .30438 L .49591 .30329 L p 0 0 .417 r
F P
0 g
s
.4979 .27544 m .49591 .30329 L .49972 .30438 L p 0 0 .384 r
F P
0 g
s
.6724 .40519 m .69552 .38954 L .69249 .38633 L p .735 .987 .894 r
F P
0 g
s
.69249 .38633 m .66955 .40243 L .6724 .40519 L p .735 .987 .894 r
F P
0 g
s
.06437 .51797 m .06243 .50984 L .06272 .51243 L p 0 0 .262 r
F P
0 g
s
.06272 .51243 m .0649 .52269 L .06437 .51797 L p 0 0 .262 r
F P
0 g
s
.70225 .11375 m .71027 .11613 L .70788 .11509 L p .396 0 0 r
F P
0 g
s
.70788 .11509 m .6979 .11185 L .70225 .11375 L p .396 0 0 r
F P
0 g
s
.73338 .86828 m .72731 .87403 L .7294 .87248 L p .588 .917 .686 r
F P
0 g
s
.7294 .87248 m .7372 .86546 L .73338 .86828 L p .588 .917 .686 r
F P
0 g
s
.06272 .48757 m .0649 .47731 L .06554 .4736 L p 0 0 0 r
F P
0 g
s
.0649 .47731 m .06272 .48757 L .06243 .49016 L p 0 0 .04 r
F P
0 g
s
.7294 .12752 m .7372 .13454 L .74009 .13695 L p .513 0 0 r
F P
0 g
s
.7372 .13454 m .7294 .12752 L .72731 .12597 L p .588 .044 0 r
F P
0 g
s
.70788 .88491 m .6979 .88815 L .69436 .88945 L p .276 .771 .716 r
F P
0 g
s
.6979 .88815 m .70788 .88491 L .71027 .88387 L p .396 .851 .797 r
F P
0 g
s
.33073 .59805 m .30531 .60986 L .30658 .6141 L p .673 .965 .93 r
F P
0 g
s
.27532 .62529 m .30658 .6141 L .30531 .60986 L p .618 .939 .955 r
F P
0 g
s
.66955 .59757 m .69249 .61367 L .69552 .61046 L p .735 .213 0 r
F P
0 g
s
.72084 .63193 m .69552 .61046 L .69249 .61367 L p .787 .288 0 r
F P
0 g
s
.4979 .72456 m .50383 .75722 L .50861 .75635 L p 0 0 .521 r
F P
0 g
s
.50861 .75635 m .5022 .72354 L .4979 .72456 L p 0 0 .521 r
F P
0 g
s
.49972 .30438 m .5022 .27646 L .4979 .27544 L p 0 0 .384 r
F P
0 g
s
.50383 .24278 m .4979 .27544 L .5022 .27646 L p 0 0 .326 r
F P
0 g
s
.69552 .38954 m .72084 .36807 L .7177 .36437 L p .787 .997 .858 r
F P
0 g
s
.7177 .36437 m .69249 .38633 L .69552 .38954 L p .787 .997 .858 r
F P
0 g
s
.30658 .3859 m .27532 .37471 L .27369 .37928 L p .618 .07 0 r
F P
0 g
s
.27369 .37928 m .30531 .39014 L .30658 .3859 L p .618 .07 0 r
F P
0 g
s
.46741 .55646 m .47201 .55946 L .47416 .55633 L p .452 .589 .899 r
F P
0 g
s
.47416 .55633 m .4693 .55317 L .46741 .55646 L p .452 .589 .899 r
F P
0 g
s
.4625 .55397 m .4674 .55645 L .4693 .55317 L p .484 .631 .918 r
F P
0 g
s
.47201 .44054 m .46741 .44354 L .4693 .44683 L p .452 .149 .36 r
F P
0 g
s
.4674 .44355 m .4625 .44603 L .46414 .44946 L p .484 .16 .341 r
F P
0 g
s
.46414 .44946 m .4693 .44683 L .4674 .44355 L p .484 .16 .341 r
F P
0 g
s
.56519 .5 m .56549 .49451 L .5617 .49422 L p .951 .792 .648 r
F P
0 g
s
.5617 .49422 m .56139 .5 L .56519 .5 L p .951 .792 .648 r
F P
0 g
s
.56549 .50549 m .56519 .5 L .56139 .5 L p .951 .761 .61 r
F P
0 g
s
.47201 .55946 m .47643 .5631 L .47882 .56012 L p .42 .545 .876 r
F P
0 g
s
.47882 .56012 m .47416 .55633 L .47201 .55946 L p .42 .545 .876 r
F P
0 g
s
.4693 .44683 m .47416 .44367 L .47201 .44054 L p .452 .149 .36 r
F P
0 g
s
.47643 .4369 m .47201 .44054 L .47416 .44367 L p .42 .141 .381 r
F P
0 g
s
.4693 .55317 m .46414 .55054 L .4625 .55397 L p .484 .631 .918 r
F P
0 g
s
.45714 .55196 m .4625 .55397 L .46414 .55054 L p .518 .672 .933 r
F P
0 g
s
.56139 .5 m .5617 .50578 L .56549 .50549 L p .951 .761 .61 r
F P
0 g
s
.56643 .51114 m .56549 .50549 L .5617 .50578 L p .947 .727 .572 r
F P
0 g
s
.56549 .49451 m .56643 .48886 L .56266 .48828 L p .947 .82 .685 r
F P
0 g
s
.56266 .48828 m .5617 .49422 L .56549 .49451 L p .947 .82 .685 r
F P
0 g
s
.4625 .44603 m .45714 .44804 L .45852 .4516 L p .518 .174 .324 r
F P
0 g
s
.45852 .4516 m .46414 .44946 L .4625 .44603 L p .518 .174 .324 r
F P
0 g
s
.45714 .44804 m .45131 .44951 L .45243 .45319 L p .554 .192 .309 r
F P
0 g
s
.45243 .45319 m .45852 .4516 L .45714 .44804 L p .554 .192 .309 r
F P
0 g
s
.46414 .55054 m .45852 .5484 L .45714 .55196 L p .518 .672 .933 r
F P
0 g
s
.45131 .55049 m .45714 .55196 L .45852 .5484 L p .554 .712 .945 r
F P
0 g
s
.47643 .5631 m .48062 .56742 L .48324 .5646 L p .389 .499 .85 r
F P
0 g
s
.48324 .5646 m .47882 .56012 L .47643 .5631 L p .389 .499 .85 r
F P
0 g
s
.5617 .50578 m .56266 .51172 L .56643 .51114 L p .947 .727 .572 r
F P
0 g
s
.56808 .51692 m .56643 .51114 L .56266 .51172 L p .94 .689 .532 r
F P
0 g
s
.47416 .44367 m .47882 .43988 L .47643 .4369 L p .42 .141 .381 r
F P
0 g
s
.48062 .43258 m .47643 .4369 L .47882 .43988 L p .389 .135 .404 r
F P
0 g
s
.56643 .48886 m .56808 .48308 L .56432 .48221 L p .94 .845 .722 r
F P
0 g
s
.56432 .48221 m .56266 .48828 L .56643 .48886 L p .94 .845 .722 r
F P
0 g
s
.45852 .5484 m .45243 .54681 L .45131 .55049 L p .554 .712 .945 r
F P
0 g
s
.445 .54965 m .45131 .55049 L .45243 .54681 L p .59 .75 .954 r
F P
0 g
s
.48062 .56742 m .48451 .57246 L .48736 .56979 L p .358 .451 .82 r
F P
0 g
s
.48736 .56979 m .48324 .5646 L .48062 .56742 L p .358 .451 .82 r
F P
0 g
s
.56266 .51172 m .56432 .51779 L .56808 .51692 L p .94 .689 .532 r
F P
0 g
s
.5705 .52281 m .56808 .51692 L .56432 .51779 L p .927 .648 .491 r
F P
0 g
s
.45131 .44951 m .445 .45035 L .44588 .45416 L p .59 .213 .296 r
F P
0 g
s
.44588 .45416 m .45243 .45319 L .45131 .44951 L p .59 .213 .296 r
F P
0 g
s
.56808 .48308 m .5705 .47719 L .56676 .47606 L p .927 .866 .759 r
F P
0 g
s
.56676 .47606 m .56432 .48221 L .56808 .48308 L p .927 .866 .759 r
F P
0 g
s
.47882 .43988 m .48324 .4354 L .48062 .43258 L p .389 .135 .404 r
F P
0 g
s
.48451 .42754 m .48062 .43258 L .48324 .4354 L p .358 .133 .43 r
F P
0 g
s
.19487 .36816 m .15214 .37942 L .14966 .38387 L p .198 0 0 r
F P
0 g
s
.11343 .40414 m .14966 .38387 L .15214 .37942 L p 0 0 0 r
F P
0 g
s
.53839 .83017 m .56951 .86154 L .57459 .86147 L p 0 .291 .788 r
F P
0 g
s
.61026 .88271 m .57459 .86147 L .56951 .86154 L p 0 .418 .837 r
F P
0 g
s
.76674 .30167 m .77835 .25903 L .77574 .25467 L p .946 .902 .514 r
F P
0 g
s
.7763 .21315 m .77574 .25467 L .77835 .25903 L p .924 .753 .269 r
F P
0 g
s
.54371 .17016 m .57459 .13853 L .56951 .13846 L p 0 0 0 r
F P
0 g
s
.56951 .13846 m .53839 .16983 L .54371 .17016 L p 0 0 0 r
F P
0 g
s
.7638 .70277 m .77574 .74533 L .77835 .74097 L p .946 .643 .198 r
F P
0 g
s
.77835 .74097 m .76674 .69833 L .7638 .70277 L p .946 .643 .198 r
F P
0 g
s
.1925 .62707 m .14966 .61613 L .15214 .62058 L p .198 .644 .946 r
F P
0 g
s
.15214 .62058 m .19487 .63184 L .1925 .62707 L p .198 .644 .946 r
F P
0 g
s
.445 .45035 m .43818 .4505 L .43885 .45444 L p .626 .237 .286 r
F P
0 g
s
.43885 .45444 m .44588 .45416 L .445 .45035 L p .626 .237 .286 r
F P
0 g
s
.45243 .54681 m .44588 .54584 L .445 .54965 L p .59 .75 .954 r
F P
0 g
s
.43818 .5495 m .445 .54965 L .44588 .54584 L p .626 .786 .958 r
F P
0 g
s
.56432 .51779 m .56676 .52394 L .5705 .52281 L p .927 .648 .491 r
F P
0 g
s
.57377 .52879 m .5705 .52281 L .56676 .52394 L p .911 .604 .45 r
F P
0 g
s
.48451 .57246 m .48805 .57828 L .49112 .57574 L p .329 .403 .787 r
F P
0 g
s
.49112 .57574 m .48736 .56979 L .48451 .57246 L p .329 .403 .787 r
F P
0 g
s
.48324 .4354 m .48736 .43021 L .48451 .42754 L p .358 .133 .43 r
F P
0 g
s
.48805 .42172 m .48451 .42754 L .48736 .43021 L p .329 .134 .457 r
F P
0 g
s
.5705 .47719 m .57377 .47121 L .57003 .46982 L p .911 .884 .794 r
F P
0 g
s
.57003 .46982 m .56676 .47606 L .5705 .47719 L p .911 .884 .794 r
F P
0 g
s
.30531 .60986 m .27369 .62072 L .27532 .62529 L p .618 .939 .955 r
F P
0 g
s
.23752 .63249 m .27532 .62529 L .27369 .62072 L p .529 .887 .979 r
F P
0 g
s
.69249 .61367 m .7177 .63563 L .72084 .63193 L p .787 .288 0 r
F P
0 g
s
.74598 .66108 m .72084 .63193 L .7177 .63563 L p .85 .389 .047 r
F P
0 g
s
.72084 .36807 m .74598 .33892 L .74285 .33477 L p .85 .998 .793 r
F P
0 g
s
.74285 .33477 m .7177 .36437 L .72084 .36807 L p .85 .998 .793 r
F P
0 g
s
.50383 .75722 m .51651 .79356 L .52167 .79294 L p 0 .055 .606 r
F P
0 g
s
.52167 .79294 m .50861 .75635 L .50383 .75722 L p 0 .055 .606 r
F P
0 g
s
.5022 .27646 m .50861 .24365 L .50383 .24278 L p 0 0 .326 r
F P
0 g
s
.51651 .20644 m .50383 .24278 L .50861 .24365 L p 0 0 .235 r
F P
0 g
s
.27532 .37471 m .23752 .36751 L .23548 .3723 L p .529 0 0 r
F P
0 g
s
.23548 .3723 m .27369 .37928 L .27532 .37471 L p .529 0 0 r
F P
0 g
s
.44588 .54584 m .43885 .54556 L .43818 .5495 L p .626 .786 .958 r
F P
0 g
s
.43082 .55013 m .43818 .5495 L .43885 .54556 L p .662 .819 .959 r
F P
0 g
s
.43818 .4505 m .43082 .44987 L .4313 .45397 L p .662 .262 .277 r
F P
0 g
s
.4313 .45397 m .43885 .45444 L .43818 .4505 L p .662 .262 .277 r
F P
0 g
s
.56676 .52394 m .57003 .53018 L .57377 .52879 L p .911 .604 .45 r
F P
0 g
s
.578 .53484 m .57377 .52879 L .57003 .53018 L p .891 .558 .409 r
F P
0 g
s
.48805 .57828 m .49117 .58498 L .49448 .58252 L p .301 .354 .75 r
F P
0 g
s
.49448 .58252 m .49112 .57574 L .48805 .57828 L p .301 .354 .75 r
F P
0 g
s
.48736 .43021 m .49112 .42426 L .48805 .42172 L p .329 .134 .457 r
F P
0 g
s
.49117 .41502 m .48805 .42172 L .49112 .42426 L p .301 .137 .485 r
F P
0 g
s
.57377 .47121 m .578 .46516 L .57422 .46352 L p .891 .898 .826 r
F P
0 g
s
.57422 .46352 m .57003 .46982 L .57377 .47121 L p .891 .898 .826 r
F P
0 g
s
.70723 .11617 m .713 .11745 L .71027 .11613 L p .489 0 0 r
F P
0 g
s
.71027 .11613 m .70225 .11375 L .70723 .11617 L p .489 0 0 r
F P
0 g
s
.72879 .87139 m .72479 .87574 L .72731 .87403 L p .63 .951 .762 r
F P
0 g
s
.72731 .87403 m .73338 .86828 L .72879 .87139 L p .63 .951 .762 r
F P
0 g
s
.06243 .49016 m .06437 .48203 L .0649 .47731 L p 0 0 .04 r
F P
0 g
s
.06437 .48203 m .06243 .49016 L .06221 .49319 L p 0 0 .146 r
F P
0 g
s
.72731 .12597 m .73338 .13172 L .7372 .13454 L p .588 .044 0 r
F P
0 g
s
.73338 .13172 m .72731 .12597 L .72479 .12426 L p .63 .077 0 r
F P
0 g
s
.71027 .88387 m .70225 .88625 L .6979 .88815 L p .396 .851 .797 r
F P
0 g
s
.70225 .88625 m .71027 .88387 L .713 .88255 L p .489 .903 .843 r
F P
0 g
s
.06397 .51245 m .06221 .50681 L .06243 .50984 L p 0 0 .308 r
F P
0 g
s
.06243 .50984 m .06437 .51797 L .06397 .51245 L p 0 0 .308 r
F P
0 g
s
.23752 .36751 m .19487 .36816 L .1925 .37293 L p .393 0 0 r
F P
0 g
s
.14966 .38387 m .1925 .37293 L .19487 .36816 L p .198 0 0 r
F P
0 g
s
.51651 .79356 m .53839 .83017 L .54371 .82984 L p 0 .164 .701 r
F P
0 g
s
.57459 .86147 m .54371 .82984 L .53839 .83017 L p 0 .291 .788 r
F P
0 g
s
.74285 .66523 m .7638 .70277 L .76674 .69833 L p .91 .512 .119 r
F P
0 g
s
.76674 .69833 m .74598 .66108 L .74285 .66523 L p .91 .512 .119 r
F P
0 g
s
.74598 .33892 m .76674 .30167 L .7638 .29723 L p .91 .974 .685 r
F P
0 g
s
.77574 .25467 m .7638 .29723 L .76674 .30167 L p .946 .902 .514 r
F P
0 g
s
.23548 .6277 m .1925 .62707 L .19487 .63184 L p .393 .796 .984 r
F P
0 g
s
.19487 .63184 m .23752 .63249 L .23548 .6277 L p .393 .796 .984 r
F P
0 g
s
.52167 .20706 m .54371 .17016 L .53839 .16983 L p 0 0 .103 r
F P
0 g
s
.53839 .16983 m .51651 .20644 L .52167 .20706 L p 0 0 .103 r
F P
0 g
s
.1925 .37293 m .23548 .3723 L .23752 .36751 L p .393 0 0 r
F P
0 g
s
.7177 .63563 m .74285 .66523 L .74598 .66108 L p .85 .389 .047 r
F P
0 g
s
.50861 .24365 m .52167 .20706 L .51651 .20644 L p 0 0 .235 r
F P
0 g
s
.27369 .62072 m .23548 .6277 L .23752 .63249 L p .529 .887 .979 r
F P
0 g
s
.54371 .82984 m .52167 .79294 L .51651 .79356 L p 0 .164 .701 r
F P
0 g
s
.7638 .29723 m .74285 .33477 L .74598 .33892 L p .91 .974 .685 r
F P
0 g
s
.43082 .44987 m .42286 .44835 L .42316 .45265 L p .696 .288 .27 r
F P
0 g
s
.42316 .45265 m .4313 .45397 L .43082 .44987 L p .696 .288 .27 r
F P
0 g
s
.43885 .54556 m .4313 .54603 L .43082 .55013 L p .662 .819 .959 r
F P
0 g
s
.42286 .55165 m .43082 .55013 L .4313 .54603 L p .696 .848 .956 r
F P
0 g
s
.57003 .53018 m .57422 .53648 L .578 .53484 L p .891 .558 .409 r
F P
0 g
s
.58331 .54098 m .578 .53484 L .57422 .53648 L p .868 .51 .37 r
F P
0 g
s
.49117 .58498 m .49384 .59264 L .49741 .59022 L p .274 .305 .712 r
F P
0 g
s
.49741 .59022 m .49448 .58252 L .49117 .58498 L p .274 .305 .712 r
F P
0 g
s
.49112 .42426 m .49448 .41748 L .49117 .41502 L p .301 .137 .485 r
F P
0 g
s
.49384 .40736 m .49117 .41502 L .49448 .41748 L p .274 .143 .513 r
F P
0 g
s
.578 .46516 m .58331 .45902 L .57943 .45713 L p .868 .908 .856 r
F P
0 g
s
.57943 .45713 m .57422 .46352 L .578 .46516 L p .868 .908 .856 r
F P
0 g
s
.4313 .54603 m .42316 .54735 L .42286 .55165 L p .696 .848 .956 r
F P
0 g
s
.41418 .55418 m .42286 .55165 L .42316 .54735 L p .727 .873 .949 r
F P
0 g
s
.42286 .44835 m .41418 .44582 L .41433 .45038 L p .727 .314 .265 r
F P
0 g
s
.41433 .45038 m .42316 .45265 L .42286 .44835 L p .727 .314 .265 r
F P
0 g
s
.49384 .59264 m .49599 .60141 L .49986 .599 L p .25 .259 .674 r
F P
0 g
s
.49986 .599 m .49741 .59022 L .49384 .59264 L p .25 .259 .674 r
F P
0 g
s
.57422 .53648 m .57943 .54287 L .58331 .54098 L p .868 .51 .37 r
F P
0 g
s
.58983 .54723 m .58331 .54098 L .57943 .54287 L p .843 .464 .332 r
F P
0 g
s
.49448 .41748 m .49741 .40978 L .49384 .40736 L p .274 .143 .513 r
F P
0 g
s
.49599 .39859 m .49384 .40736 L .49741 .40978 L p .25 .15 .54 r
F P
0 g
s
.58331 .45902 m .58983 .45277 L .5858 .45062 L p .843 .913 .882 r
F P
0 g
s
.5858 .45062 m .57943 .45713 L .58331 .45902 L p .843 .913 .882 r
F P
0 g
s
.69436 .88945 m .67623 .89227 L .67206 .89333 L p .215 .739 .785 r
F P
0 g
s
.67623 .89227 m .69436 .88945 L .6979 .88815 L p .406 .854 .909 r
F P
0 g
s
.07113 .53743 m .0649 .52269 L .06554 .5264 L p 0 0 .472 r
F P
0 g
s
.06554 .5264 m .07217 .54351 L .07113 .53743 L p 0 0 .472 r
F P
0 g
s
.74009 .13695 m .7516 .15124 L .7546 .15433 L p .633 .15 0 r
F P
0 g
s
.7516 .15124 m .74009 .13695 L .7372 .13454 L p .756 .26 0 r
F P
0 g
s
.74685 .8527 m .7372 .86546 L .74009 .86305 L p .756 .974 .708 r
F P
0 g
s
.74009 .86305 m .7516 .84876 L .74685 .8527 L p .756 .974 .708 r
F P
0 g
s
.68202 .10987 m .6979 .11185 L .69436 .11055 L p .406 0 0 r
F P
0 g
s
.69436 .11055 m .67623 .10773 L .68202 .10987 L p .406 0 0 r
F P
0 g
s
.06554 .4736 m .07217 .45649 L .07334 .45235 L p 0 0 0 r
F P
0 g
s
.07217 .45649 m .06554 .4736 L .0649 .47731 L p 0 0 .069 r
F P
0 g
s
.72479 .12426 m .72879 .12861 L .73338 .13172 L p .63 .077 0 r
F P
0 g
s
.72879 .12861 m .72479 .12426 L .72198 .12248 L p .643 .086 0 r
F P
0 g
s
.71262 .11899 m .71595 .119 L .713 .11745 L p .558 0 0 r
F P
0 g
s
.713 .11745 m .70723 .11617 L .71262 .11899 L p .558 0 0 r
F P
0 g
s
.713 .88255 m .70723 .88383 L .70225 .88625 L p .489 .903 .843 r
F P
0 g
s
.70723 .88383 m .713 .88255 L .71595 .881 L p .558 .935 .862 r
F P
0 g
s
.72365 .87464 m .72198 .87752 L .72479 .87574 L p .643 .964 .813 r
F P
0 g
s
.72479 .87574 m .72879 .87139 L .72365 .87464 L p .643 .964 .813 r
F P
0 g
s
.06221 .49319 m .06397 .48755 L .06437 .48203 L p 0 0 .146 r
F P
0 g
s
.06397 .48755 m .06221 .49319 L .06207 .49652 L p 0 0 .227 r
F P
0 g
s
.06373 .50637 m .06207 .50348 L .06221 .50681 L p 0 0 .325 r
F P
0 g
s
.06221 .50681 m .06397 .51245 L .06373 .50637 L p 0 0 .325 r
F P
0 g
s
.76315 .82571 m .7516 .84876 L .7546 .84567 L p .85 .955 .609 r
F P
0 g
s
.7546 .84567 m .76758 .8212 L .76315 .82571 L p .85 .955 .609 r
F P
0 g
s
.6505 .10926 m .67623 .10773 L .67206 .10667 L p .286 0 0 r
F P
0 g
s
.67206 .10667 m .64438 .10767 L .6505 .10926 L p .286 0 0 r
F P
0 g
s
.08636 .56504 m .07217 .54351 L .07334 .54765 L p 0 .047 .615 r
F P
0 g
s
.07334 .54765 m .08804 .57113 L .08636 .56504 L p 0 .047 .615 r
F P
0 g
s
.76758 .1788 m .7546 .15433 L .7516 .15124 L p .85 .432 0 r
F P
0 g
s
.08804 .42887 m .07334 .45235 L .07217 .45649 L p 0 0 0 r
F P
0 g
s
.64438 .89233 m .67206 .89333 L .67623 .89227 L p .286 .76 .934 r
F P
0 g
s
.42316 .54735 m .41433 .54962 L .41418 .55418 L p .727 .873 .949 r
F P
0 g
s
.40464 .55785 m .41418 .55418 L .41433 .54962 L p .755 .894 .941 r
F P
0 g
s
.41418 .44582 m .40464 .44215 L .40465 .44705 L p .755 .339 .261 r
F P
0 g
s
.40465 .44705 m .41433 .45038 L .41418 .44582 L p .755 .339 .261 r
F P
0 g
s
.49599 .60141 m .49758 .61151 L .50182 .60904 L p .229 .217 .637 r
F P
0 g
s
.50182 .60904 m .49986 .599 L .49599 .60141 L p .229 .217 .637 r
F P
0 g
s
.57943 .54287 m .5858 .54938 L .58983 .54723 L p .843 .464 .332 r
F P
0 g
s
.59778 .55366 m .58983 .54723 L .5858 .54938 L p .818 .42 .297 r
F P
0 g
s
.49741 .40978 m .49986 .401 L .49599 .39859 L p .25 .15 .54 r
F P
0 g
s
.49758 .38849 m .49599 .39859 L .49986 .401 L p .229 .157 .564 r
F P
0 g
s
.58983 .45277 m .59778 .44634 L .59352 .4439 L p .818 .916 .904 r
F P
0 g
s
.59352 .4439 m .5858 .45062 L .58983 .45277 L p .818 .916 .904 r
F P
0 g
s
.72198 .12248 m .72365 .12536 L .72879 .12861 L p .643 .086 0 r
F P
0 g
s
.72365 .12536 m .72198 .12248 L .71899 .1207 L p .633 .071 0 r
F P
0 g
s
.71595 .881 m .71262 .88101 L .70723 .88383 L p .558 .935 .862 r
F P
0 g
s
.71262 .88101 m .71595 .881 L .71899 .8793 L p .605 .954 .862 r
F P
0 g
s
.71818 .8779 m .71899 .8793 L .72198 .87752 L p .633 .963 .846 r
F P
0 g
s
.72198 .87752 m .72365 .87464 L .71818 .8779 L p .633 .963 .846 r
F P
0 g
s
.06207 .49652 m .06373 .49363 L .06397 .48755 L p 0 0 .227 r
F P
0 g
s
.06373 .49363 m .06207 .49652 L .06203 .5 L p 0 0 .283 r
F P
0 g
s
.71818 .1221 m .71899 .1207 L .71595 .119 L p .605 .035 0 r
F P
0 g
s
.71595 .119 m .71262 .11899 L .71818 .1221 L p .605 .035 0 r
F P
0 g
s
.06364 .5 m .06203 .5 L .06207 .50348 L p 0 0 .315 r
F P
0 g
s
.06207 .50348 m .06373 .50637 L .06364 .5 L p 0 0 .315 r
F P
0 g
s
.71899 .8793 m .71818 .8779 L .71262 .88101 L p .605 .954 .862 r
F P
0 g
s
.71899 .1207 m .71818 .1221 L .72365 .12536 L p .633 .071 0 r
F P
0 g
s
.06203 .5 m .06364 .5 L .06373 .49363 L p 0 0 .283 r
F P
0 g
s
.41433 .54962 m .40465 .55295 L .40464 .55785 L p .755 .894 .941 r
F P
0 g
s
.39401 .56282 m .40464 .55785 L .40465 .55295 L p .777 .91 .931 r
F P
0 g
s
.40464 .44215 m .39401 .43718 L .39388 .44252 L p .777 .36 .258 r
F P
0 g
s
.39388 .44252 m .40465 .44705 L .40464 .44215 L p .777 .36 .258 r
F P
0 g
s
.5858 .54938 m .59352 .5561 L .59778 .55366 L p .818 .42 .297 r
F P
0 g
s
.6074 .56038 m .59778 .55366 L .59352 .5561 L p .794 .382 .268 r
F P
0 g
s
.49758 .61151 m .49859 .6232 L .50328 .62064 L p .211 .18 .604 r
F P
0 g
s
.50328 .62064 m .50182 .60904 L .49758 .61151 L p .211 .18 .604 r
F P
0 g
s
.49986 .401 m .50182 .39096 L .49758 .38849 L p .229 .157 .564 r
F P
0 g
s
.49859 .3768 m .49758 .38849 L .50182 .39096 L p .211 .165 .585 r
F P
0 g
s
.59778 .44634 m .6074 .43962 L .60283 .43684 L p .794 .915 .921 r
F P
0 g
s
.60283 .43684 m .59352 .4439 L .59778 .44634 L p .794 .915 .921 r
F P
0 g
s
.39401 .43718 m .38193 .43075 L .38166 .43664 L p .794 .377 .256 r
F P
0 g
s
.38166 .43664 m .39388 .44252 L .39401 .43718 L p .794 .377 .256 r
F P
0 g
s
.40465 .55295 m .39388 .55748 L .39401 .56282 L p .777 .91 .931 r
F P
0 g
s
.38193 .56925 m .39401 .56282 L .39388 .55748 L p .794 .92 .922 r
F P
0 g
s
.49859 .6232 m .49907 .63687 L .5043 .63416 L p .198 .153 .578 r
F P
0 g
s
.5043 .63416 m .50328 .62064 L .49859 .6232 L p .198 .153 .578 r
F P
0 g
s
.59352 .5561 m .60283 .56316 L .6074 .56038 L p .794 .382 .268 r
F P
0 g
s
.619 .56763 m .6074 .56038 L .60283 .56316 L p .775 .352 .245 r
F P
0 g
s
.6074 .43962 m .619 .43237 L .61404 .4292 L p .775 .914 .933 r
F P
0 g
s
.61404 .4292 m .60283 .43684 L .6074 .43962 L p .775 .914 .933 r
F P
0 g
s
.50182 .39096 m .50328 .37936 L .49859 .3768 L p .211 .165 .585 r
F P
0 g
s
.49907 .36313 m .49859 .3768 L .50328 .37936 L p .198 .171 .6 r
F P
0 g
s
.4693 .55317 m .47416 .55633 L .47746 .55153 L p .561 .6 .849 r
F P
0 g
s
.47746 .55153 m .47221 .54813 L .4693 .55317 L p .561 .6 .849 r
F P
0 g
s
.46414 .55054 m .4693 .55317 L .47221 .54813 L p .583 .628 .862 r
F P
0 g
s
.47416 .44367 m .4693 .44683 L .47221 .45187 L p .561 .316 .503 r
F P
0 g
s
.4693 .44683 m .46414 .44946 L .46664 .45471 L p .583 .324 .49 r
F P
0 g
s
.46664 .45471 m .47221 .45187 L .4693 .44683 L p .583 .324 .49 r
F P
0 g
s
.5617 .50578 m .56139 .5 L .55557 .5 L p .883 .711 .663 r
F P
0 g
s
.56139 .5 m .5617 .49422 L .5559 .49376 L p .883 .732 .689 r
F P
0 g
s
.5559 .49376 m .55557 .5 L .56139 .5 L p .883 .732 .689 r
F P
0 g
s
.47221 .54813 m .46664 .54529 L .46414 .55054 L p .583 .628 .862 r
F P
0 g
s
.45852 .5484 m .46414 .55054 L .46664 .54529 L p .606 .656 .873 r
F P
0 g
s
.47416 .55633 m .47882 .56012 L .48249 .5556 L p .539 .57 .834 r
F P
0 g
s
.48249 .5556 m .47746 .55153 L .47416 .55633 L p .539 .57 .834 r
F P
0 g
s
.47221 .45187 m .47746 .44847 L .47416 .44367 L p .561 .316 .503 r
F P
0 g
s
.47882 .43988 m .47416 .44367 L .47746 .44847 L p .539 .311 .517 r
F P
0 g
s
.46414 .44946 m .45852 .4516 L .4606 .45704 L p .606 .334 .478 r
F P
0 g
s
.4606 .45704 m .46664 .45471 L .46414 .44946 L p .606 .334 .478 r
F P
0 g
s
.55557 .5 m .5559 .50624 L .5617 .50578 L p .883 .711 .663 r
F P
0 g
s
.56266 .51172 m .5617 .50578 L .5559 .50624 L p .881 .688 .637 r
F P
0 g
s
.5617 .49422 m .56266 .48828 L .5569 .48736 L p .881 .751 .714 r
F P
0 g
s
.5569 .48736 m .5559 .49376 L .5617 .49422 L p .881 .751 .714 r
F P
0 g
s
.46664 .54529 m .4606 .54296 L .45852 .5484 L p .606 .656 .873 r
F P
0 g
s
.45243 .54681 m .45852 .5484 L .4606 .54296 L p .631 .684 .882 r
F P
0 g
s
.47882 .56012 m .48324 .5646 L .48725 .56034 L p .518 .538 .816 r
F P
0 g
s
.48725 .56034 m .48249 .5556 L .47882 .56012 L p .518 .538 .816 r
F P
0 g
s
.45852 .4516 m .45243 .45319 L .45412 .45879 L p .631 .346 .468 r
F P
0 g
s
.45412 .45879 m .4606 .45704 L .45852 .4516 L p .631 .346 .468 r
F P
0 g
s
.5559 .50624 m .5569 .51264 L .56266 .51172 L p .881 .688 .637 r
F P
0 g
s
.56432 .51779 m .56266 .51172 L .5569 .51264 L p .876 .662 .609 r
F P
0 g
s
.47746 .44847 m .48249 .4444 L .47882 .43988 L p .539 .311 .517 r
F P
0 g
s
.48324 .4354 m .47882 .43988 L .48249 .4444 L p .518 .307 .533 r
F P
0 g
s
.56266 .48828 m .56432 .48221 L .55863 .48087 L p .876 .768 .74 r
F P
0 g
s
.55863 .48087 m .5569 .48736 L .56266 .48828 L p .876 .768 .74 r
F P
0 g
s
.6979 .88815 m .68202 .89013 L .67623 .89227 L p .406 .854 .909 r
F P
0 g
s
.68202 .89013 m .6979 .88815 L .70225 .88625 L p .542 .908 .96 r
F P
0 g
s
.7372 .13454 m .74685 .1473 L .7516 .15124 L p .756 .26 0 r
F P
0 g
s
.74685 .1473 m .7372 .13454 L .73338 .13172 L p .807 .319 0 r
F P
0 g
s
.0649 .47731 m .07113 .46257 L .07217 .45649 L p 0 0 .069 r
F P
0 g
s
.07113 .46257 m .0649 .47731 L .06437 .48203 L p 0 0 .237 r
F P
0 g
s
.74056 .85733 m .73338 .86828 L .7372 .86546 L p .807 1 .807 r
F P
0 g
s
.7372 .86546 m .74685 .8527 L .74056 .85733 L p .807 1 .807 r
F P
0 g
s
.68918 .11301 m .70225 .11375 L .6979 .11185 L p .542 0 0 r
F P
0 g
s
.6979 .11185 m .68202 .10987 L .68918 .11301 L p .542 0 0 r
F P
0 g
s
.07026 .52966 m .06437 .51797 L .0649 .52269 L p 0 0 .543 r
F P
0 g
s
.0649 .52269 m .07113 .53743 L .07026 .52966 L p 0 0 .543 r
F P
0 g
s
.45243 .45319 m .44588 .45416 L .4472 .4599 L p .656 .361 .459 r
F P
0 g
s
.4472 .4599 m .45412 .45879 L .45243 .45319 L p .656 .361 .459 r
F P
0 g
s
.48324 .5646 m .48736 .56979 L .49168 .56577 L p .497 .505 .796 r
F P
0 g
s
.49168 .56577 m .48725 .56034 L .48324 .5646 L p .497 .505 .796 r
F P
0 g
s
.4606 .54296 m .45412 .54121 L .45243 .54681 L p .631 .684 .882 r
F P
0 g
s
.44588 .54584 m .45243 .54681 L .45412 .54121 L p .656 .711 .888 r
F P
0 g
s
.5569 .51264 m .55863 .51913 L .56432 .51779 L p .876 .662 .609 r
F P
0 g
s
.56676 .52394 m .56432 .51779 L .55863 .51913 L p .868 .633 .581 r
F P
0 g
s
.48249 .4444 m .48725 .43966 L .48324 .4354 L p .518 .307 .533 r
F P
0 g
s
.48736 .43021 m .48324 .4354 L .48725 .43966 L p .497 .306 .551 r
F P
0 g
s
.56432 .48221 m .56676 .47606 L .56112 .47432 L p .868 .784 .766 r
F P
0 g
s
.56112 .47432 m .55863 .48087 L .56432 .48221 L p .868 .784 .766 r
F P
0 g
s
.44588 .45416 m .43885 .45444 L .43985 .46035 L p .682 .377 .452 r
F P
0 g
s
.43985 .46035 m .4472 .4599 L .44588 .45416 L p .682 .377 .452 r
F P
0 g
s
.45412 .54121 m .4472 .5401 L .44588 .54584 L p .656 .711 .888 r
F P
0 g
s
.43885 .54556 m .44588 .54584 L .4472 .5401 L p .682 .737 .892 r
F P
0 g
s
.48736 .56979 m .49112 .57574 L .49574 .57192 L p .476 .471 .773 r
F P
0 g
s
.49574 .57192 m .49168 .56577 L .48736 .56979 L p .476 .471 .773 r
F P
0 g
s
.55863 .51913 m .56112 .52568 L .56676 .52394 L p .868 .633 .581 r
F P
0 g
s
.57003 .53018 m .56676 .52394 L .56112 .52568 L p .857 .603 .553 r
F P
0 g
s
.48725 .43966 m .49168 .43423 L .48736 .43021 L p .497 .306 .551 r
F P
0 g
s
.49112 .42426 m .48736 .43021 L .49168 .43423 L p .476 .306 .571 r
F P
0 g
s
.56676 .47606 m .57003 .46982 L .56441 .46773 L p .857 .797 .791 r
F P
0 g
s
.56441 .46773 m .56112 .47432 L .56676 .47606 L p .857 .797 .791 r
F P
0 g
s
.39388 .55748 m .38166 .56336 L .38193 .56925 L p .794 .92 .922 r
F P
0 g
s
.3679 .57727 m .38193 .56925 L .38166 .56336 L p .804 .926 .916 r
F P
0 g
s
.38193 .43075 m .3679 .42273 L .36747 .42928 L p .804 .386 .255 r
F P
0 g
s
.36747 .42928 m .38166 .43664 L .38193 .43075 L p .804 .386 .255 r
F P
0 g
s
.49907 .63687 m .49913 .65304 L .50502 .65013 L p .191 .136 .562 r
F P
0 g
s
.50502 .65013 m .5043 .63416 L .49907 .63687 L p .191 .136 .562 r
F P
0 g
s
.50328 .37936 m .5043 .36584 L .49907 .36313 L p .198 .171 .6 r
F P
0 g
s
.49913 .34696 m .49907 .36313 L .5043 .36584 L p .191 .175 .609 r
F P
0 g
s
.60283 .56316 m .61404 .5708 L .619 .56763 L p .775 .352 .245 r
F P
0 g
s
.63297 .57577 m .619 .56763 L .61404 .5708 L p .763 .334 .232 r
F P
0 g
s
.619 .43237 m .63297 .42423 L .62751 .42059 L p .763 .912 .94 r
F P
0 g
s
.62751 .42059 m .61404 .4292 L .619 .43237 L p .763 .912 .94 r
F P
0 g
s
.43885 .45444 m .4313 .45397 L .43202 .46009 L p .708 .395 .445 r
F P
0 g
s
.43202 .46009 m .43985 .46035 L .43885 .45444 L p .708 .395 .445 r
F P
0 g
s
.4472 .5401 m .43985 .53965 L .43885 .54556 L p .682 .737 .892 r
F P
0 g
s
.4313 .54603 m .43885 .54556 L .43985 .53965 L p .708 .761 .894 r
F P
0 g
s
.49112 .57574 m .49448 .58252 L .49942 .57883 L p .456 .437 .748 r
F P
0 g
s
.49942 .57883 m .49574 .57192 L .49112 .57574 L p .456 .437 .748 r
F P
0 g
s
.56112 .52568 m .56441 .53227 L .57003 .53018 L p .857 .603 .553 r
F P
0 g
s
.57422 .53648 m .57003 .53018 L .56441 .53227 L p .845 .571 .524 r
F P
0 g
s
.49168 .43423 m .49574 .42808 L .49112 .42426 L p .476 .306 .571 r
F P
0 g
s
.49448 .41748 m .49112 .42426 L .49574 .42808 L p .456 .308 .591 r
F P
0 g
s
.57003 .46982 m .57422 .46352 L .56856 .46109 L p .844 .808 .815 r
F P
0 g
s
.56856 .46109 m .56441 .46773 L .57003 .46982 L p .844 .808 .815 r
F P
0 g
s
.43985 .53965 m .43202 .53991 L .4313 .54603 L p .708 .761 .894 r
F P
0 g
s
.42316 .54735 m .4313 .54603 L .43202 .53991 L p .733 .784 .893 r
F P
0 g
s
.4313 .45397 m .42316 .45265 L .42366 .45904 L p .733 .413 .44 r
F P
0 g
s
.42366 .45904 m .43202 .46009 L .4313 .45397 L p .733 .413 .44 r
F P
0 g
s
.49448 .58252 m .49741 .59022 L .5027 .58659 L p .437 .402 .722 r
F P
0 g
s
.5027 .58659 m .49942 .57883 L .49448 .58252 L p .437 .402 .722 r
F P
0 g
s
.56441 .53227 m .56856 .53891 L .57422 .53648 L p .845 .571 .524 r
F P
0 g
s
.57943 .54287 m .57422 .53648 L .56856 .53891 L p .83 .538 .496 r
F P
0 g
s
.49574 .42808 m .49942 .42117 L .49448 .41748 L p .456 .308 .591 r
F P
0 g
s
.49741 .40978 m .49448 .41748 L .49942 .42117 L p .437 .311 .611 r
F P
0 g
s
.57422 .46352 m .57943 .45713 L .57364 .45436 L p .83 .817 .837 r
F P
0 g
s
.57364 .45436 m .56856 .46109 L .57422 .46352 L p .83 .817 .837 r
F P
0 g
s
.61833 .11949 m .6505 .10926 L .64438 .10767 L p .321 0 0 r
F P
0 g
s
.64438 .10767 m .61026 .11729 L .61833 .11949 L p .321 0 0 r
F P
0 g
s
.11343 .40414 m .08804 .42887 L .08636 .43496 L p .045 0 .071 r
F P
0 g
s
.07217 .45649 m .08636 .43496 L .08804 .42887 L p 0 0 0 r
F P
0 g
s
.77037 .79274 m .76315 .82571 L .76758 .8212 L p .971 .923 .605 r
F P
0 g
s
.76758 .8212 m .7763 .78685 L .77037 .79274 L p .971 .923 .605 r
F P
0 g
s
.7763 .21315 m .76758 .1788 L .76315 .17429 L p .971 .663 .286 r
F P
0 g
s
.7516 .15124 m .76315 .17429 L .76758 .1788 L p .85 .432 0 r
F P
0 g
s
.61026 .88271 m .64438 .89233 L .6505 .89074 L p .321 .699 .98 r
F P
0 g
s
.67623 .89227 m .6505 .89074 L .64438 .89233 L p .286 .76 .934 r
F P
0 g
s
.1113 .58778 m .08636 .56504 L .08804 .57113 L p .045 .343 .821 r
F P
0 g
s
.08804 .57113 m .11343 .59586 L .1113 .58778 L p .045 .343 .821 r
F P
0 g
s
.42316 .45265 m .41433 .45038 L .41464 .45715 L p .757 .432 .435 r
F P
0 g
s
.41464 .45715 m .42366 .45904 L .42316 .45265 L p .757 .432 .435 r
F P
0 g
s
.43202 .53991 m .42366 .54096 L .42316 .54735 L p .733 .784 .893 r
F P
0 g
s
.41433 .54962 m .42316 .54735 L .42366 .54096 L p .757 .804 .89 r
F P
0 g
s
.49741 .59022 m .49986 .599 L .50558 .59535 L p .419 .369 .695 r
F P
0 g
s
.50558 .59535 m .5027 .58659 L .49741 .59022 L p .419 .369 .695 r
F P
0 g
s
.56856 .53891 m .57364 .54564 L .57943 .54287 L p .83 .538 .496 r
F P
0 g
s
.5858 .54938 m .57943 .54287 L .57364 .54564 L p .813 .505 .468 r
F P
0 g
s
.49942 .42117 m .5027 .41341 L .49741 .40978 L p .437 .311 .611 r
F P
0 g
s
.49986 .401 m .49741 .40978 L .5027 .41341 L p .419 .315 .63 r
F P
0 g
s
.57943 .45713 m .5858 .45062 L .57979 .4475 L p .813 .823 .858 r
F P
0 g
s
.57979 .4475 m .57364 .45436 L .57943 .45713 L p .813 .823 .858 r
F P
0 g
s
.38166 .56336 m .36747 .57072 L .3679 .57727 L p .804 .926 .916 r
F P
0 g
s
.35117 .58694 m .3679 .57727 L .36747 .57072 L p .805 .927 .916 r
F P
0 g
s
.3679 .42273 m .35117 .41306 L .35055 .42039 L p .805 .388 .255 r
F P
0 g
s
.35055 .42039 m .36747 .42928 L .3679 .42273 L p .805 .388 .255 r
F P
0 g
s
.49913 .65304 m .49912 .67236 L .50578 .66923 L p .19 .134 .56 r
F P
0 g
s
.50578 .66923 m .50502 .65013 L .49913 .65304 L p .19 .134 .56 r
F P
0 g
s
.61404 .5708 m .62751 .57941 L .63297 .57577 L p .763 .334 .232 r
F P
0 g
s
.64971 .58542 m .63297 .57577 L .62751 .57941 L p .762 .332 .23 r
F P
0 g
s
.5043 .36584 m .50502 .34987 L .49913 .34696 L p .191 .175 .609 r
F P
0 g
s
.49912 .32764 m .49913 .34696 L .50502 .34987 L p .19 .175 .61 r
F P
0 g
s
.63297 .42423 m .64971 .41458 L .64366 .41038 L p .762 .912 .941 r
F P
0 g
s
.64366 .41038 m .62751 .42059 L .63297 .42423 L p .762 .912 .941 r
F P
0 g
s
.73338 .13172 m .74056 .14267 L .74685 .1473 L p .807 .319 0 r
F P
0 g
s
.74056 .14267 m .73338 .13172 L .72879 .12861 L p .816 .338 .061 r
F P
0 g
s
.70225 .88625 m .68918 .88699 L .68202 .89013 L p .542 .908 .96 r
F P
0 g
s
.68918 .88699 m .70225 .88625 L .70723 .88383 L p .633 .931 .969 r
F P
0 g
s
.06437 .48203 m .07026 .47034 L .07113 .46257 L p 0 0 .237 r
F P
0 g
s
.07026 .47034 m .06437 .48203 L .06397 .48755 L p 0 0 .357 r
F P
0 g
s
.69739 .117 m .70723 .11617 L .70225 .11375 L p .633 .103 0 r
F P
0 g
s
.70225 .11375 m .68918 .11301 L .69739 .117 L p .633 .103 0 r
F P
0 g
s
.733 .86244 m .72879 .87139 L .73338 .86828 L p .816 .994 .864 r
F P
0 g
s
.73338 .86828 m .74056 .85733 L .733 .86244 L p .816 .994 .864 r
F P
0 g
s
.06962 .52056 m .06397 .51245 L .06437 .51797 L p 0 .035 .568 r
F P
0 g
s
.06437 .51797 m .07026 .52966 L .06962 .52056 L p 0 .035 .568 r
F P
0 g
s
.08636 .43496 m .07217 .45649 L .07113 .46257 L p 0 0 .22 r
F P
0 g
s
.76315 .17429 m .7516 .15124 L .74685 .1473 L p .913 .511 .177 r
F P
0 g
s
.6505 .89074 m .67623 .89227 L .68202 .89013 L p .489 .834 .997 r
F P
0 g
s
.65906 .11246 m .68202 .10987 L .67623 .10773 L p .489 0 0 r
F P
0 g
s
.67623 .10773 m .6505 .10926 L .65906 .11246 L p .489 0 0 r
F P
0 g
s
.08485 .55601 m .07113 .53743 L .07217 .54351 L p 0 .193 .71 r
F P
0 g
s
.07217 .54351 m .08636 .56504 L .08485 .55601 L p 0 .193 .71 r
F P
0 g
s
.75608 .83152 m .74685 .8527 L .7516 .84876 L p .913 .981 .752 r
F P
0 g
s
.7516 .84876 m .76315 .82571 L .75608 .83152 L p .913 .981 .752 r
F P
0 g
s
.41433 .45038 m .40465 .44705 L .40479 .45432 L p .778 .449 .431 r
F P
0 g
s
.40479 .45432 m .41464 .45715 L .41433 .45038 L p .778 .449 .431 r
F P
0 g
s
.42366 .54096 m .41464 .54285 L .41433 .54962 L p .757 .804 .89 r
F P
0 g
s
.40465 .55295 m .41433 .54962 L .41464 .54285 L p .778 .821 .886 r
F P
0 g
s
.49986 .599 m .50182 .60904 L .50805 .60529 L p .402 .337 .669 r
F P
0 g
s
.50805 .60529 m .50558 .59535 L .49986 .599 L p .402 .337 .669 r
F P
0 g
s
.57364 .54564 m .57979 .5525 L .5858 .54938 L p .813 .505 .468 r
F P
0 g
s
.59352 .5561 m .5858 .54938 L .57979 .5525 L p .796 .473 .442 r
F P
0 g
s
.5027 .41341 m .50558 .40465 L .49986 .401 L p .419 .315 .63 r
F P
0 g
s
.50182 .39096 m .49986 .401 L .50558 .40465 L p .402 .32 .648 r
F P
0 g
s
.5858 .45062 m .59352 .4439 L .58716 .44039 L p .796 .827 .876 r
F P
0 g
s
.58716 .44039 m .57979 .4475 L .5858 .45062 L p .796 .827 .876 r
F P
0 g
s
.47221 .54813 m .47746 .55153 L .482 .54505 L p .617 .597 .808 r
F P
0 g
s
.482 .54505 m .47618 .54126 L .47221 .54813 L p .617 .597 .808 r
F P
0 g
s
.47746 .44847 m .47221 .45187 L .47618 .45874 L p .617 .411 .58 r
F P
0 g
s
.46664 .54529 m .47221 .54813 L .47618 .54126 L p .633 .618 .817 r
F P
0 g
s
.47221 .45187 m .46664 .45471 L .46998 .46189 L p .633 .416 .57 r
F P
0 g
s
.46998 .46189 m .47618 .45874 L .47221 .45187 L p .633 .416 .57 r
F P
0 g
s
.55557 .5 m .5559 .49376 L .54801 .49306 L p .831 .686 .703 r
F P
0 g
s
.54801 .49306 m .54764 .5 L .55557 .5 L p .831 .686 .703 r
F P
0 g
s
.5559 .50624 m .55557 .5 L .54764 .5 L p .831 .671 .684 r
F P
0 g
s
.47618 .54126 m .46998 .53811 L .46664 .54529 L p .633 .618 .817 r
F P
0 g
s
.4606 .54296 m .46664 .54529 L .46998 .53811 L p .65 .638 .825 r
F P
0 g
s
.47746 .55153 m .48249 .5556 L .48754 .54956 L p .602 .575 .797 r
F P
0 g
s
.48754 .54956 m .482 .54505 L .47746 .55153 L p .602 .575 .797 r
F P
0 g
s
.46664 .45471 m .4606 .45704 L .46331 .46443 L p .65 .424 .562 r
F P
0 g
s
.46331 .46443 m .46998 .46189 L .46664 .45471 L p .65 .424 .562 r
F P
0 g
s
.47618 .45874 m .482 .45495 L .47746 .44847 L p .617 .411 .58 r
F P
0 g
s
.48249 .4444 m .47746 .44847 L .482 .45495 L p .602 .407 .59 r
F P
0 g
s
.5559 .49376 m .5569 .48736 L .54915 .48601 L p .829 .7 .722 r
F P
0 g
s
.54915 .48601 m .54801 .49306 L .5559 .49376 L p .829 .7 .722 r
F P
0 g
s
.54764 .5 m .54801 .50694 L .5559 .50624 L p .831 .671 .684 r
F P
0 g
s
.5569 .51264 m .5559 .50624 L .54801 .50694 L p .829 .654 .665 r
F P
0 g
s
.48249 .5556 m .48725 .56034 L .49271 .55474 L p .586 .552 .784 r
F P
0 g
s
.49271 .55474 m .48754 .54956 L .48249 .5556 L p .586 .552 .784 r
F P
0 g
s
.4606 .45704 m .45412 .45879 L .45624 .46632 L p .668 .433 .555 r
F P
0 g
s
.45624 .46632 m .46331 .46443 L .4606 .45704 L p .668 .433 .555 r
F P
0 g
s
.46998 .53811 m .46331 .53557 L .4606 .54296 L p .65 .638 .825 r
F P
0 g
s
.45412 .54121 m .4606 .54296 L .46331 .53557 L p .668 .658 .831 r
F P
0 g
s
.54801 .50694 m .54915 .51399 L .5569 .51264 L p .829 .654 .665 r
F P
0 g
s
.55863 .51913 m .5569 .51264 L .54915 .51399 L p .825 .635 .646 r
F P
0 g
s
.482 .45495 m .48754 .45044 L .48249 .4444 L p .602 .407 .59 r
F P
0 g
s
.48725 .43966 m .48249 .4444 L .48754 .45044 L p .586 .405 .603 r
F P
0 g
s
.5569 .48736 m .55863 .48087 L .55105 .47894 L p .825 .712 .74 r
F P
0 g
s
.55105 .47894 m .54915 .48601 L .5569 .48736 L p .825 .712 .74 r
F P
0 g
s
.36747 .57072 m .35055 .57961 L .35117 .58694 L p .805 .927 .916 r
F P
0 g
s
.33073 .59805 m .35117 .58694 L .35055 .57961 L p .796 .922 .921 r
F P
0 g
s
.35117 .41306 m .33073 .40195 L .32987 .41018 L p .796 .378 .255 r
F P
0 g
s
.32987 .41018 m .35055 .42039 L .35117 .41306 L p .796 .378 .255 r
F P
0 g
s
.49912 .67236 m .49972 .69562 L .50728 .69225 L p .196 .149 .575 r
F P
0 g
s
.50728 .69225 m .50578 .66923 L .49912 .67236 L p .196 .149 .575 r
F P
0 g
s
.62751 .57941 m .64366 .58962 L .64971 .58542 L p .762 .332 .23 r
F P
0 g
s
.66955 .59757 m .64971 .58542 L .64366 .58962 L p .773 .348 .242 r
F P
0 g
s
.50502 .34987 m .50578 .33077 L .49912 .32764 L p .19 .175 .61 r
F P
0 g
s
.49972 .30438 m .49912 .32764 L .50578 .33077 L p .196 .171 .602 r
F P
0 g
s
.64971 .41458 m .66955 .40243 L .66285 .39758 L p .773 .914 .935 r
F P
0 g
s
.66285 .39758 m .64366 .41038 L .64971 .41458 L p .773 .914 .935 r
F P
0 g
s
.46331 .53557 m .45624 .53368 L .45412 .54121 L p .668 .658 .831 r
F P
0 g
s
.45412 .45879 m .4472 .4599 L .44881 .46755 L p .687 .444 .549 r
F P
0 g
s
.44881 .46755 m .45624 .46632 L .45412 .45879 L p .687 .444 .549 r
F P
0 g
s
.4472 .5401 m .45412 .54121 L .45624 .53368 L p .687 .678 .836 r
F P
0 g
s
.54915 .51399 m .55105 .52106 L .55863 .51913 L p .825 .635 .646 r
F P
0 g
s
.56112 .52568 m .55863 .51913 L .55105 .52106 L p .819 .614 .625 r
F P
0 g
s
.48725 .56034 m .49168 .56577 L .4975 .56055 L p .571 .528 .769 r
F P
0 g
s
.4975 .56055 m .49271 .55474 L .48725 .56034 L p .571 .528 .769 r
F P
0 g
s
.48754 .45044 m .49271 .44526 L .48725 .43966 L p .586 .405 .603 r
F P
0 g
s
.49168 .43423 m .48725 .43966 L .49271 .44526 L p .571 .404 .616 r
F P
0 g
s
.55863 .48087 m .56112 .47432 L .55369 .47189 L p .819 .724 .76 r
F P
0 g
s
.55369 .47189 m .55105 .47894 L .55863 .48087 L p .819 .724 .76 r
F P
0 g
s
.06397 .48755 m .06962 .47944 L .07026 .47034 L p 0 0 .357 r
F P
0 g
s
.06962 .47944 m .06397 .48755 L .06373 .49363 L p .009 0 .441 r
F P
0 g
s
.72879 .12861 m .733 .13756 L .74056 .14267 L p .816 .338 .061 r
F P
0 g
s
.733 .13756 m .72879 .12861 L .72365 .12536 L p .802 .331 .106 r
F P
0 g
s
.70723 .88383 m .69739 .883 L .68918 .88699 L p .633 .931 .969 r
F P
0 g
s
.69739 .883 m .70723 .88383 L .71262 .88101 L p .696 .943 .961 r
F P
0 g
s
.70628 .12167 m .71262 .11899 L .70723 .11617 L p .696 .194 .044 r
F P
0 g
s
.70723 .11617 m .69739 .117 L .70628 .12167 L p .696 .194 .044 r
F P
0 g
s
.7245 .86781 m .72365 .87464 L .72879 .87139 L p .802 .979 .899 r
F P
0 g
s
.72879 .87139 m .733 .86244 L .7245 .86781 L p .802 .979 .899 r
F P
0 g
s
.06921 .51052 m .06373 .50637 L .06397 .51245 L p .009 .057 .564 r
F P
0 g
s
.06397 .51245 m .06962 .52056 L .06921 .51052 L p .009 .057 .564 r
F P
0 g
s
.45624 .53368 m .44881 .53245 L .4472 .5401 L p .687 .678 .836 r
F P
0 g
s
.43985 .53965 m .4472 .5401 L .44881 .53245 L p .707 .698 .839 r
F P
0 g
s
.4472 .4599 m .43985 .46035 L .44104 .46814 L p .707 .457 .544 r
F P
0 g
s
.44104 .46814 m .44881 .46755 L .4472 .4599 L p .707 .457 .544 r
F P
0 g
s
.49168 .56577 m .49574 .57192 L .50189 .56699 L p .556 .503 .752 r
F P
0 g
s
.50189 .56699 m .4975 .56055 L .49168 .56577 L p .556 .503 .752 r
F P
0 g
s
.55105 .52106 m .55369 .52811 L .56112 .52568 L p .819 .614 .625 r
F P
0 g
s
.56441 .53227 m .56112 .52568 L .55369 .52811 L p .811 .591 .604 r
F P
0 g
s
.49271 .44526 m .4975 .43945 L .49168 .43423 L p .571 .404 .616 r
F P
0 g
s
.49574 .42808 m .49168 .43423 L .4975 .43945 L p .556 .405 .631 r
F P
0 g
s
.56112 .47432 m .56441 .46773 L .55707 .46487 L p .811 .734 .779 r
F P
0 g
s
.55707 .46487 m .55369 .47189 L .56112 .47432 L p .811 .734 .779 r
F P
0 g
s
.40465 .44705 m .39388 .44252 L .39387 .45044 L p .796 .465 .428 r
F P
0 g
s
.39387 .45044 m .40479 .45432 L .40465 .44705 L p .796 .465 .428 r
F P
0 g
s
.41464 .54285 m .40479 .54568 L .40465 .55295 L p .778 .821 .886 r
F P
0 g
s
.39388 .55748 m .40465 .55295 L .40479 .54568 L p .796 .835 .881 r
F P
0 g
s
.57979 .5525 m .58716 .55961 L .59352 .5561 L p .796 .473 .442 r
F P
0 g
s
.60283 .56316 m .59352 .5561 L .58716 .55961 L p .78 .445 .419 r
F P
0 g
s
.50182 .60904 m .50328 .62064 L .51014 .61669 L p .388 .31 .646 r
F P
0 g
s
.51014 .61669 m .50805 .60529 L .50182 .60904 L p .388 .31 .646 r
F P
0 g
s
.50558 .40465 m .50805 .39471 L .50182 .39096 L p .402 .32 .648 r
F P
0 g
s
.50328 .37936 m .50182 .39096 L .50805 .39471 L p .388 .324 .664 r
F P
0 g
s
.59352 .4439 m .60283 .43684 L .59598 .43287 L p .78 .829 .89 r
F P
0 g
s
.59598 .43287 m .58716 .44039 L .59352 .4439 L p .78 .829 .89 r
F P
0 g
s
.44881 .53245 m .44104 .53186 L .43985 .53965 L p .707 .698 .839 r
F P
0 g
s
.43202 .53991 m .43985 .53965 L .44104 .53186 L p .727 .716 .84 r
F P
0 g
s
.43985 .46035 m .43202 .46009 L .43288 .46807 L p .727 .471 .539 r
F P
0 g
s
.43288 .46807 m .44104 .46814 L .43985 .46035 L p .727 .471 .539 r
F P
0 g
s
.49574 .57192 m .49942 .57883 L .50591 .57409 L p .541 .477 .733 r
F P
0 g
s
.50591 .57409 m .50189 .56699 L .49574 .57192 L p .541 .477 .733 r
F P
0 g
s
.55369 .52811 m .55707 .53513 L .56441 .53227 L p .811 .591 .604 r
F P
0 g
s
.56856 .53891 m .56441 .53227 L .55707 .53513 L p .802 .567 .583 r
F P
0 g
s
.4975 .43945 m .50189 .43301 L .49574 .42808 L p .556 .405 .631 r
F P
0 g
s
.49942 .42117 m .49574 .42808 L .50189 .43301 L p .541 .406 .647 r
F P
0 g
s
.56441 .46773 m .56856 .46109 L .56121 .45784 L p .802 .742 .797 r
F P
0 g
s
.56121 .45784 m .55707 .46487 L .56441 .46773 L p .802 .742 .797 r
F P
0 g
s
.71546 .12681 m .71818 .1221 L .71262 .11899 L p .742 .259 .096 r
F P
0 g
s
.71262 .11899 m .70628 .12167 L .71546 .12681 L p .742 .259 .096 r
F P
0 g
s
.71262 .88101 m .70628 .87833 L .69739 .883 L p .696 .943 .961 r
F P
0 g
s
.70628 .87833 m .71262 .88101 L .71818 .8779 L p .742 .952 .945 r
F P
0 g
s
.71546 .87319 m .71818 .8779 L .72365 .87464 L p .777 .964 .925 r
F P
0 g
s
.72365 .87464 m .7245 .86781 L .71546 .87319 L p .777 .964 .925 r
F P
0 g
s
.72365 .12536 m .7245 .13219 L .733 .13756 L p .802 .331 .106 r
F P
0 g
s
.7245 .13219 m .72365 .12536 L .71818 .1221 L p .777 .304 .116 r
F P
0 g
s
.06908 .5 m .06364 .5 L .06373 .50637 L p .042 .051 .54 r
F P
0 g
s
.06373 .50637 m .06921 .51052 L .06908 .5 L p .042 .051 .54 r
F P
0 g
s
.06373 .49363 m .06921 .48948 L .06962 .47944 L p .009 0 .441 r
F P
0 g
s
.06921 .48948 m .06373 .49363 L .06364 .5 L p .042 .018 .5 r
F P
0 g
s
.71818 .8779 m .71546 .87319 L .70628 .87833 L p .742 .952 .945 r
F P
0 g
s
.71818 .1221 m .71546 .12681 L .7245 .13219 L p .777 .304 .116 r
F P
0 g
s
.06364 .5 m .06908 .5 L .06921 .48948 L p .042 .018 .5 r
F P
0 g
s
.43202 .46009 m .42366 .45904 L .42426 .46734 L p .747 .485 .536 r
F P
0 g
s
.42426 .46734 m .43288 .46807 L .43202 .46009 L p .747 .485 .536 r
F P
0 g
s
.44104 .53186 m .43288 .53193 L .43202 .53991 L p .727 .716 .84 r
F P
0 g
s
.42366 .54096 m .43202 .53991 L .43288 .53193 L p .746 .734 .84 r
F P
0 g
s
.55707 .53513 m .56121 .54216 L .56856 .53891 L p .802 .567 .583 r
F P
0 g
s
.57364 .54564 m .56856 .53891 L .56121 .54216 L p .791 .542 .561 r
F P
0 g
s
.49942 .57883 m .5027 .58659 L .50959 .58193 L p .527 .451 .714 r
F P
0 g
s
.50959 .58193 m .50591 .57409 L .49942 .57883 L p .527 .451 .714 r
F P
0 g
s
.50189 .43301 m .50591 .42591 L .49942 .42117 L p .541 .406 .647 r
F P
0 g
s
.5027 .41341 m .49942 .42117 L .50591 .42591 L p .527 .409 .662 r
F P
0 g
s
.56856 .46109 m .57364 .45436 L .56615 .45073 L p .791 .749 .815 r
F P
0 g
s
.56615 .45073 m .56121 .45784 L .56856 .46109 L p .791 .749 .815 r
F P
0 g
s
.76854 .7522 m .77037 .79274 L .7763 .78685 L p .997 .826 .554 r
F P
0 g
s
.7763 .78685 m .77574 .74533 L .76854 .7522 L p .997 .826 .554 r
F P
0 g
s
.58414 .14134 m .61833 .11949 L .61026 .11729 L p .323 0 .134 r
F P
0 g
s
.61026 .11729 m .57459 .13853 L .58414 .14134 L p .323 0 .134 r
F P
0 g
s
.77574 .25467 m .7763 .21315 L .77037 .20726 L p .997 .801 .523 r
F P
0 g
s
.76315 .17429 m .77037 .20726 L .7763 .21315 L p .971 .663 .286 r
F P
0 g
s
.57459 .86147 m .61026 .88271 L .61833 .88051 L p .323 .593 .943 r
F P
0 g
s
.6505 .89074 m .61833 .88051 L .61026 .88271 L p .321 .699 .98 r
F P
0 g
s
.14966 .38387 m .11343 .40414 L .1113 .41222 L p .296 0 .149 r
F P
0 g
s
.08636 .43496 m .1113 .41222 L .11343 .40414 L p .045 0 .071 r
F P
0 g
s
.14732 .60647 m .1113 .58778 L .11343 .59586 L p .296 .56 .928 r
F P
0 g
s
.11343 .59586 m .14966 .61613 L .14732 .60647 L p .296 .56 .928 r
F P
0 g
s
.35055 .57961 m .32987 .58982 L .33073 .59805 L p .796 .922 .921 r
F P
0 g
s
.30531 .60986 m .33073 .59805 L .32987 .58982 L p .774 .909 .933 r
F P
0 g
s
.33073 .40195 m .30531 .39014 L .30415 .3993 L p .774 .355 .255 r
F P
0 g
s
.30415 .3993 m .32987 .41018 L .33073 .40195 L p .774 .355 .255 r
F P
0 g
s
.64366 .58962 m .66285 .60242 L .66955 .59757 L p .773 .348 .242 r
F P
0 g
s
.69249 .61367 m .66955 .59757 L .66285 .60242 L p .797 .385 .268 r
F P
0 g
s
.49972 .69562 m .5022 .72354 L .51071 .71996 L p .21 .182 .607 r
F P
0 g
s
.51071 .71996 m .50728 .69225 L .49972 .69562 L p .21 .182 .607 r
F P
0 g
s
.66955 .40243 m .69249 .38633 L .68514 .38074 L p .797 .917 .919 r
F P
0 g
s
.68514 .38074 m .66285 .39758 L .66955 .40243 L p .797 .917 .919 r
F P
0 g
s
.50578 .33077 m .50728 .30775 L .49972 .30438 L p .196 .171 .602 r
F P
0 g
s
.5022 .27646 m .49972 .30438 L .50728 .30775 L p .21 .16 .58 r
F P
0 g
s
.40479 .54568 m .39387 .54956 L .39388 .55748 L p .796 .835 .881 r
F P
0 g
s
.38166 .56336 m .39388 .55748 L .39387 .54956 L p .809 .845 .877 r
F P
0 g
s
.39388 .44252 m .38166 .43664 L .3815 .44538 L p .809 .477 .426 r
F P
0 g
s
.3815 .44538 m .39387 .45044 L .39388 .44252 L p .809 .477 .426 r
F P
0 g
s
.58716 .55961 m .59598 .56713 L .60283 .56316 L p .78 .445 .419 r
F P
0 g
s
.61404 .5708 m .60283 .56316 L .59598 .56713 L p .767 .423 .402 r
F P
0 g
s
.50328 .62064 m .5043 .63416 L .51194 .62993 L p .377 .288 .627 r
F P
0 g
s
.51194 .62993 m .51014 .61669 L .50328 .62064 L p .377 .288 .627 r
F P
0 g
s
.50805 .39471 m .51014 .38331 L .50328 .37936 L p .388 .324 .664 r
F P
0 g
s
.5043 .36584 m .50328 .37936 L .51014 .38331 L p .377 .328 .676 r
F P
0 g
s
.60283 .43684 m .61404 .4292 L .60655 .42469 L p .767 .83 .901 r
F P
0 g
s
.60655 .42469 m .59598 .43287 L .60283 .43684 L p .767 .83 .901 r
F P
0 g
s
.42366 .45904 m .41464 .45715 L .41503 .4659 L p .765 .5 .532 r
F P
0 g
s
.41503 .4659 m .42426 .46734 L .42366 .45904 L p .765 .5 .532 r
F P
0 g
s
.43288 .53193 m .42426 .53266 L .42366 .54096 L p .746 .734 .84 r
F P
0 g
s
.41464 .54285 m .42366 .54096 L .42426 .53266 L p .765 .75 .839 r
F P
0 g
s
.5027 .58659 m .50558 .59535 L .51296 .59064 L p .513 .425 .693 r
F P
0 g
s
.51296 .59064 m .50959 .58193 L .5027 .58659 L p .513 .425 .693 r
F P
0 g
s
.56121 .54216 m .56615 .54927 L .57364 .54564 L p .791 .542 .561 r
F P
0 g
s
.57979 .5525 m .57364 .54564 L .56615 .54927 L p .779 .517 .54 r
F P
0 g
s
.50591 .42591 m .50959 .41807 L .5027 .41341 L p .527 .409 .662 r
F P
0 g
s
.50558 .40465 m .5027 .41341 L .50959 .41807 L p .513 .412 .678 r
F P
0 g
s
.57364 .45436 m .57979 .4475 L .57202 .44346 L p .779 .755 .832 r
F P
0 g
s
.57202 .44346 m .56615 .45073 L .57364 .45436 L p .779 .755 .832 r
F P
0 g
s
.47618 .54126 m .482 .54505 L .48802 .53681 L p .652 .592 .774 r
F P
0 g
s
.48802 .53681 m .48132 .53235 L .47618 .54126 L p .652 .592 .774 r
F P
0 g
s
.46998 .53811 m .47618 .54126 L .48132 .53235 L p .664 .606 .781 r
F P
0 g
s
.47618 .45874 m .46998 .46189 L .47411 .47122 L p .664 .478 .623 r
F P
0 g
s
.47411 .47122 m .48132 .46765 L .47618 .45874 L p .664 .478 .623 r
F P
0 g
s
.482 .45495 m .47618 .45874 L .48132 .46765 L p .652 .474 .629 r
F P
0 g
s
.54764 .5 m .54801 .49306 L .53787 .49197 L p .789 .65 .708 r
F P
0 g
s
.53787 .49197 m .53736 .5 L .54764 .5 L p .789 .65 .708 r
F P
0 g
s
.54801 .50694 m .54764 .5 L .53736 .5 L p .789 .639 .695 r
F P
0 g
s
.482 .54505 m .48754 .54956 L .49419 .54209 L p .641 .576 .766 r
F P
0 g
s
.49419 .54209 m .48802 .53681 L .482 .54505 L p .641 .576 .766 r
F P
0 g
s
.46998 .46189 m .46331 .46443 L .46645 .47392 L p .676 .483 .617 r
F P
0 g
s
.46645 .47392 m .47411 .47122 L .46998 .46189 L p .676 .483 .617 r
F P
0 g
s
.48132 .53235 m .47411 .52878 L .46998 .53811 L p .664 .606 .781 r
F P
0 g
s
.46331 .53557 m .46998 .53811 L .47411 .52878 L p .676 .621 .786 r
F P
0 g
s
.53736 .5 m .53787 .50803 L .54801 .50694 L p .789 .639 .695 r
F P
0 g
s
.54915 .51399 m .54801 .50694 L .53787 .50803 L p .787 .626 .681 r
F P
0 g
s
.48132 .46765 m .48802 .46319 L .482 .45495 L p .652 .474 .629 r
F P
0 g
s
.48754 .45044 m .482 .45495 L .48802 .46319 L p .641 .471 .637 r
F P
0 g
s
.54801 .49306 m .54915 .48601 L .53936 .48398 L p .787 .659 .722 r
F P
0 g
s
.53936 .48398 m .53787 .49197 L .54801 .49306 L p .787 .659 .722 r
F P
0 g
s
.74685 .1473 m .75608 .16848 L .76315 .17429 L p .913 .511 .177 r
F P
0 g
s
.75608 .16848 m .74685 .1473 L .74056 .14267 L p .906 .525 .293 r
F P
0 g
s
.74669 .8384 m .74056 .85733 L .74685 .8527 L p .906 .954 .818 r
F P
0 g
s
.74685 .8527 m .75608 .83152 L .74669 .8384 L p .906 .954 .818 r
F P
0 g
s
.68202 .89013 m .65906 .88754 L .6505 .89074 L p .489 .834 .997 r
F P
0 g
s
.65906 .88754 m .68202 .89013 L .68918 .88699 L p .607 .851 .99 r
F P
0 g
s
.07113 .46257 m .08485 .44399 L .08636 .43496 L p 0 0 .22 r
F P
0 g
s
.08485 .44399 m .07113 .46257 L .07026 .47034 L p .153 0 .383 r
F P
0 g
s
.66972 .11716 m .68918 .11301 L .68202 .10987 L p .607 .141 .12 r
F P
0 g
s
.68202 .10987 m .65906 .11246 L .66972 .11716 L p .607 .141 .12 r
F P
0 g
s
.0836 .54444 m .07026 .52966 L .07113 .53743 L p .153 .265 .727 r
F P
0 g
s
.07113 .53743 m .08485 .55601 L .0836 .54444 L p .153 .265 .727 r
F P
0 g
s
.46331 .46443 m .45624 .46632 L .45854 .47581 L p .69 .491 .612 r
F P
0 g
s
.45854 .47581 m .46645 .47392 L .46331 .46443 L p .69 .491 .612 r
F P
0 g
s
.48754 .54956 m .49271 .55474 L .49978 .548 L p .63 .559 .756 r
F P
0 g
s
.49978 .548 m .49419 .54209 L .48754 .54956 L p .63 .559 .756 r
F P
0 g
s
.47411 .52878 m .46645 .52608 L .46331 .53557 L p .676 .621 .786 r
F P
0 g
s
.45624 .53368 m .46331 .53557 L .46645 .52608 L p .69 .636 .79 r
F P
0 g
s
.53787 .50803 m .53936 .51602 L .54915 .51399 L p .787 .626 .681 r
F P
0 g
s
.55105 .52106 m .54915 .51399 L .53936 .51602 L p .784 .612 .667 r
F P
0 g
s
.54915 .48601 m .55105 .47894 L .54168 .47619 L p .784 .669 .736 r
F P
0 g
s
.54168 .47619 m .53936 .48398 L .54915 .48601 L p .784 .669 .736 r
F P
0 g
s
.48802 .46319 m .49419 .45791 L .48754 .45044 L p .641 .471 .637 r
F P
0 g
s
.49271 .44526 m .48754 .45044 L .49419 .45791 L p .63 .47 .647 r
F P
0 g
s
.46645 .52608 m .45854 .52419 L .45624 .53368 L p .69 .636 .79 r
F P
0 g
s
.44881 .53245 m .45624 .53368 L .45854 .52419 L p .704 .651 .794 r
F P
0 g
s
.45624 .46632 m .44881 .46755 L .45048 .47701 L p .704 .5 .608 r
F P
0 g
s
.45048 .47701 m .45854 .47581 L .45624 .46632 L p .704 .5 .608 r
F P
0 g
s
.49271 .55474 m .4975 .56055 L .50485 .55439 L p .619 .541 .744 r
F P
0 g
s
.50485 .55439 m .49978 .548 L .49271 .55474 L p .619 .541 .744 r
F P
0 g
s
.53936 .51602 m .54168 .52381 L .55105 .52106 L p .784 .612 .667 r
F P
0 g
s
.55369 .52811 m .55105 .52106 L .54168 .52381 L p .78 .596 .652 r
F P
0 g
s
.49419 .45791 m .49978 .452 L .49271 .44526 L p .63 .47 .647 r
F P
0 g
s
.4975 .43945 m .49271 .44526 L .49978 .452 L p .619 .47 .658 r
F P
0 g
s
.55105 .47894 m .55369 .47189 L .54468 .46861 L p .78 .677 .75 r
F P
0 g
s
.54468 .46861 m .54168 .47619 L .55105 .47894 L p .78 .677 .75 r
F P
0 g
s
.45854 .52419 m .45048 .52299 L .44881 .53245 L p .704 .651 .794 r
F P
0 g
s
.44104 .53186 m .44881 .53245 L .45048 .52299 L p .72 .666 .796 r
F P
0 g
s
.44881 .46755 m .44104 .46814 L .44223 .47761 L p .72 .51 .605 r
F P
0 g
s
.44223 .47761 m .45048 .47701 L .44881 .46755 L p .72 .51 .605 r
F P
0 g
s
.4975 .56055 m .50189 .56699 L .50949 .56123 L p .608 .521 .731 r
F P
0 g
s
.50949 .56123 m .50485 .55439 L .4975 .56055 L p .608 .521 .731 r
F P
0 g
s
.54168 .52381 m .54468 .53139 L .55369 .52811 L p .78 .596 .652 r
F P
0 g
s
.55707 .53513 m .55369 .52811 L .54468 .53139 L p .773 .578 .635 r
F P
0 g
s
.55369 .47189 m .55707 .46487 L .54828 .46117 L p .773 .684 .765 r
F P
0 g
s
.54828 .46117 m .54468 .46861 L .55369 .47189 L p .773 .684 .765 r
F P
0 g
s
.49978 .452 m .50485 .44561 L .4975 .43945 L p .619 .47 .658 r
F P
0 g
s
.50189 .43301 m .4975 .43945 L .50485 .44561 L p .608 .471 .67 r
F P
0 g
s
.32987 .58982 m .30415 .6007 L .30531 .60986 L p .774 .909 .933 r
F P
0 g
s
.27369 .62072 m .30531 .60986 L .30415 .6007 L p .737 .886 .948 r
F P
0 g
s
.30531 .39014 m .27369 .37928 L .27216 .38928 L p .737 .317 .251 r
F P
0 g
s
.27216 .38928 m .30415 .3993 L .30531 .39014 L p .737 .317 .251 r
F P
0 g
s
.5022 .72354 m .50861 .75635 L .51804 .75267 L p .23 .233 .656 r
F P
0 g
s
.51804 .75267 m .51071 .71996 L .5022 .72354 L p .23 .233 .656 r
F P
0 g
s
.66285 .60242 m .68514 .61926 L .69249 .61367 L p .797 .385 .268 r
F P
0 g
s
.7177 .63563 m .69249 .61367 L .68514 .61926 L p .833 .442 .307 r
F P
0 g
s
.69249 .38633 m .7177 .36437 L .7098 .35804 L p .833 .919 .892 r
F P
0 g
s
.7098 .35804 m .68514 .38074 L .69249 .38633 L p .833 .919 .892 r
F P
0 g
s
.50728 .30775 m .51071 .28004 L .5022 .27646 L p .21 .16 .58 r
F P
0 g
s
.50861 .24365 m .5022 .27646 L .51071 .28004 L p .23 .142 .544 r
F P
0 g
s
.38166 .43664 m .36747 .42928 L .36715 .43902 L p .817 .484 .425 r
F P
0 g
s
.36715 .43902 m .3815 .44538 L .38166 .43664 L p .817 .484 .425 r
F P
0 g
s
.39387 .54956 m .3815 .55462 L .38166 .56336 L p .809 .845 .877 r
F P
0 g
s
.36747 .57072 m .38166 .56336 L .3815 .55462 L p .817 .85 .874 r
F P
0 g
s
.59598 .56713 m .60655 .57531 L .61404 .5708 L p .767 .423 .402 r
F P
0 g
s
.62751 .57941 m .61404 .5708 L .60655 .57531 L p .76 .41 .392 r
F P
0 g
s
.5043 .63416 m .50502 .65013 L .51362 .64554 L p .371 .276 .616 r
F P
0 g
s
.51362 .64554 m .51194 .62993 L .5043 .63416 L p .371 .276 .616 r
F P
0 g
s
.51014 .38331 m .51194 .37007 L .5043 .36584 L p .377 .328 .676 r
F P
0 g
s
.50502 .34987 m .5043 .36584 L .51194 .37007 L p .371 .33 .682 r
F P
0 g
s
.61404 .4292 m .62751 .42059 L .61923 .41544 L p .76 .831 .907 r
F P
0 g
s
.61923 .41544 m .60655 .42469 L .61404 .4292 L p .76 .831 .907 r
F P
0 g
s
.41464 .45715 m .40479 .45432 L .40501 .46369 L p .783 .514 .529 r
F P
0 g
s
.40501 .46369 m .41503 .4659 L .41464 .45715 L p .783 .514 .529 r
F P
0 g
s
.42426 .53266 m .41503 .5341 L .41464 .54285 L p .765 .75 .839 r
F P
0 g
s
.40479 .54568 m .41464 .54285 L .41503 .5341 L p .783 .765 .837 r
F P
0 g
s
.50558 .59535 m .50805 .60529 L .51605 .60042 L p .5 .4 .673 r
F P
0 g
s
.51605 .60042 m .51296 .59064 L .50558 .59535 L p .5 .4 .673 r
F P
0 g
s
.56615 .54927 m .57202 .55654 L .57979 .5525 L p .779 .517 .54 r
F P
0 g
s
.58716 .55961 m .57979 .5525 L .57202 .55654 L p .766 .492 .519 r
F P
0 g
s
.50959 .41807 m .51296 .40936 L .50558 .40465 L p .513 .412 .678 r
F P
0 g
s
.50805 .39471 m .50558 .40465 L .51296 .40936 L p .5 .416 .692 r
F P
0 g
s
.57979 .4475 m .58716 .44039 L .57894 .43589 L p .766 .759 .846 r
F P
0 g
s
.57894 .43589 m .57202 .44346 L .57979 .4475 L p .766 .759 .846 r
F P
0 g
s
.45048 .52299 m .44223 .52239 L .44104 .53186 L p .72 .666 .796 r
F P
0 g
s
.43288 .53193 m .44104 .53186 L .44223 .52239 L p .736 .681 .797 r
F P
0 g
s
.44104 .46814 m .43288 .46807 L .43372 .47768 L p .736 .522 .602 r
F P
0 g
s
.43372 .47768 m .44223 .47761 L .44104 .46814 L p .736 .522 .602 r
F P
0 g
s
.50189 .56699 m .50591 .57409 L .51381 .56856 L p .596 .501 .716 r
F P
0 g
s
.51381 .56856 m .50949 .56123 L .50189 .56699 L p .596 .501 .716 r
F P
0 g
s
.54468 .53139 m .54828 .53883 L .55707 .53513 L p .773 .578 .635 r
F P
0 g
s
.56121 .54216 m .55707 .53513 L .54828 .53883 L p .765 .559 .619 r
F P
0 g
s
.50485 .44561 m .50949 .43877 L .50189 .43301 L p .608 .471 .67 r
F P
0 g
s
.50591 .42591 m .50189 .43301 L .50949 .43877 L p .596 .473 .683 r
F P
0 g
s
.55707 .46487 m .56121 .45784 L .55247 .45376 L p .765 .691 .78 r
F P
0 g
s
.55247 .45376 m .54828 .46117 L .55707 .46487 L p .765 .691 .78 r
F P
0 g
s
.77037 .20726 m .76315 .17429 L .75608 .16848 L p .96 .668 .438 r
F P
0 g
s
.76086 .80043 m .75608 .83152 L .76315 .82571 L p .96 .899 .72 r
F P
0 g
s
.76315 .82571 m .77037 .79274 L .76086 .80043 L p .96 .899 .72 r
F P
0 g
s
.61833 .88051 m .6505 .89074 L .65906 .88754 L p .511 .744 .979 r
F P
0 g
s
.62975 .12387 m .65906 .11246 L .6505 .10926 L p .511 .091 .179 r
F P
0 g
s
.6505 .10926 m .61833 .11949 L .62975 .12387 L p .511 .091 .179 r
F P
0 g
s
.1113 .41222 m .08636 .43496 L .08485 .44399 L p .267 .007 .32 r
F P
0 g
s
.10939 .5757 m .08485 .55601 L .08636 .56504 L p .267 .429 .838 r
F P
0 g
s
.08636 .56504 m .1113 .58778 L .10939 .5757 L p .267 .429 .838 r
F P
0 g
s
.55392 .17347 m .58414 .14134 L .57459 .13853 L p .305 .014 .295 r
F P
0 g
s
.57459 .13853 m .54371 .17016 L .55392 .17347 L p .305 .014 .295 r
F P
0 g
s
.75583 .70996 m .76854 .7522 L .77574 .74533 L p .971 .714 .486 r
F P
0 g
s
.77574 .74533 m .7638 .70277 L .75583 .70996 L p .971 .714 .486 r
F P
0 g
s
.54371 .82984 m .57459 .86147 L .58414 .85866 L p .305 .484 .871 r
F P
0 g
s
.61833 .88051 m .58414 .85866 L .57459 .86147 L p .323 .593 .943 r
F P
0 g
s
.7638 .29723 m .77574 .25467 L .76854 .2478 L p .971 .872 .68 r
F P
0 g
s
.77037 .20726 m .76854 .2478 L .77574 .25467 L p .997 .801 .523 r
F P
0 g
s
.19026 .61657 m .14732 .60647 L .14966 .61613 L p .473 .7 .968 r
F P
0 g
s
.14966 .61613 m .1925 .62707 L .19026 .61657 L p .473 .7 .968 r
F P
0 g
s
.1925 .37293 m .14966 .38387 L .14732 .39353 L p .473 .072 .199 r
F P
0 g
s
.1113 .41222 m .14732 .39353 L .14966 .38387 L p .296 0 .149 r
F P
0 g
s
.43288 .46807 m .42426 .46734 L .42483 .47724 L p .753 .534 .599 r
F P
0 g
s
.42483 .47724 m .43372 .47768 L .43288 .46807 L p .753 .534 .599 r
F P
0 g
s
.44223 .52239 m .43372 .52232 L .43288 .53193 L p .736 .681 .797 r
F P
0 g
s
.42426 .53266 m .43288 .53193 L .43372 .52232 L p .753 .695 .797 r
F P
0 g
s
.54828 .53883 m .55247 .54624 L .56121 .54216 L p .765 .559 .619 r
F P
0 g
s
.56615 .54927 m .56121 .54216 L .55247 .54624 L p .756 .539 .601 r
F P
0 g
s
.50591 .57409 m .50959 .58193 L .51787 .57648 L p .585 .479 .7 r
F P
0 g
s
.51787 .57648 m .51381 .56856 L .50591 .57409 L p .585 .479 .7 r
F P
0 g
s
.50949 .43877 m .51381 .43144 L .50591 .42591 L p .596 .473 .683 r
F P
0 g
s
.50959 .41807 m .50591 .42591 L .51381 .43144 L p .585 .476 .696 r
F P
0 g
s
.56121 .45784 m .56615 .45073 L .5573 .44629 L p .756 .697 .795 r
F P
0 g
s
.5573 .44629 m .55247 .45376 L .56121 .45784 L p .756 .697 .795 r
F P
0 g
s
.48802 .46319 m .48132 .46765 L .48804 .47927 L p .677 .521 .665 r
F P
0 g
s
.48132 .53235 m .48802 .53681 L .49621 .52667 L p .677 .586 .745 r
F P
0 g
s
.49621 .52667 m .48804 .52073 L .48132 .53235 L p .677 .586 .745 r
F P
0 g
s
.47411 .52878 m .48132 .53235 L .48803 .52072 L p .685 .595 .75 r
F P
0 g
s
.48132 .46765 m .47411 .47122 L .4788 .48338 L p .685 .523 .661 r
F P
0 g
s
.4788 .48338 m .48803 .47928 L .48132 .46765 L p .685 .523 .661 r
F P
0 g
s
.53787 .50803 m .53736 .5 L .52393 .5 L p .754 .612 .701 r
F P
0 g
s
.53736 .5 m .53787 .49197 L .52499 .48995 L p .754 .619 .71 r
F P
0 g
s
.52499 .48995 m .52393 .5 L .53736 .5 L p .754 .619 .71 r
F P
0 g
s
.48802 .53681 m .49419 .54209 L .50296 .53351 L p .67 .575 .74 r
F P
0 g
s
.50296 .53351 m .49621 .52667 L .48802 .53681 L p .67 .575 .74 r
F P
0 g
s
.48803 .52072 m .4788 .51662 L .47411 .52878 L p .685 .595 .75 r
F P
0 g
s
.46645 .52608 m .47411 .52878 L .4788 .51662 L p .693 .605 .753 r
F P
0 g
s
.47411 .47122 m .46645 .47392 L .4695 .4858 L p .693 .527 .658 r
F P
0 g
s
.4695 .4858 m .4788 .48338 L .47411 .47122 L p .693 .527 .658 r
F P
0 g
s
.48804 .47927 m .49621 .47333 L .48802 .46319 L p .677 .521 .665 r
F P
0 g
s
.49419 .45791 m .48802 .46319 L .49621 .47333 L p .67 .519 .671 r
F P
0 g
s
.52393 .5 m .52499 .51005 L .53787 .50803 L p .754 .612 .701 r
F P
0 g
s
.53936 .51602 m .53787 .50803 L .52499 .51005 L p .753 .604 .692 r
F P
0 g
s
.53787 .49197 m .53936 .48398 L .52755 .48068 L p .753 .625 .719 r
F P
0 g
s
.52755 .48068 m .52499 .48995 L .53787 .49197 L p .753 .625 .719 r
F P
0 g
s
.40479 .45432 m .39387 .45044 L .39394 .46063 L p .798 .526 .526 r
F P
0 g
s
.39394 .46063 m .40501 .46369 L .40479 .45432 L p .798 .526 .526 r
F P
0 g
s
.41503 .5341 m .40501 .53631 L .40479 .54568 L p .783 .765 .837 r
F P
0 g
s
.39387 .54956 m .40479 .54568 L .40501 .53631 L p .798 .777 .834 r
F P
0 g
s
.50805 .60529 m .51014 .61669 L .51893 .61154 L p .488 .378 .655 r
F P
0 g
s
.51893 .61154 m .51605 .60042 L .50805 .60529 L p .488 .378 .655 r
F P
0 g
s
.57202 .55654 m .57894 .56411 L .58716 .55961 L p .766 .492 .519 r
F P
0 g
s
.59598 .56713 m .58716 .55961 L .57894 .56411 L p .754 .47 .502 r
F P
0 g
s
.58716 .44039 m .59598 .43287 L .58713 .42783 L p .754 .762 .859 r
F P
0 g
s
.58713 .42783 m .57894 .43589 L .58716 .44039 L p .754 .762 .859 r
F P
0 g
s
.51296 .40936 m .51605 .39958 L .50805 .39471 L p .5 .416 .692 r
F P
0 g
s
.51014 .38331 m .50805 .39471 L .51605 .39958 L p .488 .419 .705 r
F P
0 g
s
.49419 .54209 m .49978 .548 L .50865 .54058 L p .663 .563 .732 r
F P
0 g
s
.50865 .54058 m .50296 .53351 L .49419 .54209 L p .663 .563 .732 r
F P
0 g
s
.4788 .51662 m .4695 .5142 L .46645 .52608 L p .693 .605 .753 r
F P
0 g
s
.46645 .47392 m .45854 .47581 L .46053 .48721 L p .703 .533 .655 r
F P
0 g
s
.46053 .48721 m .4695 .4858 L .46645 .47392 L p .703 .533 .655 r
F P
0 g
s
.45854 .52419 m .46645 .52608 L .4695 .5142 L p .703 .615 .756 r
F P
0 g
s
.52499 .51005 m .52755 .51932 L .53936 .51602 L p .753 .604 .692 r
F P
0 g
s
.54168 .52381 m .53936 .51602 L .52755 .51932 L p .75 .593 .682 r
F P
0 g
s
.53936 .48398 m .54168 .47619 L .53081 .47222 L p .75 .631 .729 r
F P
0 g
s
.53081 .47222 m .52755 .48068 L .53936 .48398 L p .75 .631 .729 r
F P
0 g
s
.49621 .47333 m .50296 .46649 L .49419 .45791 L p .67 .519 .671 r
F P
0 g
s
.49978 .452 m .49419 .45791 L .50296 .46649 L p .663 .519 .678 r
F P
0 g
s
.30415 .6007 m .27216 .61072 L .27369 .62072 L p .737 .886 .948 r
F P
0 g
s
.23548 .6277 m .27369 .62072 L .27216 .61072 L p .679 .848 .964 r
F P
0 g
s
.27369 .37928 m .23548 .3723 L .23356 .38284 L p .679 .26 .243 r
F P
0 g
s
.23356 .38284 m .27216 .38928 L .27369 .37928 L p .679 .26 .243 r
F P
0 g
s
.50861 .75635 m .52167 .79294 L .53176 .78933 L p .254 .302 .719 r
F P
0 g
s
.53176 .78933 m .51804 .75267 L .50861 .75635 L p .254 .302 .719 r
F P
0 g
s
.68514 .61926 m .7098 .64196 L .7177 .63563 L p .833 .442 .307 r
F P
0 g
s
.74285 .66523 m .7177 .63563 L .7098 .64196 L p .878 .517 .359 r
F P
0 g
s
.51071 .28004 m .51804 .24733 L .50861 .24365 L p .23 .142 .544 r
F P
0 g
s
.52167 .20706 m .50861 .24365 L .51804 .24733 L p .254 .114 .489 r
F P
0 g
s
.7177 .36437 m .74285 .33477 L .73469 .32783 L p .878 .917 .849 r
F P
0 g
s
.73469 .32783 m .7098 .35804 L .7177 .36437 L p .878 .917 .849 r
F P
0 g
s
.45854 .47581 m .45048 .47701 L .45181 .48801 L p .715 .541 .653 r
F P
0 g
s
.45181 .48801 m .46053 .48721 L .45854 .47581 L p .715 .541 .653 r
F P
0 g
s
.4695 .5142 m .46053 .51279 L .45854 .52419 L p .703 .615 .756 r
F P
0 g
s
.45048 .52299 m .45854 .52419 L .46053 .51279 L p .715 .626 .757 r
F P
0 g
s
.49978 .548 m .50485 .55439 L .51372 .54773 L p .655 .549 .723 r
F P
0 g
s
.51372 .54773 m .50865 .54058 L .49978 .548 L p .655 .549 .723 r
F P
0 g
s
.52755 .51932 m .53081 .52778 L .54168 .52381 L p .75 .593 .682 r
F P
0 g
s
.54468 .53139 m .54168 .52381 L .53081 .52778 L p .746 .581 .671 r
F P
0 g
s
.50296 .46649 m .50865 .45942 L .49978 .452 L p .663 .519 .678 r
F P
0 g
s
.50485 .44561 m .49978 .452 L .50865 .45942 L p .655 .52 .687 r
F P
0 g
s
.54168 .47619 m .54468 .46861 L .53448 .46426 L p .746 .637 .74 r
F P
0 g
s
.53448 .46426 m .53081 .47222 L .54168 .47619 L p .746 .637 .74 r
F P
0 g
s
.46053 .51279 m .45181 .51199 L .45048 .52299 L p .715 .626 .757 r
F P
0 g
s
.44223 .52239 m .45048 .52299 L .45181 .51199 L p .728 .638 .759 r
F P
0 g
s
.45048 .47701 m .44223 .47761 L .44313 .48842 L p .728 .55 .651 r
F P
0 g
s
.44313 .48842 m .45181 .48801 L .45048 .47701 L p .728 .55 .651 r
F P
0 g
s
.53081 .52778 m .53448 .53574 L .54468 .53139 L p .746 .581 .671 r
F P
0 g
s
.54828 .53883 m .54468 .53139 L .53448 .53574 L p .74 .566 .658 r
F P
0 g
s
.50485 .55439 m .50949 .56123 L .5184 .55504 L p .646 .534 .712 r
F P
0 g
s
.5184 .55504 m .51372 .54773 L .50485 .55439 L p .646 .534 .712 r
F P
0 g
s
.54468 .46861 m .54828 .46117 L .53846 .45654 L p .74 .643 .752 r
F P
0 g
s
.53846 .45654 m .53448 .46426 L .54468 .46861 L p .74 .643 .752 r
F P
0 g
s
.50865 .45942 m .51372 .45227 L .50485 .44561 L p .655 .52 .687 r
F P
0 g
s
.50949 .43877 m .50485 .44561 L .51372 .45227 L p .646 .522 .698 r
F P
0 g
s
.36747 .42928 m .35055 .42039 L .35004 .43134 L p .818 .485 .425 r
F P
0 g
s
.35004 .43134 m .36715 .43902 L .36747 .42928 L p .818 .485 .425 r
F P
0 g
s
.3815 .55462 m .36715 .56098 L .36747 .57072 L p .817 .85 .874 r
F P
0 g
s
.35055 .57961 m .36747 .57072 L .36715 .56098 L p .818 .851 .873 r
F P
0 g
s
.60655 .57531 m .61923 .58456 L .62751 .57941 L p .76 .41 .392 r
F P
0 g
s
.64366 .58962 m .62751 .57941 L .61923 .58456 L p .759 .408 .391 r
F P
0 g
s
.50502 .65013 m .50578 .66923 L .51552 .66419 L p .37 .274 .615 r
F P
0 g
s
.51552 .66419 m .51362 .64554 L .50502 .65013 L p .37 .274 .615 r
F P
0 g
s
.51194 .37007 m .51362 .35446 L .50502 .34987 L p .371 .33 .682 r
F P
0 g
s
.50578 .33077 m .50502 .34987 L .51362 .35446 L p .37 .33 .683 r
F P
0 g
s
.62751 .42059 m .64366 .41038 L .63444 .40446 L p .759 .831 .907 r
F P
0 g
s
.63444 .40446 m .61923 .41544 L .62751 .42059 L p .759 .831 .907 r
F P
0 g
s
.43372 .52232 m .42483 .52276 L .42426 .53266 L p .753 .695 .797 r
F P
0 g
s
.41503 .5341 m .42426 .53266 L .42483 .52276 L p .769 .709 .796 r
F P
0 g
s
.42426 .46734 m .41503 .4659 L .41541 .47628 L p .769 .546 .596 r
F P
0 g
s
.41541 .47628 m .42483 .47724 L .42426 .46734 L p .769 .546 .596 r
F P
0 g
s
.50959 .58193 m .51296 .59064 L .52175 .58512 L p .574 .458 .684 r
F P
0 g
s
.52175 .58512 m .51787 .57648 L .50959 .58193 L p .574 .458 .684 r
F P
0 g
s
.55247 .54624 m .5573 .55371 L .56615 .54927 L p .756 .539 .601 r
F P
0 g
s
.57202 .55654 m .56615 .54927 L .5573 .55371 L p .747 .518 .584 r
F P
0 g
s
.56615 .45073 m .57202 .44346 L .56284 .4386 L p .747 .701 .809 r
F P
0 g
s
.56284 .4386 m .5573 .44629 L .56615 .45073 L p .747 .701 .809 r
F P
0 g
s
.51381 .43144 m .51787 .42352 L .50959 .41807 L p .585 .476 .696 r
F P
0 g
s
.51296 .40936 m .50959 .41807 L .51787 .42352 L p .574 .479 .709 r
F P
0 g
s
.68918 .88699 m .66972 .88284 L .65906 .88754 L p .607 .851 .99 r
F P
0 g
s
.66972 .88284 m .68918 .88699 L .69739 .883 L p .68 .853 .965 r
F P
0 g
s
.68198 .12316 m .69739 .117 L .68918 .11301 L p .68 .258 .237 r
F P
0 g
s
.68918 .11301 m .66972 .11716 L .68198 .12316 L p .68 .258 .237 r
F P
0 g
s
.74056 .14267 m .74669 .1616 L .75608 .16848 L p .906 .525 .293 r
F P
0 g
s
.74669 .1616 m .74056 .14267 L .733 .13756 L p .877 .511 .35 r
F P
0 g
s
.73536 .84602 m .733 .86244 L .74056 .85733 L p .877 .92 .852 r
F P
0 g
s
.74056 .85733 m .74669 .8384 L .73536 .84602 L p .877 .92 .852 r
F P
0 g
s
.07026 .47034 m .0836 .45556 L .08485 .44399 L p .153 0 .383 r
F P
0 g
s
.0836 .45556 m .07026 .47034 L .06962 .47944 L p .246 .108 .488 r
F P
0 g
s
.08265 .53082 m .06962 .52056 L .07026 .52966 L p .246 .294 .714 r
F P
0 g
s
.07026 .52966 m .0836 .54444 L .08265 .53082 L p .246 .294 .714 r
F P
0 g
s
.23548 .3723 m .1925 .37293 L .19026 .38343 L p .594 .181 .227 r
F P
0 g
s
.14732 .39353 m .19026 .38343 L .1925 .37293 L p .473 .072 .199 r
F P
0 g
s
.52167 .79294 m .54371 .82984 L .55392 .82653 L p .281 .386 .792 r
F P
0 g
s
.58414 .85866 m .55392 .82653 L .54371 .82984 L p .305 .484 .871 r
F P
0 g
s
.53176 .21067 m .55392 .17347 L .54371 .17016 L p .281 .072 .409 r
F P
0 g
s
.54371 .17016 m .52167 .20706 L .53176 .21067 L p .281 .072 .409 r
F P
0 g
s
.74285 .33477 m .7638 .29723 L .75583 .29004 L p .927 .905 .782 r
F P
0 g
s
.76854 .2478 m .75583 .29004 L .7638 .29723 L p .971 .872 .68 r
F P
0 g
s
.73469 .67217 m .75583 .70996 L .7638 .70277 L p .927 .609 .419 r
F P
0 g
s
.7638 .70277 m .74285 .66523 L .73469 .67217 L p .927 .609 .419 r
F P
0 g
s
.23356 .61716 m .19026 .61657 L .1925 .62707 L p .594 .79 .974 r
F P
0 g
s
.1925 .62707 m .23548 .6277 L .23356 .61716 L p .594 .79 .974 r
F P
0 g
s
.44223 .47761 m .43372 .47768 L .43434 .4885 L p .742 .56 .649 r
F P
0 g
s
.43434 .4885 m .44313 .48842 L .44223 .47761 L p .742 .56 .649 r
F P
0 g
s
.45181 .51199 m .44313 .51158 L .44223 .52239 L p .728 .638 .759 r
F P
0 g
s
.43372 .52232 m .44223 .52239 L .44313 .51158 L p .742 .651 .759 r
F P
0 g
s
.53448 .53574 m .53846 .54346 L .54828 .53883 L p .74 .566 .658 r
F P
0 g
s
.55247 .54624 m .54828 .53883 L .53846 .54346 L p .733 .549 .644 r
F P
0 g
s
.50949 .56123 m .51381 .56856 L .52287 .56261 L p .637 .516 .699 r
F P
0 g
s
.52287 .56261 m .5184 .55504 L .50949 .56123 L p .637 .516 .699 r
F P
0 g
s
.54828 .46117 m .55247 .45376 L .54279 .44889 L p .733 .648 .764 r
F P
0 g
s
.54279 .44889 m .53846 .45654 L .54828 .46117 L p .733 .648 .764 r
F P
0 g
s
.51372 .45227 m .5184 .44496 L .50949 .43877 L p .646 .522 .698 r
F P
0 g
s
.51381 .43144 m .50949 .43877 L .5184 .44496 L p .637 .524 .709 r
F P
0 g
s
.19026 .38343 m .23356 .38284 L .23548 .3723 L p .594 .181 .227 r
F P
0 g
s
.51804 .24733 m .53176 .21067 L .52167 .20706 L p .254 .114 .489 r
F P
0 g
s
.55392 .82653 m .53176 .78933 L .52167 .79294 L p .281 .386 .792 r
F P
0 g
s
.27216 .61072 m .23356 .61716 L .23548 .6277 L p .679 .848 .964 r
F P
0 g
s
.7098 .64196 m .73469 .67217 L .74285 .66523 L p .878 .517 .359 r
F P
0 g
s
.75583 .29004 m .73469 .32783 L .74285 .33477 L p .927 .905 .782 r
F P
0 g
s
.48804 .52073 m .49621 .52667 L .50902 .51562 L p .697 .578 .717 r
F P
0 g
s
.49621 .52667 m .50296 .53351 L .5145 .52512 L p .695 .576 .717 r
F P
0 g
s
.5145 .52512 m .50902 .51562 L .49621 .52667 L p .695 .576 .717 r
F P
0 g
s
.49992 .5 m .48197 .5 L .4788 .51662 L p .701 .582 .719 r
F P
0 g
s
.4788 .51662 m .48803 .52072 L .49992 .5 L p .701 .582 .719 r
F P
0 g
s
.4695 .5142 m .4788 .51662 L .48197 .5 L p .703 .587 .722 r
F P
0 g
s
.48803 .47928 m .4788 .48338 L .48197 .5 L p .703 .563 .693 r
F P
0 g
s
.4788 .48338 m .4695 .4858 L .47099 .5 L p .704 .562 .692 r
F P
0 g
s
.47099 .5 m .48197 .5 L .4788 .48338 L p .704 .562 .692 r
F P
0 g
s
.50004 .50007 m .50902 .51562 L .52499 .51005 L p .721 .588 .706 r
F P
0 g
s
.52499 .51005 m .52393 .5 L .50004 .50007 L p .721 .588 .706 r
F P
0 g
s
.52755 .51932 m .52499 .51005 L .50902 .51562 L p .722 .586 .703 r
F P
0 g
s
.50004 .49993 m .50902 .48438 L .49621 .47333 L p .7 .562 .695 r
F P
0 g
s
.49621 .47333 m .48804 .47927 L .50004 .49993 L p .7 .562 .695 r
F P
0 g
s
.50296 .46649 m .49621 .47333 L .50902 .48438 L p .696 .559 .696 r
F P
0 g
s
.52393 .5 m .52499 .48995 L .50902 .48438 L p .721 .591 .71 r
F P
0 g
s
.52499 .48995 m .52755 .48068 L .5145 .47488 L p .722 .593 .712 r
F P
0 g
s
.5145 .47488 m .50902 .48438 L .52499 .48995 L p .722 .593 .712 r
F P
0 g
s
.4695 .4858 m .46053 .48721 L .46138 .5 L p .71 .567 .691 r
F P
0 g
s
.46138 .5 m .47099 .5 L .4695 .4858 L p .71 .567 .691 r
F P
0 g
s
.48197 .5 m .47099 .5 L .4695 .5142 L p .703 .587 .722 r
F P
0 g
s
.46053 .51279 m .4695 .5142 L .47099 .5 L p .71 .593 .723 r
F P
0 g
s
.50296 .53351 m .50865 .54058 L .51931 .53345 L p .691 .569 .712 r
F P
0 g
s
.51931 .53345 m .5145 .52512 L .50296 .53351 L p .691 .569 .712 r
F P
0 g
s
.50902 .51562 m .5145 .52512 L .52755 .51932 L p .722 .586 .703 r
F P
0 g
s
.53081 .52778 m .52755 .51932 L .5145 .52512 L p .719 .578 .696 r
F P
0 g
s
.52755 .48068 m .53081 .47222 L .51931 .46655 L p .719 .596 .718 r
F P
0 g
s
.51931 .46655 m .5145 .47488 L .52755 .48068 L p .719 .596 .718 r
F P
0 g
s
.50902 .48438 m .5145 .47488 L .50296 .46649 L p .696 .559 .696 r
F P
0 g
s
.50865 .45942 m .50296 .46649 L .5145 .47488 L p .691 .56 .702 r
F P
0 g
s
.50902 .51562 m .50004 .50007 L .48804 .52073 L p .697 .578 .717 r
F P
0 g
s
.48197 .5 m .49992 .5 L .48803 .47928 L p .703 .563 .693 r
F P
0 g
s
.50902 .48438 m .50004 .49993 L .52393 .5 L p .721 .591 .71 r
F P
0 g
s
.46053 .48721 m .45181 .48801 L .45233 .5 L p .72 .574 .69 r
F P
0 g
s
.45233 .5 m .46138 .5 L .46053 .48721 L p .72 .574 .69 r
F P
0 g
s
.5145 .52512 m .51931 .53345 L .53081 .52778 L p .719 .578 .696 r
F P
0 g
s
.53448 .53574 m .53081 .52778 L .51931 .53345 L p .715 .568 .687 r
F P
0 g
s
.47099 .5 m .46138 .5 L .46053 .51279 L p .71 .593 .723 r
F P
0 g
s
.45181 .51199 m .46053 .51279 L .46138 .5 L p .72 .602 .724 r
F P
0 g
s
.50865 .54058 m .51372 .54773 L .52384 .54128 L p .686 .558 .704 r
F P
0 g
s
.52384 .54128 m .51931 .53345 L .50865 .54058 L p .686 .558 .704 r
F P
0 g
s
.5145 .47488 m .51931 .46655 L .50865 .45942 L p .691 .56 .702 r
F P
0 g
s
.51372 .45227 m .50865 .45942 L .51931 .46655 L p .686 .562 .71 r
F P
0 g
s
.53081 .47222 m .53448 .46426 L .52384 .45872 L p .715 .6 .727 r
F P
0 g
s
.52384 .45872 m .51931 .46655 L .53081 .47222 L p .715 .6 .727 r
F P
0 g
s
.39387 .45044 m .3815 .44538 L .38142 .45661 L p .809 .535 .524 r
F P
0 g
s
.38142 .45661 m .39394 .46063 L .39387 .45044 L p .809 .535 .524 r
F P
0 g
s
.40501 .53631 m .39394 .53937 L .39387 .54956 L p .798 .777 .834 r
F P
0 g
s
.3815 .55462 m .39387 .54956 L .39394 .53937 L p .809 .786 .831 r
F P
0 g
s
.51014 .61669 m .51194 .62993 L .52171 .62438 L p .479 .361 .641 r
F P
0 g
s
.52171 .62438 m .51893 .61154 L .51014 .61669 L p .479 .361 .641 r
F P
0 g
s
.57894 .56411 m .58713 .57217 L .59598 .56713 L p .754 .47 .502 r
F P
0 g
s
.60655 .57531 m .59598 .56713 L .58713 .57217 L p .745 .453 .488 r
F P
0 g
s
.51605 .39958 m .51893 .38846 L .51014 .38331 L p .488 .419 .705 r
F P
0 g
s
.51194 .37007 m .51014 .38331 L .51893 .38846 L p .479 .422 .715 r
F P
0 g
s
.59598 .43287 m .60655 .42469 L .59686 .419 L p .745 .763 .868 r
F P
0 g
s
.59686 .419 m .58713 .42783 L .59598 .43287 L p .745 .763 .868 r
F P
0 g
s
.44313 .51158 m .43434 .5115 L .43372 .52232 L p .742 .651 .759 r
F P
0 g
s
.43372 .47768 m .42483 .47724 L .42525 .48831 L p .756 .571 .647 r
F P
0 g
s
.42525 .48831 m .43434 .4885 L .43372 .47768 L p .756 .571 .647 r
F P
0 g
s
.42483 .52276 m .43372 .52232 L .43434 .5115 L p .756 .663 .759 r
F P
0 g
s
.51381 .56856 m .51787 .57648 L .52725 .57058 L p .628 .498 .685 r
F P
0 g
s
.52725 .57058 m .52287 .56261 L .51381 .56856 L p .628 .498 .685 r
F P
0 g
s
.53846 .54346 m .54279 .55111 L .55247 .54624 L p .733 .549 .644 r
F P
0 g
s
.5573 .55371 m .55247 .54624 L .54279 .55111 L p .725 .532 .629 r
F P
0 g
s
.55247 .45376 m .5573 .44629 L .5475 .44112 L p .725 .652 .777 r
F P
0 g
s
.5475 .44112 m .54279 .44889 L .55247 .45376 L p .725 .652 .777 r
F P
0 g
s
.5184 .44496 m .52287 .43739 L .51381 .43144 L p .637 .524 .709 r
F P
0 g
s
.51787 .42352 m .51381 .43144 L .52287 .43739 L p .628 .527 .721 r
F P
0 g
s
.45181 .48801 m .44313 .48842 L .44348 .5 L p .731 .583 .689 r
F P
0 g
s
.44348 .5 m .45233 .5 L .45181 .48801 L p .731 .583 .689 r
F P
0 g
s
.46138 .5 m .45233 .5 L .45181 .51199 L p .72 .602 .724 r
F P
0 g
s
.44313 .51158 m .45181 .51199 L .45233 .5 L p .731 .611 .724 r
F P
0 g
s
.51372 .54773 m .5184 .55504 L .52826 .54895 L p .679 .544 .694 r
F P
0 g
s
.52826 .54895 m .52384 .54128 L .51372 .54773 L p .679 .544 .694 r
F P
0 g
s
.51931 .53345 m .52384 .54128 L .53448 .53574 L p .715 .568 .687 r
F P
0 g
s
.53846 .54346 m .53448 .53574 L .52384 .54128 L p .709 .554 .676 r
F P
0 g
s
.53448 .46426 m .53846 .45654 L .52826 .45105 L p .709 .604 .737 r
F P
0 g
s
.52826 .45105 m .52384 .45872 L .53448 .46426 L p .709 .604 .737 r
F P
0 g
s
.51931 .46655 m .52384 .45872 L .51372 .45227 L p .686 .562 .71 r
F P
0 g
s
.5184 .44496 m .51372 .45227 L .52384 .45872 L p .679 .565 .719 r
F P
0 g
s
.41503 .4659 m .40501 .46369 L .40523 .47477 L p .783 .558 .594 r
F P
0 g
s
.40523 .47477 m .41541 .47628 L .41503 .4659 L p .783 .558 .594 r
F P
0 g
s
.42483 .52276 m .41541 .52372 L .41503 .5341 L p .769 .709 .796 r
F P
0 g
s
.40501 .53631 m .41503 .5341 L .41541 .52372 L p .783 .721 .794 r
F P
0 g
s
.5573 .55371 m .56284 .5614 L .57202 .55654 L p .747 .518 .584 r
F P
0 g
s
.57894 .56411 m .57202 .55654 L .56284 .5614 L p .736 .497 .567 r
F P
0 g
s
.51296 .59064 m .51605 .60042 L .52553 .59469 L p .563 .437 .667 r
F P
0 g
s
.52553 .59469 m .52175 .58512 L .51296 .59064 L p .563 .437 .667 r
F P
0 g
s
.51787 .42352 m .52175 .41488 L .51296 .40936 L p .574 .479 .709 r
F P
0 g
s
.51605 .39958 m .51296 .40936 L .52175 .41488 L p .563 .482 .721 r
F P
0 g
s
.57202 .44346 m .57894 .43589 L .56923 .43055 L p .736 .705 .822 r
F P
0 g
s
.56923 .43055 m .56284 .4386 L .57202 .44346 L p .736 .705 .822 r
F P
0 g
s
.45233 .5 m .44348 .5 L .44313 .51158 L p .731 .611 .724 r
F P
0 g
s
.52384 .54128 m .52826 .54895 L .53846 .54346 L p .709 .554 .676 r
F P
0 g
s
.52384 .45872 m .52826 .45105 L .5184 .44496 L p .679 .565 .719 r
F P
0 g
s
.43434 .5115 m .44313 .51158 L .44348 .5 L p .744 .622 .724 r
F P
0 g
s
.44313 .48842 m .43434 .4885 L .43457 .5 L p .744 .593 .688 r
F P
0 g
s
.43457 .5 m .44348 .5 L .44313 .48842 L p .744 .593 .688 r
F P
0 g
s
.5184 .55504 m .52287 .56261 L .53271 .55666 L p .671 .528 .682 r
F P
0 g
s
.53271 .55666 m .52826 .54895 L .5184 .55504 L p .671 .528 .682 r
F P
0 g
s
.54279 .55111 m .53846 .54346 L .52826 .54895 L p .702 .539 .664 r
F P
0 g
s
.53846 .45654 m .54279 .44889 L .53271 .44334 L p .702 .608 .748 r
F P
0 g
s
.53271 .44334 m .52826 .45105 L .53846 .45654 L p .702 .608 .748 r
F P
0 g
s
.52287 .43739 m .5184 .44496 L .52826 .45105 L p .671 .568 .73 r
F P
0 g
s
.35055 .42039 m .32987 .41018 L .32914 .4225 L p .81 .477 .425 r
F P
0 g
s
.32914 .4225 m .35004 .43134 L .35055 .42039 L p .81 .477 .425 r
F P
0 g
s
.36715 .56098 m .35004 .56866 L .35055 .57961 L p .818 .851 .873 r
F P
0 g
s
.32987 .58982 m .35055 .57961 L .35004 .56866 L p .81 .846 .877 r
F P
0 g
s
.61923 .58456 m .63444 .59554 L .64366 .58962 L p .759 .408 .391 r
F P
0 g
s
.66285 .60242 m .64366 .58962 L .63444 .59554 L p .767 .421 .4 r
F P
0 g
s
.50578 .66923 m .50728 .69225 L .51831 .68672 L p .376 .287 .626 r
F P
0 g
s
.51831 .68672 m .51552 .66419 L .50578 .66923 L p .376 .287 .626 r
F P
0 g
s
.64366 .41038 m .66285 .39758 L .65255 .39078 L p .767 .831 .902 r
F P
0 g
s
.65255 .39078 m .63444 .40446 L .64366 .41038 L p .767 .831 .902 r
F P
0 g
s
.51362 .35446 m .51552 .33581 L .50578 .33077 L p .37 .33 .683 r
F P
0 g
s
.50728 .30775 m .50578 .33077 L .51552 .33581 L p .376 .328 .676 r
F P
0 g
s
.44348 .5 m .43457 .5 L .43434 .5115 L p .744 .622 .724 r
F P
0 g
s
.52826 .54895 m .53271 .55666 L .54279 .55111 L p .702 .539 .664 r
F P
0 g
s
.52826 .45105 m .53271 .44334 L .52287 .43739 L p .671 .568 .73 r
F P
0 g
s
.43434 .5115 m .42525 .51169 L .42483 .52276 L p .756 .663 .759 r
F P
0 g
s
.41541 .52372 m .42483 .52276 L .42525 .51169 L p .77 .675 .758 r
F P
0 g
s
.42483 .47724 m .41541 .47628 L .41568 .48783 L p .77 .582 .645 r
F P
0 g
s
.41568 .48783 m .42525 .48831 L .42483 .47724 L p .77 .582 .645 r
F P
0 g
s
.54279 .55111 m .5475 .55888 L .5573 .55371 L p .725 .532 .629 r
F P
0 g
s
.56284 .5614 m .5573 .55371 L .5475 .55888 L p .716 .513 .614 r
F P
0 g
s
.51787 .57648 m .52175 .58512 L .53162 .5791 L p .618 .48 .671 r
F P
0 g
s
.53162 .5791 m .52725 .57058 L .51787 .57648 L p .618 .48 .671 r
F P
0 g
s
.52287 .43739 m .52725 .42942 L .51787 .42352 L p .628 .527 .721 r
F P
0 g
s
.52175 .41488 m .51787 .42352 L .52725 .42942 L p .618 .53 .732 r
F P
0 g
s
.5573 .44629 m .56284 .4386 L .5527 .43306 L p .716 .656 .789 r
F P
0 g
s
.5527 .43306 m .5475 .44112 L .5573 .44629 L p .716 .656 .789 r
F P
0 g
s
.733 .13756 m .73536 .15398 L .74669 .1616 L p .877 .511 .35 r
F P
0 g
s
.73536 .15398 m .733 .13756 L .7245 .13219 L p .843 .484 .373 r
F P
0 g
s
.69739 .883 m .68198 .87684 L .66972 .88284 L p .68 .853 .965 r
F P
0 g
s
.68198 .87684 m .69739 .883 L .70628 .87833 L p .731 .854 .939 r
F P
0 g
s
.72263 .85405 m .7245 .86781 L .733 .86244 L p .843 .893 .874 r
F P
0 g
s
.733 .86244 m .73536 .84602 L .72263 .85405 L p .843 .893 .874 r
F P
0 g
s
.6953 .13017 m .70628 .12167 L .69739 .117 L p .731 .34 .309 r
F P
0 g
s
.69739 .117 m .68198 .12316 L .6953 .13017 L p .731 .34 .309 r
F P
0 g
s
.08207 .51578 m .06921 .51052 L .06962 .52056 L p .297 .296 .688 r
F P
0 g
s
.06962 .52056 m .08265 .53082 L .08207 .51578 L p .297 .296 .688 r
F P
0 g
s
.06962 .47944 m .08265 .46918 L .0836 .45556 L p .246 .108 .488 r
F P
0 g
s
.08265 .46918 m .06962 .47944 L .06921 .48948 L p .297 .19 .559 r
F P
0 g
s
.42525 .51169 m .43434 .5115 L .43457 .5 L p .757 .633 .723 r
F P
0 g
s
.43434 .4885 m .42525 .48831 L .42541 .5 L p .757 .603 .687 r
F P
0 g
s
.42541 .5 m .43457 .5 L .43434 .4885 L p .757 .603 .687 r
F P
0 g
s
.5475 .55888 m .54279 .55111 L .53271 .55666 L p .695 .523 .651 r
F P
0 g
s
.52287 .56261 m .52725 .57058 L .5373 .5646 L p .663 .512 .669 r
F P
0 g
s
.5373 .5646 m .53271 .55666 L .52287 .56261 L p .663 .512 .669 r
F P
0 g
s
.52725 .42942 m .52287 .43739 L .53271 .44334 L p .663 .571 .741 r
F P
0 g
s
.54279 .44889 m .5475 .44112 L .5373 .4354 L p .695 .611 .759 r
F P
0 g
s
.5373 .4354 m .53271 .44334 L .54279 .44889 L p .695 .611 .759 r
F P
0 g
s
.41541 .52372 m .40523 .52523 L .40501 .53631 L p .783 .721 .794 r
F P
0 g
s
.40501 .46369 m .39394 .46063 L .39403 .47266 L p .796 .568 .592 r
F P
0 g
s
.39403 .47266 m .40523 .47477 L .40501 .46369 L p .796 .568 .592 r
F P
0 g
s
.39394 .53937 m .40501 .53631 L .40523 .52523 L p .796 .732 .792 r
F P
0 g
s
.56284 .5614 m .56923 .56945 L .57894 .56411 L p .736 .497 .567 r
F P
0 g
s
.58713 .57217 m .57894 .56411 L .56923 .56945 L p .727 .479 .552 r
F P
0 g
s
.51605 .60042 m .51893 .61154 L .52931 .60544 L p .553 .419 .652 r
F P
0 g
s
.52931 .60544 m .52553 .59469 L .51605 .60042 L p .553 .419 .652 r
F P
0 g
s
.52175 .41488 m .52553 .40531 L .51605 .39958 L p .563 .482 .721 r
F P
0 g
s
.51893 .38846 m .51605 .39958 L .52553 .40531 L p .553 .484 .732 r
F P
0 g
s
.57894 .43589 m .58713 .42783 L .57666 .4219 L p .727 .708 .832 r
F P
0 g
s
.57666 .4219 m .56923 .43055 L .57894 .43589 L p .727 .708 .832 r
F P
0 g
s
.43457 .5 m .42541 .5 L .42525 .51169 L p .757 .633 .723 r
F P
0 g
s
.53271 .55666 m .5373 .5646 L .5475 .55888 L p .695 .523 .651 r
F P
0 g
s
.53271 .44334 m .5373 .4354 L .52725 .42942 L p .663 .571 .741 r
F P
0 g
s
.3815 .44538 m .36715 .43902 L .36692 .45157 L p .815 .541 .523 r
F P
0 g
s
.36692 .45157 m .38142 .45661 L .3815 .44538 L p .815 .541 .523 r
F P
0 g
s
.39394 .53937 m .38142 .54339 L .3815 .55462 L p .809 .786 .831 r
F P
0 g
s
.36715 .56098 m .3815 .55462 L .38142 .54339 L p .815 .791 .829 r
F P
0 g
s
.58713 .57217 m .59686 .581 L .60655 .57531 L p .745 .453 .488 r
F P
0 g
s
.61923 .58456 m .60655 .57531 L .59686 .581 L p .739 .443 .479 r
F P
0 g
s
.51194 .62993 m .51362 .64554 L .52459 .63946 L p .474 .351 .632 r
F P
0 g
s
.52459 .63946 m .52171 .62438 L .51194 .62993 L p .474 .351 .632 r
F P
0 g
s
.51893 .38846 m .52171 .37562 L .51194 .37007 L p .479 .422 .715 r
F P
0 g
s
.51362 .35446 m .51194 .37007 L .52171 .37562 L p .474 .423 .72 r
F P
0 g
s
.60655 .42469 m .61923 .41544 L .60848 .40897 L p .739 .764 .873 r
F P
0 g
s
.60848 .40897 m .59686 .419 L .60655 .42469 L p .739 .764 .873 r
F P
0 g
s
.42525 .51169 m .41568 .51217 L .41541 .52372 L p .77 .675 .758 r
F P
0 g
s
.40523 .52523 m .41541 .52372 L .41568 .51217 L p .783 .686 .757 r
F P
0 g
s
.41541 .47628 m .40523 .47477 L .4054 .48707 L p .783 .593 .643 r
F P
0 g
s
.4054 .48707 m .41568 .48783 L .41541 .47628 L p .783 .593 .643 r
F P
0 g
s
.5475 .55888 m .5527 .56694 L .56284 .5614 L p .716 .513 .614 r
F P
0 g
s
.56923 .56945 m .56284 .5614 L .5527 .56694 L p .707 .495 .599 r
F P
0 g
s
.52175 .58512 m .52553 .59469 L .5361 .58839 L p .609 .462 .656 r
F P
0 g
s
.5361 .58839 m .53162 .5791 L .52175 .58512 L p .609 .462 .656 r
F P
0 g
s
.56284 .4386 m .56923 .43055 L .5585 .42454 L p .707 .66 .8 r
F P
0 g
s
.5585 .42454 m .5527 .43306 L .56284 .4386 L p .707 .66 .8 r
F P
0 g
s
.52725 .42942 m .53162 .4209 L .52175 .41488 L p .618 .53 .732 r
F P
0 g
s
.52553 .40531 m .52175 .41488 L .53162 .4209 L p .609 .533 .744 r
F P
0 g
s
.41568 .51217 m .42525 .51169 L .42541 .5 L p .77 .644 .722 r
F P
0 g
s
.5527 .56694 m .5475 .55888 L .5373 .5646 L p .686 .506 .637 r
F P
0 g
s
.42525 .48831 m .41568 .48783 L .41579 .5 L p .77 .614 .685 r
F P
0 g
s
.41579 .5 m .42541 .5 L .42525 .48831 L p .77 .614 .685 r
F P
0 g
s
.52725 .57058 m .53162 .5791 L .54211 .57293 L p .654 .495 .655 r
F P
0 g
s
.54211 .57293 m .5373 .5646 L .52725 .57058 L p .654 .495 .655 r
F P
0 g
s
.53162 .4209 m .52725 .42942 L .5373 .4354 L p .654 .574 .752 r
F P
0 g
s
.5475 .44112 m .5527 .43306 L .54211 .42707 L p .686 .615 .771 r
F P
0 g
s
.54211 .42707 m .5373 .4354 L .5475 .44112 L p .686 .615 .771 r
F P
0 g
s
.7245 .13219 m .72263 .14595 L .73536 .15398 L p .843 .484 .373 r
F P
0 g
s
.72263 .14595 m .7245 .13219 L .71546 .12681 L p .808 .447 .373 r
F P
0 g
s
.70906 .13789 m .71546 .12681 L .70628 .12167 L p .772 .4 .352 r
F P
0 g
s
.70628 .12167 m .6953 .13017 L .70906 .13789 L p .772 .4 .352 r
F P
0 g
s
.70906 .86211 m .71546 .87319 L .7245 .86781 L p .808 .873 .894 r
F P
0 g
s
.7245 .86781 m .72263 .85405 L .70906 .86211 L p .808 .873 .894 r
F P
0 g
s
.70628 .87833 m .6953 .86983 L .68198 .87684 L p .731 .854 .939 r
F P
0 g
s
.6953 .86983 m .70628 .87833 L .71546 .87319 L p .772 .86 .915 r
F P
0 g
s
.06921 .48948 m .08207 .48422 L .08265 .46918 L p .297 .19 .559 r
F P
0 g
s
.08207 .48422 m .06921 .48948 L .06908 .5 L p .32 .244 .613 r
F P
0 g
s
.08187 .5 m .06908 .5 L .06921 .51052 L p .32 .279 .655 r
F P
0 g
s
.06921 .51052 m .08207 .51578 L .08187 .5 L p .32 .279 .655 r
F P
0 g
s
.42541 .5 m .41579 .5 L .41568 .51217 L p .77 .644 .722 r
F P
0 g
s
.5373 .5646 m .54211 .57293 L .5527 .56694 L p .686 .506 .637 r
F P
0 g
s
.5373 .4354 m .54211 .42707 L .53162 .4209 L p .654 .574 .752 r
F P
0 g
s
.64404 .13028 m .66972 .11716 L .65906 .11246 L p .612 .248 .327 r
F P
0 g
s
.65906 .11246 m .62975 .12387 L .64404 .13028 L p .612 .248 .327 r
F P
0 g
s
.65906 .88754 m .62975 .87613 L .61833 .88051 L p .511 .744 .979 r
F P
0 g
s
.62975 .87613 m .65906 .88754 L .66972 .88284 L p .612 .751 .944 r
F P
0 g
s
.75608 .16848 m .76086 .19957 L .77037 .20726 L p .96 .668 .438 r
F P
0 g
s
.76086 .19957 m .75608 .16848 L .74669 .1616 L p .915 .638 .502 r
F P
0 g
s
.10779 .56012 m .0836 .54444 L .08485 .55601 L p .381 .454 .811 r
F P
0 g
s
.08485 .55601 m .10939 .5757 L .10779 .56012 L p .381 .454 .811 r
F P
0 g
s
.08485 .44399 m .10939 .4243 L .1113 .41222 L p .267 .007 .32 r
F P
0 g
s
.10939 .4243 m .08485 .44399 L .0836 .45556 L p .381 .168 .461 r
F P
0 g
s
.74817 .8096 m .74669 .8384 L .75608 .83152 L p .915 .856 .769 r
F P
0 g
s
.75608 .83152 m .76086 .80043 L .74817 .8096 L p .915 .856 .769 r
F P
0 g
s
.71546 .12681 m .70906 .13789 L .72263 .14595 L p .808 .447 .373 r
F P
0 g
s
.71546 .87319 m .70906 .86211 L .6953 .86983 L p .772 .86 .915 r
F P
0 g
s
.06908 .5 m .08187 .5 L .08207 .48422 L p .32 .244 .613 r
F P
0 g
s
.59779 .14679 m .62975 .12387 L .61833 .11949 L p .501 .176 .348 r
F P
0 g
s
.61833 .11949 m .58414 .14134 L .59779 .14679 L p .501 .176 .348 r
F P
0 g
s
.14522 .59192 m .10939 .5757 L .1113 .58778 L p .452 .58 .891 r
F P
0 g
s
.1113 .58778 m .14732 .60647 L .14522 .59192 L p .452 .58 .891 r
F P
0 g
s
.75699 .76129 m .76086 .80043 L .77037 .79274 L p .947 .796 .661 r
F P
0 g
s
.77037 .79274 m .76854 .7522 L .75699 .76129 L p .947 .796 .661 r
F P
0 g
s
.58414 .85866 m .61833 .88051 L .62975 .87613 L p .501 .642 .919 r
F P
0 g
s
.76854 .2478 m .77037 .20726 L .76086 .19957 L p .947 .75 .605 r
F P
0 g
s
.14732 .39353 m .1113 .41222 L .10939 .4243 L p .452 .159 .376 r
F P
0 g
s
.35004 .56866 m .32914 .5775 L .32987 .58982 L p .81 .846 .877 r
F P
0 g
s
.30415 .6007 m .32987 .58982 L .32914 .5775 L p .792 .833 .883 r
F P
0 g
s
.32987 .41018 m .30415 .3993 L .30314 .41306 L p .792 .461 .427 r
F P
0 g
s
.30314 .41306 m .32914 .4225 L .32987 .41018 L p .792 .461 .427 r
F P
0 g
s
.63444 .59554 m .65255 .60922 L .66285 .60242 L p .767 .421 .4 r
F P
0 g
s
.50728 .69225 m .51071 .71996 L .52314 .71396 L p .389 .313 .65 r
F P
0 g
s
.52314 .71396 m .51831 .68672 L .50728 .69225 L p .389 .313 .65 r
F P
0 g
s
.68514 .61926 m .66285 .60242 L .65255 .60922 L p .784 .45 .422 r
F P
0 g
s
.51552 .33581 m .51831 .31328 L .50728 .30775 L p .376 .328 .676 r
F P
0 g
s
.51071 .28004 m .50728 .30775 L .51831 .31328 L p .389 .321 .66 r
F P
0 g
s
.66285 .39758 m .68514 .38074 L .67372 .37298 L p .784 .83 .888 r
F P
0 g
s
.67372 .37298 m .65255 .39078 L .66285 .39758 L p .784 .83 .888 r
F P
0 g
s
.40523 .52523 m .39403 .52734 L .39394 .53937 L p .796 .732 .792 r
F P
0 g
s
.38142 .54339 m .39394 .53937 L .39403 .52734 L p .806 .74 .79 r
F P
0 g
s
.39394 .46063 m .38142 .45661 L .3814 .46988 L p .806 .576 .59 r
F P
0 g
s
.3814 .46988 m .39403 .47266 L .39394 .46063 L p .806 .576 .59 r
F P
0 g
s
.51893 .61154 m .52171 .62438 L .53321 .61777 L p .546 .405 .64 r
F P
0 g
s
.53321 .61777 m .52931 .60544 L .51893 .61154 L p .546 .405 .64 r
F P
0 g
s
.56923 .56945 m .57666 .5781 L .58713 .57217 L p .727 .479 .552 r
F P
0 g
s
.59686 .581 m .58713 .57217 L .57666 .5781 L p .719 .465 .54 r
F P
0 g
s
.58713 .42783 m .59686 .419 L .58539 .41235 L p .719 .71 .841 r
F P
0 g
s
.58539 .41235 m .57666 .4219 L .58713 .42783 L p .719 .71 .841 r
F P
0 g
s
.52553 .40531 m .52931 .39456 L .51893 .38846 L p .553 .484 .732 r
F P
0 g
s
.52171 .37562 m .51893 .38846 L .52931 .39456 L p .546 .487 .74 r
F P
0 g
s
.41568 .48783 m .4054 .48707 L .40546 .5 L p .783 .624 .684 r
F P
0 g
s
.40546 .5 m .41579 .5 L .41568 .48783 L p .783 .624 .684 r
F P
0 g
s
.4054 .51293 m .41568 .51217 L .41579 .5 L p .783 .654 .721 r
F P
0 g
s
.41568 .51217 m .4054 .51293 L .40523 .52523 L p .783 .686 .757 r
F P
0 g
s
.53162 .5791 m .5361 .58839 L .54727 .58187 L p .646 .478 .642 r
F P
0 g
s
.54727 .58187 m .54211 .57293 L .53162 .5791 L p .646 .478 .642 r
F P
0 g
s
.5585 .57546 m .5527 .56694 L .54211 .57293 L p .678 .489 .623 r
F P
0 g
s
.5527 .56694 m .5585 .57546 L .56923 .56945 L p .707 .495 .599 r
F P
0 g
s
.5527 .43306 m .5585 .42454 L .54727 .41813 L p .678 .618 .781 r
F P
0 g
s
.54727 .41813 m .54211 .42707 L .5527 .43306 L p .678 .618 .781 r
F P
0 g
s
.5361 .41161 m .53162 .4209 L .54211 .42707 L p .646 .577 .763 r
F P
0 g
s
.53162 .4209 m .5361 .41161 L .52553 .40531 L p .609 .533 .744 r
F P
0 g
s
.39403 .52734 m .40523 .52523 L .4054 .51293 L p .795 .695 .755 r
F P
0 g
s
.40523 .47477 m .39403 .47266 L .39411 .48599 L p .795 .603 .641 r
F P
0 g
s
.39411 .48599 m .4054 .48707 L .40523 .47477 L p .795 .603 .641 r
F P
0 g
s
.52553 .59469 m .52931 .60544 L .54081 .59871 L p .601 .445 .643 r
F P
0 g
s
.54081 .59871 m .5361 .58839 L .52553 .59469 L p .601 .445 .643 r
F P
0 g
s
.57666 .5781 m .56923 .56945 L .5585 .57546 L p .699 .479 .586 r
F P
0 g
s
.56923 .43055 m .57666 .4219 L .56508 .4153 L p .699 .662 .81 r
F P
0 g
s
.56508 .4153 m .5585 .42454 L .56923 .43055 L p .699 .662 .81 r
F P
0 g
s
.52931 .39456 m .52553 .40531 L .5361 .41161 L p .601 .535 .753 r
F P
0 g
s
.41579 .5 m .40546 .5 L .4054 .51293 L p .783 .654 .721 r
F P
0 g
s
.54211 .57293 m .54727 .58187 L .5585 .57546 L p .678 .489 .623 r
F P
0 g
s
.54211 .42707 m .54727 .41813 L .5361 .41161 L p .646 .577 .763 r
F P
0 g
s
.36715 .43902 m .35004 .43134 L .34965 .44546 L p .816 .541 .523 r
F P
0 g
s
.34965 .44546 m .36692 .45157 L .36715 .43902 L p .816 .541 .523 r
F P
0 g
s
.38142 .54339 m .36692 .54843 L .36715 .56098 L p .815 .791 .829 r
F P
0 g
s
.35004 .56866 m .36715 .56098 L .36692 .54843 L p .816 .791 .829 r
F P
0 g
s
.51362 .64554 m .51552 .66419 L .52794 .65748 L p .474 .351 .632 r
F P
0 g
s
.52794 .65748 m .52459 .63946 L .51362 .64554 L p .474 .351 .632 r
F P
0 g
s
.59686 .581 m .60848 .59103 L .61923 .58456 L p .739 .443 .479 r
F P
0 g
s
.63444 .59554 m .61923 .58456 L .60848 .59103 L p .739 .442 .479 r
F P
0 g
s
.52171 .37562 m .52459 .36054 L .51362 .35446 L p .474 .423 .72 r
F P
0 g
s
.51552 .33581 m .51362 .35446 L .52459 .36054 L p .474 .423 .721 r
F P
0 g
s
.61923 .41544 m .63444 .40446 L .62241 .39707 L p .739 .764 .874 r
F P
0 g
s
.62241 .39707 m .60848 .40897 L .61923 .41544 L p .739 .764 .874 r
F P
0 g
s
.4054 .48707 m .39411 .48599 L .39414 .5 L p .794 .633 .682 r
F P
0 g
s
.39414 .5 m .40546 .5 L .4054 .48707 L p .794 .633 .682 r
F P
0 g
s
.39411 .51401 m .4054 .51293 L .40546 .5 L p .794 .663 .719 r
F P
0 g
s
.4054 .51293 m .39411 .51401 L .39403 .52734 L p .795 .695 .755 r
F P
0 g
s
.5361 .58839 m .54081 .59871 L .55293 .59168 L p .638 .463 .629 r
F P
0 g
s
.55293 .59168 m .54727 .58187 L .5361 .58839 L p .638 .463 .629 r
F P
0 g
s
.56508 .5847 m .5585 .57546 L .54727 .58187 L p .67 .474 .611 r
F P
0 g
s
.5585 .57546 m .56508 .5847 L .57666 .5781 L p .699 .479 .586 r
F P
0 g
s
.54081 .40129 m .5361 .41161 L .54727 .41813 L p .638 .579 .772 r
F P
0 g
s
.5361 .41161 m .54081 .40129 L .52931 .39456 L p .601 .535 .753 r
F P
0 g
s
.5585 .42454 m .56508 .4153 L .55293 .40832 L p .67 .621 .791 r
F P
0 g
s
.55293 .40832 m .54727 .41813 L .5585 .42454 L p .67 .621 .791 r
F P
0 g
s
.32914 .5775 m .30314 .58694 L .30415 .6007 L p .792 .833 .883 r
F P
0 g
s
.27216 .61072 m .30415 .6007 L .30314 .58694 L p .763 .813 .892 r
F P
0 g
s
.30415 .3993 m .27216 .38928 L .27081 .40437 L p .763 .433 .427 r
F P
0 g
s
.27081 .40437 m .30314 .41306 L .30415 .3993 L p .763 .433 .427 r
F P
0 g
s
.51071 .71996 m .51804 .75267 L .53178 .7463 L p .407 .354 .687 r
F P
0 g
s
.53178 .7463 m .52314 .71396 L .51071 .71996 L p .407 .354 .687 r
F P
0 g
s
.65255 .60922 m .67372 .62702 L .68514 .61926 L p .784 .45 .422 r
F P
0 g
s
.7098 .64196 m .68514 .61926 L .67372 .62702 L p .81 .493 .454 r
F P
0 g
s
.51831 .31328 m .52314 .28604 L .51071 .28004 L p .389 .321 .66 r
F P
0 g
s
.51804 .24733 m .51071 .28004 L .52314 .28604 L p .407 .31 .633 r
F P
0 g
s
.68514 .38074 m .7098 .35804 L .69741 .34933 L p .81 .829 .865 r
F P
0 g
s
.69741 .34933 m .67372 .37298 L .68514 .38074 L p .81 .829 .865 r
F P
0 g
s
.38142 .45661 m .36692 .45157 L .36678 .46638 L p .812 .581 .589 r
F P
0 g
s
.36678 .46638 m .3814 .46988 L .38142 .45661 L p .812 .581 .589 r
F P
0 g
s
.39403 .52734 m .3814 .53012 L .38142 .54339 L p .806 .74 .79 r
F P
0 g
s
.36692 .54843 m .38142 .54339 L .3814 .53012 L p .812 .744 .789 r
F P
0 g
s
.57666 .5781 m .58539 .58765 L .59686 .581 L p .719 .465 .54 r
F P
0 g
s
.52171 .62438 m .52459 .63946 L .53749 .63218 L p .542 .396 .633 r
F P
0 g
s
.53749 .63218 m .53321 .61777 L .52171 .62438 L p .542 .396 .633 r
F P
0 g
s
.60848 .59103 m .59686 .581 L .58539 .58765 L p .715 .456 .533 r
F P
0 g
s
.52931 .39456 m .53321 .38223 L .52171 .37562 L p .546 .487 .74 r
F P
0 g
s
.52459 .36054 m .52171 .37562 L .53321 .38223 L p .542 .488 .745 r
F P
0 g
s
.59686 .419 m .60848 .40897 L .59573 .40144 L p .715 .711 .845 r
F P
0 g
s
.59573 .40144 m .58539 .41235 L .59686 .419 L p .715 .711 .845 r
F P
0 g
s
.40546 .5 m .39414 .5 L .39411 .51401 L p .794 .663 .719 r
F P
0 g
s
.54727 .58187 m .55293 .59168 L .56508 .5847 L p .67 .474 .611 r
F P
0 g
s
.54727 .41813 m .55293 .40832 L .54081 .40129 L p .638 .579 .772 r
F P
0 g
s
.3814 .53012 m .39403 .52734 L .39411 .51401 L p .804 .703 .753 r
F P
0 g
s
.39403 .47266 m .3814 .46988 L .3814 .48457 L p .804 .61 .64 r
F P
0 g
s
.3814 .48457 m .39411 .48599 L .39403 .47266 L p .804 .61 .64 r
F P
0 g
s
.52931 .60544 m .53321 .61777 L .54594 .61043 L p .594 .432 .632 r
F P
0 g
s
.54594 .61043 m .54081 .59871 L .52931 .60544 L p .594 .432 .632 r
F P
0 g
s
.58539 .58765 m .57666 .5781 L .56508 .5847 L p .692 .466 .576 r
F P
0 g
s
.57666 .4219 m .58539 .41235 L .57266 .405 L p .692 .664 .818 r
F P
0 g
s
.57266 .405 m .56508 .4153 L .57666 .4219 L p .692 .664 .818 r
F P
0 g
s
.53321 .38223 m .52931 .39456 L .54081 .40129 L p .594 .537 .761 r
F P
0 g
s
.35004 .43134 m .32914 .4225 L .32855 .43841 L p .809 .535 .524 r
F P
0 g
s
.32855 .43841 m .34965 .44546 L .35004 .43134 L p .809 .535 .524 r
F P
0 g
s
.36692 .54843 m .34965 .55454 L .35004 .56866 L p .816 .791 .829 r
F P
0 g
s
.32914 .5775 m .35004 .56866 L .34965 .55454 L p .809 .786 .831 r
F P
0 g
s
.51552 .66419 m .51831 .68672 L .53239 .67928 L p .479 .361 .641 r
F P
0 g
s
.53239 .67928 m .52794 .65748 L .51552 .66419 L p .479 .361 .641 r
F P
0 g
s
.60848 .59103 m .62241 .60293 L .63444 .59554 L p .739 .442 .479 r
F P
0 g
s
.65255 .60922 m .63444 .59554 L .62241 .60293 L p .745 .453 .487 r
F P
0 g
s
.52459 .36054 m .52794 .34252 L .51552 .33581 L p .474 .423 .721 r
F P
0 g
s
.51831 .31328 m .51552 .33581 L .52794 .34252 L p .479 .421 .715 r
F P
0 g
s
.63444 .40446 m .65255 .39078 L .63906 .38232 L p .745 .764 .868 r
F P
0 g
s
.63906 .38232 m .62241 .39707 L .63444 .40446 L p .745 .764 .868 r
F P
0 g
s
.66056 .13844 m .68198 .12316 L .66972 .11716 L p .674 .348 .414 r
F P
0 g
s
.66972 .11716 m .64404 .13028 L .66056 .13844 L p .674 .348 .414 r
F P
0 g
s
.74669 .1616 m .74817 .1904 L .76086 .19957 L p .915 .638 .502 r
F P
0 g
s
.74817 .1904 m .74669 .1616 L .73536 .15398 L p .871 .601 .527 r
F P
0 g
s
.73284 .81983 m .73536 .84602 L .74669 .8384 L p .871 .821 .797 r
F P
0 g
s
.74669 .8384 m .74817 .8096 L .73284 .81983 L p .871 .821 .797 r
F P
0 g
s
.66972 .88284 m .64404 .86972 L .62975 .87613 L p .612 .751 .944 r
F P
0 g
s
.64404 .86972 m .66972 .88284 L .68198 .87684 L p .674 .753 .91 r
F P
0 g
s
.10659 .54173 m .08265 .53082 L .0836 .54444 L p .441 .453 .775 r
F P
0 g
s
.0836 .54444 m .10779 .56012 L .10659 .54173 L p .441 .453 .775 r
F P
0 g
s
.0836 .45556 m .10779 .43988 L .10939 .4243 L p .381 .168 .461 r
F P
0 g
s
.10779 .43988 m .0836 .45556 L .08265 .46918 L p .441 .268 .549 r
F P
0 g
s
.55392 .82653 m .58414 .85866 L .59779 .85321 L p .479 .551 .852 r
F P
0 g
s
.62975 .87613 m .59779 .85321 L .58414 .85866 L p .501 .642 .919 r
F P
0 g
s
.75583 .29004 m .76854 .2478 L .75699 .23871 L p .914 .792 .711 r
F P
0 g
s
.76086 .19957 m .75699 .23871 L .76854 .2478 L p .947 .75 .605 r
F P
0 g
s
.56866 .17966 m .59779 .14679 L .58414 .14134 L p .479 .231 .46 r
F P
0 g
s
.58414 .14134 m .55392 .17347 L .56866 .17966 L p .479 .231 .46 r
F P
0 g
s
.19026 .38343 m .14732 .39353 L .14522 .40808 L p .574 .264 .404 r
F P
0 g
s
.10939 .4243 m .14522 .40808 L .14732 .39353 L p .452 .159 .376 r
F P
0 g
s
.18825 .6007 m .14522 .59192 L .14732 .60647 L p .574 .674 .907 r
F P
0 g
s
.14732 .60647 m .19026 .61657 L .18825 .6007 L p .574 .674 .907 r
F P
0 g
s
.74309 .71963 m .75699 .76129 L .76854 .7522 L p .914 .701 .601 r
F P
0 g
s
.76854 .7522 m .75583 .70996 L .74309 .71963 L p .914 .701 .601 r
F P
0 g
s
.39411 .48599 m .3814 .48457 L .3814 .5 L p .802 .64 .681 r
F P
0 g
s
.3814 .5 m .39414 .5 L .39411 .48599 L p .802 .64 .681 r
F P
0 g
s
.3814 .51543 m .39411 .51401 L .39414 .5 L p .802 .67 .718 r
F P
0 g
s
.39411 .51401 m .3814 .51543 L .3814 .53012 L p .804 .703 .753 r
F P
0 g
s
.54081 .59871 m .54594 .61043 L .5593 .60271 L p .632 .45 .619 r
F P
0 g
s
.5593 .60271 m .55293 .59168 L .54081 .59871 L p .632 .45 .619 r
F P
0 g
s
.57266 .595 m .56508 .5847 L .55293 .59168 L p .664 .461 .601 r
F P
0 g
s
.56508 .5847 m .57266 .595 L .58539 .58765 L p .692 .466 .576 r
F P
0 g
s
.56508 .4153 m .57266 .405 L .5593 .39729 L p .664 .622 .798 r
F P
0 g
s
.5593 .39729 m .55293 .40832 L .56508 .4153 L p .664 .622 .798 r
F P
0 g
s
.54594 .38957 m .54081 .40129 L .55293 .40832 L p .632 .581 .779 r
F P
0 g
s
.54081 .40129 m .54594 .38957 L .53321 .38223 L p .594 .537 .761 r
F P
0 g
s
.30314 .58694 m .27081 .59563 L .27216 .61072 L p .763 .813 .892 r
F P
0 g
s
.23356 .61716 m .27216 .61072 L .27081 .59563 L p .72 .782 .902 r
F P
0 g
s
.67372 .62702 m .69741 .65067 L .7098 .64196 L p .81 .493 .454 r
F P
0 g
s
.73469 .67217 m .7098 .64196 L .69741 .65067 L p .842 .55 .496 r
F P
0 g
s
.27216 .38928 m .23356 .38284 L .23184 .39878 L p .72 .393 .425 r
F P
0 g
s
.23184 .39878 m .27081 .40437 L .27216 .38928 L p .72 .393 .425 r
F P
0 g
s
.51804 .75267 m .53176 .78933 L .54642 .78284 L p .429 .408 .734 r
F P
0 g
s
.54642 .78284 m .53178 .7463 L .51804 .75267 L p .429 .408 .734 r
F P
0 g
s
.52314 .28604 m .53178 .2537 L .51804 .24733 L p .407 .31 .633 r
F P
0 g
s
.53176 .21067 m .51804 .24733 L .53178 .2537 L p .429 .293 .593 r
F P
0 g
s
.7098 .35804 m .73469 .32783 L .72174 .31838 L p .842 .824 .831 r
F P
0 g
s
.72174 .31838 m .69741 .34933 L .7098 .35804 L p .842 .824 .831 r
F P
0 g
s
.39414 .5 m .3814 .5 L .3814 .51543 L p .802 .67 .718 r
F P
0 g
s
.55293 .59168 m .5593 .60271 L .57266 .595 L p .664 .461 .601 r
F P
0 g
s
.55293 .40832 m .5593 .39729 L .54594 .38957 L p .632 .581 .779 r
F P
0 g
s
.36692 .45157 m .34965 .44546 L .34938 .46213 L p .812 .581 .589 r
F P
0 g
s
.34938 .46213 m .36678 .46638 L .36692 .45157 L p .812 .581 .589 r
F P
0 g
s
.3814 .53012 m .36678 .53362 L .36692 .54843 L p .812 .744 .789 r
F P
0 g
s
.34965 .55454 m .36692 .54843 L .36678 .53362 L p .812 .744 .789 r
F P
0 g
s
.52459 .63946 m .52794 .65748 L .54251 .64938 L p .541 .396 .633 r
F P
0 g
s
.54251 .64938 m .53749 .63218 L .52459 .63946 L p .541 .396 .633 r
F P
0 g
s
.58539 .58765 m .59573 .59856 L .60848 .59103 L p .715 .456 .533 r
F P
0 g
s
.62241 .60293 m .60848 .59103 L .59573 .59856 L p .714 .456 .533 r
F P
0 g
s
.60848 .40897 m .62241 .39707 L .60811 .38849 L p .714 .711 .845 r
F P
0 g
s
.60811 .38849 m .59573 .40144 L .60848 .40897 L p .714 .711 .845 r
F P
0 g
s
.53321 .38223 m .53749 .36782 L .52459 .36054 L p .542 .488 .745 r
F P
0 g
s
.52794 .34252 m .52459 .36054 L .53749 .36782 L p .541 .488 .745 r
F P
0 g
s
.3814 .46988 m .36678 .46638 L .3667 .48278 L p .809 .614 .639 r
F P
0 g
s
.3667 .48278 m .3814 .48457 L .3814 .46988 L p .809 .614 .639 r
F P
0 g
s
.36678 .53362 m .3814 .53012 L .3814 .51543 L p .809 .707 .752 r
F P
0 g
s
.59573 .59856 m .58539 .58765 L .57266 .595 L p .688 .459 .569 r
F P
0 g
s
.53321 .61777 m .53749 .63218 L .55173 .62405 L p .59 .425 .626 r
F P
0 g
s
.55173 .62405 m .54594 .61043 L .53321 .61777 L p .59 .425 .626 r
F P
0 g
s
.53749 .36782 m .53321 .38223 L .54594 .38957 L p .59 .539 .765 r
F P
0 g
s
.58539 .41235 m .59573 .40144 L .58156 .39317 L p .688 .665 .822 r
F P
0 g
s
.58156 .39317 m .57266 .405 L .58539 .41235 L p .688 .665 .822 r
F P
0 g
s
.54642 .21716 m .56866 .17966 L .55392 .17347 L p .454 .268 .537 r
F P
0 g
s
.55392 .17347 m .53176 .21067 L .54642 .21716 L p .454 .268 .537 r
F P
0 g
s
.23184 .60122 m .18825 .6007 L .19026 .61657 L p .659 .738 .908 r
F P
0 g
s
.19026 .61657 m .23356 .61716 L .23184 .60122 L p .659 .738 .908 r
F P
0 g
s
.53176 .78933 m .55392 .82653 L .56866 .82034 L p .454 .474 .79 r
F P
0 g
s
.59779 .85321 m .56866 .82034 L .55392 .82653 L p .479 .551 .852 r
F P
0 g
s
.72174 .68162 m .74309 .71963 L .75583 .70996 L p .878 .62 .545 r
F P
0 g
s
.75583 .70996 m .73469 .67217 L .72174 .68162 L p .878 .62 .545 r
F P
0 g
s
.23356 .38284 m .19026 .38343 L .18825 .3993 L p .659 .338 .419 r
F P
0 g
s
.14522 .40808 m .18825 .3993 L .19026 .38343 L p .574 .264 .404 r
F P
0 g
s
.73469 .32783 m .75583 .29004 L .74309 .28037 L p .878 .813 .782 r
F P
0 g
s
.75699 .23871 m .74309 .28037 L .75583 .29004 L p .914 .792 .711 r
F P
0 g
s
.27081 .59563 m .23184 .60122 L .23356 .61716 L p .72 .782 .902 r
F P
0 g
s
.18825 .3993 m .23184 .39878 L .23356 .38284 L p .659 .338 .419 r
F P
0 g
s
.69741 .65067 m .72174 .68162 L .73469 .67217 L p .842 .55 .496 r
F P
0 g
s
.53178 .2537 m .54642 .21716 L .53176 .21067 L p .429 .293 .593 r
F P
0 g
s
.56866 .82034 m .54642 .78284 L .53176 .78933 L p .454 .474 .79 r
F P
0 g
s
.74309 .28037 m .72174 .31838 L .73469 .32783 L p .878 .813 .782 r
F P
0 g
s
.14522 .40808 m .10939 .4243 L .10779 .43988 L p .524 .288 .498 r
F P
0 g
s
.75699 .23871 m .76086 .19957 L .74817 .1904 L p .892 .695 .63 r
F P
0 g
s
.59779 .85321 m .62975 .87613 L .64404 .86972 L p .594 .659 .883 r
F P
0 g
s
.61499 .1547 m .64404 .13028 L .62975 .12387 L p .594 .312 .458 r
F P
0 g
s
.62975 .12387 m .59779 .14679 L .61499 .1547 L p .594 .312 .458 r
F P
0 g
s
.14347 .57307 m .10779 .56012 L .10939 .5757 L p .524 .568 .842 r
F P
0 g
s
.10939 .5757 m .14522 .59192 L .14347 .57307 L p .524 .568 .842 r
F P
0 g
s
.74155 .77223 m .74817 .8096 L .76086 .80043 L p .892 .761 .711 r
F P
0 g
s
.76086 .80043 m .75699 .76129 L .74155 .77223 L p .892 .761 .711 r
F P
0 g
s
.67856 .14797 m .6953 .13017 L .68198 .12316 L p .72 .419 .468 r
F P
0 g
s
.68198 .12316 m .66056 .13844 L .67856 .14797 L p .72 .419 .468 r
F P
0 g
s
.71559 .83066 m .72263 .85405 L .73536 .84602 L p .831 .795 .817 r
F P
0 g
s
.73536 .84602 m .73284 .81983 L .71559 .83066 L p .831 .795 .817 r
F P
0 g
s
.73536 .15398 m .73284 .18017 L .74817 .1904 L p .871 .601 .527 r
F P
0 g
s
.73284 .18017 m .73536 .15398 L .72263 .14595 L p .831 .562 .532 r
F P
0 g
s
.10585 .52137 m .08207 .51578 L .08265 .53082 L p .473 .438 .739 r
F P
0 g
s
.08265 .53082 m .10659 .54173 L .10585 .52137 L p .473 .438 .739 r
F P
0 g
s
.68198 .87684 m .66056 .86156 L .64404 .86972 L p .674 .753 .91 r
F P
0 g
s
.66056 .86156 m .68198 .87684 L .6953 .86983 L p .72 .757 .881 r
F P
0 g
s
.08265 .46918 m .10659 .45827 L .10779 .43988 L p .441 .268 .549 r
F P
0 g
s
.10659 .45827 m .08265 .46918 L .08207 .48422 L p .473 .334 .611 r
F P
0 g
s
.34965 .55454 m .32855 .56159 L .32914 .5775 L p .809 .786 .831 r
F P
0 g
s
.30314 .58694 m .32914 .5775 L .32855 .56159 L p .794 .774 .835 r
F P
0 g
s
.62241 .60293 m .63906 .61768 L .65255 .60922 L p .745 .453 .487 r
F P
0 g
s
.67372 .62702 m .65255 .60922 L .63906 .61768 L p .758 .476 .505 r
F P
0 g
s
.51831 .68672 m .52314 .71396 L .53899 .70576 L p .49 .384 .66 r
F P
0 g
s
.53899 .70576 m .53239 .67928 L .51831 .68672 L p .49 .384 .66 r
F P
0 g
s
.32914 .4225 m .30314 .41306 L .30231 .43089 L p .794 .521 .526 r
F P
0 g
s
.30231 .43089 m .32855 .43841 L .32914 .4225 L p .794 .521 .526 r
F P
0 g
s
.52794 .34252 m .53239 .32072 L .51831 .31328 L p .479 .421 .715 r
F P
0 g
s
.52314 .28604 m .51831 .31328 L .53239 .32072 L p .49 .417 .701 r
F P
0 g
s
.65255 .39078 m .67372 .37298 L .6587 .36335 L p .758 .762 .856 r
F P
0 g
s
.6587 .36335 m .63906 .38232 L .65255 .39078 L p .758 .762 .856 r
F P
0 g
s
.3667 .51722 m .3814 .51543 L .3814 .5 L p .807 .674 .717 r
F P
0 g
s
.3814 .51543 m .3667 .51722 L .36678 .53362 L p .809 .707 .752 r
F P
0 g
s
.3814 .48457 m .3667 .48278 L .36668 .5 L p .807 .644 .68 r
F P
0 g
s
.36668 .5 m .3814 .5 L .3814 .48457 L p .807 .644 .68 r
F P
0 g
s
.58156 .60683 m .57266 .595 L .5593 .60271 L p .66 .454 .595 r
F P
0 g
s
.57266 .595 m .58156 .60683 L .59573 .59856 L p .688 .459 .569 r
F P
0 g
s
.54594 .61043 m .55173 .62405 L .56666 .61546 L p .628 .443 .613 r
F P
0 g
s
.56666 .61546 m .5593 .60271 L .54594 .61043 L p .628 .443 .613 r
F P
0 g
s
.57266 .405 m .58156 .39317 L .56666 .38454 L p .66 .623 .802 r
F P
0 g
s
.56666 .38454 m .5593 .39729 L .57266 .405 L p .66 .623 .802 r
F P
0 g
s
.55173 .37595 m .54594 .38957 L .5593 .39729 L p .628 .582 .783 r
F P
0 g
s
.54594 .38957 m .55173 .37595 L .53749 .36782 L p .59 .539 .765 r
F P
0 g
s
.3814 .5 m .36668 .5 L .3667 .51722 L p .807 .674 .717 r
F P
0 g
s
.5593 .60271 m .56666 .61546 L .58156 .60683 L p .66 .454 .595 r
F P
0 g
s
.5593 .39729 m .56666 .38454 L .55173 .37595 L p .628 .582 .783 r
F P
0 g
s
.34938 .53787 m .36678 .53362 L .3667 .51722 L p .809 .707 .752 r
F P
0 g
s
.36678 .53362 m .34938 .53787 L .34965 .55454 L p .812 .744 .789 r
F P
0 g
s
.36678 .46638 m .34938 .46213 L .34922 .4806 L p .809 .614 .639 r
F P
0 g
s
.34922 .4806 m .3667 .48278 L .36678 .46638 L p .809 .614 .639 r
F P
0 g
s
.53749 .63218 m .54251 .64938 L .55859 .64028 L p .59 .425 .626 r
F P
0 g
s
.55859 .64028 m .55173 .62405 L .53749 .63218 L p .59 .425 .626 r
F P
0 g
s
.60811 .61151 m .59573 .59856 L .58156 .60683 L p .688 .459 .569 r
F P
0 g
s
.59573 .59856 m .60811 .61151 L .62241 .60293 L p .714 .456 .533 r
F P
0 g
s
.54251 .35062 m .53749 .36782 L .55173 .37595 L p .59 .539 .765 r
F P
0 g
s
.53749 .36782 m .54251 .35062 L .52794 .34252 L p .541 .488 .745 r
F P
0 g
s
.59573 .40144 m .60811 .38849 L .59219 .37912 L p .688 .665 .822 r
F P
0 g
s
.59219 .37912 m .58156 .39317 L .59573 .40144 L p .688 .665 .822 r
F P
0 g
s
.34965 .44546 m .32855 .43841 L .32812 .45723 L p .805 .576 .59 r
F P
0 g
s
.32812 .45723 m .34938 .46213 L .34965 .44546 L p .805 .576 .59 r
F P
0 g
s
.32855 .56159 m .34965 .55454 L .34938 .53787 L p .805 .739 .791 r
F P
0 g
s
.52794 .65748 m .53239 .67928 L .5489 .67024 L p .546 .406 .641 r
F P
0 g
s
.5489 .67024 m .54251 .64938 L .52794 .65748 L p .546 .406 .641 r
F P
0 g
s
.63906 .61768 m .62241 .60293 L .60811 .61151 L p .72 .465 .541 r
F P
0 g
s
.53239 .32072 m .52794 .34252 L .54251 .35062 L p .546 .486 .74 r
F P
0 g
s
.62241 .39707 m .63906 .38232 L .62298 .37254 L p .72 .71 .84 r
F P
0 g
s
.62298 .37254 m .60811 .38849 L .62241 .39707 L p .72 .71 .84 r
F P
0 g
s
.72263 .14595 m .71559 .16934 L .73284 .18017 L p .831 .562 .532 r
F P
0 g
s
.71559 .16934 m .72263 .14595 L .70906 .13789 L p .794 .521 .523 r
F P
0 g
s
.6953 .86983 m .67856 .85203 L .66056 .86156 L p .72 .757 .881 r
F P
0 g
s
.67856 .85203 m .6953 .86983 L .70906 .86211 L p .759 .764 .857 r
F P
0 g
s
.6972 .15844 m .70906 .13789 L .6953 .13017 L p .759 .474 .502 r
F P
0 g
s
.6953 .13017 m .67856 .14797 L .6972 .15844 L p .759 .474 .502 r
F P
0 g
s
.08207 .48422 m .10585 .47863 L .10659 .45827 L p .473 .334 .611 r
F P
0 g
s
.10585 .47863 m .08207 .48422 L .08187 .5 L p .487 .381 .659 r
F P
0 g
s
.6972 .84156 m .70906 .86211 L .72263 .85405 L p .794 .777 .837 r
F P
0 g
s
.72263 .85405 m .71559 .83066 L .6972 .84156 L p .794 .777 .837 r
F P
0 g
s
.1056 .5 m .08187 .5 L .08207 .51578 L p .487 .414 .701 r
F P
0 g
s
.08207 .51578 m .10585 .52137 L .1056 .5 L p .487 .414 .701 r
F P
0 g
s
.70906 .13789 m .6972 .15844 L .71559 .16934 L p .794 .521 .523 r
F P
0 g
s
.70906 .86211 m .6972 .84156 L .67856 .85203 L p .759 .764 .857 r
F P
0 g
s
.08187 .5 m .1056 .5 L .10585 .47863 L p .487 .381 .659 r
F P
0 g
s
.32855 .56159 m .30231 .56911 L .30314 .58694 L p .794 .774 .835 r
F P
0 g
s
.27081 .59563 m .30314 .58694 L .30231 .56911 L p .769 .756 .841 r
F P
0 g
s
.30314 .41306 m .27081 .40437 L .26969 .42395 L p .769 .499 .527 r
F P
0 g
s
.26969 .42395 m .30231 .43089 L .30314 .41306 L p .769 .499 .527 r
F P
0 g
s
.63906 .61768 m .6587 .63665 L .67372 .62702 L p .758 .476 .505 r
F P
0 g
s
.69741 .65067 m .67372 .62702 L .6587 .63665 L p .778 .512 .533 r
F P
0 g
s
.52314 .71396 m .53178 .7463 L .54929 .73748 L p .506 .418 .69 r
F P
0 g
s
.54929 .73748 m .53899 .70576 L .52314 .71396 L p .506 .418 .69 r
F P
0 g
s
.53239 .32072 m .53899 .29424 L .52314 .28604 L p .49 .417 .701 r
F P
0 g
s
.53178 .2537 m .52314 .28604 L .53899 .29424 L p .506 .409 .679 r
F P
0 g
s
.67372 .37298 m .69741 .34933 L .68102 .33857 L p .778 .759 .836 r
F P
0 g
s
.68102 .33857 m .6587 .36335 L .67372 .37298 L p .778 .759 .836 r
F P
0 g
s
.34922 .5194 m .3667 .51722 L .36668 .5 L p .807 .674 .717 r
F P
0 g
s
.3667 .51722 m .34922 .5194 L .34938 .53787 L p .809 .707 .752 r
F P
0 g
s
.3667 .48278 m .34922 .4806 L .34917 .5 L p .807 .644 .68 r
F P
0 g
s
.34917 .5 m .36668 .5 L .3667 .48278 L p .807 .644 .68 r
F P
0 g
s
.59219 .62088 m .58156 .60683 L .56666 .61546 L p .66 .455 .595 r
F P
0 g
s
.58156 .60683 m .59219 .62088 L .60811 .61151 L p .688 .459 .569 r
F P
0 g
s
.55173 .62405 m .55859 .64028 L .57542 .63063 L p .628 .444 .614 r
F P
0 g
s
.57542 .63063 m .56666 .61546 L .55173 .62405 L p .628 .444 .614 r
F P
0 g
s
.58156 .39317 m .59219 .37912 L .57542 .36937 L p .66 .623 .802 r
F P
0 g
s
.57542 .36937 m .56666 .38454 L .58156 .39317 L p .66 .623 .802 r
F P
0 g
s
.55859 .35972 m .55173 .37595 L .56666 .38454 L p .628 .582 .783 r
F P
0 g
s
.55173 .37595 m .55859 .35972 L .54251 .35062 L p .59 .539 .765 r
F P
0 g
s
.36668 .5 m .34917 .5 L .34922 .5194 L p .807 .674 .717 r
F P
0 g
s
.56666 .61546 m .57542 .63063 L .59219 .62088 L p .66 .455 .595 r
F P
0 g
s
.56666 .38454 m .57542 .36937 L .55859 .35972 L p .628 .582 .783 r
F P
0 g
s
.58735 .18852 m .61499 .1547 L .59779 .14679 L p .571 .352 .543 r
F P
0 g
s
.59779 .14679 m .56866 .17966 L .58735 .18852 L p .571 .352 .543 r
F P
0 g
s
.56866 .82034 m .59779 .85321 L .61499 .8453 L p .571 .581 .824 r
F P
0 g
s
.64404 .86972 m .61499 .8453 L .59779 .85321 L p .594 .659 .883 r
F P
0 g
s
.74309 .28037 m .75699 .23871 L .74155 .22777 L p .862 .726 .711 r
F P
0 g
s
.74817 .1904 m .74155 .22777 L .75699 .23871 L p .892 .695 .63 r
F P
0 g
s
.72608 .73139 m .74155 .77223 L .75699 .76129 L p .862 .681 .657 r
F P
0 g
s
.75699 .76129 m .74309 .71963 L .72608 .73139 L p .862 .681 .657 r
F P
0 g
s
.18825 .3993 m .14522 .40808 L .14347 .42693 L p .618 .368 .516 r
F P
0 g
s
.10779 .43988 m .14347 .42693 L .14522 .40808 L p .524 .288 .498 r
F P
0 g
s
.18657 .5801 m .14347 .57307 L .14522 .59192 L p .618 .642 .851 r
F P
0 g
s
.14522 .59192 m .18825 .6007 L .18657 .5801 L p .618 .642 .851 r
F P
0 g
s
.63497 .16471 m .66056 .13844 L .64404 .13028 L p .654 .4 .523 r
F P
0 g
s
.64404 .13028 m .61499 .1547 L .63497 .16471 L p .654 .4 .523 r
F P
0 g
s
.14215 .55076 m .10659 .54173 L .10779 .56012 L p .561 .549 .798 r
F P
0 g
s
.10779 .56012 m .14347 .57307 L .14215 .55076 L p .561 .549 .798 r
F P
0 g
s
.61499 .8453 m .64404 .86972 L .66056 .86156 L p .654 .668 .851 r
F P
0 g
s
.74155 .22777 m .74817 .1904 L .73284 .18017 L p .846 .647 .633 r
F P
0 g
s
.72288 .78453 m .73284 .81983 L .74817 .8096 L p .846 .734 .741 r
F P
0 g
s
.74817 .8096 m .74155 .77223 L .72288 .78453 L p .846 .734 .741 r
F P
0 g
s
.14347 .42693 m .10779 .43988 L .10659 .45827 L p .561 .368 .576 r
F P
0 g
s
.32812 .54277 m .34938 .53787 L .34922 .5194 L p .803 .702 .754 r
F P
0 g
s
.34938 .53787 m .32812 .54277 L .32855 .56159 L p .805 .739 .791 r
F P
0 g
s
.34938 .46213 m .32812 .45723 L .32786 .47809 L p .803 .609 .64 r
F P
0 g
s
.32786 .47809 m .34922 .4806 L .34938 .46213 L p .803 .609 .64 r
F P
0 g
s
.54251 .64938 m .5489 .67024 L .56709 .66003 L p .595 .434 .634 r
F P
0 g
s
.56709 .66003 m .55859 .64028 L .54251 .64938 L p .595 .434 .634 r
F P
0 g
s
.62298 .62746 m .60811 .61151 L .59219 .62088 L p .693 .468 .577 r
F P
0 g
s
.60811 .61151 m .62298 .62746 L .63906 .61768 L p .72 .465 .541 r
F P
0 g
s
.5489 .32976 m .54251 .35062 L .55859 .35972 L p .595 .537 .76 r
F P
0 g
s
.54251 .35062 m .5489 .32976 L .53239 .32072 L p .546 .486 .74 r
F P
0 g
s
.60811 .38849 m .62298 .37254 L .60505 .36188 L p .693 .664 .817 r
F P
0 g
s
.60505 .36188 m .59219 .37912 L .60811 .38849 L p .693 .664 .817 r
F P
0 g
s
.32855 .43841 m .30231 .43089 L .30169 .45199 L p .792 .564 .592 r
F P
0 g
s
.30169 .45199 m .32812 .45723 L .32855 .43841 L p .792 .564 .592 r
F P
0 g
s
.30231 .56911 m .32855 .56159 L .32812 .54277 L p .792 .729 .794 r
F P
0 g
s
.53239 .67928 m .53899 .70576 L .55757 .69575 L p .556 .426 .658 r
F P
0 g
s
.55757 .69575 m .5489 .67024 L .53239 .67928 L p .556 .426 .658 r
F P
0 g
s
.6587 .63665 m .63906 .61768 L .62298 .62746 L p .731 .486 .557 r
F P
0 g
s
.53899 .29424 m .53239 .32072 L .5489 .32976 L p .556 .483 .728 r
F P
0 g
s
.63906 .38232 m .6587 .36335 L .64073 .35227 L p .731 .708 .829 r
F P
0 g
s
.64073 .35227 m .62298 .37254 L .63906 .38232 L p .731 .708 .829 r
F P
0 g
s
.27081 .40437 m .23184 .39878 L .23042 .41948 L p .733 .468 .527 r
F P
0 g
s
.23042 .41948 m .26969 .42395 L .27081 .40437 L p .733 .468 .527 r
F P
0 g
s
.30231 .56911 m .26969 .57605 L .27081 .59563 L p .769 .756 .841 r
F P
0 g
s
.23184 .60122 m .27081 .59563 L .26969 .57605 L p .733 .729 .847 r
F P
0 g
s
.53178 .7463 m .54642 .78284 L .56506 .77373 L p .526 .462 .728 r
F P
0 g
s
.56506 .77373 m .54929 .73748 L .53178 .7463 L p .526 .462 .728 r
F P
0 g
s
.6587 .63665 m .68102 .66143 L .69741 .65067 L p .778 .512 .533 r
F P
0 g
s
.72174 .68162 m .69741 .65067 L .68102 .66143 L p .803 .558 .568 r
F P
0 g
s
.53899 .29424 m .54929 .26252 L .53178 .2537 L p .506 .409 .679 r
F P
0 g
s
.54642 .21716 m .53178 .2537 L .54929 .26252 L p .526 .396 .647 r
F P
0 g
s
.69741 .34933 m .72174 .31838 L .70452 .30679 L p .803 .753 .807 r
F P
0 g
s
.70452 .30679 m .68102 .33857 L .69741 .34933 L p .803 .753 .807 r
F P
0 g
s
.34922 .4806 m .32786 .47809 L .32778 .5 L p .801 .639 .681 r
F P
0 g
s
.32778 .5 m .34917 .5 L .34922 .4806 L p .801 .639 .681 r
F P
0 g
s
.32786 .52191 m .34922 .5194 L .34917 .5 L p .801 .669 .718 r
F P
0 g
s
.34922 .5194 m .32786 .52191 L .32812 .54277 L p .803 .702 .754 r
F P
0 g
s
.55859 .64028 m .56709 .66003 L .58611 .64915 L p .633 .452 .621 r
F P
0 g
s
.58611 .64915 m .57542 .63063 L .55859 .64028 L p .633 .452 .621 r
F P
0 g
s
.60505 .63812 m .59219 .62088 L .57542 .63063 L p .665 .463 .602 r
F P
0 g
s
.59219 .62088 m .60505 .63812 L .62298 .62746 L p .693 .468 .577 r
F P
0 g
s
.59219 .37912 m .60505 .36188 L .58611 .35085 L p .665 .622 .797 r
F P
0 g
s
.58611 .35085 m .57542 .36937 L .59219 .37912 L p .665 .622 .797 r
F P
0 g
s
.56709 .33997 m .55859 .35972 L .57542 .36937 L p .633 .581 .778 r
F P
0 g
s
.55859 .35972 m .56709 .33997 L .5489 .32976 L p .595 .537 .76 r
F P
0 g
s
.54642 .78284 m .56866 .82034 L .58735 .81148 L p .548 .517 .773 r
F P
0 g
s
.61499 .8453 m .58735 .81148 L .56866 .82034 L p .571 .581 .824 r
F P
0 g
s
.23184 .39878 m .18825 .3993 L .18657 .4199 L p .684 .425 .524 r
F P
0 g
s
.14347 .42693 m .18657 .4199 L .18825 .3993 L p .618 .368 .516 r
F P
0 g
s
.70452 .69321 m .72608 .73139 L .74309 .71963 L p .831 .615 .609 r
F P
0 g
s
.74309 .71963 m .72174 .68162 L .70452 .69321 L p .831 .615 .609 r
F P
0 g
s
.56506 .22627 m .58735 .18852 L .56866 .17966 L p .548 .378 .603 r
F P
0 g
s
.56866 .17966 m .54642 .21716 L .56506 .22627 L p .548 .378 .603 r
F P
0 g
s
.72174 .31838 m .74309 .28037 L .72608 .26861 L p .831 .743 .767 r
F P
0 g
s
.74155 .22777 m .72608 .26861 L .74309 .28037 L p .862 .726 .711 r
F P
0 g
s
.23042 .58052 m .18657 .5801 L .18825 .6007 L p .684 .692 .851 r
F P
0 g
s
.18825 .6007 m .23184 .60122 L .23042 .58052 L p .684 .692 .851 r
F P
0 g
s
.18657 .4199 m .23042 .41948 L .23184 .39878 L p .684 .425 .524 r
F P
0 g
s
.58735 .81148 m .56506 .77373 L .54642 .78284 L p .548 .517 .773 r
F P
0 g
s
.54929 .26252 m .56506 .22627 L .54642 .21716 L p .526 .396 .647 r
F P
0 g
s
.26969 .57605 m .23042 .58052 L .23184 .60122 L p .733 .729 .847 r
F P
0 g
s
.68102 .66143 m .70452 .69321 L .72174 .68162 L p .803 .558 .568 r
F P
0 g
s
.72608 .26861 m .70452 .30679 L .72174 .31838 L p .831 .743 .767 r
F P
0 g
s
.34917 .5 m .32778 .5 L .32786 .52191 L p .801 .669 .718 r
F P
0 g
s
.57542 .63063 m .58611 .64915 L .60505 .63812 L p .665 .463 .602 r
F P
0 g
s
.57542 .36937 m .58611 .35085 L .56709 .33997 L p .633 .581 .778 r
F P
0 g
s
.65681 .17638 m .67856 .14797 L .66056 .13844 L p .698 .464 .564 r
F P
0 g
s
.66056 .13844 m .63497 .16471 L .65681 .17638 L p .698 .464 .564 r
F P
0 g
s
.70186 .79762 m .71559 .83066 L .73284 .81983 L p .806 .714 .763 r
F P
0 g
s
.73284 .81983 m .72288 .78453 L .70186 .79762 L p .806 .714 .763 r
F P
0 g
s
.73284 .18017 m .72288 .21547 L .74155 .22777 L p .846 .647 .633 r
F P
0 g
s
.72288 .21547 m .73284 .18017 L .71559 .16934 L p .806 .603 .627 r
F P
0 g
s
.14133 .52601 m .10585 .52137 L .10659 .54173 L p .58 .525 .757 r
F P
0 g
s
.10659 .54173 m .14215 .55076 L .14133 .52601 L p .58 .525 .757 r
F P
0 g
s
.66056 .86156 m .63497 .83529 L .61499 .8453 L p .654 .668 .851 r
F P
0 g
s
.63497 .83529 m .66056 .86156 L .67856 .85203 L p .698 .677 .826 r
F P
0 g
s
.10659 .45827 m .14215 .44924 L .14347 .42693 L p .561 .368 .576 r
F P
0 g
s
.14215 .44924 m .10659 .45827 L .10585 .47863 L p .58 .423 .633 r
F P
0 g
s
.32812 .54277 m .30169 .54801 L .30231 .56911 L p .792 .729 .794 r
F P
0 g
s
.26969 .57605 m .30231 .56911 L .30169 .54801 L p .769 .712 .798 r
F P
0 g
s
.30231 .43089 m .26969 .42395 L .26885 .44716 L p .769 .545 .594 r
F P
0 g
s
.26885 .44716 m .30169 .45199 L .30231 .43089 L p .769 .545 .594 r
F P
0 g
s
.53899 .70576 m .54929 .73748 L .56981 .7266 L p .571 .456 .683 r
F P
0 g
s
.56981 .7266 m .55757 .69575 L .53899 .70576 L p .571 .456 .683 r
F P
0 g
s
.62298 .62746 m .64073 .64773 L .6587 .63665 L p .731 .486 .557 r
F P
0 g
s
.68102 .66143 m .6587 .63665 L .64073 .64773 L p .748 .517 .581 r
F P
0 g
s
.5489 .32976 m .55757 .30425 L .53899 .29424 L p .556 .483 .728 r
F P
0 g
s
.54929 .26252 m .53899 .29424 L .55757 .30425 L p .571 .476 .708 r
F P
0 g
s
.6587 .36335 m .68102 .33857 L .66134 .32624 L p .748 .704 .811 r
F P
0 g
s
.66134 .32624 m .64073 .35227 L .6587 .36335 L p .748 .704 .811 r
F P
0 g
s
.30169 .54801 m .32812 .54277 L .32786 .52191 L p .79 .691 .756 r
F P
0 g
s
.32812 .45723 m .30169 .45199 L .30132 .4754 L p .79 .598 .642 r
F P
0 g
s
.30132 .4754 m .32786 .47809 L .32812 .45723 L p .79 .598 .642 r
F P
0 g
s
.5489 .67024 m .55757 .69575 L .57804 .68437 L p .604 .452 .649 r
F P
0 g
s
.57804 .68437 m .56709 .66003 L .5489 .67024 L p .604 .452 .649 r
F P
0 g
s
.64073 .64773 m .62298 .62746 L .60505 .63812 L p .703 .487 .592 r
F P
0 g
s
.55757 .30425 m .5489 .32976 L .56709 .33997 L p .604 .534 .749 r
F P
0 g
s
.62298 .37254 m .64073 .35227 L .62065 .34023 L p .703 .662 .806 r
F P
0 g
s
.62065 .34023 m .60505 .36188 L .62298 .37254 L p .703 .662 .806 r
F P
0 g
s
.18531 .55566 m .14215 .55076 L .14347 .57307 L p .64 .611 .805 r
F P
0 g
s
.14347 .57307 m .18657 .5801 L .18531 .55566 L p .64 .611 .805 r
F P
0 g
s
.60914 .19964 m .63497 .16471 L .61499 .1547 L p .631 .431 .594 r
F P
0 g
s
.61499 .1547 m .58735 .18852 L .60914 .19964 L p .631 .431 .594 r
F P
0 g
s
.70555 .7447 m .72288 .78453 L .74155 .77223 L p .818 .664 .691 r
F P
0 g
s
.74155 .77223 m .72608 .73139 L .70555 .7447 L p .818 .664 .691 r
F P
0 g
s
.72608 .26861 m .74155 .22777 L .72288 .21547 L p .818 .672 .702 r
F P
0 g
s
.58735 .81148 m .61499 .8453 L .63497 .83529 L p .631 .599 .799 r
F P
0 g
s
.18657 .4199 m .14347 .42693 L .14215 .44924 L p .64 .434 .588 r
F P
0 g
s
.67948 .18914 m .6972 .15844 L .67856 .14797 L p .736 .515 .593 r
F P
0 g
s
.67856 .14797 m .65681 .17638 L .67948 .18914 L p .736 .515 .593 r
F P
0 g
s
.67856 .85203 m .65681 .82362 L .63497 .83529 L p .698 .677 .826 r
F P
0 g
s
.65681 .82362 m .67856 .85203 L .6972 .84156 L p .736 .686 .803 r
F P
0 g
s
.71559 .16934 m .70186 .20238 L .72288 .21547 L p .806 .603 .627 r
F P
0 g
s
.70186 .20238 m .71559 .16934 L .6972 .15844 L p .771 .56 .613 r
F P
0 g
s
.67948 .81086 m .6972 .84156 L .71559 .83066 L p .771 .699 .783 r
F P
0 g
s
.71559 .83066 m .70186 .79762 L .67948 .81086 L p .771 .699 .783 r
F P
0 g
s
.14105 .5 m .1056 .5 L .10585 .52137 L p .589 .497 .718 r
F P
0 g
s
.10585 .52137 m .14133 .52601 L .14105 .5 L p .589 .497 .718 r
F P
0 g
s
.10585 .47863 m .14133 .47399 L .14215 .44924 L p .58 .423 .633 r
F P
0 g
s
.14133 .47399 m .10585 .47863 L .1056 .5 L p .589 .464 .678 r
F P
0 g
s
.30132 .5246 m .32786 .52191 L .32778 .5 L p .789 .659 .72 r
F P
0 g
s
.32786 .52191 m .30132 .5246 L .30169 .54801 L p .79 .691 .756 r
F P
0 g
s
.32786 .47809 m .30132 .4754 L .30119 .5 L p .789 .629 .683 r
F P
0 g
s
.30119 .5 m .32778 .5 L .32786 .47809 L p .789 .629 .683 r
F P
0 g
s
.62065 .65977 m .60505 .63812 L .58611 .64915 L p .674 .481 .617 r
F P
0 g
s
.60505 .63812 m .62065 .65977 L .64073 .64773 L p .703 .487 .592 r
F P
0 g
s
.56709 .66003 m .57804 .68437 L .59941 .67218 L p .642 .47 .635 r
F P
0 g
s
.59941 .67218 m .58611 .64915 L .56709 .66003 L p .642 .47 .635 r
F P
0 g
s
.57804 .31563 m .56709 .33997 L .58611 .35085 L p .642 .578 .768 r
F P
0 g
s
.56709 .33997 m .57804 .31563 L .55757 .30425 L p .604 .534 .749 r
F P
0 g
s
.60505 .36188 m .62065 .34023 L .59941 .32782 L p .674 .62 .786 r
F P
0 g
s
.59941 .32782 m .58611 .35085 L .60505 .36188 L p .674 .62 .786 r
F P
0 g
s
.6972 .15844 m .67948 .18914 L .70186 .20238 L p .771 .56 .613 r
F P
0 g
s
.6972 .84156 m .67948 .81086 L .65681 .82362 L p .736 .686 .803 r
F P
0 g
s
.1056 .5 m .14105 .5 L .14133 .47399 L p .589 .464 .678 r
F P
0 g
s
.30169 .54801 m .26885 .55284 L .26969 .57605 L p .769 .712 .798 r
F P
0 g
s
.23042 .58052 m .26969 .57605 L .26885 .55284 L p .738 .687 .802 r
F P
0 g
s
.26969 .42395 m .23042 .41948 L .22934 .44404 L p .738 .518 .595 r
F P
0 g
s
.22934 .44404 m .26885 .44716 L .26969 .42395 L p .738 .518 .595 r
F P
0 g
s
.54929 .73748 m .56506 .77373 L .58687 .76237 L p .589 .495 .716 r
F P
0 g
s
.58687 .76237 m .56981 .7266 L .54929 .73748 L p .589 .495 .716 r
F P
0 g
s
.64073 .64773 m .66134 .67376 L .68102 .66143 L p .748 .517 .581 r
F P
0 g
s
.70452 .69321 m .68102 .66143 L .66134 .67376 L p .768 .557 .612 r
F P
0 g
s
.55757 .30425 m .56981 .2734 L .54929 .26252 L p .571 .476 .708 r
F P
0 g
s
.56506 .22627 m .54929 .26252 L .56981 .2734 L p .589 .466 .681 r
F P
0 g
s
.68102 .33857 m .70452 .30679 L .68379 .29358 L p .768 .698 .785 r
F P
0 g
s
.68379 .29358 m .66134 .32624 L .68102 .33857 L p .768 .698 .785 r
F P
0 g
s
.32778 .5 m .30119 .5 L .30132 .5246 L p .789 .659 .72 r
F P
0 g
s
.58611 .64915 m .59941 .67218 L .62065 .65977 L p .674 .481 .617 r
F P
0 g
s
.58611 .35085 m .59941 .32782 L .57804 .31563 L p .642 .578 .768 r
F P
0 g
s
.26885 .55284 m .30169 .54801 L .30132 .5246 L p .769 .675 .759 r
F P
0 g
s
.30169 .45199 m .26885 .44716 L .26834 .47292 L p .769 .581 .644 r
F P
0 g
s
.26834 .47292 m .30132 .4754 L .30169 .45199 L p .769 .581 .644 r
F P
0 g
s
.55757 .69575 m .56981 .7266 L .59238 .71417 L p .618 .48 .672 r
F P
0 g
s
.59238 .71417 m .57804 .68437 L .55757 .69575 L p .618 .48 .672 r
F P
0 g
s
.66134 .67376 m .64073 .64773 L .62065 .65977 L p .718 .515 .614 r
F P
0 g
s
.56981 .2734 m .55757 .30425 L .57804 .31563 L p .618 .528 .731 r
F P
0 g
s
.64073 .35227 m .66134 .32624 L .63929 .31292 L p .718 .657 .789 r
F P
0 g
s
.63929 .31292 m .62065 .34023 L .64073 .35227 L p .718 .657 .789 r
F P
0 g
s
.23042 .41948 m .18657 .4199 L .18531 .44434 L p .696 .482 .593 r
F P
0 g
s
.14215 .44924 m .18531 .44434 L .18657 .4199 L p .64 .434 .588 r
F P
0 g
s
.58687 .23763 m .60914 .19964 L .58735 .18852 L p .609 .452 .644 r
F P
0 g
s
.58735 .18852 m .56506 .22627 L .58687 .23763 L p .609 .452 .644 r
F P
0 g
s
.56506 .77373 m .58735 .81148 L .60914 .80036 L p .609 .543 .755 r
F P
0 g
s
.63497 .83529 m .60914 .80036 L .58735 .81148 L p .631 .599 .799 r
F P
0 g
s
.68379 .70642 m .70555 .7447 L .72608 .73139 L p .792 .606 .649 r
F P
0 g
s
.72608 .73139 m .70452 .69321 L .68379 .70642 L p .792 .606 .649 r
F P
0 g
s
.22934 .55596 m .18531 .55566 L .18657 .5801 L p .696 .655 .805 r
F P
0 g
s
.18657 .5801 m .23042 .58052 L .22934 .55596 L p .696 .655 .805 r
F P
0 g
s
.70452 .30679 m .72608 .26861 L .70555 .2553 L p .792 .688 .749 r
F P
0 g
s
.72288 .21547 m .70555 .2553 L .72608 .26861 L p .818 .672 .702 r
F P
0 g
s
.26885 .55284 m .22934 .55596 L .23042 .58052 L p .738 .687 .802 r
F P
0 g
s
.18531 .44434 m .22934 .44404 L .23042 .41948 L p .696 .482 .593 r
F P
0 g
s
.60914 .80036 m .58687 .76237 L .56506 .77373 L p .609 .543 .755 r
F P
0 g
s
.66134 .67376 m .68379 .70642 L .70452 .69321 L p .768 .557 .612 r
F P
0 g
s
.56981 .2734 m .58687 .23763 L .56506 .22627 L p .589 .466 .681 r
F P
0 g
s
.70555 .2553 m .68379 .29358 L .70452 .30679 L p .792 .688 .749 r
F P
0 g
s
.70555 .2553 m .72288 .21547 L .70186 .20238 L p .781 .626 .688 r
F P
0 g
s
.63303 .21253 m .65681 .17638 L .63497 .16471 L p .676 .49 .627 r
F P
0 g
s
.63497 .16471 m .60914 .19964 L .63303 .21253 L p .676 .49 .627 r
F P
0 g
s
.60914 .80036 m .63497 .83529 L .65681 .82362 L p .676 .613 .778 r
F P
0 g
s
.18531 .44434 m .14215 .44924 L .14133 .47399 L p .651 .482 .642 r
F P
0 g
s
.18453 .52853 m .14133 .52601 L .14215 .55076 L p .651 .581 .764 r
F P
0 g
s
.14215 .55076 m .18531 .55566 L .18453 .52853 L p .651 .581 .764 r
F P
0 g
s
.68244 .75894 m .70186 .79762 L .72288 .78453 L p .781 .649 .717 r
F P
0 g
s
.72288 .78453 m .70555 .7447 L .68244 .75894 L p .781 .649 .717 r
F P
0 g
s
.30132 .4754 m .26834 .47292 L .26816 .5 L p .769 .612 .685 r
F P
0 g
s
.26816 .5 m .30119 .5 L .30132 .4754 L p .769 .612 .685 r
F P
0 g
s
.26834 .52708 m .30132 .5246 L .30119 .5 L p .769 .643 .723 r
F P
0 g
s
.30132 .5246 m .26834 .52708 L .26885 .55284 L p .769 .675 .759 r
F P
0 g
s
.63929 .68708 m .62065 .65977 L .59941 .67218 L p .688 .508 .638 r
F P
0 g
s
.62065 .65977 m .63929 .68708 L .66134 .67376 L p .718 .515 .614 r
F P
0 g
s
.57804 .68437 m .59238 .71417 L .61592 .70078 L p .655 .497 .657 r
F P
0 g
s
.61592 .70078 m .59941 .67218 L .57804 .68437 L p .655 .497 .657 r
F P
0 g
s
.59238 .28583 m .57804 .31563 L .59941 .32782 L p .655 .573 .751 r
F P
0 g
s
.57804 .31563 m .59238 .28583 L .56981 .2734 L p .618 .528 .731 r
F P
0 g
s
.62065 .34023 m .63929 .31292 L .61592 .29922 L p .688 .615 .769 r
F P
0 g
s
.61592 .29922 m .59941 .32782 L .62065 .34023 L p .688 .615 .769 r
F P
0 g
s
.30119 .5 m .26816 .5 L .26834 .52708 L p .769 .643 .723 r
F P
0 g
s
.59941 .67218 m .61592 .70078 L .63929 .68708 L p .688 .508 .638 r
F P
0 g
s
.59941 .32782 m .61592 .29922 L .59238 .28583 L p .655 .573 .751 r
F P
0 g
s
.22934 .55596 m .26885 .55284 L .26834 .52708 L p .74 .652 .762 r
F P
0 g
s
.26885 .44716 m .22934 .44404 L .22868 .47132 L p .74 .556 .645 r
F P
0 g
s
.22868 .47132 m .26834 .47292 L .26885 .44716 L p .74 .556 .645 r
F P
0 g
s
.68379 .70642 m .66134 .67376 L .63929 .68708 L p .736 .552 .643 r
F P
0 g
s
.56981 .7266 m .58687 .76237 L .61082 .74931 L p .635 .516 .702 r
F P
0 g
s
.61082 .74931 m .59238 .71417 L .56981 .7266 L p .635 .516 .702 r
F P
0 g
s
.58687 .23763 m .56981 .2734 L .59238 .28583 L p .635 .52 .706 r
F P
0 g
s
.66134 .32624 m .68379 .29358 L .6605 .27937 L p .736 .651 .765 r
F P
0 g
s
.6605 .27937 m .63929 .31292 L .66134 .32624 L p .736 .651 .765 r
F P
0 g
s
.70186 .20238 m .68244 .24106 L .70555 .2553 L p .781 .626 .688 r
F P
0 g
s
.68244 .24106 m .70186 .20238 L .67948 .18914 L p .747 .583 .672 r
F P
0 g
s
.65787 .22656 m .67948 .18914 L .65681 .17638 L p .713 .539 .653 r
F P
0 g
s
.65681 .17638 m .63303 .21253 L .65787 .22656 L p .713 .539 .653 r
F P
0 g
s
.14133 .47399 m .18453 .47147 L .18531 .44434 L p .651 .482 .642 r
F P
0 g
s
.18453 .47147 m .14133 .47399 L .14105 .5 L p .656 .519 .685 r
F P
0 g
s
.65681 .82362 m .63303 .78747 L .60914 .80036 L p .676 .613 .778 r
F P
0 g
s
.63303 .78747 m .65681 .82362 L .67948 .81086 L p .713 .625 .758 r
F P
0 g
s
.65787 .77344 m .67948 .81086 L .70186 .79762 L p .747 .637 .738 r
F P
0 g
s
.70186 .79762 m .68244 .75894 L .65787 .77344 L p .747 .637 .738 r
F P
0 g
s
.18426 .5 m .14105 .5 L .14133 .52601 L p .656 .552 .725 r
F P
0 g
s
.14133 .52601 m .18453 .52853 L .18426 .5 L p .656 .552 .725 r
F P
0 g
s
.22934 .44404 m .18531 .44434 L .18453 .47147 L p .702 .524 .645 r
F P
0 g
s
.58687 .76237 m .60914 .80036 L .63303 .78747 L p .654 .56 .737 r
F P
0 g
s
.22868 .52868 m .18453 .52853 L .18531 .55566 L p .702 .622 .764 r
F P
0 g
s
.18531 .55566 m .22934 .55596 L .22868 .52868 L p .702 .622 .764 r
F P
0 g
s
.6605 .72063 m .68244 .75894 L .70555 .7447 L p .758 .596 .677 r
F P
0 g
s
.70555 .7447 m .68379 .70642 L .6605 .72063 L p .758 .596 .677 r
F P
0 g
s
.61082 .25069 m .63303 .21253 L .60914 .19964 L p .654 .508 .672 r
F P
0 g
s
.60914 .19964 m .58687 .23763 L .61082 .25069 L p .654 .508 .672 r
F P
0 g
s
.68379 .29358 m .70555 .2553 L .68244 .24106 L p .758 .641 .732 r
F P
0 g
s
.67948 .18914 m .65787 .22656 L .68244 .24106 L p .747 .583 .672 r
F P
0 g
s
.67948 .81086 m .65787 .77344 L .63303 .78747 L p .713 .625 .758 r
F P
0 g
s
.14105 .5 m .18426 .5 L .18453 .47147 L p .656 .519 .685 r
F P
0 g
s
.26834 .52708 m .22868 .52868 L .22934 .55596 L p .74 .652 .762 r
F P
0 g
s
.18453 .47147 m .22868 .47132 L .22934 .44404 L p .702 .524 .645 r
F P
0 g
s
.63303 .78747 m .61082 .74931 L .58687 .76237 L p .654 .56 .737 r
F P
0 g
s
.63929 .68708 m .6605 .72063 L .68379 .70642 L p .736 .552 .643 r
F P
0 g
s
.59238 .28583 m .61082 .25069 L .58687 .23763 L p .635 .52 .706 r
F P
0 g
s
.68244 .24106 m .6605 .27937 L .68379 .29358 L p .758 .641 .732 r
F P
0 g
s
.26834 .47292 m .22868 .47132 L .22845 .5 L p .741 .589 .687 r
F P
0 g
s
.22845 .5 m .26816 .5 L .26834 .47292 L p .741 .589 .687 r
F P
0 g
s
.22868 .52868 m .26834 .52708 L .26816 .5 L p .741 .62 .725 r
F P
0 g
s
.59238 .71417 m .61082 .74931 L .63577 .73517 L p .672 .532 .685 r
F P
0 g
s
.63577 .73517 m .61592 .70078 L .59238 .71417 L p .672 .532 .685 r
F P
0 g
s
.6605 .72063 m .63929 .68708 L .61592 .70078 L p .705 .543 .666 r
F P
0 g
s
.61082 .25069 m .59238 .28583 L .61592 .29922 L p .672 .566 .727 r
F P
0 g
s
.63929 .31292 m .6605 .27937 L .63577 .26483 L p .705 .608 .746 r
F P
0 g
s
.63577 .26483 m .61592 .29922 L .63929 .31292 L p .705 .608 .746 r
F P
0 g
s
.26816 .5 m .22845 .5 L .22868 .52868 L p .741 .62 .725 r
F P
0 g
s
.61592 .70078 m .63577 .73517 L .6605 .72063 L p .705 .543 .666 r
F P
0 g
s
.61592 .29922 m .63577 .26483 L .61082 .25069 L p .672 .566 .727 r
F P
0 g
s
.61082 .74931 m .63303 .78747 L .65787 .77344 L p .691 .574 .719 r
F P
0 g
s
.22868 .47132 m .18453 .47147 L .18426 .5 L p .704 .559 .687 r
F P
0 g
s
.63577 .73517 m .65787 .77344 L .68244 .75894 L p .725 .586 .699 r
F P
0 g
s
.68244 .75894 m .6605 .72063 L .63577 .73517 L p .725 .586 .699 r
F P
0 g
s
.63577 .26483 m .65787 .22656 L .63303 .21253 L p .691 .555 .695 r
F P
0 g
s
.63303 .21253 m .61082 .25069 L .63577 .26483 L p .691 .555 .695 r
F P
0 g
s
.6605 .27937 m .68244 .24106 L .65787 .22656 L p .725 .598 .714 r
F P
0 g
s
.22845 .5 m .18426 .5 L .18453 .52853 L p .704 .591 .726 r
F P
0 g
s
.18453 .52853 m .22868 .52868 L .22845 .5 L p .704 .591 .726 r
F P
0 g
s
.18426 .5 m .22845 .5 L .22868 .47132 L p .704 .559 .687 r
F P
0 g
s
.65787 .77344 m .63577 .73517 L .61082 .74931 L p .691 .574 .719 r
F P
0 g
s
.65787 .22656 m .63577 .26483 L .6605 .27937 L p .725 .598 .714 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
      ImageSize->{288, 288},
      ImageMargins->{{0, 0}, {0, 0}},
      ImageRegion->{{0, 1}, {0, 1}},
      ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ROooo`d0002:
oooo001ooooo2P0000goool:0000P?ooo`00NOooo`H0000Qoooo1P0007[oool007Coool50000;Ooo
o`D0001eoooo001aoooo0`0003Ooool30000L_ooo`00KOooo`@0000moooo100006koool006[oool3
0000AOooo`<0001[oooo001Woooo0`0004_oool30000J?ooo`00I?ooo`<0001Aoooo0`0006Goool0
067oool30000Eoooo`<0001Roooo001Noooo0`0005goool30000Goooo`00Foooo`<0001Soooo0P00
05goool005Woool20000J?ooo`80001Koooo001Goooo0P0005gooolA0000FOooo`00EOooo`80001K
oooo1@00009B000500000Wd000T0001Goooo001Coooo0P0005[oool500000U8000<00003PQL]1000
00>K91h90000E?ooo`00DOooo`80001Joooo1000009B000300000h8G;@<00003W3mC100000B^@S`7
0000D_ooo`00D?ooo`030000oooooooo05Soool400000U808P800003PQL]0`0000BL?e<200000ZaI
J@800002[T8l0P0000>kEdl60000D?ooo`00C_ooo`80001Ioooo1000009B028200000X0]F@<00005
W3mC0P0000J/FFT200001;]GC`050000aFIJ00000000_D8H00<0001?oooo001=oooo00<0003ooooo
ool0F?ooo`<00002DP0R0P0000B0;ET00`0009Q?MIQ?M@02000000>L?e<0000000001ZaIJ@800002
^6]g0P000003^eM?0000aFIJ00?5IUX3000000?=E1/000000000COooo`00Boooo`80001Ioooo0`00
00=B02800`00080]FH0]F@02P2eI0P0000FHCgD200001ZaIJ@030000^6]g^6]g00BhJgL200000lEV
FP050000cW9OcW9O0000cE@K00<0001<oooo0019oooo0P0005Woool300000e808P800004P2eI00<0
002HCgFHCgD019Q?M@030000YfJ5YfJ500800002[5UY0P0000JhJgL00`000<9iP<9iP002000000C5
IUX0003>LUo>LUl70000B_ooo`00B?ooo`030000oooooooo05Soool300000U808P800005P2eI00<0
002HCgFHCgD019Q?M@030000YfJ5YfJ500>WIXD200001kQ[M`030000`WV0`WV000?2NH0200000/ib
G`030000eg]Oeg]O00<000000oooo`000?ooo`18oooo0016oooo0P0005[oool200000Th3B`<00004
P2eI0P0000FHCgD200001ZMVQ@040000/WJ@000000001;Q[M`030000`WV0`WV000C2NH000`000<^5
Q@00000200000]MkG`050000h89I00000000oooo00800017oooo0015oooo00<0003oooooool0FOoo
o`800003CP=;00<0001j>gEj>gD00P000003P2eI0000V4me00FHCgD00`000:MVQJMVQ@05YfJ500<0
002bMY2bMY000[9fT08000000kQ[M`000<9iP005`WV000<0003;QHG;QHD00/^5Q@050000eg]Oeg]O
0000h89I00<00002oooo00<0003oooooool0A?ooo`00A?ooo`030000oooooooo05Woool200000dh3
B`030000NS]eNS]e00=j>gD200001IQ?M@030000YfJ5YfJ500FWIXD00`000;9fT;9fT005/WJ@0P00
00K2NH000`000<^5QL^5Q@02bhF50`000003eg]O0000h89I00800003oooo00<0003oooooool0@ooo
o`00@oooo`030000oooooooo05Woool200000dh3B`030000NS]eNS]e00=j>gD00`00099JRi9JR`02
00000YQ?M@030000YfJ5YfJ500JWIXD00`000;9fT;9fT004/WJ@00<0002lPiNlPiL00P0000?2NH00
0`000<^5QL^5Q@02bhF500@0003DShSDShSDShP2000000CPPUT0000000000003oooo00<0003ooooo
ool0@_ooo`00@_ooo`030000oooooooo05Woool300000Th3B`030000NS]eNS]e00=j>gD00`00099J
Ri9JR`03TUZ;0`0000NWIXD00`000;9fT;9fT005/WJ@00<0002lPiNlPiL00[b3U`8000000l9iP000
0<^5Q@03bhF500<0003DShSDShP00]B?R0040000h89I0000ihI;0P0000?oool00`000?ooooooo`11
oooo0010oooo0P0005_oool300000Th3B`030000NS]eNS]e00=j>gD00`00099JRi9JR`04TUZ;00<0
002QKYRQKYP00P0000BWIXD00`000;9fT;9fT005/WJ@00<0002lPiNlPiL01Kb3U`030000bhF5bhF5
00?;QHD00`000=B?R=B?R002e8n81`0000?oool20000@Oooo`00?oooo`030000oooooooo05[oool3
00000Th3B`030000NS]eNS]e00=j>gD00`00099JRi9JR`04TUZ;00<0002QKYRQKYP00j5^V0800000
0jMVQ@000;9fT006/WJ@00<0002lPiNlPiL01Kb3U`040000aHnL000000000l^5Q@030000e8n8e8n8
00;DShP00`000=jIQ]jIQP02000000?YPRd0003oool01?ooo`030000oooooooo03koool003koool0
0`000?ooooooo`1Joooo0`00009>0d/00`0007XkMGXkM@04NS]e00<0002BFX^BFX/0199JR`030000
XFjHXFjH00FQKYP200001[9fT0030000_8>G_8>G00JlPiL010000<F?W<F?W<F?W0<00005e8n800<0
003NVHKNVHH00`000003jH8]0000oooo00Coool00`000?ooooooo`0moooo000moooo00<0003ooooo
ool0F_ooo`@000000dh3B`0007XkM@05NS]e00<0002BFX^BFX/0199JR`030000XFjHXFjH00FQKYP0
0`000:emX:emX00200001;9fT0030000_8>G_8>G00FlPiL00`000<F?W<F?W004aHnL00<0003DShSD
ShP00]B?R0090000gYV6gYV6gYV60000jZ>00000jH8]000000Koool00`000?ooooooo`0loooo000l
oooo00<0003oooooool0F_ooo`030000000J000000974VP200001GXkM@030000TUZ;TUZ;00BBFX/0
0`000:5^V:5^V005XFjH00<0002]OJ2]OJ000jemX08000000k9fT0000;b3U`07_8>G00<00035Sic5
Si`01<F?W0<00002e8n800H0003NVHKNVHKNVHH0003ZXh0400001_ooo`030000oooooooo03_oool0
03_oool00`000?ooooooo`1Koooo00D0000001X000174VP000000WA4R@800002NS]e00<0002BFX^B
FX/0199JR`030000XFjHXFjH00JQKYP00`000:emX:emX005[GfP00<0002lPiNlPiL01[b3U`030000
aHnLaHnL00C5Si`010000<jJX<jJX<jJX0<00003gYV600<0003ZXh0000000_F[L0030000oooooooo
00Goool00`000?ooooooo`0joooo000joooo00<0003oooooool0Foooo`030000000J000000974VP0
0`0007A4RGA4R@02M4B90P0000JBFX/00`000:5^V:5^V006XFjH00<0002]OJ2]OJ001JemX0040000
]XVW000000001[b3U`030000aHnLaHnL00C5Si`00`000<jJX<jJX003cYZP00D0003NVHKNVHKNVHH0
00000^ZSP0040000mJ]`000000001oooo`030000oooooooo03Woool003Woool00`000?ooooooo`1L
oooo0P0000974VP00`0007A4RGA4R@03M4B900@0002<H9X000000004TUZ;00<0002QKYRQKYP01J5^
V0030000[GfP[GfP00J]OJ0010000;J9YkJ9YkJ9Y`800003_8>G00<00035Sic5Si`01<F?W0030000
cYZPcYZP00C>VZ03000000KNVHH0003ZXh3ZXh00003eZg0200002?ooo`030000oooooooo03Soool0
03Soool00`000?ooooooo`1Loooo00<0000001X000000TLBJ0030000M4B9M4B900=dA8T0100008aP
VXaPVXaPVP8000000i9JR`000:5^V006XFjH00<0002]OJ2]OJ001ZemX0030000]XVW]XVW00BfRJL2
000000>lPiL00035Si`01LF?W0030000cYZPcYZP00?>VZ0010000=RUX]RUX]RUXP800002jZ>000@0
003eZg3eZg000009oooo00<0003oooooool0=oooo`00=oooo`030000oooooooo05goool200000TLB
J0030000M4B9M4B900=dA8T00`0008aPVXaPVP04S62J0P0000JQKYP00`000:emX:emX006[GfP00<0
002fRJNfRJL01kJ9Y`030000aHnLaHnL00G5Si`00`000<jJX<jJX003cYZP00<0003HYJ;HYJ800]RU
XP040000jZ>0jZ>000000_F[L0800009oooo00<0003oooooool0=_ooo`00=_ooo`030000oooooooo
05goool00`0000006P000002Aa9X00<0001dA8UdA8T00WA4R@030000S62JS62J00B<H9X00`0009]c
Y9]cY00200001:5^V0030000[GfP[GfP00J]OJ000`000;J9YkJ9Y`06]XVW00@0002oUJ`000000004
aHnL00<0003>VZ3>VZ001<jJX0030000f:FRf:FR00;HYJ83000000?ZXh00003eZg000P0000[oool0
0`000?ooooooo`0eoooo000eoooo00<0003oooooool0G_ooo`800002Aa9X00<0001dA8UdA8T00gA4
R@030000S62JS62J00B<H9X00`0009]cY9]cY002Vg>T0P000003XFjH0000[GfP00N]OJ000`000;J9
YkJ9Y`07]XVW00D0002oUJboUJboUJ`000000lF?W0030000cYZPcYZP00C>VZ000`000=RUX]RUXP02
f:FR00<0003T/J7T/J400P000003mJ]`0000000000_oool00`000?ooooooo`0doooo000doooo00<0
003oooooool0G_ooo`800003Aa9X00<0001dA8UdA8T00WA4R@030000S62JS62J00B<H9X00`0009]c
Y9]cY005Vg>T0P0000N]OJ000`000;J9YkJ9Y`07]XVW00<0002oUJboUJ`00knE[0<00006cYZP00<0
003HYJ;HYJ800]RUXP030000i;6Qi;6Q00;T/J4010000?F[L?F[L00000coool00`000?ooooooo`0c
oooo000coooo00<0003oooooool0Goooo`800002Aa9X00<0001dA8UdA8T00gA4R@030000S62JS62J
00B<H9X00`0009]cY9]cY004Vg>T00<0002WPZbWPZ`00P0000B]OJ000`000;J9YkJ9Y`07]XVW00<0
002oUJboUJ`01[nE[0800005cYZP00<0003HYJ;HYJ800]RUXP030000i;6Qi;6Q00;T/J4500003?oo
o`030000oooooooo03;oool003;oool00`000?ooooooo`1Ooooo0`0000974VP00`0007A4RGA4R@02
M4B900<0002<H9Z<H9X018aPVP030000Vg>TVg>T00FKLj@00`000:N2[:N2[002Yh:/0P0000:]OJ00
0`000;J9YkJ9Y`07]XVW00<0002oUJboUJ`01KnE[0030000aj2`aj2`00800003cYZP00<0003HYJ;H
YJ800]RUXP030000i;6Qi;6Q00;T/J400`000?:oV_:oVP0200003Oooo`030000oooooooo037oool0
037oool00`000?ooooooo`1Poooo00<003a17Ge17Gd00`0000=dA8T00`0008aPVXaPVP04S62J00<0
002KLjBKLj@01I]cY0030000Yh:/Yh:/00FWPZ`200002KJ9Y`030000_iF/_iF/00JoUJ`00`000<NP
/<NP/002aj2`0`0000GHYJ800`000>BaXNBaX@02i;6Q00<0003b_i[b_iX00P0000koool00`000?oo
ooooo`0`oooo000`oooo00<0003oooooool0H?ooo`800003@Aem0Ve;U`8000000gA4R@0008aPVP05
S62J00<0002KLjBKLj@01I]cY0030000Yh:/Yh:/00FWPZ`010000;2>/@00000000NfRJL00`000;nE
[;nE[005_iF/00<00037X;37X;001LNP/0030000f:FRf:FR00?HYJ800`000>BaXNBaX@02i;6Q00<0
003b_i[b_iX00`0000koool00`000?ooooooo`0_oooo000_oooo00<0003oooooool0HOooo`800002
@Aem00<0001]BiM]BiL00Ve;U`800005S62J00<0002KLjBKLj@01I]cY0030000Yh:/Yh:/00JWPZ`0
1@000;2>/K2>/K2>/@000005]XVW00<0002oUJboUJ`01[nE[0030000aj2`aj2`00G7X;0200001=RU
XP030000i;6Qi;6Q00;T/J400`000?:oV_:oVP0300003oooo`030000oooooooo02koool002koool0
0`000?ooooooo`1Qoooo0P0000=17Gd00`0006e;Ufe;U`02KD^G00<00026IJD000000P0000:<H9X0
0`0009]cY9]cY005Vg>T00<0002WPZbWPZ`01JN2[0030000/8ja/8ja00>`S[401@000;J9YkJ9YkJ9
Y`000008_iF/00<00037X;37X;001LNP/0030000dJbcdJbc008000000mRUXP000>BaX@03i;6Q00@0
003b_i[b_i[b_iX300004?ooo`030000oooooooo02goool002koool00`000?ooooooo`1Qoooo0P00
00917Gd00`0006e;Ufe;U`02KD^G00<00026IJF6IJD00hIUY@800007Vg>T00<0002WPZbWPZ`01ZN2
[0030000/8ja/8ja00B`S[42000000>fRJL0002oUJ`01knE[0030000aj2`aj2`00G7X;000`000=6/
/m6//`02dJbc0P0000CT/J4010000?:oV_:oV_:oVP<0000@oooo00<0003oooooool0;Oooo`00;Ooo
o`030000oooooooo06;oool200000T4MO@030000KD^GKD^G009]BiL00`0008IUYHIUY@04QVFU0`00
00FKLj@00`000:N2[:N2[005Yh:/00<0002`S[6`S[401k2>/@030000_iF/_iF/00JoUJ`00`000<NP
/<NP/005aj2`00<0003A[;?A[;<01=6//`030000i;6Qi;6Q00;T/J4010000?:oV_:oV_:oVP<0000A
oooo00<0003oooooool0;?ooo`00;?ooo`030000oooooooo06;oool200000d4MO@050000KD^GKD^G
KD^G000000J6IJD01@0009Ig[YIg[YIg[P000003Vg>T00<0002WPZbWPZ`01ZN2[0030000/8ja/8ja
00J`S[4010000;VI]P00000000JoUJ`00`000<NP/<NP/005aj2`00<0003A[;?A[;<01=6//`<00002
i;6Q00D0003b_i[b_iX0003ocHD00P0001;oool00`000?ooooooo`0[oooo000[oooo00<0003ooooo
ool0Hoooo`800002@Aem00<0001]BiM]BiL00Ve;U`030000QVFUQVFU00B6IJD00`0009Ig[YIg[P02
UWN^0P000003Vg>T0000Yh:/00JWPZ`00`000;2>/K2>/@07/8ja00@0002iVKJiVKJiVKH200000knE
[0030000aj2`aj2`00K7X;000`000=6//m6//`03dJbc00@0003L^KKL^KKL^KH300000_:oVP040000
olf5000000004oooo`030000oooooooo02[oool002[oool00`000?ooooooo`1Soooo0P0000=17Gd0
0`0006e;Ufe;U`02KD^G00<00026IJF6IJD00hIUY@030000UWN^UWN^00FFMjh200001jN2[0030000
/8ja/8ja00J`S[400`000;VI][VI]P04^IVf0P000003_iF/0000aj2`00K7X;000`000=6//m6//`04
dJbc00<0003L^KKL^KH00mbi]P050000l[nJl[nJ0000olf50080000Doooo00<0003oooooool0:Ooo
o`00:Oooo`030000oooooooo06Coool3000000=17Gd0001]BiL00fe;U`030000QVFUQVFU00B6IJD0
0`0009Ig[YIg[P05UWN^00@0002RQK@000000004Yh:/00<0002`S[6`S[401k2>/@030000^IVf^IVf
00JiVKH00`000<NP/<NP/006aj2`00<0003A[;?A[;<01=6//`030000g;Vfg;Vf00?L^KH2000000?b
_iX0003ocHD00P0001Goool00`000?ooooooo`0Xoooo000Xoooo00<0003oooooool0IOooo`03001C
0000>RB;00<00003KD^G00<00026IJF6IJD00hIUY@030000UWN^UWN^00FFMjh00`000::5]::5]002
XXFd0P0000:WPZ`00`000;2>/K2>/@06/8ja00<0002iVKJiVKH01[VI]P040000`ZBk000000001LNP
/0030000dJbcdJbc00CA[;<00`000=bi]]bi]P03g;Vf00<0003Yb[KYb[H00P000003olf500000000
01Koool00`000?ooooooo`0Woooo000Xoooo00<0003oooooool0IOooo`06001C0000>RB;>RB;0000
J4nR0`0000J6IJD00`0009Ig[YIg[P05UWN^00<0002RQKBRQK@01::5]0800009/8ja00<0002iVKJi
VKH01[VI]P040000`ZBk`ZBk`ZBk0P0000?7X;000`000=6//m6//`04dJbc00<0003L^KKL^KH00mbi
]P060000jLZfjLZfjLZf0000olf50P0001Koool00`000?ooooooo`0Woooo000Woooo00<0003ooooo
ool0IOooo`030000001C0000008j98/01@0006Q?XVQ?XVQ?XP000005QVFU00<0002FMjjFMjh01IIg
[P030000XXFdXXFd00JRQK@300001[2>/@030000^IVf^IVf00JiVKH00`000<:T^l:T^`04`ZBk0`00
00OA[;<00`000=bi]]bi]P03g;Vf00@0003Yb[KYb[KYb[H400005oooo`030000oooooooo02Koool0
02Koool00`000?ooooooo`1Voooo00D0000005<0000j98/0000016Q?XP<00003QVFU00<0002FMjjF
Mjh01IIg[P030000XXFdXXFd00FRQK@01@000:b@^Zb@^Zb@^P000005/8ja00<0002iVKJiVKH01[VI
]P030000`ZBk`ZBk00K2Y;/00`000=6//m6//`04dJbc00<0003L^KKL^KH00mbi]P050000jLZfjLZf
jLZf000000;hgjh200006?ooo`030000oooooooo02Goool002Koool00`000?ooooooo`1Voooo00D0
000005<0000j98/0000016Q?XP030000PFR]PFR]00<00007UWN^00<0002RQKBRQK@01Z:5]0030000
[92j[92j00:/T;X01@000;2>/K2>/K2>/@000008^IVf00<00032Y;_2Y;/01/:T^`040000b[2o0000
00001=6//`030000g;Vfg;Vf00?L^KH01@000>W:]^W:]^W:]P000002n=n^0P0001Soool00`000?oo
ooooo`0Uoooo000Uoooo00<0003oooooool0Ioooo`800002>RB;00D0001XCj9XCj9XCj8000001H5X
[@800006UWN^00<0002RQKBRQK@01J:5]0030000[92j[92j00B/T;X2000000>`S[40002iVKH01kVI
]P030000`ZBk`ZBk00K2Y;/01@000<Z`_lZ`_lZ`_`000003dJbc00<0003L^KKL^KH00mbi]P050000
jLZfjLZfjLZf000000;hgjh200006Oooo`030000oooooooo02Coool002Goool00`000?ooooooo`1W
oooo0P00008j98/01@0006Q?XVQ?XVQ?XP000005PFR]00@0002BNKD000000003UWN^00<0002RQKBR
QK@01Z:5]0030000[92j[92j00J/T;X00`000;VI][VI]P06^IVf00<00032Y;_2Y;/01/:T^`030000
b[2ob[2o00?:/;l300001Mbi]P050000jLZfjLZfjLZf000000;hgjh00`000?;VP`00000Ioooo00<0
003oooooool09?ooo`009?ooo`030000oooooooo06Ooool00`000000D`000002>RB;00D0001XCj9X
Cj9XCj800000185X[@030000TWVeTWVe00:BNKD2000000>FMjh0002RQK@01Z:5]0030000[92j[92j
00J/T;X010000;BK_P00000000JiVKH00`000<:T^l:T^`06`ZBk00<0003:/;o:/;l01LZ`_`030000
g;Vfg;Vf00?L^KH01@000>W:]^W:]^W:]P000002n=n^0P0001_oool00`000?ooooooo`0Soooo000S
oooo00<0003oooooool0J?ooo`050000001C0000>RB;000000AXCj800`00085X[H5X[@02PFR]00<0
002BNKFBNKD0199i]@030000XXFdXXFd00JRQK@00`000:b@^Zb@^P06[92j00@0002dVkjdVkjdVkh2
00000kVI]P030000`ZBk`ZBk00K2Y;/00`000<Z`_lZ`_`05b[2o00@0003D_/@000000003g;Vf00D0
003Yb[KYb[KYb[H000000_SO[P80000Loooo00<0003oooooool08_ooo`008oooo`030000oooooooo
06Soool5000016Q?XP030000PFR]PFR]00:1J:d00`00099i]I9i]@04TWVe0`0000FRQK@00`000:b@
^Zb@^P06[92j00<0002dVkjdVkh01;BK_P8000000kVI]P000<:T^`07`ZBk00<0003:/;o:/;l01LZ`
_`040000e;k4e;k4e;k40`0000?Yb[H010000?SO[_SO[_SO[P80000Loooo00<0003oooooool08_oo
o`008_ooo`030000oooooooo06Woool010000000HP0003DXU0800002J4nR00<00021J:f1J:d00X5X
[@030000TWVeTWVe00BBNKD0100009j7^ij7^ij7^`800003XXFd00<0002/T;Z/T;X01Jb@^P030000
]9^n]9^n00NdVkh00`000<:T^l:T^`06`ZBk00<0003:/;o:/;l01LZ`_`030000e;k4e;k400CD_/@0
1@000>W:]^W:]^W:]P000002n=n^00<0003biX<000007Oooo`030000oooooooo027oool002;oool0
0`000?ooooooo`1Yoooo00H000000680000e:9@0001SDZP30000185X[@030000TWVeTWVe00BBNKD0
0`0009j7^ij7^`03WXNk0`0000R/T;X00`000;BK_[BK_P06]9^n00@0002lY/<000000006`ZBk00<0
003:/;o:/;l01LZ`_`030000e;k4e;k400?D_/@00`000>3@b0000002jLZf00<0003hgjkhgjh00P00
01koool00`000?ooooooo`0Qoooo000Qoooo00<0003oooooool0J_ooo`050000001R0000=BRD0000
00=SDZP200000h5X[@030000TWVeTWVe00BBNKD00`0009j7^ij7^`05WXNk0P0000J/T;X00`000;BK
_[BK_P07]9^n00@0002lY/>lY/>lY/<200000l:T^`030000b[2ob[2o00G:/;l00`000=Bna=Bna004
e;k400D0003Pd<SPd<P0003Yb[H00oSO[P80000Ooooo00<0003oooooool08?ooo`008Oooo`030000
oooooooo06[oool01@000000HP0003DXU0000003He:X00<0001mJ[<000000P0000JBNKD00`0009j7
^ij7^`05WXNk00<0002WT/2WT/000P0000>/T;X00`000;BK_[BK_P07]9^n00<0002lY/>lY/<01;bV
``8000000l:T^`000<Z`_`06b[2o00<0003D_/CD_/@00mBna0030000h=38h=3800;Pd<P010000?SO
[_SO[_SO[P80000Ooooo00<0003oooooool08?ooo`008?ooo`030000oooooooo06_oool200000SDX
U0040000He:XHe:X000017eZ/`800005TWVe00<0002NQk^NQk/01Ij7^`030000Yi;0Yi;000:WT/02
000000>/T;X0002dVkh01kBK_P030000_:K3_:K300NlY/<00`000<Z`_lZ`_`05b[2o00<0003D_/CD
_/@01=Bna0060000h=38h=38h=380000kNO80P000003n=n^l^J30000023oool00`000?ooooooo`0O
oooo000Poooo00<0003oooooool0Joooo`8000000cDXU00006=BZ002He:X00<0001mJ[=mJ[<00WeZ
/`040000SW^j000000000i9i]@030000WXNkWXNk00BNQk/00`000:NB`:NB`005Yi;000<0002dVkjd
Vkh01kBK_P030000_:K3_:K300JlY/<010000<Bbb000000000G:/;l00`000=Bna=Bna003e;k400<0
003Pd<SPd<P00^3@b0060000kNO8kNO8kNO80000l^J38Oooo`030000oooooooo01ooool001ooool0
0`000?ooooooo`1/oooo0P000003=BRD0000He:X009SDZP00`0007eZ/geZ/`02OFZc00@0002>NkZ>
NkZ>NkX300001ij7^`030000Yi;0Yi;000FWT/0300001[BK_P030000_:K3_:K300JlY/<00`000<Bb
b<Bbb002a;;800D0003:/;o:/;o:/;l000001]Bna0050000h=38h=38h=38000000?]ilP00`000>Si
[`00000Roooo00<0003oooooool07_ooo`007oooo`030000oooooooo06coool400000f=BZ0050000
OFZcOFZcOFZc000000J>NkX00`0009j7^ij7^`04WXNk00<0002WT/2WT/001JNB`0040000/9g4/9g4
/9g40P0000>dVkh00`000;bV`kbV``07_:K300<00034//S4//P00lBbb08000000lZ`_`000=Bna004
e;k400<0003Pd<SPd<P00^3@b0040000kNO8kNO8kNO80P0002?oool00`000?ooooooo`0Noooo000N
oooo00<0003oooooool0KOooo`8000001C8[VP00000006=BZ0000004OFZc00<0002>NkZ>NkX018ik
^P<00003WXNk00<0002WT/2WT/001ZNB`0030000/9g4/9g400>`WL@2000000>dVkh0002lY/<01kbV
``030000a;;8a;;800K4//P00`000=Bna=Bna004e;k400D0003Pd<SPd<SPd<P000000ngWb0030000
j?V_000002Coool00`000?ooooooo`0Moooo000Noooo00<0003oooooool0KOooo`8000000c8[VP00
061C[@02000017eZ/`030000SW^jSW^j00>>NkX0100009Z8_iZ8_iZ8_`8000000ij7^`000:NB`006
Yi;000<0002`WLB`WL@01[2Ma0030000_:K3_:K300JlY/<00`000<Bbb<Bbb006a;;800@0003=`<h0
00000003e;k400<0003Pd<SPd<P00^3@b0040000kNO8kNO8kNO80P0002Goool00`000?ooooooo`0M
oooo000Moooo00<0003oooooool0K_ooo`800000138[VP00061C[F1C[@<00002OFZc00<0002>NkZ>
NkX00hik^P030000VXRoVXRo00>JR;l00`000:NB`:NB`006Yi;000<0002`WLB`WL@01K2Ma0040000
]jS9000000001KbV``030000a;;8a;;800K4//P00`000<g0c/g0cP02cL3>0P000003e;k40000h=38
00;Pd<P01`000>gWb>gWb>gWb0000>Si[`00000Voooo00<0003oooooool07?ooo`007Oooo`030000
oooooooo06koool2000000Db:iX0001PDjePDjd000000WY[]`800005SW^j00<0002JR;nJR;l019Z8
_`<00005Yi;000<0002`WLB`WL@01[2Ma0050000]jS9]jS9]jS9000000BlY/<00`000<Bbb<Bbb006
a;;800<0003=`<k=`<h01<g0cP030000h=38h=3800;Pd<P010000>gWb>gWb>gWb080000Woooo00<0
003oooooool07?ooo`007?ooo`030000oooooooo06ooool2000000Db:iX0001PDjePDjd000000gY[
]`800004SW^j00<0002JR;nJR;l00iZ8_`040000Y9?4Y9?4Y9?40P0000>WT/000`000;2Ma;2Ma005
/9g400<0002gZ<VgZ<T00kNXb@8000000kbV``000<Bbb007a;;800<0003=`<k=`<h01<g0cP030000
em;D000000;Pd<P01`000>gWb>gWb>gWb0000>Si[`00000Xoooo00<0003oooooool06oooo`007?oo
o`030000oooooooo06ooool2000000@b:iX0001PDjd00004NV^g00H0002;O;d00000002>NkX00006
VXRo00<0002TTlBTTl@00jBCa0<00008/9g400<0002gZ<VgZ<T01KNXb@030000a;;8a;;800K4//P0
0`000<g0c/g0cP04cL3>00L0003Gd]CGd]CGd]@0003Pd<P000000ngWb080000Yoooo00<0003ooooo
ool06oooo`006oooo`030000oooooooo073oool4000000=PDjd0001jJkL00gY[]`040000RgbmRgbm
Rgbm0P0000FJR;l00`000:BCa:BCa006Y9?40P0000J`WL@00`000;NXbKNXb@05]jS900@0002o]<l0
00000005a;;800<0003=`<k=`<h01Lg0cP030000em;Dem;D00;Gd]@01`000>gWb>gWb>gWb0000>Si
[`00000Zoooo00<0003oooooool06_ooo`006oooo`030000oooooooo073oool2000000@`;9`00000
00000004NV^g00<0002;O;f;O;d00X]l_@<00003VXRo00<0002TTlBTTl@01JBCa0030000[9k9[9k9
00800003/9g400<0002gZ<VgZ<T01[NXb@050000_kC?_kC?_kC?000000C4//P00`000<g0c/g0cP04
cL3>00<0003Gd]CGd]@00]OBe0050000h>[I00000000kNO80080000[oooo00<0003oooooool06_oo
o`006oooo`030000oooooooo073oool2000000<`;9`0001NE:h00P00009jJkL00`0008]l_H]l_@02
Rgbm00@0002HRL:HRL:HRL8300002:BCa0030000[9k9[9k900:/W/T2000000>`WL@0002gZ<T01[NX
b@030000_kC?_kC?00>o]<l2000000?4//P0003=`<h01Lg0cP030000em;Dem;D00;Gd]@00`000>3Z
fN3Zf@02h>[I00<0003XnJl00000:oooo`030000oooooooo01[oool001[oool00`000?ooooooo`1a
oooo0P000005<2bL0000GUB^0000NFbh00<00004Rgbm00<0002HRL:HRL800iR9`P800006Y9?400<0
002/W/V/W/T01JbNb@030000]jS9]jS900FgZ<T00`000;ndckndc`06_kC?00<0003=`<k=`<h01<g0
cP030000em;Dem;D00;Gd]@00`000>3ZfN3Zf@02h>[I00<0003Iol/00000;Oooo`030000oooooooo
01Woool001[oool00`000?ooooooo`1aoooo0`00009NE:h0100007U/^7U/^7U/^0800003Rgbm00<0
002HRL:HRL800iR9`P040000XYC7000000000jBCa0030000[9k9[9k900F/W/T00`000;>YcP000005
]jS900<0002o]<no]<l01[ndc`040000al;F000000001<g0cP030000em;Dem;D00;Gd]@01`000>3Z
fN3ZfN3Zf@000=Wob`00000^oooo00<0003oooooool06Oooo`006_ooo`030000oooooooo077oool3
00000UiD[P060000NFbhNFbhNFbh0000RWbn0`0000FHRL800`000::Daj:Da`02XYC70P000003Y9?4
0000[9k900F/W/T010000;>Yc[>Yc[>YcP800003]jS900<0002o]<no]<l01Kndc`030000al;Fal;F
00;7`]H2000000?=`<h0003Gd]@00mOBe0070000h>[Ih>[Ih>[I0000fOo;000002ooool00`000?oo
ooooo`0Ioooo000Ioooo00<0003oooooool0L_ooo`@000000eiD[P0007U/^002NFbh00D0002:O;j:
O;j:O;h000001IR9`P030000XYC7XYC700BRU<L00`000:bNbJbNb@05[9k900<0002cZLjcZLh00k>Y
cP030000]jS9000000No]<l00`000<O2e/O2eP05al;F00<0003Gd]CGd]@00]OBe0070000h>[Ih>[I
h>[I0000fOo;0000037oool00`000?ooooooo`0Hoooo000Ioooo00<0003oooooool0L_ooo`<00000
0eiD[P0000000002NFbh00<0002:O;j:O;h00XYl_P<00003V8W200<0002RU<NRU<L01::Da`<00004
[9k900<0002cZLjcZLh01K>YcP800007_kC?00<00037`]K7`]H01<O2eP060000cmCM00000000em;D
00000n3Zf@030000fOo;000003;oool00`000?ooooooo`0Hoooo000Ioooo00<0003oooooool0L_oo
o`<00002GUB^100000B:O;h00`0009N9`iN9``0300001Z:Da`040000ZYo<ZYo<ZYo<0P000003[9k9
0000/jW>00JcZLh00`000;^ee;^ee00200001;ndc`030000al;Fal;F00C7`]H00`000<oDgLoDg@02
cmCM00L0003Pj]WPj]WPj]T0003Iol/00000<oooo`030000oooooooo01Soool001Soool00`000?oo
ooooo`1coooo0`00009NE:h00`0007U/^7U/^00200000XYl_P030000UhW3UhW300>GRL<00`000::D
aj:Da`04XYC700<0002ZWlbZWl`00jZOc0030000/jW>/jW>00FcZLh00`000;^ee;^ee003^kGD0P00
0003_kC?0000al;F00G7`]H00`000<oDgLoDg@02cmCM00L0003Ejn@0003Pj]T0003Iol/00000=Ooo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`1coooo0`000003GUB^0000NFbh009iK;P0
0`0008Yl_P00000200001IN9``<00003XYC700<0002ZWlbZWl`00jZOc0040000/JWA000000001;>Y
cP030000^kGD^kGD00Jk]M@00`000<O2e/O2eP04al;F00<0003?e=g?e=d00/oDg@070000eN_TeN_T
eN_T0000fOo;000003Koool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool06_oooa800017
oooo1@0000=iK;P0100008Yl_XYl_XYl_P800003UhW300@0002PU<RPU<RPU<P2000000>RU<L0002Z
Wl`00jZOc0030000/JWA/JWA00:aZM42000000>cZLh0002k]M@01k^ee0040000`/?K000000000lO2
eP030000cmCMcmCM00;?e=d01`000=G[i=G[i=G[i0000<Wof`00000goooo00<0003oooooool05ooo
o`005oooo`030000oooooooo01Ooool400000S8000030000I000I00000=T0009000000>700000000
00001000047oool3000000EPDjd00000001iK;P0000018Yl_P060000UhW300000000UhW300001J2D
b0800004ZYo<00<0002aZM6aZM401;6Yd@030000^kGD^kGD00Fk]M@200001<;3f`030000al;F0000
00C?e=d01`000=G[i=G[i=G[i0000<Wof`00000ioooo00<0003oooooool05_ooo`005oooo`030000
oooooooo01?oool40000138000P00006V2hj00<0002]@Sj]@Sh01P0000>700020000?Oooo`<00000
0f1C[@0007Y/]`0300000hYl_P050000UhW3UhW3UhW3000000FPU<P00`000:ROcJROc@02000000>Z
Wl`0002aZM401K6Yd@040000^;GG000000001;^ee0030000`/?K`/?K00G2`m/00`000<oDgLoDg@02
cmCM00<0003EjnCEjn@00P000003bOoK0000oooo03Woool00`000?ooooooo`0Foooo000Goooo00<0
003oooooool04Oooo`800004<P001000009i4S800`0009P^>YP^>P09V2hj00<0002]@Sj]@Sh01Ze2
?P@0000019hA00000000000003[oool01@00H`000000061C[@000002NVbg00<0002;O;d000000P00
00BGRL<300000j2Db0030000Z9o=Z9o=00:XWld00`000;6YdK6Yd@04/JWA00<0002h]MNh]ML00[Re
e`8000000k^ee0000<;3f`06`/?K00H00038e><00000003?e=d00002eN_T00@00039om/00000000k
oooo00<0003oooooool05_ooo`005_ooo`030000oooooooo013oool3000000<b0000000000000P00
00Ei4S800`0009P^>YP^>P04V2hj2@0000R]@Sh00`000;aA@0000002000000BN4@0000000000000g
oooo00<006<0000000000P00009jK;L01@0008]l_H]l_H]l_@000003UhW300L0002PU<RPU<RPU<P0
002PU<P000001:ROc@040000/:[B000000001;6Yd@030000^;GG^;GG00Bh]ML00`000<;3fl;3f`04
`/?K0P0000C8e><2000000?Ejn@00039om/00P0003goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool03_ooo`H00006NA8b2P0000JXEV/00`000;QTK;QTK00600000Ze2?P030000_550_550
00:lDD03000000>N4@0000000000=Oooo`040000=RZE0000He:Y0`0000B;O;d3000000>GRL<0002P
U<P00j2Db0800004Z9o=00@0002`Z]:`Z]:`Z]82000000>aZM40002h]ML01KRee`040000_/?N0000
00000l;3f`030000b=CSb=CS00?8e><01@000<cZjlcZj`000<Wof`020000?_ooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0=oooo0`000004B`0V0000NA8bNA8b1P0000>B@fL00`000:QF
JjQFJ`0:Z5I[00<0002hI6bhI6`01[QTK0@00006_5500P000003[2800000000003?oool3000000AS
DZT0001lJk@00003Rgbm00D0002HRL:HRL:HRL8000001J2Db0060000Z9o=00000000Z9o=00001[2Z
dP800004^;GG0P0000Bn`mh00`000<;3f`000004b=CS0P0000;<j^/010000;cli000000003ooool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool02oooo`<00003B`0V0`0000VB@fL00`000:QF
JjQFJ`09Z5I[00<0002hI6bhI6`02KQTK0030000`fi]000000800004_5500`000003[28000000000
037oool0100003XXT0000000009lJk@3000000>;O;d0002HRL800YR9`P<00002X9C800<0002XWlfX
Wld00ZROc@030000/:[B/:[B00B`Z]800`000;Jff;Jff002000000>h]ML0002n`mh01[k3gP030000
b=CSb=CS00;8e><00`000<cZjlcZj`050000@?ooo`030000oooooooo01Goool001Goool00`000?oo
ooooo`0:oooo0`0000=;02H00`0007<XH000000;TT=W00<0002XEV^XEV/02JQFJ`030000^6A/^6A/
00VhI6`00`000<=^KL=^K@02`fi]0`000004_5500000aUY1aUY10P000003[2800000000002koool2
000000Hj:90000000000001lJk@00002SG^k0P0000>HRL801P000:6Daj6Da`000:2Db00000BXWld3
00000k2ZdP030000][KH][KH00>f]]P00`000;k3g[k3gP05_/?N00H00034e>H000000038e><00002
c>[[00<0002lo>@000000P0004;oool00`000?ooooooo`0Doooo000Eoooo00<0003oooooool02Ooo
o`800003B`0V0P00009c:6000`000993Ii93I`07TT=W4@0000RhI6`00`000<=^KL=^K@06`fi]0`00
00?6FT42000000>/8P0000000000;?ooo`<000000fIAY@0007mZ/@0200000Xek^`030000VHS00000
00800004XIC70P0000>XWld01`000;2Zd[2Zd[2ZdP000;2ZdP000005][KH00@0002m`ml000000003
_/?N0P0000?4e>H3000000?<j^/0002lo>@00P0004Coool00`000?ooooooo`0Doooo000Eoooo00<0
003oooooool02?ooo`040000B`0VB`0VB`0V0P0000=c:6000`000993Ii93I`04TT=W100000:NGX@0
0`000:m/QZm/QP09[fb600<0002kMhJkMhH01P0000:hI6`00`000<=^KL=^K@07`fi]00@0003:MVd0
00000003aUY11@0002[oool00`00DClVRP00000200000WmZ/@<00004VHS000D0002QU<NQU<NQU<L0
00000ZVOc08000000jROc@000;2ZdP03/:[B0P0000Bf]]P00`000;g3gkg3g`02_L?O00<0002n`mh0
00000lCDiP800002aNW_100004Koool00`000?ooooooo`0Doooo000Doooo00<0003oooooool02?oo
o`8000000d/09P0000000005LbQP00<0002B@fNB@fL0100000JNGX@00`000:m/QZm/QP09[fb600<0
002kMhJkMhH01[]gQPD00007`fi]00@0003:MVg:MVg:MVd2000000?6FT40003;H4401@0002Soool0
100003lVRP0006]@X@<00002T7^h00H0002IR<2IR<2IR<00002SU<D2000000>QU<L0002YWl`00jVO
c0800003/:[B00<0002g]]Rg]]P00P000003][KH0000_L?O00Fm`ml2000000?4e>H0000000000/GY
k`8000000k?jj@000?ooo`18oooo00<0003oooooool04oooo`005?ooo`030000oooooooo00Ooool4
00001W<XH0@0000:WUj400<0002_K8J_K8H02Jm/QP030000^gN6^gN600RkMhH00`000<AoQ/AoQP05
00000/=^K@030000bWI]bWI]00?:MVd300000/]P@@@0000Woooo00M698<00000001[D:400023JJd0
00000Y1k^0<000000iV8`0000:>Da@02XiC50P0000>YWl`00`000;6YdK6Yd@02000000>`Z]80002g
]]P00kNff0030000_L?O_L?O00>m`ml200000/;Dj08000001<GYk`0000000;?jj@80001:oooo00<0
003oooooool04oooo`005?ooo`030000oooooooo00Koool00`0000/04P000006LbQP0P000003QTUo
0000WUj400ZNGX@00`000:m/QZm/QP0:[fb600<0002kMhJkMhH02;]gQP030000a7n6a7n600G4OhH4
00001LYfK@040000cgY/000000000/]P@@@0000Toooo00@0001698<0001_Ci`2000000B3JJd00000
00000003VhRn0P0000>SU<D01P000:^NbP0000000:VOc00000BaZM400`000;Nff;Nff002]kKH00D0
002m`ml00000002m`ml00P0000;2e>P200000/?Yl0040000/o[Y/o[Y0000C?ooo`030000oooooooo
01?oool001Coool00`000?ooooooo`05oooo00@0000;018000000003LbQP0`0000>6BGl00`0009iN
Q9iNQ009WUj400<0002_K8J_K8H02Zm/QP030000^gN6^gN600RkMhH00`000<AoQ/AoQP07a7n600@0
003;QHH000000003bWI]00@0003?NVc?NVc?NV`700008oooo`<0000016m?W00008IXZ@0000:BN[D2
00000Y^8_P030000YI?3000000800004Zik:00<0002aZM6aZM400[6Yd@060000^;GG00000000]kKH
00001;g3g`800002`]CX00<00033jO33jO000P000003[oS[0000oooo04goool00`000?ooooooo`0C
oooo000Doooo00<0003oooooool01?ooo`0600002`0B0000A05A0000LbQP0P0000J6BGl00`0009iN
Q9iNQ006WUj45P0000FkMhH00`000<AoQ/AoQP07a7n600@0003;QHK;QHK;QHH2000000?:MVd0003?
NV`01<mjK0030000cV=1cV=100@0000Poooo00D0001=8g`0001dCYL000000XIXZ@8000000i9j]@00
09j7^`0200001:FC``800002Zik:00H0002bZLl00000002aZM400004^;GG0P0000:m`ml200000/;D
j08000001<?Yl00000000:ohj`80001?oooo00<0003oooooool04oooo`004oooo`030000oooooooo
00Coool300000T@1D@800008QTUo00<0002NGXBNGX@01P0000>SKiH00`000;9kUk9kU`0:/W^G00<0
002lQ9RlQ9P00kb4V0P00006a7n600<0003;QHK;QHH01<^5QP<00004cgY/0`0000;>Hd4400007_oo
o`04000_00000000M4jG0`0000:ENK80100009j7^ij7^ij7^`<000001:FC``000:fNajfNa`800004
/ZW?0P0000:h]ML200000[k3gP800003`]CX0P000003`nW`0000[oS[0080001Boooo00<0003ooooo
ool04_ooo`004oooo`030000oooooooo00?oool200000d@1D@800008QTUo100000VSKiH00`000;9k
Uk9kU`0:/W^G00<0002lQ9RlQ9P02;b4V0030000a8^Ha8^H00@00002a7n600<0003;QHK;QHH01L^5
QP030000chR60000008000001<mjK0000=5lK=5lK0<000000leR@@000000000200006oooo`<00000
17U>TP0008YWYHYWY@8000000iEi/P000000000200000jNB`0060000[Ik7[Ik7[Ik70000]:S<0P00
0004/ZW?0000^[GD^[GD0P0000Bn`mh01P000<CDiP000<;Dj0000<?Yl0@0001Doooo00<0003ooooo
ool04_ooo`004oooo`030000oooooooo00;oool200000d@1D@030000HB]f000000F6BGl3000000>?
GY<0002SKiH02Z=_UP030000/W^G/W^G00ZbNiL00`000;b4V;b4V008_8BH00<00034RiS4RiP01<B;
V0D00005bhF600<0003?R8K?R8H00/n8QP<00003dGa/0P0000;=HT4400006?ooo`@000001gU>TXiW
X@0008YWY@0009Qi[P000003X8Jh0P0000:WT/03000000>]W/L0002dZ<`00[BXc0060000^[GD^[GD
^[GD0000`L?K0P000003_/?N0000a=CV00;4e>H00`000<?Yl00000020000E_ooo`030000oooooooo
01;oool001?oool00`000?ooooooo`02oooo00<000140E540E400P000003HB]f0000QTUo00>6BGl2
000018mNT`030000XfnFXfnF00VSKiH00`000;9kUk9kU`09/W^G00<0002lQ9RlQ9P02Kb4V0030000
a8^Ha8^H00K4RiP00`000<Z@UlZ@U`04000000?;QHH0003?R8H01<n8QP070000d8Z500000000dGa/
0000dG]/00<000001<]P@@000000000001Koool300000Wm>S@030000SVNQSVNQ008000001iQi[P00
000000000:26^0000:VB_@0200000jnMa@800002]:S<00H0002l]=800000002j]M@00003`L?K0P00
0004a=CV00000000a^W^0P0005Soool00`000?ooooooo`0Boooo000Coooo00@0003oooooooooool2
000000=40E40001Q:gH00V4[MP030000QTUo000000800006SejC00<0002SKiJSKiH02J=_UP030000
/W^G/W^G00VbNiL00`000;b4V;b4V009_8BH00<00034RiS4RiP01/B;V0030000bY2GbY2G00C:T9L3
00001<n8QP040000d8Z5d8Z5d8Z50`0000;ANf`200000/]P@@<0000Doooo00@0001S8VL0001oCXd2
000000F>Ij40002KN:^KN:/000000j>6]@050000ZI:mZI:m0000/Ic2008000000jnMa@000;NWb@02
00001;bddP8000000l73f`0000000002amCS00@00036jNh00000001Joooo00<0003oooooool04_oo
o`004oooo`050000oooooooooooo000h00800004HB]f0P0000R?GY<00`000:=_UZ=_UP0:XfnF00<0
002bNiNbNiL02K9kU`030000_8BH_8BH00VlQ9P00`000<B;V<B;V006a8^H00<0003:T9O:T9L01LZ@
U`030000cY>G0000008000000ln8QP000=2:Q@03d8Z500<0003@RXD000000P000005cgY]00000000
0000aUa200<0000?oooo0`000003JbAQ0000Q4j8008000003I9WW@00000009]hZ`000:F5/P000:>6
]@000:^A^P000:VB_@000003/Ic200D0002gYlVgYlT0002o/ll00P000004_;CB0000a<;Ha<;H0P00
0005amCS00000000bn[[000005coool00`000?ooooooo`0Boooo000Boooo00L0003oooooooooool0
000003P000000f4[MP<00009SejC00<0002SKiJSKiH01:=_UQT00005_8BH00<00034RiS4RiP01/B;
V0030000bY2GbY2G00G:T9L00`000<jCUljCU`02cY>G0`0000?@RXD010000=2:QM2:QM2:Q@800002
cgY]0P000003aUa20000`EI2008000000oooo`000?ooo`09oooo1@000005RDn40000UVNJUVNJ0000
00:NN:P01@000:F5/ZF5/ZF5/P000003Zi6j0P0000:aW<801@000;VVaP000;NWb@000003_k??0P00
0006a<;H0000bm?Pbm?P0000bn[[0`0005goool00`000?ooooooo`0Aoooo000Boooo00D0003ooooo
ooooool003P00P000003HB]f00000000009`A8`00`0008mNThmNT`06SejC200000JVNj@00`000;>6
YK>6Y@09/hJU00<0002mSZFmSZD01;f>Y@X00004a8^H00<0003:T9O:T9L01LZ@U`030000cY>GcY>G
00?>TiL01P000<nDUP0000000=2:Q@0000?@RXD00`000<n8QP000002000000?;Mfd0000000000P00
0003^U130000000000d000002Hm@P0000000000009IWVP000:5hY@0009ihZ003000000NUQK800000
0000002[TKX0002cVkl00P0000>iY/H200000[ncc`030000al7Dal7D008000000l_Ch00000000002
0000Goooo`030000oooooooo017oool001;oool00`000?ooooooo`0500001714S0030000SejCSejC
00:?GY<4000000>DK:80002VNj@02jIkY0030000/hJU/hJU00VcQZD00`000;f>YKf>Y@09_HjU00<0
0034U:C4U:@00/BDY0L00005bY2G00<0003>TiO>TiL00ljCU`040000ciBFciBFciBF0`0000;@RXD0
10000<n8Q/n8Q/n8QP8000000l]gK@000<MbKP0>000000RKEGX000000000002MJI@0002JJ9L00003
XGRU00D0002WQJnWQJnWQJl000000jf@^0040000/i^o/i^o/i^o0`000003^JK60000`K;;00<00000
1<O1e0000=3Bfm3Bf`@0001Poooo00<0003oooooool04Oooo`004_ooo`040000oooooooo000h0P00
00I`A8`00`0008mNT`00000200001IA/XP030000YW^TYW^T00ZVNj@00`000;>6YK>6Y@09/hJU00<0
002mSZFmSZD02Kf>Y@030000a9BTa9BT00K4U:@00`000<ZIY<ZIY004000000?:T9L0003>TiL01<jC
U`030000ciBFciBF00;?U9H00`000<nDUP00000200000ln8QP030000c8J6000000<00002`Fi_00<0
002kJG0000001P000007XEQg0000VeEj0000XVZA0000WFVD008000002JAhX`000:5hY@000:V4[@00
0:N5[`000:n?]@02000000>]T;P0000000000P0000>kYL<200000/6bb`050000b[o@00000000d=;K
00<0001Roooo00<0003oooooool04Oooo`004_ooo`030000oooo000000<00005L4B<0`0000RDK:80
0`000:IkY:IkY00:YW^T00<0002cQZFcQZD02K>6Y@030000_HjU_HjU00VmSZD00`000<BDY<BDY006
a9BT00<0003:VJC:VJ@01<ZIY0D00002cY>G00<0003?U9K?U9H00/nDUP040000ciBFciBFciBF0`00
0006chR60000c8J6c8J60000b8>71P000003]FEa0000[V1c00L000000j9ZT@0000000002YWVQ00<0
002TN:<000000jV4[@800003[hne00@0002eV[beV[beV[`200000[^U``030000`k37000000800000
0lZod0000=CAeP030000Hoooo`030000oooooooo017oool001;oool01P000?ooo`0002L0HShKO000
00=`A8`2000000=iEI`0002DK:8029A/XP030000YW^TYW^T00VVNj@00`000;>6YK>6Y@0:/hJU00<0
002mSZFmSZD02Kf>Y@030000a9BTa9BT00K4U:@00`000<ZIY<ZIY005bYVT00@0003=Vj?=Vj?=Vj<5
00000/nDUP050000ciBFciBFciBF000000;>TiL3000000S<QXH00038PhO8PhL00033OhP0002oO8T4
000000FdM8/0002_LH`0002[KXh00`0000:YNYl01@000:IiXJIiX@000:^4Z`02000000>YQ:d0002`
Sk<00P000007[hne000000000000]IZl0000_JC000<000001/>`a`000<fmc<fmc0000=CAeP<0001T
oooo00<0003oooooool04Oooo`004_ooo`@000000chKO0000714S00200000gUEW0030000U6bRU6bR
00NDK:800`000:IkY:IkY009YW^T00<0002cQZFcQZD02[>6Y@030000_HjU_HjU00VmSZD00`000<BD
Y<BDY006a9BT00<0003:VJC:VJ@01LZIY0030000cI^ScI^S00?=Vj<00`000<nMXlnMX`05000000??
U9H0003>TiL00/jCU`030000bi6G000000H000001[mlR@000;YhRKYhR@000;AdR`D00002[G^M00L0
002YNYl0002VNJ40002]QJX000000Z^4Z`030000/8nc/8nc00:`Sk<010000;NI^[NI^[NI^P800002
_JC000L00035[l<00000003=_L`0003Hc]000`0006Goool00`000?ooooooo`0Aoooo000Boooo0`00
008n6g`200001GUEW0030000U6bRU6bR00NDK:800`000:IkY:IkY009YW^T00<0002cQZFcQZD02[>6
Y@030000_HjU_HjU00VmSZD00`000<BDY<BDY006a9BT00<0003:VJC:VJ@01LZIY0030000cI^ScI^S
00?=Vj<00`000<nMXlnMX`02cifS00<0003?WJ??WJ<010000005cY>G0000bi6Gbi6G000000;8SYP0
0`000<B;V0000007000000BdOi/0002`OI`00002[G^M00@0002YNYl000000002[HFZ00D0002[Q:/0
002bSk8000000[2?/`070000^9Rg00000000]iVj0000_Z>m00<000000lF_``000<nka`03000000?T
iM<000000000IOooo`030000oooooooo017oool001;oool00`000000?000000300001WUEW0030000
U6bRU6bR00NDK:800`000:IkY:IkY003YW^T900000C4U:@00`000<ZIY<ZIY005bYVT00<0003=Vj?=
Vj<00lfKX`030000cifScifS00;?WJ<01@000<nMXlnMXlnMX`000002cIbS0`000007bi6G0000b8jH
b8jH0000a8^H000000;0R9T01@000;b5VP000;R2VP000002]7nK00@0002`OI`0002]Nid200000Zn5
Z@040000[HFZ[HFZ00000k:?/P030000/8nc000000>hV;L200000[jS_@070000ajfo00000000ck_7
0000flc:00<0001Voooo00<0003oooooool04Oooo`004_ooo`<00002C32?00<0001iEIaiEI`017UE
W0030000U6bRU6bR00:DK:8;00001ZN4[`030000]8n_]8n_00ZdSjl00`000;fF[kfF[`09_IJ_00<0
0034W:o4W:l00/BL[`T00003bYVT00<0003=Vj?=Vj<00lfKX`030000cifScifS00;?WJ<01@000<nM
XlnMXlnMX`000003cIbS00<0003;VZ@000001`000005`8RI0000_8FJ0000^8:J00L000002K66Z000
0:n5ZJn5Z@000:f5ZP000;>?/@000003/Xnb0`0000:hV;L00`000;nQ^P000002000000?7[Kl0003A
^L8010000003kOVi0000oooo06Goool00`000?ooooooo`0Aoooo000Boooo0P0000=<<8l0100007UE
W7UEW7UEW0P00005UWJ]00<0002WQ:nWQ:l02JN4[`030000]8n_]8n_00ZdSjl00`000;fF[kfF[`09
_IJ_00<00034W:o4W:l01/BL[`030000bJ6^bJ6^00;9XJh<00000/nMX`050000cifScifScifS0000
00?=W:<010000<^JY<^JY00000;8Uj@010000<FDY@000<6BY@D000001[Z<YP000;N:Y`000;>8Y`00
00>aQZP010000:n5Z@00000000>cSk4010000;:?/[:?/P0000:hUkH300000[nQ^P030000b:^l0000
008000000m6i`P00000000020000J?ooo`030000oooooooo013oool001;oool200000T``S`D00003
O66X00<0002FMZfFMZd01iIf[@030000YhB_YhB_00VWQ:l00`000;B?[kB?[`0:]8n_00<0002mUZnm
UZl02KfF[`030000a9b_a9b_00K4W:l00`000<VQ[/VQ[P05bJ6^00<0003=Xjk=Xjh00lfS[P030000
cZB^cZB^00D000000lnMX`000<fLX`02cIbS00@0003;VZC;VZ@00002b9NT00<00035U:D000000/6B
Y@030000_HnV000000:jS:H01`000;N:YkN:Y`000;>8Y`000;66Z003000000>cT;40002cSk400k>?
/@800004^9Nf00<00030WkP000000P0000;8Zk`00`000=>f_@0000030000JOooo`030000oooooooo
013oool001;oool4000000=A?Y`0001lHJP01GaQZ0030000UWJ]UWJ]00NFMZd00`000:N4[jN4[`09
YhB_00<0002dSjndSjl02[B?[`030000_IJ__IJ_00VmUZl00`000<BL[lBL[`06a9b_00<00039XJk9
XJh01LVQ[P030000cJ>^cJ>^00?=Xjh00`000<jT[/jT[P02cZB^00<0003>Y:k>Y:h02P000007b9NT
0000aIBUaIBU0000`I:U000000:mSjH010000;Z<YP000;N:Y`D000000kB?/@000;>@/@02/i2a00<0
002cSk6cSk400[>?/@<000000kRG]P000<2O^002`9nh00<00039Z;P000001@000003l=Rh0000oooo
06Soool00`000?ooooooo`0@oooo000Aoooo0`0000=A?Y`00`0007aQZ7aQZ004O66X00<0002FMZfF
MZd01iIf[@030000YhB_YhB_00VWQ:l00`000;B?[kB?[`0:]8n_00<0002mUZnmUZl02;fF[`030000
a9b_a9b_00O4W:l00`000<VQ[/VQ[P05bJ6^00<0003=Xjk=Xjh00lfS[P030000cZB^cZB^00;>Y:h0
1@000<jT[/jT[/jT[P000003cJ>^00D0003;XZk;XZh00038Wjl03@000004^9:`0000]I6`00000[B?
/@050000/i2a/i2a/i2a000000>cSk4010000;RG]KRG]KRG]@@000002<2O^0000<VX^<VX^0000=Bc
^0000>70]P<0001Yoooo00<0003oooooool04?ooo`004Oooo`<00003DCjL00<0001lHJQlHJP017aQ
Z0030000UWJ]UWJ]00NFMZd00`000:N4[jN4[`09YhB_00<0002dSjndSjl02[B?[`030000_IJ__IJ_
00RmUZl00`000<BL[lBL[`07a9b_00<00039XJk9XJh01LVQ[P030000cJ>^cJ>^00?=Xjh00`000<jT
[/jT[P02cZB^00D0003>Y:k>Y:k>Y:h000000lfS[P040000bj:^bj:^00000/RO[`060000aIf_aIf_
0000`IZ_00000[jG/0030000^iF`000000:hT[000`000;FA/0000003]8na00D0002cT;6cT;6cT;40
00000[>?/@030000^9Ne^9Ne00:hUkD00`000<6N]L6N]@0:0000J_ooo`030000oooooooo013oool0
017oool300000e4nW0030000O66XO66X00AlHJP00`0009If[IIf[@07UWJ]00<0002WQ:nWQ:l02JN4
[`030000]8n_]8n_00ZdSjl00`000;fF[kfF[`08_IJ_00<00034W:o4W:l01lBL[`030000bJ6^bJ6^
00G9XJh00`000<fS[/fS[P03cJ>^00<0003>Y:k>Y:h00/jT[P050000cZB^cZB^cZB^000000?=Xjh0
10000<^R[/^R[P0000;8Wjl01P000<FM[lFM[`000<6J[`0000:nUk000`000;^E/0000002^9:`00@0
002eTK2eTK000002]8na00L0002cT;6cT;6cT;40002cSk4000001KRG]@050000`Ije`Ije`Ije0000
00;9Y[D010000=B_/`000>:k/080001Zoooo00<0003oooooool04?ooo`004Ooooi80001Zoooo00<0
003oooooool04?ooo`004Oooo`<00003DDNW00<0001lJK=lJK<017aY/`030000UWngUWng00NFOkL0
0`000:N=^JN=^@09Yhfi00<0002dUkVdUkT02[BG^@030000_Iji_Iji00RmW[T00`000<BT^LBT^@07
a:Bi00<00039Z;S9Z;P01LVX^0030000cJ^gcJ^g00?=ZkL00`000<j/]lj/]`02cZbg00D0003>[;O>
[;O>[;L000000lf[]`040000bjVhbjVh00000/RW^0060000aJBhaJBh0000`J:i00000[jO^@030000
^ibi000000:hV[T010000;FG^KFG^@0000:cU[P00`000;>D^;>D^002/iBh0P0000FhU[@01@000<6L
/l6L/l6L/`000002bJ>a00@0003DZjl0003R]ZT20000J_ooo`030000oooooooo013oool0017oool3
00000e57Y`030000O6VcO6Vc00AlJK<00`0009Io]iIo]`07UWng00<0002WSKVWSKT02JN=^@030000
]9Ni]9Ni00ZdUkT00`000;fN^KfN^@08_Iji00<00034Y;W4Y;T01lBT^@030000bJRhbJRh00G9Z;P0
0`000<f[]lf[]`03cJ^g00<0003>[;O>[;L00/j/]`050000cZbgcZbgcZbg000000?=ZkL010000<^Y
^<^Y^00000;8YkP01P000<FT^<FT^0000<6R^@0000:nWkT00`000;^L^@000002^9Zi00@0002eUkVe
UkT00002/iJh00L0002cU;RcU;RcU;P0002bTkL000001KRF]0030000`Ibc000000X0001Zoooo00<0
003oooooool04?ooo`004Oooo`@00002DDNW00<0001lJK=lJK<017aY/`030000UWngUWng00NFOkL0
0`000:N=^JN=^@09Yhfi00<0002dUkVdUkT02[BG^@030000_Iji_Iji00RmW[T00`000<BT^LBT^@07
a:Bi00<00039Z;S9Z;P01LVX^0030000cJ^gcJ^g00?=ZkL00`000<j/]lj/]`02cZbg00D0003>[;O>
[;O>[;L000000lf[]`050000bjVhbjVh0000b:Nh00d000001;RJ^@000;FG^@0000:cU[P00`000;>D
^;>D^002/iBh00@0002bTkNbTkL00002^9Jd100000;0V[401@000<VP[/VP[P000=BWZP050000JOoo
o`030000oooooooo013oool0017oool3000000A<Bk00000000000006O6Vc00<0002FOkNFOkL01iIo
]`030000YhfiYhfi00VWSKT00`000;BG^KBG^@0:]9Ni00<0002mW[VmW[T02;fN^@030000a:Bia:Bi
00O4Y;T00`000<VX^<VX^005bJRh00<0003=ZkO=ZkL00lf[]`030000cZbgcZbg00;>[;L00`000<j/
]`00000:000000O8[l400035[<;5[<800031ZL8000000[fV`P040000^Z?20000]j311@000003/iJh
0000/iBh00:cU;P00`000;:C]k:C]`02/Y>g0P0000:hU[<01P000<2J/L2J/L2J/@000<VP[P@00000
1>2YV`000000000006Woool00`000?ooooooo`0@oooo000Boooo0P0000=<Bk0400000gaY/`030000
UWngUWng00NFOkL00`000:N=^JN=^@09Yhfi00<0002dUkVdUkT02[BG^@030000_Iji_Iji00VmW[T0
0`000<BT^LBT^@06a:Bi00<00039Z;S9Z;P01LVX^0030000cJ^gcJ^g00?=ZkL00`000<j/]lj/]`04
00000/nd`0050000cK?0cK?0cK?0000000;;/L4010000<R_`LR_`@0000;5[<801@000<6Y`P000;fV
`P000002^Z?200L0002gX<6gX<40002cWL40002aV/000`0000:cU;P010000;:C]k:C]k:C]`800004
^9Jc00<00030V[4000000P000003b9bZ0000dj:U00D0001Yoooo00<0003oooooool04?ooo`004_oo
o`800003C4^`00@0001iL;eiL;eiL;d9000019Io]`030000YhfiYhfi00VWSKT00`000;BG^KBG^@0:
]9Ni00<0002mW[VmW[T02KfN^@030000a:Bia:Bi00K4Y;T010000<VX^<VX^<VX^0d00002ckC000D0
003?]<3?]<3?]<0000000lfc`0040000bk71bk7100000/R_`@040000aJc20000`JW21@000006^Z?2
0000]j310000/ig100000k6J`0040000[iRo000000000k:C]`050000/I>g/I>g0000^9Jc00@00000
1;nG[P000<RLZ/RLZP8000001=6MW`0000000>fUO@80001Xoooo00<0003oooooool04?ooo`004_oo
o`@000000da;/00007U`_@05NG2m00<0002DQ/6DQ/400iB6`@/00005Yhfi00<0002dUkVdUkT02[BG
^@030000_Iji_Iji00VmW[T00`000<BT^LBT^@02a:Bi200000C:/<400`000<fc`Lfc`@03cK?100<0
003?]<3?]<000/nd`0050000ckC0ckC0ckC0000000?=/l000`000<^a`@000007000000G0/L`0002l
[/`0002hZ//01`000009/I[00000[iRo[iRo0000[IJn0000/Y>g000000>aTkL200000[RC/P030000
_iN^_iN^00<000000lNHYP000=6MW`050000Ioooo`030000oooooooo017oool001;oool3000000<n
BkH0000000001WU`_@030000U8K1U8K100NDQ/400`000:JD`jJD``04YYC38`0000C4[<800`000<Z`
`LZ``@05b[3100<0003=/l7=/l400lfc`@030000ckC0ckC000;?]<001P000<nd`<nd`<nd`0000<fc
`0@000001l^kbP000<RhblRhb`000<Beb`000002`;7<00<0002l[/`000000[RZb`060000]:K;0000
/:;:0000[Ik90`000005[iRo0000[IJn[IJn000000>aTkL00`000;2A]P000003^9>b0P000003_YB[
0000aiRV00<000001<nGVP0000000>VJL`80001Voooo00<0003oooooool04Oooo`004_ooo`<00002
?T^f0P0000EiL;d00`0009B6`IB6`@07U8K100<0002VU<>VU<<02JJD``030000/io3/io300ZcWl<0
0`000;fV`kfV``09_JK300<00034[<;4[<801/B/`P030000b[31b[3100G:/<400`000<fc`Lfc`@03
cK?100<0003?]<3?]<000/nd`0030000ckC0000000<00002c[g:00@0003;^l[;^lX00002b;S;3000
0005/:;:0000[Ik9[Ik9000000:YVlL020000:fF_ZfF_P000:^C_@000;6C]`0000:`TKH00`000;RC
/P00000200000[jDZ`8000000lFCXP000<nGVP060000I_ooo`030000oooooooo017oool001;oool4
000000<nBkH0001`LlH00P0000=iL;d00`0009B6`IB6`@07U8K100<0002VU<>VU<<02JJD``030000
/io3/io300ZcWl<00`000;fV`kfV``09_JK300<00034[<;4[<801/B/`P030000b[31b[3100G:/<40
0`000<fc`Lfc`@03cK?100<0003?]<3?]<00100000;?_/T01P000<jmb/jmb/jmbP000<^kbPD00000
2/>oeP000;jkekjke`000;Zge`000;BbeP000:n]eP@000002:fNb@000:VKa`000:JGaP000:fF_P00
00:[Tkd010000;2A][2A][2A]P800003]i6_0P000003_I2X0000aI>R00800002cI6E00<0003HTXH0
00000P0006Goool00`000?ooooooo`0Aoooo000Boooo10000003?T^f0000L7?6009`LlH2000000=i
L;d0002DQ/4029B6`@030000YYC3YYC300VVU<<00`000;>O`k>O``0:/io300<0002mY/>mY/<02KfV
``030000a:c2a:c200K4[<800`000<Z``LZ``@05b[3100<0003=/l7=/l401P0000;?_/T01P000<nn
bLnnbLnnb@000<jmbP@000001/c6e@000<S3e/S3eP000<>oePP000001Jn]eP000:^Xe0000:JSd`02
000000JYVlL0002VUlJVUlH0002[Tkd3000000J`TKH00000002_S[@0002gTJl300000[f@Z0800002
`hnN00D0003=TID00000003DRGh00`0006Coool00`000?ooooooo`0Aoooo000Boooo00<0003oool0
00000`0000E`LlH3000029B6`@030000YYC3YYC300VVU<<00`000;>O`k>O``0:/io300<0002mY/>m
Y/<02KfV``030000a:c2a:c200K4[<800`000<Z``LZ``@03b[311@0000?>_LX00`000<nnbLnnb@02
ckk900<0003?_/W?_/T00`0000;?bM@01@000<c6eLc6e@000<S3eP04000000Jkb>@0002e`^Be`^@0
002^_>@5000000>VXm<0002RW]400P000004YYO60000Y9?400000jV@^`030000[hjd[hjd00:_S[@0
10000;F=[KF=[KF=[@8000001;^<Y0000<>?W/>?WP8000000lZ:S`000=B9OP040000Hoooo`030000
oooooooo017oool001;oool00`000?ooo`00000300001W1caP030000Shc<000000<00004U8K100<0
002VU<>VU<<02ZJD``030000/io3/io300VcWl<00`000;fV`kfV``09_JK300<00034[<;4[<801/B/
`P030000b[31000000<00002b[[;00<0003>_L[>_LX00ljmbP030000ckk9ckk900;?_/T3000000?@
b]@0003?bM@00/o9e0030000c<KE0000008000000lOBhP000<7=h`0:0000016Q[n4000000000002R
W]40002MV<h0002TTl@0002QSl40002YT;/0002WS;T0002_S[@00`000004]Hf]0000000000000k^<
Y08000000l69V@000<Z:S`0200000]21M`<0001Roooo00<0003oooooool04Oooo`004_ooo`030000
oooooooo00D00004L7?600<0002?S<b?S<`00hn<c0<000000iB6`@000:JD``0;YYC300<0002cWl>c
Wl<02K>O``030000_JK3_JK300VmY/<00`000<B/`/B/`P02a:c21P0000K:^//00`000<jmb/jmbP03
c[g:00@0003?_/W?_/W?_/T200000m3:e0030000clWDclWD00<000000l_Eh@000000000<000000F=
]_4000000000002EX=`00P000003WIS>0000000000>QSl401@000:N<^JN<^JN<^@000003[H^a00@0
002cRJVcRJVcRJT400000/69V@800002ahB:00<0003@PGL000001000063oool00`000?ooooooo`0A
oooo000Boooo00@0003oooooooooool3000000=QM<l0000000000W1caP030000Shc<Shc<00J?S<`8
00001ZJD``030000/io3/io300VcWl<00`000;fV`kfV``03_JK32`0000C4]/`00`000<ZjblZjb`05
b[[;00<0003>_L[>_LX00ljmbP060000ckk900000000d<[D00000m3:e0<000000loHh0000<_Eh@02
000000?1i?00002jgo802P000003Ek?k0000Q:c^00800002SiWI00D0002JTl`00000002QSl400P00
0005Yhbi000000000000[H^a00<00002/hVY0P0000>iR:4200000[n4U@040000ahB:000000000/]i
L@040000dF]<00000000Goooo`030000oooooooo017oool001;oool01`000?ooooooooooo`00000a
]@000003HGC?0`0000V?S<`00`000:>LcZ>LcP04Xic>600000Jl[ld00`000<Bfc<Bfc006a;K<00<0
003:^/_:^//01LZjb`030000c[g:c[g:00;>_LX300000m3:e0030000d<[D000000800002cmSP0`00
0003a^S^000000000080000<oooo00P0000kT_40001cU^H00029TMD0002FSLP2000000>NR[h00000
00000jF8]P040000ZhN^ZhN^ZhN^0P0000:aQJH01@000;V8X@000;N3W@000003_hBE00D00034OHC4
OH@0003;NG400P000003bf540000000005koool00`000?ooooooo`0Aoooo000Coooo00@0003ooooo
ooooool30000165dc`800008Shc<00<0002SW<jSW<h02Z>LcP030000/ZO>/ZO>00VbYlh00`000;b_
cKb_c@09_:o=00<00034]/c4]/`01/Bfc0030000b[[;b[[;00G:^//00`000<jmbP000002000000??
bM@0003@b]@00m3:e0800002dMWO0`000003bn_/0000a^S^0080000@oooo00L0000^P^T0001[Rn00
0024RM0000000Y:7a00<0000VhFkVhFk0000YHRf0000XhBb0000ZhN^0000ZH>[00000k65YP050000
]h>M]h>M0000_hBE008000000kaoT@000<AmQ00200000/MaJ`8000000l]QA0000000001Koooo00<0
003oooooool04_ooo`004oooo`040000oooooooooooo0P000003A6gF0000HGC?009QM<l00`0008JA
e`00000200001Hn<c0030000Xic>Xic>00ZSW<h00`000;:Wc[:WcP09/ZO>00<0002l[lfl[ld02Kb_
c@030000a;K<a;K<00K4]/`00`000<ZjblZjb`03b[[;100000C?bM@00`000=3:e=3:e00300000]7I
g`800002bn_/100001?oool3000000B4RM000000002BQl@2000000>KQK/0000000000j>4/P050000
ZH>[ZH>[0000/HFV00<00002]h>M0P0000BlOi400`000<5hP<5hP002000000C7LF/000000036FSh3
0000FOooo`030000oooooooo01;oool001?oool00`000?ooooooo`02oooo00<00014KMI4KMH00P00
0003HGC?0000QY7G00>6TML2000018n<c0030000Xic>Xic>00VSW<h00`000;:Wc[:WcP09/ZO>00<0
002l[lfl[ld02Kb_c@030000a;K<a;K<00K4]/`00`000<Zjb`00000300000/_6e@030000clWDclWD
00??bM@300000]7Ig`<000000lg]jP000000000300005_ooo`<000000gn1b`0000000002SX3000@0
002HP;L0002SQ;8300000ZV3Z`800003[h6S0P0000:dOYT01P000;aoT@0000000;YjS@0000?1N800
0`000<A/I/A/IP02000000C6FSh000000000001Goooo00<0003oooooool04_ooo`004oooo`030000
oooooooo00;oool200000dA]eP030000HGC?000000F6TML3000000>?S<`0002SW<h02Z>LcP030000
/ZO>/ZO>00ZbYlh00`000;b_cKb_c@08_:o=00<00034]/c4]/`01<Bfc0@00006blKE00<0003?bMC?
bM@00/o9e0800004dMWO00<0003=kN[=kNX00P000003/o[Y0000oooo01Soool3000000=iN<D0002>
P<000P000003V82g0000000000>POjl2000000>WOZL0002_PJ<00P000003[GfO0000]7jI00:dOYT0
1P000;YjSKYjSKYjS@000<5hP08000000kicO0000<A/IP02a6aV00<00033EC/000000`0005Goool0
0`000?ooooooo`0Boooo000Coooo00<0003oooooool00oooo`800003A6gF0P0000R6TML500002:>L
cP030000/ZO>/ZO>00ZbYlh00`000;b_cKb_c@08_:o=00<00034]/c4]/`0100000;4`ML00`000<_6
eL_6e@05blKE00<0003?bM@000000P000004cmSP0000dMWOdMWO1`0001coool2000000=iN<D00000
00000XYj^`040000UGZc0000X7n_0`0000>WOZL01P000:emWjemWjemW`000;AnV@8000001;9jUP00
0;YjSKYjS@800004_W=l00@00034K6H00032J6@2000000C3EC/0002_9P00001Doooo00<0003ooooo
ool04_ooo`004oooo`030000oooooooo00Coool300000TA]eP800008QY7G00@0002NY=VNY=VNY=T6
00000Z>LcP030000/ZO>/ZO>00ZbYlh00`000;b_cKb_c@03_:o=200000K4`ML00`000<_6eL_6e@04
blKE0`0000C?f>0300000/k]jP030000]__V000001koool01P000:Hl000007A__`0008Yj^`800002
UGZc00@0002NNZ^NNZ^NNZ/3000000BUNZ@0002]OIn]OIl200001;9jUP800002^7N:0P0000:nLg`2
00001<9XI0040000`eDk0000[bD00P0005;oool00`000?ooooooo`0Boooo000Doooo00<0003ooooo
ool01?ooo`<000000dA]eP0007>Di00200001XJAe`030000WZCIWZCI00NNY=TE00001K^jf0030000
a<7Ga<7G00O4`ML010000<_6eL_6eL_6e@8000000l[EhP000<oHh003cmSP0P0000;>kNX300008Ooo
o`8000000gA__`0000000002QW>f0`0000:NNZ/200000jEjY0<00002ZgVL00H0002bNYH00000002a
Mi<00004^7N:0P0000:mLGX200000/9XI08000001<=D>P0000000:lU0080001?oooo00<0003ooooo
ool04oooo`005?ooo`030000oooooooo00Goool0100000]GdP00000000=cU>@300000hJAe`030000
WZCIWZCI00VNY=T00`000:nafJnaf@0:[k7I00<0002k^]Rk^]P02;^jf0030000a<7Ga<7G00O4`ML0
10000<_6e@00000000?:eN800`000<oHh<oHh002000000?;k>/0000000000`0002;oool3000000=_
I[P00026LkH00P0000:BMJl2000000>KMZL0002UNZ@00P000003XgJQ0000ZgVL00:[NI`200001;5g
T`060000^7N:00000000]gB800001;eaNP800002`VQT0P000005`e@j00000000[bD0000004koool0
0`000?ooooooo`0Coooo000Doooo00<0003oooooool01_ooo`0300002eOB000000IcU>@2000000>6
TML0002NY=T02YjTf@030000[k7I[k7I00Z_/MT00`000;^jf;^jf008^k[H00<00034`MO4`ML01LC1
e`@00005b]GR0`0000;;k>/2000000>gnnH0003oool09?ooo`8000001VmV^000000008=//@00099e
[`800003VgJW00<0002SMZ6SMZ400Z=fX@<00002ZGJI00@0002aMi>aMi>aMi<200001;MdR0050000
_G5j00000000_G5j00800003`VQT00<00033E3X00000100004coool00`000?ooooooo`0Coooo000D
oooo00<0003oooooool01oooo`@00006LiCT100000VNY=T00`000:nafJnaf@0:[k7I00<0002k^]Rk
^]P02;^jf0030000a<7Ga<7G00D00002`m3T00<0003:eN;:eN800l[EhP800002bnc[0P000003/o[X
0000000002Koool3000000=[G[400023K;400P0000:@KjX3000000>ILJ@0002SMZ400Z=fX@030000
ZGJIZGJI00:YMYT010000;5gT`00000000:`MI4010000;MdR;MdR;MdR0800005_G5j0P000004`VQT
0000000000000/EI?@@0001:oooo00<0003oooooool04oooo`005?ooo`030000oooooooo00Soool2
000000=;Snd0000000001G>Di0030000TZcXTZcX00@00006WZCI00<0002_/MV_/MT02Jnaf@030000
^k[H^k[H00Jk^]P500001l?@i0040000b]GRb]GRb]GR0P000005a^S^0000bnc[0000/o[X0080000Y
oooo0P000005Jeja00000000OfJ/000000:@KjX01P0009UaY9UaY9UaY0000:=fX@8000000j5cWP00
0:UfV@02ZGJI0P0000B`MI4010000;MdR000000000:fM8P00`000;eaN[eaNP04_G5j00@00034JfK4
JfK4JfH200000/EI?@<00019oooo00<0003oooooool04oooo`005Oooo`030000oooooooo00Soool2
00000T^?k@800003LiCT00<0002B[>RB[>P019:/j0@00002WZCI00<0002_/MV_/MT02Jnaf@030000
^k[H^k[H00H00002^<SV00<00033d>C3d>@01l?@i0040000b]GR000000000lKXkP040000/o[X/o[X
0000:oooo`050000?d:/0000IUJ[0000009oIZ`300000iUaY0800003XG>N00H0002YMYT00000002X
M9P00005/7FA00<0002fM8RfM8P00kIdR0040000_G5j_G5j_G5j0P000003_W=l0000a6]V00?4JfH2
000000?5FCd0000000000P0004Koool00`000?ooooooo`0Doooo000Eoooo00<0003oooooool02Ooo
o`<00002Bho]0P00009cU>@00`0009:/j9:/j007TZcX4@0000Rhb>H00`000<?@i<?@i006`m3T0`00
00?6j>h40000;Oooo`<000000fIFZ`0007mV[00200000Xe[YP<000000iQ^X@000:5cWP03XG>N00<0
002XM9RXM9P00ZQdV0030000/7FA/7FA008000000k1eT@000;IdR004]WB800<0002mLGX000001;ic
O0800004a6]V00D0003<HTC<HT@0002l=P000P0004Coool00`000?ooooooo`0Doooo000Eoooo00<0
003oooooool02_ooo`@00002Bho]0`0000^B[>P00`000:Rlj:Rlj009Z;cX00<0002hb>Jhb>H02KS8
iP030000`m3T`m3T00;3d>@3000000Blh_800036j>k6j>h50000;_ooo`8000001SXgX`0000000000
07aPY`0000:=JjH01@0009Q^XIQ^XIQ^X@000002XG>N0`0000BXM9P00`000;1eT@000004/7FA00<0
002fM8RfM8P00[IdR0800007_W=l00H00034JfH000000038Lf`00002c6941@0004;oool00`000?oo
ooooo`0Doooo000Foooo00<0003oooooool02oooo`@00002Bho]100000RB[>P00`000:Rlj:Rlj009
Z;cX00<0002hb>Jhb>H02KS8iP030000`m3T000000800004_>;b00<00036j>h000000`00037oool4
00000WaPY`@00004V6jQ0P0000>PLI`010000:QdV:QdV:QdV0800006/7FA00@0002fM8P000000002
^7N:00<0002nLgbnLg`01KicO0030000b7=/b7=/00;8Lf`200000/aRA0040000_3H000000000@?oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0=oooo00<00000JMD000000P0000=i/oL6
00000Y:/j0030000Z;cXZ;cX00ZX_>P00`000;S8i[S8iP06^<SV100000Jlh_82000000>/mnh00000
0000<oooo`040000=RjJ0000HdnU0`0000>;Ij<01@0009Q^XIQ^XIQ^X@000004X76L00@0002XM9P0
00000002Z7BH00<0002`MI6`MI401;1eT@030000^7N:^7N:00>hMhX200000kicO08000000l9iP@00
0<QcK004b7=/00D0003<HTC<HT@0002l=P000P0003ooool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool03_ooo`800000101Ye@000000000000Mi/oL900001ZRlj0030000^<SV^<SV00H00002
[MWf00<0002lh_:lh_800[cRlPH0000eoooo00L0000f;YX0001SCjD0001jG:@000000h]WX`030000
V6jQ000000800005X76L00<0002XM9RXM9P00ZQdV0030000/7FA/7FA00:`MI42000000>aMi<0002h
MhX01KQgRP030000_W=l000000C2NH4200001<QcK0050000c69400000000bDT00080000noooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo013oool200000S:TlP@00005NK?g00<0002Hb_VH
b_T019S:n@T00008[MWf00<0002lh_8000001P0003Ooool5000000=jG:@0002;Ij<00X]WX`800003
UfbP00<0002PLIbPLI`00P000003X76M0000Z7BH00>XM9P010000;1eT@00000000BaMi<00`000;Qg
R[QgRP04^7N:00<00032NH72NH401L9iP@030000b7=/b7=/00;8Lf`01@000=EaC]EaCP000<U90002
0000?Oooo`030000oooooooo01Goool001Ooool00`000?ooooooo`0Aoooo0`0000<bY?8400000WVc
m`030000V<[iV<[i00VHb_T00`000:gImZgImP06[MWf10000004W_3d000000000000>_ooo`<00000
1619X00007YLY7YLY0<000000hYUXP0009M/X002UfbP00<0002PLI`000000j1aW@030000Z7BHZ7BH
00:XM9P200001[5gT`030000^7N:^7N:00:hMhX2000000>kO8h00032NH401/9iP@060000b7=/0000
0000cgid00000]EaCP040000bDT000000000>oooo`030000oooooooo01Koool001Ooool00`000?oo
ooooo`0Doooo100000<bY?8900001IS:n@030000[MWf[MWf00H000000hOSnP00000000020000?Ooo
o`<000000f19X00007YLY00200000hYUXP040000UfbPUfbPUfbP0P0000FPLId010000:QdV0000000
00:ZMYX00`000;5gTk5gT`04/GNC00@0002hMhX000000004^gb>0P0000K2NH400`000<mnM<mnM002
cgid00<0003ELDkELDh00P000003bDT00000oooo03Woool00`000?ooooooo`0Foooo000Goooo00<0
003oooooool06?ooo`@000000c:TlP0006C;n`05I<_k200000:7hoX50000@Oooo`<000001F19X000
000007UIX@000004RVFR0`000003UfbP0000X76M00FPLId00`000:YfVZYfVP03ZWJJ00<0002aMi>a
Mi<01;5gT`030000^gb>^gb>00JkO8h010000<9iPL9iPL9iP@8000000lN3R0000<mnM003cgid00L0
003ELDkELDkELDh00039B@000000>Oooo`030000oooooooo01Koool001Soool00`000?ooooooo`0K
oooo4@0004Ooool500000WUIX@040000RVFRRVFRRVFR0P0000BGK:0010000:1aWJ1aWJ1aW@<00005
ZWJJ00<0002aMi>aMi<00[5gT`8000000k=lU`000;]lSP07^gb>00<00032NH4000001<N3R0030000
cgidcgid00;?OW@01`000=EaC]EaC]EaCP000<U90000000goooo00<0003oooooool05oooo`006?oo
o`030000oooooooo07?oool3000000=NAYd0001iFJ400WUIX@<000000hYUXP0009M/X003UfbP00@0
002PLId000000003XW>N00<0002ZMYZZMYX00jYfVP040000/GNC000000001;=lU`030000^gb>^gb>
00FkO8h200001/N3R0030000cgidcgid00;?OW@01`000=EaC]EaC]EaCP000=US3000000foooo00<0
003oooooool05oooo`006?ooo`030000oooooooo07?oool300000Ui6W@040000NEVQNEVQ00000hYU
XP030000UfbPUfbP00>GK:000`000:9cWZ9cWP03XW>N00<0002ZMYZZMYX01:YfVP030000/gbG/gbG
00FcO9L00`000;]lS[]lSP02^gb>0P0000:oQ9@00`000<N3R<N3R004ah>800<0003?OWC?OW@00/mn
M0070000eG5>0000h8AK0000fF<<000003Goool00`000?ooooooo`0Goooo000Ioooo00<0003ooooo
ool0L_ooo`<00002GTJM100000B:IJ800`0009M/X9M/X00300001Z9cWP040000ZWJJZWJJZWJJ0P00
0003[7^M0000/gbG00JcO9L010000;]lSP00000000FoQ9@00`000<N3R<N3R004ah>800<0003?OWC?
OW@00/mnM0070000h8AKh8AKh8AK0000fF<<000003?oool00`000?ooooooo`0Hoooo000Ioooo00<0
003oooooool0L_ooo`<000000ei6W@0000000002NEVQ00<0002:IJ::IJ800XYUXP<00003V6nR00<0
002RLijRLih00j9cWP040000ZWJJ000000001:akW@030000/gbG/gbG00FcO9L00`000;n4U;n4U006
_hBD00<00037PhS7PhP01<N3R0060000cgid00000000ehan00000n24F`030000fF<<000003;oool0
0`000?ooooooo`0Hoooo000Ioooo00<0003oooooool0L_ooo`@000000ei6W@0007UIX@02NEVQ00<0
002:IJ::IJ800P0000FHKj800`000:9cWZ9cWP03XW>N0P0000J/Nid00`000;=lUk=lU`04/gbG00<0
002gPid000001kn4U0030000ah>8ah>800G7PhP00`000=N<O]N<OP02ehan00L0003PQ5_PQ5_PQ5/0
003IH``00000<Oooo`030000oooooooo01Soool001[oool00`000?ooooooo`1aoooo0`00009NAYd0
100007UIXGUIXGUIX@<000000h]WY00009Q_XP04V6nR00@0002RLijRLijRLih200000ZAhXP030000
[7^M[7^M00B/Nid010000;=lUk=lUk=lU`800002]h>M00<0002oQ9BoQ9@01[n4U0030000ah>8ah>8
00;7PhP2000000?=SY40003GS7h00mN<OP070000h8AKh8AKh8AK0000fF<<000002ooool00`000?oo
ooooo`0Ioooo000Joooo00<0003oooooool0LOooo`<00002GTJM00<0001iFJ5iFJ400P0000B;Ij@0
0`0009Q_XYQ_XP03V6nR0`0000BTN:800`000:akWJakW@05[7^M00<0002cO9L000001KN3W@030000
_hBD_hBD00JoQ9@010000<N3R000000000C=SY401@000=N<O]N<O]N<OP000004h8AK00<0003IH``0
0000;_ooo`030000oooooooo01Woool001[oool00`000?ooooooo`1aoooo0`00009NAYd3000000=j
G:@0002;Ij@00h]WY0030000V6nRV6nR00>HKj800`000:AhXZAhXP05Y7RR00<0002/Nif/Nid01:ak
W@800007]h>M00<0002oQ9BoQ9@01[n4U0030000cHjAcHjA00C=SY400`000=N<O]N<OP02ehan00<0
003PQ5_PQ5/00^24F`030000fF<<000002goool00`000?ooooooo`0Ioooo000Koooo00<0003ooooo
ool0L?ooo`800000130RS`0005i6W@0000=jG:@00`0008]WY8]WY002RfNT00@0002HKj:HKj:HKj83
00002:AhXP040000[7^M[7^M[7^M0P0000:`PZ<00`000;N3WKN3W@05]h>M00<0002oQ9BoQ9@00kn4
U08000000lB>W0000<f>T@05cHjA00<0003GS7kGS7h00]N<OP030000h8AKh8AK00;PQ5/00`000>R3
7P00000[oooo00<0003oooooool06_ooo`006oooo`030000oooooooo073oool2000000@`8Xl00000
00000003NUbT00<0002;IjB;Ij@00h]WY0<00003VW>V00<0002TN::TN:801JAhXP040000[7^M0000
00001;22X`030000]h>M]h>M00FgPid00`000;n4U;n4U002_hBD00<00034SYc4SY`00/B>W0030000
cHjAcHjA00C=SY400`000=N<O]N<OP02ehan00D0003PQ5/00000003]Vf/00P0002_oool00`000?oo
ooooo`0Joooo000Koooo00<0003oooooool0L?ooo`@000000f19X00007YLY003NUbT00@0002;IjB;
IjB;Ij@200001IYcYP030000Y7RRY7RR00JTN:800`000;22Xk22X`05/8:S00<0002gPifgPid01KN3
W@040000_hBD000000001LB>W0030000cHjAcHjA00G=SY400`000=N<O]N<OP02ehan00L0003]Vf_]
Vf_]Vf/0003XPah00000:_ooo`030000oooooooo01[oool001coool00`000?ooooooo`1_oooo0P00
0004<RJC0000H4VP000017YLY0060000RfNT00000000SVfX00001YYcYP030000Y7RRY7RR00>TN:83
00001k22X`030000]h>M]h>M00JgPid00`000<B>W<B>W006a8jL00<0003=SY7=SY401<f>T@070000
ehanehanehan0000h9j;000000?]Vf/20000:Oooo`030000oooooooo01_oool001coool00`000?oo
ooooo`1_oooo0P000005<RJC0000H4VPH4VP000000=jG:@2000018i]Z0030000VW>VVW>V00>JLjH0
10000:AhXZAhXZAhXP800003YgnX00<0002`PZ>`PZ<01K22X`030000]h>M]h>M00>gPid2000000>l
SJ@00034SY`01lB>W0030000cHjAcHjA00C=SY400`000=N<OP000002h9j;00L0003]Vf_]Vf_]Vf/0
003XPah00000:?ooo`030000oooooooo01_oool001coool00`000?ooooooo`1_oooo0P000006<RJC
0000H4VPH4VP0000NUbT0`0000F>KJP00`0009YcYYYcYP04VW>V0`0000FWOjP00`000;22Xk22X`06
/8:S00D0002gPifgPifgPid000001;b=Y0030000a8jLa8jL00K4SY`00`000<f>TLf>T@04cHjA00<0
003PWX_PWX/00^2NR`040000kI][kI][kI][0P0002Soool00`000?ooooooo`0Koooo000Moooo00<0
003oooooool0K_ooo`800000138VT`000619X619X0800002OF:X00<0002>KJR>KJP018i]Z0030000
VW>VVW>V00>JLjH00`000:MoZ:MoZ006YgnX00<0002`PZ>`PZ<01K22X`040000]h>M000000001Kb=
Y0030000a8jLa8jL00K4SY`00`000<f>TLf>T@02cHjA0P000003e9fK0000h9j;00;PWX/01`000>fK
JnfKJnfKJ`000>R37P00000Voooo00<0003oooooool07?ooo`007Oooo`030000oooooooo06koool2
000000<b9Y<0001PBJ000P0000AmHZP00`0008i]Z8i]Z003SVfX00@0002JLjJJLjJJLjH2000000>N
NZ`0002WOjP01ZMoZ0030000/8:S/8:S00J`PZ<00`000;b=Y;b=Y006_8fT00<00034SYc4SY`01/B>
W0040000cHjA000000000mBMV`030000h9j;h9j;00;PWX/010000>fKJnfKJnfKJ`80000Voooo00<0
003oooooool07?ooo`007_ooo`030000oooooooo06goool5000000=SD:H0001mHZP00geRZ0030000
SVfXSVfX00B>KJP300000iij[0030000YgnXYgnX00JWOjP00`000;22Xk22X`03/8:S0P000003]8^Z
0000_8fT00NlSJ@00`000<B>W<B>W006a8jL00<0003DWI_DWI/01=BMV`050000h9j;h9j;h9j;0000
00?]Vf/00`000>R37P00000Toooo00<0003oooooool07Oooo`007_ooo`030000oooooooo06goool2
000000<e;Y/0001SD:H00V=@YP050000OF:XOF:XOF:X000000F>KJP200001Yij[0030000YgnXYgnX
00FWOjP010000;22Xk22Xk22X`800003]8^Z00<0002lSJBlSJ@01kb=Y0030000a8jLa8jL00?4SY`2
000000?:VjH0003DWI/01=BMV`030000h9j;h9j;00;PWX/010000>fKJnfKJnfKJ`80000Toooo00<0
003oooooool07Oooo`007oooo`030000oooooooo06coool2000000<e;Y/0001SD:H00V=@YP050000
OF:XOF:XOF:X000000>>KJP2000000>BM:h0002NNZ`01Iij[0030000YgnXYgnX00JWOjP300001[B;
ZP030000_8fT_8fT00JlSJ@00`000<B>W<B>W002a8jL00D0003:VjK:VjK:VjH000001]BMV`050000
h9j;h9j;h9j;000000?]Vf/00`000>R37P00000Roooo00<0003oooooool07_ooo`007oooo`030000
oooooooo06coool2000000<e;Y/0001SD:H00V=@YP030000OF:XOF:X009mHZP30000199d[P030000
WWZ/WWZ/00BNNZ`00`000:MoZ:MoZ004YgnX0P0000VdRjX00`000;b=Y;b=Y006_8fT00@00034SY`0
00000005bY^V00<0003DWI_DWI/00mBMV`030000h9j;h9j;00;PWX/010000>fKJnfKJnfKJ`80000R
oooo00<0003oooooool07_ooo`008?ooo`030000oooooooo06_oool2000000<e;Y/0001SD:H00V=@
YP040000OF:XOF:XOF:X0P0000JBM:h00`0009ij[9ij[005WWZ/00@0002WOjRWOjRWOjP200000Zb8
[`030000]8^Z]8^Z00JdRjX00`000;b=Y;b=Y007_8fT00<0003:VjK:VjH01LZKYP030000e9fKe9fK
00CDWI/01P000>2NRn2NRn2NR`000>fKJ`@0000Qoooo00<0003oooooool07oooo`008?ooo`030000
oooooooo06_oool200000SD^V`040000He2VHe2VHe2V0`000003PF^`0000TWB^00FBM:h00`0009ij
[9ij[005WWZ/00@0002WOjP000000004[8R_00<0002dRjZdRjX01kB;ZP030000_8fT_8fT00BlSJ@2
000000?2V:d0003:VjH01/ZKYP030000e9fKe9fK00?DWI/00`000>2NRn2NR`02h9j;00H0003h]Wch
]W`0003bY380000Poooo00<0003oooooool07oooo`008Oooo`030000oooooooo06[oool01@000000
M00003D^V`000002He2V0P0000B1Jk000`00099d[Y9d[P04TWB^00<0002NNZbNNZ`01Iij[0030000
[8R_[8R_00F/R:l00`000;B;Z[B;ZP07]8^Z00@0002lSJBlSJBlSJ@200000l:H[@030000bY^VbY^V
00G:VjH00`000=BMVmBMV`04e9fK00<0003PWX_PWX/00P0000?h]W`200007oooo`030000oooooooo
023oool0027oool00`000?ooooooo`1Zoooo00@0000007@0000e;Y/3000000=XFZl00021Jk000h5[
/0030000TWB^TWB^00BBM:h00`0009ij[9ij[003WWZ/0`0000R/R:l00`000;B;Z[B;ZP06]8^Z00@0
002lSJ@000000006`YR]00<0003:VjK:VjH01LZKYP030000e9fKe9fK00?DWI/00`000>2NR`000002
jK>I00<0003h]Wch]W`00P0001ooool00`000?ooooooo`0Poooo000Roooo00<0003oooooool0JOoo
o`030000001d000000800003J5Z_00<00021Jk21Jk000X5[/0030000TWB^TWB^00BBM:h0100009ij
[9ij[9ij[0800003XXBc00<0002/R:n/R:l01Jb8[`030000]8^Z]8^Z00NdRjX00`000<:H[L:H[@06
`YR]00<0003:VjK:VjH01LZKYP030000e9fKe9fK00CDWI/01@000>VcVNVcVNVcV@000002n;Il0P00
01koool00`000?ooooooo`0Qoooo000Soooo00<0003oooooool0J?ooo`<000000cXkY`0006QJ[`03
J5Z_00<00021Jk21Jk000X5[/0030000TWB^TWB^00BBM:h300001J:4/`030000[8R_[8R_00J/R:l0
0`000;B;Z[B;ZP04]8^Z0P000003^IJb0000`YR]00O2V:d00`000<ZKY/ZKYP05bY^V00@0003DWI_D
WI_DWI/300000nVcV@060000n;Iln;Il0000lZ@b00007?ooo`030000oooooooo02;oool002?oool0
0`000?ooooooo`1Xoooo00D0000008D0000j>jL0000016QJ[`030000PF^`PF^`00:1Jk000`00099d
[Y9d[P03TWB^0P0000RRQ;<00`000:b8[jb8[`06[8R_00@0002dRjZdRjZdRjX200000kVF/P030000
`YR]`YR]00K2V:d00`000<ZKY/ZKYP05bY^V00@0003DWI/000000003g:jX00D0003Y/iWY/iWY/iT0
00000_RfO080000Loooo00<0003oooooool08_ooo`009?ooo`030000oooooooo06Ooool00`000000
Q@000002>S^W00D0001XFZmXFZmXFZl00000185[/0040000TWB^TWB^TWB^0P000003UWjg0000XXBc
00NRQ;<00`000:b8[jb8[`06[8R_00@0002dRjX000000006^IJb00<00032V:g2V:d01/:H[@030000
bY^VbY^V00G:VjH00`000=b^Z=b^Z003g:jX00D0003Y/iWY/iWY/iT000000_RfO080000Koooo00<0
003oooooool08oooo`009Oooo`030000oooooooo06Ooool01@00Q@0003XkYcXkY`000003J5Z_00<0
0021Jk21Jk000h5[/0<00004UWjg00<0002RQ;>RQ;<01Z:4/`030000[8R_[8R_00J/R:l00`000;VF
/[VF/P06^IJb00<00032V:g2V:d01/:H[@030000bY^VbY^V00?:VjH300001Mb^Z0050000jK>IjK>I
jK>I000000;h]W`200006_ooo`030000oooooooo02Coool002Goool00`000?ooooooo`1Woooo0P00
008j>jL01@0006QJ[fQJ[fQJ[`000005PF^`00<0002FO[NFO[L019In]`030000XXBcXXBc00JRQ;<0
0`000:b8[jb8[`04[8R_0P000003/9:h0000^IJb00NiU[800`000<:H[L:H[@06`YR]00D0003:VjK:
VjK:VjH000000m6Y/0030000g:jXg:jX00?L[ZP02@000>VcVNVcVNVcV@000?RfO0000?:T<P00000I
oooo00<0003oooooool09?ooo`009_ooo`030000oooooooo06Koool200000SXkY`030000J5Z_J5Z_
009XFZl00`00085[/85[/00300001iIn]`030000XXBcXXBc00JRQ;<00`000:b8[jb8[`02[8R_00D0
002`T[R`T[R`T[P000002;VF/P030000`YR]`YR]00K2V:d010000<ZKYP00000000CAZK000`000=b^
Z=b^Z003g:jX00D0003Y/iWY/iWY/iT000000_RfO080000Hoooo00<0003oooooool09Oooo`009_oo
o`030000oooooooo06Koool01@000000Q@0003XkY`000004J5Z_0`0000>6M[X00`0009In]iIn]`04
UWjg00<0002RQ;>RQ;<01Z:4/`050000[8R_[8R_[8R_000000F`T[P00`000;VF/[VF/P06^IJb00<0
0032V:g2V:d01/:H[@030000dJV`dJV`00CAZK000`000=b^Z=b^Z003g:jX00D0003Y/iWY/iWY/iT0
00000_RfO080000Hoooo00<0003oooooool09Oooo`009oooo`030000oooooooo06Goool00`000000
Q@000002>S^W00<0001XFZmXFZl00P0000F6M[X00`0009In]iIn]`05UWjg00<0002RQ;>RQ;<01Z:4
/`<00006/9:h00<0002iU[:iU[801[VF/P030000`YR]`YR]00C2V:d300001m6Y/0030000g:jXg:jX
00?L[ZP010000>VcVNVcVNVcV@@0000Goooo00<0003oooooool09_ooo`00:?ooo`030000oooooooo
06Goool200000SXkY`<000000feX^`0008If^P05QWJj00<0002FO[NFO[L019In]`030000XXBcXXBc
00FRQ;<200002K2B^0030000^IJb^IJb00JiU[8010000<:H[L:H[L:H[@800003ajJg00<0003AZK3A
ZK001=6Y/0030000g:jXg:jX00?L[ZP01P000>VcVNVcVNVcV@000?oCS@80000Foooo00<0003ooooo
ool09oooo`00:?ooo`030000oooooooo06Goool2000000<j>jL00000000016eX^`030000QWJjQWJj
00>6M[X00`0009In]iIn]`05UWjg00<0002RQ;>RQ;<00Z:4/`800002Yhnl00<0002`T[R`T[P01[2B
^0030000^IJb^IJb00JiU[8010000<:H[@00000000G7Y[L00`000=6Y/=6Y/004dJV`00<0003L[ZSL
[ZP00mb^Z0030000jK>IjK>I008000000ooCS@000000000Foooo00<0003oooooool09oooo`00:Ooo
o`030000oooooooo06Coool3000000=1CKP0001]J;/00feX^`030000QWJjQWJj00B6M[X00`0009In
]iIn]`04UWjg00<0002RQ;>RQ;<00P0000BWSk`00`000;2B^;2B^007/9:h00<0002iU[:iU[801[VF
/P030000ajJgajJg00K7Y[L00`000=6Y/=6Y/004dJV`00<0003L[ZSL[ZP00mb^Z08000000o;;Z@00
0?oCS@0200005Oooo`030000oooooooo02Soool002[oool00`000?ooooooo`1Soooo0P0000=1CKP0
0`0006eX^feX^`02KFRk00<00026M[Z6M[X00hIf^P030000UWjgUWjg00FFO[L200001jN?_0030000
/9:h/9:h00J`T[P00`000;VF/[VF/P04^IJb0P000003_j>l0000ajJg00K7Y[L00`000=6Y/=6Y/004
dJV`00<0003L[ZSL[ZP00mb^Z0050000l/^Yl/^Y0000om>=0080000Doooo00<0003oooooool0:Ooo
o`00:oooo`030000oooooooo06?oool01@0>V`00045=^45=^0000004KFRk00<00026M[Z6M[X018If
^P030000UWjgUWjg00:FO[L2000000>KRl40002WSk`01ZN?_0030000/9:h/9:h00N`T[P010000;VF
/[VF/[VF/P800003_j>l00<00037Y[O7Y[L01LNV]`030000dJV`dJV`00CAZK0010000=b^Z=b^Z=b^
Z0<00002l/^Y00@0003odhd00000000Coooo00<0003oooooool0:_ooo`00;?ooo`030000oooooooo
06;oool200000d5=^0050000KFRkKFRkKFRk000000J6M[X01@0009In]iIn]iIn]`000003Vh_100<0
002WSkbWSk`01ZN?_0030000/9:h/9:h00J`T[P010000;VF/P00000000JoXk`00`000<NV]lNV]`05
ajJg00<0003AZK3AZK001=6Y/0<00002i<:f00D0003bbjWbbjT0003odhd00P0001;oool00`000?oo
ooooo`0[oooo000]oooo00<0003oooooool0H_ooo`0500jK0000@Dfh@Dfh000000A]J;/00`0008If
^XIf^P04QWJj0`0000FKRl400`000:N?_:N?_005Yhnl00<0002`T[R`T[P01k2B^0030000_j>l_j>l
00JoXk`00`000<NV]lNV]`05ajJg00<0003AZK3AZK001=6Y/0030000i<:fi<:f00;T`[H01@000?;;
ZO;;Z@000?oCS@0200004Oooo`030000oooooooo02coool002goool00`000?ooooooo`1Roooo0P00
0091CKP00`0006eX^feX^`02KFRk00<00026M[Z6M[X00hIf^P800007Vh_100<0002WSkbWSk`01ZN?
_0030000/9:h/9:h00B`T[P2000000>fWl80002oXk`01knS_0030000ajJgajJg00G7Y[L00`000=6Y
/=6Y/002dJV`0P0000CT`[H010000?;;ZO;;ZO;;Z@<0000Aoooo00<0003oooooool0;?ooo`00;_oo
o`030000oooooooo067oool200000d5=^0030000KFRkKFRk009]J;/00`0008If^P00000200000Xb4
a@030000Vh_1Vh_100FKRl400`000:N?_:N?_005Yhnl00<0002`T[R`T[P00k2B^0050000]Yo2]Yo2
]Yo2000000RoXk`00`000<NV]lNV]`05ajJg00<0003AZK3AZK000P000003f;^m0000i<:f00?T`[H0
10000?;;ZO;;ZO;;Z@<0000@oooo00<0003oooooool0;Oooo`00;oooo`030000oooooooo067oool2
00000T5=^0040000KFRkKFRkKFRk0`0000F<Q<D00`0009^;`I^;`@05Vh_100<0002WSkbWSk`01ZN?
_0050000/9:h/9:h/9:h000000FfWl800`000;nS_;nS_006_j>l00<00037Y[O7Y[L01LNV]`800004
f;^m00<0003T`[KT`[H00^C2]P030000l/^Yl/^Y00<0000?oooo00<0003oooooool0;_ooo`00<?oo
o`030000oooooooo063oool200000d5=^0<00002M7W:00<0002<Q<F<Q<D018b4a@030000Vh_1Vh_1
00FKRl400`000:N?_:N?_005Yhnl00@0002`T[P000000007]Yo200<0002oXkboXk`01KnS_0030000
ajJgajJg00C7Y[L200001MRk_@030000i<:fi<:f00;T`[H00`000?;;ZO;;Z@0300003_ooo`030000
oooooooo02ooool0037oool00`000?ooooooo`1Poooo0P000003@Dfh0000000000AdNLX00`0008b4
aHb4a@04S8C500<0002KRl6KRl401I^;`@030000YhnlYhnl00FWSk`200002KJO`P030000_j>l_j>l
00JoXk`010000<NV]lNV]lNV]`8000000ljf``000=Rk_@04f;^m00<0003T`[KT`[H00^C2]P030000
l/^Yl/^Y0080000>oooo00<0003oooooool0<?ooo`00<_ooo`030000oooooooo05ooool300000TMR
bP030000M7W:M7W:009dNLX00`0008b4aHb4a@04S8C500<0002KRl6KRl401I^;`@030000YhnlYhnl
00:WSk`200000ZfLa`030000]Yo2]Yo200NfWl800`000;nS_;nS_005_j>l00@00037Y[L000000004
c[K300<0003H^kgH^kd00]Rk_@030000i<:fi<:f00;T`[H00`000?;;ZO;;Z@0200003Oooo`030000
oooooooo037oool003?oool00`000?ooooooo`1Ooooo00D0:K=7H/Y7H/Y7H/X000001GAibP030000
S8C5S8C500B<Q<D00`0009^;`I^;`@04Vh_100<0002WSkbWSk`00P0000B]W<L00`000;JO`[JO`P07
]Yo200<0002oXkboXk`01[nS_0030000c[K3c[K300C>]/<00`000=Rk_MRk_@02f;^m00<0003T`[KT
`[H00^C2]PD0000<oooo00<0003oooooool0<_ooo`00=?ooo`030000oooooooo05koool200000dMR
bP030000M7W:M7W:009dNLX00`0008b4aHb4a@04S8C500<0002KRl6KRl4019^;`@<00007[Ic700<0
002fWl:fWl801kJO`P030000_j>l_j>l00>oXk`300001/jf``030000f;^mf;^m00;H^kd00`000>C2
]^C2]P02i<:f00<0003ei[Sei[P00P0000_oool00`000?ooooooo`0coooo000eoooo00<0003ooooo
ool0G_ooo`800002Af;:00<0001dNLYdNLX00gAibP030000S8C5S8C500B<Q<D0100009^;`I^;`I^;
`@800002XIW<00<0002]W<N]W<L01ZfLa`030000]Yo2]Yo200NfWl801@000;nS_;nS_;nS_0000003
aK;800<0003>]/?>]/<00ljf``030000f;^mf;^m00?H^kd00`000>C2]P000002000000?ei[P00000
00002oooo`030000oooooooo03Coool003Koool00`000?ooooooo`1Moooo00<00000:K<000000TMR
bP030000M7W:M7W:009dNLX00`0008b4aHb4a@04S8C500@0002KRl4000000005XIW<00<0002]W<N]
W<L01JfLa`030000]Yo2]Yo200NfWl8010000;nS_000000000C5//P00`000<jf`ljf``04c[K300<0
003H^kgH^kd00]Rk_@800002j]_400@0003ei[P00000000:oooo00<0003oooooool0=Oooo`00=ooo
o`030000oooooooo05goool200000TMRbP030000M7W:M7W:00=dNLX00`0008b4aHb4a@04S8C500<0
002QVLbQVL`01J6Ic0030000[Ic7[Ic700J]W<L00`000;JO`[JO`P07]Yo200<00035//S5//P01LFb
b0030000c[K3c[K300?>]/<00`000=Rk_MRk_@02f;^m00@0003ZflCZfl@00002mNJh0P0000Woool0
0`000?ooooooo`0foooo000hoooo00<0003oooooool0G?ooo`03000002Vc00000097H/X00`0007Ai
bWAibP03M7W:00@0002<Q<F<Q<F<Q<D2000000>BU=80002QVL`01Z6Ic0030000[Ic7[Ic700J]W<L0
0`000;JO`[JO`P04]Yo20P000003_:o=0000aK;800G5//P00`000<jf`ljf``03c[K300<0003H^kgH
^kd00`0000;Zfl@010000?GV^?GV^00000Woool00`000?ooooooo`0goooo000ioooo00<0003ooooo
ool0G?ooo`800002Af;:00<0001dNLYdNLX00gAibP040000S8C50000000019:DdP030000XIW<XIW<
00FQVL`00`000:fLajfLa`06[Ic700@0002fWl:fWl:fWl8200000kb_c@030000aK;8aK;800C5//P0
0`000<jf`ljf``04c[K30P0000;Nd/`01@000>[Ka>[Ka0000?GV^00200002?ooo`030000oooooooo
03Soool003[oool00`000?ooooooo`1Koooo00<00000:K<000000TMRbP030000M7W:M7W:009dNLX2
00001Y:DdP030000XIW<XIW<00JQVL`00`000:fLajfLa`05[Ic700@0002fWl8000000006_:o=00<0
0035//S5//P01<Fbb0030000c[K3c[K300?>]/<01@000=kBc=kBc=kBc0000002j]_400@0003ei[P0
00000007oooo00<0003oooooool0>Oooo`00>oooo`030000oooooooo05_oool01@00000Y/`0004MR
bP000002M7W:0P00009jSMX00`0009:DdY:DdP04TYCB00<0002QVLbQVL`01Z6Ic0030000[Ic7[Ic7
00B]W<L200002;b_c@030000aK;8aK;800C5//P010000<jf`ljf`ljf``<00003g];<00<0003Zfl@0
00000_GV^0030000oooooooo00Goool00`000?ooooooo`0joooo000loooo00<0003oooooool0F_oo
o`04000002Vc0000Af;:0`0000EjSMX00`0009:DdY:DdP04TYCB00<0002QVLbQVL`01J6Ic0030000
[Ic7[Ic700:]W<L200000[:]d`030000_:o=_:o=00Jl[ld00`000<Fbb<Fbb004aK;80`0000;Dbm40
1P000=kBc=kBc=kBc0000>[Ka0@00006oooo00<0003oooooool0>oooo`00?Oooo`030000oooooooo
05[oool300000TikgP030000NXgJNXgJ00AjSMX00`0009:DdY:DdP04TYCB00<0002QVLbQVL`01J6I
c0040000[Ic7000000001;:]d`030000_:o=_:o=00Jl[ld00`000<Fbb<Fbb004aK;800<0003Dbm7D
bm400]C;d@090000g];<g];<g];<0000j]_40000jO_0000000Koool00`000?ooooooo`0loooo000n
oooo00<0003oooooool0F_ooo`03000004[90000009>Nmh00`0007Z=fWZ=fP04NXgJ00<0002BU=:B
U=8019:DdP030000XIW<XIW<00BQVL`200001k:]d`030000_:o=_:o=00Jl[ld010000<Fbb<Fbb<Fb
b0<00005e<_A00<0003Nd/cNd/`01@0000Goool00`000?ooooooo`0moooo000ooooo0P0005_oool0
0`00001:b@000002CW_N00<0001jSMYjSMX00gZ=fP030000TYCBTYCB00BBU=800`000:6Ic:6Ic002
XIW<0P0000:WZmT00`000;:]dk:]d`05/ZgC00<0002l[lfl[ld01Kb_c@040000aK;8000000000l_6
eP030000e<_Ae<_A00;Dbm400`000=kBc=kBc002000000?Ynl00003oool00oooo`800010oooo0011
oooo00<0003oooooool0FOooo`03000004[90000009>Nmh00`0007Z=fWZ=fP03NXgJ00<0002BU=:B
U=8019:DdP040000XIW<000000001JN[f@030000/ZgC/ZgC00Fb[M<00`000;b_cKb_c@04_:o=0P00
00G;a]H00`000=C;dMC;d@02e<_A1`0000?oool00`000?ooooooo`10oooo0012oooo00<0003ooooo
ool0FOooo`03000004[90000009>Nmh00`0007Z=fWZ=fP03NXgJ00<0002BU=:BU=800i:DdP800008
Yj_I00<0002b[M>b[M<01;:]d`030000_:o=_:o=00:l[ld2000000?2`m/0003;a]H01<_6eP030000
e<_Ae<_A00;Dbm4010000>3[fP000>Odd@800003oooo00<0003oooooool0@Oooo`00@oooo`030000
oooooooo05Woool200000dikgP030000NXgJNXgJ00=jSMX00`0009:DdY:DdP0200000YRXhP030000
Yj_IYj_I00FWZmT00`000;:]dk:]d`05/ZgC00@0002l[ld000000004`/?K00<0003;a]K;a]H00/_6
eP030000e<_Ae<_A00<000001>3[fP000000000000?oool00`000?ooooooo`12oooo0014oooo00<0
003oooooool0FOooo`800003CW_N00<0001jSMYjSMX00WZ=fP<00005V:SR00<0002WZmVWZmT01JN[
f@030000/ZgC/ZgC00Fb[M<00`000<;3fl;3f`04`/?K00<0003;a]K;a]H00l_6eP800002enCO00<0
003PjmX000000P0000;oool00`000?ooooooo`13oooo0015oooo00<0003oooooool0FOooo`800003
CW_N00@0001jSMX000000002P:C[00<0002HZ>:HZ>8019RXhP800006Yj_I00<0002b[M>b[M<00[:]
d`8000000kS1h@000<;3f`05`/?K00@0003;a]K;a]K;a]H200000]OTg`030000h>_J000000800002
oooo00<0003oooooool0A?ooo`00A_ooo`80001Joooo0P00009>Nmh200001H2Tj`800006V:SR00<0
002WZmVWZmT01:N[f@040000/ZgC000000001;S1h@030000`/?K`/?K00?2`m/01P000<_6eP000000
0<kOi00000;Gi=l4000000?oool000000000Aoooo`00B?ooo`030000oooooooo05Soool300000U:G
l@800005P:C[00<0002HZ>:HZ>8019RXhP030000Yj_IYj_I00>WZmT200001kS1h@030000`/?K`/?K
00;2`m/200000lkOi0030000enCOenCO00<000000oooo`000?ooo`18oooo0019oooo0P0005Woool3
00000e:Gl@800004P:C[00<0002HZ>:HZ>8019RXhP030000Yj_IYj_I00800002[<3X0P0000Jh`N40
10000<;3f`00000000;5g>X00`000<kOi<kOi0070000B_ooo`00Boooo`80001Ioooo0`0000=BUo40
0`00082Tjh2Tj`02P:C[0P0000BHZ>8300001Zc0j0030000^<7Q^<7Q00>h`N4200001<GLjP050000
c]oT00000000cO[V00<0001<oooo001=oooo00<0003oooooool0F?ooo`<00002DYOa0P0000B0Y>/0
100009RXhP00000000>L`?4200001Jc0j08000000kS1h@0000000002^m[`00<00035g>[5g>X00/GL
jP030000a_K/00000080001>oooo001>oooo0P0005Woool400000U:Gl@800002P:C[0P0000NL`?42
00001Jc0j0030000^m[`^m[`00>kf_001@000<GLjP0000000;gcl@030000Coooo`00D?ooo`80001I
oooo10000004DYOa0000000000000h:nnP<00005W<3a0P000003[<3X0000000000:^f_L200000[_J
l0@000000i[dg0000?ooo`1@oooo001Boooo0P0005Woool300000e:bnP<00003P[kj0`0000>L`?42
00001ZkJm`L0001Boooo001Doooo0P0005Woool500000U:bnP<00003P[kj0`0000BKfOd80000EOoo
o`00E_ooo`80001Koooo1000009B/_X300001GgEo`P0001Goooo001Hoooo0P0005coool300001TW2
k`P0001Ioooo001Joooo0P0006Ooool20000Foooo`00G?ooo`80001Soooo0P0005goool005koool3
0000GOooo`<0001Ooooo001Qoooo0`0005Ooool30000H_ooo`00I?ooo`<0001Aoooo0`0006Goool0
06Ooool30000Boooo`<0001Xoooo001Zoooo0`0004Goool30000Joooo`00KOooo`@0000moooo1000
06koool0077oool30000=oooo`<0001boooo001doooo1@0002goool50000MOooo`00NOooo`H0000Q
oooo1P0007[oool007ooool:00003Oooo`X00020oooo0029oooo3@0008[oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
      ImageRangeCache->{{{68.25, 297.625}, {291.625, 62.25}} -> {0, 0, 0, 
      0}}]}], "Input",
  Editable->False,
  CellDingbat->None,
  Background->GrayLevel[1]],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.4829690195410925`;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    StyleBox[\(\(\[CapitalDelta]1 = 
          0.4829690195410925`;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(\[CapitalDelta]8 = 
          0.4829690195410925`;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(kembed = 0;\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.33146 .5 m .24532 .5 L .24503 .46153 L p .696 .583 .724 r
F P
0 g
s
.33127 .53741 m .24503 .53847 L .24532 .5 L p .696 .554 .689 r
F P
0 g
s
.24532 .5 m .33146 .5 L .33127 .53741 L p .696 .554 .689 r
F P
0 g
s
.24532 .5 m .15898 .5 L .15866 .46847 L p .772 .644 .721 r
F P
0 g
s
.15866 .46847 m .24503 .46153 L .24532 .5 L p .772 .644 .721 r
F P
0 g
s
.15898 .5 m .24532 .5 L .24503 .53847 L p .772 .616 .687 r
F P
0 g
s
.58427 .64596 m .62734 .72056 L .59417 .74005 L p .727 .594 .707 r
F P
0 g
s
.61676 .62742 m .66081 .70158 L .62734 .72056 L p .697 .584 .725 r
F P
0 g
s
.62734 .72056 m .58427 .64596 L .61676 .62742 L p .697 .584 .725 r
F P
0 g
s
.62734 .72056 m .67051 .79533 L .64336 .81138 L p .684 .504 .636 r
F P
0 g
s
.64336 .81138 m .59417 .74005 L .62734 .72056 L p .684 .504 .636 r
F P
0 g
s
.67051 .79533 m .62734 .72056 L .66081 .70158 L p .655 .494 .653 r
F P
0 g
s
.58427 .35404 m .62734 .27944 L .66081 .29842 L p .697 .554 .689 r
F P
0 g
s
.55197 .33517 m .59417 .25995 L .62734 .27944 L p .727 .594 .707 r
F P
0 g
s
.62734 .27944 m .58427 .35404 L .55197 .33517 L p .727 .594 .707 r
F P
0 g
s
.62734 .27944 m .67051 .20467 L .69798 .22015 L p .655 .576 .754 r
F P
0 g
s
.69798 .22015 m .66081 .29842 L .62734 .27944 L p .655 .576 .754 r
F P
0 g
s
.67051 .20467 m .62734 .27944 L .59417 .25995 L p .684 .614 .771 r
F P
0 g
s
.3307 .57342 m .24415 .57553 L .24503 .53847 L p .694 .522 .651 r
F P
0 g
s
.24503 .53847 m .33127 .53741 L .3307 .57342 L p .694 .522 .651 r
F P
0 g
s
.15866 .53153 m .24503 .53847 L .24415 .57553 L p .772 .588 .649 r
F P
0 g
s
.24503 .53847 m .15866 .53153 L .15898 .5 L p .772 .616 .687 r
F P
0 g
s
.24503 .46153 m .33127 .46259 L .33146 .5 L p .696 .583 .724 r
F P
0 g
s
.33127 .46259 m .24503 .46153 L .24415 .42447 L p .694 .611 .759 r
F P
0 g
s
.24503 .46153 m .15866 .46847 L .1577 .43814 L p .772 .673 .754 r
F P
0 g
s
.1577 .43814 m .24415 .42447 L .24503 .46153 L p .772 .673 .754 r
F P
0 g
s
.59417 .74005 m .55197 .66483 L .58427 .64596 L p .727 .594 .707 r
F P
0 g
s
.55197 .66483 m .59417 .74005 L .56252 .75933 L p .757 .604 .687 r
F P
0 g
s
.59417 .74005 m .64336 .81138 L .61758 .82737 L p .712 .51 .614 r
F P
0 g
s
.61758 .82737 m .56252 .75933 L .59417 .74005 L p .712 .51 .614 r
F P
0 g
s
.64823 .60991 m .69333 .68381 L .66081 .70158 L p .663 .572 .742 r
F P
0 g
s
.66081 .70158 m .61676 .62742 L .64823 .60991 L p .663 .572 .742 r
F P
0 g
s
.69798 .77985 m .66081 .70158 L .69333 .68381 L p .621 .479 .667 r
F P
0 g
s
.66081 .70158 m .69798 .77985 L .67051 .79533 L p .655 .494 .653 r
F P
0 g
s
.66081 .29842 m .61676 .37258 L .58427 .35404 L p .697 .554 .689 r
F P
0 g
s
.61676 .37258 m .66081 .29842 L .69333 .31619 L p .663 .512 .668 r
F P
0 g
s
.66081 .29842 m .69798 .22015 L .72472 .23449 L p .621 .536 .737 r
F P
0 g
s
.72472 .23449 m .69333 .31619 L .66081 .29842 L p .621 .536 .737 r
F P
0 g
s
.52106 .31667 m .56252 .24067 L .59417 .25995 L p .757 .633 .723 r
F P
0 g
s
.59417 .25995 m .55197 .33517 L .52106 .31667 L p .757 .633 .723 r
F P
0 g
s
.64336 .18862 m .59417 .25995 L .56252 .24067 L p .712 .652 .789 r
F P
0 g
s
.59417 .25995 m .64336 .18862 L .67051 .20467 L p .684 .614 .771 r
F P
0 g
s
.55365 .59293 m .58427 .64596 L .55197 .66483 L p .76 .673 .766 r
F P
0 g
s
.58077 .57739 m .61676 .62742 L .58427 .64596 L p .729 .662 .784 r
F P
0 g
s
.58427 .64596 m .55365 .59293 L .58077 .57739 L p .729 .662 .784 r
F P
0 g
s
.3927 .5 m .33146 .5 L .33127 .46259 L p .617 .519 .72 r
F P
0 g
s
.3926 .53126 m .33127 .53741 L .33146 .5 L p .617 .489 .684 r
F P
0 g
s
.33146 .5 m .3927 .5 L .3926 .53126 L p .617 .489 .684 r
F P
0 g
s
.55365 .40707 m .58427 .35404 L .61676 .37258 L p .729 .528 .62 r
F P
0 g
s
.52663 .39136 m .55197 .33517 L .58427 .35404 L p .76 .568 .637 r
F P
0 g
s
.58427 .35404 m .55365 .40707 L .52663 .39136 L p .76 .568 .637 r
F P
0 g
s
.55197 .66483 m .52663 .60864 L .55365 .59293 L p .76 .673 .766 r
F P
0 g
s
.52663 .60864 m .55197 .66483 L .52106 .68333 L p .791 .686 .748 r
F P
0 g
s
.56252 .75933 m .52106 .68333 L .55197 .66483 L p .757 .604 .687 r
F P
0 g
s
.60696 .56262 m .64823 .60991 L .61676 .62742 L p .696 .653 .803 r
F P
0 g
s
.61676 .62742 m .58077 .57739 L .60696 .56262 L p .696 .653 .803 r
F P
0 g
s
.39229 .56132 m .3307 .57342 L .33127 .53741 L p .611 .454 .644 r
F P
0 g
s
.33127 .53741 m .3926 .53126 L .39229 .56132 L p .611 .454 .644 r
F P
0 g
s
.33127 .46259 m .3926 .46874 L .3927 .5 L p .617 .519 .72 r
F P
0 g
s
.3926 .46874 m .33127 .46259 L .3307 .42658 L p .611 .544 .755 r
F P
0 g
s
.24415 .42447 m .3307 .42658 L .33127 .46259 L p .694 .611 .759 r
F P
0 g
s
.61676 .37258 m .58077 .42261 L .55365 .40707 L p .729 .528 .62 r
F P
0 g
s
.58077 .42261 m .61676 .37258 L .64823 .39009 L p .696 .483 .596 r
F P
0 g
s
.69333 .31619 m .64823 .39009 L .61676 .37258 L p .663 .512 .668 r
F P
0 g
s
.50075 .37606 m .52106 .31667 L .55197 .33517 L p .791 .606 .651 r
F P
0 g
s
.55197 .33517 m .52663 .39136 L .50075 .37606 L p .791 .606 .651 r
F P
0 g
s
.32978 .60668 m .24272 .60975 L .24415 .57553 L p .689 .484 .605 r
F P
0 g
s
.24415 .57553 m .3307 .57342 L .32978 .60668 L p .689 .484 .605 r
F P
0 g
s
.1577 .56186 m .24415 .57553 L .24272 .60975 L p .773 .557 .606 r
F P
0 g
s
.24415 .57553 m .1577 .56186 L .15866 .53153 L p .772 .588 .649 r
F P
0 g
s
.52106 .68333 m .56252 .75933 L .53359 .77768 L p .789 .614 .663 r
F P
0 g
s
.56252 .75933 m .61758 .82737 L .59416 .8427 L p .738 .511 .585 r
F P
0 g
s
.59416 .8427 m .53359 .77768 L .56252 .75933 L p .738 .511 .585 r
F P
0 g
s
.3307 .42658 m .24415 .42447 L .24272 .39025 L p .689 .64 .796 r
F P
0 g
s
.24415 .42447 m .1577 .43814 L .15614 .4102 L p .773 .706 .788 r
F P
0 g
s
.15614 .4102 m .24272 .39025 L .24415 .42447 L p .773 .706 .788 r
F P
0 g
s
.67749 .59408 m .72369 .66793 L .69333 .68381 L p .624 .557 .759 r
F P
0 g
s
.69333 .68381 m .64823 .60991 L .67749 .59408 L p .624 .557 .759 r
F P
0 g
s
.72472 .76551 m .69333 .68381 L .72369 .66793 L p .58 .457 .677 r
F P
0 g
s
.69333 .68381 m .72472 .76551 L .69798 .77985 L p .621 .479 .667 r
F P
0 g
s
.64823 .39009 m .69333 .31619 L .72369 .33207 L p .624 .462 .642 r
F P
0 g
s
.69333 .31619 m .72472 .23449 L .7497 .24711 L p .58 .49 .717 r
F P
0 g
s
.7497 .24711 m .72369 .33207 L .69333 .31619 L p .58 .49 .717 r
F P
0 g
s
.49273 .29925 m .53359 .22232 L .56252 .24067 L p .789 .675 .738 r
F P
0 g
s
.56252 .24067 m .52106 .31667 L .49273 .29925 L p .789 .675 .738 r
F P
0 g
s
.61758 .17263 m .56252 .24067 L .53359 .22232 L p .738 .694 .809 r
F P
0 g
s
.56252 .24067 m .61758 .17263 L .64336 .18862 L p .712 .652 .789 r
F P
0 g
s
.52106 .68333 m .50075 .62394 L .52663 .60864 L p .791 .686 .748 r
F P
0 g
s
.50075 .62394 m .52106 .68333 L .49273 .70075 L p .826 .702 .728 r
F P
0 g
s
.53359 .77768 m .49273 .70075 L .52106 .68333 L p .789 .614 .663 r
F P
0 g
s
.3918 .58901 m .32978 .60668 L .3307 .57342 L p .598 .409 .597 r
F P
0 g
s
.3307 .57342 m .39229 .56132 L .3918 .58901 L p .598 .409 .597 r
F P
0 g
s
.63119 .5492 m .67749 .59408 L .64823 .60991 L p .658 .644 .825 r
F P
0 g
s
.64823 .60991 m .60696 .56262 L .63119 .5492 L p .658 .644 .825 r
F P
0 g
s
.3307 .42658 m .39229 .43868 L .3926 .46874 L p .611 .544 .755 r
F P
0 g
s
.39229 .43868 m .3307 .42658 L .32978 .39332 L p .598 .568 .791 r
F P
0 g
s
.24272 .39025 m .32978 .39332 L .3307 .42658 L p .689 .64 .796 r
F P
0 g
s
.64823 .39009 m .60696 .43738 L .58077 .42261 L p .696 .483 .596 r
F P
0 g
s
.60696 .43738 m .64823 .39009 L .67749 .40592 L p .658 .43 .563 r
F P
0 g
s
.72369 .33207 m .67749 .40592 L .64823 .39009 L p .624 .462 .642 r
F P
0 g
s
.47701 .36179 m .49273 .29925 L .52106 .31667 L p .826 .646 .659 r
F P
0 g
s
.52106 .31667 m .50075 .37606 L .47701 .36179 L p .826 .646 .659 r
F P
0 g
s
.67051 .20467 m .69907 .1552 L .71672 .16512 L p .593 .593 .821 r
F P
0 g
s
.71672 .16512 m .69798 .22015 L .67051 .20467 L p .593 .593 .821 r
F P
0 g
s
.69907 .1552 m .67051 .20467 L .64336 .18862 L p .62 .628 .837 r
F P
0 g
s
.15898 .5 m .10186 .5 L .10162 .47976 L p .851 .708 .703 r
F P
0 g
s
.10162 .47976 m .15866 .46847 L .15898 .5 L p .851 .708 .703 r
F P
0 g
s
.10186 .5 m .15898 .5 L .15866 .53153 L p .851 .682 .672 r
F P
0 g
s
.67051 .79533 m .69907 .8448 L .68166 .85513 L p .62 .384 .539 r
F P
0 g
s
.68166 .85513 m .64336 .81138 L .67051 .79533 L p .62 .384 .539 r
F P
0 g
s
.69907 .8448 m .67051 .79533 L .69798 .77985 L p .593 .375 .554 r
F P
0 g
s
.32853 .63586 m .24079 .6398 L .24272 .60975 L p .678 .435 .546 r
F P
0 g
s
.24272 .60975 m .32978 .60668 L .32853 .63586 L p .678 .435 .546 r
F P
0 g
s
.15614 .5898 m .24272 .60975 L .24079 .6398 L p .774 .519 .549 r
F P
0 g
s
.24272 .60975 m .15614 .5898 L .1577 .56186 L p .773 .557 .606 r
F P
0 g
s
.49273 .70075 m .53359 .77768 L .50853 .79438 L p .825 .624 .631 r
F P
0 g
s
.53359 .77768 m .59416 .8427 L .57406 .85674 L p .765 .507 .544 r
F P
0 g
s
.57406 .85674 m .50853 .79438 L .53359 .77768 L p .765 .507 .544 r
F P
0 g
s
.32978 .39332 m .24272 .39025 L .24079 .3602 L p .678 .673 .838 r
F P
0 g
s
.24272 .39025 m .15614 .4102 L .15402 .38577 L p .774 .745 .827 r
F P
0 g
s
.15402 .38577 m .24079 .3602 L .24272 .39025 L p .774 .745 .827 r
F P
0 g
s
.70339 .58057 m .75068 .65458 L .72369 .66793 L p .572 .536 .776 r
F P
0 g
s
.72369 .66793 m .67749 .59408 L .70339 .58057 L p .572 .536 .776 r
F P
0 g
s
.7497 .75289 m .72369 .66793 L .75068 .65458 L p .525 .424 .682 r
F P
0 g
s
.72369 .66793 m .7497 .75289 L .72472 .76551 L p .58 .457 .677 r
F P
0 g
s
.67749 .40592 m .72369 .33207 L .75068 .34542 L p .572 .398 .607 r
F P
0 g
s
.72369 .33207 m .7497 .24711 L .77192 .25749 L p .525 .433 .694 r
F P
0 g
s
.77192 .25749 m .75068 .34542 L .72369 .33207 L p .525 .433 .694 r
F P
0 g
s
.46808 .28358 m .50853 .20562 L .53359 .22232 L p .825 .723 .753 r
F P
0 g
s
.53359 .22232 m .49273 .29925 L .46808 .28358 L p .825 .723 .753 r
F P
0 g
s
.59416 .1573 m .53359 .22232 L .50853 .20562 L p .765 .742 .832 r
F P
0 g
s
.53359 .22232 m .59416 .1573 L .61758 .17263 L p .738 .694 .809 r
F P
0 g
s
.53562 .56169 m .55365 .59293 L .52663 .60864 L p .784 .746 .818 r
F P
0 g
s
.55668 .54959 m .58077 .57739 L .55365 .59293 L p .753 .735 .836 r
F P
0 g
s
.55365 .59293 m .53562 .56169 L .55668 .54959 L p .753 .735 .836 r
F P
0 g
s
.42877 .5 m .3927 .5 L .3926 .46874 L p .529 .446 .706 r
F P
0 g
s
.42872 .52429 m .3926 .53126 L .3927 .5 L p .529 .417 .671 r
F P
0 g
s
.3927 .5 m .42877 .5 L .42872 .52429 L p .529 .417 .671 r
F P
0 g
s
.53562 .43831 m .55365 .40707 L .58077 .42261 L p .753 .495 .541 r
F P
0 g
s
.51461 .42612 m .52663 .39136 L .55365 .40707 L p .784 .534 .559 r
F P
0 g
s
.55365 .40707 m .53562 .43831 L .51461 .42612 L p .784 .534 .559 r
F P
0 g
s
.68166 .14487 m .64336 .18862 L .61758 .17263 L p .642 .663 .855 r
F P
0 g
s
.64336 .18862 m .68166 .14487 L .69907 .1552 L p .62 .628 .837 r
F P
0 g
s
.69798 .22015 m .71672 .16512 L .7339 .17421 L p .559 .556 .807 r
F P
0 g
s
.7339 .17421 m .72472 .23449 L .69798 .22015 L p .559 .556 .807 r
F P
0 g
s
.10162 .52024 m .15866 .53153 L .1577 .56186 L p .854 .658 .637 r
F P
0 g
s
.15866 .53153 m .10162 .52024 L .10186 .5 L p .851 .682 .672 r
F P
0 g
s
.15866 .46847 m .10162 .47976 L .10091 .46033 L p .854 .736 .733 r
F P
0 g
s
.10091 .46033 m .1577 .43814 L .15866 .46847 L p .854 .736 .733 r
F P
0 g
s
.64336 .81138 m .68166 .85513 L .66519 .86546 L p .642 .385 .515 r
F P
0 g
s
.66519 .86546 m .61758 .82737 L .64336 .81138 L p .642 .385 .515 r
F P
0 g
s
.71672 .83488 m .69798 .77985 L .72472 .76551 L p .559 .357 .563 r
F P
0 g
s
.69798 .77985 m .71672 .83488 L .69907 .8448 L p .593 .375 .554 r
F P
0 g
s
.52663 .60864 m .51461 .57388 L .53562 .56169 L p .784 .746 .818 r
F P
0 g
s
.51461 .57388 m .52663 .60864 L .50075 .62394 L p .816 .761 .802 r
F P
0 g
s
.57696 .53806 m .60696 .56262 L .58077 .57739 L p .721 .728 .856 r
F P
0 g
s
.58077 .57739 m .55668 .54959 L .57696 .53806 L p .721 .728 .856 r
F P
0 g
s
.42856 .54762 m .39229 .56132 L .3926 .53126 L p .519 .379 .63 r
F P
0 g
s
.3926 .53126 m .42872 .52429 L .42856 .54762 L p .519 .379 .63 r
F P
0 g
s
.3926 .46874 m .42872 .47571 L .42877 .5 L p .529 .446 .706 r
F P
0 g
s
.42872 .47571 m .3926 .46874 L .39229 .43868 L p .519 .469 .74 r
F P
0 g
s
.58077 .42261 m .55668 .45041 L .53562 .43831 L p .753 .495 .541 r
F P
0 g
s
.55668 .45041 m .58077 .42261 L .60696 .43738 L p .721 .449 .514 r
F P
0 g
s
.49448 .41432 m .50075 .37606 L .52663 .39136 L p .816 .571 .569 r
F P
0 g
s
.52663 .39136 m .51461 .42612 L .49448 .41432 L p .816 .571 .569 r
F P
0 g
s
.49273 .70075 m .47701 .63821 L .50075 .62394 L p .826 .702 .728 r
F P
0 g
s
.47701 .63821 m .49273 .70075 L .46808 .71642 L p .865 .723 .703 r
F P
0 g
s
.50853 .79438 m .46808 .71642 L .49273 .70075 L p .825 .624 .631 r
F P
0 g
s
.39114 .61322 m .32853 .63586 L .32978 .60668 L p .574 .348 .535 r
F P
0 g
s
.32978 .60668 m .3918 .58901 L .39114 .61322 L p .574 .348 .535 r
F P
0 g
s
.65248 .53767 m .70339 .58057 L .67749 .59408 L p .609 .635 .851 r
F P
0 g
s
.67749 .59408 m .63119 .5492 L .65248 .53767 L p .609 .635 .851 r
F P
0 g
s
.32978 .39332 m .3918 .41099 L .39229 .43868 L p .598 .568 .791 r
F P
0 g
s
.3918 .41099 m .32978 .39332 L .32853 .36414 L p .574 .589 .831 r
F P
0 g
s
.24079 .3602 m .32853 .36414 L .32978 .39332 L p .678 .673 .838 r
F P
0 g
s
.67749 .40592 m .63119 .4508 L .60696 .43738 L p .658 .43 .563 r
F P
0 g
s
.63119 .4508 m .67749 .40592 L .70339 .41943 L p .609 .36 .514 r
F P
0 g
s
.75068 .34542 m .70339 .41943 L .67749 .40592 L p .572 .398 .607 r
F P
0 g
s
.45638 .34911 m .46808 .28358 L .49273 .29925 L p .865 .69 .662 r
F P
0 g
s
.49273 .29925 m .47701 .36179 L .45638 .34911 L p .865 .69 .662 r
F P
0 g
s
.72472 .23449 m .7339 .17421 L .74992 .18211 L p .516 .516 .794 r
F P
0 g
s
.74992 .18211 m .7497 .24711 L .72472 .23449 L p .516 .516 .794 r
F P
0 g
s
.66519 .13454 m .61758 .17263 L .59416 .1573 L p .66 .701 .877 r
F P
0 g
s
.61758 .17263 m .66519 .13454 L .68166 .14487 L p .642 .663 .855 r
F P
0 g
s
.10091 .53967 m .1577 .56186 L .15614 .5898 L p .86 .634 .595 r
F P
0 g
s
.1577 .56186 m .10091 .53967 L .10162 .52024 L p .854 .658 .637 r
F P
0 g
s
.1577 .43814 m .10091 .46033 L .09974 .4425 L p .86 .77 .761 r
F P
0 g
s
.09974 .4425 m .15614 .4102 L .1577 .43814 L p .86 .77 .761 r
F P
0 g
s
.61758 .82737 m .66519 .86546 L .65034 .87538 L p .66 .377 .48 r
F P
0 g
s
.65034 .87538 m .59416 .8427 L .61758 .82737 L p .66 .377 .48 r
F P
0 g
s
.7339 .82579 m .72472 .76551 L .7497 .75289 L p .516 .327 .563 r
F P
0 g
s
.72472 .76551 m .7339 .82579 L .71672 .83488 L p .559 .357 .563 r
F P
0 g
s
.50075 .62394 m .49448 .58568 L .51461 .57388 L p .816 .761 .802 r
F P
0 g
s
.49448 .58568 m .50075 .62394 L .47701 .63821 L p .85 .782 .785 r
F P
0 g
s
.59565 .52757 m .63119 .5492 L .60696 .56262 L p .684 .725 .881 r
F P
0 g
s
.60696 .56262 m .57696 .53806 L .59565 .52757 L p .684 .725 .881 r
F P
0 g
s
.4283 .56905 m .3918 .58901 L .39229 .56132 L p .497 .327 .581 r
F P
0 g
s
.39229 .56132 m .42856 .54762 L .4283 .56905 L p .497 .327 .581 r
F P
0 g
s
.39229 .43868 m .42856 .45238 L .42872 .47571 L p .519 .469 .74 r
F P
0 g
s
.42856 .45238 m .39229 .43868 L .3918 .41099 L p .497 .484 .773 r
F P
0 g
s
.60696 .43738 m .57696 .46194 L .55668 .45041 L p .721 .449 .514 r
F P
0 g
s
.57696 .46194 m .60696 .43738 L .63119 .4508 L p .684 .392 .473 r
F P
0 g
s
.47605 .40338 m .47701 .36179 L .50075 .37606 L p .85 .606 .569 r
F P
0 g
s
.50075 .37606 m .49448 .41432 L .47605 .40338 L p .85 .606 .569 r
F P
0 g
s
.327 .65973 m .23841 .66441 L .24079 .6398 L p .657 .362 .46 r
F P
0 g
s
.24079 .6398 m .32853 .63586 L .327 .65973 L p .657 .362 .46 r
F P
0 g
s
.15402 .61423 m .24079 .6398 L .23841 .66441 L p .774 .468 .469 r
F P
0 g
s
.24079 .6398 m .15402 .61423 L .15614 .5898 L p .774 .519 .549 r
F P
0 g
s
.46808 .71642 m .50853 .79438 L .48841 .80875 L p .867 .632 .581 r
F P
0 g
s
.50853 .79438 m .57406 .85674 L .55813 .86893 L p .792 .492 .48 r
F P
0 g
s
.55813 .86893 m .48841 .80875 L .50853 .79438 L p .792 .492 .48 r
F P
0 g
s
.32853 .36414 m .24079 .3602 L .23841 .33559 L p .657 .711 .887 r
F P
0 g
s
.24079 .3602 m .15402 .38577 L .15143 .36588 L p .774 .796 .871 r
F P
0 g
s
.15143 .36588 m .23841 .33559 L .24079 .3602 L p .774 .796 .871 r
F P
0 g
s
.72483 .56996 m .77318 .64434 L .75068 .65458 L p .497 .505 .795 r
F P
0 g
s
.75068 .65458 m .70339 .58057 L .72483 .56996 L p .497 .505 .795 r
F P
0 g
s
.77192 .74251 m .75068 .65458 L .77318 .64434 L p .444 .372 .681 r
F P
0 g
s
.75068 .65458 m .77192 .74251 L .7497 .75289 L p .525 .424 .682 r
F P
0 g
s
.70339 .41943 m .75068 .34542 L .77318 .35566 L p .497 .307 .553 r
F P
0 g
s
.75068 .34542 m .77192 .25749 L .79043 .26519 L p .444 .354 .659 r
F P
0 g
s
.79043 .26519 m .77318 .35566 L .75068 .34542 L p .444 .354 .659 r
F P
0 g
s
.44817 .27032 m .48841 .19125 L .50853 .20562 L p .867 .783 .766 r
F P
0 g
s
.50853 .20562 m .46808 .28358 L .44817 .27032 L p .867 .783 .766 r
F P
0 g
s
.57406 .14326 m .50853 .20562 L .48841 .19125 L p .792 .802 .86 r
F P
0 g
s
.50853 .20562 m .57406 .14326 L .59416 .1573 L p .765 .742 .832 r
F P
0 g
s
.7497 .24711 m .74992 .18211 L .76412 .18849 L p .458 .466 .779 r
F P
0 g
s
.76412 .18849 m .77192 .25749 L .7497 .24711 L p .458 .466 .779 r
F P
0 g
s
.65034 .12462 m .59416 .1573 L .57406 .14326 L p .672 .743 .903 r
F P
0 g
s
.59416 .1573 m .65034 .12462 L .66519 .13454 L p .66 .701 .877 r
F P
0 g
s
.09974 .5575 m .15614 .5898 L .15402 .61423 L p .868 .608 .542 r
F P
0 g
s
.15614 .5898 m .09974 .5575 L .10091 .53967 L p .86 .634 .595 r
F P
0 g
s
.15614 .4102 m .09974 .4425 L .09817 .42702 L p .868 .81 .79 r
F P
0 g
s
.09817 .42702 m .15402 .38577 L .15614 .4102 L p .868 .81 .79 r
F P
0 g
s
.59416 .8427 m .65034 .87538 L .63771 .88449 L p .672 .355 .429 r
F P
0 g
s
.63771 .88449 m .57406 .85674 L .59416 .8427 L p .672 .355 .429 r
F P
0 g
s
.74992 .81789 m .7497 .75289 L .77192 .74251 L p .458 .281 .553 r
F P
0 g
s
.7497 .75289 m .74992 .81789 L .7339 .82579 L p .516 .327 .563 r
F P
0 g
s
.47701 .63821 m .47605 .59662 L .49448 .58568 L p .85 .782 .785 r
F P
0 g
s
.47605 .59662 m .47701 .63821 L .45638 .65089 L p .89 .811 .765 r
F P
0 g
s
.46808 .71642 m .45638 .65089 L .47701 .63821 L p .865 .723 .703 r
F P
0 g
s
.61199 .51853 m .65248 .53767 L .63119 .5492 L p .637 .724 .911 r
F P
0 g
s
.63119 .5492 m .59565 .52757 L .61199 .51853 L p .637 .724 .911 r
F P
0 g
s
.42795 .58772 m .39114 .61322 L .3918 .58901 L p .457 .254 .515 r
F P
0 g
s
.3918 .58901 m .4283 .56905 L .42795 .58772 L p .457 .254 .515 r
F P
0 g
s
.3918 .41099 m .4283 .43095 L .42856 .45238 L p .497 .484 .773 r
F P
0 g
s
.4283 .43095 m .3918 .41099 L .39114 .38678 L p .457 .492 .807 r
F P
0 g
s
.32853 .36414 m .39114 .38678 L .3918 .41099 L p .574 .589 .831 r
F P
0 g
s
.63119 .4508 m .59565 .47243 L .57696 .46194 L p .684 .392 .473 r
F P
0 g
s
.59565 .47243 m .63119 .4508 L .65248 .46233 L p .637 .316 .411 r
F P
0 g
s
.70339 .41943 m .65248 .46233 L .63119 .4508 L p .609 .36 .514 r
F P
0 g
s
.46006 .39375 m .45638 .34911 L .47701 .36179 L p .89 .642 .557 r
F P
0 g
s
.47701 .36179 m .47605 .40338 L .46006 .39375 L p .89 .642 .557 r
F P
0 g
s
.45638 .65089 m .46808 .71642 L .44817 .72968 L p .914 .751 .666 r
F P
0 g
s
.48841 .80875 m .44817 .72968 L .46808 .71642 L p .867 .632 .581 r
F P
0 g
s
.39032 .63292 m .327 .65973 L .32853 .63586 L p .528 .254 .444 r
F P
0 g
s
.32853 .63586 m .39114 .61322 L .39032 .63292 L p .528 .254 .444 r
F P
0 g
s
.66995 .52852 m .72483 .56996 L .70339 .58057 L p .539 .621 .883 r
F P
0 g
s
.70339 .58057 m .65248 .53767 L .66995 .52852 L p .539 .621 .883 r
F P
0 g
s
.39114 .38678 m .32853 .36414 L .327 .34027 L p .528 .608 .877 r
F P
0 g
s
.23841 .33559 m .327 .34027 L .32853 .36414 L p .657 .711 .887 r
F P
0 g
s
.65248 .46233 m .70339 .41943 L .72483 .43004 L p .539 .258 .437 r
F P
0 g
s
.77318 .35566 m .72483 .43004 L .70339 .41943 L p .497 .307 .553 r
F P
0 g
s
.43973 .33856 m .44817 .27032 L .46808 .28358 L p .914 .741 .654 r
F P
0 g
s
.46808 .28358 m .45638 .34911 L .43973 .33856 L p .914 .741 .654 r
F P
0 g
s
.52558 .5443 m .53562 .56169 L .51461 .57388 L p .799 .811 .861 r
F P
0 g
s
.54156 .53511 m .55668 .54959 L .53562 .56169 L p .769 .8 .878 r
F P
0 g
s
.53562 .56169 m .52558 .5443 L .54156 .53511 L p .769 .8 .878 r
F P
0 g
s
.44884 .5 m .42877 .5 L .42872 .47571 L p .433 .368 .685 r
F P
0 g
s
.44881 .51843 m .42872 .52429 L .42877 .5 L p .433 .339 .65 r
F P
0 g
s
.42877 .5 m .44884 .5 L .44881 .51843 L p .433 .339 .65 r
F P
0 g
s
.52558 .4557 m .53562 .43831 L .55668 .45041 L p .769 .455 .456 r
F P
0 g
s
.50963 .44645 m .51461 .42612 L .53562 .43831 L p .799 .494 .473 r
F P
0 g
s
.53562 .43831 m .52558 .4557 L .50963 .44645 L p .799 .494 .473 r
F P
0 g
s
.51461 .57388 m .50963 .55355 L .52558 .5443 L p .799 .811 .861 r
F P
0 g
s
.50963 .55355 m .51461 .57388 L .49448 .58568 L p .83 .827 .845 r
F P
0 g
s
.55692 .52635 m .57696 .53806 L .55668 .54959 L p .737 .795 .899 r
F P
0 g
s
.55668 .54959 m .54156 .53511 L .55692 .52635 L p .737 .795 .899 r
F P
0 g
s
.44872 .53612 m .42856 .54762 L .42872 .52429 L p .419 .299 .608 r
F P
0 g
s
.42872 .52429 m .44881 .51843 L .44872 .53612 L p .419 .299 .608 r
F P
0 g
s
.42872 .47571 m .44881 .48157 L .44884 .5 L p .433 .368 .685 r
F P
0 g
s
.44881 .48157 m .42872 .47571 L .42856 .45238 L p .419 .386 .716 r
F P
0 g
s
.49436 .43753 m .49448 .41432 L .51461 .42612 L p .83 .528 .479 r
F P
0 g
s
.51461 .42612 m .50963 .44645 L .49436 .43753 L p .83 .528 .479 r
F P
0 g
s
.55668 .45041 m .54156 .46489 L .52558 .4557 L p .769 .455 .456 r
F P
0 g
s
.54156 .46489 m .55668 .45041 L .57696 .46194 L p .737 .408 .425 r
F P
0 g
s
.49448 .58568 m .49436 .56247 L .50963 .55355 L p .83 .827 .845 r
F P
0 g
s
.49436 .56247 m .49448 .58568 L .47605 .59662 L p .862 .851 .83 r
F P
0 g
s
.57104 .51836 m .59565 .52757 L .57696 .53806 L p .7 .795 .924 r
F P
0 g
s
.57696 .53806 m .55692 .52635 L .57104 .51836 L p .7 .795 .924 r
F P
0 g
s
.44858 .55234 m .4283 .56905 L .42856 .54762 L p .389 .241 .557 r
F P
0 g
s
.42856 .54762 m .44872 .53612 L .44858 .55234 L p .389 .241 .557 r
F P
0 g
s
.42856 .45238 m .44872 .46388 L .44881 .48157 L p .419 .386 .716 r
F P
0 g
s
.44872 .46388 m .42856 .45238 L .4283 .43095 L p .389 .394 .744 r
F P
0 g
s
.57696 .46194 m .55692 .47365 L .54156 .46489 L p .737 .408 .425 r
F P
0 g
s
.55692 .47365 m .57696 .46194 L .59565 .47243 L p .7 .349 .377 r
F P
0 g
s
.48039 .4293 m .47605 .40338 L .49448 .41432 L p .862 .557 .47 r
F P
0 g
s
.49448 .41432 m .49436 .43753 L .48039 .4293 L p .862 .557 .47 r
F P
0 g
s
.77192 .25749 m .76412 .18849 L .77588 .19307 L p .374 .401 .76 r
F P
0 g
s
.77588 .19307 m .79043 .26519 L .77192 .25749 L p .374 .401 .76 r
F P
0 g
s
.48841 .19125 m .55813 .13107 L .57406 .14326 L p .792 .802 .86 r
F P
0 g
s
.63771 .11551 m .57406 .14326 L .55813 .13107 L p .677 .791 .935 r
F P
0 g
s
.57406 .14326 m .63771 .11551 L .65034 .12462 L p .672 .743 .903 r
F P
0 g
s
.23841 .66441 m .15143 .63412 L .15402 .61423 L p .774 .468 .469 r
F P
0 g
s
.09817 .57298 m .15402 .61423 L .15143 .63412 L p .879 .575 .468 r
F P
0 g
s
.15402 .61423 m .09817 .57298 L .09974 .5575 L p .868 .608 .542 r
F P
0 g
s
.15402 .38577 m .09817 .42702 L .09625 .41455 L p .879 .861 .818 r
F P
0 g
s
.09625 .41455 m .15143 .36588 L .15402 .38577 L p .879 .861 .818 r
F P
0 g
s
.57406 .85674 m .63771 .88449 L .62787 .89238 L p .677 .314 .351 r
F P
0 g
s
.62787 .89238 m .55813 .86893 L .57406 .85674 L p .677 .314 .351 r
F P
0 g
s
.77318 .64434 m .79043 .73481 L .77192 .74251 L p .444 .372 .681 r
F P
0 g
s
.76412 .81151 m .77192 .74251 L .79043 .73481 L p .374 .21 .526 r
F P
0 g
s
.77192 .74251 m .76412 .81151 L .74992 .81789 L p .458 .281 .553 r
F P
0 g
s
.45638 .65089 m .46006 .60625 L .47605 .59662 L p .89 .811 .765 r
F P
0 g
s
.46006 .60625 m .45638 .65089 L .43973 .66144 L p .934 .849 .735 r
F P
0 g
s
.44817 .72968 m .43973 .66144 L .45638 .65089 L p .914 .751 .666 r
F P
0 g
s
.62526 .51135 m .66995 .52852 L .65248 .53767 L p .568 .723 .946 r
F P
0 g
s
.65248 .53767 m .61199 .51853 L .62526 .51135 L p .568 .723 .946 r
F P
0 g
s
.42753 .60281 m .39032 .63292 L .39114 .61322 L p .385 .141 .418 r
F P
0 g
s
.39114 .61322 m .42795 .58772 L .42753 .60281 L p .385 .141 .418 r
F P
0 g
s
.39114 .38678 m .42795 .41228 L .4283 .43095 L p .457 .492 .807 r
F P
0 g
s
.42795 .41228 m .39114 .38678 L .39032 .36708 L p .385 .486 .84 r
F P
0 g
s
.327 .34027 m .39032 .36708 L .39114 .38678 L p .528 .608 .877 r
F P
0 g
s
.65248 .46233 m .61199 .48147 L .59565 .47243 L p .637 .316 .411 r
F P
0 g
s
.61199 .48147 m .65248 .46233 L .66995 .47148 L p .568 .205 .312 r
F P
0 g
s
.72483 .43004 m .66995 .47148 L .65248 .46233 L p .539 .258 .437 r
F P
0 g
s
.4472 .38584 m .43973 .33856 L .45638 .34911 L p .934 .676 .523 r
F P
0 g
s
.45638 .34911 m .46006 .39375 L .4472 .38584 L p .934 .676 .523 r
F P
0 g
s
.69907 .1552 m .71216 .13253 L .7213 .13765 L p .489 .599 .889 r
F P
0 g
s
.7213 .13765 m .71672 .16512 L .69907 .1552 L p .489 .599 .889 r
F P
0 g
s
.71216 .13253 m .69907 .1552 L .68166 .14487 L p .512 .628 .902 r
F P
0 g
s
.10186 .5 m .07568 .5 L .07555 .48952 L p .934 .773 .658 r
F P
0 g
s
.07555 .48952 m .10162 .47976 L .10186 .5 L p .934 .773 .658 r
F P
0 g
s
.07568 .5 m .10186 .5 L .10162 .52024 L p .934 .752 .632 r
F P
0 g
s
.69907 .8448 m .71216 .86747 L .70315 .87282 L p .512 .208 .388 r
F P
0 g
s
.70315 .87282 m .68166 .85513 L .69907 .8448 L p .512 .208 .388 r
F P
0 g
s
.71216 .86747 m .69907 .8448 L .71672 .83488 L p .489 .2 .401 r
F P
0 g
s
.71672 .16512 m .7213 .13765 L .73019 .14233 L p .458 .568 .878 r
F P
0 g
s
.73019 .14233 m .7339 .17421 L .71672 .16512 L p .458 .568 .878 r
F P
0 g
s
.70315 .12718 m .68166 .14487 L .66519 .13454 L p .526 .656 .917 r
F P
0 g
s
.68166 .14487 m .70315 .12718 L .71216 .13253 L p .512 .628 .902 r
F P
0 g
s
.10162 .47976 m .07555 .48952 L .07516 .47949 L p .938 .798 .68 r
F P
0 g
s
.07516 .47949 m .10091 .46033 L .10162 .47976 L p .938 .798 .68 r
F P
0 g
s
.07555 .51048 m .10162 .52024 L .10091 .53967 L p .938 .733 .601 r
F P
0 g
s
.10162 .52024 m .07555 .51048 L .07568 .5 L p .934 .752 .632 r
F P
0 g
s
.68166 .85513 m .70315 .87282 L .69466 .87818 L p .526 .203 .363 r
F P
0 g
s
.69466 .87818 m .66519 .86546 L .68166 .85513 L p .526 .203 .363 r
F P
0 g
s
.7213 .86235 m .71672 .83488 L .7339 .82579 L p .458 .18 .403 r
F P
0 g
s
.71672 .83488 m .7213 .86235 L .71216 .86747 L p .489 .2 .401 r
F P
0 g
s
.47605 .59662 m .48039 .5707 L .49436 .56247 L p .862 .851 .83 r
F P
0 g
s
.48039 .5707 m .47605 .59662 L .46006 .60625 L p .896 .882 .812 r
F P
0 g
s
.58331 .5115 m .61199 .51853 L .59565 .52757 L p .653 .798 .952 r
F P
0 g
s
.59565 .52757 m .57104 .51836 L .58331 .5115 L p .653 .798 .952 r
F P
0 g
s
.44839 .5664 m .42795 .58772 L .4283 .56905 L p .334 .158 .487 r
F P
0 g
s
.4283 .56905 m .44858 .55234 L .44839 .5664 L p .334 .158 .487 r
F P
0 g
s
.4283 .43095 m .44858 .44766 L .44872 .46388 L p .389 .394 .744 r
F P
0 g
s
.44858 .44766 m .4283 .43095 L .42795 .41228 L p .334 .387 .768 r
F P
0 g
s
.4683 .4221 m .46006 .39375 L .47605 .40338 L p .896 .581 .443 r
F P
0 g
s
.47605 .40338 m .48039 .4293 L .4683 .4221 L p .896 .581 .443 r
F P
0 g
s
.59565 .47243 m .57104 .48164 L .55692 .47365 L p .7 .349 .377 r
F P
0 g
s
.57104 .48164 m .59565 .47243 L .61199 .48147 L p .653 .268 .303 r
F P
0 g
s
.32524 .67719 m .23567 .68244 L .23841 .66441 L p .611 .241 .317 r
F P
0 g
s
.23841 .66441 m .327 .65973 L .32524 .67719 L p .611 .241 .317 r
F P
0 g
s
.15143 .63412 m .23841 .66441 L .23567 .68244 L p .764 .386 .339 r
F P
0 g
s
.44817 .72968 m .48841 .80875 L .47416 .82014 L p .917 .635 .493 r
F P
0 g
s
.48841 .80875 m .55813 .86893 L .54713 .87871 L p .816 .453 .369 r
F P
0 g
s
.54713 .87871 m .47416 .82014 L .48841 .80875 L p .816 .453 .369 r
F P
0 g
s
.327 .34027 m .23841 .33559 L .23567 .31756 L p .611 .757 .948 r
F P
0 g
s
.23841 .33559 m .15143 .36588 L .14846 .35146 L p .764 .861 .922 r
F P
0 g
s
.14846 .35146 m .23567 .31756 L .23841 .33559 L p .764 .861 .922 r
F P
0 g
s
.72483 .43004 m .77318 .35566 L .79017 .36231 L p .37 .158 .456 r
F P
0 g
s
.77318 .35566 m .79043 .26519 L .80441 .26983 L p .312 .23 .6 r
F P
0 g
s
.80441 .26983 m .79017 .36231 L .77318 .35566 L p .312 .23 .6 r
F P
0 g
s
.43393 .26006 m .47416 .17986 L .48841 .19125 L p .917 .862 .772 r
F P
0 g
s
.48841 .19125 m .44817 .27032 L .43393 .26006 L p .917 .862 .772 r
F P
0 g
s
.55813 .13107 m .48841 .19125 L .47416 .17986 L p .816 .879 .891 r
F P
0 g
s
.74083 .56275 m .79017 .63769 L .77318 .64434 L p .37 .446 .809 r
F P
0 g
s
.77318 .64434 m .72483 .56996 L .74083 .56275 L p .37 .446 .809 r
F P
0 g
s
.79043 .73481 m .77318 .64434 L .79017 .63769 L p .312 .279 .661 r
F P
0 g
s
.43973 .66144 m .44817 .72968 L .43393 .73994 L p .969 .783 .597 r
F P
0 g
s
.47416 .82014 m .43393 .73994 L .44817 .72968 L p .917 .635 .493 r
F P
0 g
s
.38939 .6472 m .32524 .67719 L .327 .65973 L p .435 .095 .289 r
F P
0 g
s
.327 .65973 m .39032 .63292 L .38939 .6472 L p .435 .095 .289 r
F P
0 g
s
.68278 .52219 m .74083 .56275 L .72483 .56996 L p .418 .593 .916 r
F P
0 g
s
.72483 .56996 m .66995 .52852 L .68278 .52219 L p .418 .593 .916 r
F P
0 g
s
.39032 .36708 m .327 .34027 L .32524 .32281 L p .435 .616 .926 r
F P
0 g
s
.23567 .31756 m .32524 .32281 L .327 .34027 L p .611 .757 .948 r
F P
0 g
s
.66995 .47148 m .72483 .43004 L .74083 .43725 L p .418 .089 .299 r
F P
0 g
s
.79017 .36231 m .74083 .43725 L .72483 .43004 L p .37 .158 .456 r
F P
0 g
s
.42783 .33061 m .43393 .26006 L .44817 .27032 L p .969 .8 .618 r
F P
0 g
s
.44817 .27032 m .43973 .33856 L .42783 .33061 L p .969 .8 .618 r
F P
0 g
s
.7339 .17421 m .73019 .14233 L .73845 .14636 L p .415 .533 .868 r
F P
0 g
s
.73845 .14636 m .74992 .18211 L .7339 .17421 L p .415 .533 .868 r
F P
0 g
s
.69466 .12182 m .66519 .13454 L .65034 .12462 L p .532 .684 .936 r
F P
0 g
s
.66519 .13454 m .69466 .12182 L .70315 .12718 L p .526 .656 .917 r
F P
0 g
s
.07516 .52051 m .10091 .53967 L .09974 .5575 L p .944 .715 .563 r
F P
0 g
s
.10091 .53967 m .07516 .52051 L .07555 .51048 L p .938 .733 .601 r
F P
0 g
s
.10091 .46033 m .07516 .47949 L .07452 .47031 L p .944 .826 .698 r
F P
0 g
s
.07452 .47031 m .09974 .4425 L .10091 .46033 L p .944 .826 .698 r
F P
0 g
s
.66519 .86546 m .69466 .87818 L .68703 .88332 L p .532 .185 .325 r
F P
0 g
s
.68703 .88332 m .65034 .87538 L .66519 .86546 L p .532 .185 .325 r
F P
0 g
s
.73019 .85767 m .7339 .82579 L .74992 .81789 L p .415 .145 .392 r
F P
0 g
s
.7339 .82579 m .73019 .85767 L .7213 .86235 L p .458 .18 .403 r
F P
0 g
s
.51986 .53439 m .52558 .5443 L .50963 .55355 L p .805 .862 .891 r
F P
0 g
s
.53198 .52741 m .54156 .53511 L .52558 .5443 L p .775 .852 .908 r
F P
0 g
s
.52558 .5443 m .51986 .53439 L .53198 .52741 L p .775 .852 .908 r
F P
0 g
s
.46029 .5 m .44884 .5 L .44881 .48157 L p .341 .292 .657 r
F P
0 g
s
.46027 .51399 m .44881 .51843 L .44884 .5 L p .341 .265 .624 r
F P
0 g
s
.44884 .5 m .46029 .5 L .46027 .51399 L p .341 .265 .624 r
F P
0 g
s
.51986 .46561 m .52558 .4557 L .54156 .46489 L p .775 .415 .373 r
F P
0 g
s
.50775 .4586 m .50963 .44645 L .52558 .4557 L p .805 .452 .39 r
F P
0 g
s
.52558 .4557 m .51986 .46561 L .50775 .4586 L p .805 .452 .39 r
F P
0 g
s
.50963 .55355 m .50775 .5414 L .51986 .53439 L p .805 .862 .891 r
F P
0 g
s
.50775 .5414 m .50963 .55355 L .49436 .56247 L p .833 .878 .876 r
F P
0 g
s
.54363 .52075 m .55692 .52635 L .54156 .53511 L p .744 .847 .928 r
F P
0 g
s
.54156 .53511 m .53198 .52741 L .54363 .52075 L p .744 .847 .928 r
F P
0 g
s
.46021 .52741 m .44872 .53612 L .44881 .51843 L p .324 .223 .582 r
F P
0 g
s
.44881 .51843 m .46027 .51399 L .46021 .52741 L p .324 .223 .582 r
F P
0 g
s
.44881 .48157 m .46027 .48601 L .46029 .5 L p .341 .292 .657 r
F P
0 g
s
.46027 .48601 m .44881 .48157 L .44872 .46388 L p .324 .307 .685 r
F P
0 g
s
.49616 .45184 m .49436 .43753 L .50963 .44645 L p .833 .482 .391 r
F P
0 g
s
.50963 .44645 m .50775 .4586 L .49616 .45184 L p .833 .482 .391 r
F P
0 g
s
.54156 .46489 m .53198 .47259 L .51986 .46561 L p .775 .415 .373 r
F P
0 g
s
.53198 .47259 m .54156 .46489 L .55692 .47365 L p .744 .367 .34 r
F P
0 g
s
.49436 .56247 m .49616 .54816 L .50775 .5414 L p .833 .878 .876 r
F P
0 g
s
.49616 .54816 m .49436 .56247 L .48039 .5707 L p .861 .901 .861 r
F P
0 g
s
.5543 .51469 m .57104 .51836 L .55692 .52635 L p .706 .848 .95 r
F P
0 g
s
.55692 .52635 m .54363 .52075 L .5543 .51469 L p .706 .848 .95 r
F P
0 g
s
.46012 .53968 m .44858 .55234 L .44872 .53612 L p .287 .161 .529 r
F P
0 g
s
.44872 .53612 m .46021 .52741 L .46012 .53968 L p .287 .161 .529 r
F P
0 g
s
.44872 .46388 m .46021 .47259 L .46027 .48601 L p .324 .307 .685 r
F P
0 g
s
.46021 .47259 m .44872 .46388 L .44858 .44766 L p .287 .307 .708 r
F P
0 g
s
.55692 .47365 m .54363 .47925 L .53198 .47259 L p .744 .367 .34 r
F P
0 g
s
.54363 .47925 m .55692 .47365 L .57104 .48164 L p .706 .306 .286 r
F P
0 g
s
.48557 .44563 m .48039 .4293 L .49436 .43753 L p .861 .505 .376 r
F P
0 g
s
.49436 .43753 m .49616 .45184 L .48557 .44563 L p .861 .505 .376 r
F P
0 g
s
.74992 .18211 m .73845 .14636 L .74574 .14958 L p .357 .492 .858 r
F P
0 g
s
.74574 .14958 m .76412 .18849 L .74992 .18211 L p .357 .492 .858 r
F P
0 g
s
.68703 .11668 m .65034 .12462 L .63771 .11551 L p .527 .711 .956 r
F P
0 g
s
.65034 .12462 m .68703 .11668 L .69466 .12182 L p .532 .684 .936 r
F P
0 g
s
.07452 .52969 m .09974 .5575 L .09817 .57298 L p .952 .697 .514 r
F P
0 g
s
.09974 .5575 m .07452 .52969 L .07516 .52051 L p .944 .715 .563 r
F P
0 g
s
.09974 .4425 m .07452 .47031 L .07365 .46239 L p .952 .858 .71 r
F P
0 g
s
.07365 .46239 m .09817 .42702 L .09974 .4425 L p .952 .858 .71 r
F P
0 g
s
.65034 .87538 m .68703 .88332 L .6806 .88803 L p .527 .149 .268 r
F P
0 g
s
.6806 .88803 m .63771 .88449 L .65034 .87538 L p .527 .149 .268 r
F P
0 g
s
.73845 .85364 m .74992 .81789 L .76412 .81151 L p .357 .091 .366 r
F P
0 g
s
.74992 .81789 m .73845 .85364 L .73019 .85767 L p .415 .145 .392 r
F P
0 g
s
.46006 .60625 m .4683 .5779 L .48039 .5707 L p .896 .882 .812 r
F P
0 g
s
.4683 .5779 m .46006 .60625 L .4472 .61416 L p .929 .922 .783 r
F P
0 g
s
.43973 .66144 m .4472 .61416 L .46006 .60625 L p .934 .849 .735 r
F P
0 g
s
.59323 .50604 m .62526 .51135 L .61199 .51853 L p .584 .802 .983 r
F P
0 g
s
.61199 .51853 m .58331 .5115 L .59323 .50604 L p .584 .802 .983 r
F P
0 g
s
.44816 .57772 m .42753 .60281 L .42795 .58772 L p .239 .032 .385 r
F P
0 g
s
.42795 .58772 m .44839 .5664 L .44816 .57772 L p .239 .032 .385 r
F P
0 g
s
.42795 .41228 m .44839 .4336 L .44858 .44766 L p .334 .387 .768 r
F P
0 g
s
.44839 .4336 m .42795 .41228 L .42753 .39719 L p .239 .358 .783 r
F P
0 g
s
.39032 .36708 m .42753 .39719 L .42795 .41228 L p .385 .486 .84 r
F P
0 g
s
.61199 .48147 m .58331 .4885 L .57104 .48164 L p .653 .268 .303 r
F P
0 g
s
.58331 .4885 m .61199 .48147 L .62526 .48865 L p .584 .151 .185 r
F P
0 g
s
.66995 .47148 m .62526 .48865 L .61199 .48147 L p .568 .205 .312 r
F P
0 g
s
.45862 .41624 m .4472 .38584 L .46006 .39375 L p .929 .596 .385 r
F P
0 g
s
.46006 .39375 m .4683 .4221 L .45862 .41624 L p .929 .596 .385 r
F P
0 g
s
.79043 .26519 m .77588 .19307 L .78468 .19563 L p .243 .304 .727 r
F P
0 g
s
.78468 .19563 m .80441 .26983 L .79043 .26519 L p .243 .304 .727 r
F P
0 g
s
.47416 .17986 m .54713 .12129 L .55813 .13107 L p .816 .879 .891 r
F P
0 g
s
.62787 .10762 m .55813 .13107 L .54713 .12129 L p .663 .845 .97 r
F P
0 g
s
.55813 .13107 m .62787 .10762 L .63771 .11551 L p .677 .791 .935 r
F P
0 g
s
.23567 .68244 m .14846 .64854 L .15143 .63412 L p .764 .386 .339 r
F P
0 g
s
.09625 .58545 m .15143 .63412 L .14846 .64854 L p .888 .527 .355 r
F P
0 g
s
.15143 .63412 m .09625 .58545 L .09817 .57298 L p .879 .575 .468 r
F P
0 g
s
.15143 .36588 m .09625 .41455 L .09407 .40565 L p .888 .923 .84 r
F P
0 g
s
.09407 .40565 m .14846 .35146 L .15143 .36588 L p .888 .923 .84 r
F P
0 g
s
.55813 .86893 m .62787 .89238 L .62126 .89872 L p .663 .237 .225 r
F P
0 g
s
.62126 .89872 m .54713 .87871 L .55813 .86893 L p .663 .237 .225 r
F P
0 g
s
.79017 .63769 m .80441 .73017 L .79043 .73481 L p .312 .279 .661 r
F P
0 g
s
.77588 .80693 m .79043 .73481 L .80441 .73017 L p .243 .092 .468 r
F P
0 g
s
.79043 .73481 m .77588 .80693 L .76412 .81151 L p .374 .21 .526 r
F P
0 g
s
.4472 .61416 m .43973 .66144 L .42783 .66939 L p .976 .893 .676 r
F P
0 g
s
.43393 .73994 m .42783 .66939 L .43973 .66144 L p .969 .783 .597 r
F P
0 g
s
.63488 .50635 m .68278 .52219 L .66995 .52852 L p .451 .712 .979 r
F P
0 g
s
.66995 .52852 m .62526 .51135 L .63488 .50635 L p .451 .712 .979 r
F P
0 g
s
.42706 .61363 m .38939 .6472 L .39032 .63292 L p .248 0 .256 r
F P
0 g
s
.39032 .63292 m .42753 .60281 L .42706 .61363 L p .248 0 .256 r
F P
0 g
s
.42753 .39719 m .39032 .36708 L .38939 .3528 L p .248 .45 .861 r
F P
0 g
s
.32524 .32281 m .38939 .3528 L .39032 .36708 L p .435 .616 .926 r
F P
0 g
s
.62526 .48865 m .66995 .47148 L .68278 .47781 L p .451 .026 .138 r
F P
0 g
s
.74083 .43725 m .68278 .47781 L .66995 .47148 L p .418 .089 .299 r
F P
0 g
s
.43806 .38001 m .42783 .33061 L .43973 .33856 L p .976 .701 .441 r
F P
0 g
s
.43973 .33856 m .4472 .38584 L .43806 .38001 L p .976 .701 .441 r
F P
0 g
s
.48039 .5707 m .48557 .55437 L .49616 .54816 L p .861 .901 .861 r
F P
0 g
s
.48557 .55437 m .48039 .5707 L .4683 .5779 L p .888 .931 .841 r
F P
0 g
s
.56356 .50948 m .58331 .5115 L .57104 .51836 L p .658 .852 .974 r
F P
0 g
s
.57104 .51836 m .5543 .51469 L .56356 .50948 L p .658 .852 .974 r
F P
0 g
s
.46001 .55031 m .44839 .5664 L .44858 .55234 L p .221 .072 .456 r
F P
0 g
s
.44858 .55234 m .46012 .53968 L .46001 .55031 L p .221 .072 .456 r
F P
0 g
s
.44858 .44766 m .46012 .46032 L .46021 .47259 L p .287 .307 .708 r
F P
0 g
s
.46012 .46032 m .44858 .44766 L .44839 .4336 L p .221 .289 .722 r
F P
0 g
s
.57104 .48164 m .5543 .48531 L .54363 .47925 L p .706 .306 .286 r
F P
0 g
s
.5543 .48531 m .57104 .48164 L .58331 .4885 L p .658 .222 .203 r
F P
0 g
s
.47643 .44021 m .4683 .4221 L .48039 .4293 L p .888 .519 .336 r
F P
0 g
s
.48039 .4293 m .48557 .44563 L .47643 .44021 L p .888 .519 .336 r
F P
0 g
s
.51637 .52835 m .51986 .53439 L .50775 .5414 L p .804 .895 .908 r
F P
0 g
s
.52567 .52299 m .53198 .52741 L .51986 .53439 L p .775 .885 .925 r
F P
0 g
s
.51986 .53439 m .51637 .52835 L .52567 .52299 L p .775 .885 .925 r
F P
0 g
s
.46727 .5 m .46029 .5 L .46027 .48601 L p .269 .233 .632 r
F P
0 g
s
.46725 .51073 m .46027 .51399 L .46029 .5 L p .269 .206 .6 r
F P
0 g
s
.46029 .5 m .46727 .5 L .46725 .51073 L p .269 .206 .6 r
F P
0 g
s
.51637 .47165 m .51986 .46561 L .53198 .47259 L p .775 .381 .307 r
F P
0 g
s
.50708 .46628 m .50775 .4586 L .51986 .46561 L p .804 .417 .324 r
F P
0 g
s
.51986 .46561 m .51637 .47165 L .50708 .46628 L p .804 .417 .324 r
F P
0 g
s
.76412 .18849 m .74574 .14958 L .75174 .15184 L p .277 .441 .844 r
F P
0 g
s
.75174 .15184 m .77588 .19307 L .76412 .18849 L p .277 .441 .844 r
F P
0 g
s
.6806 .11197 m .63771 .11551 L .62787 .10762 L p .506 .736 .977 r
F P
0 g
s
.63771 .11551 m .6806 .11197 L .68703 .11668 L p .527 .711 .956 r
F P
0 g
s
.07365 .53761 m .09817 .57298 L .09625 .58545 L p .961 .677 .449 r
F P
0 g
s
.09817 .57298 m .07365 .53761 L .07452 .52969 L p .952 .697 .514 r
F P
0 g
s
.09817 .42702 m .07365 .46239 L .07261 .45606 L p .961 .893 .714 r
F P
0 g
s
.07261 .45606 m .09625 .41455 L .09817 .42702 L p .961 .893 .714 r
F P
0 g
s
.63771 .88449 m .6806 .88803 L .67565 .8921 L p .506 .091 .186 r
F P
0 g
s
.67565 .8921 m .62787 .89238 L .63771 .88449 L p .506 .091 .186 r
F P
0 g
s
.74574 .85042 m .76412 .81151 L .77588 .80693 L p .277 .011 .319 r
F P
0 g
s
.76412 .81151 m .74574 .85042 L .73845 .85364 L p .357 .091 .366 r
F P
0 g
s
.53459 .51789 m .54363 .52075 L .53198 .52741 L p .744 .881 .943 r
F P
0 g
s
.53198 .52741 m .52567 .52299 L .53459 .51789 L p .744 .881 .943 r
F P
0 g
s
.50775 .5414 m .50708 .53372 L .51637 .52835 L p .804 .895 .908 r
F P
0 g
s
.50708 .53372 m .50775 .5414 L .49616 .54816 L p .83 .91 .893 r
F P
0 g
s
.46722 .52101 m .46021 .52741 L .46027 .51399 L p .25 .163 .558 r
F P
0 g
s
.46027 .51399 m .46725 .51073 L .46722 .52101 L p .25 .163 .558 r
F P
0 g
s
.46027 .48601 m .46725 .48927 L .46727 .5 L p .269 .233 .632 r
F P
0 g
s
.46725 .48927 m .46027 .48601 L .46021 .47259 L p .25 .245 .658 r
F P
0 g
s
.53198 .47259 m .52567 .47701 L .51637 .47165 L p .775 .381 .307 r
F P
0 g
s
.52567 .47701 m .53198 .47259 L .54363 .47925 L p .744 .334 .273 r
F P
0 g
s
.4982 .4611 m .49616 .45184 L .50775 .4586 L p .83 .445 .323 r
F P
0 g
s
.50775 .4586 m .50708 .46628 L .4982 .4611 L p .83 .445 .323 r
F P
0 g
s
.49616 .54816 m .4982 .5389 L .50708 .53372 L p .83 .91 .893 r
F P
0 g
s
.4982 .5389 m .49616 .54816 L .48557 .55437 L p .854 .932 .877 r
F P
0 g
s
.54276 .51324 m .5543 .51469 L .54363 .52075 L p .706 .881 .962 r
F P
0 g
s
.54363 .52075 m .53459 .51789 L .54276 .51324 L p .706 .881 .962 r
F P
0 g
s
.46716 .53041 m .46012 .53968 L .46021 .52741 L p .208 .1 .503 r
F P
0 g
s
.46021 .52741 m .46722 .52101 L .46716 .53041 L p .208 .1 .503 r
F P
0 g
s
.46021 .47259 m .46722 .47899 L .46725 .48927 L p .25 .245 .658 r
F P
0 g
s
.46722 .47899 m .46021 .47259 L .46012 .46032 L p .208 .24 .675 r
F P
0 g
s
.54363 .47925 m .53459 .48211 L .52567 .47701 L p .744 .334 .273 r
F P
0 g
s
.53459 .48211 m .54363 .47925 L .5543 .48531 L p .706 .271 .216 r
F P
0 g
s
.49009 .45635 m .48557 .44563 L .49616 .45184 L p .854 .463 .302 r
F P
0 g
s
.49616 .45184 m .4982 .4611 L .49009 .45635 L p .854 .463 .302 r
F P
0 g
s
.4683 .5779 m .47643 .55979 L .48557 .55437 L p .888 .931 .841 r
F P
0 g
s
.47643 .55979 m .4683 .5779 L .45862 .58376 L p .907 .965 .809 r
F P
0 g
s
.4472 .61416 m .45862 .58376 L .4683 .5779 L p .929 .922 .783 r
F P
0 g
s
.571 .50535 m .59323 .50604 L .58331 .5115 L p .587 .854 .994 r
F P
0 g
s
.58331 .5115 m .56356 .50948 L .571 .50535 L p .587 .854 .994 r
F P
0 g
s
.45987 .55882 m .44816 .57772 L .44839 .5664 L p .112 0 .35 r
F P
0 g
s
.44839 .5664 m .46001 .55031 L .45987 .55882 L p .112 0 .35 r
F P
0 g
s
.44839 .4336 m .46001 .44969 L .46012 .46032 L p .221 .289 .722 r
F P
0 g
s
.46001 .44969 m .44839 .4336 L .44816 .42228 L p .112 .242 .72 r
F P
0 g
s
.42753 .39719 m .44816 .42228 L .44839 .4336 L p .239 .358 .783 r
F P
0 g
s
.46913 .43584 m .45862 .41624 L .4683 .4221 L p .907 .517 .261 r
F P
0 g
s
.4683 .4221 m .47643 .44021 L .46913 .43584 L p .907 .517 .261 r
F P
0 g
s
.58331 .4885 m .56356 .49052 L .5543 .48531 L p .658 .222 .203 r
F P
0 g
s
.56356 .49052 m .58331 .4885 L .59323 .49396 L p .587 .104 .076 r
F P
0 g
s
.62526 .48865 m .59323 .49396 L .58331 .4885 L p .584 .151 .185 r
F P
0 g
s
.45862 .58376 m .4472 .61416 L .43806 .61999 L p .945 .958 .724 r
F P
0 g
s
.42783 .66939 m .43806 .61999 L .4472 .61416 L p .976 .893 .676 r
F P
0 g
s
.60033 .50224 m .63488 .50635 L .62526 .51135 L p .469 .794 .999 r
F P
0 g
s
.62526 .51135 m .59323 .50604 L .60033 .50224 L p .469 .794 .999 r
F P
0 g
s
.44789 .58577 m .42706 .61363 L .42753 .60281 L p .074 0 .221 r
F P
0 g
s
.42753 .60281 m .44816 .57772 L .44789 .58577 L p .074 0 .221 r
F P
0 g
s
.44816 .42228 m .42753 .39719 L .42706 .38637 L p .074 .285 .771 r
F P
0 g
s
.38939 .3528 m .42706 .38637 L .42753 .39719 L p .248 .45 .861 r
F P
0 g
s
.59323 .49396 m .62526 .48865 L .63488 .49365 L p .469 0 0 r
F P
0 g
s
.68278 .47781 m .63488 .49365 L .62526 .48865 L p .451 .026 .138 r
F P
0 g
s
.45178 .41199 m .43806 .38001 L .4472 .38584 L p .945 .586 .268 r
F P
0 g
s
.4472 .38584 m .45862 .41624 L .45178 .41199 L p .945 .586 .268 r
F P
0 g
s
.32332 .68733 m .23267 .69294 L .23567 .68244 L p .482 0 .028 r
F P
0 g
s
.23567 .68244 m .32524 .67719 L .32332 .68733 L p .482 0 .028 r
F P
0 g
s
.14846 .64854 m .23567 .68244 L .23267 .69294 L p .711 .226 .091 r
F P
0 g
s
.43393 .73994 m .47416 .82014 L .46657 .82798 L p .949 .599 .297 r
F P
0 g
s
.47416 .82014 m .54713 .87871 L .54163 .88562 L p .809 .352 .147 r
F P
0 g
s
.54163 .88562 m .46657 .82798 L .47416 .82014 L p .809 .352 .147 r
F P
0 g
s
.42611 .25332 m .46657 .17202 L .47416 .17986 L p .949 .951 .729 r
F P
0 g
s
.47416 .17986 m .43393 .26006 L .42611 .25332 L p .949 .951 .729 r
F P
0 g
s
.54713 .12129 m .47416 .17986 L .46657 .17202 L p .809 .97 .904 r
F P
0 g
s
.75057 .55935 m .80076 .63504 L .79017 .63769 L p .108 .308 .783 r
F P
0 g
s
.79017 .63769 m .74083 .56275 L .75057 .55935 L p .108 .308 .783 r
F P
0 g
s
.80441 .73017 m .79017 .63769 L .80076 .63504 L p .056 .092 .582 r
F P
0 g
s
.74083 .43725 m .79017 .36231 L .80076 .36496 L p .108 0 .244 r
F P
0 g
s
.79017 .36231 m .80441 .26983 L .81315 .27114 L p .056 0 .469 r
F P
0 g
s
.81315 .27114 m .80076 .36496 L .79017 .36231 L p .056 0 .469 r
F P
0 g
s
.32524 .32281 m .23567 .31756 L .23267 .30706 L p .482 .79 .999 r
F P
0 g
s
.23567 .31756 m .14846 .35146 L .14522 .34324 L p .711 .936 .961 r
F P
0 g
s
.14522 .34324 m .23267 .30706 L .23567 .31756 L p .711 .936 .961 r
F P
0 g
s
.42783 .66939 m .43393 .73994 L .42611 .74668 L p .997 .789 .432 r
F P
0 g
s
.46657 .82798 m .42611 .74668 L .43393 .73994 L p .949 .599 .297 r
F P
0 g
s
.38838 .65533 m .32332 .68733 L .32524 .67719 L p .221 0 0 r
F P
0 g
s
.32524 .67719 m .38939 .6472 L .38838 .65533 L p .221 0 0 r
F P
0 g
s
.69033 .519 m .75057 .55935 L .74083 .56275 L p .169 .503 .91 r
F P
0 g
s
.74083 .56275 m .68278 .52219 L .69033 .519 L p .169 .503 .91 r
F P
0 g
s
.38939 .3528 m .32524 .32281 L .32332 .31267 L p .221 .571 .94 r
F P
0 g
s
.23267 .30706 m .32332 .31267 L .32524 .32281 L p .482 .79 .999 r
F P
0 g
s
.68278 .47781 m .74083 .43725 L .75057 .44065 L p .169 0 .015 r
F P
0 g
s
.80076 .36496 m .75057 .44065 L .74083 .43725 L p .108 0 .244 r
F P
0 g
s
.42129 .32567 m .42611 .25332 L .43393 .26006 L p .997 .838 .493 r
F P
0 g
s
.43393 .26006 m .42783 .33061 L .42129 .32567 L p .997 .838 .493 r
F P
0 g
s
.48557 .55437 m .49009 .54365 L .4982 .5389 L p .854 .932 .877 r
F P
0 g
s
.49009 .54365 m .48557 .55437 L .47643 .55979 L p .874 .959 .855 r
F P
0 g
s
.54982 .50925 m .56356 .50948 L .5543 .51469 L p .656 .883 .981 r
F P
0 g
s
.5543 .51469 m .54276 .51324 L .54982 .50925 L p .656 .883 .981 r
F P
0 g
s
.46708 .53853 m .46001 .55031 L .46012 .53968 L p .136 .008 .429 r
F P
0 g
s
.46012 .53968 m .46716 .53041 L .46708 .53853 L p .136 .008 .429 r
F P
0 g
s
.46012 .46032 m .46716 .46959 L .46722 .47899 L p .208 .24 .675 r
F P
0 g
s
.46716 .46959 m .46012 .46032 L .46001 .44969 L p .136 .214 .682 r
F P
0 g
s
.5543 .48531 m .54276 .48676 L .53459 .48211 L p .706 .271 .216 r
F P
0 g
s
.54276 .48676 m .5543 .48531 L .56356 .49052 L p .656 .187 .129 r
F P
0 g
s
.4831 .45223 m .47643 .44021 L .48557 .44563 L p .874 .469 .255 r
F P
0 g
s
.48557 .44563 m .49009 .45635 L .4831 .45223 L p .874 .469 .255 r
F P
0 g
s
.51405 .52433 m .51637 .52835 L .50708 .53372 L p .801 .911 .915 r
F P
0 g
s
.52128 .52016 m .52567 .52299 L .51637 .52835 L p .773 .901 .931 r
F P
0 g
s
.51637 .52835 m .51405 .52433 L .52128 .52016 L p .773 .901 .931 r
F P
0 g
s
.47191 .5 m .46727 .5 L .46725 .48927 L p .228 .199 .617 r
F P
0 g
s
.4719 .50835 m .46725 .51073 L .46727 .5 L p .228 .173 .585 r
F P
0 g
s
.46727 .5 m .47191 .5 L .4719 .50835 L p .228 .173 .585 r
F P
0 g
s
.51405 .47567 m .51637 .47165 L .52567 .47701 L p .773 .361 .27 r
F P
0 g
s
.50682 .47149 m .50708 .46628 L .51637 .47165 L p .801 .397 .286 r
F P
0 g
s
.51637 .47165 m .51405 .47567 L .50682 .47149 L p .801 .397 .286 r
F P
0 g
s
.71216 .13253 m .71683 .12445 L .72066 .12659 L p .331 .575 .93 r
F P
0 g
s
.72066 .12659 m .7213 .13765 L .71216 .13253 L p .331 .575 .93 r
F P
0 g
s
.71683 .12445 m .71216 .13253 L .70315 .12718 L p .347 .595 .939 r
F P
0 g
s
.07568 .5 m .06635 .5 L .06629 .4956 L p .993 .818 .566 r
F P
0 g
s
.06629 .4956 m .07555 .48952 L .07568 .5 L p .993 .818 .566 r
F P
0 g
s
.06635 .5 m .07568 .5 L .07555 .51048 L p .993 .803 .548 r
F P
0 g
s
.71216 .86747 m .71683 .87555 L .71305 .8778 L p .347 0 .175 r
F P
0 g
s
.71305 .8778 m .70315 .87282 L .71216 .86747 L p .347 0 .175 r
F P
0 g
s
.71683 .87555 m .71216 .86747 L .7213 .86235 L p .331 0 .184 r
F P
0 g
s
.50708 .53372 m .50682 .52851 L .51405 .52433 L p .801 .911 .915 r
F P
0 g
s
.50682 .52851 m .50708 .53372 L .4982 .5389 L p .826 .926 .9 r
F P
0 g
s
.52822 .51619 m .53459 .51789 L .52567 .52299 L p .742 .897 .949 r
F P
0 g
s
.52567 .52299 m .52128 .52016 L .52822 .51619 L p .742 .897 .949 r
F P
0 g
s
.47187 .51634 m .46722 .52101 L .46725 .51073 L p .208 .13 .543 r
F P
0 g
s
.46725 .51073 m .4719 .50835 L .47187 .51634 L p .208 .13 .543 r
F P
0 g
s
.46725 .48927 m .4719 .49165 L .47191 .5 L p .228 .199 .617 r
F P
0 g
s
.4719 .49165 m .46725 .48927 L .46722 .47899 L p .208 .21 .64 r
F P
0 g
s
.52567 .47701 m .52128 .47984 L .51405 .47567 L p .773 .361 .27 r
F P
0 g
s
.52128 .47984 m .52567 .47701 L .53459 .48211 L p .742 .314 .235 r
F P
0 g
s
.49991 .46747 m .4982 .4611 L .50708 .46628 L p .826 .423 .284 r
F P
0 g
s
.50708 .46628 m .50682 .47149 L .49991 .46747 L p .826 .423 .284 r
F P
0 g
s
.54713 .12129 m .62126 .10128 L .62787 .10762 L p .663 .845 .97 r
F P
0 g
s
.67565 .1079 m .62787 .10762 L .62126 .10128 L p .461 .754 .993 r
F P
0 g
s
.62787 .10762 m .67565 .1079 L .6806 .11197 L p .506 .736 .977 r
F P
0 g
s
.77588 .19307 m .75174 .15184 L .75619 .15303 L p .164 .372 .822 r
F P
0 g
s
.75619 .15303 m .78468 .19563 L .77588 .19307 L p .164 .372 .822 r
F P
0 g
s
.14846 .64854 m .09407 .59435 L .09625 .58545 L p .888 .527 .355 r
F P
0 g
s
.07261 .54394 m .09625 .58545 L .09407 .59435 L p .966 .648 .359 r
F P
0 g
s
.09625 .58545 m .07261 .54394 L .07365 .53761 L p .961 .677 .449 r
F P
0 g
s
.09625 .41455 m .07261 .45606 L .07142 .45162 L p .966 .928 .702 r
F P
0 g
s
.07142 .45162 m .09407 .40565 L .09625 .41455 L p .966 .928 .702 r
F P
0 g
s
.80441 .73017 m .78468 .80437 L .77588 .80693 L p .243 .092 .468 r
F P
0 g
s
.75174 .84816 m .77588 .80693 L .78468 .80437 L p .164 0 .239 r
F P
0 g
s
.77588 .80693 m .75174 .84816 L .74574 .85042 L p .277 .011 .319 r
F P
0 g
s
.62787 .89238 m .67565 .8921 L .67239 .89535 L p .461 0 .068 r
F P
0 g
s
.67239 .89535 m .62126 .89872 L .62787 .89238 L p .461 0 .068 r
F P
0 g
s
.71305 .1222 m .70315 .12718 L .69466 .12182 L p .352 .612 .947 r
F P
0 g
s
.70315 .12718 m .71305 .1222 L .71683 .12445 L p .347 .595 .939 r
F P
0 g
s
.7213 .13765 m .72066 .12659 L .72439 .12855 L p .306 .552 .921 r
F P
0 g
s
.72439 .12855 m .73019 .14233 L .7213 .13765 L p .306 .552 .921 r
F P
0 g
s
.06629 .5044 m .07555 .51048 L .07516 .52051 L p .993 .789 .524 r
F P
0 g
s
.07555 .51048 m .06629 .5044 L .06635 .5 L p .993 .803 .548 r
F P
0 g
s
.07555 .48952 m .06629 .4956 L .06612 .4914 L p .993 .833 .577 r
F P
0 g
s
.06612 .4914 m .07516 .47949 L .07555 .48952 L p .993 .833 .577 r
F P
0 g
s
.72066 .87341 m .7213 .86235 L .73019 .85767 L p .306 0 .181 r
F P
0 g
s
.7213 .86235 m .72066 .87341 L .71683 .87555 L p .331 0 .184 r
F P
0 g
s
.70315 .87282 m .71305 .8778 L .70949 .88005 L p .352 0 .154 r
F P
0 g
s
.70949 .88005 m .69466 .87818 L .70315 .87282 L p .352 0 .154 r
F P
0 g
s
.46657 .17202 m .54163 .11438 L .54713 .12129 L p .809 .97 .904 r
F P
0 g
s
.62126 .10128 m .54713 .12129 L .54163 .11438 L p .601 .892 .989 r
F P
0 g
s
.80441 .26983 m .78468 .19563 L .79009 .19602 L p .022 .145 .655 r
F P
0 g
s
.79009 .19602 m .81315 .27114 L .80441 .26983 L p .022 .145 .655 r
F P
0 g
s
.23267 .69294 m .14522 .65676 L .14846 .64854 L p .711 .226 .091 r
F P
0 g
s
.09407 .59435 m .14846 .64854 L .14522 .65676 L p .872 .439 .164 r
F P
0 g
s
.54713 .87871 m .62126 .89872 L .61821 .90322 L p .601 .09 .007 r
F P
0 g
s
.61821 .90322 m .54163 .88562 L .54713 .87871 L p .601 .09 .007 r
F P
0 g
s
.14846 .35146 m .09407 .40565 L .0917 .40076 L p .872 .985 .833 r
F P
0 g
s
.0917 .40076 m .14522 .34324 L .14846 .35146 L p .872 .985 .833 r
F P
0 g
s
.80076 .63504 m .81315 .72886 L .80441 .73017 L p .056 .092 .582 r
F P
0 g
s
.78468 .80437 m .80441 .73017 L .81315 .72886 L p .022 0 .342 r
F P
0 g
s
.43806 .61999 m .42783 .66939 L .42129 .67433 L p .962 .9 .529 r
F P
0 g
s
.42611 .74668 m .42129 .67433 L .42783 .66939 L p .997 .789 .432 r
F P
0 g
s
.42654 .61966 m .38838 .65533 L .38939 .6472 L p 0 0 0 r
F P
0 g
s
.38939 .6472 m .42706 .61363 L .42654 .61966 L p 0 0 0 r
F P
0 g
s
.64036 .50379 m .69033 .519 L .68278 .52219 L p .223 .645 .956 r
F P
0 g
s
.68278 .52219 m .63488 .50635 L .64036 .50379 L p .223 .645 .956 r
F P
0 g
s
.42706 .38637 m .38939 .3528 L .38838 .34467 L p 0 .332 .815 r
F P
0 g
s
.32332 .31267 m .38838 .34467 L .38939 .3528 L p .221 .571 .94 r
F P
0 g
s
.63488 .49365 m .68278 .47781 L .69033 .481 L p .223 0 0 r
F P
0 g
s
.75057 .44065 m .69033 .481 L .68278 .47781 L p .169 0 .015 r
F P
0 g
s
.4331 .37655 m .42129 .32567 L .42783 .33061 L p .962 .671 .248 r
F P
0 g
s
.42783 .33061 m .43806 .38001 L .4331 .37655 L p .962 .671 .248 r
F P
0 g
s
.4982 .5389 m .49991 .53253 L .50682 .52851 L p .826 .926 .9 r
F P
0 g
s
.49991 .53253 m .4982 .5389 L .49009 .54365 L p .848 .946 .883 r
F P
0 g
s
.53456 .51258 m .54276 .51324 L .53459 .51789 L p .703 .896 .966 r
F P
0 g
s
.53459 .51789 m .52822 .51619 L .53456 .51258 L p .703 .896 .966 r
F P
0 g
s
.47183 .52364 m .46716 .53041 L .46722 .52101 L p .164 .066 .488 r
F P
0 g
s
.46722 .52101 m .47187 .51634 L .47183 .52364 L p .164 .066 .488 r
F P
0 g
s
.46722 .47899 m .47187 .48366 L .4719 .49165 L p .208 .21 .64 r
F P
0 g
s
.47187 .48366 m .46722 .47899 L .46716 .46959 L p .164 .202 .655 r
F P
0 g
s
.49361 .46378 m .49009 .45635 L .4982 .4611 L p .848 .438 .261 r
F P
0 g
s
.4982 .4611 m .49991 .46747 L .49361 .46378 L p .848 .438 .261 r
F P
0 g
s
.53459 .48211 m .52822 .48381 L .52128 .47984 L p .742 .314 .235 r
F P
0 g
s
.52822 .48381 m .53459 .48211 L .54276 .48676 L p .703 .252 .177 r
F P
0 g
s
.70949 .11995 m .69466 .12182 L .68703 .11668 L p .348 .625 .956 r
F P
0 g
s
.69466 .12182 m .70949 .11995 L .71305 .1222 L p .352 .612 .947 r
F P
0 g
s
.73019 .14233 m .72439 .12855 L .72785 .13023 L p .271 .526 .911 r
F P
0 g
s
.72785 .13023 m .73845 .14636 L .73019 .14233 L p .271 .526 .911 r
F P
0 g
s
.06612 .5086 m .07516 .52051 L .07452 .52969 L p .995 .776 .493 r
F P
0 g
s
.07516 .52051 m .06612 .5086 L .06629 .5044 L p .993 .789 .524 r
F P
0 g
s
.07516 .47949 m .06612 .4914 L .06585 .48756 L p .995 .848 .582 r
F P
0 g
s
.06585 .48756 m .07452 .47031 L .07516 .47949 L p .995 .848 .582 r
F P
0 g
s
.69466 .87818 m .70949 .88005 L .7063 .88221 L p .348 0 .12 r
F P
0 g
s
.7063 .88221 m .68703 .88332 L .69466 .87818 L p .348 0 .12 r
F P
0 g
s
.72439 .87145 m .73019 .85767 L .73845 .85364 L p .271 0 .165 r
F P
0 g
s
.73019 .85767 m .72439 .87145 L .72066 .87341 L p .306 0 .181 r
F P
0 g
s
.47643 .55979 m .4831 .54777 L .49009 .54365 L p .874 .959 .855 r
F P
0 g
s
.4831 .54777 m .47643 .55979 L .46913 .56416 L p .882 .985 .82 r
F P
0 g
s
.45862 .58376 m .46913 .56416 L .47643 .55979 L p .907 .965 .809 r
F P
0 g
s
.55548 .50609 m .571 .50535 L .56356 .50948 L p .583 .882 .992 r
F P
0 g
s
.56356 .50948 m .54982 .50925 L .55548 .50609 L p .583 .882 .992 r
F P
0 g
s
.46699 .54501 m .45987 .55882 L .46001 .55031 L p .022 0 .323 r
F P
0 g
s
.46001 .55031 m .46708 .53853 L .46699 .54501 L p .022 0 .323 r
F P
0 g
s
.46001 .44969 m .46708 .46147 L .46716 .46959 L p .136 .214 .682 r
F P
0 g
s
.46708 .46147 m .46001 .44969 L .45987 .44118 L p .022 .159 .668 r
F P
0 g
s
.44816 .42228 m .45987 .44118 L .46001 .44969 L p .112 .242 .72 r
F P
0 g
s
.56356 .49052 m .54982 .49075 L .54276 .48676 L p .656 .187 .129 r
F P
0 g
s
.54982 .49075 m .56356 .49052 L .571 .49465 L p .583 .07 0 r
F P
0 g
s
.59323 .49396 m .571 .49465 L .56356 .49052 L p .587 .104 .076 r
F P
0 g
s
.47753 .44891 m .46913 .43584 L .47643 .44021 L p .882 .455 .171 r
F P
0 g
s
.47643 .44021 m .4831 .45223 L .47753 .44891 L p .882 .455 .171 r
F P
0 g
s
.46913 .56416 m .45862 .58376 L .45178 .58801 L p .899 .986 .745 r
F P
0 g
s
.43806 .61999 m .45178 .58801 L .45862 .58376 L p .945 .958 .724 r
F P
0 g
s
.57629 .50248 m .60033 .50224 L .59323 .50604 L p .472 .839 .992 r
F P
0 g
s
.59323 .50604 m .571 .50535 L .57629 .50248 L p .472 .839 .992 r
F P
0 g
s
.45971 .56483 m .44789 .58577 L .44816 .57772 L p 0 0 .19 r
F P
0 g
s
.44816 .57772 m .45987 .55882 L .45971 .56483 L p 0 0 .19 r
F P
0 g
s
.45987 .44118 m .44816 .42228 L .44789 .41423 L p 0 .15 .682 r
F P
0 g
s
.42706 .38637 m .44789 .41423 L .44816 .42228 L p .074 .285 .771 r
F P
0 g
s
.571 .49465 m .59323 .49396 L .60033 .49776 L p .472 0 0 r
F P
0 g
s
.63488 .49365 m .60033 .49776 L .59323 .49396 L p .469 0 0 r
F P
0 g
s
.464 .43269 m .45178 .41199 L .45862 .41624 L p .899 .482 .127 r
F P
0 g
s
.45862 .41624 m .46913 .43584 L .464 .43269 L p .899 .482 .127 r
F P
0 g
s
.49009 .54365 m .49361 .53622 L .49991 .53253 L p .848 .946 .883 r
F P
0 g
s
.49361 .53622 m .49009 .54365 L .4831 .54777 L p .864 .97 .86 r
F P
0 g
s
.54004 .50948 m .54982 .50925 L .54276 .51324 L p .652 .897 .982 r
F P
0 g
s
.54276 .51324 m .53456 .51258 L .54004 .50948 L p .652 .897 .982 r
F P
0 g
s
.47177 .52994 m .46708 .53853 L .46716 .53041 L p .09 0 .413 r
F P
0 g
s
.46716 .53041 m .47183 .52364 L .47177 .52994 L p .09 0 .413 r
F P
0 g
s
.46716 .46959 m .47183 .47636 L .47187 .48366 L p .164 .202 .655 r
F P
0 g
s
.47183 .47636 m .46716 .46959 L .46708 .46147 L p .09 .173 .658 r
F P
0 g
s
.54276 .48676 m .53456 .48742 L .52822 .48381 L p .703 .252 .177 r
F P
0 g
s
.53456 .48742 m .54276 .48676 L .54982 .49075 L p .652 .168 .089 r
F P
0 g
s
.48819 .46058 m .4831 .45223 L .49009 .45635 L p .864 .44 .211 r
F P
0 g
s
.49009 .45635 m .49361 .46378 L .48819 .46058 L p .864 .44 .211 r
F P
0 g
s
.7063 .11779 m .68703 .11668 L .6806 .11197 L p .332 .635 .962 r
F P
0 g
s
.68703 .11668 m .7063 .11779 L .70949 .11995 L p .348 .625 .956 r
F P
0 g
s
.73845 .14636 m .72785 .13023 L .73089 .13156 L p .224 .496 .9 r
F P
0 g
s
.73089 .13156 m .74574 .14958 L .73845 .14636 L p .224 .496 .9 r
F P
0 g
s
.06585 .51244 m .07452 .52969 L .07365 .53761 L p .995 .762 .455 r
F P
0 g
s
.07452 .52969 m .06585 .51244 L .06612 .5086 L p .995 .776 .493 r
F P
0 g
s
.07452 .47031 m .06585 .48756 L .06548 .48426 L p .995 .864 .58 r
F P
0 g
s
.06548 .48426 m .07365 .46239 L .07452 .47031 L p .995 .864 .58 r
F P
0 g
s
.68703 .88332 m .7063 .88221 L .70363 .88418 L p .332 0 .072 r
F P
0 g
s
.70363 .88418 m .6806 .88803 L .68703 .88332 L p .332 0 .072 r
F P
0 g
s
.72785 .86977 m .73845 .85364 L .74574 .85042 L p .224 0 .134 r
F P
0 g
s
.73845 .85364 m .72785 .86977 L .72439 .87145 L p .271 0 .165 r
F P
0 g
s
.51236 .52141 m .51405 .52433 L .50682 .52851 L p .8 .913 .916 r
F P
0 g
s
.51808 .51812 m .52128 .52016 L .51405 .52433 L p .773 .904 .932 r
F P
0 g
s
.51405 .52433 m .51236 .52141 L .51808 .51812 L p .773 .904 .932 r
F P
0 g
s
.47528 .5 m .47191 .5 L .4719 .49165 L p .222 .194 .614 r
F P
0 g
s
.47527 .5066 m .4719 .50835 L .47191 .5 L p .222 .168 .582 r
F P
0 g
s
.47191 .5 m .47528 .5 L .47527 .5066 L p .222 .168 .582 r
F P
0 g
s
.51236 .47859 m .51405 .47567 L .52128 .47984 L p .773 .358 .264 r
F P
0 g
s
.50665 .47528 m .50682 .47149 L .51405 .47567 L p .8 .394 .28 r
F P
0 g
s
.51405 .47567 m .51236 .47859 L .50665 .47528 L p .8 .394 .28 r
F P
0 g
s
.50682 .52851 m .50665 .52472 L .51236 .52141 L p .8 .913 .916 r
F P
0 g
s
.50665 .52472 m .50682 .52851 L .49991 .53253 L p .825 .928 .901 r
F P
0 g
s
.52356 .51498 m .52822 .51619 L .52128 .52016 L p .741 .899 .949 r
F P
0 g
s
.52128 .52016 m .51808 .51812 L .52356 .51498 L p .741 .899 .949 r
F P
0 g
s
.47525 .51292 m .47187 .51634 L .4719 .50835 L p .201 .125 .541 r
F P
0 g
s
.4719 .50835 m .47527 .5066 L .47525 .51292 L p .201 .125 .541 r
F P
0 g
s
.4719 .49165 m .47527 .4934 L .47528 .5 L p .222 .194 .614 r
F P
0 g
s
.47527 .4934 m .4719 .49165 L .47187 .48366 L p .201 .204 .638 r
F P
0 g
s
.52128 .47984 m .51808 .48188 L .51236 .47859 L p .773 .358 .264 r
F P
0 g
s
.51808 .48188 m .52128 .47984 L .52822 .48381 L p .741 .311 .229 r
F P
0 g
s
.50119 .47211 m .49991 .46747 L .50682 .47149 L p .825 .419 .278 r
F P
0 g
s
.50682 .47149 m .50665 .47528 L .50119 .47211 L p .825 .419 .278 r
F P
0 g
s
.45178 .58801 m .43806 .61999 L .4331 .62345 L p .888 .944 .583 r
F P
0 g
s
.42129 .67433 m .4331 .62345 L .43806 .61999 L p .962 .9 .529 r
F P
0 g
s
.60427 .50029 m .64036 .50379 L .63488 .50635 L p .261 .728 .946 r
F P
0 g
s
.63488 .50635 m .60033 .50224 L .60427 .50029 L p .261 .728 .946 r
F P
0 g
s
.44761 .59016 m .42654 .61966 L .42706 .61363 L p 0 0 0 r
F P
0 g
s
.42706 .61363 m .44789 .58577 L .44761 .59016 L p 0 0 0 r
F P
0 g
s
.44789 .41423 m .42706 .38637 L .42654 .38034 L p 0 .129 .678 r
F P
0 g
s
.38838 .34467 m .42654 .38034 L .42706 .38637 L p 0 .332 .815 r
F P
0 g
s
.60033 .49776 m .63488 .49365 L .64036 .49621 L p .261 0 0 r
F P
0 g
s
.69033 .481 m .64036 .49621 L .63488 .49365 L p .223 0 0 r
F P
0 g
s
.44811 .40955 m .4331 .37655 L .43806 .38001 L p .888 .506 .047 r
F P
0 g
s
.43806 .38001 m .45178 .41199 L .44811 .40955 L p .888 .506 .047 r
F P
0 g
s
.49991 .53253 m .50119 .52789 L .50665 .52472 L p .825 .928 .901 r
F P
0 g
s
.50119 .52789 m .49991 .53253 L .49361 .53622 L p .847 .948 .884 r
F P
0 g
s
.52857 .51213 m .53456 .51258 L .52822 .51619 L p .703 .899 .967 r
F P
0 g
s
.52822 .51619 m .52356 .51498 L .52857 .51213 L p .703 .899 .967 r
F P
0 g
s
.47521 .51868 m .47183 .52364 L .47187 .51634 L p .158 .061 .486 r
F P
0 g
s
.47187 .51634 m .47525 .51292 L .47521 .51868 L p .158 .061 .486 r
F P
0 g
s
.47187 .48366 m .47525 .48708 L .47527 .4934 L p .201 .204 .638 r
F P
0 g
s
.47525 .48708 m .47187 .48366 L .47183 .47636 L p .158 .197 .652 r
F P
0 g
s
.52822 .48381 m .52356 .48502 L .51808 .48188 L p .741 .311 .229 r
F P
0 g
s
.52356 .48502 m .52822 .48381 L .53456 .48742 L p .703 .249 .171 r
F P
0 g
s
.49622 .46919 m .49361 .46378 L .49991 .46747 L p .847 .434 .254 r
F P
0 g
s
.49991 .46747 m .50119 .47211 L .49622 .46919 L p .847 .434 .254 r
F P
0 g
s
.4831 .54777 m .48819 .53942 L .49361 .53622 L p .864 .97 .86 r
F P
0 g
s
.48819 .53942 m .4831 .54777 L .47753 .55109 L p .866 .992 .822 r
F P
0 g
s
.46913 .56416 m .47753 .55109 L .4831 .54777 L p .882 .985 .82 r
F P
0 g
s
.54442 .50703 m .55548 .50609 L .54982 .50925 L p .579 .893 .988 r
F P
0 g
s
.54982 .50925 m .54004 .50948 L .54442 .50703 L p .579 .893 .988 r
F P
0 g
s
.4717 .53496 m .46699 .54501 L .46708 .53853 L p 0 0 .308 r
F P
0 g
s
.46708 .53853 m .47177 .52994 L .4717 .53496 L p 0 0 .308 r
F P
0 g
s
.46708 .46147 m .47177 .47006 L .47183 .47636 L p .09 .173 .658 r
F P
0 g
s
.47177 .47006 m .46708 .46147 L .46699 .45499 L p 0 .114 .639 r
F P
0 g
s
.45987 .44118 m .46699 .45499 L .46708 .46147 L p .022 .159 .668 r
F P
0 g
s
.48387 .45802 m .47753 .44891 L .4831 .45223 L p .866 .422 .124 r
F P
0 g
s
.4831 .45223 m .48819 .46058 L .48387 .45802 L p .866 .422 .124 r
F P
0 g
s
.54982 .49075 m .54004 .49052 L .53456 .48742 L p .652 .168 .089 r
F P
0 g
s
.54004 .49052 m .54982 .49075 L .55548 .49391 L p .579 .053 0 r
F P
0 g
s
.571 .49465 m .55548 .49391 L .54982 .49075 L p .583 .07 0 r
F P
0 g
s
.47753 .55109 m .46913 .56416 L .464 .56731 L p .858 .994 .751 r
F P
0 g
s
.45178 .58801 m .464 .56731 L .46913 .56416 L p .899 .986 .745 r
F P
0 g
s
.55948 .5039 m .57629 .50248 L .571 .50535 L p .47 .86 .975 r
F P
0 g
s
.571 .50535 m .55548 .50609 L .55948 .5039 L p .47 .86 .975 r
F P
0 g
s
.46688 .54956 m .45971 .56483 L .45987 .55882 L p 0 0 .168 r
F P
0 g
s
.45987 .55882 m .46699 .54501 L .46688 .54956 L p 0 0 .168 r
F P
0 g
s
.46699 .45499 m .45987 .44118 L .45971 .43517 L p 0 .058 .616 r
F P
0 g
s
.44789 .41423 m .45971 .43517 L .45987 .44118 L p 0 .15 .682 r
F P
0 g
s
.55548 .49391 m .571 .49465 L .57629 .49752 L p .47 0 0 r
F P
0 g
s
.60033 .49776 m .57629 .49752 L .571 .49465 L p .472 0 0 r
F P
0 g
s
.47363 .44654 m .464 .43269 L .46913 .43584 L p .858 .407 .033 r
F P
0 g
s
.46913 .43584 m .47753 .44891 L .47363 .44654 L p .858 .407 .033 r
F P
0 g
s
.70363 .11582 m .6806 .11197 L .67565 .1079 L p .303 .638 .965 r
F P
0 g
s
.6806 .11197 m .70363 .11582 L .7063 .11779 L p .332 .635 .962 r
F P
0 g
s
.74574 .14958 m .73089 .13156 L .73338 .13249 L p .164 .46 .886 r
F P
0 g
s
.73338 .13249 m .75174 .15184 L .74574 .14958 L p .164 .46 .886 r
F P
0 g
s
.06548 .51574 m .07365 .53761 L .07261 .54394 L p .993 .746 .407 r
F P
0 g
s
.07365 .53761 m .06548 .51574 L .06585 .51244 L p .995 .762 .455 r
F P
0 g
s
.07365 .46239 m .06548 .48426 L .06503 .48164 L p .993 .876 .567 r
F P
0 g
s
.06503 .48164 m .07261 .45606 L .07365 .46239 L p .993 .876 .567 r
F P
0 g
s
.73089 .86844 m .74574 .85042 L .75174 .84816 L p .164 0 .088 r
F P
0 g
s
.74574 .85042 m .73089 .86844 L .72785 .86977 L p .224 0 .134 r
F P
0 g
s
.6806 .88803 m .70363 .88418 L .70158 .88587 L p .303 0 .008 r
F P
0 g
s
.70158 .88587 m .67565 .8921 L .6806 .88803 L p .303 0 .008 r
F P
0 g
s
.49361 .53622 m .49622 .53081 L .50119 .52789 L p .847 .948 .884 r
F P
0 g
s
.49622 .53081 m .49361 .53622 L .48819 .53942 L p .862 .972 .861 r
F P
0 g
s
.5329 .50968 m .54004 .50948 L .53456 .51258 L p .652 .899 .982 r
F P
0 g
s
.53456 .51258 m .52857 .51213 L .5329 .50968 L p .652 .899 .982 r
F P
0 g
s
.47516 .52365 m .47177 .52994 L .47183 .52364 L p .083 0 .411 r
F P
0 g
s
.47183 .52364 m .47521 .51868 L .47516 .52365 L p .083 0 .411 r
F P
0 g
s
.47183 .47636 m .47521 .48132 L .47525 .48708 L p .158 .197 .652 r
F P
0 g
s
.47521 .48132 m .47183 .47636 L .47177 .47006 L p .083 .167 .654 r
F P
0 g
s
.53456 .48742 m .52857 .48787 L .52356 .48502 L p .703 .249 .171 r
F P
0 g
s
.52857 .48787 m .53456 .48742 L .54004 .49052 L p .652 .165 .083 r
F P
0 g
s
.49194 .46667 m .48819 .46058 L .49361 .46378 L p .862 .436 .204 r
F P
0 g
s
.49361 .46378 m .49622 .46919 L .49194 .46667 L p .862 .436 .204 r
F P
0 g
s
.51104 .51912 m .51236 .52141 L .50665 .52472 L p .802 .905 .913 r
F P
0 g
s
.51564 .51648 m .51808 .51812 L .51236 .52141 L p .774 .895 .929 r
F P
0 g
s
.51236 .52141 m .51104 .51912 L .51564 .51648 L p .774 .895 .929 r
F P
0 g
s
.47792 .5 m .47528 .5 L .47527 .4934 L p .244 .213 .623 r
F P
0 g
s
.47791 .5053 m .47527 .5066 L .47528 .5 L p .244 .186 .591 r
F P
0 g
s
.47528 .5 m .47792 .5 L .47791 .5053 L p .244 .186 .591 r
F P
0 g
s
.51104 .48088 m .51236 .47859 L .51808 .48188 L p .774 .369 .285 r
F P
0 g
s
.50645 .47822 m .50665 .47528 L .51236 .47859 L p .802 .405 .301 r
F P
0 g
s
.51236 .47859 m .51104 .48088 L .50645 .47822 L p .802 .405 .301 r
F P
0 g
s
.50665 .52472 m .50645 .52178 L .51104 .51912 L p .802 .905 .913 r
F P
0 g
s
.50645 .52178 m .50665 .52472 L .50119 .52789 L p .828 .92 .897 r
F P
0 g
s
.52004 .51396 m .52356 .51498 L .51808 .51812 L p .743 .891 .946 r
F P
0 g
s
.51808 .51812 m .51564 .51648 L .52004 .51396 L p .743 .891 .946 r
F P
0 g
s
.47789 .51038 m .47525 .51292 L .47527 .5066 L p .225 .143 .549 r
F P
0 g
s
.47527 .5066 m .47791 .5053 L .47789 .51038 L p .225 .143 .549 r
F P
0 g
s
.47527 .4934 m .47791 .4947 L .47792 .5 L p .244 .213 .623 r
F P
0 g
s
.47791 .4947 m .47527 .4934 L .47525 .48708 L p .225 .224 .647 r
F P
0 g
s
.50206 .47566 m .50119 .47211 L .50665 .47528 L p .828 .432 .299 r
F P
0 g
s
.50665 .47528 m .50645 .47822 L .50206 .47566 L p .828 .432 .299 r
F P
0 g
s
.51808 .48188 m .51564 .48352 L .51104 .48088 L p .774 .369 .285 r
F P
0 g
s
.51564 .48352 m .51808 .48188 L .52356 .48502 L p .743 .322 .25 r
F P
0 g
s
.54163 .11438 m .61821 .09678 L .62126 .10128 L p .601 .892 .989 r
F P
0 g
s
.67239 .10465 m .62126 .10128 L .61821 .09678 L p .376 .752 .99 r
F P
0 g
s
.62126 .10128 m .67239 .10465 L .67565 .1079 L p .461 .754 .993 r
F P
0 g
s
.78468 .19563 m .75619 .15303 L .75887 .15311 L p .005 .276 .776 r
F P
0 g
s
.75887 .15311 m .79009 .19602 L .78468 .19563 L p .005 .276 .776 r
F P
0 g
s
.14522 .65676 m .0917 .59924 L .09407 .59435 L p .872 .439 .164 r
F P
0 g
s
.07142 .54838 m .09407 .59435 L .0917 .59924 L p .951 .602 .23 r
F P
0 g
s
.09407 .59435 m .07142 .54838 L .07261 .54394 L p .966 .648 .359 r
F P
0 g
s
.09407 .40565 m .07142 .45162 L .07015 .44925 L p .951 .951 .658 r
F P
0 g
s
.07015 .44925 m .0917 .40076 L .09407 .40565 L p .951 .951 .658 r
F P
0 g
s
.62126 .89872 m .67239 .89535 L .67098 .89764 L p .376 0 0 r
F P
0 g
s
.67098 .89764 m .61821 .90322 L .62126 .89872 L p .376 0 0 r
F P
0 g
s
.81315 .72886 m .79009 .80398 L .78468 .80437 L p .022 0 .342 r
F P
0 g
s
.75619 .84697 m .78468 .80437 L .79009 .80398 L p .005 0 .112 r
F P
0 g
s
.78468 .80437 m .75619 .84697 L .75174 .84816 L p .164 0 .239 r
F P
0 g
s
.52407 .51167 m .52857 .51213 L .52356 .51498 L p .704 .89 .965 r
F P
0 g
s
.52356 .51498 m .52004 .51396 L .52407 .51167 L p .704 .89 .965 r
F P
0 g
s
.50119 .52789 m .50206 .52434 L .50645 .52178 L p .828 .92 .897 r
F P
0 g
s
.50206 .52434 m .50119 .52789 L .49622 .53081 L p .851 .941 .881 r
F P
0 g
s
.47786 .51501 m .47521 .51868 L .47525 .51292 L p .182 .08 .495 r
F P
0 g
s
.47525 .51292 m .47789 .51038 L .47786 .51501 L p .182 .08 .495 r
F P
0 g
s
.47525 .48708 m .47789 .48962 L .47791 .4947 L p .225 .224 .647 r
F P
0 g
s
.47789 .48962 m .47525 .48708 L .47521 .48132 L p .182 .218 .663 r
F P
0 g
s
.52356 .48502 m .52004 .48604 L .51564 .48352 L p .743 .322 .25 r
F P
0 g
s
.52004 .48604 m .52356 .48502 L .52857 .48787 L p .704 .26 .193 r
F P
0 g
s
.49807 .47332 m .49622 .46919 L .50119 .47211 L p .851 .448 .277 r
F P
0 g
s
.50119 .47211 m .50206 .47566 L .49807 .47332 L p .851 .448 .277 r
F P
0 g
s
.464 .56731 m .45178 .58801 L .44811 .59045 L p .816 .952 .609 r
F P
0 g
s
.4331 .62345 m .44811 .59045 L .45178 .58801 L p .888 .944 .583 r
F P
0 g
s
.57917 .501 m .60427 .50029 L .60033 .50224 L p .283 .768 .916 r
F P
0 g
s
.60033 .50224 m .57629 .50248 L .57917 .501 L p .283 .768 .916 r
F P
0 g
s
.45955 .56806 m .44761 .59016 L .44789 .58577 L p 0 0 0 r
F P
0 g
s
.44789 .58577 m .45971 .56483 L .45955 .56806 L p 0 0 0 r
F P
0 g
s
.45971 .43517 m .44789 .41423 L .44761 .40984 L p 0 0 .566 r
F P
0 g
s
.42654 .38034 m .44761 .40984 L .44789 .41423 L p 0 .129 .678 r
F P
0 g
s
.57629 .49752 m .60033 .49776 L .60427 .49971 L p .283 0 0 r
F P
0 g
s
.64036 .49621 m .60427 .49971 L .60033 .49776 L p .261 0 0 r
F P
0 g
s
.46128 .43094 m .44811 .40955 L .45178 .41199 L p .816 .38 0 r
F P
0 g
s
.45178 .41199 m .464 .43269 L .46128 .43094 L p .816 .38 0 r
F P
0 g
s
.48819 .53942 m .49194 .53333 L .49622 .53081 L p .862 .972 .861 r
F P
0 g
s
.49194 .53333 m .48819 .53942 L .48387 .54198 L p .863 .993 .823 r
F P
0 g
s
.47753 .55109 m .48387 .54198 L .48819 .53942 L p .866 .992 .822 r
F P
0 g
s
.53634 .50775 m .54442 .50703 L .54004 .50948 L p .579 .895 .987 r
F P
0 g
s
.54004 .50948 m .5329 .50968 L .53634 .50775 L p .579 .895 .987 r
F P
0 g
s
.47511 .5276 m .4717 .53496 L .47177 .52994 L p 0 0 .305 r
F P
0 g
s
.47177 .52994 m .47516 .52365 L .47511 .5276 L p 0 0 .305 r
F P
0 g
s
.47177 .47006 m .47516 .47635 L .47521 .48132 L p .083 .167 .654 r
F P
0 g
s
.47516 .47635 m .47177 .47006 L .4717 .46504 L p 0 .108 .634 r
F P
0 g
s
.46699 .45499 m .4717 .46504 L .47177 .47006 L p 0 .114 .639 r
F P
0 g
s
.54004 .49052 m .5329 .49032 L .52857 .48787 L p .652 .165 .083 r
F P
0 g
s
.5329 .49032 m .54004 .49052 L .54442 .49297 L p .579 .05 0 r
F P
0 g
s
.55548 .49391 m .54442 .49297 L .54004 .49052 L p .579 .053 0 r
F P
0 g
s
.48854 .46465 m .48387 .45802 L .48819 .46058 L p .863 .417 .117 r
F P
0 g
s
.48819 .46058 m .49194 .46667 L .48854 .46465 L p .863 .417 .117 r
F P
0 g
s
.48387 .54198 m .47753 .55109 L .47363 .55346 L p .835 .995 .752 r
F P
0 g
s
.464 .56731 m .47363 .55346 L .47753 .55109 L p .858 .994 .751 r
F P
0 g
s
.5475 .50533 m .55948 .5039 L .55548 .50609 L p .468 .868 .964 r
F P
0 g
s
.55548 .50609 m .54442 .50703 L .5475 .50533 L p .468 .868 .964 r
F P
0 g
s
.47163 .53847 m .46688 .54956 L .46699 .54501 L p 0 0 .157 r
F P
0 g
s
.46699 .54501 m .4717 .53496 L .47163 .53847 L p 0 0 .157 r
F P
0 g
s
.4717 .46504 m .46699 .45499 L .46688 .45044 L p 0 .013 .58 r
F P
0 g
s
.45971 .43517 m .46688 .45044 L .46699 .45499 L p 0 .058 .616 r
F P
0 g
s
.54442 .49297 m .55548 .49391 L .55948 .4961 L p .468 0 0 r
F P
0 g
s
.57629 .49752 m .55948 .4961 L .55548 .49391 L p .47 0 0 r
F P
0 g
s
.48087 .4562 m .47363 .44654 L .47753 .44891 L p .835 .368 0 r
F P
0 g
s
.47753 .44891 m .48387 .45802 L .48087 .4562 L p .835 .368 0 r
F P
0 g
s
.49622 .53081 m .49807 .52668 L .50206 .52434 L p .851 .941 .881 r
F P
0 g
s
.49807 .52668 m .49622 .53081 L .49194 .53333 L p .868 .966 .858 r
F P
0 g
s
.52754 .50971 m .5329 .50968 L .52857 .51213 L p .654 .892 .982 r
F P
0 g
s
.52857 .51213 m .52407 .51167 L .52754 .50971 L p .654 .892 .982 r
F P
0 g
s
.47782 .519 m .47516 .52365 L .47521 .51868 L p .109 0 .42 r
F P
0 g
s
.47521 .51868 m .47786 .51501 L .47782 .519 L p .109 0 .42 r
F P
0 g
s
.47521 .48132 m .47786 .48499 L .47789 .48962 L p .182 .218 .663 r
F P
0 g
s
.47786 .48499 m .47521 .48132 L .47516 .47635 L p .109 .19 .668 r
F P
0 g
s
.52857 .48787 m .52407 .48833 L .52004 .48604 L p .704 .26 .193 r
F P
0 g
s
.52407 .48833 m .52857 .48787 L .5329 .49032 L p .654 .176 .106 r
F P
0 g
s
.49464 .47129 m .49194 .46667 L .49622 .46919 L p .868 .452 .229 r
F P
0 g
s
.49622 .46919 m .49807 .47332 L .49464 .47129 L p .868 .452 .229 r
F P
0 g
s
.75174 .15184 m .73338 .13249 L .73522 .13297 L p .09 .417 .865 r
F P
0 g
s
.73522 .13297 m .75619 .15303 L .75174 .15184 L p .09 .417 .865 r
F P
0 g
s
.70158 .11413 m .67565 .1079 L .67239 .10465 L p .257 .632 .961 r
F P
0 g
s
.67565 .1079 m .70158 .11413 L .70363 .11582 L p .303 .638 .965 r
F P
0 g
s
.06503 .51836 m .07261 .54394 L .07142 .54838 L p .986 .726 .348 r
F P
0 g
s
.07261 .54394 m .06503 .51836 L .06548 .51574 L p .993 .746 .407 r
F P
0 g
s
.07261 .45606 m .06503 .48164 L .06453 .47981 L p .986 .884 .541 r
F P
0 g
s
.06453 .47981 m .07142 .45162 L .07261 .45606 L p .986 .884 .541 r
F P
0 g
s
.67565 .8921 m .70158 .88587 L .70025 .88722 L p .257 0 0 r
F P
0 g
s
.70025 .88722 m .67239 .89535 L .67565 .8921 L p .257 0 0 r
F P
0 g
s
.73338 .86751 m .75174 .84816 L .75619 .84697 L p .09 0 .023 r
F P
0 g
s
.75174 .84816 m .73338 .86751 L .73089 .86844 L p .164 0 .088 r
F P
0 g
s
.50994 .51721 m .51104 .51912 L .50645 .52178 L p .804 .887 .904 r
F P
0 g
s
.5137 .51505 m .51564 .51648 L .51104 .51912 L p .776 .877 .921 r
F P
0 g
s
.51104 .51912 m .50994 .51721 L .5137 .51505 L p .776 .877 .921 r
F P
0 g
s
.48013 .5 m .47792 .5 L .47791 .4947 L p .287 .248 .639 r
F P
0 g
s
.48012 .50434 m .47791 .5053 L .47792 .5 L p .287 .221 .606 r
F P
0 g
s
.47792 .5 m .48013 .5 L .48012 .50434 L p .287 .221 .606 r
F P
0 g
s
.50994 .48279 m .51104 .48088 L .51564 .48352 L p .776 .39 .324 r
F P
0 g
s
.50618 .48061 m .50645 .47822 L .51104 .48088 L p .804 .426 .34 r
F P
0 g
s
.51104 .48088 m .50994 .48279 L .50618 .48061 L p .804 .426 .34 r
F P
0 g
s
.50645 .52178 m .50618 .51939 L .50994 .51721 L p .804 .887 .904 r
F P
0 g
s
.50618 .51939 m .50645 .52178 L .50206 .52434 L p .831 .903 .889 r
F P
0 g
s
.5173 .51299 m .52004 .51396 L .51564 .51648 L p .744 .873 .939 r
F P
0 g
s
.51564 .51648 m .5137 .51505 L .5173 .51299 L p .744 .873 .939 r
F P
0 g
s
.4801 .50849 m .47789 .51038 L .47791 .5053 L p .269 .178 .564 r
F P
0 g
s
.47791 .5053 m .48012 .50434 L .4801 .50849 L p .269 .178 .564 r
F P
0 g
s
.47791 .4947 m .48012 .49566 L .48013 .5 L p .287 .248 .639 r
F P
0 g
s
.48012 .49566 m .47791 .4947 L .47789 .48962 L p .269 .26 .665 r
F P
0 g
s
.5026 .47852 m .50206 .47566 L .50645 .47822 L p .831 .454 .34 r
F P
0 g
s
.50645 .47822 m .50618 .48061 L .5026 .47852 L p .831 .454 .34 r
F P
0 g
s
.51564 .48352 m .5137 .48495 L .50994 .48279 L p .776 .39 .324 r
F P
0 g
s
.5137 .48495 m .51564 .48352 L .52004 .48604 L p .744 .342 .29 r
F P
0 g
s
.5206 .51113 m .52407 .51167 L .52004 .51396 L p .706 .873 .96 r
F P
0 g
s
.52004 .51396 m .5173 .51299 L .5206 .51113 L p .706 .873 .96 r
F P
0 g
s
.50206 .52434 m .5026 .52148 L .50618 .51939 L p .831 .903 .889 r
F P
0 g
s
.5026 .52148 m .50206 .52434 L .49807 .52668 L p .857 .925 .873 r
F P
0 g
s
.48006 .51227 m .47786 .51501 L .47789 .51038 L p .228 .116 .51 r
F P
0 g
s
.47789 .51038 m .4801 .50849 L .48006 .51227 L p .228 .116 .51 r
F P
0 g
s
.47789 .48962 m .4801 .49151 L .48012 .49566 L p .269 .26 .665 r
F P
0 g
s
.4801 .49151 m .47789 .48962 L .47786 .48499 L p .228 .257 .684 r
F P
0 g
s
.49934 .4766 m .49807 .47332 L .50206 .47566 L p .857 .474 .321 r
F P
0 g
s
.50206 .47566 m .5026 .47852 L .49934 .4766 L p .857 .474 .321 r
F P
0 g
s
.52004 .48604 m .5173 .48701 L .5137 .48495 L p .744 .342 .29 r
F P
0 g
s
.5173 .48701 m .52004 .48604 L .52407 .48833 L p .706 .281 .234 r
F P
0 g
s
.71683 .12445 m .71827 .12195 L .71949 .12264 L p .162 .521 .918 r
F P
0 g
s
.71949 .12264 m .72066 .12659 L .71683 .12445 L p .162 .521 .918 r
F P
0 g
s
.71827 .12195 m .71683 .12445 L .71305 .1222 L p .17 .531 .922 r
F P
0 g
s
.06635 .5 m .06347 .5 L .06345 .4986 L p .994 .815 .446 r
F P
0 g
s
.06345 .4986 m .06629 .4956 L .06635 .5 L p .994 .815 .446 r
F P
0 g
s
.06347 .5 m .06635 .5 L .06629 .5044 L p .994 .808 .437 r
F P
0 g
s
.71683 .87555 m .71827 .87805 L .71706 .87877 L p .17 0 0 r
F P
0 g
s
.71706 .87877 m .71305 .8778 L .71683 .87555 L p .17 0 0 r
F P
0 g
s
.71827 .87805 m .71683 .87555 L .72066 .87341 L p .162 0 0 r
F P
0 g
s
.49194 .53333 m .49464 .52871 L .49807 .52668 L p .868 .966 .858 r
F P
0 g
s
.49464 .52871 m .49194 .53333 L .48854 .53535 L p .873 .989 .821 r
F P
0 g
s
.48387 .54198 m .48854 .53535 L .49194 .53333 L p .863 .993 .823 r
F P
0 g
s
.53031 .50817 m .53634 .50775 L .5329 .50968 L p .581 .889 .99 r
F P
0 g
s
.5329 .50968 m .52754 .50971 L .53031 .50817 L p .581 .889 .99 r
F P
0 g
s
.47778 .52216 m .47511 .5276 L .47516 .52365 L p 0 0 .314 r
F P
0 g
s
.47516 .52365 m .47782 .519 L .47778 .52216 L p 0 0 .314 r
F P
0 g
s
.47516 .47635 m .47782 .481 L .47786 .48499 L p .109 .19 .668 r
F P
0 g
s
.47782 .481 m .47516 .47635 L .47511 .4724 L p 0 .133 .651 r
F P
0 g
s
.4717 .46504 m .47511 .4724 L .47516 .47635 L p 0 .108 .634 r
F P
0 g
s
.49192 .46967 m .48854 .46465 L .49194 .46667 L p .873 .436 .144 r
F P
0 g
s
.49194 .46667 m .49464 .47129 L .49192 .46967 L p .873 .436 .144 r
F P
0 g
s
.5329 .49032 m .52754 .49029 L .52407 .48833 L p .654 .176 .106 r
F P
0 g
s
.52754 .49029 m .5329 .49032 L .53634 .49225 L p .581 .06 0 r
F P
0 g
s
.54442 .49297 m .53634 .49225 L .5329 .49032 L p .579 .05 0 r
F P
0 g
s
.47363 .55346 m .464 .56731 L .46128 .56906 L p .764 .948 .619 r
F P
0 g
s
.44811 .59045 m .46128 .56906 L .464 .56731 L p .816 .952 .609 r
F P
0 g
s
.56163 .50278 m .57917 .501 L .57629 .50248 L p .296 .786 .89 r
F P
0 g
s
.57629 .50248 m .55948 .5039 L .56163 .50278 L p .296 .786 .89 r
F P
0 g
s
.46678 .55199 m .45955 .56806 L .45971 .56483 L p 0 0 0 r
F P
0 g
s
.45971 .56483 m .46688 .54956 L .46678 .55199 L p 0 0 0 r
F P
0 g
s
.46688 .45044 m .45971 .43517 L .45955 .43194 L p 0 0 .493 r
F P
0 g
s
.44761 .40984 m .45955 .43194 L .45971 .43517 L p 0 0 .566 r
F P
0 g
s
.47159 .44524 m .46128 .43094 L .464 .43269 L p .764 .3 0 r
F P
0 g
s
.464 .43269 m .47363 .44654 L .47159 .44524 L p .764 .3 0 r
F P
0 g
s
.55948 .4961 m .57629 .49752 L .57917 .499 L p .296 0 0 r
F P
0 g
s
.60427 .49971 m .57917 .499 L .57629 .49752 L p .283 0 0 r
F P
0 g
s
.72066 .12659 m .71949 .12264 L .72068 .12326 L p .148 .509 .912 r
F P
0 g
s
.72068 .12326 m .72439 .12855 L .72066 .12659 L p .148 .509 .912 r
F P
0 g
s
.71706 .12123 m .71305 .1222 L .70949 .11995 L p .171 .538 .925 r
F P
0 g
s
.71305 .1222 m .71706 .12123 L .71827 .12195 L p .17 .531 .922 r
F P
0 g
s
.06629 .4956 m .06345 .4986 L .06339 .49726 L p .993 .821 .45 r
F P
0 g
s
.06339 .49726 m .06612 .4914 L .06629 .4956 L p .993 .821 .45 r
F P
0 g
s
.06345 .5014 m .06629 .5044 L .06612 .5086 L p .993 .8 .424 r
F P
0 g
s
.06629 .5044 m .06345 .5014 L .06347 .5 L p .994 .808 .437 r
F P
0 g
s
.71305 .8778 m .71706 .87877 L .71593 .87948 L p .171 0 0 r
F P
0 g
s
.71593 .87948 m .70949 .88005 L .71305 .8778 L p .171 0 0 r
F P
0 g
s
.71949 .87736 m .72066 .87341 L .72439 .87145 L p .148 0 0 r
F P
0 g
s
.72066 .87341 m .71949 .87736 L .71827 .87805 L p .162 0 0 r
F P
0 g
s
.50897 .51554 m .50994 .51721 L .50618 .51939 L p .805 .862 .892 r
F P
0 g
s
.51211 .51374 m .5137 .51505 L .50994 .51721 L p .776 .852 .908 r
F P
0 g
s
.50994 .51721 m .50897 .51554 L .51211 .51374 L p .776 .852 .908 r
F P
0 g
s
.48205 .5 m .48013 .5 L .48012 .49566 L p .34 .291 .657 r
F P
0 g
s
.48204 .50361 m .48012 .50434 L .48013 .5 L p .34 .264 .623 r
F P
0 g
s
.48013 .5 m .48205 .5 L .48204 .50361 L p .34 .264 .623 r
F P
0 g
s
.50897 .48446 m .50994 .48279 L .5137 .48495 L p .776 .414 .372 r
F P
0 g
s
.50585 .48264 m .50618 .48061 L .50994 .48279 L p .805 .452 .389 r
F P
0 g
s
.50994 .48279 m .50897 .48446 L .50585 .48264 L p .805 .452 .389 r
F P
0 g
s
.49807 .52668 m .49934 .5234 L .5026 .52148 L p .857 .925 .873 r
F P
0 g
s
.49934 .5234 m .49807 .52668 L .49464 .52871 L p .879 .952 .852 r
F P
0 g
s
.52344 .50953 m .52754 .50971 L .52407 .51167 L p .657 .875 .98 r
F P
0 g
s
.52407 .51167 m .5206 .51113 L .52344 .50953 L p .657 .875 .98 r
F P
0 g
s
.48003 .51553 m .47782 .519 L .47786 .51501 L p .159 .025 .437 r
F P
0 g
s
.47786 .51501 m .48006 .51227 L .48003 .51553 L p .159 .025 .437 r
F P
0 g
s
.47786 .48499 m .48006 .48773 L .4801 .49151 L p .228 .257 .684 r
F P
0 g
s
.48006 .48773 m .47786 .48499 L .47782 .481 L p .159 .234 .693 r
F P
0 g
s
.52407 .48833 m .5206 .48887 L .5173 .48701 L p .706 .281 .234 r
F P
0 g
s
.5206 .48887 m .52407 .48833 L .52754 .49029 L p .657 .197 .149 r
F P
0 g
s
.49654 .47494 m .49464 .47129 L .49807 .47332 L p .879 .483 .277 r
F P
0 g
s
.49807 .47332 m .49934 .4766 L .49654 .47494 L p .879 .483 .277 r
F P
0 g
s
.32131 .68946 m .22954 .69521 L .23267 .69294 L p .097 0 0 r
F P
0 g
s
.23267 .69294 m .32332 .68733 L .32131 .68946 L p .097 0 0 r
F P
0 g
s
.14522 .65676 m .23267 .69294 L .22954 .69521 L p .477 0 0 r
F P
0 g
s
.42611 .74668 m .46657 .82798 L .46618 .83183 L p .761 .369 0 r
F P
0 g
s
.46657 .82798 m .54163 .88562 L .54202 .88929 L p .625 .074 0 r
F P
0 g
s
.54202 .88929 m .46618 .83183 L .46657 .82798 L p .625 .074 0 r
F P
0 g
s
.75057 .44065 m .80076 .36496 L .80428 .36338 L p 0 0 0 r
F P
0 g
s
.80076 .36496 m .81315 .27114 L .81612 .26896 L p 0 0 .131 r
F P
0 g
s
.81612 .26896 m .80428 .36338 L .80076 .36496 L p 0 0 .131 r
F P
0 g
s
.42527 .25052 m .46618 .16817 L .46657 .17202 L p .761 .873 .449 r
F P
0 g
s
.46657 .17202 m .42611 .25332 L .42527 .25052 L p .761 .873 .449 r
F P
0 g
s
.54163 .11438 m .46657 .17202 L .46618 .16817 L p .625 .948 .752 r
F P
0 g
s
.32332 .31267 m .23267 .30706 L .22954 .30479 L p .097 .644 .832 r
F P
0 g
s
.23267 .30706 m .14522 .34324 L .14185 .34175 L p .477 .896 .838 r
F P
0 g
s
.14185 .34175 m .22954 .30479 L .23267 .30706 L p .477 .896 .838 r
F P
0 g
s
.75342 .56002 m .80428 .63662 L .80076 .63504 L p 0 0 .523 r
F P
0 g
s
.80076 .63504 m .75057 .55935 L .75342 .56002 L p 0 0 .523 r
F P
0 g
s
.81315 .72886 m .80076 .63504 L .80428 .63662 L p 0 0 .303 r
F P
0 g
s
.48854 .53535 m .48387 .54198 L .48087 .5438 L p .831 .994 .752 r
F P
0 g
s
.47363 .55346 m .48087 .5438 L .48387 .54198 L p .835 .995 .752 r
F P
0 g
s
.53876 .50642 m .5475 .50533 L .54442 .50703 L p .467 .869 .962 r
F P
0 g
s
.54442 .50703 m .53634 .50775 L .53876 .50642 L p .467 .869 .962 r
F P
0 g
s
.47506 .53036 m .47163 .53847 L .4717 .53496 L p 0 0 .155 r
F P
0 g
s
.4717 .53496 m .47511 .5276 L .47506 .53036 L p 0 0 .155 r
F P
0 g
s
.47511 .4724 m .4717 .46504 L .47163 .46153 L p 0 .006 .575 r
F P
0 g
s
.46688 .45044 m .47163 .46153 L .4717 .46504 L p 0 .013 .58 r
F P
0 g
s
.53634 .49225 m .54442 .49297 L .5475 .49467 L p .467 0 0 r
F P
0 g
s
.55948 .4961 m .5475 .49467 L .54442 .49297 L p .468 0 0 r
F P
0 g
s
.48618 .46322 m .48087 .4562 L .48387 .45802 L p .831 .363 0 r
F P
0 g
s
.48387 .45802 m .48854 .46465 L .48618 .46322 L p .831 .363 0 r
F P
0 g
s
.50618 .51939 m .50585 .51736 L .50897 .51554 L p .805 .862 .892 r
F P
0 g
s
.50585 .51736 m .50618 .51939 L .5026 .52148 L p .833 .878 .876 r
F P
0 g
s
.51511 .51204 m .5173 .51299 L .5137 .51505 L p .744 .848 .928 r
F P
0 g
s
.5137 .51505 m .51211 .51374 L .51511 .51204 L p .744 .848 .928 r
F P
0 g
s
.48202 .50707 m .4801 .50849 L .48012 .50434 L p .323 .222 .582 r
F P
0 g
s
.48012 .50434 m .48204 .50361 L .48202 .50707 L p .323 .222 .582 r
F P
0 g
s
.48012 .49566 m .48204 .49639 L .48205 .5 L p .34 .291 .657 r
F P
0 g
s
.48204 .49639 m .48012 .49566 L .4801 .49151 L p .323 .306 .685 r
F P
0 g
s
.50287 .48089 m .5026 .47852 L .50618 .48061 L p .833 .482 .391 r
F P
0 g
s
.50618 .48061 m .50585 .48264 L .50287 .48089 L p .833 .482 .391 r
F P
0 g
s
.5137 .48495 m .51211 .48626 L .50897 .48446 L p .776 .414 .372 r
F P
0 g
s
.51211 .48626 m .5137 .48495 L .5173 .48701 L p .744 .367 .339 r
F P
0 g
s
.42129 .67433 m .42611 .74668 L .42527 .74948 L p .774 .595 .027 r
F P
0 g
s
.46618 .83183 m .42527 .74948 L .42611 .74668 L p .761 .369 0 r
F P
0 g
s
.38733 .65679 m .32131 .68946 L .32332 .68733 L p 0 0 0 r
F P
0 g
s
.32332 .68733 m .38838 .65533 L .38733 .65679 L p 0 0 0 r
F P
0 g
s
.69212 .51918 m .75342 .56002 L .75057 .55935 L p 0 .218 .657 r
F P
0 g
s
.75057 .55935 m .69033 .519 L .69212 .51918 L p 0 .218 .657 r
F P
0 g
s
.38838 .34467 m .32332 .31267 L .32131 .31054 L p 0 .32 .703 r
F P
0 g
s
.22954 .30479 m .32131 .31054 L .32332 .31267 L p .097 .644 .832 r
F P
0 g
s
.69033 .481 m .75057 .44065 L .75342 .43998 L p 0 0 0 r
F P
0 g
s
.80428 .36338 m .75342 .43998 L .75057 .44065 L p 0 0 0 r
F P
0 g
s
.42055 .32403 m .42527 .25052 L .42611 .25332 L p .774 .67 .119 r
F P
0 g
s
.42611 .25332 m .42129 .32567 L .42055 .32403 L p .774 .67 .119 r
F P
0 g
s
.71593 .12052 m .70949 .11995 L .7063 .11779 L p .165 .541 .926 r
F P
0 g
s
.70949 .11995 m .71593 .12052 L .71706 .12123 L p .171 .538 .925 r
F P
0 g
s
.72439 .12855 m .72068 .12326 L .72178 .12379 L p .129 .494 .905 r
F P
0 g
s
.72178 .12379 m .72785 .13023 L .72439 .12855 L p .129 .494 .905 r
F P
0 g
s
.06339 .50274 m .06612 .5086 L .06585 .51244 L p .991 .791 .407 r
F P
0 g
s
.06612 .5086 m .06339 .50274 L .06345 .5014 L p .993 .8 .424 r
F P
0 g
s
.06612 .4914 m .06339 .49726 L .06331 .49604 L p .991 .826 .449 r
F P
0 g
s
.06331 .49604 m .06585 .48756 L .06612 .4914 L p .991 .826 .449 r
F P
0 g
s
.72068 .87674 m .72439 .87145 L .72785 .86977 L p .129 0 0 r
F P
0 g
s
.72439 .87145 m .72068 .87674 L .71949 .87736 L p .148 0 0 r
F P
0 g
s
.70949 .88005 m .71593 .87948 L .71491 .88017 L p .165 0 0 r
F P
0 g
s
.71491 .88017 m .7063 .88221 L .70949 .88005 L p .165 0 0 r
F P
0 g
s
.51786 .51049 m .5206 .51113 L .5173 .51299 L p .706 .848 .95 r
F P
0 g
s
.5173 .51299 m .51511 .51204 L .51786 .51049 L p .706 .848 .95 r
F P
0 g
s
.5026 .52148 m .50287 .51911 L .50585 .51736 L p .833 .878 .876 r
F P
0 g
s
.50287 .51911 m .5026 .52148 L .49934 .5234 L p .861 .901 .861 r
F P
0 g
s
.48198 .51022 m .48006 .51227 L .4801 .50849 L p .287 .161 .529 r
F P
0 g
s
.4801 .50849 m .48202 .50707 L .48198 .51022 L p .287 .161 .529 r
F P
0 g
s
.4801 .49151 m .48202 .49293 L .48204 .49639 L p .323 .306 .685 r
F P
0 g
s
.48202 .49293 m .4801 .49151 L .48006 .48773 L p .287 .307 .708 r
F P
0 g
s
.50016 .47929 m .49934 .4766 L .5026 .47852 L p .861 .505 .376 r
F P
0 g
s
.5026 .47852 m .50287 .48089 L .50016 .47929 L p .861 .505 .376 r
F P
0 g
s
.5173 .48701 m .51511 .48796 L .51211 .48626 L p .744 .367 .339 r
F P
0 g
s
.51511 .48796 m .5173 .48701 L .5206 .48887 L p .706 .306 .286 r
F P
0 g
s
.72785 .13023 m .72178 .12379 L .72275 .12422 L p .103 .477 .896 r
F P
0 g
s
.72275 .12422 m .73089 .13156 L .72785 .13023 L p .103 .477 .896 r
F P
0 g
s
.71491 .11983 m .7063 .11779 L .70363 .11582 L p .153 .542 .924 r
F P
0 g
s
.7063 .11779 m .71491 .11983 L .71593 .12052 L p .165 .541 .926 r
F P
0 g
s
.06331 .50396 m .06585 .51244 L .06548 .51574 L p .987 .782 .386 r
F P
0 g
s
.06585 .51244 m .06331 .50396 L .06339 .50274 L p .991 .791 .407 r
F P
0 g
s
.06585 .48756 m .06331 .49604 L .06319 .49499 L p .987 .829 .443 r
F P
0 g
s
.06319 .49499 m .06548 .48426 L .06585 .48756 L p .987 .829 .443 r
F P
0 g
s
.7063 .88221 m .71491 .88017 L .71406 .8808 L p .153 0 0 r
F P
0 g
s
.71406 .8808 m .70363 .88418 L .7063 .88221 L p .153 0 0 r
F P
0 g
s
.72178 .87621 m .72785 .86977 L .73089 .86844 L p .103 0 0 r
F P
0 g
s
.72785 .86977 m .72178 .87621 L .72068 .87674 L p .129 0 0 r
F P
0 g
s
.49464 .52871 m .49654 .52506 L .49934 .5234 L p .879 .952 .852 r
F P
0 g
s
.49654 .52506 m .49464 .52871 L .49192 .53033 L p .89 .98 .818 r
F P
0 g
s
.48854 .53535 m .49192 .53033 L .49464 .52871 L p .873 .989 .821 r
F P
0 g
s
.52569 .50828 m .53031 .50817 L .52754 .50971 L p .585 .875 .994 r
F P
0 g
s
.52754 .50971 m .52344 .50953 L .52569 .50828 L p .585 .875 .994 r
F P
0 g
s
.47998 .51811 m .47778 .52216 L .47782 .519 L p .046 0 .331 r
F P
0 g
s
.47782 .519 m .48003 .51553 L .47998 .51811 L p .046 0 .331 r
F P
0 g
s
.47782 .481 m .48003 .48447 L .48006 .48773 L p .159 .234 .693 r
F P
0 g
s
.48003 .48447 m .47782 .481 L .47778 .47784 L p .046 .182 .683 r
F P
0 g
s
.47511 .4724 m .47778 .47784 L .47782 .481 L p 0 .133 .651 r
F P
0 g
s
.49432 .47361 m .49192 .46967 L .49464 .47129 L p .89 .473 .196 r
F P
0 g
s
.49464 .47129 m .49654 .47494 L .49432 .47361 L p .89 .473 .196 r
F P
0 g
s
.52754 .49029 m .52344 .49047 L .5206 .48887 L p .657 .197 .149 r
F P
0 g
s
.52344 .49047 m .52754 .49029 L .53031 .49183 L p .585 .08 .02 r
F P
0 g
s
.53634 .49225 m .53031 .49183 L .52754 .49029 L p .581 .06 0 r
F P
0 g
s
.5081 .51404 m .50897 .51554 L .50585 .51736 L p .802 .833 .875 r
F P
0 g
s
.51077 .51251 m .51211 .51374 L .50897 .51554 L p .773 .823 .892 r
F P
0 g
s
.50897 .51554 m .5081 .51404 L .51077 .51251 L p .773 .823 .892 r
F P
0 g
s
.48379 .5 m .48205 .5 L .48204 .49639 L p .395 .337 .674 r
F P
0 g
s
.48378 .50307 m .48204 .50361 L .48205 .5 L p .395 .309 .64 r
F P
0 g
s
.48205 .5 m .48379 .5 L .48378 .50307 L p .395 .309 .64 r
F P
0 g
s
.5081 .48596 m .50897 .48446 L .51211 .48626 L p .773 .439 .422 r
F P
0 g
s
.50545 .48442 m .50585 .48264 L .50897 .48446 L p .802 .477 .439 r
F P
0 g
s
.50897 .48446 m .5081 .48596 L .50545 .48442 L p .802 .477 .439 r
F P
0 g
s
.52023 .50918 m .52344 .50953 L .5206 .51113 L p .658 .851 .974 r
F P
0 g
s
.5206 .51113 m .51786 .51049 L .52023 .50918 L p .658 .851 .974 r
F P
0 g
s
.49934 .5234 m .50016 .52071 L .50287 .51911 L p .861 .901 .861 r
F P
0 g
s
.50016 .52071 m .49934 .5234 L .49654 .52506 L p .888 .931 .841 r
F P
0 g
s
.48194 .51293 m .48003 .51553 L .48006 .51227 L p .222 .073 .456 r
F P
0 g
s
.48006 .51227 m .48198 .51022 L .48194 .51293 L p .222 .073 .456 r
F P
0 g
s
.48006 .48773 m .48198 .48978 L .48202 .49293 L p .287 .307 .708 r
F P
0 g
s
.48198 .48978 m .48006 .48773 L .48003 .48447 L p .222 .29 .723 r
F P
0 g
s
.49783 .4779 m .49654 .47494 L .49934 .4766 L p .888 .52 .338 r
F P
0 g
s
.49934 .4766 m .50016 .47929 L .49783 .4779 L p .888 .52 .338 r
F P
0 g
s
.5206 .48887 m .51786 .48951 L .51511 .48796 L p .706 .306 .286 r
F P
0 g
s
.51786 .48951 m .5206 .48887 L .52344 .49047 L p .658 .223 .205 r
F P
0 g
s
.81315 .27114 m .79009 .19602 L .79183 .1942 L p 0 0 .471 r
F P
0 g
s
.79183 .1942 m .81612 .26896 L .81315 .27114 L p 0 0 .471 r
F P
0 g
s
.46618 .16817 m .54202 .11071 L .54163 .11438 L p .625 .948 .752 r
F P
0 g
s
.61821 .09678 m .54163 .11438 L .54202 .11071 L p .416 .859 .911 r
F P
0 g
s
.22954 .69521 m .14185 .65825 L .14522 .65676 L p .477 0 0 r
F P
0 g
s
.0917 .59924 m .14522 .65676 L .14185 .65825 L p .755 .258 0 r
F P
0 g
s
.14522 .34324 m .0917 .40076 L .08925 .40017 L p .755 .976 .715 r
F P
0 g
s
.08925 .40017 m .14185 .34175 L .14522 .34324 L p .755 .976 .715 r
F P
0 g
s
.54163 .88562 m .61821 .90322 L .61892 .90563 L p .416 0 0 r
F P
0 g
s
.61892 .90563 m .54202 .88929 L .54163 .88562 L p .416 0 0 r
F P
0 g
s
.80428 .63662 m .81612 .73104 L .81315 .72886 L p 0 0 .303 r
F P
0 g
s
.79009 .80398 m .81315 .72886 L .81612 .73104 L p 0 0 .079 r
F P
0 g
s
.51333 .51107 m .51511 .51204 L .51211 .51374 L p .741 .817 .912 r
F P
0 g
s
.51211 .51374 m .51077 .51251 L .51333 .51107 L p .741 .817 .912 r
F P
0 g
s
.50585 .51736 m .50545 .51558 L .5081 .51404 L p .802 .833 .875 r
F P
0 g
s
.50545 .51558 m .50585 .51736 L .50287 .51911 L p .832 .849 .859 r
F P
0 g
s
.48375 .50601 m .48202 .50707 L .48204 .50361 L p .381 .268 .599 r
F P
0 g
s
.48204 .50361 m .48378 .50307 L .48375 .50601 L p .381 .268 .599 r
F P
0 g
s
.48204 .49639 m .48378 .49693 L .48379 .5 L p .395 .337 .674 r
F P
0 g
s
.48378 .49693 m .48204 .49639 L .48202 .49293 L p .381 .354 .704 r
F P
0 g
s
.50292 .48292 m .50287 .48089 L .50585 .48264 L p .832 .51 .444 r
F P
0 g
s
.50585 .48264 m .50545 .48442 L .50292 .48292 L p .832 .51 .444 r
F P
0 g
s
.51211 .48626 m .51077 .48749 L .5081 .48596 L p .773 .439 .422 r
F P
0 g
s
.51077 .48749 m .51211 .48626 L .51511 .48796 L p .741 .392 .391 r
F P
0 g
s
.4331 .62345 m .42129 .67433 L .42055 .67597 L p .718 .717 .19 r
F P
0 g
s
.42527 .74948 m .42055 .67597 L .42129 .67433 L p .774 .595 .027 r
F P
0 g
s
.64137 .50381 m .69212 .51918 L .69033 .519 L p 0 .409 .706 r
F P
0 g
s
.69033 .519 m .64036 .50379 L .64137 .50381 L p 0 .409 .706 r
F P
0 g
s
.42601 .62053 m .38733 .65679 L .38838 .65533 L p 0 0 0 r
F P
0 g
s
.38838 .65533 m .42654 .61966 L .42601 .62053 L p 0 0 0 r
F P
0 g
s
.42654 .38034 m .38838 .34467 L .38733 .34321 L p 0 .051 .546 r
F P
0 g
s
.32131 .31054 m .38733 .34321 L .38838 .34467 L p 0 .32 .703 r
F P
0 g
s
.64036 .49621 m .69033 .481 L .69212 .48082 L p 0 0 0 r
F P
0 g
s
.75342 .43998 m .69212 .48082 L .69033 .481 L p 0 0 0 r
F P
0 g
s
.43262 .37566 m .42055 .32403 L .42129 .32567 L p .718 .456 0 r
F P
0 g
s
.42129 .32567 m .4331 .37655 L .43262 .37566 L p .718 .456 0 r
F P
0 g
s
.48087 .5438 m .47363 .55346 L .47159 .55476 L p .738 .943 .623 r
F P
0 g
s
.46128 .56906 m .47159 .55476 L .47363 .55346 L p .764 .948 .619 r
F P
0 g
s
.54914 .50447 m .56163 .50278 L .55948 .5039 L p .301 .793 .875 r
F P
0 g
s
.55948 .5039 m .5475 .50533 L .54914 .50447 L p .301 .793 .875 r
F P
0 g
s
.47156 .54032 m .46678 .55199 L .46688 .54956 L p 0 0 0 r
F P
0 g
s
.46688 .54956 m .47163 .53847 L .47156 .54032 L p 0 0 0 r
F P
0 g
s
.47163 .46153 m .46688 .45044 L .46678 .44801 L p 0 0 .457 r
F P
0 g
s
.45955 .43194 m .46678 .44801 L .46688 .45044 L p 0 0 .493 r
F P
0 g
s
.4793 .45521 m .47159 .44524 L .47363 .44654 L p .738 .261 0 r
F P
0 g
s
.47363 .44654 m .48087 .4562 L .4793 .45521 L p .738 .261 0 r
F P
0 g
s
.5475 .49467 m .55948 .4961 L .56163 .49722 L p .301 0 0 r
F P
0 g
s
.57917 .499 m .56163 .49722 L .55948 .4961 L p .296 0 0 r
F P
0 g
s
.49192 .53033 m .48854 .53535 L .48618 .53678 L p .845 .995 .752 r
F P
0 g
s
.48087 .5438 m .48618 .53678 L .48854 .53535 L p .831 .994 .752 r
F P
0 g
s
.53224 .5071 m .53876 .50642 L .53634 .50775 L p .469 .865 .969 r
F P
0 g
s
.53634 .50775 m .53031 .50817 L .53224 .5071 L p .469 .865 .969 r
F P
0 g
s
.47773 .52437 m .47506 .53036 L .47511 .5276 L p 0 0 .162 r
F P
0 g
s
.47511 .5276 m .47778 .52216 L .47773 .52437 L p 0 0 .162 r
F P
0 g
s
.47778 .47784 m .47511 .4724 L .47506 .46964 L p 0 .032 .596 r
F P
0 g
s
.47163 .46153 m .47506 .46964 L .47511 .4724 L p 0 .006 .575 r
F P
0 g
s
.53031 .49183 m .53634 .49225 L .53876 .49358 L p .469 0 0 r
F P
0 g
s
.5475 .49467 m .53876 .49358 L .53634 .49225 L p .467 0 0 r
F P
0 g
s
.49003 .46853 m .48618 .46322 L .48854 .46465 L p .845 .385 .005 r
F P
0 g
s
.48854 .46465 m .49192 .46967 L .49003 .46853 L p .845 .385 .005 r
F P
0 g
s
.61821 .09678 m .67098 .10236 L .67239 .10465 L p .376 .752 .99 r
F P
0 g
s
.70025 .11278 m .67239 .10465 L .67098 .10236 L p .192 .613 .946 r
F P
0 g
s
.67239 .10465 m .70025 .11278 L .70158 .11413 L p .257 .632 .961 r
F P
0 g
s
.75619 .15303 m .73522 .13297 L .73631 .13297 L p 0 .366 .835 r
F P
0 g
s
.73631 .13297 m .75887 .15311 L .75619 .15303 L p 0 .366 .835 r
F P
0 g
s
.0917 .59924 m .07015 .55075 L .07142 .54838 L p .951 .602 .23 r
F P
0 g
s
.06453 .52019 m .07142 .54838 L .07015 .55075 L p .968 .7 .276 r
F P
0 g
s
.07142 .54838 m .06453 .52019 L .06503 .51836 L p .986 .726 .348 r
F P
0 g
s
.07142 .45162 m .06453 .47981 L .06399 .47886 L p .968 .881 .498 r
F P
0 g
s
.06399 .47886 m .07015 .44925 L .07142 .45162 L p .968 .881 .498 r
F P
0 g
s
.79009 .80398 m .75887 .84689 L .75619 .84697 L p .005 0 .112 r
F P
0 g
s
.73522 .86703 m .75619 .84697 L .75887 .84689 L p 0 0 0 r
F P
0 g
s
.75619 .84697 m .73522 .86703 L .73338 .86751 L p .09 0 .023 r
F P
0 g
s
.67239 .89535 m .70025 .88722 L .6997 .88816 L p .192 0 0 r
F P
0 g
s
.6997 .88816 m .67098 .89764 L .67239 .89535 L p .192 0 0 r
F P
0 g
s
.50287 .51911 m .50292 .51708 L .50545 .51558 L p .832 .849 .859 r
F P
0 g
s
.50292 .51708 m .50287 .51911 L .50016 .52071 L p .863 .872 .843 r
F P
0 g
s
.51566 .50977 m .51786 .51049 L .51511 .51204 L p .704 .817 .935 r
F P
0 g
s
.51511 .51204 m .51333 .51107 L .51566 .50977 L p .704 .817 .935 r
F P
0 g
s
.48371 .50868 m .48198 .51022 L .48202 .50707 L p .349 .21 .547 r
F P
0 g
s
.48202 .50707 m .48375 .50601 L .48371 .50868 L p .349 .21 .547 r
F P
0 g
s
.48202 .49293 m .48375 .49399 L .48378 .49693 L p .381 .354 .704 r
F P
0 g
s
.48375 .49399 m .48202 .49293 L .48198 .48978 L p .349 .36 .73 r
F P
0 g
s
.51511 .48796 m .51333 .48893 L .51077 .48749 L p .741 .392 .391 r
F P
0 g
s
.51333 .48893 m .51511 .48796 L .51786 .48951 L p .704 .332 .342 r
F P
0 g
s
.50063 .48155 m .50016 .47929 L .50287 .48089 L p .863 .537 .434 r
F P
0 g
s
.50287 .48089 m .50292 .48292 L .50063 .48155 L p .863 .537 .434 r
F P
0 g
s
.71406 .1192 m .70363 .11582 L .70158 .11413 L p .135 .538 .92 r
F P
0 g
s
.70363 .11582 m .71406 .1192 L .71491 .11983 L p .153 .542 .924 r
F P
0 g
s
.73089 .13156 m .72275 .12422 L .72354 .12451 L p .073 .458 .885 r
F P
0 g
s
.72354 .12451 m .73338 .13249 L .73089 .13156 L p .073 .458 .885 r
F P
0 g
s
.06319 .50501 m .06548 .51574 L .06503 .51836 L p .981 .772 .361 r
F P
0 g
s
.06548 .51574 m .06319 .50501 L .06331 .50396 L p .987 .782 .386 r
F P
0 g
s
.72275 .87578 m .73089 .86844 L .73338 .86751 L p .073 0 0 r
F P
0 g
s
.73089 .86844 m .72275 .87578 L .72178 .87621 L p .103 0 0 r
F P
0 g
s
.06548 .48426 m .06319 .49499 L .06305 .49416 L p .981 .83 .432 r
F P
0 g
s
.06305 .49416 m .06503 .48164 L .06548 .48426 L p .981 .83 .432 r
F P
0 g
s
.70363 .88418 m .71406 .8808 L .71342 .88134 L p .135 0 0 r
F P
0 g
s
.71342 .88134 m .70158 .88587 L .70363 .88418 L p .135 0 0 r
F P
0 g
s
.5073 .51264 m .5081 .51404 L .50545 .51558 L p .797 .801 .855 r
F P
0 g
s
.50962 .51132 m .51077 .51251 L .5081 .51404 L p .767 .791 .872 r
F P
0 g
s
.5081 .51404 m .5073 .51264 L .50962 .51132 L p .767 .791 .872 r
F P
0 g
s
.4854 .5 m .48379 .5 L .48378 .49693 L p .448 .38 .688 r
F P
0 g
s
.48539 .50267 m .48378 .50307 L .48379 .5 L p .448 .352 .654 r
F P
0 g
s
.48379 .5 m .4854 .5 L .48539 .50267 L p .448 .352 .654 r
F P
0 g
s
.5073 .48736 m .5081 .48596 L .51077 .48749 L p .767 .462 .47 r
F P
0 g
s
.505 .48601 m .50545 .48442 L .5081 .48596 L p .797 .501 .487 r
F P
0 g
s
.5081 .48596 m .5073 .48736 L .505 .48601 L p .797 .501 .487 r
F P
0 g
s
.51184 .51008 m .51333 .51107 L .51077 .51251 L p .735 .785 .892 r
F P
0 g
s
.51077 .51251 m .50962 .51132 L .51184 .51008 L p .735 .785 .892 r
F P
0 g
s
.50545 .51558 m .505 .51399 L .5073 .51264 L p .797 .801 .855 r
F P
0 g
s
.505 .51399 m .50545 .51558 L .50292 .51708 L p .828 .817 .839 r
F P
0 g
s
.48378 .49693 m .48539 .49733 L .4854 .5 L p .448 .38 .688 r
F P
0 g
s
.48539 .49733 m .48378 .49693 L .48375 .49399 L p .436 .4 .72 r
F P
0 g
s
.48535 .50522 m .48375 .50601 L .48378 .50307 L p .436 .313 .613 r
F P
0 g
s
.48378 .50307 m .48539 .50267 L .48535 .50522 L p .436 .313 .613 r
F P
0 g
s
.50281 .4847 m .50292 .48292 L .50545 .48442 L p .828 .535 .494 r
F P
0 g
s
.50545 .48442 m .505 .48601 L .50281 .4847 L p .828 .535 .494 r
F P
0 g
s
.51077 .48749 m .50962 .48868 L .5073 .48736 L p .767 .462 .47 r
F P
0 g
s
.50962 .48868 m .51077 .48749 L .51333 .48893 L p .735 .416 .44 r
F P
0 g
s
.49654 .52506 m .49783 .5221 L .50016 .52071 L p .888 .931 .841 r
F P
0 g
s
.49783 .5221 m .49654 .52506 L .49432 .52639 L p .908 .964 .809 r
F P
0 g
s
.49192 .53033 m .49432 .52639 L .49654 .52506 L p .89 .98 .818 r
F P
0 g
s
.52211 .50814 m .52569 .50828 L .52344 .50953 L p .587 .853 .994 r
F P
0 g
s
.52344 .50953 m .52023 .50918 L .52211 .50814 L p .587 .853 .994 r
F P
0 g
s
.4819 .51507 m .47998 .51811 L .48003 .51553 L p .115 0 .351 r
F P
0 g
s
.48003 .51553 m .48194 .51293 L .4819 .51507 L p .115 0 .351 r
F P
0 g
s
.48003 .48447 m .48194 .48707 L .48198 .48978 L p .222 .29 .723 r
F P
0 g
s
.48194 .48707 m .48003 .48447 L .47998 .48189 L p .115 .245 .722 r
F P
0 g
s
.47778 .47784 m .47998 .48189 L .48003 .48447 L p .046 .182 .683 r
F P
0 g
s
.52344 .49047 m .52023 .49082 L .51786 .48951 L p .658 .223 .205 r
F P
0 g
s
.52023 .49082 m .52344 .49047 L .52569 .49172 L p .587 .105 .079 r
F P
0 g
s
.53031 .49183 m .52569 .49172 L .52344 .49047 L p .585 .08 .02 r
F P
0 g
s
.496 .47679 m .49432 .47361 L .49654 .47494 L p .908 .519 .264 r
F P
0 g
s
.49654 .47494 m .49783 .4779 L .496 .47679 L p .908 .519 .264 r
F P
0 g
s
.50016 .52071 m .50063 .51845 L .50292 .51708 L p .863 .872 .843 r
F P
0 g
s
.50063 .51845 m .50016 .52071 L .49783 .5221 L p .895 .902 .825 r
F P
0 g
s
.51768 .50866 m .52023 .50918 L .51786 .51049 L p .656 .82 .962 r
F P
0 g
s
.51786 .51049 m .51566 .50977 L .51768 .50866 L p .656 .82 .962 r
F P
0 g
s
.48366 .51098 m .48194 .51293 L .48198 .51022 L p .291 .125 .476 r
F P
0 g
s
.48198 .51022 m .48371 .50868 L .48366 .51098 L p .291 .125 .476 r
F P
0 g
s
.48198 .48978 m .48371 .49132 L .48375 .49399 L p .349 .36 .73 r
F P
0 g
s
.48371 .49132 m .48198 .48978 L .48194 .48707 L p .291 .35 .752 r
F P
0 g
s
.49866 .48036 m .49783 .4779 L .50016 .47929 L p .895 .558 .403 r
F P
0 g
s
.50016 .47929 m .50063 .48155 L .49866 .48036 L p .895 .558 .403 r
F P
0 g
s
.51786 .48951 m .51566 .49023 L .51333 .48893 L p .704 .332 .342 r
F P
0 g
s
.51566 .49023 m .51786 .48951 L .52023 .49082 L p .656 .251 .266 r
F P
0 g
s
.51388 .50897 m .51566 .50977 L .51333 .51107 L p .698 .783 .916 r
F P
0 g
s
.51333 .51107 m .51184 .51008 L .51388 .50897 L p .698 .783 .916 r
F P
0 g
s
.50292 .51708 m .50281 .5153 L .505 .51399 L p .828 .817 .839 r
F P
0 g
s
.50281 .5153 m .50292 .51708 L .50063 .51845 L p .86 .839 .823 r
F P
0 g
s
.48529 .50753 m .48371 .50868 L .48375 .50601 L p .409 .258 .563 r
F P
0 g
s
.48375 .50601 m .48535 .50522 L .48529 .50753 L p .409 .258 .563 r
F P
0 g
s
.48375 .49399 m .48535 .49478 L .48539 .49733 L p .436 .4 .72 r
F P
0 g
s
.48535 .49478 m .48375 .49399 L .48371 .49132 L p .409 .41 .749 r
F P
0 g
s
.50083 .4835 m .50063 .48155 L .50292 .48292 L p .86 .566 .489 r
F P
0 g
s
.50292 .48292 m .50281 .4847 L .50083 .4835 L p .86 .566 .489 r
F P
0 g
s
.51333 .48893 m .51184 .48992 L .50962 .48868 L p .735 .416 .44 r
F P
0 g
s
.51184 .48992 m .51333 .48893 L .51566 .49023 L p .698 .358 .396 r
F P
0 g
s
.49432 .52639 m .49192 .53033 L .49003 .53147 L p .87 .993 .75 r
F P
0 g
s
.48618 .53678 m .49003 .53147 L .49192 .53033 L p .845 .995 .752 r
F P
0 g
s
.52727 .50741 m .53224 .5071 L .53031 .50817 L p .471 .855 .981 r
F P
0 g
s
.53031 .50817 m .52569 .50828 L .52727 .50741 L p .471 .855 .981 r
F P
0 g
s
.47994 .51991 m .47773 .52437 L .47778 .52216 L p 0 0 .174 r
F P
0 g
s
.47778 .52216 m .47998 .51811 L .47994 .51991 L p 0 0 .174 r
F P
0 g
s
.47998 .48189 m .47778 .47784 L .47773 .47563 L p 0 .084 .635 r
F P
0 g
s
.47506 .46964 m .47773 .47563 L .47778 .47784 L p 0 .032 .596 r
F P
0 g
s
.49279 .47268 m .49003 .46853 L .49192 .46967 L p .87 .428 .059 r
F P
0 g
s
.49192 .46967 m .49432 .47361 L .49279 .47268 L p .87 .428 .059 r
F P
0 g
s
.52569 .49172 m .53031 .49183 L .53224 .4929 L p .471 0 0 r
F P
0 g
s
.53876 .49358 m .53224 .4929 L .53031 .49183 L p .469 0 0 r
F P
0 g
s
.44811 .59045 m .4331 .62345 L .43262 .62434 L p .651 .771 .301 r
F P
0 g
s
.42055 .67597 m .43262 .62434 L .4331 .62345 L p .718 .717 .19 r
F P
0 g
s
.60484 .50029 m .64137 .50381 L .64036 .50379 L p 0 .525 .712 r
F P
0 g
s
.64036 .50379 m .60427 .50029 L .60484 .50029 L p 0 .525 .712 r
F P
0 g
s
.44733 .59065 m .42601 .62053 L .42654 .61966 L p 0 0 0 r
F P
0 g
s
.42654 .61966 m .44761 .59016 L .44733 .59065 L p 0 0 0 r
F P
0 g
s
.44761 .40984 m .42654 .38034 L .42601 .37947 L p 0 0 .419 r
F P
0 g
s
.38733 .34321 m .42601 .37947 L .42654 .38034 L p 0 .051 .546 r
F P
0 g
s
.60427 .49971 m .64036 .49621 L .64137 .49619 L p 0 0 0 r
F P
0 g
s
.69212 .48082 m .64137 .49619 L .64036 .49621 L p 0 0 0 r
F P
0 g
s
.44783 .40906 m .43262 .37566 L .4331 .37655 L p .651 .293 0 r
F P
0 g
s
.4331 .37655 m .44811 .40955 L .44783 .40906 L p .651 .293 0 r
F P
0 g
s
.48618 .53678 m .48087 .5438 L .4793 .54479 L p .734 .943 .624 r
F P
0 g
s
.47159 .55476 m .4793 .54479 L .48087 .5438 L p .738 .943 .623 r
F P
0 g
s
.54004 .50574 m .54914 .50447 L .5475 .50533 L p .302 .794 .873 r
F P
0 g
s
.5475 .50533 m .53876 .50642 L .54004 .50574 L p .302 .794 .873 r
F P
0 g
s
.47501 .5318 m .47156 .54032 L .47163 .53847 L p 0 0 0 r
F P
0 g
s
.47163 .53847 m .47506 .53036 L .47501 .5318 L p 0 0 0 r
F P
0 g
s
.47506 .46964 m .47163 .46153 L .47156 .45968 L p 0 0 .452 r
F P
0 g
s
.46678 .44801 m .47156 .45968 L .47163 .46153 L p 0 0 .457 r
F P
0 g
s
.53876 .49358 m .5475 .49467 L .54914 .49553 L p .302 0 0 r
F P
0 g
s
.56163 .49722 m .54914 .49553 L .5475 .49467 L p .301 0 0 r
F P
0 g
s
.48495 .46245 m .4793 .45521 L .48087 .4562 L p .734 .256 0 r
F P
0 g
s
.48087 .4562 m .48618 .46322 L .48495 .46245 L p .734 .256 0 r
F P
0 g
s
.50654 .51133 m .5073 .51264 L .505 .51399 L p .79 .769 .834 r
F P
0 g
s
.50861 .51016 m .50962 .51132 L .5073 .51264 L p .76 .759 .852 r
F P
0 g
s
.5073 .51264 m .50654 .51133 L .50861 .51016 L p .76 .759 .852 r
F P
0 g
s
.48691 .5 m .4854 .5 L .48539 .49733 L p .497 .42 .7 r
F P
0 g
s
.4869 .50237 m .48539 .50267 L .4854 .5 L p .497 .391 .665 r
F P
0 g
s
.4854 .5 m .48691 .5 L .4869 .50237 L p .497 .391 .665 r
F P
0 g
s
.50654 .48867 m .5073 .48736 L .50962 .48868 L p .76 .482 .513 r
F P
0 g
s
.5045 .48747 m .505 .48601 L .5073 .48736 L p .79 .521 .53 r
F P
0 g
s
.5073 .48736 m .50654 .48867 L .5045 .48747 L p .79 .521 .53 r
F P
0 g
s
.505 .51399 m .5045 .51253 L .50654 .51133 L p .79 .769 .834 r
F P
0 g
s
.5045 .51253 m .505 .51399 L .50281 .5153 L p .821 .784 .818 r
F P
0 g
s
.51059 .50907 m .51184 .51008 L .50962 .51132 L p .728 .752 .871 r
F P
0 g
s
.50962 .51132 m .50861 .51016 L .51059 .50907 L p .728 .752 .871 r
F P
0 g
s
.48685 .50463 m .48535 .50522 L .48539 .50267 L p .487 .354 .625 r
F P
0 g
s
.48539 .50267 m .4869 .50237 L .48685 .50463 L p .487 .354 .625 r
F P
0 g
s
.48539 .49733 m .4869 .49763 L .48691 .5 L p .497 .42 .7 r
F P
0 g
s
.4869 .49763 m .48539 .49733 L .48535 .49478 L p .487 .441 .732 r
F P
0 g
s
.50256 .48629 m .50281 .4847 L .505 .48601 L p .821 .557 .539 r
F P
0 g
s
.505 .48601 m .5045 .48747 L .50256 .48629 L p .821 .557 .539 r
F P
0 g
s
.50962 .48868 m .50861 .48984 L .50654 .48867 L p .76 .482 .513 r
F P
0 g
s
.50861 .48984 m .50962 .48868 L .51184 .48992 L p .728 .437 .486 r
F P
0 g
s
.51563 .50803 m .51768 .50866 L .51566 .50977 L p .651 .784 .945 r
F P
0 g
s
.51566 .50977 m .51388 .50897 L .51563 .50803 L p .651 .784 .945 r
F P
0 g
s
.50063 .51845 m .50083 .5165 L .50281 .5153 L p .86 .839 .823 r
F P
0 g
s
.50083 .5165 m .50063 .51845 L .49866 .51964 L p .896 .869 .804 r
F P
0 g
s
.49783 .5221 m .49866 .51964 L .50063 .51845 L p .895 .902 .825 r
F P
0 g
s
.48523 .50952 m .48366 .51098 L .48371 .50868 L p .36 .178 .494 r
F P
0 g
s
.48371 .50868 m .48529 .50753 L .48523 .50952 L p .36 .178 .494 r
F P
0 g
s
.48371 .49132 m .48529 .49247 L .48535 .49478 L p .409 .41 .749 r
F P
0 g
s
.48529 .49247 m .48371 .49132 L .48366 .48902 L p .36 .409 .777 r
F P
0 g
s
.48194 .48707 m .48366 .48902 L .48371 .49132 L p .291 .35 .752 r
F P
0 g
s
.49914 .48245 m .49866 .48036 L .50063 .48155 L p .896 .594 .467 r
F P
0 g
s
.50063 .48155 m .50083 .4835 L .49914 .48245 L p .896 .594 .467 r
F P
0 g
s
.51566 .49023 m .51388 .49103 L .51184 .48992 L p .698 .358 .396 r
F P
0 g
s
.51388 .49103 m .51566 .49023 L .51768 .49134 L p .651 .279 .326 r
F P
0 g
s
.52023 .49082 m .51768 .49134 L .51566 .49023 L p .656 .251 .266 r
F P
0 g
s
.49866 .51964 m .49783 .5221 L .496 .52321 L p .923 .939 .794 r
F P
0 g
s
.49432 .52639 m .496 .52321 L .49783 .5221 L p .908 .964 .809 r
F P
0 g
s
.51928 .5078 m .52211 .50814 L .52023 .50918 L p .586 .823 .989 r
F P
0 g
s
.52023 .50918 m .51768 .50866 L .51928 .5078 L p .586 .823 .989 r
F P
0 g
s
.48361 .51279 m .4819 .51507 L .48194 .51293 L p .193 0 .373 r
F P
0 g
s
.48194 .51293 m .48366 .51098 L .48361 .51279 L p .193 0 .373 r
F P
0 g
s
.48366 .48902 m .48194 .48707 L .4819 .48493 L p .193 .316 .762 r
F P
0 g
s
.47998 .48189 m .4819 .48493 L .48194 .48707 L p .115 .245 .722 r
F P
0 g
s
.51768 .49134 m .52023 .49082 L .52211 .49186 L p .586 .134 .145 r
F P
0 g
s
.52569 .49172 m .52211 .49186 L .52023 .49082 L p .587 .105 .079 r
F P
0 g
s
.49712 .47941 m .496 .47679 L .49783 .4779 L p .923 .568 .34 r
F P
0 g
s
.49783 .4779 m .49866 .48036 L .49712 .47941 L p .923 .568 .34 r
F P
0 g
s
.51241 .50811 m .51388 .50897 L .51184 .51008 L p .691 .748 .895 r
F P
0 g
s
.51184 .51008 m .51059 .50907 L .51241 .50811 L p .691 .748 .895 r
F P
0 g
s
.50281 .5153 m .50256 .51371 L .5045 .51253 L p .821 .784 .818 r
F P
0 g
s
.50256 .51371 m .50281 .5153 L .50083 .5165 L p .854 .804 .801 r
F P
0 g
s
.48677 .50669 m .48529 .50753 L .48535 .50522 L p .465 .302 .576 r
F P
0 g
s
.48535 .50522 m .48685 .50463 L .48677 .50669 L p .465 .302 .576 r
F P
0 g
s
.48535 .49478 m .48685 .49537 L .4869 .49763 L p .487 .441 .732 r
F P
0 g
s
.48685 .49537 m .48535 .49478 L .48529 .49247 L p .465 .456 .764 r
F P
0 g
s
.50082 .4852 m .50083 .4835 L .50281 .4847 L p .854 .591 .539 r
F P
0 g
s
.50281 .4847 m .50256 .48629 L .50082 .4852 L p .854 .591 .539 r
F P
0 g
s
.51184 .48992 m .51059 .49093 L .50861 .48984 L p .728 .437 .486 r
F P
0 g
s
.51059 .49093 m .51184 .48992 L .51388 .49103 L p .691 .381 .445 r
F P
0 g
s
.71342 .11866 m .70158 .11413 L .70025 .11278 L p .109 .53 .913 r
F P
0 g
s
.70158 .11413 m .71342 .11866 L .71406 .1192 L p .135 .538 .92 r
F P
0 g
s
.73338 .13249 m .72354 .12451 L .72412 .12466 L p .038 .438 .872 r
F P
0 g
s
.72412 .12466 m .73522 .13297 L .73338 .13249 L p .038 .438 .872 r
F P
0 g
s
.06305 .50584 m .06503 .51836 L .06453 .52019 L p .972 .76 .332 r
F P
0 g
s
.06503 .51836 m .06305 .50584 L .06319 .50501 L p .981 .772 .361 r
F P
0 g
s
.72354 .87549 m .73338 .86751 L .73522 .86703 L p .038 0 0 r
F P
0 g
s
.73338 .86751 m .72354 .87549 L .72275 .87578 L p .073 0 0 r
F P
0 g
s
.06503 .48164 m .06305 .49416 L .06289 .49358 L p .972 .828 .415 r
F P
0 g
s
.06289 .49358 m .06453 .47981 L .06503 .48164 L p .972 .828 .415 r
F P
0 g
s
.70158 .88587 m .71342 .88134 L .713 .88176 L p .109 0 0 r
F P
0 g
s
.713 .88176 m .70025 .88722 L .70158 .88587 L p .109 0 0 r
F P
0 g
s
.79009 .19602 m .75887 .15311 L .75967 .15205 L p 0 .141 .685 r
F P
0 g
s
.75967 .15205 m .79183 .1942 L .79009 .19602 L p 0 .141 .685 r
F P
0 g
s
.54202 .11071 m .61892 .09437 L .61821 .09678 L p .416 .859 .911 r
F P
0 g
s
.67098 .10236 m .61821 .09678 L .61892 .09437 L p .229 .705 .938 r
F P
0 g
s
.61821 .90322 m .67098 .89764 L .6715 .89885 L p .229 0 0 r
F P
0 g
s
.6715 .89885 m .61892 .90563 L .61821 .90322 L p .229 0 0 r
F P
0 g
s
.0917 .40076 m .07015 .44925 L .06883 .4491 L p .89 .933 .556 r
F P
0 g
s
.06883 .4491 m .08925 .40017 L .0917 .40076 L p .89 .933 .556 r
F P
0 g
s
.14185 .65825 m .08925 .59983 L .0917 .59924 L p .755 .258 0 r
F P
0 g
s
.07015 .55075 m .0917 .59924 L .08925 .59983 L p .89 .52 .051 r
F P
0 g
s
.81612 .73104 m .79183 .8058 L .79009 .80398 L p 0 0 .079 r
F P
0 g
s
.75887 .84689 m .79009 .80398 L .79183 .8058 L p 0 0 0 r
F P
0 g
s
.496 .52321 m .49432 .52639 L .49279 .52732 L p .901 .986 .744 r
F P
0 g
s
.49003 .53147 m .49279 .52732 L .49432 .52639 L p .87 .993 .75 r
F P
0 g
s
.52342 .50743 m .52727 .50741 L .52569 .50828 L p .472 .838 .992 r
F P
0 g
s
.52569 .50828 m .52211 .50814 L .52342 .50743 L p .472 .838 .992 r
F P
0 g
s
.48186 .51657 m .47994 .51991 L .47998 .51811 L p 0 0 .19 r
F P
0 g
s
.47998 .51811 m .4819 .51507 L .48186 .51657 L p 0 0 .19 r
F P
0 g
s
.4819 .48493 m .47998 .48189 L .47994 .48009 L p 0 .154 .686 r
F P
0 g
s
.47773 .47563 m .47994 .48009 L .47998 .48189 L p 0 .084 .635 r
F P
0 g
s
.52211 .49186 m .52569 .49172 L .52727 .49259 L p .472 0 0 r
F P
0 g
s
.53224 .4929 m .52727 .49259 L .52569 .49172 L p .471 0 0 r
F P
0 g
s
.49472 .47601 m .49279 .47268 L .49432 .47361 L p .901 .485 .131 r
F P
0 g
s
.49432 .47361 m .496 .47679 L .49472 .47601 L p .901 .485 .131 r
F P
0 g
s
.50582 .51008 m .50654 .51133 L .5045 .51253 L p .781 .738 .813 r
F P
0 g
s
.50771 .50902 m .50861 .51016 L .50654 .51133 L p .751 .728 .83 r
F P
0 g
s
.50654 .51133 m .50582 .51008 L .50771 .50902 L p .751 .728 .83 r
F P
0 g
s
.48836 .5 m .48691 .5 L .4869 .49763 L p .539 .454 .708 r
F P
0 g
s
.48834 .50216 m .4869 .50237 L .48691 .5 L p .539 .426 .673 r
F P
0 g
s
.48691 .5 m .48836 .5 L .48834 .50216 L p .539 .426 .673 r
F P
0 g
s
.50582 .48992 m .50654 .48867 L .50861 .48984 L p .751 .499 .55 r
F P
0 g
s
.50396 .48882 m .5045 .48747 L .50654 .48867 L p .781 .538 .568 r
F P
0 g
s
.50654 .48867 m .50582 .48992 L .50396 .48882 L p .781 .538 .568 r
F P
0 g
s
.5045 .51253 m .50396 .51118 L .50582 .51008 L p .781 .738 .813 r
F P
0 g
s
.50396 .51118 m .5045 .51253 L .50256 .51371 L p .812 .752 .796 r
F P
0 g
s
.50953 .50805 m .51059 .50907 L .50861 .51016 L p .719 .72 .85 r
F P
0 g
s
.50861 .51016 m .50771 .50902 L .50953 .50805 L p .719 .72 .85 r
F P
0 g
s
.48827 .50423 m .48685 .50463 L .4869 .50237 L p .531 .39 .634 r
F P
0 g
s
.4869 .50237 m .48834 .50216 L .48827 .50423 L p .531 .39 .634 r
F P
0 g
s
.4869 .49763 m .48834 .49784 L .48836 .5 L p .539 .454 .708 r
F P
0 g
s
.48834 .49784 m .4869 .49763 L .48685 .49537 L p .531 .478 .741 r
F P
0 g
s
.50861 .48984 m .50771 .49098 L .50582 .48992 L p .751 .499 .55 r
F P
0 g
s
.50771 .49098 m .50861 .48984 L .51059 .49093 L p .719 .455 .526 r
F P
0 g
s
.50221 .48773 m .50256 .48629 L .5045 .48747 L p .812 .574 .579 r
F P
0 g
s
.5045 .48747 m .50396 .48882 L .50221 .48773 L p .812 .574 .579 r
F P
0 g
s
.49003 .53147 m .48618 .53678 L .48495 .53755 L p .749 .945 .622 r
F P
0 g
s
.4793 .54479 m .48495 .53755 L .48618 .53678 L p .734 .943 .624 r
F P
0 g
s
.53326 .50656 m .54004 .50574 L .53876 .50642 L p .299 .79 .882 r
F P
0 g
s
.53876 .50642 m .53224 .5071 L .53326 .50656 L p .299 .79 .882 r
F P
0 g
s
.47769 .52552 m .47501 .5318 L .47506 .53036 L p 0 0 0 r
F P
0 g
s
.47506 .53036 m .47773 .52437 L .47769 .52552 L p 0 0 0 r
F P
0 g
s
.47773 .47563 m .47506 .46964 L .47501 .4682 L p 0 0 .473 r
F P
0 g
s
.47156 .45968 m .47501 .4682 L .47506 .46964 L p 0 0 .452 r
F P
0 g
s
.53224 .4929 m .53876 .49358 L .54004 .49426 L p .299 0 0 r
F P
0 g
s
.54914 .49553 m .54004 .49426 L .53876 .49358 L p .302 0 0 r
F P
0 g
s
.48905 .46792 m .48495 .46245 L .48618 .46322 L p .749 .278 0 r
F P
0 g
s
.48618 .46322 m .49003 .46853 L .48905 .46792 L p .749 .278 0 r
F P
0 g
s
.50083 .5165 m .50082 .5148 L .50256 .51371 L p .854 .804 .801 r
F P
0 g
s
.50082 .5148 m .50083 .5165 L .49914 .51755 L p .892 .832 .78 r
F P
0 g
s
.49866 .51964 m .49914 .51755 L .50083 .5165 L p .896 .869 .804 r
F P
0 g
s
.51397 .5073 m .51563 .50803 L .51388 .50897 L p .644 .747 .924 r
F P
0 g
s
.51388 .50897 m .51241 .50811 L .51397 .5073 L p .644 .747 .924 r
F P
0 g
s
.48669 .50844 m .48523 .50952 L .48529 .50753 L p .424 .229 .51 r
F P
0 g
s
.48529 .50753 m .48677 .50669 L .48669 .50844 L p .424 .229 .51 r
F P
0 g
s
.48529 .49247 m .48677 .49331 L .48685 .49537 L p .465 .456 .764 r
F P
0 g
s
.48677 .49331 m .48529 .49247 L .48523 .49048 L p .424 .463 .797 r
F P
0 g
s
.48366 .48902 m .48523 .49048 L .48529 .49247 L p .36 .409 .777 r
F P
0 g
s
.49934 .48425 m .49914 .48245 L .50083 .4835 L p .892 .625 .526 r
F P
0 g
s
.50083 .4835 m .50082 .4852 L .49934 .48425 L p .892 .625 .526 r
F P
0 g
s
.51388 .49103 m .51241 .49189 L .51059 .49093 L p .691 .381 .445 r
F P
0 g
s
.51241 .49189 m .51388 .49103 L .51563 .49197 L p .644 .305 .383 r
F P
0 g
s
.51768 .49134 m .51563 .49197 L .51388 .49103 L p .651 .279 .326 r
F P
0 g
s
.43262 .62434 m .44783 .59094 L .44811 .59045 L p .651 .771 .301 r
F P
0 g
s
.46128 .56906 m .44811 .59045 L .44783 .59094 L p 0 0 0 r
F P
0 g
s
.57949 .50101 m .60484 .50029 L .60427 .50029 L p 0 0 0 r
F P
0 g
s
.60427 .50029 m .57917 .501 L .57949 .50101 L p 0 0 0 r
F P
0 g
s
.45938 .56834 m .44733 .59065 L .44761 .59016 L p .625 .784 .339 r
F P
0 g
s
.44761 .59016 m .45955 .56806 L .45938 .56834 L p .625 .784 .339 r
F P
0 g
s
.42601 .37947 m .44733 .40935 L .44761 .40984 L p 0 0 .419 r
F P
0 g
s
.45955 .43194 m .44761 .40984 L .44733 .40935 L p .625 .236 0 r
F P
0 g
s
.64137 .49619 m .60484 .49971 L .60427 .49971 L p 0 0 0 r
F P
0 g
s
.57917 .499 m .60427 .49971 L .60484 .49971 L p 0 .563 .709 r
F P
0 g
s
.46112 .43065 m .44783 .40906 L .44811 .40955 L p 0 0 .373 r
F P
0 g
s
.44811 .40955 m .46128 .43094 L .46112 .43065 L p 0 0 .373 r
F P
0 g
s
.49914 .51755 m .49866 .51964 L .49712 .52059 L p .932 .907 .774 r
F P
0 g
s
.496 .52321 m .49712 .52059 L .49866 .51964 L p .923 .939 .794 r
F P
0 g
s
.51702 .5073 m .51928 .5078 L .51768 .50866 L p .582 .786 .977 r
F P
0 g
s
.51768 .50866 m .51563 .50803 L .51702 .5073 L p .582 .786 .977 r
F P
0 g
s
.48517 .51109 m .48361 .51279 L .48366 .51098 L p .272 .057 .393 r
F P
0 g
s
.48366 .51098 m .48523 .50952 L .48517 .51109 L p .272 .057 .393 r
F P
0 g
s
.48523 .49048 m .48366 .48902 L .48361 .48721 L p .272 .387 .798 r
F P
0 g
s
.4819 .48493 m .48361 .48721 L .48366 .48902 L p .193 .316 .762 r
F P
0 g
s
.51563 .49197 m .51768 .49134 L .51928 .4922 L p .582 .164 .214 r
F P
0 g
s
.52211 .49186 m .51928 .4922 L .51768 .49134 L p .586 .134 .145 r
F P
0 g
s
.49781 .48161 m .49712 .47941 L .49866 .48036 L p .932 .615 .417 r
F P
0 g
s
.49866 .48036 m .49914 .48245 L .49781 .48161 L p .932 .615 .417 r
F P
0 g
s
.50256 .51371 m .50221 .51227 L .50396 .51118 L p .812 .752 .796 r
F P
0 g
s
.50221 .51227 m .50256 .51371 L .50082 .5148 L p .846 .77 .778 r
F P
0 g
s
.51119 .5072 m .51241 .50811 L .51059 .50907 L p .682 .713 .872 r
F P
0 g
s
.51059 .50907 m .50953 .50805 L .51119 .5072 L p .682 .713 .872 r
F P
0 g
s
.48685 .49537 m .48827 .49577 L .48834 .49784 L p .531 .478 .741 r
F P
0 g
s
.48827 .49577 m .48685 .49537 L .48677 .49331 L p .514 .497 .775 r
F P
0 g
s
.48817 .50609 m .48677 .50669 L .48685 .50463 L p .514 .343 .586 r
F P
0 g
s
.48685 .50463 m .48827 .50423 L .48817 .50609 L p .514 .343 .586 r
F P
0 g
s
.50064 .48671 m .50082 .4852 L .50256 .48629 L p .846 .611 .584 r
F P
0 g
s
.50256 .48629 m .50221 .48773 L .50064 .48671 L p .846 .611 .584 r
F P
0 g
s
.51059 .49093 m .50953 .49195 L .50771 .49098 L p .719 .455 .526 r
F P
0 g
s
.50953 .49195 m .51059 .49093 L .51241 .49189 L p .682 .401 .489 r
F P
0 g
s
.50512 .50886 m .50582 .51008 L .50396 .51118 L p .772 .709 .793 r
F P
0 g
s
.50689 .50788 m .50771 .50902 L .50582 .51008 L p .742 .698 .81 r
F P
0 g
s
.50582 .51008 m .50512 .50886 L .50689 .50788 L p .742 .698 .81 r
F P
0 g
s
.48977 .5 m .48836 .5 L .48834 .49784 L p .576 .484 .714 r
F P
0 g
s
.48973 .50203 m .48834 .50216 L .48836 .5 L p .576 .456 .679 r
F P
0 g
s
.48836 .5 m .48977 .5 L .48973 .50203 L p .576 .456 .679 r
F P
0 g
s
.50512 .49114 m .50582 .48992 L .50771 .49098 L p .742 .513 .583 r
F P
0 g
s
.50337 .49009 m .50396 .48882 L .50582 .48992 L p .772 .552 .6 r
F P
0 g
s
.50582 .48992 m .50512 .49114 L .50337 .49009 L p .772 .552 .6 r
F P
0 g
s
.50396 .51118 m .50337 .50991 L .50512 .50886 L p .772 .709 .793 r
F P
0 g
s
.50337 .50991 m .50396 .51118 L .50221 .51227 L p .802 .721 .775 r
F P
0 g
s
.50861 .507 m .50953 .50805 L .50771 .50902 L p .71 .689 .828 r
F P
0 g
s
.50771 .50902 m .50689 .50788 L .50861 .507 L p .71 .689 .828 r
F P
0 g
s
.48963 .50396 m .48827 .50423 L .48834 .50216 L p .57 .422 .641 r
F P
0 g
s
.48834 .50216 m .48973 .50203 L .48963 .50396 L p .57 .422 .641 r
F P
0 g
s
.48834 .49784 m .48973 .49797 L .48977 .5 L p .576 .484 .714 r
F P
0 g
s
.48973 .49797 m .48834 .49784 L .48827 .49577 L p .57 .509 .747 r
F P
0 g
s
.50771 .49098 m .50689 .49212 L .50512 .49114 L p .742 .513 .583 r
F P
0 g
s
.50689 .49212 m .50771 .49098 L .50953 .49195 L p .71 .471 .56 r
F P
0 g
s
.50175 .48904 m .50221 .48773 L .50396 .48882 L p .802 .589 .613 r
F P
0 g
s
.50396 .48882 m .50337 .49009 L .50175 .48904 L p .802 .589 .613 r
F P
0 g
s
.49712 .52059 m .496 .52321 L .49472 .52399 L p .931 .971 .732 r
F P
0 g
s
.49279 .52732 m .49472 .52399 L .496 .52321 L p .901 .986 .744 r
F P
0 g
s
.52039 .5072 m .52342 .50743 L .52211 .50814 L p .47 .811 .999 r
F P
0 g
s
.52211 .50814 m .51928 .5078 L .52039 .5072 L p .47 .811 .999 r
F P
0 g
s
.48357 .51406 m .48186 .51657 L .4819 .51507 L p .023 0 .208 r
F P
0 g
s
.4819 .51507 m .48361 .51279 L .48357 .51406 L p .023 0 .208 r
F P
0 g
s
.48361 .48721 m .4819 .48493 L .48186 .48343 L p .023 .236 .741 r
F P
0 g
s
.47994 .48009 m .48186 .48343 L .4819 .48493 L p 0 .154 .686 r
F P
0 g
s
.49604 .47874 m .49472 .47601 L .496 .47679 L p .931 .55 .217 r
F P
0 g
s
.496 .47679 m .49712 .47941 L .49604 .47874 L p .931 .55 .217 r
F P
0 g
s
.51928 .4922 m .52211 .49186 L .52342 .49257 L p .47 0 0 r
F P
0 g
s
.52727 .49259 m .52342 .49257 L .52211 .49186 L p .472 0 0 r
F P
0 g
s
.50082 .5148 m .50064 .51329 L .50221 .51227 L p .846 .77 .778 r
F P
0 g
s
.50064 .51329 m .50082 .5148 L .49934 .51575 L p .884 .794 .755 r
F P
0 g
s
.49914 .51755 m .49934 .51575 L .50082 .5148 L p .892 .832 .78 r
F P
0 g
s
.51262 .5065 m .51397 .5073 L .51241 .50811 L p .635 .708 .9 r
F P
0 g
s
.51241 .50811 m .51119 .5072 L .51262 .5065 L p .635 .708 .9 r
F P
0 g
s
.48677 .49331 m .48817 .49391 L .48827 .49577 L p .514 .497 .775 r
F P
0 g
s
.48817 .49391 m .48677 .49331 L .48669 .49156 L p .482 .511 .811 r
F P
0 g
s
.48523 .49048 m .48669 .49156 L .48677 .49331 L p .424 .463 .797 r
F P
0 g
s
.48806 .50768 m .48669 .50844 L .48677 .50669 L p .482 .276 .523 r
F P
0 g
s
.48677 .50669 m .48817 .50609 L .48806 .50768 L p .482 .276 .523 r
F P
0 g
s
.51241 .49189 m .51119 .4928 L .50953 .49195 L p .682 .401 .489 r
F P
0 g
s
.51119 .4928 m .51241 .49189 L .51397 .4927 L p .635 .328 .434 r
F P
0 g
s
.51563 .49197 m .51397 .4927 L .51241 .49189 L p .644 .305 .383 r
F P
0 g
s
.49932 .48582 m .49934 .48425 L .50082 .4852 L p .884 .65 .579 r
F P
0 g
s
.50082 .4852 m .50064 .48671 L .49932 .48582 L p .884 .65 .579 r
F P
0 g
s
.50221 .51227 m .50175 .51096 L .50337 .50991 L p .802 .721 .775 r
F P
0 g
s
.50175 .51096 m .50221 .51227 L .50064 .51329 L p .835 .736 .755 r
F P
0 g
s
.51018 .50625 m .51119 .5072 L .50953 .50805 L p .673 .68 .849 r
F P
0 g
s
.50953 .50805 m .50861 .507 L .51018 .50625 L p .673 .68 .849 r
F P
0 g
s
.48949 .50569 m .48817 .50609 L .48827 .50423 L p .558 .379 .595 r
F P
0 g
s
.48827 .50423 m .48963 .50396 L .48949 .50569 L p .558 .379 .595 r
F P
0 g
s
.48827 .49577 m .48963 .49604 L .48973 .49797 L p .57 .509 .747 r
F P
0 g
s
.48963 .49604 m .48827 .49577 L .48817 .49391 L p .558 .532 .782 r
F P
0 g
s
.50953 .49195 m .50861 .493 L .50689 .49212 L p .71 .471 .56 r
F P
0 g
s
.50861 .493 m .50953 .49195 L .51119 .4928 L p .673 .419 .529 r
F P
0 g
s
.50032 .48806 m .50064 .48671 L .50221 .48773 L p .835 .627 .622 r
F P
0 g
s
.50221 .48773 m .50175 .48904 L .50032 .48806 L p .835 .627 .622 r
F P
0 g
s
.50442 .50766 m .50512 .50886 L .50337 .50991 L p .762 .681 .773 r
F P
0 g
s
.50616 .50672 m .50689 .50788 L .50512 .50886 L p .733 .671 .79 r
F P
0 g
s
.50512 .50886 m .50442 .50766 L .50616 .50672 L p .733 .671 .79 r
F P
0 g
s
.49115 .5 m .48977 .5 L .48973 .49797 L p .607 .51 .717 r
F P
0 g
s
.4911 .50197 m .48973 .50203 L .48977 .5 L p .607 .482 .684 r
F P
0 g
s
.48977 .5 m .49115 .5 L .4911 .50197 L p .607 .482 .684 r
F P
0 g
s
.50442 .49234 m .50512 .49114 L .50689 .49212 L p .733 .525 .611 r
F P
0 g
s
.50274 .49131 m .50337 .49009 L .50512 .49114 L p .762 .563 .628 r
F P
0 g
s
.50512 .49114 m .50442 .49234 L .50274 .49131 L p .762 .563 .628 r
F P
0 g
s
.49934 .51575 m .49914 .51755 L .49781 .51839 L p .935 .87 .75 r
F P
0 g
s
.49712 .52059 m .49781 .51839 L .49914 .51755 L p .932 .907 .774 r
F P
0 g
s
.51521 .50668 m .51702 .5073 L .51563 .50803 L p .575 .745 .958 r
F P
0 g
s
.51563 .50803 m .51397 .5073 L .51521 .50668 L p .575 .745 .958 r
F P
0 g
s
.48661 .50983 m .48517 .51109 L .48523 .50952 L p .349 .115 .411 r
F P
0 g
s
.48523 .50952 m .48669 .50844 L .48661 .50983 L p .349 .115 .411 r
F P
0 g
s
.48669 .49156 m .48523 .49048 L .48517 .48891 L p .349 .455 .827 r
F P
0 g
s
.48361 .48721 m .48517 .48891 L .48523 .49048 L p .272 .387 .798 r
F P
0 g
s
.51397 .4927 m .51563 .49197 L .51702 .4927 L p .575 .193 .281 r
F P
0 g
s
.51928 .4922 m .51702 .4927 L .51563 .49197 L p .582 .164 .214 r
F P
0 g
s
.49818 .48349 m .49781 .48161 L .49914 .48245 L p .935 .657 .489 r
F P
0 g
s
.49914 .48245 m .49934 .48425 L .49818 .48349 L p .935 .657 .489 r
F P
0 g
s
.49279 .52732 m .49003 .53147 L .48905 .53208 L p .779 .949 .616 r
F P
0 g
s
.48495 .53755 m .48905 .53208 L .49003 .53147 L p .749 .945 .622 r
F P
0 g
s
.52809 .50698 m .53326 .50656 L .53224 .5071 L p .291 .781 .897 r
F P
0 g
s
.53224 .5071 m .52727 .50741 L .52809 .50698 L p .291 .781 .897 r
F P
0 g
s
.47991 .52084 m .47769 .52552 L .47773 .52437 L p 0 0 0 r
F P
0 g
s
.47773 .52437 m .47994 .51991 L .47991 .52084 L p 0 0 0 r
F P
0 g
s
.47994 .48009 m .47773 .47563 L .47769 .47448 L p 0 0 .513 r
F P
0 g
s
.47501 .4682 m .47769 .47448 L .47773 .47563 L p 0 0 .473 r
F P
0 g
s
.49199 .47218 m .48905 .46792 L .49003 .46853 L p .779 .322 0 r
F P
0 g
s
.49003 .46853 m .49279 .47268 L .49199 .47218 L p .779 .322 0 r
F P
0 g
s
.52727 .49259 m .53224 .4929 L .53326 .49344 L p .291 0 0 r
F P
0 g
s
.54004 .49426 m .53326 .49344 L .53224 .4929 L p .299 0 0 r
F P
0 g
s
.50337 .50991 m .50274 .50869 L .50442 .50766 L p .762 .681 .773 r
F P
0 g
s
.50274 .50869 m .50337 .50991 L .50175 .51096 L p .791 .692 .755 r
F P
0 g
s
.50783 .50592 m .50861 .507 L .50689 .50788 L p .701 .661 .807 r
F P
0 g
s
.50689 .50788 m .50616 .50672 L .50783 .50592 L p .701 .661 .807 r
F P
0 g
s
.49095 .50382 m .48963 .50396 L .48973 .50203 L p .604 .451 .647 r
F P
0 g
s
.48973 .50203 m .4911 .50197 L .49095 .50382 L p .604 .451 .647 r
F P
0 g
s
.48973 .49797 m .4911 .49803 L .49115 .5 L p .607 .51 .717 r
F P
0 g
s
.4911 .49803 m .48973 .49797 L .48963 .49604 L p .604 .535 .751 r
F P
0 g
s
.50689 .49212 m .50616 .49328 L .50442 .49234 L p .733 .525 .611 r
F P
0 g
s
.50616 .49328 m .50689 .49212 L .50861 .493 L p .701 .485 .591 r
F P
0 g
s
.50121 .49025 m .50175 .48904 L .50337 .49009 L p .791 .6 .643 r
F P
0 g
s
.50337 .49009 m .50274 .49131 L .50121 .49025 L p .791 .6 .643 r
F P
0 g
s
.50175 .51096 m .50121 .50975 L .50274 .50869 L p .791 .692 .755 r
F P
0 g
s
.50121 .50975 m .50175 .51096 L .50032 .51194 L p .823 .704 .734 r
F P
0 g
s
.50064 .51329 m .50032 .51194 L .50175 .51096 L p .835 .736 .755 r
F P
0 g
s
.50936 .50526 m .51018 .50625 L .50861 .507 L p .664 .649 .825 r
F P
0 g
s
.50861 .507 m .50783 .50592 L .50936 .50526 L p .664 .649 .825 r
F P
0 g
s
.49076 .50547 m .48949 .50569 L .48963 .50396 L p .596 .412 .603 r
F P
0 g
s
.48963 .50396 m .49095 .50382 L .49076 .50547 L p .596 .412 .603 r
F P
0 g
s
.48963 .49604 m .49095 .49618 L .4911 .49803 L p .604 .535 .751 r
F P
0 g
s
.49095 .49618 m .48963 .49604 L .48949 .49431 L p .596 .561 .786 r
F P
0 g
s
.48817 .49391 m .48949 .49431 L .48963 .49604 L p .558 .532 .782 r
F P
0 g
s
.50861 .493 m .50783 .49408 L .50616 .49328 L p .701 .485 .591 r
F P
0 g
s
.50783 .49408 m .50861 .493 L .51018 .49375 L p .664 .436 .563 r
F P
0 g
s
.51119 .4928 m .51018 .49375 L .50861 .493 L p .673 .419 .529 r
F P
0 g
s
.49988 .48927 m .50032 .48806 L .50175 .48904 L p .823 .639 .655 r
F P
0 g
s
.50175 .48904 m .50121 .49025 L .49988 .48927 L p .823 .639 .655 r
F P
0 g
s
.50032 .51194 m .50064 .51329 L .49932 .51418 L p .873 .756 .73 r
F P
0 g
s
.49934 .51575 m .49932 .51418 L .50064 .51329 L p .884 .794 .755 r
F P
0 g
s
.51152 .50565 m .51262 .5065 L .51119 .5072 L p .625 .671 .874 r
F P
0 g
s
.51119 .5072 m .51018 .50625 L .51152 .50565 L p .625 .671 .874 r
F P
0 g
s
.48935 .50716 m .48806 .50768 L .48817 .50609 L p .533 .318 .534 r
F P
0 g
s
.48817 .50609 m .48949 .50569 L .48935 .50716 L p .533 .318 .534 r
F P
0 g
s
.48949 .49431 m .48817 .49391 L .48806 .49232 L p .533 .552 .821 r
F P
0 g
s
.48669 .49156 m .48806 .49232 L .48817 .49391 L p .482 .511 .811 r
F P
0 g
s
.51018 .49375 m .51119 .4928 L .51262 .4935 L p .625 .35 .481 r
F P
0 g
s
.51397 .4927 m .51262 .4935 L .51119 .4928 L p .635 .328 .434 r
F P
0 g
s
.49913 .4872 m .49932 .48582 L .50064 .48671 L p .873 .67 .624 r
F P
0 g
s
.50064 .48671 m .50032 .48806 L .49913 .4872 L p .873 .67 .624 r
F P
0 g
s
.50373 .50646 m .50442 .50766 L .50274 .50869 L p .752 .656 .755 r
F P
0 g
s
.50548 .50555 m .50616 .50672 L .50442 .50766 L p .724 .647 .771 r
F P
0 g
s
.50442 .50766 m .50373 .50646 L .50548 .50555 L p .724 .647 .771 r
F P
0 g
s
.49254 .5 m .49115 .5 L .4911 .49803 L p .635 .531 .72 r
F P
0 g
s
.49246 .50198 m .4911 .50197 L .49115 .5 L p .635 .505 .687 r
F P
0 g
s
.49115 .5 m .49254 .5 L .49246 .50198 L p .635 .505 .687 r
F P
0 g
s
.50373 .49354 m .50442 .49234 L .50616 .49328 L p .724 .536 .636 r
F P
0 g
s
.50206 .49248 m .50274 .49131 L .50442 .49234 L p .752 .572 .652 r
F P
0 g
s
.50442 .49234 m .50373 .49354 L .50206 .49248 L p .752 .572 .652 r
F P
0 g
s
.47159 .55476 m .46128 .56906 L .46112 .56935 L p 0 0 0 r
F P
0 g
s
.44783 .59094 m .46112 .56935 L .46128 .56906 L p 0 0 0 r
F P
0 g
s
.56182 .50279 m .57949 .50101 L .57917 .501 L p 0 0 0 r
F P
0 g
s
.57917 .501 m .56163 .50278 L .56182 .50279 L p 0 0 0 r
F P
0 g
s
.46668 .55215 m .45938 .56834 L .45955 .56806 L p .652 .769 .298 r
F P
0 g
s
.45955 .56806 m .46678 .55199 L .46668 .55215 L p .652 .769 .298 r
F P
0 g
s
.46678 .44801 m .45955 .43194 L .45938 .43166 L p .652 .295 0 r
F P
0 g
s
.44733 .40935 m .45938 .43166 L .45955 .43194 L p .625 .236 0 r
F P
0 g
s
.56163 .49722 m .57917 .499 L .57949 .49899 L p 0 .522 .711 r
F P
0 g
s
.60484 .49971 m .57949 .49899 L .57917 .499 L p 0 .563 .709 r
F P
0 g
s
.4715 .44507 m .46112 .43065 L .46128 .43094 L p 0 0 .42 r
F P
0 g
s
.46128 .43094 m .47159 .44524 L .4715 .44507 L p 0 0 .42 r
F P
0 g
s
.50274 .50869 m .50206 .50752 L .50373 .50646 L p .752 .656 .755 r
F P
0 g
s
.50206 .50752 m .50274 .50869 L .50121 .50975 L p .78 .665 .737 r
F P
0 g
s
.50717 .50481 m .50783 .50592 L .50616 .50672 L p .693 .635 .786 r
F P
0 g
s
.50616 .50672 m .50548 .50555 L .50717 .50481 L p .693 .635 .786 r
F P
0 g
s
.49225 .50381 m .49095 .50382 L .4911 .50197 L p .633 .476 .652 r
F P
0 g
s
.4911 .50197 m .49246 .50198 L .49225 .50381 L p .633 .476 .652 r
F P
0 g
s
.4911 .49803 m .49246 .49802 L .49254 .5 L p .635 .531 .72 r
F P
0 g
s
.49246 .49802 m .4911 .49803 L .49095 .49618 L p .633 .558 .752 r
F P
0 g
s
.50616 .49328 m .50548 .49445 L .50373 .49354 L p .724 .536 .636 r
F P
0 g
s
.50548 .49445 m .50616 .49328 L .50783 .49408 L p .693 .497 .618 r
F P
0 g
s
.50058 .49138 m .50121 .49025 L .50274 .49131 L p .78 .608 .667 r
F P
0 g
s
.50274 .49131 m .50206 .49248 L .50058 .49138 L p .78 .608 .667 r
F P
0 g
s
.49781 .51839 m .49712 .52059 L .49604 .52126 L p .956 .946 .714 r
F P
0 g
s
.49472 .52399 m .49604 .52126 L .49712 .52059 L p .931 .971 .732 r
F P
0 g
s
.51798 .5068 m .52039 .5072 L .51928 .5078 L p .464 .776 .998 r
F P
0 g
s
.51928 .5078 m .51702 .5073 L .51798 .5068 L p .464 .776 .998 r
F P
0 g
s
.48512 .51218 m .48357 .51406 L .48361 .51279 L p .113 0 .227 r
F P
0 g
s
.48361 .51279 m .48517 .51109 L .48512 .51218 L p .113 0 .227 r
F P
0 g
s
.48517 .48891 m .48361 .48721 L .48357 .48594 L p .113 .324 .795 r
F P
0 g
s
.48186 .48343 m .48357 .48594 L .48361 .48721 L p .023 .236 .741 r
F P
0 g
s
.51702 .4927 m .51928 .4922 L .52039 .4928 L p .464 0 .025 r
F P
0 g
s
.52342 .49257 m .52039 .4928 L .51928 .4922 L p .47 0 0 r
F P
0 g
s
.49689 .48103 m .49604 .47874 L .49712 .47941 L p .956 .615 .308 r
F P
0 g
s
.49712 .47941 m .49781 .48161 L .49689 .48103 L p .956 .615 .308 r
F P
0 g
s
.49932 .51418 m .49934 .51575 L .49818 .51651 L p .93 .828 .722 r
F P
0 g
s
.49781 .51839 m .49818 .51651 L .49934 .51575 L p .935 .87 .75 r
F P
0 g
s
.51375 .50597 m .51521 .50668 L .51397 .5073 L p .565 .702 .933 r
F P
0 g
s
.51397 .5073 m .51262 .5065 L .51375 .50597 L p .565 .702 .933 r
F P
0 g
s
.48796 .50892 m .48661 .50983 L .48669 .50844 L p .42 .171 .428 r
F P
0 g
s
.48669 .50844 m .48806 .50768 L .48796 .50892 L p .42 .171 .428 r
F P
0 g
s
.48806 .49232 m .48669 .49156 L .48661 .49017 L p .42 .515 .85 r
F P
0 g
s
.48517 .48891 m .48661 .49017 L .48669 .49156 L p .349 .455 .827 r
F P
0 g
s
.4983 .48511 m .49818 .48349 L .49934 .48425 L p .93 .691 .555 r
F P
0 g
s
.49934 .48425 m .49932 .48582 L .4983 .48511 L p .93 .691 .555 r
F P
0 g
s
.51262 .4935 m .51397 .4927 L .51521 .49332 L p .565 .221 .344 r
F P
0 g
s
.51702 .4927 m .51521 .49332 L .51397 .4927 L p .575 .193 .281 r
F P
0 g
s
.71827 .12195 m .71866 .12126 L .71891 .1214 L p .053 .473 .886 r
F P
0 g
s
.71891 .1214 m .71949 .12264 L .71827 .12195 L p .053 .473 .886 r
F P
0 g
s
.71866 .12126 m .71827 .12195 L .71706 .12123 L p .055 .477 .887 r
F P
0 g
s
.06347 .5 m .06267 .5 L .06267 .49972 L p .968 .792 .36 r
F P
0 g
s
.06267 .49972 m .06345 .4986 L .06347 .5 L p .968 .792 .36 r
F P
0 g
s
.06267 .5 m .06347 .5 L .06345 .5014 L p .968 .789 .357 r
F P
0 g
s
.71827 .87805 m .71866 .87874 L .71843 .87888 L p .055 0 0 r
F P
0 g
s
.71843 .87888 m .71706 .87877 L .71827 .87805 L p .055 0 0 r
F P
0 g
s
.71866 .87874 m .71827 .87805 L .71949 .87736 L p .053 0 0 r
F P
0 g
s
.50302 .50523 m .50373 .50646 L .50206 .50752 L p .742 .633 .739 r
F P
0 g
s
.50487 .50432 m .50548 .50555 L .50373 .50646 L p .716 .624 .754 r
F P
0 g
s
.50373 .50646 m .50302 .50523 L .50487 .50432 L p .716 .624 .754 r
F P
0 g
s
.49396 .5 m .49254 .5 L .49246 .49802 L p .658 .55 .721 r
F P
0 g
s
.49383 .50206 m .49246 .50198 L .49254 .5 L p .658 .525 .69 r
F P
0 g
s
.49254 .5 m .49396 .5 L .49383 .50206 L p .658 .525 .69 r
F P
0 g
s
.50302 .49477 m .50373 .49354 L .50548 .49445 L p .716 .545 .657 r
F P
0 g
s
.5013 .49362 m .50206 .49248 L .50373 .49354 L p .742 .579 .672 r
F P
0 g
s
.50373 .49354 m .50302 .49477 L .5013 .49362 L p .742 .579 .672 r
F P
0 g
s
.71949 .12264 m .71891 .1214 L .71914 .12152 L p .048 .469 .883 r
F P
0 g
s
.71914 .12152 m .72068 .12326 L .71949 .12264 L p .048 .469 .883 r
F P
0 g
s
.71706 .87877 m .71843 .87888 L .7182 .87902 L p .055 0 0 r
F P
0 g
s
.7182 .87902 m .71593 .87948 L .71706 .87877 L p .055 0 0 r
F P
0 g
s
.06345 .4986 m .06267 .49972 L .06266 .49946 L p .967 .793 .361 r
F P
0 g
s
.06266 .49946 m .06339 .49726 L .06345 .4986 L p .967 .793 .361 r
F P
0 g
s
.71843 .12112 m .71706 .12123 L .71593 .12052 L p .055 .478 .888 r
F P
0 g
s
.71706 .12123 m .71843 .12112 L .71866 .12126 L p .055 .477 .887 r
F P
0 g
s
.71891 .8786 m .71949 .87736 L .72068 .87674 L p .048 0 0 r
F P
0 g
s
.71949 .87736 m .71891 .8786 L .71866 .87874 L p .053 0 0 r
F P
0 g
s
.06267 .50028 m .06345 .5014 L .06339 .50274 L p .967 .786 .353 r
F P
0 g
s
.06345 .5014 m .06267 .50028 L .06267 .5 L p .968 .789 .357 r
F P
0 g
s
.50121 .50975 m .50058 .50862 L .50206 .50752 L p .78 .665 .737 r
F P
0 g
s
.50058 .50862 m .50121 .50975 L .49988 .51073 L p .809 .673 .714 r
F P
0 g
s
.50032 .51194 m .49988 .51073 L .50121 .50975 L p .823 .704 .734 r
F P
0 g
s
.50869 .50424 m .50936 .50526 L .50783 .50592 L p .656 .62 .802 r
F P
0 g
s
.50783 .50592 m .50717 .50481 L .50869 .50424 L p .656 .62 .802 r
F P
0 g
s
.49198 .5054 m .49076 .50547 L .49095 .50382 L p .629 .442 .61 r
F P
0 g
s
.49095 .50382 m .49225 .50381 L .49198 .5054 L p .629 .442 .61 r
F P
0 g
s
.49095 .49618 m .49225 .49619 L .49246 .49802 L p .633 .558 .752 r
F P
0 g
s
.49225 .49619 m .49095 .49618 L .49076 .49453 L p .629 .586 .787 r
F P
0 g
s
.48949 .49431 m .49076 .49453 L .49095 .49618 L p .596 .561 .786 r
F P
0 g
s
.50783 .49408 m .50717 .49519 L .50548 .49445 L p .693 .497 .618 r
F P
0 g
s
.50717 .49519 m .50783 .49408 L .50936 .49474 L p .656 .451 .594 r
F P
0 g
s
.51018 .49375 m .50936 .49474 L .50783 .49408 L p .664 .436 .563 r
F P
0 g
s
.49933 .49035 m .49988 .48927 L .50121 .49025 L p .809 .648 .683 r
F P
0 g
s
.50121 .49025 m .50058 .49138 L .49933 .49035 L p .809 .648 .683 r
F P
0 g
s
.73522 .13297 m .72412 .12466 L .72446 .12466 L p 0 .416 .856 r
F P
0 g
s
.72446 .12466 m .73631 .13297 L .73522 .13297 L p 0 .416 .856 r
F P
0 g
s
.67098 .10236 m .6997 .11184 L .70025 .11278 L p .192 .613 .946 r
F P
0 g
s
.713 .11824 m .70025 .11278 L .6997 .11184 L p .078 .517 .901 r
F P
0 g
s
.70025 .11278 m .713 .11824 L .71342 .11866 L p .109 .53 .913 r
F P
0 g
s
.70025 .88722 m .713 .88176 L .71283 .88206 L p .078 0 0 r
F P
0 g
s
.71283 .88206 m .6997 .88816 L .70025 .88722 L p .078 0 0 r
F P
0 g
s
.06453 .47981 m .06289 .49358 L .06271 .49328 L p .961 .822 .392 r
F P
0 g
s
.06271 .49328 m .06399 .47886 L .06453 .47981 L p .961 .822 .392 r
F P
0 g
s
.07015 .55075 m .06399 .52114 L .06453 .52019 L p .968 .7 .276 r
F P
0 g
s
.06289 .50642 m .06453 .52019 L .06399 .52114 L p .961 .748 .301 r
F P
0 g
s
.06453 .52019 m .06289 .50642 L .06305 .50584 L p .972 .76 .332 r
F P
0 g
s
.75887 .84689 m .73631 .86703 L .73522 .86703 L p 0 0 0 r
F P
0 g
s
.72412 .87534 m .73522 .86703 L .73631 .86703 L p 0 0 0 r
F P
0 g
s
.73522 .86703 m .72412 .87534 L .72354 .87549 L p .038 0 0 r
F P
0 g
s
.50206 .50752 m .5013 .50638 L .50302 .50523 L p .742 .633 .739 r
F P
0 g
s
.5013 .50638 m .50206 .50752 L .50058 .50862 L p .768 .64 .72 r
F P
0 g
s
.50663 .50366 m .50717 .50481 L .50548 .50555 L p .686 .611 .767 r
F P
0 g
s
.50548 .50555 m .50487 .50432 L .50663 .50366 L p .686 .611 .767 r
F P
0 g
s
.49351 .50391 m .49225 .50381 L .49246 .50198 L p .659 .499 .657 r
F P
0 g
s
.49246 .50198 m .49383 .50206 L .49351 .50391 L p .659 .499 .657 r
F P
0 g
s
.49246 .49802 m .49383 .49794 L .49396 .5 L p .658 .55 .721 r
F P
0 g
s
.49383 .49794 m .49246 .49802 L .49225 .49619 L p .659 .576 .751 r
F P
0 g
s
.50548 .49445 m .50487 .49568 L .50302 .49477 L p .716 .545 .657 r
F P
0 g
s
.50487 .49568 m .50548 .49445 L .50717 .49519 L p .686 .509 .641 r
F P
0 g
s
.49986 .49242 m .50058 .49138 L .50206 .49248 L p .768 .614 .688 r
F P
0 g
s
.50206 .49248 m .5013 .49362 L .49986 .49242 L p .768 .614 .688 r
F P
0 g
s
.49988 .51073 m .50032 .51194 L .49913 .5128 L p .86 .719 .706 r
F P
0 g
s
.49932 .51418 m .49913 .5128 L .50032 .51194 L p .873 .756 .73 r
F P
0 g
s
.51065 .50475 m .51152 .50565 L .51018 .50625 L p .616 .635 .847 r
F P
0 g
s
.51018 .50625 m .50936 .50526 L .51065 .50475 L p .616 .635 .847 r
F P
0 g
s
.49057 .50685 m .48935 .50716 L .48949 .50569 L p .579 .358 .544 r
F P
0 g
s
.48949 .50569 m .49076 .50547 L .49057 .50685 L p .579 .358 .544 r
F P
0 g
s
.49076 .49453 m .48949 .49431 L .48935 .49284 L p .579 .588 .826 r
F P
0 g
s
.48806 .49232 m .48935 .49284 L .48949 .49431 L p .533 .552 .821 r
F P
0 g
s
.50936 .49474 m .51018 .49375 L .51152 .49435 L p .616 .37 .523 r
F P
0 g
s
.51262 .4935 m .51152 .49435 L .51018 .49375 L p .625 .35 .481 r
F P
0 g
s
.49879 .48841 m .49913 .4872 L .50032 .48806 L p .86 .685 .664 r
F P
0 g
s
.50032 .48806 m .49988 .48927 L .49879 .48841 L p .86 .685 .664 r
F P
0 g
s
.49472 .52399 m .49279 .52732 L .49199 .52782 L p .818 .951 .606 r
F P
0 g
s
.48905 .53208 m .49199 .52782 L .49279 .52732 L p .779 .949 .616 r
F P
0 g
s
.5241 .50707 m .52809 .50698 L .52727 .50741 L p .28 .766 .917 r
F P
0 g
s
.52727 .50741 m .52342 .50743 L .5241 .50707 L p .28 .766 .917 r
F P
0 g
s
.48183 .51734 m .47991 .52084 L .47994 .51991 L p 0 0 0 r
F P
0 g
s
.47994 .51991 m .48186 .51657 L .48183 .51734 L p 0 0 0 r
F P
0 g
s
.48186 .48343 m .47994 .48009 L .47991 .47916 L p 0 0 .57 r
F P
0 g
s
.47769 .47448 m .47991 .47916 L .47994 .48009 L p 0 0 .513 r
F P
0 g
s
.49407 .47559 m .49199 .47218 L .49279 .47268 L p .818 .384 0 r
F P
0 g
s
.49279 .47268 m .49472 .47601 L .49407 .47559 L p .818 .384 0 r
F P
0 g
s
.52342 .49257 m .52727 .49259 L .52809 .49302 L p .28 0 0 r
F P
0 g
s
.53326 .49344 m .52809 .49302 L .52727 .49259 L p .291 0 0 r
F P
0 g
s
.50227 .50392 m .50302 .50523 L .5013 .50638 L p .733 .613 .724 r
F P
0 g
s
.50433 .503 m .50487 .50432 L .50302 .50523 L p .709 .605 .738 r
F P
0 g
s
.50302 .50523 m .50227 .50392 L .50433 .503 L p .709 .605 .738 r
F P
0 g
s
.49547 .5 m .49396 .5 L .49383 .49794 L p .678 .565 .72 r
F P
0 g
s
.49523 .50225 m .49383 .50206 L .49396 .5 L p .677 .542 .692 r
F P
0 g
s
.49396 .5 m .49547 .5 L .49523 .50225 L p .677 .542 .692 r
F P
0 g
s
.50227 .49608 m .50302 .49477 L .50487 .49568 L p .709 .553 .674 r
F P
0 g
s
.50044 .49475 m .5013 .49362 L .50302 .49477 L p .733 .584 .688 r
F P
0 g
s
.50302 .49477 m .50227 .49608 L .50044 .49475 L p .733 .584 .688 r
F P
0 g
s
.72068 .12326 m .71914 .12152 L .71936 .12163 L p .041 .464 .88 r
F P
0 g
s
.71936 .12163 m .72178 .12379 L .72068 .12326 L p .041 .464 .88 r
F P
0 g
s
.71593 .87948 m .7182 .87902 L .718 .87916 L p .053 0 0 r
F P
0 g
s
.718 .87916 m .71491 .88017 L .71593 .87948 L p .053 0 0 r
F P
0 g
s
.7182 .12098 m .71593 .12052 L .71491 .11983 L p .053 .479 .887 r
F P
0 g
s
.71593 .12052 m .7182 .12098 L .71843 .12112 L p .055 .478 .888 r
F P
0 g
s
.06339 .49726 m .06266 .49946 L .06264 .49921 L p .966 .794 .36 r
F P
0 g
s
.06264 .49921 m .06331 .49604 L .06339 .49726 L p .966 .794 .36 r
F P
0 g
s
.71914 .87848 m .72068 .87674 L .72178 .87621 L p .041 0 0 r
F P
0 g
s
.72068 .87674 m .71914 .87848 L .71891 .8786 L p .048 0 0 r
F P
0 g
s
.06266 .50054 m .06339 .50274 L .06331 .50396 L p .966 .783 .347 r
F P
0 g
s
.06339 .50274 m .06266 .50054 L .06267 .50028 L p .967 .786 .353 r
F P
0 g
s
.5013 .50638 m .50044 .50525 L .50227 .50392 L p .733 .613 .724 r
F P
0 g
s
.50044 .50525 m .5013 .50638 L .49986 .50758 L p .756 .616 .705 r
F P
0 g
s
.50058 .50862 m .49986 .50758 L .5013 .50638 L p .768 .64 .72 r
F P
0 g
s
.50622 .50247 m .50663 .50366 L .50487 .50432 L p .68 .59 .749 r
F P
0 g
s
.50487 .50432 m .50433 .503 L .50622 .50247 L p .68 .59 .749 r
F P
0 g
s
.49475 .50415 m .49351 .50391 L .49383 .50206 L p .681 .52 .662 r
F P
0 g
s
.49383 .50206 m .49523 .50225 L .49475 .50415 L p .681 .52 .662 r
F P
0 g
s
.49383 .49794 m .49523 .49775 L .49547 .5 L p .678 .565 .72 r
F P
0 g
s
.49523 .49775 m .49383 .49794 L .49351 .49609 L p .681 .591 .749 r
F P
0 g
s
.49225 .49619 m .49351 .49609 L .49383 .49794 L p .659 .576 .751 r
F P
0 g
s
.50487 .49568 m .50433 .497 L .50227 .49608 L p .709 .553 .674 r
F P
0 g
s
.50433 .497 m .50487 .49568 L .50663 .49634 L p .68 .52 .662 r
F P
0 g
s
.50717 .49519 m .50663 .49634 L .50487 .49568 L p .686 .509 .641 r
F P
0 g
s
.49903 .49338 m .49986 .49242 L .5013 .49362 L p .756 .617 .706 r
F P
0 g
s
.5013 .49362 m .50044 .49475 L .49903 .49338 L p .756 .617 .706 r
F P
0 g
s
.49986 .50758 m .50058 .50862 L .49933 .50965 L p .795 .644 .695 r
F P
0 g
s
.49988 .51073 m .49933 .50965 L .50058 .50862 L p .809 .673 .714 r
F P
0 g
s
.50818 .5032 m .50869 .50424 L .50717 .50481 L p .649 .594 .779 r
F P
0 g
s
.50717 .50481 m .50663 .50366 L .50818 .5032 L p .649 .594 .779 r
F P
0 g
s
.49314 .50548 m .49198 .5054 L .49225 .50381 L p .659 .469 .617 r
F P
0 g
s
.49225 .50381 m .49351 .50391 L .49314 .50548 L p .659 .469 .617 r
F P
0 g
s
.49351 .49609 m .49225 .49619 L .49198 .4946 L p .659 .607 .785 r
F P
0 g
s
.49076 .49453 m .49198 .4946 L .49225 .49619 L p .629 .586 .787 r
F P
0 g
s
.50663 .49634 m .50717 .49519 L .50869 .49576 L p .649 .466 .622 r
F P
0 g
s
.50936 .49474 m .50869 .49576 L .50717 .49519 L p .656 .451 .594 r
F P
0 g
s
.49868 .49132 m .49933 .49035 L .50058 .49138 L p .795 .654 .706 r
F P
0 g
s
.50058 .49138 m .49986 .49242 L .49868 .49132 L p .795 .654 .706 r
F P
0 g
s
.50141 .50244 m .50227 .50392 L .50044 .50525 L p .724 .596 .712 r
F P
0 g
s
.50391 .50156 m .50433 .503 L .50227 .50392 L p .703 .588 .725 r
F P
0 g
s
.50227 .50392 m .50141 .50244 L .50391 .50156 L p .703 .588 .725 r
F P
0 g
s
.49719 .5 m .49547 .5 L .49523 .49775 L p .694 .576 .719 r
F P
0 g
s
.49669 .50261 m .49523 .50225 L .49547 .5 L p .693 .556 .695 r
F P
0 g
s
.49547 .5 m .49719 .5 L .49669 .50261 L p .693 .556 .695 r
F P
0 g
s
.50141 .49756 m .50227 .49608 L .50433 .497 L p .703 .56 .689 r
F P
0 g
s
.4994 .49583 m .50044 .49475 L .50227 .49608 L p .724 .587 .701 r
F P
0 g
s
.50227 .49608 m .50141 .49756 L .4994 .49583 L p .724 .587 .701 r
F P
0 g
s
.49913 .5128 m .49932 .51418 L .4983 .51489 L p .921 .784 .693 r
F P
0 g
s
.49818 .51651 m .4983 .51489 L .49932 .51418 L p .93 .828 .722 r
F P
0 g
s
.51258 .50519 m .51375 .50597 L .51262 .5065 L p .555 .658 .905 r
F P
0 g
s
.51262 .5065 m .51152 .50565 L .51258 .50519 L p .555 .658 .905 r
F P
0 g
s
.48921 .5083 m .48796 .50892 L .48806 .50768 L p .485 .224 .442 r
F P
0 g
s
.48806 .50768 m .48935 .50716 L .48921 .5083 L p .485 .224 .442 r
F P
0 g
s
.48935 .49284 m .48806 .49232 L .48796 .49108 L p .485 .569 .865 r
F P
0 g
s
.48661 .49017 m .48796 .49108 L .48806 .49232 L p .42 .515 .85 r
F P
0 g
s
.51152 .49435 m .51262 .4935 L .51375 .49403 L p .555 .248 .402 r
F P
0 g
s
.51521 .49332 m .51375 .49403 L .51262 .4935 L p .565 .221 .344 r
F P
0 g
s
.4982 .48651 m .4983 .48511 L .49932 .48582 L p .921 .719 .613 r
F P
0 g
s
.49932 .48582 m .49913 .4872 L .4982 .48651 L p .921 .719 .613 r
F P
0 g
s
.49818 .51651 m .49781 .51839 L .49689 .51897 L p .972 .911 .688 r
F P
0 g
s
.49604 .52126 m .49689 .51897 L .49781 .51839 L p .956 .946 .714 r
F P
0 g
s
.51606 .50625 m .51798 .5068 L .51702 .5073 L p .455 .733 .987 r
F P
0 g
s
.51702 .5073 m .51521 .50668 L .51606 .50625 L p .455 .733 .987 r
F P
0 g
s
.48655 .51079 m .48512 .51218 L .48517 .51109 L p .206 0 .246 r
F P
0 g
s
.48517 .51109 m .48661 .50983 L .48655 .51079 L p .206 0 .246 r
F P
0 g
s
.48661 .49017 m .48517 .48891 L .48512 .48782 L p .206 .412 .843 r
F P
0 g
s
.48357 .48594 m .48512 .48782 L .48517 .48891 L p .113 .324 .795 r
F P
0 g
s
.51521 .49332 m .51702 .4927 L .51798 .4932 L p .455 .01 .102 r
F P
0 g
s
.52039 .4928 m .51798 .4932 L .51702 .4927 L p .464 0 .025 r
F P
0 g
s
.49738 .48296 m .49689 .48103 L .49781 .48161 L p .972 .676 .4 r
F P
0 g
s
.49781 .48161 m .49818 .48349 L .49738 .48296 L p .972 .676 .4 r
F P
0 g
s
.50001 .50001 m .50141 .50244 L .4994 .50417 L p .715 .581 .704 r
F P
0 g
s
.50374 .5 m .50391 .50156 L .50141 .50244 L p .7 .577 .714 r
F P
0 g
s
.50141 .50244 m .50001 .50001 L .50374 .5 L p .7 .577 .714 r
F P
0 g
s
.50044 .50525 m .4994 .50417 L .50141 .50244 L p .724 .596 .712 r
F P
0 g
s
.49999 .5 m .49719 .5 L .49669 .49739 L p .706 .584 .716 r
F P
0 g
s
.49813 .50324 m .49669 .50261 L .49719 .5 L p .705 .568 .698 r
F P
0 g
s
.49719 .5 m .49999 .5 L .49813 .50324 L p .705 .568 .698 r
F P
0 g
s
.49523 .49775 m .49669 .49739 L .49719 .5 L p .694 .576 .719 r
F P
0 g
s
.50001 .49999 m .50141 .49756 L .50391 .49844 L p .7 .567 .702 r
F P
0 g
s
.49813 .49676 m .4994 .49583 L .50141 .49756 L p .716 .587 .71 r
F P
0 g
s
.50141 .49756 m .50001 .49999 L .49813 .49676 L p .716 .587 .71 r
F P
0 g
s
.50433 .497 m .50391 .49844 L .50141 .49756 L p .703 .56 .689 r
F P
0 g
s
.4994 .50417 m .50044 .50525 L .49903 .50662 L p .743 .595 .692 r
F P
0 g
s
.49986 .50758 m .49903 .50662 L .50044 .50525 L p .756 .616 .705 r
F P
0 g
s
.50596 .50124 m .50622 .50247 L .50433 .503 L p .675 .572 .731 r
F P
0 g
s
.50433 .503 m .50391 .50156 L .50596 .50124 L p .675 .572 .731 r
F P
0 g
s
.49595 .50454 m .49475 .50415 L .49523 .50225 L p .699 .539 .667 r
F P
0 g
s
.49523 .50225 m .49669 .50261 L .49595 .50454 L p .699 .539 .667 r
F P
0 g
s
.49669 .49739 m .49523 .49775 L .49475 .49585 L p .7 .603 .745 r
F P
0 g
s
.49351 .49609 m .49475 .49585 L .49523 .49775 L p .681 .591 .749 r
F P
0 g
s
.50391 .49844 m .50433 .497 L .50622 .49753 L p .675 .531 .681 r
F P
0 g
s
.50663 .49634 m .50622 .49753 L .50433 .497 L p .68 .52 .662 r
F P
0 g
s
.4981 .49422 m .49903 .49338 L .50044 .49475 L p .743 .618 .72 r
F P
0 g
s
.50044 .49475 m .4994 .49583 L .4981 .49422 L p .743 .618 .72 r
F P
0 g
s
.4994 .50417 m .49813 .50324 L .50001 .50001 L p .715 .581 .704 r
F P
0 g
s
.49669 .49739 m .49813 .49676 L .49999 .5 L p .706 .584 .716 r
F P
0 g
s
.50391 .49844 m .50374 .5 L .50001 .49999 L p .7 .567 .702 r
F P
0 g
s
.49933 .50965 m .49988 .51073 L .49879 .51159 L p .844 .683 .683 r
F P
0 g
s
.49913 .5128 m .49879 .51159 L .49988 .51073 L p .86 .719 .706 r
F P
0 g
s
.50996 .50381 m .51065 .50475 L .50936 .50526 L p .607 .601 .82 r
F P
0 g
s
.50936 .50526 m .50869 .50424 L .50996 .50381 L p .607 .601 .82 r
F P
0 g
s
.49172 .50672 m .49057 .50685 L .49076 .50547 L p .619 .394 .553 r
F P
0 g
s
.49076 .50547 m .49198 .5054 L .49172 .50672 L p .619 .394 .553 r
F P
0 g
s
.49198 .4946 m .49076 .49453 L .49057 .49315 L p .62 .617 .827 r
F P
0 g
s
.48935 .49284 m .49057 .49315 L .49076 .49453 L p .579 .588 .826 r
F P
0 g
s
.50869 .49576 m .50936 .49474 L .51065 .49525 L p .607 .39 .561 r
F P
0 g
s
.51152 .49435 m .51065 .49525 L .50936 .49474 L p .616 .37 .523 r
F P
0 g
s
.49832 .48946 m .49879 .48841 L .49988 .48927 L p .844 .695 .697 r
F P
0 g
s
.49988 .48927 m .49933 .49035 L .49832 .48946 L p .844 .695 .697 r
F P
0 g
s
.49813 .50324 m .4994 .50417 L .4981 .50578 L p .73 .576 .682 r
F P
0 g
s
.49903 .50662 m .4981 .50578 L .4994 .50417 L p .743 .595 .692 r
F P
0 g
s
.49707 .50508 m .49595 .50454 L .49669 .50261 L p .716 .557 .673 r
F P
0 g
s
.49669 .50261 m .49813 .50324 L .49707 .50508 L p .716 .557 .673 r
F P
0 g
s
.50587 .5 m .50596 .50124 L .50391 .50156 L p .673 .556 .715 r
F P
0 g
s
.50391 .50156 m .50374 .5 L .50587 .5 L p .673 .556 .715 r
F P
0 g
s
.49813 .49676 m .49669 .49739 L .49595 .49546 L p .716 .611 .739 r
F P
0 g
s
.49475 .49585 m .49595 .49546 L .49669 .49739 L p .7 .603 .745 r
F P
0 g
s
.50374 .5 m .50391 .49844 L .50596 .49876 L p .673 .543 .698 r
F P
0 g
s
.50622 .49753 m .50596 .49876 L .50391 .49844 L p .675 .531 .681 r
F P
0 g
s
.49707 .49492 m .4981 .49422 L .4994 .49583 L p .73 .616 .731 r
F P
0 g
s
.4994 .49583 m .49813 .49676 L .49707 .49492 L p .73 .616 .731 r
F P
0 g
s
.49903 .50662 m .49986 .50758 L .49868 .50868 L p .779 .617 .679 r
F P
0 g
s
.49933 .50965 m .49868 .50868 L .49986 .50758 L p .795 .644 .695 r
F P
0 g
s
.50781 .50213 m .50818 .5032 L .50663 .50366 L p .643 .57 .757 r
F P
0 g
s
.50663 .50366 m .50622 .50247 L .50781 .50213 L p .643 .57 .757 r
F P
0 g
s
.49425 .5057 m .49314 .50548 L .49351 .50391 L p .685 .495 .624 r
F P
0 g
s
.49351 .50391 m .49475 .50415 L .49425 .5057 L p .685 .495 .624 r
F P
0 g
s
.49475 .49585 m .49351 .49609 L .49314 .49452 L p .685 .623 .781 r
F P
0 g
s
.49198 .4946 m .49314 .49452 L .49351 .49609 L p .659 .607 .785 r
F P
0 g
s
.50622 .49753 m .50663 .49634 L .50818 .4968 L p .643 .481 .648 r
F P
0 g
s
.50869 .49576 m .50818 .4968 L .50663 .49634 L p .649 .466 .622 r
F P
0 g
s
.49794 .49217 m .49868 .49132 L .49986 .49242 L p .78 .656 .726 r
F P
0 g
s
.49986 .49242 m .49903 .49338 L .49794 .49217 L p .78 .656 .726 r
F P
0 g
s
.4981 .50578 m .49707 .50508 L .49813 .50324 L p .73 .576 .682 r
F P
0 g
s
.50596 .49876 m .50587 .5 L .50374 .5 L p .673 .543 .698 r
F P
0 g
s
.49595 .49546 m .49707 .49492 L .49813 .49676 L p .716 .611 .739 r
F P
0 g
s
.4981 .50578 m .49903 .50662 L .49794 .50783 L p .763 .591 .664 r
F P
0 g
s
.49868 .50868 m .49794 .50783 L .49903 .50662 L p .779 .617 .679 r
F P
0 g
s
.49529 .50605 m .49425 .5057 L .49475 .50415 L p .708 .519 .632 r
F P
0 g
s
.49475 .50415 m .49595 .50454 L .49529 .50605 L p .708 .519 .632 r
F P
0 g
s
.50759 .50106 m .50781 .50213 L .50622 .50247 L p .639 .548 .736 r
F P
0 g
s
.50622 .50247 m .50596 .50124 L .50759 .50106 L p .639 .548 .736 r
F P
0 g
s
.49595 .49546 m .49475 .49585 L .49425 .4943 L p .708 .636 .775 r
F P
0 g
s
.49314 .49452 m .49425 .4943 L .49475 .49585 L p .685 .623 .781 r
F P
0 g
s
.50596 .49876 m .50622 .49753 L .50781 .49787 L p .639 .496 .671 r
F P
0 g
s
.50818 .4968 m .50781 .49787 L .50622 .49753 L p .643 .481 .648 r
F P
0 g
s
.49712 .49289 m .49794 .49217 L .49903 .49338 L p .763 .655 .743 r
F P
0 g
s
.49903 .49338 m .4981 .49422 L .49712 .49289 L p .763 .655 .743 r
F P
0 g
s
.72178 .12379 m .71936 .12163 L .71955 .12171 L p .033 .458 .877 r
F P
0 g
s
.71955 .12171 m .72275 .12422 L .72178 .12379 L p .033 .458 .877 r
F P
0 g
s
.718 .12084 m .71491 .11983 L .71406 .1192 L p .049 .478 .886 r
F P
0 g
s
.71491 .11983 m .718 .12084 L .7182 .12098 L p .053 .479 .887 r
F P
0 g
s
.71491 .88017 m .718 .87916 L .71783 .87928 L p .049 0 0 r
F P
0 g
s
.71783 .87928 m .71406 .8808 L .71491 .88017 L p .049 0 0 r
F P
0 g
s
.71936 .87837 m .72178 .87621 L .72275 .87578 L p .033 0 0 r
F P
0 g
s
.72178 .87621 m .71936 .87837 L .71914 .87848 L p .041 0 0 r
F P
0 g
s
.06264 .50079 m .06331 .50396 L .06319 .50501 L p .964 .779 .339 r
F P
0 g
s
.06331 .50396 m .06264 .50079 L .06266 .50054 L p .966 .783 .347 r
F P
0 g
s
.06331 .49604 m .06264 .49921 L .06262 .49901 L p .964 .794 .357 r
F P
0 g
s
.06262 .49901 m .06319 .49499 L .06331 .49604 L p .964 .794 .357 r
F P
0 g
s
.4793 .54479 m .47159 .55476 L .4715 .55493 L p 0 0 0 r
F P
0 g
s
.46112 .56935 m .4715 .55493 L .47159 .55476 L p 0 0 0 r
F P
0 g
s
.54926 .50448 m .56182 .50279 L .56163 .50278 L p 0 0 0 r
F P
0 g
s
.56163 .50278 m .54914 .50447 L .54926 .50448 L p 0 0 0 r
F P
0 g
s
.47149 .54042 m .46668 .55215 L .46678 .55199 L p .663 .76 .277 r
F P
0 g
s
.46678 .55199 m .47156 .54032 L .47149 .54042 L p .663 .76 .277 r
F P
0 g
s
.47156 .45968 m .46678 .44801 L .46668 .44785 L p .663 .322 0 r
F P
0 g
s
.45938 .43166 m .46668 .44785 L .46678 .44801 L p .652 .295 0 r
F P
0 g
s
.47925 .4551 m .4715 .44507 L .47159 .44524 L p 0 0 .441 r
F P
0 g
s
.47159 .44524 m .4793 .45521 L .47925 .4551 L p 0 0 .441 r
F P
0 g
s
.54914 .49553 m .56163 .49722 L .56182 .49721 L p 0 .502 .71 r
F P
0 g
s
.57949 .49899 m .56182 .49721 L .56163 .49722 L p 0 .522 .711 r
F P
0 g
s
.49868 .50868 m .49933 .50965 L .49832 .51054 L p .826 .648 .662 r
F P
0 g
s
.49879 .51159 m .49832 .51054 L .49933 .50965 L p .844 .683 .683 r
F P
0 g
s
.50945 .50286 m .50996 .50381 L .50869 .50424 L p .6 .57 .793 r
F P
0 g
s
.50869 .50424 m .50818 .5032 L .50945 .50286 L p .6 .57 .793 r
F P
0 g
s
.4928 .50675 m .49172 .50672 L .49198 .5054 L p .655 .428 .563 r
F P
0 g
s
.49198 .5054 m .49314 .50548 L .4928 .50675 L p .655 .428 .563 r
F P
0 g
s
.49314 .49452 m .49198 .4946 L .49172 .49328 L p .655 .642 .825 r
F P
0 g
s
.49057 .49315 m .49172 .49328 L .49198 .4946 L p .62 .617 .827 r
F P
0 g
s
.50818 .4968 m .50869 .49576 L .50996 .49619 L p .6 .409 .595 r
F P
0 g
s
.51065 .49525 m .50996 .49619 L .50869 .49576 L p .607 .39 .561 r
F P
0 g
s
.49775 .49039 m .49832 .48946 L .49933 .49035 L p .826 .701 .726 r
F P
0 g
s
.49933 .49035 m .49868 .49132 L .49775 .49039 L p .826 .701 .726 r
F P
0 g
s
.49707 .50508 m .4981 .50578 L .49712 .50711 L p .746 .567 .652 r
F P
0 g
s
.49794 .50783 m .49712 .50711 L .4981 .50578 L p .763 .591 .664 r
F P
0 g
s
.49624 .50652 m .49529 .50605 L .49595 .50454 L p .728 .543 .641 r
F P
0 g
s
.49595 .50454 m .49707 .50508 L .49624 .50652 L p .728 .543 .641 r
F P
0 g
s
.50752 .5 m .50759 .50106 L .50596 .50124 L p .637 .529 .714 r
F P
0 g
s
.50596 .50124 m .50587 .5 L .50752 .5 L p .637 .529 .714 r
F P
0 g
s
.49707 .49492 m .49595 .49546 L .49529 .49395 L p .728 .646 .767 r
F P
0 g
s
.49425 .4943 m .49529 .49395 L .49595 .49546 L p .708 .636 .775 r
F P
0 g
s
.50587 .5 m .50596 .49876 L .50759 .49894 L p .637 .512 .693 r
F P
0 g
s
.50781 .49787 m .50759 .49894 L .50596 .49876 L p .639 .496 .671 r
F P
0 g
s
.49624 .49348 m .49712 .49289 L .4981 .49422 L p .746 .652 .756 r
F P
0 g
s
.4981 .49422 m .49707 .49492 L .49624 .49348 L p .746 .652 .756 r
F P
0 g
s
.61892 .09437 m .6715 .10115 L .67098 .10236 L p .229 .705 .938 r
F P
0 g
s
.6997 .11184 m .67098 .10236 L .6715 .10115 L p .107 .577 .913 r
F P
0 g
s
.75887 .15311 m .73631 .13297 L .73661 .13251 L p 0 .307 .792 r
F P
0 g
s
.73661 .13251 m .75967 .15205 L .75887 .15311 L p 0 .307 .792 r
F P
0 g
s
.79183 .8058 m .75967 .84795 L .75887 .84689 L p 0 0 0 r
F P
0 g
s
.73631 .86703 m .75887 .84689 L .75967 .84795 L p 0 0 0 r
F P
0 g
s
.07015 .44925 m .06399 .47886 L .06344 .47884 L p .935 .863 .434 r
F P
0 g
s
.06344 .47884 m .06883 .4491 L .07015 .44925 L p .935 .863 .434 r
F P
0 g
s
.08925 .59983 m .06883 .5509 L .07015 .55075 L p .89 .52 .051 r
F P
0 g
s
.06399 .52114 m .07015 .55075 L .06883 .5509 L p .935 .665 .192 r
F P
0 g
s
.67098 .89764 m .6997 .88816 L .69995 .88866 L p .107 0 0 r
F P
0 g
s
.69995 .88866 m .6715 .89885 L .67098 .89764 L p .107 0 0 r
F P
0 g
s
.49712 .50711 m .49624 .50652 L .49707 .50508 L p .746 .567 .652 r
F P
0 g
s
.50759 .49894 m .50752 .5 L .50587 .5 L p .637 .512 .693 r
F P
0 g
s
.49529 .49395 m .49624 .49348 L .49707 .49492 L p .728 .646 .767 r
F P
0 g
s
.49879 .51159 m .49913 .5128 L .4982 .51349 L p .906 .74 .665 r
F P
0 g
s
.4983 .51489 m .4982 .51349 L .49913 .5128 L p .921 .784 .693 r
F P
0 g
s
.51166 .50436 m .51258 .50519 L .51152 .50565 L p .544 .615 .874 r
F P
0 g
s
.51152 .50565 m .51065 .50475 L .51166 .50436 L p .544 .615 .874 r
F P
0 g
s
.49039 .50792 m .48921 .5083 L .48935 .50716 L p .544 .273 .455 r
F P
0 g
s
.48935 .50716 m .49057 .50685 L .49039 .50792 L p .544 .273 .455 r
F P
0 g
s
.49057 .49315 m .48935 .49284 L .48921 .4917 L p .544 .615 .874 r
F P
0 g
s
.48796 .49108 m .48921 .4917 L .48935 .49284 L p .485 .569 .865 r
F P
0 g
s
.51065 .49525 m .51152 .49435 L .51258 .49481 L p .544 .273 .455 r
F P
0 g
s
.51375 .49403 m .51258 .49481 L .51152 .49435 L p .555 .248 .402 r
F P
0 g
s
.49795 .48772 m .4982 .48651 L .49913 .4872 L p .906 .74 .664 r
F P
0 g
s
.49913 .4872 m .49879 .48841 L .49795 .48772 L p .906 .74 .664 r
F P
0 g
s
.52097 .5069 m .5241 .50707 L .52342 .50743 L p .265 .742 .935 r
F P
0 g
s
.52342 .50743 m .52039 .5072 L .52097 .5069 L p .265 .742 .935 r
F P
0 g
s
.49604 .52126 m .49472 .52399 L .49407 .52441 L p .862 .948 .59 r
F P
0 g
s
.49199 .52782 m .49407 .52441 L .49472 .52399 L p .818 .951 .606 r
F P
0 g
s
.48354 .51471 m .48183 .51734 L .48186 .51657 L p 0 0 0 r
F P
0 g
s
.48186 .51657 m .48357 .51406 L .48354 .51471 L p 0 0 0 r
F P
0 g
s
.48357 .48594 m .48186 .48343 L .48183 .48266 L p 0 .076 .637 r
F P
0 g
s
.47991 .47916 m .48183 .48266 L .48186 .48343 L p 0 0 .57 r
F P
0 g
s
.52039 .4928 m .52342 .49257 L .5241 .49293 L p .265 0 0 r
F P
0 g
s
.52809 .49302 m .5241 .49293 L .52342 .49257 L p .28 0 0 r
F P
0 g
s
.49549 .47839 m .49407 .47559 L .49472 .47601 L p .862 .46 0 r
F P
0 g
s
.49472 .47601 m .49604 .47874 L .49549 .47839 L p .862 .46 0 r
F P
0 g
s
.4983 .51489 m .49818 .51651 L .49738 .51704 L p .979 .868 .658 r
F P
0 g
s
.49689 .51897 m .49738 .51704 L .49818 .51651 L p .972 .911 .688 r
F P
0 g
s
.51453 .50561 m .51606 .50625 L .51521 .50668 L p .444 .684 .967 r
F P
0 g
s
.51521 .50668 m .51375 .50597 L .51453 .50561 L p .444 .684 .967 r
F P
0 g
s
.48788 .50978 m .48655 .51079 L .48661 .50983 L p .296 0 .264 r
F P
0 g
s
.48661 .50983 m .48796 .50892 L .48788 .50978 L p .296 0 .264 r
F P
0 g
s
.48796 .49108 m .48661 .49017 L .48655 .48921 L p .296 .494 .882 r
F P
0 g
s
.48512 .48782 m .48655 .48921 L .48661 .49017 L p .206 .412 .843 r
F P
0 g
s
.51375 .49403 m .51521 .49332 L .51606 .49375 L p .444 .041 .179 r
F P
0 g
s
.51798 .4932 m .51606 .49375 L .51521 .49332 L p .455 .01 .102 r
F P
0 g
s
.49759 .48461 m .49738 .48296 L .49818 .48349 L p .979 .73 .488 r
F P
0 g
s
.49818 .48349 m .4983 .48511 L .49759 .48461 L p .979 .73 .488 r
F P
0 g
s
.49794 .50783 m .49868 .50868 L .49775 .50961 L p .807 .615 .642 r
F P
0 g
s
.49832 .51054 m .49775 .50961 L .49868 .50868 L p .826 .648 .662 r
F P
0 g
s
.5091 .5019 m .50945 .50286 L .50818 .5032 L p .594 .541 .765 r
F P
0 g
s
.50818 .5032 m .50781 .50213 L .5091 .5019 L p .594 .541 .765 r
F P
0 g
s
.49381 .50693 m .4928 .50675 L .49314 .50548 L p .688 .461 .573 r
F P
0 g
s
.49314 .50548 m .49425 .5057 L .49381 .50693 L p .688 .461 .573 r
F P
0 g
s
.49425 .4943 m .49314 .49452 L .4928 .49325 L p .688 .662 .819 r
F P
0 g
s
.49172 .49328 m .4928 .49325 L .49314 .49452 L p .655 .642 .825 r
F P
0 g
s
.50781 .49787 m .50818 .4968 L .50945 .49714 L p .594 .428 .627 r
F P
0 g
s
.50996 .49619 m .50945 .49714 L .50818 .4968 L p .6 .409 .595 r
F P
0 g
s
.4971 .49117 m .49775 .49039 L .49868 .49132 L p .807 .703 .75 r
F P
0 g
s
.49868 .49132 m .49794 .49217 L .4971 .49117 L p .807 .703 .75 r
F P
0 g
s
.49712 .50711 m .49794 .50783 L .4971 .50883 L p .787 .583 .625 r
F P
0 g
s
.49775 .50961 m .4971 .50883 L .49794 .50783 L p .807 .615 .642 r
F P
0 g
s
.49474 .50723 m .49381 .50693 L .49425 .5057 L p .716 .492 .584 r
F P
0 g
s
.49425 .5057 m .49529 .50605 L .49474 .50723 L p .716 .492 .584 r
F P
0 g
s
.50889 .50094 m .5091 .5019 L .50781 .50213 L p .59 .515 .738 r
F P
0 g
s
.50781 .50213 m .50759 .50106 L .50889 .50094 L p .59 .515 .738 r
F P
0 g
s
.49529 .49395 m .49425 .4943 L .49381 .49307 L p .716 .678 .811 r
F P
0 g
s
.4928 .49325 m .49381 .49307 L .49425 .4943 L p .688 .662 .819 r
F P
0 g
s
.50759 .49894 m .50781 .49787 L .5091 .4981 L p .59 .448 .657 r
F P
0 g
s
.50945 .49714 m .5091 .4981 L .50781 .49787 L p .594 .428 .627 r
F P
0 g
s
.49637 .49183 m .4971 .49117 L .49794 .49217 L p .787 .702 .771 r
F P
0 g
s
.49794 .49217 m .49712 .49289 L .49637 .49183 L p .787 .702 .771 r
F P
0 g
s
.49832 .51054 m .49879 .51159 L .49795 .51228 L p .888 .696 .637 r
F P
0 g
s
.4982 .51349 m .49795 .51228 L .49879 .51159 L p .906 .74 .665 r
F P
0 g
s
.51095 .5035 m .51166 .50436 L .51065 .50475 L p .534 .574 .841 r
F P
0 g
s
.51065 .50475 m .50996 .50381 L .51095 .5035 L p .534 .574 .841 r
F P
0 g
s
.49149 .50773 m .49039 .50792 L .49057 .50685 L p .596 .32 .468 r
F P
0 g
s
.49057 .50685 m .49172 .50672 L .49149 .50773 L p .596 .32 .468 r
F P
0 g
s
.49172 .49328 m .49057 .49315 L .49039 .49208 L p .596 .653 .877 r
F P
0 g
s
.48921 .4917 m .49039 .49208 L .49057 .49315 L p .544 .615 .874 r
F P
0 g
s
.50996 .49619 m .51065 .49525 L .51166 .49564 L p .534 .299 .504 r
F P
0 g
s
.51258 .49481 m .51166 .49564 L .51065 .49525 L p .544 .273 .455 r
F P
0 g
s
.49756 .48877 m .49795 .48772 L .49879 .48841 L p .888 .754 .708 r
F P
0 g
s
.49879 .48841 m .49832 .48946 L .49756 .48877 L p .888 .754 .708 r
F P
0 g
s
.49624 .50652 m .49712 .50711 L .49637 .50817 L p .765 .552 .61 r
F P
0 g
s
.4971 .50883 m .49637 .50817 L .49712 .50711 L p .787 .583 .625 r
F P
0 g
s
.49559 .50764 m .49474 .50723 L .49529 .50605 L p .742 .522 .596 r
F P
0 g
s
.49529 .50605 m .49624 .50652 L .49559 .50764 L p .742 .522 .596 r
F P
0 g
s
.50883 .5 m .50889 .50094 L .50759 .50106 L p .588 .491 .712 r
F P
0 g
s
.50759 .50106 m .50752 .5 L .50883 .5 L p .588 .491 .712 r
F P
0 g
s
.49624 .49348 m .49529 .49395 L .49474 .49277 L p .742 .689 .801 r
F P
0 g
s
.49381 .49307 m .49474 .49277 L .49529 .49395 L p .716 .678 .811 r
F P
0 g
s
.50752 .5 m .50759 .49894 L .50889 .49906 L p .588 .469 .685 r
F P
0 g
s
.5091 .4981 m .50889 .49906 L .50759 .49894 L p .59 .448 .657 r
F P
0 g
s
.49559 .49236 m .49637 .49183 L .49712 .49289 L p .765 .697 .787 r
F P
0 g
s
.49712 .49289 m .49624 .49348 L .49559 .49236 L p .765 .697 .787 r
F P
0 g
s
.49637 .50817 m .49559 .50764 L .49624 .50652 L p .765 .552 .61 r
F P
0 g
s
.50889 .49906 m .50883 .5 L .50752 .5 L p .588 .469 .685 r
F P
0 g
s
.49474 .49277 m .49559 .49236 L .49624 .49348 L p .742 .689 .801 r
F P
0 g
s
.71783 .12072 m .71406 .1192 L .71342 .11866 L p .042 .476 .883 r
F P
0 g
s
.71406 .1192 m .71783 .12072 L .718 .12084 L p .049 .478 .886 r
F P
0 g
s
.06262 .50099 m .06319 .50501 L .06305 .50584 L p .961 .775 .331 r
F P
0 g
s
.06319 .50501 m .06262 .50099 L .06264 .50079 L p .964 .779 .339 r
F P
0 g
s
.72275 .12422 m .71955 .12171 L .71971 .12177 L p .023 .452 .872 r
F P
0 g
s
.71971 .12177 m .72354 .12451 L .72275 .12422 L p .023 .452 .872 r
F P
0 g
s
.71406 .8808 m .71783 .87928 L .7177 .87939 L p .042 0 0 r
F P
0 g
s
.7177 .87939 m .71342 .88134 L .71406 .8808 L p .042 0 0 r
F P
0 g
s
.06319 .49499 m .06262 .49901 L .06259 .49884 L p .961 .794 .353 r
F P
0 g
s
.06259 .49884 m .06305 .49416 L .06319 .49499 L p .961 .794 .353 r
F P
0 g
s
.71955 .87829 m .72275 .87578 L .72354 .87549 L p .023 0 0 r
F P
0 g
s
.72275 .87578 m .71955 .87829 L .71936 .87837 L p .033 0 0 r
F P
0 g
s
.4982 .51349 m .4983 .51489 L .49759 .51539 L p .975 .819 .624 r
F P
0 g
s
.49738 .51704 m .49759 .51539 L .4983 .51489 L p .979 .868 .658 r
F P
0 g
s
.51331 .50488 m .51453 .50561 L .51375 .50597 L p .43 .631 .938 r
F P
0 g
s
.51375 .50597 m .51258 .50519 L .51331 .50488 L p .43 .631 .938 r
F P
0 g
s
.48912 .50909 m .48788 .50978 L .48796 .50892 L p .383 .055 .282 r
F P
0 g
s
.48796 .50892 m .48921 .5083 L .48912 .50909 L p .383 .055 .282 r
F P
0 g
s
.48921 .4917 m .48796 .49108 L .48788 .49022 L p .383 .569 .911 r
F P
0 g
s
.48655 .48921 m .48788 .49022 L .48796 .49108 L p .296 .494 .882 r
F P
0 g
s
.51258 .49481 m .51375 .49403 L .51453 .49439 L p .43 .072 .254 r
F P
0 g
s
.51606 .49375 m .51453 .49439 L .51375 .49403 L p .444 .041 .179 r
F P
0 g
s
.49757 .48603 m .49759 .48461 L .4983 .48511 L p .975 .774 .568 r
F P
0 g
s
.4983 .48511 m .4982 .48651 L .49757 .48603 L p .975 .774 .568 r
F P
0 g
s
.49775 .50961 m .49832 .51054 L .49756 .51123 L p .866 .652 .611 r
F P
0 g
s
.49795 .51228 m .49756 .51123 L .49832 .51054 L p .888 .696 .637 r
F P
0 g
s
.51043 .50262 m .51095 .5035 L .50996 .50381 L p .526 .535 .807 r
F P
0 g
s
.50996 .50381 m .50945 .50286 L .51043 .50262 L p .526 .535 .807 r
F P
0 g
s
.49252 .50772 m .49149 .50773 L .49172 .50672 L p .643 .364 .482 r
F P
0 g
s
.49172 .50672 m .4928 .50675 L .49252 .50772 L p .643 .364 .482 r
F P
0 g
s
.4928 .49325 m .49172 .49328 L .49149 .49227 L p .643 .685 .875 r
F P
0 g
s
.49039 .49208 m .49149 .49227 L .49172 .49328 L p .596 .653 .877 r
F P
0 g
s
.50945 .49714 m .50996 .49619 L .51095 .4965 L p .526 .324 .549 r
F P
0 g
s
.51166 .49564 m .51095 .4965 L .50996 .49619 L p .534 .299 .504 r
F P
0 g
s
.49706 .48966 m .49756 .48877 L .49832 .48946 L p .866 .763 .746 r
F P
0 g
s
.49832 .48946 m .49775 .49039 L .49706 .48966 L p .866 .763 .746 r
F P
0 g
s
.51849 .50655 m .52097 .5069 L .52039 .5072 L p .245 .707 .949 r
F P
0 g
s
.52039 .5072 m .51798 .5068 L .51849 .50655 L p .245 .707 .949 r
F P
0 g
s
.49689 .51897 m .49604 .52126 L .49549 .52161 L p .906 .936 .567 r
F P
0 g
s
.49407 .52441 m .49549 .52161 L .49604 .52126 L p .862 .948 .59 r
F P
0 g
s
.48509 .51274 m .48354 .51471 L .48357 .51406 L p 0 0 0 r
F P
0 g
s
.48357 .51406 m .48512 .51218 L .48509 .51274 L p 0 0 0 r
F P
0 g
s
.48512 .48782 m .48357 .48594 L .48354 .48529 L p 0 .173 .709 r
F P
0 g
s
.48183 .48266 m .48354 .48529 L .48357 .48594 L p 0 .076 .637 r
F P
0 g
s
.51798 .4932 m .52039 .4928 L .52097 .4931 L p .245 0 0 r
F P
0 g
s
.5241 .49293 m .52097 .4931 L .52039 .4928 L p .265 0 0 r
F P
0 g
s
.49643 .48072 m .49549 .47839 L .49604 .47874 L p .906 .545 .088 r
F P
0 g
s
.49604 .47874 m .49689 .48103 L .49643 .48072 L p .906 .545 .088 r
F P
0 g
s
.48495 .53755 m .4793 .54479 L .47925 .5449 L p 0 0 0 r
F P
0 g
s
.4715 .55493 m .47925 .5449 L .4793 .54479 L p 0 0 0 r
F P
0 g
s
.54012 .50575 m .54926 .50448 L .54914 .50447 L p 0 0 0 r
F P
0 g
s
.54914 .50447 m .54004 .50574 L .54012 .50575 L p 0 0 0 r
F P
0 g
s
.47501 .4682 m .47156 .45968 L .47149 .45958 L p .664 .326 0 r
F P
0 g
s
.46668 .44785 m .47149 .45958 L .47156 .45968 L p .663 .322 0 r
F P
0 g
s
.47496 .53187 m .47149 .54042 L .47156 .54032 L p .664 .759 .275 r
F P
0 g
s
.47156 .54032 m .47501 .5318 L .47496 .53187 L p .664 .759 .275 r
F P
0 g
s
.54004 .49426 m .54914 .49553 L .54926 .49552 L p 0 .499 .709 r
F P
0 g
s
.56182 .49721 m .54926 .49552 L .54914 .49553 L p 0 .502 .71 r
F P
0 g
s
.48492 .46238 m .47925 .4551 L .4793 .45521 L p 0 0 .444 r
F P
0 g
s
.4793 .45521 m .48495 .46245 L .48492 .46238 L p 0 0 .444 r
F P
0 g
s
.4971 .50883 m .49775 .50961 L .49706 .51034 L p .842 .609 .586 r
F P
0 g
s
.49756 .51123 m .49706 .51034 L .49775 .50961 L p .866 .652 .611 r
F P
0 g
s
.51007 .50174 m .51043 .50262 L .50945 .50286 L p .519 .498 .773 r
F P
0 g
s
.50945 .50286 m .5091 .5019 L .51007 .50174 L p .519 .498 .773 r
F P
0 g
s
.49346 .50785 m .49252 .50772 L .4928 .50675 L p .685 .407 .496 r
F P
0 g
s
.4928 .50675 m .49381 .50693 L .49346 .50785 L p .685 .407 .496 r
F P
0 g
s
.49381 .49307 m .4928 .49325 L .49252 .49228 L p .685 .712 .868 r
F P
0 g
s
.49149 .49227 m .49252 .49228 L .4928 .49325 L p .643 .685 .875 r
F P
0 g
s
.5091 .4981 m .50945 .49714 L .51043 .49738 L p .519 .35 .591 r
F P
0 g
s
.51095 .4965 m .51043 .49738 L .50945 .49714 L p .526 .324 .549 r
F P
0 g
s
.49647 .49041 m .49706 .48966 L .49775 .49039 L p .842 .766 .778 r
F P
0 g
s
.49775 .49039 m .4971 .49117 L .49647 .49041 L p .842 .766 .778 r
F P
0 g
s
.49637 .50817 m .4971 .50883 L .49647 .50959 L p .816 .568 .564 r
F P
0 g
s
.49706 .51034 m .49647 .50959 L .4971 .50883 L p .842 .609 .586 r
F P
0 g
s
.49432 .50812 m .49346 .50785 L .49381 .50693 L p .723 .448 .511 r
F P
0 g
s
.49381 .50693 m .49474 .50723 L .49432 .50812 L p .723 .448 .511 r
F P
0 g
s
.50987 .50086 m .51007 .50174 L .5091 .5019 L p .515 .464 .738 r
F P
0 g
s
.5091 .5019 m .50889 .50094 L .50987 .50086 L p .515 .464 .738 r
F P
0 g
s
.49474 .49277 m .49381 .49307 L .49346 .49215 L p .723 .732 .858 r
F P
0 g
s
.49252 .49228 m .49346 .49215 L .49381 .49307 L p .685 .712 .868 r
F P
0 g
s
.50889 .49906 m .5091 .4981 L .51007 .49826 L p .515 .377 .631 r
F P
0 g
s
.51043 .49738 m .51007 .49826 L .5091 .4981 L p .519 .35 .591 r
F P
0 g
s
.49581 .49102 m .49647 .49041 L .4971 .49117 L p .816 .764 .804 r
F P
0 g
s
.4971 .49117 m .49637 .49183 L .49581 .49102 L p .816 .764 .804 r
F P
0 g
s
.49795 .51228 m .4982 .51349 L .49757 .51397 L p .963 .765 .588 r
F P
0 g
s
.49759 .51539 m .49757 .51397 L .4982 .51349 L p .975 .819 .624 r
F P
0 g
s
.51236 .50411 m .51331 .50488 L .51258 .50519 L p .417 .576 .903 r
F P
0 g
s
.51258 .50519 m .51166 .50436 L .51236 .50411 L p .417 .576 .903 r
F P
0 g
s
.49027 .50865 m .48912 .50909 L .48921 .5083 L p .463 .12 .299 r
F P
0 g
s
.48921 .5083 m .49039 .50792 L .49027 .50865 L p .463 .12 .299 r
F P
0 g
s
.49039 .49208 m .48921 .4917 L .48912 .49091 L p .463 .635 .93 r
F P
0 g
s
.48788 .49022 m .48912 .49091 L .48921 .4917 L p .383 .569 .911 r
F P
0 g
s
.51166 .49564 m .51258 .49481 L .51331 .49512 L p .417 .104 .325 r
F P
0 g
s
.51453 .49439 m .51331 .49512 L .51258 .49481 L p .43 .072 .254 r
F P
0 g
s
.49738 .48725 m .49757 .48603 L .4982 .48651 L p .963 .808 .641 r
F P
0 g
s
.4982 .48651 m .49795 .48772 L .49738 .48725 L p .963 .808 .641 r
F P
0 g
s
.49559 .50764 m .49637 .50817 L .49581 .50898 L p .787 .528 .545 r
F P
0 g
s
.49647 .50959 m .49581 .50898 L .49637 .50817 L p .816 .568 .564 r
F P
0 g
s
.4951 .50849 m .49432 .50812 L .49474 .50723 L p .757 .488 .527 r
F P
0 g
s
.49474 .50723 m .49559 .50764 L .4951 .50849 L p .757 .488 .527 r
F P
0 g
s
.5098 .5 m .50987 .50086 L .50889 .50094 L p .513 .433 .703 r
F P
0 g
s
.50889 .50094 m .50883 .5 L .5098 .5 L p .513 .433 .703 r
F P
0 g
s
.49559 .49236 m .49474 .49277 L .49432 .49188 L p .757 .747 .844 r
F P
0 g
s
.49346 .49215 m .49432 .49188 L .49474 .49277 L p .723 .732 .858 r
F P
0 g
s
.50883 .5 m .50889 .49906 L .50987 .49914 L p .513 .404 .668 r
F P
0 g
s
.51007 .49826 m .50987 .49914 L .50889 .49906 L p .515 .377 .631 r
F P
0 g
s
.4951 .49151 m .49581 .49102 L .49637 .49183 L p .787 .758 .826 r
F P
0 g
s
.49637 .49183 m .49559 .49236 L .4951 .49151 L p .787 .758 .826 r
F P
0 g
s
.49581 .50898 m .4951 .50849 L .49559 .50764 L p .787 .528 .545 r
F P
0 g
s
.50987 .49914 m .5098 .5 L .50883 .5 L p .513 .404 .668 r
F P
0 g
s
.49432 .49188 m .4951 .49151 L .49559 .49236 L p .757 .747 .844 r
F P
0 g
s
.49738 .51704 m .49689 .51897 L .49643 .51928 L p .945 .912 .535 r
F P
0 g
s
.49549 .52161 m .49643 .51928 L .49689 .51897 L p .906 .936 .567 r
F P
0 g
s
.51651 .50604 m .51849 .50655 L .51798 .5068 L p .221 .662 .953 r
F P
0 g
s
.51798 .5068 m .51606 .50625 L .51651 .50604 L p .221 .662 .953 r
F P
0 g
s
.48651 .51128 m .48509 .51274 L .48512 .51218 L p 0 0 0 r
F P
0 g
s
.48512 .51218 m .48655 .51079 L .48651 .51128 L p 0 0 0 r
F P
0 g
s
.48655 .48921 m .48512 .48782 L .48509 .48726 L p 0 .28 .782 r
F P
0 g
s
.48354 .48529 m .48509 .48726 L .48512 .48782 L p 0 .173 .709 r
F P
0 g
s
.49698 .48268 m .49643 .48072 L .49689 .48103 L p .945 .632 .193 r
F P
0 g
s
.49689 .48103 m .49738 .48296 L .49698 .48268 L p .945 .632 .193 r
F P
0 g
s
.51606 .49375 m .51798 .4932 L .51849 .49345 L p .221 0 0 r
F P
0 g
s
.52097 .4931 m .51849 .49345 L .51798 .4932 L p .245 0 0 r
F P
0 g
s
.49756 .51123 m .49795 .51228 L .49738 .51275 L p .944 .708 .552 r
F P
0 g
s
.49757 .51397 m .49738 .51275 L .49795 .51228 L p .963 .765 .588 r
F P
0 g
s
.51162 .5033 m .51236 .50411 L .51166 .50436 L p .404 .522 .863 r
F P
0 g
s
.51166 .50436 m .51095 .5035 L .51162 .5033 L p .404 .522 .863 r
F P
0 g
s
.49133 .50842 m .49027 .50865 L .49039 .50792 L p .536 .184 .317 r
F P
0 g
s
.49039 .50792 m .49149 .50773 L .49133 .50842 L p .536 .184 .317 r
F P
0 g
s
.49149 .49227 m .49039 .49208 L .49027 .49135 L p .536 .692 .94 r
F P
0 g
s
.48912 .49091 m .49027 .49135 L .49039 .49208 L p .463 .635 .93 r
F P
0 g
s
.51095 .4965 m .51166 .49564 L .51236 .49589 L p .404 .138 .393 r
F P
0 g
s
.51331 .49512 m .51236 .49589 L .51166 .49564 L p .417 .104 .325 r
F P
0 g
s
.49704 .48828 m .49738 .48725 L .49795 .48772 L p .944 .833 .704 r
F P
0 g
s
.49795 .48772 m .49756 .48877 L .49704 .48828 L p .944 .833 .704 r
F P
0 g
s
.06259 .50116 m .06305 .50584 L .06289 .50642 L p .957 .771 .321 r
F P
0 g
s
.06305 .50584 m .06259 .50116 L .06262 .50099 L p .961 .775 .331 r
F P
0 g
s
.06305 .49416 m .06259 .49884 L .06256 .49873 L p .957 .792 .347 r
F P
0 g
s
.06256 .49873 m .06289 .49358 L .06305 .49416 L p .957 .792 .347 r
F P
0 g
s
.7177 .12061 m .71342 .11866 L .713 .11824 L p .034 .473 .88 r
F P
0 g
s
.71342 .11866 m .7177 .12061 L .71783 .12072 L p .042 .476 .883 r
F P
0 g
s
.72354 .12451 m .71971 .12177 L .71982 .1218 L p .012 .445 .867 r
F P
0 g
s
.71982 .1218 m .72412 .12466 L .72354 .12451 L p .012 .445 .867 r
F P
0 g
s
.71342 .88134 m .7177 .87939 L .71762 .87947 L p .034 0 0 r
F P
0 g
s
.71762 .87947 m .713 .88176 L .71342 .88134 L p .034 0 0 r
F P
0 g
s
.71971 .87823 m .72354 .87549 L .72412 .87534 L p .012 0 0 r
F P
0 g
s
.72354 .87549 m .71971 .87823 L .71955 .87829 L p .023 0 0 r
F P
0 g
s
.49706 .51034 m .49756 .51123 L .49704 .51172 L p .918 .65 .517 r
F P
0 g
s
.49738 .51275 m .49704 .51172 L .49756 .51123 L p .944 .708 .552 r
F P
0 g
s
.51109 .50247 m .51162 .5033 L .51095 .5035 L p .393 .469 .82 r
F P
0 g
s
.51095 .5035 m .51043 .50262 L .51109 .50247 L p .393 .469 .82 r
F P
0 g
s
.49232 .50837 m .49133 .50842 L .49149 .50773 L p .603 .245 .335 r
F P
0 g
s
.49149 .50773 m .49252 .50772 L .49232 .50837 L p .603 .245 .335 r
F P
0 g
s
.49252 .49228 m .49149 .49227 L .49133 .49158 L p .603 .74 .941 r
F P
0 g
s
.49027 .49135 m .49133 .49158 L .49149 .49227 L p .536 .692 .94 r
F P
0 g
s
.51043 .49738 m .51095 .4965 L .51162 .4967 L p .393 .173 .457 r
F P
0 g
s
.51236 .49589 m .51162 .4967 L .51095 .4965 L p .404 .138 .393 r
F P
0 g
s
.49659 .48916 m .49704 .48828 L .49756 .48877 L p .918 .848 .759 r
F P
0 g
s
.49756 .48877 m .49706 .48966 L .49659 .48916 L p .918 .848 .759 r
F P
0 g
s
.48905 .53208 m .48495 .53755 L .48492 .53762 L p 0 0 0 r
F P
0 g
s
.47925 .5449 m .48492 .53762 L .48495 .53755 L p 0 0 0 r
F P
0 g
s
.53331 .50657 m .54012 .50575 L .54004 .50574 L p 0 0 0 r
F P
0 g
s
.54004 .50574 m .53326 .50656 L .53331 .50657 L p 0 0 0 r
F P
0 g
s
.47766 .52556 m .47496 .53187 L .47501 .5318 L p .659 .765 .286 r
F P
0 g
s
.47501 .5318 m .47769 .52552 L .47766 .52556 L p .659 .765 .286 r
F P
0 g
s
.47769 .47448 m .47501 .4682 L .47496 .46813 L p .659 .311 0 r
F P
0 g
s
.47149 .45958 m .47496 .46813 L .47501 .4682 L p .664 .326 0 r
F P
0 g
s
.53326 .49344 m .54004 .49426 L .54012 .49425 L p 0 .511 .71 r
F P
0 g
s
.54926 .49552 m .54012 .49425 L .54004 .49426 L p 0 .499 .709 r
F P
0 g
s
.48904 .46787 m .48492 .46238 L .48495 .46245 L p 0 0 .433 r
F P
0 g
s
.48495 .46245 m .48905 .46792 L .48904 .46787 L p 0 0 .433 r
F P
0 g
s
.51493 .50542 m .51651 .50604 L .51606 .50625 L p .194 .605 .946 r
F P
0 g
s
.51606 .50625 m .51453 .50561 L .51493 .50542 L p .194 .605 .946 r
F P
0 g
s
.49759 .51539 m .49738 .51704 L .49698 .51732 L p .975 .874 .495 r
F P
0 g
s
.49643 .51928 m .49698 .51732 L .49738 .51704 L p .945 .912 .535 r
F P
0 g
s
.48783 .51022 m .48651 .51128 L .48655 .51079 L p .028 0 0 r
F P
0 g
s
.48655 .51079 m .48788 .50978 L .48783 .51022 L p .028 0 0 r
F P
0 g
s
.48788 .49022 m .48655 .48921 L .48651 .48872 L p .028 .391 .85 r
F P
0 g
s
.48509 .48726 m .48651 .48872 L .48655 .48921 L p 0 .28 .782 r
F P
0 g
s
.51453 .49439 m .51606 .49375 L .51651 .49396 L p .194 0 0 r
F P
0 g
s
.51849 .49345 m .51651 .49396 L .51606 .49375 L p .221 0 0 r
F P
0 g
s
.49723 .48435 m .49698 .48268 L .49738 .48296 L p .975 .718 .303 r
F P
0 g
s
.49738 .48296 m .49759 .48461 L .49723 .48435 L p .975 .718 .303 r
F P
0 g
s
.49647 .50959 m .49706 .51034 L .49659 .51084 L p .886 .592 .484 r
F P
0 g
s
.49704 .51172 m .49659 .51084 L .49706 .51034 L p .918 .65 .517 r
F P
0 g
s
.51073 .50163 m .51109 .50247 L .51043 .50262 L p .385 .419 .773 r
F P
0 g
s
.51043 .50262 m .51007 .50174 L .51073 .50163 L p .385 .419 .773 r
F P
0 g
s
.49322 .50847 m .49232 .50837 L .49252 .50772 L p .664 .306 .355 r
F P
0 g
s
.49252 .50772 m .49346 .50785 L .49322 .50847 L p .664 .306 .355 r
F P
0 g
s
.49346 .49215 m .49252 .49228 L .49232 .49163 L p .664 .778 .934 r
F P
0 g
s
.49133 .49158 m .49232 .49163 L .49252 .49228 L p .603 .74 .941 r
F P
0 g
s
.51007 .49826 m .51043 .49738 L .51109 .49753 L p .385 .209 .517 r
F P
0 g
s
.51162 .4967 m .51109 .49753 L .51043 .49738 L p .393 .173 .457 r
F P
0 g
s
.49605 .48989 m .49659 .48916 L .49706 .48966 L p .886 .855 .806 r
F P
0 g
s
.49706 .48966 m .49647 .49041 L .49605 .48989 L p .886 .855 .806 r
F P
0 g
s
.49581 .50898 m .49647 .50959 L .49605 .51011 L p .85 .534 .453 r
F P
0 g
s
.49659 .51084 m .49605 .51011 L .49647 .50959 L p .886 .592 .484 r
F P
0 g
s
.49404 .50871 m .49322 .50847 L .49346 .50785 L p .718 .364 .377 r
F P
0 g
s
.49346 .50785 m .49432 .50812 L .49404 .50871 L p .718 .364 .377 r
F P
0 g
s
.51052 .50081 m .51073 .50163 L .51007 .50174 L p .379 .372 .725 r
F P
0 g
s
.51007 .50174 m .50987 .50086 L .51052 .50081 L p .379 .372 .725 r
F P
0 g
s
.49432 .49188 m .49346 .49215 L .49322 .49153 L p .718 .808 .921 r
F P
0 g
s
.49232 .49163 m .49322 .49153 L .49346 .49215 L p .664 .778 .934 r
F P
0 g
s
.50987 .49914 m .51007 .49826 L .51073 .49837 L p .379 .247 .573 r
F P
0 g
s
.51109 .49753 m .51073 .49837 L .51007 .49826 L p .385 .209 .517 r
F P
0 g
s
.49544 .49048 m .49605 .48989 L .49647 .49041 L p .85 .854 .845 r
F P
0 g
s
.49647 .49041 m .49581 .49102 L .49544 .49048 L p .85 .854 .845 r
F P
0 g
s
.4951 .50849 m .49581 .50898 L .49544 .50952 L p .81 .477 .426 r
F P
0 g
s
.49605 .51011 m .49544 .50952 L .49581 .50898 L p .85 .534 .453 r
F P
0 g
s
.49477 .50906 m .49404 .50871 L .49432 .50812 L p .767 .421 .4 r
F P
0 g
s
.49432 .50812 m .4951 .50849 L .49477 .50906 L p .767 .421 .4 r
F P
0 g
s
.51046 .5 m .51052 .50081 L .50987 .50086 L p .376 .328 .676 r
F P
0 g
s
.50987 .50086 m .5098 .5 L .51046 .5 L p .376 .328 .676 r
F P
0 g
s
.4951 .49151 m .49432 .49188 L .49404 .49129 L p .767 .831 .902 r
F P
0 g
s
.49322 .49153 m .49404 .49129 L .49432 .49188 L p .718 .808 .921 r
F P
0 g
s
.5098 .5 m .50987 .49914 L .51052 .49919 L p .376 .287 .626 r
F P
0 g
s
.51073 .49837 m .51052 .49919 L .50987 .49914 L p .379 .247 .573 r
F P
0 g
s
.49477 .49094 m .49544 .49048 L .49581 .49102 L p .81 .846 .876 r
F P
0 g
s
.49581 .49102 m .4951 .49151 L .49477 .49094 L p .81 .846 .876 r
F P
0 g
s
.49544 .50952 m .49477 .50906 L .4951 .50849 L p .81 .477 .426 r
F P
0 g
s
.51052 .49919 m .51046 .5 L .5098 .5 L p .376 .287 .626 r
F P
0 g
s
.49404 .49129 m .49477 .49094 L .4951 .49151 L p .767 .831 .902 r
F P
0 g
s
.49757 .51397 m .49759 .51539 L .49723 .51565 L p .991 .823 .448 r
F P
0 g
s
.49698 .51732 m .49723 .51565 L .49759 .51539 L p .975 .874 .495 r
F P
0 g
s
.51369 .50473 m .51493 .50542 L .51453 .50561 L p .166 .538 .925 r
F P
0 g
s
.51453 .50561 m .51331 .50488 L .51369 .50473 L p .166 .538 .925 r
F P
0 g
s
.48906 .50949 m .48783 .51022 L .48788 .50978 L p .137 0 0 r
F P
0 g
s
.48788 .50978 m .48912 .50909 L .48906 .50949 L p .137 0 0 r
F P
0 g
s
.48912 .49091 m .48788 .49022 L .48783 .48978 L p .137 .501 .908 r
F P
0 g
s
.48651 .48872 m .48783 .48978 L .48788 .49022 L p .028 .391 .85 r
F P
0 g
s
.49725 .48578 m .49723 .48435 L .49759 .48461 L p .991 .796 .415 r
F P
0 g
s
.49759 .48461 m .49757 .48603 L .49725 .48578 L p .991 .796 .415 r
F P
0 g
s
.51331 .49512 m .51453 .49439 L .51493 .49458 L p .166 0 0 r
F P
0 g
s
.51651 .49396 m .51493 .49458 L .51453 .49439 L p .194 0 0 r
F P
0 g
s
.49199 .52782 m .48905 .53208 L .48904 .53213 L p 0 0 0 r
F P
0 g
s
.48492 .53762 m .48904 .53213 L .48905 .53208 L p 0 0 0 r
F P
0 g
s
.52813 .50698 m .53331 .50657 L .53326 .50656 L p 0 0 0 r
F P
0 g
s
.53326 .50656 m .52809 .50698 L .52813 .50698 L p 0 0 0 r
F P
0 g
s
.47989 .52087 m .47766 .52556 L .47769 .52552 L p .646 .775 .311 r
F P
0 g
s
.47769 .52552 m .47991 .52084 L .47989 .52087 L p .646 .775 .311 r
F P
0 g
s
.47991 .47916 m .47769 .47448 L .47766 .47444 L p .646 .28 0 r
F P
0 g
s
.47496 .46813 m .47766 .47444 L .47769 .47448 L p .659 .311 0 r
F P
0 g
s
.49198 .47215 m .48904 .46787 L .48905 .46792 L p 0 0 .409 r
F P
0 g
s
.48905 .46792 m .49199 .47218 L .49198 .47215 L p 0 0 .409 r
F P
0 g
s
.52809 .49302 m .53326 .49344 L .53331 .49343 L p 0 .535 .712 r
F P
0 g
s
.54012 .49425 m .53331 .49343 L .53326 .49344 L p 0 .511 .71 r
F P
0 g
s
.49738 .51275 m .49757 .51397 L .49725 .51422 L p .993 .759 .397 r
F P
0 g
s
.49723 .51565 m .49725 .51422 L .49757 .51397 L p .991 .823 .448 r
F P
0 g
s
.51271 .50398 m .51369 .50473 L .51331 .50488 L p .138 .464 .89 r
F P
0 g
s
.51331 .50488 m .51236 .50411 L .51271 .50398 L p .138 .464 .89 r
F P
0 g
s
.4902 .50902 m .48906 .50949 L .48912 .50909 L p .248 0 0 r
F P
0 g
s
.48912 .50909 m .49027 .50865 L .4902 .50902 L p .248 0 0 r
F P
0 g
s
.49027 .49135 m .48912 .49091 L .48906 .49051 L p .248 .605 .953 r
F P
0 g
s
.48783 .48978 m .48906 .49051 L .48912 .49091 L p .137 .501 .908 r
F P
0 g
s
.51236 .49589 m .51331 .49512 L .51369 .49527 L p .138 0 .03 r
F P
0 g
s
.51493 .49458 m .51369 .49527 L .51331 .49512 L p .166 0 0 r
F P
0 g
s
.49709 .487 m .49725 .48578 L .49757 .48603 L p .993 .863 .523 r
F P
0 g
s
.49757 .48603 m .49738 .48725 L .49709 .487 L p .993 .863 .523 r
F P
0 g
s
.6997 .88816 m .71283 .88206 L .71291 .88221 L p .041 0 0 r
F P
0 g
s
.71291 .88221 m .69995 .88866 L .6997 .88816 L p .041 0 0 r
F P
0 g
s
.75967 .84795 m .73661 .86749 L .73631 .86703 L p 0 0 0 r
F P
0 g
s
.72446 .87534 m .73631 .86703 L .73661 .86749 L p 0 0 0 r
F P
0 g
s
.73631 .86703 m .72446 .87534 L .72412 .87534 L p 0 0 0 r
F P
0 g
s
.6715 .10115 m .69995 .11134 L .6997 .11184 L p .107 .577 .913 r
F P
0 g
s
.71283 .11794 m .6997 .11184 L .69995 .11134 L p .041 .499 .886 r
F P
0 g
s
.6997 .11184 m .71283 .11794 L .713 .11824 L p .078 .517 .901 r
F P
0 g
s
.73631 .13297 m .72446 .12466 L .72455 .12451 L p 0 .393 .838 r
F P
0 g
s
.72455 .12451 m .73661 .13251 L .73631 .13297 L p 0 .393 .838 r
F P
0 g
s
.06399 .47886 m .06271 .49328 L .06254 .49328 L p .947 .812 .363 r
F P
0 g
s
.06254 .49328 m .06344 .47884 L .06399 .47886 L p .947 .812 .363 r
F P
0 g
s
.06883 .5509 m .06344 .52116 L .06399 .52114 L p .935 .665 .192 r
F P
0 g
s
.06271 .50672 m .06399 .52114 L .06344 .52116 L p .947 .734 .268 r
F P
0 g
s
.06399 .52114 m .06271 .50672 L .06289 .50642 L p .961 .748 .301 r
F P
0 g
s
.49704 .51172 m .49738 .51275 L .49709 .513 L p .98 .685 .342 r
F P
0 g
s
.49725 .51422 m .49709 .513 L .49738 .51275 L p .993 .759 .397 r
F P
0 g
s
.51197 .5032 m .51271 .50398 L .51236 .50411 L p .113 .386 .843 r
F P
0 g
s
.51236 .50411 m .51162 .5033 L .51197 .5032 L p .113 .386 .843 r
F P
0 g
s
.49125 .50877 m .4902 .50902 L .49027 .50865 L p .357 0 0 r
F P
0 g
s
.49027 .50865 m .49133 .50842 L .49125 .50877 L p .357 0 0 r
F P
0 g
s
.49133 .49158 m .49027 .49135 L .4902 .49098 L p .357 .7 .984 r
F P
0 g
s
.48906 .49051 m .4902 .49098 L .49027 .49135 L p .248 .605 .953 r
F P
0 g
s
.51162 .4967 m .51236 .49589 L .51271 .49602 L p .113 0 .124 r
F P
0 g
s
.51369 .49527 m .51271 .49602 L .51236 .49589 L p .138 0 .03 r
F P
0 g
s
.49678 .48804 m .49709 .487 L .49738 .48725 L p .98 .915 .624 r
F P
0 g
s
.49738 .48725 m .49704 .48828 L .49678 .48804 L p .98 .915 .624 r
F P
0 g
s
.49407 .52441 m .49199 .52782 L .49198 .52785 L p 0 0 0 r
F P
0 g
s
.48904 .53213 m .49198 .52785 L .49199 .52782 L p 0 0 0 r
F P
0 g
s
.52413 .50707 m .52813 .50698 L .52809 .50698 L p 0 0 0 r
F P
0 g
s
.52809 .50698 m .5241 .50707 L .52413 .50707 L p 0 0 0 r
F P
0 g
s
.48181 .51736 m .47989 .52087 L .47991 .52084 L p .626 .789 .346 r
F P
0 g
s
.47991 .52084 m .48183 .51734 L .48181 .51736 L p .626 .789 .346 r
F P
0 g
s
.48183 .48266 m .47991 .47916 L .47989 .47913 L p .626 .234 0 r
F P
0 g
s
.47766 .47444 m .47989 .47913 L .47991 .47916 L p .646 .28 0 r
F P
0 g
s
.5241 .49293 m .52809 .49302 L .52813 .49302 L p 0 .569 .713 r
F P
0 g
s
.53331 .49343 m .52813 .49302 L .52809 .49302 L p 0 .535 .712 r
F P
0 g
s
.49406 .47557 m .49198 .47215 L .49199 .47218 L p 0 0 .373 r
F P
0 g
s
.49199 .47218 m .49407 .47559 L .49406 .47557 L p 0 0 .373 r
F P
0 g
s
.72412 .12466 m .71982 .1218 L .71989 .1218 L p 0 .438 .862 r
F P
0 g
s
.71989 .1218 m .72446 .12466 L .72412 .12466 L p 0 .438 .862 r
F P
0 g
s
.71762 .12053 m .713 .11824 L .71283 .11794 L p .023 .469 .876 r
F P
0 g
s
.713 .11824 m .71762 .12053 L .7177 .12061 L p .034 .473 .88 r
F P
0 g
s
.06289 .49358 m .06256 .49873 L .06252 .49867 L p .953 .789 .339 r
F P
0 g
s
.06252 .49867 m .06271 .49328 L .06289 .49358 L p .953 .789 .339 r
F P
0 g
s
.71982 .8782 m .72412 .87534 L .72446 .87534 L p 0 0 0 r
F P
0 g
s
.72412 .87534 m .71982 .8782 L .71971 .87823 L p .012 0 0 r
F P
0 g
s
.713 .88176 m .71762 .87947 L .71759 .87953 L p .023 0 0 r
F P
0 g
s
.71759 .87953 m .71283 .88206 L .713 .88176 L p .023 0 0 r
F P
0 g
s
.06256 .50127 m .06289 .50642 L .06271 .50672 L p .953 .767 .312 r
F P
0 g
s
.06289 .50642 m .06256 .50127 L .06259 .50116 L p .957 .771 .321 r
F P
0 g
s
.49659 .51084 m .49704 .51172 L .49678 .51196 L p .952 .603 .287 r
F P
0 g
s
.49709 .513 m .49678 .51196 L .49704 .51172 L p .98 .685 .342 r
F P
0 g
s
.51143 .50239 m .51197 .5032 L .51162 .5033 L p .091 .305 .785 r
F P
0 g
s
.51162 .5033 m .51109 .50247 L .51143 .50239 L p .091 .305 .785 r
F P
0 g
s
.49221 .5087 m .49125 .50877 L .49133 .50842 L p .461 0 .004 r
F P
0 g
s
.49133 .50842 m .49232 .50837 L .49221 .5087 L p .461 0 .004 r
F P
0 g
s
.49232 .49163 m .49133 .49158 L .49125 .49123 L p .461 .783 .998 r
F P
0 g
s
.4902 .49098 m .49125 .49123 L .49133 .49158 L p .357 .7 .984 r
F P
0 g
s
.51109 .49753 m .51162 .4967 L .51197 .4968 L p .091 0 .218 r
F P
0 g
s
.51271 .49602 m .51197 .4968 L .51162 .4967 L p .113 0 .124 r
F P
0 g
s
.49636 .48891 m .49678 .48804 L .49704 .48828 L p .952 .952 .715 r
F P
0 g
s
.49704 .48828 m .49659 .48916 L .49636 .48891 L p .952 .952 .715 r
F P
0 g
s
.49605 .51011 m .49659 .51084 L .49636 .51109 L p .911 .515 .234 r
F P
0 g
s
.49678 .51196 m .49636 .51109 L .49659 .51084 L p .952 .603 .287 r
F P
0 g
s
.4931 .50879 m .49221 .5087 L .49232 .50837 L p .559 .062 .031 r
F P
0 g
s
.49232 .50837 m .49322 .50847 L .4931 .50879 L p .559 .062 .031 r
F P
0 g
s
.51106 .50158 m .51143 .50239 L .51109 .50247 L p .074 .226 .718 r
F P
0 g
s
.51109 .50247 m .51073 .50163 L .51106 .50158 L p .074 .226 .718 r
F P
0 g
s
.49322 .49153 m .49232 .49163 L .49221 .4913 L p .559 .851 .998 r
F P
0 g
s
.49125 .49123 m .49221 .4913 L .49232 .49163 L p .461 .783 .998 r
F P
0 g
s
.51073 .49837 m .51109 .49753 L .51143 .49761 L p .074 0 .311 r
F P
0 g
s
.51197 .4968 m .51143 .49761 L .51109 .49753 L p .091 0 .218 r
F P
0 g
s
.49584 .48963 m .49636 .48891 L .49659 .48916 L p .911 .972 .794 r
F P
0 g
s
.49659 .48916 m .49605 .48989 L .49584 .48963 L p .911 .972 .794 r
F P
0 g
s
.49544 .50952 m .49605 .51011 L .49584 .51037 L p .858 .425 .185 r
F P
0 g
s
.49636 .51109 m .49584 .51037 L .49605 .51011 L p .911 .515 .234 r
F P
0 g
s
.49389 .50901 m .4931 .50879 L .49322 .50847 L p .648 .153 .063 r
F P
0 g
s
.49322 .50847 m .49404 .50871 L .49389 .50901 L p .648 .153 .063 r
F P
0 g
s
.51085 .50078 m .51106 .50158 L .51073 .50163 L p .062 .15 .644 r
F P
0 g
s
.51073 .50163 m .51052 .50081 L .51085 .50078 L p .062 .15 .644 r
F P
0 g
s
.49404 .49129 m .49322 .49153 L .4931 .49121 L p .648 .904 .982 r
F P
0 g
s
.49221 .4913 m .4931 .49121 L .49322 .49153 L p .559 .851 .998 r
F P
0 g
s
.51052 .49919 m .51073 .49837 L .51106 .49842 L p .062 0 .401 r
F P
0 g
s
.51143 .49761 m .51106 .49842 L .51073 .49837 L p .074 0 .311 r
F P
0 g
s
.49525 .49021 m .49584 .48963 L .49605 .48989 L p .858 .977 .861 r
F P
0 g
s
.49605 .48989 m .49544 .49048 L .49525 .49021 L p .858 .977 .861 r
F P
0 g
s
.49477 .50906 m .49544 .50952 L .49525 .50979 L p .797 .334 .14 r
F P
0 g
s
.49584 .51037 m .49525 .50979 L .49544 .50952 L p .858 .425 .185 r
F P
0 g
s
.49461 .50934 m .49389 .50901 L .49404 .50871 L p .727 .244 .099 r
F P
0 g
s
.49404 .50871 m .49477 .50906 L .49461 .50934 L p .727 .244 .099 r
F P
0 g
s
.51079 .5 m .51085 .50078 L .51052 .50081 L p .056 .079 .567 r
F P
0 g
s
.51052 .50081 m .51046 .5 L .51079 .5 L p .056 .079 .567 r
F P
0 g
s
.49477 .49094 m .49404 .49129 L .49389 .49099 L p .727 .942 .954 r
F P
0 g
s
.4931 .49121 m .49389 .49099 L .49404 .49129 L p .648 .904 .982 r
F P
0 g
s
.51046 .5 m .51052 .49919 L .51085 .49922 L p .056 .013 .486 r
F P
0 g
s
.51106 .49842 m .51085 .49922 L .51052 .49919 L p .062 0 .401 r
F P
0 g
s
.49461 .49066 m .49525 .49021 L .49544 .49048 L p .797 .966 .914 r
F P
0 g
s
.49544 .49048 m .49477 .49094 L .49461 .49066 L p .797 .966 .914 r
F P
0 g
s
.49525 .50979 m .49461 .50934 L .49477 .50906 L p .797 .334 .14 r
F P
0 g
s
.51085 .49922 m .51079 .5 L .51046 .5 L p .056 .013 .486 r
F P
0 g
s
.49389 .49099 m .49461 .49066 L .49477 .49094 L p .727 .942 .954 r
F P
0 g
s
.49549 .52161 m .49407 .52441 L .49406 .52443 L p 0 0 0 r
F P
0 g
s
.49198 .52785 m .49406 .52443 L .49407 .52441 L p 0 0 0 r
F P
0 g
s
.52099 .50691 m .52413 .50707 L .5241 .50707 L p .042 0 0 r
F P
0 g
s
.5241 .50707 m .52097 .5069 L .52099 .50691 L p .042 0 0 r
F P
0 g
s
.48352 .51472 m .48181 .51736 L .48183 .51734 L p .598 .802 .39 r
F P
0 g
s
.48183 .51734 m .48354 .51471 L .48352 .51472 L p .598 .802 .39 r
F P
0 g
s
.48354 .48529 m .48183 .48266 L .48181 .48264 L p .598 .174 0 r
F P
0 g
s
.47989 .47913 m .48181 .48264 L .48183 .48266 L p .626 .234 0 r
F P
0 g
s
.49549 .47837 m .49406 .47557 L .49407 .47559 L p 0 0 .326 r
F P
0 g
s
.49407 .47559 m .49549 .47839 L .49549 .47837 L p 0 0 .326 r
F P
0 g
s
.52097 .4931 m .5241 .49293 L .52413 .49293 L p .042 .611 .711 r
F P
0 g
s
.52813 .49302 m .52413 .49293 L .5241 .49293 L p 0 .569 .713 r
F P
0 g
s
.49643 .51928 m .49549 .52161 L .49549 .52163 L p 0 0 0 r
F P
0 g
s
.49406 .52443 m .49549 .52163 L .49549 .52161 L p 0 0 0 r
F P
0 g
s
.5185 .50655 m .52099 .50691 L .52097 .5069 L p .104 0 0 r
F P
0 g
s
.52097 .5069 m .51849 .50655 L .5185 .50655 L p .104 0 0 r
F P
0 g
s
.48508 .51275 m .48352 .51472 L .48354 .51471 L p .559 .813 .441 r
F P
0 g
s
.48354 .51471 m .48509 .51274 L .48508 .51275 L p .559 .813 .441 r
F P
0 g
s
.48509 .48726 m .48354 .48529 L .48352 .48528 L p .559 .099 0 r
F P
0 g
s
.48181 .48264 m .48352 .48528 L .48354 .48529 L p .598 .174 0 r
F P
0 g
s
.49642 .4807 m .49549 .47837 L .49549 .47839 L p 0 0 .265 r
F P
0 g
s
.49549 .47839 m .49643 .48072 L .49642 .4807 L p 0 0 .265 r
F P
0 g
s
.51849 .49345 m .52097 .4931 L .52099 .49309 L p .104 .657 .703 r
F P
0 g
s
.52413 .49293 m .52099 .49309 L .52097 .4931 L p .042 .611 .711 r
F P
0 g
s
.71866 .87874 m .71874 .87888 L .71873 .87889 L p .01 0 0 r
F P
0 g
s
.71873 .87889 m .71843 .87888 L .71866 .87874 L p .01 0 0 r
F P
0 g
s
.71874 .87888 m .71866 .87874 L .71891 .8786 L p .01 0 0 r
F P
0 g
s
.71866 .12126 m .71874 .12112 L .71876 .12113 L p .01 .452 .868 r
F P
0 g
s
.71876 .12113 m .71891 .1214 L .71866 .12126 L p .01 .452 .868 r
F P
0 g
s
.71874 .12112 m .71866 .12126 L .71843 .12112 L p .01 .453 .869 r
F P
0 g
s
.06267 .5 m .06251 .5 L .06251 .49998 L p .953 .778 .325 r
F P
0 g
s
.06251 .49998 m .06267 .49972 L .06267 .5 L p .953 .778 .325 r
F P
0 g
s
.06251 .5 m .06267 .5 L .06267 .50028 L p .953 .778 .324 r
F P
0 g
s
.71876 .87887 m .71891 .8786 L .71914 .87848 L p .009 0 0 r
F P
0 g
s
.71891 .8786 m .71876 .87887 L .71874 .87888 L p .01 0 0 r
F P
0 g
s
.06251 .50002 m .06267 .50028 L .06266 .50054 L p .952 .777 .323 r
F P
0 g
s
.06267 .50028 m .06251 .50002 L .06251 .5 L p .953 .778 .324 r
F P
0 g
s
.71873 .12111 m .71843 .12112 L .7182 .12098 L p .01 .453 .869 r
F P
0 g
s
.71843 .12112 m .71873 .12111 L .71874 .12112 L p .01 .453 .869 r
F P
0 g
s
.71891 .1214 m .71876 .12113 L .71877 .12114 L p .009 .451 .868 r
F P
0 g
s
.71877 .12114 m .71914 .12152 L .71891 .1214 L p .009 .451 .868 r
F P
0 g
s
.06267 .49972 m .06251 .49998 L .06251 .49997 L p .952 .778 .325 r
F P
0 g
s
.06251 .49997 m .06266 .49946 L .06267 .49972 L p .952 .778 .325 r
F P
0 g
s
.71843 .87888 m .71873 .87889 L .71872 .87889 L p .01 0 0 r
F P
0 g
s
.71872 .87889 m .7182 .87902 L .71843 .87888 L p .01 0 0 r
F P
0 g
s
.51652 .50604 m .5185 .50655 L .51849 .50655 L p .177 0 0 r
F P
0 g
s
.51849 .50655 m .51651 .50604 L .51652 .50604 L p .177 0 0 r
F P
0 g
s
.49698 .51732 m .49643 .51928 L .49642 .5193 L p 0 0 0 r
F P
0 g
s
.49549 .52163 m .49642 .5193 L .49643 .51928 L p 0 0 0 r
F P
0 g
s
.48651 .51128 m .48508 .51275 L .48509 .51274 L p .507 .818 .496 r
F P
0 g
s
.48509 .51274 m .48651 .51128 L .48651 .51128 L p .507 .818 .496 r
F P
0 g
s
.48651 .48872 m .48509 .48726 L .48508 .48725 L p .507 .01 0 r
F P
0 g
s
.48352 .48528 m .48508 .48725 L .48509 .48726 L p .559 .099 0 r
F P
0 g
s
.49697 .48267 m .49642 .4807 L .49643 .48072 L p 0 0 .192 r
F P
0 g
s
.49643 .48072 m .49698 .48268 L .49697 .48267 L p 0 0 .192 r
F P
0 g
s
.51651 .49396 m .51849 .49345 L .5185 .49345 L p .177 .704 .686 r
F P
0 g
s
.52099 .49309 m .5185 .49345 L .51849 .49345 L p .104 .657 .703 r
F P
0 g
s
.71914 .12152 m .71877 .12114 L .71879 .12115 L p .008 .45 .867 r
F P
0 g
s
.71879 .12115 m .71936 .12163 L .71914 .12152 L p .008 .45 .867 r
F P
0 g
s
.71872 .12111 m .7182 .12098 L .718 .12084 L p .01 .453 .869 r
F P
0 g
s
.7182 .12098 m .71872 .12111 L .71873 .12111 L p .01 .453 .869 r
F P
0 g
s
.06251 .50003 m .06266 .50054 L .06264 .50079 L p .952 .776 .322 r
F P
0 g
s
.06266 .50054 m .06251 .50003 L .06251 .50002 L p .952 .777 .323 r
F P
0 g
s
.7182 .87902 m .71872 .87889 L .7187 .8789 L p .01 0 0 r
F P
0 g
s
.7187 .8789 m .718 .87916 L .7182 .87902 L p .01 0 0 r
F P
0 g
s
.71877 .87886 m .71914 .87848 L .71936 .87837 L p .008 0 0 r
F P
0 g
s
.71914 .87848 m .71877 .87886 L .71876 .87887 L p .009 0 0 r
F P
0 g
s
.06266 .49946 m .06251 .49997 L .06251 .49995 L p .952 .778 .325 r
F P
0 g
s
.06251 .49995 m .06264 .49921 L .06266 .49946 L p .952 .778 .325 r
F P
0 g
s
.7187 .1211 m .718 .12084 L .71783 .12072 L p .009 .453 .868 r
F P
0 g
s
.718 .12084 m .7187 .1211 L .71872 .12111 L p .01 .453 .869 r
F P
0 g
s
.71879 .87885 m .71936 .87837 L .71955 .87829 L p .006 0 0 r
F P
0 g
s
.71936 .87837 m .71879 .87885 L .71877 .87886 L p .008 0 0 r
F P
0 g
s
.06264 .49921 m .06251 .49995 L .06251 .49994 L p .952 .778 .324 r
F P
0 g
s
.06251 .49994 m .06262 .49901 L .06264 .49921 L p .952 .778 .324 r
F P
0 g
s
.06251 .50005 m .06264 .50079 L .06262 .50099 L p .952 .776 .321 r
F P
0 g
s
.06264 .50079 m .06251 .50005 L .06251 .50003 L p .952 .776 .322 r
F P
0 g
s
.71936 .12163 m .71879 .12115 L .7188 .12115 L p .006 .449 .866 r
F P
0 g
s
.7188 .12115 m .71955 .12171 L .71936 .12163 L p .006 .449 .866 r
F P
0 g
s
.718 .87916 m .7187 .8789 L .71869 .87891 L p .009 0 0 r
F P
0 g
s
.71869 .87891 m .71783 .87928 L .718 .87916 L p .009 0 0 r
F P
0 g
s
.51494 .50543 m .51652 .50604 L .51651 .50604 L p 0 .328 .659 r
F P
0 g
s
.51651 .50604 m .51493 .50542 L .51494 .50543 L p 0 .328 .659 r
F P
0 g
s
.49723 .51565 m .49698 .51732 L .49697 .51733 L p .699 .658 .107 r
F P
0 g
s
.49642 .5193 m .49697 .51733 L .49698 .51732 L p 0 0 0 r
F P
0 g
s
.48783 .51023 m .48651 .51128 L .48651 .51128 L p 0 0 0 r
F P
0 g
s
.48651 .51128 m .48783 .51022 L .48783 .51023 L p 0 0 0 r
F P
0 g
s
.48783 .48978 m .48651 .48872 L .48651 .48872 L p 0 .09 .552 r
F P
0 g
s
.48508 .48725 m .48651 .48872 L .48651 .48872 L p .507 .01 0 r
F P
0 g
s
.51493 .49458 m .51651 .49396 L .51652 .49396 L p 0 0 0 r
F P
0 g
s
.5185 .49345 m .51652 .49396 L .51651 .49396 L p .177 .704 .686 r
F P
0 g
s
.49723 .48435 m .49697 .48267 L .49698 .48268 L p .699 .484 0 r
F P
0 g
s
.49698 .48268 m .49723 .48435 L .49723 .48435 L p .699 .484 0 r
F P
0 g
s
.49725 .51422 m .49723 .51565 L .49723 .51565 L p .709 .588 .013 r
F P
0 g
s
.49697 .51733 m .49723 .51565 L .49723 .51565 L p .699 .658 .107 r
F P
0 g
s
.51369 .50473 m .51494 .50543 L .51493 .50542 L p 0 .226 .62 r
F P
0 g
s
.51493 .50542 m .51369 .50473 L .51369 .50473 L p 0 .226 .62 r
F P
0 g
s
.48905 .50949 m .48783 .51023 L .48783 .51022 L p 0 0 0 r
F P
0 g
s
.48783 .51022 m .48906 .50949 L .48905 .50949 L p 0 0 0 r
F P
0 g
s
.48906 .49051 m .48783 .48978 L .48783 .48977 L p 0 .2 .609 r
F P
0 g
s
.48651 .48872 m .48783 .48977 L .48783 .48978 L p 0 .09 .552 r
F P
0 g
s
.51369 .49527 m .51493 .49458 L .51494 .49457 L p 0 0 0 r
F P
0 g
s
.51652 .49396 m .51494 .49457 L .51493 .49458 L p 0 0 0 r
F P
0 g
s
.49725 .48578 m .49723 .48435 L .49723 .48435 L p .709 .57 0 r
F P
0 g
s
.49723 .48435 m .49725 .48578 L .49725 .48578 L p .709 .57 0 r
F P
0 g
s
.06251 .50006 m .06262 .50099 L .06259 .50116 L p .951 .775 .319 r
F P
0 g
s
.06262 .50099 m .06251 .50006 L .06251 .50005 L p .952 .776 .321 r
F P
0 g
s
.71869 .12109 m .71783 .12072 L .7177 .12061 L p .008 .453 .868 r
F P
0 g
s
.71783 .12072 m .71869 .12109 L .7187 .1211 L p .009 .453 .868 r
F P
0 g
s
.06262 .49901 m .06251 .49994 L .06251 .49993 L p .951 .778 .323 r
F P
0 g
s
.06251 .49993 m .06259 .49884 L .06262 .49901 L p .951 .778 .323 r
F P
0 g
s
.7188 .87885 m .71955 .87829 L .71971 .87823 L p .004 0 0 r
F P
0 g
s
.71955 .87829 m .7188 .87885 L .71879 .87885 L p .006 0 0 r
F P
0 g
s
.71783 .87928 m .71869 .87891 L .71868 .87892 L p .008 0 0 r
F P
0 g
s
.71868 .87892 m .7177 .87939 L .71783 .87928 L p .008 0 0 r
F P
0 g
s
.71955 .12171 m .7188 .12115 L .71881 .12115 L p .004 .448 .866 r
F P
0 g
s
.71881 .12115 m .71971 .12177 L .71955 .12171 L p .004 .448 .866 r
F P
0 g
s
.49709 .513 m .49725 .51422 L .49725 .51422 L p .705 .5 0 r
F P
0 g
s
.49723 .51565 m .49725 .51422 L .49725 .51422 L p .709 .588 .013 r
F P
0 g
s
.51272 .50398 m .51369 .50473 L .51369 .50473 L p 0 .109 .564 r
F P
0 g
s
.51369 .50473 m .51271 .50398 L .51272 .50398 L p 0 .109 .564 r
F P
0 g
s
.49019 .50902 m .48905 .50949 L .48906 .50949 L p 0 0 0 r
F P
0 g
s
.48906 .50949 m .4902 .50902 L .49019 .50902 L p 0 0 0 r
F P
0 g
s
.4902 .49098 m .48906 .49051 L .48905 .49051 L p 0 .316 .657 r
F P
0 g
s
.48783 .48977 m .48905 .49051 L .48906 .49051 L p 0 .2 .609 r
F P
0 g
s
.51271 .49602 m .51369 .49527 L .51369 .49527 L p 0 0 0 r
F P
0 g
s
.51494 .49457 m .51369 .49527 L .51369 .49527 L p 0 0 0 r
F P
0 g
s
.49709 .487 m .49725 .48578 L .49725 .48578 L p .705 .651 .096 r
F P
0 g
s
.49725 .48578 m .49709 .487 L .49709 .487 L p .705 .651 .096 r
F P
0 g
s
.49678 .51196 m .49709 .513 L .49709 .513 L p .683 .393 0 r
F P
0 g
s
.49725 .51422 m .49709 .513 L .49709 .513 L p .705 .5 0 r
F P
0 g
s
.51197 .5032 m .51272 .50398 L .51271 .50398 L p 0 0 .491 r
F P
0 g
s
.51271 .50398 m .51197 .5032 L .51197 .5032 L p 0 0 .491 r
F P
0 g
s
.49124 .50877 m .49019 .50902 L .4902 .50902 L p 0 0 0 r
F P
0 g
s
.4902 .50902 m .49125 .50877 L .49124 .50877 L p 0 0 0 r
F P
0 g
s
.49125 .49123 m .4902 .49098 L .49019 .49098 L p 0 .432 .693 r
F P
0 g
s
.48905 .49051 m .49019 .49098 L .4902 .49098 L p 0 .316 .657 r
F P
0 g
s
.51197 .4968 m .51271 .49602 L .51272 .49602 L p 0 0 0 r
F P
0 g
s
.51369 .49527 m .51272 .49602 L .51271 .49602 L p 0 0 0 r
F P
0 g
s
.49678 .48803 m .49709 .487 L .49709 .487 L p .683 .722 .207 r
F P
0 g
s
.49709 .487 m .49678 .48804 L .49678 .48803 L p .683 .722 .207 r
F P
0 g
s
.06344 .52116 m .06254 .50672 L .06271 .50672 L p .947 .734 .268 r
F P
0 g
s
.06252 .50133 m .06271 .50672 L .06254 .50672 L p .949 .763 .302 r
F P
0 g
s
.06271 .50672 m .06252 .50133 L .06256 .50127 L p .953 .767 .312 r
F P
0 g
s
.72446 .12466 m .71989 .1218 L .71991 .12177 L p 0 .431 .857 r
F P
0 g
s
.71991 .12177 m .72455 .12451 L .72446 .12466 L p 0 .431 .857 r
F P
0 g
s
.06271 .49328 m .06252 .49867 L .06249 .49867 L p .949 .786 .33 r
F P
0 g
s
.06249 .49867 m .06254 .49328 L .06271 .49328 L p .949 .786 .33 r
F P
0 g
s
.69995 .11134 m .71291 .11779 L .71283 .11794 L p .041 .499 .886 r
F P
0 g
s
.71759 .12047 m .71283 .11794 L .71291 .11779 L p .012 .463 .871 r
F P
0 g
s
.71283 .11794 m .71759 .12047 L .71762 .12053 L p .023 .469 .876 r
F P
0 g
s
.71283 .88206 m .71759 .87953 L .7176 .87956 L p .012 0 0 r
F P
0 g
s
.7176 .87956 m .71291 .88221 L .71283 .88206 L p .012 0 0 r
F P
0 g
s
.73661 .86749 m .72455 .87549 L .72446 .87534 L p 0 0 0 r
F P
0 g
s
.71989 .8782 m .72446 .87534 L .72455 .87549 L p 0 0 0 r
F P
0 g
s
.72446 .87534 m .71989 .8782 L .71982 .8782 L p 0 0 0 r
F P
0 g
s
.49636 .51109 m .49678 .51196 L .49678 .51197 L p .642 .271 0 r
F P
0 g
s
.49709 .513 m .49678 .51197 L .49678 .51196 L p .683 .393 0 r
F P
0 g
s
.51143 .50239 m .51197 .5032 L .51197 .5032 L p 0 0 .402 r
F P
0 g
s
.51197 .5032 m .51143 .50239 L .51143 .50239 L p 0 0 .402 r
F P
0 g
s
.49221 .5087 m .49124 .50877 L .49125 .50877 L p 0 0 0 r
F P
0 g
s
.49125 .50877 m .49221 .5087 L .49221 .5087 L p 0 0 0 r
F P
0 g
s
.49221 .4913 m .49125 .49123 L .49124 .49123 L p 0 .541 .712 r
F P
0 g
s
.49019 .49098 m .49124 .49123 L .49125 .49123 L p 0 .432 .693 r
F P
0 g
s
.51143 .49761 m .51197 .4968 L .51197 .4968 L p 0 0 0 r
F P
0 g
s
.51272 .49602 m .51197 .4968 L .51197 .4968 L p 0 0 0 r
F P
0 g
s
.49636 .4889 m .49678 .48803 L .49678 .48804 L p .642 .777 .317 r
F P
0 g
s
.49678 .48804 m .49636 .48891 L .49636 .4889 L p .642 .777 .317 r
F P
0 g
s
.7177 .87939 m .71868 .87892 L .71868 .87892 L p .006 0 0 r
F P
0 g
s
.71868 .87892 m .71762 .87947 L .7177 .87939 L p .006 0 0 r
F P
0 g
s
.06259 .49884 m .06251 .49993 L .0625 .49992 L p .95 .778 .322 r
F P
0 g
s
.0625 .49992 m .06256 .49873 L .06259 .49884 L p .95 .778 .322 r
F P
0 g
s
.71971 .12177 m .71881 .12115 L .71882 .12116 L p .002 .447 .865 r
F P
0 g
s
.71882 .12116 m .71982 .1218 L .71971 .12177 L p .002 .447 .865 r
F P
0 g
s
.71881 .87885 m .71971 .87823 L .71982 .8782 L p .002 0 0 r
F P
0 g
s
.71971 .87823 m .71881 .87885 L .7188 .87885 L p .004 0 0 r
F P
0 g
s
.71868 .12108 m .7177 .12061 L .71762 .12053 L p .006 .452 .867 r
F P
0 g
s
.7177 .12061 m .71868 .12108 L .71869 .12109 L p .008 .453 .868 r
F P
0 g
s
.06251 .50007 m .06259 .50116 L .06256 .50127 L p .95 .774 .317 r
F P
0 g
s
.06259 .50116 m .06251 .50007 L .06251 .50006 L p .951 .775 .319 r
F P
0 g
s
.49584 .51037 m .49636 .51109 L .49636 .5111 L p .582 .138 0 r
F P
0 g
s
.49678 .51197 m .49636 .5111 L .49636 .51109 L p .642 .271 0 r
F P
0 g
s
.51107 .50159 m .51143 .50239 L .51143 .50239 L p 0 0 .298 r
F P
0 g
s
.51143 .50239 m .51106 .50158 L .51107 .50159 L p 0 0 .298 r
F P
0 g
s
.49309 .50879 m .49221 .5087 L .49221 .5087 L p .078 0 0 r
F P
0 g
s
.49221 .5087 m .4931 .50879 L .49309 .50879 L p .078 0 0 r
F P
0 g
s
.4931 .49121 m .49221 .4913 L .49221 .4913 L p .078 .638 .711 r
F P
0 g
s
.49124 .49123 m .49221 .4913 L .49221 .4913 L p 0 .541 .712 r
F P
0 g
s
.51106 .49842 m .51143 .49761 L .51143 .49761 L p 0 0 0 r
F P
0 g
s
.51197 .4968 m .51143 .49761 L .51143 .49761 L p 0 0 0 r
F P
0 g
s
.49584 .48962 m .49636 .4889 L .49636 .48891 L p .582 .812 .42 r
F P
0 g
s
.49636 .48891 m .49584 .48963 L .49584 .48962 L p .582 .812 .42 r
F P
0 g
s
.49525 .50979 m .49584 .51037 L .49584 .51038 L p .504 0 0 r
F P
0 g
s
.49636 .5111 m .49584 .51038 L .49584 .51037 L p .582 .138 0 r
F P
0 g
s
.49389 .50901 m .49309 .50879 L .4931 .50879 L p .197 0 0 r
F P
0 g
s
.4931 .50879 m .49389 .50901 L .49389 .50901 L p .197 0 0 r
F P
0 g
s
.51086 .50078 m .51107 .50159 L .51106 .50158 L p 0 0 .185 r
F P
0 g
s
.51106 .50158 m .51085 .50078 L .51086 .50078 L p 0 0 .185 r
F P
0 g
s
.49389 .49099 m .4931 .49121 L .49309 .49121 L p .197 .717 .69 r
F P
0 g
s
.49221 .4913 m .49309 .49121 L .4931 .49121 L p .078 .638 .711 r
F P
0 g
s
.51085 .49922 m .51106 .49842 L .51107 .49841 L p 0 0 0 r
F P
0 g
s
.51143 .49761 m .51107 .49841 L .51106 .49842 L p 0 0 0 r
F P
0 g
s
.49525 .4902 m .49584 .48962 L .49584 .48963 L p .504 .823 .513 r
F P
0 g
s
.49584 .48963 m .49525 .49021 L .49525 .4902 L p .504 .823 .513 r
F P
0 g
s
.49461 .50934 m .49525 .50979 L .49525 .5098 L p .412 0 0 r
F P
0 g
s
.49584 .51038 m .49525 .5098 L .49525 .50979 L p .504 0 0 r
F P
0 g
s
.4946 .50935 m .49389 .50901 L .49389 .50901 L p .31 0 0 r
F P
0 g
s
.49389 .50901 m .49461 .50934 L .4946 .50935 L p .31 0 0 r
F P
0 g
s
.51079 .5 m .51086 .50078 L .51085 .50078 L p 0 0 .068 r
F P
0 g
s
.51085 .50078 m .51079 .5 L .51079 .5 L p 0 0 .068 r
F P
0 g
s
.49461 .49066 m .49389 .49099 L .49389 .49099 L p .31 .775 .648 r
F P
0 g
s
.49309 .49121 m .49389 .49099 L .49389 .49099 L p .197 .717 .69 r
F P
0 g
s
.51079 .5 m .51085 .49922 L .51086 .49922 L p 0 0 0 r
F P
0 g
s
.51107 .49841 m .51086 .49922 L .51085 .49922 L p 0 0 0 r
F P
0 g
s
.4946 .49065 m .49525 .4902 L .49525 .49021 L p .412 .811 .589 r
F P
0 g
s
.49525 .49021 m .49461 .49066 L .4946 .49065 L p .412 .811 .589 r
F P
0 g
s
.49525 .5098 m .4946 .50935 L .49461 .50934 L p .412 0 0 r
F P
0 g
s
.51086 .49922 m .51079 .5 L .51079 .5 L p 0 0 0 r
F P
0 g
s
.49389 .49099 m .4946 .49065 L .49461 .49066 L p .31 .775 .648 r
F P
0 g
s
.71762 .87947 m .71868 .87892 L .71868 .87893 L p .004 0 0 r
F P
0 g
s
.71868 .87893 m .71759 .87953 L .71762 .87947 L p .004 0 0 r
F P
0 g
s
.71982 .1218 m .71882 .12116 L .71882 .12116 L p 0 .446 .864 r
F P
0 g
s
.71882 .12116 m .71989 .1218 L .71982 .1218 L p 0 .446 .864 r
F P
0 g
s
.06256 .49873 m .0625 .49992 L .0625 .49992 L p .95 .777 .32 r
F P
0 g
s
.0625 .49992 m .06252 .49867 L .06256 .49873 L p .95 .777 .32 r
F P
0 g
s
.0625 .50008 m .06256 .50127 L .06252 .50133 L p .95 .773 .315 r
F P
0 g
s
.06256 .50127 m .0625 .50008 L .06251 .50007 L p .95 .774 .317 r
F P
0 g
s
.71882 .87884 m .71982 .8782 L .71989 .8782 L p 0 0 0 r
F P
0 g
s
.71982 .8782 m .71882 .87884 L .71881 .87885 L p .002 0 0 r
F P
0 g
s
.71868 .12108 m .71762 .12053 L .71759 .12047 L p .004 .451 .866 r
F P
0 g
s
.71762 .12053 m .71868 .12108 L .71868 .12108 L p .006 .452 .867 r
F P
0 g
s
.06252 .49867 m .0625 .49992 L .0625 .49992 L p .949 .777 .319 r
F P
0 g
s
.0625 .49992 m .06249 .49867 L .06252 .49867 L p .949 .777 .319 r
F P
0 g
s
.71759 .87953 m .71868 .87893 L .71868 .87893 L p .002 0 0 r
F P
0 g
s
.71868 .87893 m .7176 .87956 L .71759 .87953 L p .002 0 0 r
F P
0 g
s
.71989 .1218 m .71882 .12116 L .71882 .12115 L p 0 .444 .863 r
F P
0 g
s
.71882 .12115 m .71991 .12177 L .71989 .1218 L p 0 .444 .863 r
F P
0 g
s
.06254 .50672 m .06249 .50133 L .06252 .50133 L p .949 .763 .302 r
F P
0 g
s
.0625 .50008 m .06252 .50133 L .06249 .50133 L p .949 .773 .314 r
F P
0 g
s
.06252 .50133 m .0625 .50008 L .0625 .50008 L p .95 .773 .315 r
F P
0 g
s
.72455 .87549 m .71991 .87823 L .71989 .8782 L p 0 0 0 r
F P
0 g
s
.71882 .87884 m .71989 .8782 L .71991 .87823 L p 0 0 0 r
F P
0 g
s
.71989 .8782 m .71882 .87884 L .71882 .87884 L p 0 0 0 r
F P
0 g
s
.71291 .11779 m .7176 .12044 L .71759 .12047 L p .012 .463 .871 r
F P
0 g
s
.71868 .12107 m .71759 .12047 L .7176 .12044 L p .002 .45 .865 r
F P
0 g
s
.71759 .12047 m .71868 .12107 L .71868 .12108 L p .004 .451 .866 r
F P
0 g
s
.0625 .5 m .06251 .49998 L .06251 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .5 L .06251 .50002 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71876 .12113 L .71874 .12112 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12112 L .71873 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .87889 m .71873 .87889 L .71874 .87888 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87888 L .71876 .87887 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .87889 L .71873 .87889 L closepath p .001 0 0 r
F P
0 g
s
.71875 .12111 m .71877 .12114 L .71876 .12113 L closepath p .001 .447 .864 r
F P
0 g
s
.0625 .5 m .06251 .49997 L .06251 .49998 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71876 .87887 L .71877 .87886 L closepath p .001 0 0 r
F P
0 g
s
.71875 .12111 m .71873 .12111 L .71872 .12111 L closepath p .001 .448 .864 r
F P
0 g
s
.0625 .5 m .06251 .50002 L .06251 .50003 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .50003 L .06251 .50005 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71877 .87886 L .71879 .87885 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71872 .12111 L .7187 .1211 L closepath p .001 .448 .864 r
F P
0 g
s
.0625 .5 m .06251 .49995 L .06251 .49997 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .7187 .8789 L .71872 .87889 L closepath p .001 0 0 r
F P
0 g
s
.71875 .12111 m .71879 .12115 L .71877 .12114 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71869 .87891 L .7187 .8789 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87885 L .7188 .87885 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .7187 .1211 L .71869 .12109 L closepath p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .7188 .12115 L .71879 .12115 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .06251 .49994 L .06251 .49995 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .50005 L .06251 .50006 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71869 .12109 L .71868 .12108 L closepath p 0 .448 .864 r
F P
0 g
s
.71875 .12111 m .71881 .12115 L .7188 .12115 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .7188 .87885 L .71881 .87885 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71868 .87892 L .71869 .87891 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .06251 .50006 L .06251 .50007 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .06251 .49993 L .06251 .49994 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .49992 L .06251 .49993 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71868 .12108 L .71868 .12108 L closepath p 0 .448 .864 r
F P
0 g
s
.71875 .87889 m .71868 .87892 L .71868 .87892 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71881 .87885 L .71882 .87884 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71882 .12116 L .71881 .12115 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .06251 .50007 L .0625 .50008 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71868 .87893 L .71868 .87892 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71882 .87884 L .71882 .87884 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71882 .12116 L .71882 .12116 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .49992 L .0625 .49992 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .50008 L .0625 .50008 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71868 .12108 L .71868 .12107 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71868 .87893 L .71868 .87893 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49992 L .0625 .49992 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71882 .12115 L .71882 .12116 L closepath p 0 .447 .864 r
F P
0 g
s
.71991 .87823 m .71882 .87885 L .71882 .87884 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71882 .87884 L .71882 .87885 L closepath p 0 0 0 r
F P
0 g
s
.06249 .50133 m .0625 .50008 L .0625 .50008 L p .949 .773 .314 r
F P
0 g
s
.0625 .5 m .0625 .50008 L .0625 .50008 L closepath p .949 .774 .316 r
F P
0 g
s
.7176 .12044 m .71868 .12107 L .71868 .12107 L p .002 .45 .865 r
F P
0 g
s
.71875 .12111 m .71868 .12107 L .71868 .12107 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71876 .8789 L .71874 .8789 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71877 .87889 L .71876 .8789 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71878 .87888 L .71877 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .7188 .87887 L .71878 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71881 .87886 L .7188 .87887 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71882 .87885 L .71881 .87886 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71882 .87885 L .71882 .87885 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71882 .87885 L .71882 .87885 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .06249 .5 L .06249 .49998 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .50002 L .06249 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .50003 L .06249 .50002 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .50005 L .06249 .50003 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .50006 L .06249 .50005 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .50007 L .06249 .50006 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50008 L .06249 .50007 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50008 L .0625 .50008 L closepath p .949 .774 .316 r
F P
0 g
s
.71875 .12111 m .71876 .1211 L .71877 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .1211 L .71876 .1211 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .12109 L .71874 .1211 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71871 .12108 L .71873 .12109 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .7187 .12108 L .71871 .12108 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71869 .12107 L .7187 .12108 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71868 .12107 L .71869 .12107 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71868 .12107 L .71868 .12107 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71882 .12115 L .71882 .12115 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71882 .12115 L .71882 .12115 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71881 .12114 L .71882 .12115 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .7188 .12113 L .71881 .12114 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71878 .12112 L .7188 .12113 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12111 L .71878 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.45427 .9351 m
.5 .9375 L
s
.40904 .92794 m
.45427 .9351 L
s
.36481 .91609 m
.40904 .92794 L
s
.32205 .89968 m
.36481 .91609 L
s
.28125 .87889 m
.32205 .89968 L
s
.24284 .85394 m
.28125 .87889 L
s
.20726 .82513 m
.24284 .85394 L
s
.17487 .79274 m
.20726 .82513 L
s
.14606 .75716 m
.17487 .79274 L
s
.12111 .71875 m
.14606 .75716 L
s
.10032 .67795 m
.12111 .71875 L
s
.08391 .63519 m
.10032 .67795 L
s
.07206 .59096 m
.08391 .63519 L
s
.0649 .54573 m
.07206 .59096 L
s
.06368 .52251 m
.0649 .54573 L
s
.06368 .47749 m
.0649 .45427 L
s
.0649 .45427 m
.07206 .40904 L
s
.07206 .40904 m
.08391 .36481 L
s
.08391 .36481 m
.10032 .32205 L
s
.12111 .28125 m
.10032 .32205 L
s
.14606 .24284 m
.12111 .28125 L
s
.17487 .20726 m
.14606 .24284 L
s
.20726 .17487 m
.17487 .20726 L
s
.24284 .14606 m
.20726 .17487 L
s
.28125 .12111 m
.24284 .14606 L
s
.32205 .10032 m
.28125 .12111 L
s
.36481 .08391 m
.32205 .10032 L
s
.40904 .07206 m
.36481 .08391 L
s
.45427 .0649 m
.40904 .07206 L
s
.5 .0625 m
.45427 .0649 L
s
.54573 .9351 m
.5 .9375 L
s
.59096 .92794 m
.54573 .9351 L
s
.63519 .91609 m
.59096 .92794 L
s
.63519 .91609 m
.67795 .89968 L
s
.67795 .89968 m
.69867 .88912 L
s
.73765 .86661 m
.75716 .85394 L
s
.75716 .85394 m
.79274 .82513 L
s
.79274 .82513 m
.82513 .79274 L
s
.85394 .75716 m
.82513 .79274 L
s
.87889 .71875 m
.85394 .75716 L
s
.89968 .67795 m
.87889 .71875 L
s
.91609 .63519 m
.89968 .67795 L
s
.92794 .59096 m
.91609 .63519 L
s
.9351 .54573 m
.92794 .59096 L
s
.9375 .5 m
.9351 .54573 L
s
.9351 .45427 m
.9375 .5 L
s
.92794 .40904 m
.9351 .45427 L
s
.91609 .36481 m
.92794 .40904 L
s
.89968 .32205 m
.91609 .36481 L
s
.87889 .28125 m
.89968 .32205 L
s
.85394 .24284 m
.87889 .28125 L
s
.82513 .20726 m
.85394 .24284 L
s
.79274 .17487 m
.82513 .20726 L
s
.75716 .14606 m
.79274 .17487 L
s
.71875 .12111 m
.7327 .13017 L
s
.73765 .13339 m
.75716 .14606 L
s
.70393 .11356 m
.71875 .12111 L
s
.67795 .10032 m
.69867 .11088 L
s
.63519 .08391 m
.67795 .10032 L
s
.59096 .07206 m
.63519 .08391 L
s
.54573 .0649 m
.59096 .07206 L
s
.5 .0625 m
.54573 .0649 L
s
.71875 .87889 m .71868 .87893 L .71868 .87893 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71869 .87893 L .71868 .87893 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .7187 .87892 L .71869 .87893 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71871 .87892 L .7187 .87892 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71873 .87891 L .71871 .87892 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .8789 L .71873 .87891 L closepath p 0 0 0 r
F P
0 g
s
.70393 .88644 m
.71875 .87889 L
s
.71875 .87889 m
.7327 .86983 L
s
.0625 .5 m .0625 .49992 L .0625 .49992 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .06249 .49993 L .0625 .49992 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .06249 .49994 L .06249 .49993 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .06249 .49995 L .06249 .49994 L closepath p .948 .775 .316 r
F P
0 g
s
.0625 .5 m .06249 .49997 L .06249 .49995 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .49998 L .06249 .49997 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m
.06337 .51661 L
s
.0625 .5 m
.06337 .48339 L
s
.71767 .12044 m .71868 .12107 L .71868 .12107 L p 0 .449 .864 r
F P
0 g
s
.71868 .12107 m .7176 .12044 L .71767 .12044 L p 0 .449 .864 r
F P
0 g
s
.71988 .87829 m .71882 .87885 L .71882 .87885 L p 0 0 0 r
F P
0 g
s
.71882 .87885 m .71991 .87823 L .71988 .87829 L p 0 0 0 r
F P
0 g
s
.06245 .50127 m .0625 .50008 L .0625 .50008 L p .948 .772 .312 r
F P
0 g
s
.0625 .50008 m .06249 .50133 L .06245 .50127 L p .948 .772 .312 r
F P
0 g
s
.06249 .49867 m .0625 .49992 L .0625 .49992 L p .948 .776 .317 r
F P
0 g
s
.71991 .12177 m .71882 .12115 L .71882 .12115 L p 0 .443 .862 r
F P
0 g
s
.7176 .87956 m .71868 .87893 L .71868 .87893 L p 0 0 0 r
F P
0 g
s
.71868 .87893 m .71767 .87956 L .7176 .87956 L p 0 0 0 r
F P
0 g
s
.71767 .87956 m .71868 .87893 L .71869 .87893 L p 0 0 0 r
F P
0 g
s
.71882 .12115 m .71988 .12171 L .71991 .12177 L p 0 .443 .862 r
F P
0 g
s
.71988 .12171 m .71882 .12115 L .71882 .12115 L p 0 .442 .861 r
F P
0 g
s
.0625 .49992 m .06245 .49873 L .06249 .49867 L p .948 .776 .317 r
F P
0 g
s
.06245 .49873 m .0625 .49992 L .06249 .49993 L p .947 .775 .315 r
F P
0 g
s
.71979 .87837 m .71882 .87885 L .71882 .87885 L p 0 0 0 r
F P
0 g
s
.71882 .87885 m .71988 .87829 L .71979 .87837 L p 0 0 0 r
F P
0 g
s
.71779 .12047 m .71869 .12107 L .71868 .12107 L p 0 .448 .863 r
F P
0 g
s
.71868 .12107 m .71767 .12044 L .71779 .12047 L p 0 .448 .863 r
F P
0 g
s
.06242 .50116 m .06249 .50007 L .0625 .50008 L p .947 .771 .311 r
F P
0 g
s
.0625 .50008 m .06245 .50127 L .06242 .50116 L p .947 .771 .311 r
F P
0 g
s
.06239 .50099 m .06249 .50006 L .06249 .50007 L p .946 .771 .309 r
F P
0 g
s
.06249 .50007 m .06242 .50116 L .06239 .50099 L p .946 .771 .309 r
F P
0 g
s
.71966 .87848 m .71881 .87886 L .71882 .87885 L p 0 0 0 r
F P
0 g
s
.71882 .87885 m .71979 .87837 L .71966 .87848 L p 0 0 0 r
F P
0 g
s
.71794 .12052 m .7187 .12108 L .71869 .12107 L p 0 .446 .862 r
F P
0 g
s
.71869 .12107 m .71779 .12047 L .71794 .12052 L p 0 .446 .862 r
F P
0 g
s
.71882 .12115 m .71979 .12163 L .71988 .12171 L p 0 .442 .861 r
F P
0 g
s
.71979 .12163 m .71882 .12115 L .71881 .12114 L p 0 .442 .86 r
F P
0 g
s
.71869 .87893 m .71779 .87953 L .71767 .87956 L p 0 0 0 r
F P
0 g
s
.71779 .87953 m .71869 .87893 L .7187 .87892 L p 0 0 0 r
F P
0 g
s
.06249 .49993 m .06242 .49884 L .06245 .49873 L p .947 .775 .315 r
F P
0 g
s
.06242 .49884 m .06249 .49993 L .06249 .49994 L p .946 .774 .313 r
F P
0 g
s
.06249 .49994 m .06239 .49901 L .06242 .49884 L p .946 .774 .313 r
F P
0 g
s
.06239 .49901 m .06249 .49994 L .06249 .49995 L p .946 .773 .312 r
F P
0 g
s
.7187 .87892 m .71794 .87948 L .71779 .87953 L p 0 0 0 r
F P
0 g
s
.71794 .87948 m .7187 .87892 L .71871 .87892 L p 0 0 0 r
F P
0 g
s
.71881 .12114 m .71966 .12152 L .71979 .12163 L p 0 .442 .86 r
F P
0 g
s
.71966 .12152 m .71881 .12114 L .7188 .12113 L p 0 .441 .86 r
F P
0 g
s
.7195 .87861 m .7188 .87887 L .71881 .87886 L p 0 0 0 r
F P
0 g
s
.71881 .87886 m .71966 .87848 L .7195 .87861 L p 0 0 0 r
F P
0 g
s
.71813 .12061 m .71871 .12108 L .7187 .12108 L p 0 .445 .861 r
F P
0 g
s
.7187 .12108 m .71794 .12052 L .71813 .12061 L p 0 .445 .861 r
F P
0 g
s
.06237 .50079 m .06249 .50005 L .06249 .50006 L p .946 .771 .308 r
F P
0 g
s
.06249 .50006 m .06239 .50099 L .06237 .50079 L p .946 .771 .308 r
F P
0 g
s
.7188 .12113 m .7195 .12139 L .71966 .12152 L p 0 .441 .86 r
F P
0 g
s
.7195 .12139 m .7188 .12113 L .71878 .12112 L p 0 .441 .859 r
F P
0 g
s
.71871 .87892 m .71813 .87939 L .71794 .87948 L p 0 0 0 r
F P
0 g
s
.71813 .87939 m .71871 .87892 L .71873 .87891 L p 0 0 0 r
F P
0 g
s
.7193 .87874 m .71878 .87888 L .7188 .87887 L p 0 0 0 r
F P
0 g
s
.7188 .87887 m .7195 .87861 L .7193 .87874 L p 0 0 0 r
F P
0 g
s
.71835 .12071 m .71873 .12109 L .71871 .12108 L p 0 .444 .861 r
F P
0 g
s
.71871 .12108 m .71813 .12061 L .71835 .12071 L p 0 .444 .861 r
F P
0 g
s
.06235 .50054 m .06249 .50003 L .06249 .50005 L p .945 .771 .308 r
F P
0 g
s
.06249 .50005 m .06237 .50079 L .06235 .50054 L p .945 .771 .308 r
F P
0 g
s
.06249 .49995 m .06237 .49921 L .06239 .49901 L p .946 .773 .312 r
F P
0 g
s
.06237 .49921 m .06249 .49995 L .06249 .49997 L p .945 .773 .31 r
F P
0 g
s
.71859 .12084 m .71874 .1211 L .71873 .12109 L p 0 .443 .86 r
F P
0 g
s
.71873 .12109 m .71835 .12071 L .71859 .12084 L p 0 .443 .86 r
F P
0 g
s
.06234 .50028 m .06249 .50002 L .06249 .50003 L p .945 .771 .308 r
F P
0 g
s
.06249 .50003 m .06235 .50054 L .06234 .50028 L p .945 .771 .308 r
F P
0 g
s
.71907 .87888 m .71877 .87889 L .71878 .87888 L p 0 0 0 r
F P
0 g
s
.71878 .87888 m .7193 .87874 L .71907 .87888 L p 0 0 0 r
F P
0 g
s
.71878 .12112 m .7193 .12126 L .7195 .12139 L p 0 .441 .859 r
F P
0 g
s
.7193 .12126 m .71878 .12112 L .71877 .12111 L p 0 .441 .859 r
F P
0 g
s
.06249 .49997 m .06235 .49946 L .06237 .49921 L p .945 .773 .31 r
F P
0 g
s
.06235 .49946 m .06249 .49997 L .06249 .49998 L p .945 .772 .309 r
F P
0 g
s
.71873 .87891 m .71835 .87929 L .71813 .87939 L p 0 0 0 r
F P
0 g
s
.71835 .87929 m .71873 .87891 L .71874 .8789 L p 0 0 0 r
F P
0 g
s
.06249 .49998 m .06234 .49972 L .06235 .49946 L p .945 .772 .309 r
F P
0 g
s
.06234 .49972 m .06249 .49998 L .06249 .5 L p .945 .771 .308 r
F P
0 g
s
.71874 .8789 m .71859 .87916 L .71835 .87929 L p 0 0 0 r
F P
0 g
s
.71859 .87916 m .71874 .8789 L .71876 .8789 L p 0 0 0 r
F P
0 g
s
.06234 .5 m .06249 .5 L .06249 .50002 L p .945 .771 .308 r
F P
0 g
s
.06249 .50002 m .06234 .50028 L .06234 .5 L p .945 .771 .308 r
F P
0 g
s
.71877 .12111 m .71907 .12112 L .7193 .12126 L p 0 .441 .859 r
F P
0 g
s
.71907 .12112 m .71877 .12111 L .71876 .1211 L p 0 .441 .859 r
F P
0 g
s
.71883 .87903 m .71876 .8789 L .71877 .87889 L p 0 0 0 r
F P
0 g
s
.71877 .87889 m .71907 .87888 L .71883 .87903 L p 0 0 0 r
F P
0 g
s
.71883 .12097 m .71876 .1211 L .71874 .1211 L p 0 .442 .859 r
F P
0 g
s
.71874 .1211 m .71859 .12084 L .71883 .12097 L p 0 .442 .859 r
F P
0 g
s
.71876 .8789 m .71883 .87903 L .71859 .87916 L p 0 0 0 r
F P
0 g
s
.06249 .5 m .06234 .5 L .06234 .49972 L p .945 .771 .308 r
F P
0 g
s
.71876 .1211 m .71883 .12097 L .71907 .12112 L p 0 .441 .859 r
F P
0 g
s
.71291 .88221 m .7176 .87956 L .71767 .87956 L p 0 0 0 r
F P
0 g
s
.06254 .49328 m .06249 .49867 L .06245 .49873 L p .944 .782 .321 r
F P
0 g
s
.72455 .12451 m .71991 .12177 L .71988 .12171 L p 0 .425 .851 r
F P
0 g
s
.72439 .87579 m .71988 .87829 L .71991 .87823 L p 0 0 0 r
F P
0 g
s
.71991 .87823 m .72455 .87549 L .72439 .87579 L p 0 0 0 r
F P
0 g
s
.71325 .11778 m .71767 .12044 L .7176 .12044 L p 0 .456 .865 r
F P
0 g
s
.7176 .12044 m .71291 .11779 L .71325 .11778 L p 0 .456 .865 r
F P
0 g
s
.06236 .50643 m .06245 .50127 L .06249 .50133 L p .944 .759 .293 r
F P
0 g
s
.06249 .50133 m .06254 .50672 L .06236 .50643 L p .944 .759 .293 r
F P
0 g
s
.71383 .11793 m .71779 .12047 L .71767 .12044 L p 0 .449 .859 r
F P
0 g
s
.71767 .12044 m .71325 .11778 L .71383 .11793 L p 0 .449 .859 r
F P
0 g
s
.72397 .87622 m .71979 .87837 L .71988 .87829 L p 0 0 0 r
F P
0 g
s
.71988 .87829 m .72439 .87579 L .72397 .87622 L p 0 0 0 r
F P
0 g
s
.71767 .87956 m .71325 .88222 L .71291 .88221 L p 0 0 0 r
F P
0 g
s
.71325 .88222 m .71767 .87956 L .71779 .87953 L p 0 0 0 r
F P
0 g
s
.06245 .49873 m .06236 .49357 L .06254 .49328 L p .944 .782 .321 r
F P
0 g
s
.06236 .49357 m .06245 .49873 L .06242 .49884 L p .939 .777 .311 r
F P
0 g
s
.71988 .12171 m .72439 .12421 L .72455 .12451 L p 0 .425 .851 r
F P
0 g
s
.72439 .12421 m .71988 .12171 L .71979 .12163 L p 0 .42 .846 r
F P
0 g
s
.0622 .50586 m .06242 .50116 L .06245 .50127 L p .939 .756 .284 r
F P
0 g
s
.06245 .50127 m .06236 .50643 L .0622 .50586 L p .939 .756 .284 r
F P
0 g
s
.49525 .4902 m .4946 .49065 L .49477 .49093 L p .248 0 .129 r
F P
0 g
s
.4946 .49065 m .49389 .49099 L .49403 .49128 L p .319 0 .089 r
F P
0 g
s
.49403 .49128 m .49477 .49093 L .4946 .49065 L p .319 0 .089 r
F P
0 g
s
.51079 .5 m .51086 .49922 L .51053 .49919 L p .997 .848 .562 r
F P
0 g
s
.51053 .49919 m .51047 .5 L .51079 .5 L p .997 .848 .562 r
F P
0 g
s
.51086 .50078 m .51079 .5 L .51047 .5 L p .997 .781 .48 r
F P
0 g
s
.49389 .50901 m .4946 .50935 L .49477 .50907 L p .319 .613 .954 r
F P
0 g
s
.4946 .50935 m .49525 .5098 L .49543 .50953 L p .248 .522 .913 r
F P
0 g
s
.49543 .50953 m .49477 .50907 L .4946 .50935 L p .248 .522 .913 r
F P
0 g
s
.49477 .49093 m .49543 .49047 L .49525 .4902 L p .248 0 .129 r
F P
0 g
s
.49584 .48962 m .49525 .4902 L .49543 .49047 L p .178 0 .175 r
F P
0 g
s
.51086 .49922 m .51107 .49841 L .51074 .49836 L p .983 .903 .64 r
F P
0 g
s
.51074 .49836 m .51053 .49919 L .51086 .49922 L p .983 .903 .64 r
F P
0 g
s
.49389 .49099 m .49309 .49121 L .49321 .49152 L p .391 0 .052 r
F P
0 g
s
.49321 .49152 m .49403 .49128 L .49389 .49099 L p .391 0 .052 r
F P
0 g
s
.51047 .5 m .51053 .50081 L .51086 .50078 L p .997 .781 .48 r
F P
0 g
s
.51107 .50159 m .51086 .50078 L .51053 .50081 L p .983 .702 .394 r
F P
0 g
s
.49477 .50907 m .49403 .50872 L .49389 .50901 L p .319 .613 .954 r
F P
0 g
s
.49309 .50879 m .49389 .50901 L .49403 .50872 L p .391 .699 .982 r
F P
0 g
s
.49525 .5098 m .49584 .51038 L .49605 .51012 L p .178 .424 .859 r
F P
0 g
s
.49605 .51012 m .49543 .50953 L .49525 .5098 L p .178 .424 .859 r
F P
0 g
s
.49543 .49047 m .49605 .48988 L .49584 .48962 L p .178 0 .175 r
F P
0 g
s
.49636 .4889 m .49584 .48962 L .49605 .48988 L p .109 0 .226 r
F P
0 g
s
.51107 .49841 m .51143 .49761 L .5111 .49753 L p .955 .947 .715 r
F P
0 g
s
.5111 .49753 m .51074 .49836 L .51107 .49841 L p .955 .947 .715 r
F P
0 g
s
.49309 .49121 m .49221 .4913 L .49231 .49162 L p .464 0 .021 r
F P
0 g
s
.49231 .49162 m .49321 .49152 L .49309 .49121 L p .464 0 .021 r
F P
0 g
s
.51053 .50081 m .51074 .50164 L .51107 .50159 L p .983 .702 .394 r
F P
0 g
s
.51143 .50239 m .51107 .50159 L .51074 .50164 L p .955 .612 .304 r
F P
0 g
s
.49403 .50872 m .49321 .50848 L .49309 .50879 L p .391 .699 .982 r
F P
0 g
s
.49221 .5087 m .49309 .50879 L .49321 .50848 L p .464 .778 .998 r
F P
0 g
s
.49584 .51038 m .49636 .5111 L .49659 .51085 L p .109 .32 .792 r
F P
0 g
s
.49659 .51085 m .49605 .51012 L .49584 .51038 L p .109 .32 .792 r
F P
0 g
s
.49605 .48988 m .49659 .48915 L .49636 .4889 L p .109 0 .226 r
F P
0 g
s
.49678 .48803 m .49636 .4889 L .49659 .48915 L p .042 0 .281 r
F P
0 g
s
.51143 .49761 m .51197 .4968 L .51164 .4967 L p .911 .977 .782 r
F P
0 g
s
.51164 .4967 m .5111 .49753 L .51143 .49761 L p .911 .977 .782 r
F P
0 g
s
.49221 .4913 m .49124 .49123 L .49132 .49157 L p .537 .029 0 r
F P
0 g
s
.49132 .49157 m .49231 .49162 L .49221 .4913 L p .537 .029 0 r
F P
0 g
s
.49321 .50848 m .49231 .50838 L .49221 .5087 L p .464 .778 .998 r
F P
0 g
s
.49124 .50877 m .49221 .5087 L .49231 .50838 L p .537 .848 .998 r
F P
0 g
s
.51074 .50164 m .5111 .50247 L .51143 .50239 L p .955 .612 .304 r
F P
0 g
s
.51197 .5032 m .51143 .50239 L .5111 .50247 L p .911 .51 .211 r
F P
0 g
s
.49636 .5111 m .49678 .51197 L .49704 .51173 L p .042 .21 .712 r
F P
0 g
s
.49704 .51173 m .49659 .51085 L .49636 .5111 L p .042 .21 .712 r
F P
0 g
s
.71779 .87953 m .71383 .88207 L .71325 .88222 L p 0 0 0 r
F P
0 g
s
.71383 .88207 m .71779 .87953 L .71794 .87948 L p 0 0 0 r
F P
0 g
s
.72332 .87675 m .71966 .87848 L .71979 .87837 L p 0 0 0 r
F P
0 g
s
.71979 .87837 m .72397 .87622 L .72332 .87675 L p 0 0 0 r
F P
0 g
s
.71979 .12163 m .72397 .12378 L .72439 .12421 L p 0 .42 .846 r
F P
0 g
s
.72397 .12378 m .71979 .12163 L .71966 .12152 L p 0 .416 .842 r
F P
0 g
s
.06242 .49884 m .0622 .49414 L .06236 .49357 L p .939 .777 .311 r
F P
0 g
s
.0622 .49414 m .06242 .49884 L .06239 .49901 L p .934 .772 .301 r
F P
0 g
s
.71462 .11822 m .71794 .12052 L .71779 .12047 L p 0 .442 .854 r
F P
0 g
s
.71779 .12047 m .71383 .11793 L .71462 .11822 L p 0 .442 .854 r
F P
0 g
s
.06206 .50503 m .06239 .50099 L .06242 .50116 L p .934 .753 .277 r
F P
0 g
s
.06242 .50116 m .0622 .50586 L .06206 .50503 L p .934 .753 .277 r
F P
0 g
s
.49659 .48915 m .49704 .48827 L .49678 .48803 L p .042 0 .281 r
F P
0 g
s
.49709 .487 m .49678 .48803 L .49704 .48827 L p 0 0 .337 r
F P
0 g
s
.51197 .4968 m .51272 .49602 L .51237 .49589 L p .852 .992 .841 r
F P
0 g
s
.51237 .49589 m .51164 .4967 L .51197 .4968 L p .852 .992 .841 r
F P
0 g
s
.49124 .49123 m .49019 .49098 L .49025 .49134 L p .606 .083 0 r
F P
0 g
s
.49025 .49134 m .49132 .49157 L .49124 .49123 L p .606 .083 0 r
F P
0 g
s
.49231 .50838 m .49132 .50843 L .49124 .50877 L p .537 .848 .998 r
F P
0 g
s
.49019 .50902 m .49124 .50877 L .49132 .50843 L p .606 .907 .983 r
F P
0 g
s
.5111 .50247 m .51164 .5033 L .51197 .5032 L p .911 .51 .211 r
F P
0 g
s
.51272 .50398 m .51197 .5032 L .51164 .5033 L p .852 .4 .117 r
F P
0 g
s
.49678 .51197 m .49709 .513 L .49738 .51277 L p 0 .099 .621 r
F P
0 g
s
.49738 .51277 m .49704 .51173 L .49678 .51197 L p 0 .099 .621 r
F P
0 g
s
.06344 .47884 m .06254 .49328 L .06236 .49357 L p .929 .798 .331 r
F P
0 g
s
.69995 .88866 m .71291 .88221 L .71325 .88222 L p .001 0 0 r
F P
0 g
s
.73661 .13251 m .72455 .12451 L .72439 .12421 L p 0 .371 .819 r
F P
0 g
s
.7361 .86841 m .72439 .87579 L .72455 .87549 L p 0 0 0 r
F P
0 g
s
.72455 .87549 m .73661 .86749 L .7361 .86841 L p 0 0 0 r
F P
0 g
s
.06289 .52026 m .06236 .50643 L .06254 .50672 L p .929 .72 .235 r
F P
0 g
s
.06254 .50672 m .06344 .52116 L .06289 .52026 L p .929 .72 .235 r
F P
0 g
s
.701 .11132 m .71325 .11778 L .71291 .11779 L p .001 .477 .866 r
F P
0 g
s
.71291 .11779 m .69995 .11134 L .701 .11132 L p .001 .477 .866 r
F P
0 g
s
.49704 .48827 m .49738 .48723 L .49709 .487 L p 0 0 .337 r
F P
0 g
s
.49725 .48578 m .49709 .487 L .49738 .48723 L p 0 0 .393 r
F P
0 g
s
.51272 .49602 m .51369 .49527 L .51333 .49511 L p .78 .99 .889 r
F P
0 g
s
.51333 .49511 m .51237 .49589 L .51272 .49602 L p .78 .99 .889 r
F P
0 g
s
.49019 .49098 m .48905 .49051 L .4891 .4909 L p .67 .142 0 r
F P
0 g
s
.4891 .4909 m .49025 .49134 L .49019 .49098 L p .67 .142 0 r
F P
0 g
s
.49132 .50843 m .49025 .50866 L .49019 .50902 L p .606 .907 .983 r
F P
0 g
s
.48905 .50949 m .49019 .50902 L .49025 .50866 L p .67 .952 .953 r
F P
0 g
s
.51164 .5033 m .51237 .50411 L .51272 .50398 L p .852 .4 .117 r
F P
0 g
s
.51369 .50473 m .51272 .50398 L .51237 .50411 L p .78 .284 .024 r
F P
0 g
s
.49709 .513 m .49725 .51422 L .49757 .51399 L p 0 0 .52 r
F P
0 g
s
.49757 .51399 m .49738 .51277 L .49709 .513 L p 0 0 .52 r
F P
0 g
s
.49738 .48723 m .49757 .48601 L .49725 .48578 L p 0 0 .393 r
F P
0 g
s
.49723 .48435 m .49725 .48578 L .49757 .48601 L p 0 0 .446 r
F P
0 g
s
.51369 .49527 m .51494 .49457 L .51455 .49438 L p .696 .972 .924 r
F P
0 g
s
.51455 .49438 m .51333 .49511 L .51369 .49527 L p .696 .972 .924 r
F P
0 g
s
.48905 .49051 m .48783 .48977 L .48786 .4902 L p .725 .202 0 r
F P
0 g
s
.48786 .4902 m .4891 .4909 L .48905 .49051 L p .725 .202 0 r
F P
0 g
s
.49025 .50866 m .4891 .5091 L .48905 .50949 L p .67 .952 .953 r
F P
0 g
s
.48783 .51023 m .48905 .50949 L .4891 .5091 L p .725 .982 .907 r
F P
0 g
s
.51237 .50411 m .51333 .50489 L .51369 .50473 L p .78 .284 .024 r
F P
0 g
s
.51494 .50543 m .51369 .50473 L .51333 .50489 L p .696 .164 0 r
F P
0 g
s
.49725 .51422 m .49723 .51565 L .49759 .51541 L p 0 0 .413 r
F P
0 g
s
.49759 .51541 m .49757 .51399 L .49725 .51422 L p 0 0 .413 r
F P
0 g
s
.71794 .87948 m .71462 .88178 L .71383 .88207 L p 0 0 0 r
F P
0 g
s
.71462 .88178 m .71794 .87948 L .71813 .87939 L p 0 0 0 r
F P
0 g
s
.06239 .49901 m .06206 .49497 L .0622 .49414 L p .934 .772 .301 r
F P
0 g
s
.06206 .49497 m .06239 .49901 L .06237 .49921 L p .93 .767 .291 r
F P
0 g
s
.71966 .12152 m .72332 .12325 L .72397 .12378 L p 0 .416 .842 r
F P
0 g
s
.72332 .12325 m .71966 .12152 L .7195 .12139 L p 0 .413 .838 r
F P
0 g
s
.06194 .50398 m .06237 .50079 L .06239 .50099 L p .93 .752 .272 r
F P
0 g
s
.06239 .50099 m .06206 .50503 L .06194 .50398 L p .93 .752 .272 r
F P
0 g
s
.71559 .11864 m .71813 .12061 L .71794 .12052 L p 0 .434 .848 r
F P
0 g
s
.71794 .12052 m .71462 .11822 L .71559 .11864 L p 0 .434 .848 r
F P
0 g
s
.72247 .87738 m .7195 .87861 L .71966 .87848 L p 0 0 0 r
F P
0 g
s
.71966 .87848 m .72332 .87675 L .72247 .87738 L p 0 0 0 r
F P
0 g
s
.49757 .48601 m .49759 .48459 L .49723 .48435 L p 0 0 .446 r
F P
0 g
s
.49697 .48267 m .49723 .48435 L .49759 .48459 L p 0 0 .495 r
F P
0 g
s
.51494 .49457 m .51652 .49396 L .51609 .49373 L p .604 .939 .946 r
F P
0 g
s
.51609 .49373 m .51455 .49438 L .51494 .49457 L p .604 .939 .946 r
F P
0 g
s
.48783 .48977 m .48651 .48872 L .48653 .48919 L p .77 .261 0 r
F P
0 g
s
.48653 .48919 m .48786 .4902 L .48783 .48977 L p .77 .261 0 r
F P
0 g
s
.4891 .5091 m .48786 .5098 L .48783 .51023 L p .725 .982 .907 r
F P
0 g
s
.48651 .51128 m .48783 .51023 L .48786 .5098 L p .77 .997 .85 r
F P
0 g
s
.51333 .50489 m .51455 .50562 L .51494 .50543 L p .696 .164 0 r
F P
0 g
s
.51652 .50604 m .51494 .50543 L .51455 .50562 L p .604 .047 0 r
F P
0 g
s
.49723 .51565 m .49697 .51733 L .49738 .51707 L p 0 0 .303 r
F P
0 g
s
.49738 .51707 m .49759 .51541 L .49723 .51565 L p 0 0 .303 r
F P
0 g
s
.49759 .48459 m .49738 .48293 L .49697 .48267 L p 0 0 .495 r
F P
0 g
s
.49642 .4807 m .49697 .48267 L .49738 .48293 L p 0 0 .536 r
F P
0 g
s
.51652 .49396 m .5185 .49345 L .51802 .49319 L p .508 .895 .954 r
F P
0 g
s
.51802 .49319 m .51609 .49373 L .51652 .49396 L p .508 .895 .954 r
F P
0 g
s
.48651 .48872 m .48508 .48725 L .48509 .4878 L p .804 .315 0 r
F P
0 g
s
.48509 .4878 m .48653 .48919 L .48651 .48872 L p .804 .315 0 r
F P
0 g
s
.48786 .5098 m .48653 .51081 L .48651 .51128 L p .77 .997 .85 r
F P
0 g
s
.48508 .51275 m .48651 .51128 L .48653 .51081 L p .804 .997 .783 r
F P
0 g
s
.51455 .50562 m .51609 .50627 L .51652 .50604 L p .604 .047 0 r
F P
0 g
s
.5185 .50655 m .51652 .50604 L .51609 .50627 L p .508 0 0 r
F P
0 g
s
.49697 .51733 m .49642 .5193 L .49689 .51901 L p 0 0 .195 r
F P
0 g
s
.49689 .51901 m .49738 .51707 L .49697 .51733 L p 0 0 .195 r
F P
0 g
s
.72146 .87807 m .7193 .87874 L .7195 .87861 L p 0 0 0 r
F P
0 g
s
.7195 .87861 m .72247 .87738 L .72146 .87807 L p 0 0 0 r
F P
0 g
s
.06185 .50275 m .06235 .50054 L .06237 .50079 L p .927 .751 .268 r
F P
0 g
s
.06237 .50079 m .06194 .50398 L .06185 .50275 L p .927 .751 .268 r
F P
0 g
s
.71669 .11918 m .71835 .12071 L .71813 .12061 L p 0 .428 .843 r
F P
0 g
s
.71813 .12061 m .71559 .11864 L .71669 .11918 L p 0 .428 .843 r
F P
0 g
s
.06237 .49921 m .06194 .49602 L .06206 .49497 L p .93 .767 .291 r
F P
0 g
s
.06194 .49602 m .06237 .49921 L .06235 .49946 L p .927 .763 .283 r
F P
0 g
s
.71813 .87939 m .71559 .88136 L .71462 .88178 L p 0 0 0 r
F P
0 g
s
.71559 .88136 m .71813 .87939 L .71835 .87929 L p 0 0 0 r
F P
0 g
s
.7195 .12139 m .72247 .12262 L .72332 .12325 L p 0 .413 .838 r
F P
0 g
s
.72247 .12262 m .7195 .12139 L .7193 .12126 L p 0 .411 .836 r
F P
0 g
s
.0618 .50141 m .06234 .50028 L .06235 .50054 L p .924 .751 .267 r
F P
0 g
s
.06235 .50054 m .06185 .50275 L .0618 .50141 L p .924 .751 .267 r
F P
0 g
s
.71835 .87929 m .71669 .88082 L .71559 .88136 L p 0 0 0 r
F P
0 g
s
.71669 .88082 m .71835 .87929 L .71859 .87916 L p 0 0 0 r
F P
0 g
s
.72032 .87879 m .71907 .87888 L .7193 .87874 L p 0 0 0 r
F P
0 g
s
.7193 .87874 m .72146 .87807 L .72032 .87879 L p 0 0 0 r
F P
0 g
s
.06235 .49946 m .06185 .49725 L .06194 .49602 L p .927 .763 .283 r
F P
0 g
s
.06185 .49725 m .06235 .49946 L .06234 .49972 L p .924 .758 .276 r
F P
0 g
s
.71788 .1198 m .71859 .12084 L .71835 .12071 L p 0 .422 .839 r
F P
0 g
s
.71835 .12071 m .71669 .11918 L .71788 .1198 L p 0 .422 .839 r
F P
0 g
s
.7193 .12126 m .72146 .12193 L .72247 .12262 L p 0 .411 .836 r
F P
0 g
s
.72146 .12193 m .7193 .12126 L .71907 .12112 L p 0 .412 .835 r
F P
0 g
s
.49738 .48293 m .49689 .48099 L .49642 .4807 L p 0 0 .536 r
F P
0 g
s
.49549 .47837 m .49642 .4807 L .49689 .48099 L p 0 0 .57 r
F P
0 g
s
.5185 .49345 m .52099 .49309 L .52044 .49278 L p .414 .843 .951 r
F P
0 g
s
.52044 .49278 m .51802 .49319 L .5185 .49345 L p .414 .843 .951 r
F P
0 g
s
.48508 .48725 m .48352 .48528 L .48353 .48591 L p .827 .364 0 r
F P
0 g
s
.48353 .48591 m .48509 .4878 L .48508 .48725 L p .827 .364 0 r
F P
0 g
s
.48653 .51081 m .48509 .5122 L .48508 .51275 L p .804 .997 .783 r
F P
0 g
s
.48352 .51472 m .48508 .51275 L .48509 .5122 L p .827 .986 .712 r
F P
0 g
s
.49642 .5193 m .49549 .52163 L .49603 .52131 L p 0 0 .093 r
F P
0 g
s
.49603 .52131 m .49689 .51901 L .49642 .5193 L p 0 0 .093 r
F P
0 g
s
.51609 .50627 m .51802 .50681 L .5185 .50655 L p .508 0 0 r
F P
0 g
s
.52099 .50691 m .5185 .50655 L .51802 .50681 L p .414 0 0 r
F P
0 g
s
.06234 .49972 m .0618 .49859 L .06185 .49725 L p .924 .758 .276 r
F P
0 g
s
.0618 .49859 m .06234 .49972 L .06234 .5 L p .923 .755 .271 r
F P
0 g
s
.71859 .87916 m .71788 .8802 L .71669 .88082 L p 0 0 0 r
F P
0 g
s
.71788 .8802 m .71859 .87916 L .71883 .87903 L p 0 0 0 r
F P
0 g
s
.71911 .12049 m .71883 .12097 L .71859 .12084 L p 0 .417 .836 r
F P
0 g
s
.71859 .12084 m .71788 .1198 L .71911 .12049 L p 0 .417 .836 r
F P
0 g
s
.71911 .87951 m .71883 .87903 L .71907 .87888 L p 0 0 0 r
F P
0 g
s
.71907 .87888 m .72032 .87879 L .71911 .87951 L p 0 0 0 r
F P
0 g
s
.06178 .5 m .06234 .5 L .06234 .50028 L p .923 .752 .268 r
F P
0 g
s
.06234 .50028 m .0618 .50141 L .06178 .5 L p .923 .752 .268 r
F P
0 g
s
.71907 .12112 m .72032 .12121 L .72146 .12193 L p 0 .412 .835 r
F P
0 g
s
.72032 .12121 m .71907 .12112 L .71883 .12097 L p 0 .413 .835 r
F P
0 g
s
.71883 .87903 m .71911 .87951 L .71788 .8802 L p 0 0 0 r
F P
0 g
s
.71883 .12097 m .71911 .12049 L .72032 .12121 L p 0 .413 .835 r
F P
0 g
s
.06234 .5 m .06178 .5 L .0618 .49859 L p .923 .755 .271 r
F P
0 g
s
.49689 .48099 m .49603 .47869 L .49549 .47837 L p 0 0 .57 r
F P
0 g
s
.49406 .47557 m .49549 .47837 L .49603 .47869 L p 0 .023 .596 r
F P
0 g
s
.52099 .49309 m .52413 .49293 L .52349 .49255 L p .325 .788 .939 r
F P
0 g
s
.52349 .49255 m .52044 .49278 L .52099 .49309 L p .325 .788 .939 r
F P
0 g
s
.48352 .48528 m .48181 .48264 L .48181 .48338 L p .84 .405 0 r
F P
0 g
s
.48181 .48338 m .48353 .48591 L .48352 .48528 L p .84 .405 0 r
F P
0 g
s
.48509 .5122 m .48353 .51409 L .48352 .51472 L p .827 .986 .712 r
F P
0 g
s
.48181 .51736 m .48352 .51472 L .48353 .51409 L p .84 .966 .642 r
F P
0 g
s
.49549 .52163 m .49406 .52443 L .49471 .52406 L p 0 0 .001 r
F P
0 g
s
.49471 .52406 m .49603 .52131 L .49549 .52163 L p 0 0 .001 r
F P
0 g
s
.51802 .50681 m .52044 .50722 L .52099 .50691 L p .414 0 0 r
F P
0 g
s
.52413 .50707 m .52099 .50691 L .52044 .50722 L p .325 0 0 r
F P
0 g
s
.52413 .49293 m .52813 .49302 L .52737 .49256 L p .248 .736 .923 r
F P
0 g
s
.52737 .49256 m .52349 .49255 L .52413 .49293 L p .248 .736 .923 r
F P
0 g
s
.49603 .47869 m .49471 .47594 L .49406 .47557 L p 0 .023 .596 r
F P
0 g
s
.49198 .47215 m .49406 .47557 L .49471 .47594 L p 0 .048 .614 r
F P
0 g
s
.48181 .48264 m .47989 .47913 L .47987 .48002 L p .846 .438 0 r
F P
0 g
s
.47987 .48002 m .48181 .48338 L .48181 .48264 L p .846 .438 0 r
F P
0 g
s
.48353 .51409 m .48181 .51662 L .48181 .51736 L p .84 .966 .642 r
F P
0 g
s
.47989 .52087 m .48181 .51736 L .48181 .51662 L p .846 .942 .578 r
F P
0 g
s
.52044 .50722 m .52349 .50745 L .52413 .50707 L p .325 0 0 r
F P
0 g
s
.52813 .50698 m .52413 .50707 L .52349 .50745 L p .248 0 0 r
F P
0 g
s
.49406 .52443 m .49198 .52785 L .49276 .52742 L p 0 0 0 r
F P
0 g
s
.49276 .52742 m .49471 .52406 L .49406 .52443 L p 0 0 0 r
F P
0 g
s
.49543 .49047 m .49477 .49093 L .49509 .4915 L p .489 .214 .422 r
F P
0 g
s
.49477 .49093 m .49403 .49128 L .49431 .49187 L p .533 .229 .397 r
F P
0 g
s
.49431 .49187 m .49509 .4915 L .49477 .49093 L p .533 .229 .397 r
F P
0 g
s
.51047 .5 m .51053 .49919 L .50989 .49914 L p .927 .778 .675 r
F P
0 g
s
.50989 .49914 m .50982 .5 L .51047 .5 L p .927 .778 .675 r
F P
0 g
s
.51053 .50081 m .51047 .5 L .50982 .5 L p .927 .736 .625 r
F P
0 g
s
.49403 .50872 m .49477 .50907 L .49509 .5085 L p .533 .642 .903 r
F P
0 g
s
.49477 .50907 m .49543 .50953 L .4958 .50899 L p .489 .585 .877 r
F P
0 g
s
.4958 .50899 m .49509 .5085 L .49477 .50907 L p .489 .585 .877 r
F P
0 g
s
.49509 .4915 m .4958 .49101 L .49543 .49047 L p .489 .214 .422 r
F P
0 g
s
.49605 .48988 m .49543 .49047 L .4958 .49101 L p .445 .202 .45 r
F P
0 g
s
.51053 .49919 m .51074 .49836 L .51009 .49826 L p .92 .814 .725 r
F P
0 g
s
.51009 .49826 m .50989 .49914 L .51053 .49919 L p .92 .814 .725 r
F P
0 g
s
.49403 .49128 m .49321 .49152 L .49345 .49213 L p .578 .248 .374 r
F P
0 g
s
.49345 .49213 m .49431 .49187 L .49403 .49128 L p .578 .248 .374 r
F P
0 g
s
.50982 .5 m .50989 .50086 L .51053 .50081 L p .927 .736 .625 r
F P
0 g
s
.51074 .50164 m .51053 .50081 L .50989 .50086 L p .92 .689 .571 r
F P
0 g
s
.49509 .5085 m .49431 .50813 L .49403 .50872 L p .533 .642 .903 r
F P
0 g
s
.49321 .50848 m .49403 .50872 L .49431 .50813 L p .578 .696 .922 r
F P
0 g
s
.49543 .50953 m .49605 .51012 L .49646 .50961 L p .445 .525 .846 r
F P
0 g
s
.49646 .50961 m .4958 .50899 L .49543 .50953 L p .445 .525 .846 r
F P
0 g
s
.4958 .49101 m .49646 .49039 L .49605 .48988 L p .445 .202 .45 r
F P
0 g
s
.49659 .48915 m .49605 .48988 L .49646 .49039 L p .401 .194 .481 r
F P
0 g
s
.51074 .49836 m .5111 .49753 L .51045 .49737 L p .906 .845 .773 r
F P
0 g
s
.51045 .49737 m .51009 .49826 L .51074 .49836 L p .906 .845 .773 r
F P
0 g
s
.49321 .49152 m .49231 .49162 L .4925 .49227 L p .625 .272 .352 r
F P
0 g
s
.4925 .49227 m .49345 .49213 L .49321 .49152 L p .625 .272 .352 r
F P
0 g
s
.50989 .50086 m .51009 .50174 L .51074 .50164 L p .92 .689 .571 r
F P
0 g
s
.5111 .50247 m .51074 .50164 L .51009 .50174 L p .906 .634 .514 r
F P
0 g
s
.49431 .50813 m .49345 .50787 L .49321 .50848 L p .578 .696 .922 r
F P
0 g
s
.49231 .50838 m .49321 .50848 L .49345 .50787 L p .625 .748 .936 r
F P
0 g
s
.49605 .51012 m .49659 .51085 L .49705 .51036 L p .401 .46 .806 r
F P
0 g
s
.49705 .51036 m .49646 .50961 L .49605 .51012 L p .401 .46 .806 r
F P
0 g
s
.49646 .49039 m .49705 .48964 L .49659 .48915 L p .401 .194 .481 r
F P
0 g
s
.49704 .48827 m .49659 .48915 L .49705 .48964 L p .355 .19 .515 r
F P
0 g
s
.5111 .49753 m .51164 .4967 L .51097 .49649 L p .884 .871 .82 r
F P
0 g
s
.51097 .49649 m .51045 .49737 L .5111 .49753 L p .884 .871 .82 r
F P
0 g
s
.49231 .49162 m .49132 .49157 L .49148 .49225 L p .672 .3 .332 r
F P
0 g
s
.49148 .49225 m .4925 .49227 L .49231 .49162 L p .672 .3 .332 r
F P
0 g
s
.49345 .50787 m .4925 .50773 L .49231 .50838 L p .625 .748 .936 r
F P
0 g
s
.49132 .50843 m .49231 .50838 L .4925 .50773 L p .672 .798 .942 r
F P
0 g
s
.51009 .50174 m .51045 .50263 L .5111 .50247 L p .906 .634 .514 r
F P
0 g
s
.51164 .5033 m .5111 .50247 L .51045 .50263 L p .884 .572 .454 r
F P
0 g
s
.49659 .51085 m .49704 .51173 L .49755 .51126 L p .355 .39 .759 r
F P
0 g
s
.49755 .51126 m .49705 .51036 L .49659 .51085 L p .355 .39 .759 r
F P
0 g
s
.49705 .48964 m .49755 .48874 L .49704 .48827 L p .355 .19 .515 r
F P
0 g
s
.49738 .48723 m .49704 .48827 L .49755 .48874 L p .31 .19 .55 r
F P
0 g
s
.51164 .4967 m .51237 .49589 L .51168 .49563 L p .852 .889 .864 r
F P
0 g
s
.51168 .49563 m .51097 .49649 L .51164 .4967 L p .852 .889 .864 r
F P
0 g
s
.49132 .49157 m .49025 .49134 L .49037 .49207 L p .719 .332 .314 r
F P
0 g
s
.49037 .49207 m .49148 .49225 L .49132 .49157 L p .719 .332 .314 r
F P
0 g
s
.4925 .50773 m .49148 .50775 L .49132 .50843 L p .672 .798 .942 r
F P
0 g
s
.49025 .50866 m .49132 .50843 L .49148 .50775 L p .719 .843 .94 r
F P
0 g
s
.51045 .50263 m .51097 .50351 L .51164 .5033 L p .884 .572 .454 r
F P
0 g
s
.51237 .50411 m .51164 .5033 L .51097 .50351 L p .852 .503 .39 r
F P
0 g
s
.49704 .51173 m .49738 .51277 L .49794 .5123 L p .309 .315 .704 r
F P
0 g
s
.49794 .5123 m .49755 .51126 L .49704 .51173 L p .309 .315 .704 r
F P
0 g
s
.71325 .88222 m .701 .88868 L .69995 .88866 L p .001 0 0 r
F P
0 g
s
.701 .88868 m .71325 .88222 L .71383 .88207 L p 0 0 0 r
F P
0 g
s
.73481 .86975 m .72397 .87622 L .72439 .87579 L p 0 0 0 r
F P
0 g
s
.72439 .87579 m .7361 .86841 L .73481 .86975 L p 0 0 0 r
F P
0 g
s
.72439 .12421 m .7361 .13159 L .73661 .13251 L p 0 .371 .819 r
F P
0 g
s
.7361 .13159 m .72439 .12421 L .72397 .12378 L p 0 .35 .798 r
F P
0 g
s
.70281 .11178 m .71383 .11793 L .71325 .11778 L p 0 .452 .844 r
F P
0 g
s
.71325 .11778 m .701 .11132 L .70281 .11178 L p 0 .452 .844 r
F P
0 g
s
.06236 .49357 m .06289 .47974 L .06344 .47884 L p .929 .798 .331 r
F P
0 g
s
.06289 .47974 m .06236 .49357 L .0622 .49414 L p .909 .78 .295 r
F P
0 g
s
.06238 .51847 m .0622 .50586 L .06236 .50643 L p .909 .705 .204 r
F P
0 g
s
.06236 .50643 m .06289 .52026 L .06238 .51847 L p .909 .705 .204 r
F P
0 g
s
.49471 .47594 m .49276 .47258 L .49198 .47215 L p 0 .048 .614 r
F P
0 g
s
.48904 .46787 m .49198 .47215 L .49276 .47258 L p 0 .068 .626 r
F P
0 g
s
.52813 .49302 m .53331 .49343 L .53238 .49287 L p .186 .691 .905 r
F P
0 g
s
.53238 .49287 m .52737 .49256 L .52813 .49302 L p .186 .691 .905 r
F P
0 g
s
.47989 .47913 m .47766 .47444 L .47763 .47552 L p .846 .463 0 r
F P
0 g
s
.47763 .47552 m .47987 .48002 L .47989 .47913 L p .846 .463 0 r
F P
0 g
s
.48181 .51662 m .47987 .51998 L .47989 .52087 L p .846 .942 .578 r
F P
0 g
s
.47766 .52556 m .47989 .52087 L .47987 .51998 L p .846 .919 .524 r
F P
0 g
s
.52349 .50745 m .52737 .50744 L .52813 .50698 L p .248 0 0 r
F P
0 g
s
.53331 .50657 m .52813 .50698 L .52737 .50744 L p .186 0 0 r
F P
0 g
s
.49198 .52785 m .48904 .53213 L .48998 .53161 L p 0 0 0 r
F P
0 g
s
.48998 .53161 m .49276 .52742 L .49198 .52785 L p 0 0 0 r
F P
0 g
s
.49755 .48874 m .49794 .4877 L .49738 .48723 L p .31 .19 .55 r
F P
0 g
s
.49757 .48601 m .49738 .48723 L .49794 .4877 L p .263 .193 .587 r
F P
0 g
s
.51237 .49589 m .51333 .49511 L .51261 .4948 L p .812 .9 .904 r
F P
0 g
s
.51261 .4948 m .51168 .49563 L .51237 .49589 L p .812 .9 .904 r
F P
0 g
s
.49025 .49134 m .4891 .4909 L .48919 .49168 L p .766 .367 .297 r
F P
0 g
s
.48919 .49168 m .49037 .49207 L .49025 .49134 L p .766 .367 .297 r
F P
0 g
s
.49148 .50775 m .49037 .50793 L .49025 .50866 L p .719 .843 .94 r
F P
0 g
s
.4891 .5091 m .49025 .50866 L .49037 .50793 L p .766 .884 .93 r
F P
0 g
s
.51097 .50351 m .51168 .50437 L .51237 .50411 L p .852 .503 .39 r
F P
0 g
s
.51333 .50489 m .51237 .50411 L .51168 .50437 L p .812 .426 .323 r
F P
0 g
s
.49738 .51277 m .49757 .51399 L .4982 .51352 L p .263 .236 .64 r
F P
0 g
s
.4982 .51352 m .49794 .5123 L .49738 .51277 L p .263 .236 .64 r
F P
0 g
s
.06883 .4491 m .06344 .47884 L .06289 .47974 L p .883 .824 .35 r
F P
0 g
s
.06754 .54882 m .06289 .52026 L .06344 .52116 L p .883 .619 .099 r
F P
0 g
s
.06344 .52116 m .06883 .5509 L .06754 .54882 L p .883 .619 .099 r
F P
0 g
s
.75851 .85011 m .7361 .86841 L .73661 .86749 L p 0 0 0 r
F P
0 g
s
.73661 .86749 m .75967 .84795 L .75851 .85011 L p 0 0 0 r
F P
0 g
s
.6715 .89885 m .69995 .88866 L .701 .88868 L p .004 0 0 r
F P
0 g
s
.75967 .15205 m .73661 .13251 L .7361 .13159 L p 0 .241 .732 r
F P
0 g
s
.67395 .10107 m .701 .11132 L .69995 .11134 L p .004 .52 .858 r
F P
0 g
s
.69995 .11134 m .6715 .10115 L .67395 .10107 L p .004 .52 .858 r
F P
0 g
s
.49794 .4877 m .4982 .48648 L .49757 .48601 L p .263 .193 .587 r
F P
0 g
s
.49759 .48459 m .49757 .48601 L .4982 .48648 L p .215 .198 .623 r
F P
0 g
s
.51333 .49511 m .51455 .49438 L .51378 .49402 L p .762 .902 .939 r
F P
0 g
s
.51378 .49402 m .51261 .4948 L .51333 .49511 L p .762 .902 .939 r
F P
0 g
s
.4891 .4909 m .48786 .4902 L .48793 .49106 L p .81 .404 .28 r
F P
0 g
s
.48793 .49106 m .48919 .49168 L .4891 .4909 L p .81 .404 .28 r
F P
0 g
s
.49037 .50793 m .48919 .50832 L .4891 .5091 L p .766 .884 .93 r
F P
0 g
s
.48786 .5098 m .4891 .5091 L .48919 .50832 L p .81 .919 .911 r
F P
0 g
s
.51168 .50437 m .51261 .5052 L .51333 .50489 L p .812 .426 .323 r
F P
0 g
s
.51455 .50562 m .51333 .50489 L .51261 .5052 L p .762 .342 .252 r
F P
0 g
s
.49757 .51399 m .49759 .51541 L .49829 .51493 L p .215 .153 .568 r
F P
0 g
s
.49829 .51493 m .4982 .51352 L .49757 .51399 L p .215 .153 .568 r
F P
0 g
s
.53331 .49343 m .54012 .49425 L .53898 .49354 L p .142 .658 .891 r
F P
0 g
s
.53898 .49354 m .53238 .49287 L .53331 .49343 L p .142 .658 .891 r
F P
0 g
s
.49276 .47258 m .48998 .46839 L .48904 .46787 L p 0 .068 .626 r
F P
0 g
s
.48492 .46238 m .48904 .46787 L .48998 .46839 L p 0 .082 .633 r
F P
0 g
s
.47766 .47444 m .47496 .46813 L .47492 .46947 L p .845 .479 0 r
F P
0 g
s
.47492 .46947 m .47763 .47552 L .47766 .47444 L p .845 .479 0 r
F P
0 g
s
.47987 .51998 m .47763 .52448 L .47766 .52556 L p .846 .919 .524 r
F P
0 g
s
.47496 .53187 m .47766 .52556 L .47763 .52448 L p .845 .901 .486 r
F P
0 g
s
.52737 .50744 m .53238 .50713 L .53331 .50657 L p .186 0 0 r
F P
0 g
s
.54012 .50575 m .53331 .50657 L .53238 .50713 L p .142 0 0 r
F P
0 g
s
.48904 .53213 m .48492 .53762 L .4861 .53699 L p 0 0 0 r
F P
0 g
s
.4861 .53699 m .48998 .53161 L .48904 .53213 L p 0 0 0 r
F P
0 g
s
.4982 .48648 m .49829 .48507 L .49759 .48459 L p .215 .198 .623 r
F P
0 g
s
.49738 .48293 m .49759 .48459 L .49829 .48507 L p .167 .206 .658 r
F P
0 g
s
.51455 .49438 m .51609 .49373 L .51525 .4933 L p .702 .895 .967 r
F P
0 g
s
.51525 .4933 m .51378 .49402 L .51455 .49438 L p .702 .895 .967 r
F P
0 g
s
.48786 .4902 m .48653 .48919 L .48657 .49014 L p .849 .441 .264 r
F P
0 g
s
.48657 .49014 m .48793 .49106 L .48786 .4902 L p .849 .441 .264 r
F P
0 g
s
.48919 .50832 m .48793 .50894 L .48786 .5098 L p .81 .919 .911 r
F P
0 g
s
.48653 .51081 m .48786 .5098 L .48793 .50894 L p .849 .946 .882 r
F P
0 g
s
.51261 .5052 m .51378 .50598 L .51455 .50562 L p .762 .342 .252 r
F P
0 g
s
.51609 .50627 m .51455 .50562 L .51378 .50598 L p .702 .252 .179 r
F P
0 g
s
.49759 .51541 m .49738 .51707 L .49818 .51656 L p .167 .067 .488 r
F P
0 g
s
.49818 .51656 m .49829 .51493 L .49759 .51541 L p .167 .067 .488 r
F P
0 g
s
.4958 .49101 m .49509 .4915 L .49558 .49234 L p .583 .36 .543 r
F P
0 g
s
.49509 .4915 m .49431 .49187 L .49473 .49275 L p .614 .371 .526 r
F P
0 g
s
.49473 .49275 m .49558 .49234 L .49509 .4915 L p .614 .371 .526 r
F P
0 g
s
.50982 .5 m .50989 .49914 L .50891 .49906 L p .859 .716 .703 r
F P
0 g
s
.50891 .49906 m .50885 .5 L .50982 .5 L p .859 .716 .703 r
F P
0 g
s
.50989 .50086 m .50982 .5 L .50885 .5 L p .859 .687 .667 r
F P
0 g
s
.49431 .50813 m .49509 .5085 L .49558 .50766 L p .614 .631 .845 r
F P
0 g
s
.49509 .5085 m .4958 .50899 L .49636 .50819 L p .583 .592 .827 r
F P
0 g
s
.49636 .50819 m .49558 .50766 L .49509 .5085 L p .583 .592 .827 r
F P
0 g
s
.49558 .49234 m .49636 .49181 L .4958 .49101 L p .583 .36 .543 r
F P
0 g
s
.49646 .49039 m .4958 .49101 L .49636 .49181 L p .552 .352 .563 r
F P
0 g
s
.50989 .49914 m .51009 .49826 L .50912 .4981 L p .855 .742 .738 r
F P
0 g
s
.50912 .4981 m .50891 .49906 L .50989 .49914 L p .855 .742 .738 r
F P
0 g
s
.49431 .49187 m .49345 .49213 L .49379 .49306 L p .645 .384 .509 r
F P
0 g
s
.49379 .49306 m .49473 .49275 L .49431 .49187 L p .645 .384 .509 r
F P
0 g
s
.50885 .5 m .50891 .50094 L .50989 .50086 L p .859 .687 .667 r
F P
0 g
s
.51009 .50174 m .50989 .50086 L .50891 .50094 L p .855 .654 .63 r
F P
0 g
s
.49558 .50766 m .49473 .50725 L .49431 .50813 L p .614 .631 .845 r
F P
0 g
s
.49345 .50787 m .49431 .50813 L .49473 .50725 L p .645 .67 .859 r
F P
0 g
s
.4958 .50899 m .49646 .50961 L .49709 .50885 L p .552 .549 .805 r
F P
0 g
s
.49709 .50885 m .49636 .50819 L .4958 .50899 L p .552 .549 .805 r
F P
0 g
s
.49636 .49181 m .49709 .49115 L .49646 .49039 L p .552 .352 .563 r
F P
0 g
s
.49705 .48964 m .49646 .49039 L .49709 .49115 L p .521 .347 .585 r
F P
0 g
s
.51009 .49826 m .51045 .49737 L .50947 .49713 L p .846 .765 .773 r
F P
0 g
s
.50947 .49713 m .50912 .4981 L .51009 .49826 L p .846 .765 .773 r
F P
0 g
s
.49345 .49213 m .4925 .49227 L .49278 .49323 L p .679 .401 .494 r
F P
0 g
s
.49278 .49323 m .49379 .49306 L .49345 .49213 L p .679 .401 .494 r
F P
0 g
s
.50891 .50094 m .50912 .5019 L .51009 .50174 L p .855 .654 .63 r
F P
0 g
s
.51045 .50263 m .51009 .50174 L .50912 .5019 L p .846 .616 .591 r
F P
0 g
s
.49473 .50725 m .49379 .50694 L .49345 .50787 L p .645 .67 .859 r
F P
0 g
s
.4925 .50773 m .49345 .50787 L .49379 .50694 L p .679 .707 .869 r
F P
0 g
s
.49646 .50961 m .49705 .51036 L .49775 .50964 L p .521 .504 .778 r
F P
0 g
s
.49775 .50964 m .49709 .50885 L .49646 .50961 L p .521 .504 .778 r
F P
0 g
s
.49709 .49115 m .49775 .49036 L .49705 .48964 L p .521 .347 .585 r
F P
0 g
s
.49755 .48874 m .49705 .48964 L .49775 .49036 L p .489 .344 .61 r
F P
0 g
s
.51045 .49737 m .51097 .49649 L .50999 .49618 L p .831 .785 .808 r
F P
0 g
s
.50999 .49618 m .50947 .49713 L .51045 .49737 L p .831 .785 .808 r
F P
0 g
s
.4925 .49227 m .49148 .49225 L .49169 .49326 L p .714 .421 .48 r
F P
0 g
s
.49169 .49326 m .49278 .49323 L .4925 .49227 L p .714 .421 .48 r
F P
0 g
s
.49379 .50694 m .49278 .50677 L .4925 .50773 L p .679 .707 .869 r
F P
0 g
s
.49148 .50775 m .4925 .50773 L .49278 .50677 L p .714 .744 .876 r
F P
0 g
s
.50912 .5019 m .50947 .50287 L .51045 .50263 L p .846 .616 .591 r
F P
0 g
s
.51097 .50351 m .51045 .50263 L .50947 .50287 L p .831 .573 .548 r
F P
0 g
s
.49705 .51036 m .49755 .51126 L .49832 .51056 L p .489 .455 .746 r
F P
0 g
s
.49832 .51056 m .49775 .50964 L .49705 .51036 L p .489 .455 .746 r
F P
0 g
s
.49829 .48507 m .49818 .48344 L .49738 .48293 L p .167 .206 .658 r
F P
0 g
s
.49689 .48099 m .49738 .48293 L .49818 .48344 L p .118 .214 .689 r
F P
0 g
s
.51609 .49373 m .51802 .49319 L .51708 .49268 L p .634 .878 .987 r
F P
0 g
s
.51708 .49268 m .51525 .4933 L .51609 .49373 L p .634 .878 .987 r
F P
0 g
s
.48653 .48919 m .48509 .4878 L .48512 .48887 L p .883 .478 .247 r
F P
0 g
s
.48512 .48887 m .48657 .49014 L .48653 .48919 L p .883 .478 .247 r
F P
0 g
s
.48793 .50894 m .48657 .50986 L .48653 .51081 L p .849 .946 .882 r
F P
0 g
s
.48509 .5122 m .48653 .51081 L .48657 .50986 L p .883 .964 .843 r
F P
0 g
s
.49738 .51707 m .49689 .51901 L .4978 .51845 L p .118 0 .401 r
F P
0 g
s
.4978 .51845 m .49818 .51656 L .49738 .51707 L p .118 0 .401 r
F P
0 g
s
.51378 .50598 m .51525 .5067 L .51609 .50627 L p .702 .252 .179 r
F P
0 g
s
.51802 .50681 m .51609 .50627 L .51525 .5067 L p .634 .157 .104 r
F P
0 g
s
.48998 .46839 m .4861 .46301 L .48492 .46238 L p 0 .082 .633 r
F P
0 g
s
.47925 .4551 m .48492 .46238 L .4861 .46301 L p 0 .089 .636 r
F P
0 g
s
.54012 .49425 m .54926 .49552 L .54784 .49463 L p .121 .642 .884 r
F P
0 g
s
.54784 .49463 m .53898 .49354 L .54012 .49425 L p .121 .642 .884 r
F P
0 g
s
.47496 .46813 m .47149 .45958 L .47143 .46125 L p .844 .487 0 r
F P
0 g
s
.47143 .46125 m .47492 .46947 L .47496 .46813 L p .844 .487 0 r
F P
0 g
s
.47763 .52448 m .47492 .53053 L .47496 .53187 L p .845 .901 .486 r
F P
0 g
s
.47149 .54042 m .47496 .53187 L .47492 .53053 L p .844 .891 .466 r
F P
0 g
s
.53238 .50713 m .53898 .50646 L .54012 .50575 L p .142 0 0 r
F P
0 g
s
.54926 .50448 m .54012 .50575 L .53898 .50646 L p .121 0 0 r
F P
0 g
s
.48492 .53762 m .47925 .5449 L .48073 .54412 L p 0 0 0 r
F P
0 g
s
.48073 .54412 m .4861 .53699 L .48492 .53762 L p 0 0 0 r
F P
0 g
s
.49775 .49036 m .49832 .48944 L .49755 .48874 L p .489 .344 .61 r
F P
0 g
s
.49794 .4877 m .49755 .48874 L .49832 .48944 L p .456 .343 .636 r
F P
0 g
s
.51097 .49649 m .51168 .49563 L .51068 .49524 L p .811 .801 .842 r
F P
0 g
s
.51068 .49524 m .50999 .49618 L .51097 .49649 L p .811 .801 .842 r
F P
0 g
s
.49148 .49225 m .49037 .49207 L .49054 .49313 L p .749 .444 .467 r
F P
0 g
s
.49054 .49313 m .49169 .49326 L .49148 .49225 L p .749 .444 .467 r
F P
0 g
s
.49278 .50677 m .49169 .50674 L .49148 .50775 L p .714 .744 .876 r
F P
0 g
s
.49037 .50793 m .49148 .50775 L .49169 .50674 L p .749 .779 .877 r
F P
0 g
s
.50947 .50287 m .50999 .50382 L .51097 .50351 L p .831 .573 .548 r
F P
0 g
s
.51168 .50437 m .51097 .50351 L .50999 .50382 L p .811 .524 .503 r
F P
0 g
s
.49755 .51126 m .49794 .5123 L .49878 .51163 L p .456 .402 .708 r
F P
0 g
s
.49878 .51163 m .49832 .51056 L .49755 .51126 L p .456 .402 .708 r
F P
0 g
s
.71383 .88207 m .70281 .88822 L .701 .88868 L p 0 0 0 r
F P
0 g
s
.70281 .88822 m .71383 .88207 L .71462 .88178 L p 0 0 0 r
F P
0 g
s
.73278 .87144 m .72332 .87675 L .72397 .87622 L p 0 0 0 r
F P
0 g
s
.72397 .87622 m .73481 .86975 L .73278 .87144 L p 0 0 0 r
F P
0 g
s
.06193 .51587 m .06206 .50503 L .0622 .50586 L p .889 .692 .176 r
F P
0 g
s
.0622 .50586 m .06238 .51847 L .06193 .51587 L p .889 .692 .176 r
F P
0 g
s
.0622 .49414 m .06238 .48153 L .06289 .47974 L p .909 .78 .295 r
F P
0 g
s
.06238 .48153 m .0622 .49414 L .06206 .49497 L p .889 .759 .258 r
F P
0 g
s
.72397 .12378 m .73481 .13025 L .7361 .13159 L p 0 .35 .798 r
F P
0 g
s
.73481 .13025 m .72397 .12378 L .72332 .12325 L p 0 .332 .778 r
F P
0 g
s
.70529 .11269 m .71462 .11822 L .71383 .11793 L p 0 .424 .819 r
F P
0 g
s
.71383 .11793 m .70281 .11178 L .70529 .11269 L p 0 .424 .819 r
F P
0 g
s
.49832 .48944 m .49878 .48837 L .49794 .4877 L p .456 .343 .636 r
F P
0 g
s
.4982 .48648 m .49794 .4877 L .49878 .48837 L p .422 .345 .664 r
F P
0 g
s
.51168 .49563 m .51261 .4948 L .51156 .49434 L p .785 .813 .874 r
F P
0 g
s
.51156 .49434 m .51068 .49524 L .51168 .49563 L p .785 .813 .874 r
F P
0 g
s
.49037 .49207 m .48919 .49168 L .48931 .49282 L p .786 .47 .454 r
F P
0 g
s
.48931 .49282 m .49054 .49313 L .49037 .49207 L p .786 .47 .454 r
F P
0 g
s
.49169 .50674 m .49054 .50687 L .49037 .50793 L p .749 .779 .877 r
F P
0 g
s
.48919 .50832 m .49037 .50793 L .49054 .50687 L p .786 .813 .874 r
F P
0 g
s
.50999 .50382 m .51068 .50476 L .51168 .50437 L p .811 .524 .503 r
F P
0 g
s
.51261 .5052 m .51168 .50437 L .51068 .50476 L p .785 .47 .454 r
F P
0 g
s
.49794 .5123 m .4982 .51352 L .49913 .51284 L p .422 .344 .664 r
F P
0 g
s
.49913 .51284 m .49878 .51163 L .49794 .5123 L p .422 .344 .664 r
F P
0 g
s
.49818 .48344 m .4978 .48155 L .49689 .48099 L p .118 .214 .689 r
F P
0 g
s
.49603 .47869 m .49689 .48099 L .4978 .48155 L p .071 .222 .715 r
F P
0 g
s
.51802 .49319 m .52044 .49278 L .51935 .49217 L p .56 .852 .997 r
F P
0 g
s
.51935 .49217 m .51708 .49268 L .51802 .49319 L p .56 .852 .997 r
F P
0 g
s
.48509 .4878 m .48353 .48591 L .48354 .48715 L p .909 .512 .231 r
F P
0 g
s
.48354 .48715 m .48512 .48887 L .48509 .4878 L p .909 .512 .231 r
F P
0 g
s
.48657 .50986 m .48512 .51113 L .48509 .5122 L p .883 .964 .843 r
F P
0 g
s
.48353 .51409 m .48509 .5122 L .48512 .51113 L p .909 .973 .796 r
F P
0 g
s
.51525 .5067 m .51708 .50732 L .51802 .50681 L p .634 .157 .104 r
F P
0 g
s
.52044 .50722 m .51802 .50681 L .51708 .50732 L p .56 .062 .029 r
F P
0 g
s
.49689 .51901 m .49603 .52131 L .4971 .52067 L p .071 0 .311 r
F P
0 g
s
.4971 .52067 m .4978 .51845 L .49689 .51901 L p .071 0 .311 r
F P
0 g
s
.49636 .49181 m .49558 .49234 L .49623 .49347 L p .631 .442 .609 r
F P
0 g
s
.49558 .49234 m .49473 .49275 L .49527 .49394 L p .655 .451 .595 r
F P
0 g
s
.49527 .49394 m .49623 .49347 L .49558 .49234 L p .655 .451 .595 r
F P
0 g
s
.50885 .5 m .50891 .49906 L .50762 .49894 L p .809 .672 .712 r
F P
0 g
s
.50762 .49894 m .50754 .5 L .50885 .5 L p .809 .672 .712 r
F P
0 g
s
.50891 .50094 m .50885 .5 L .50754 .5 L p .809 .65 .685 r
F P
0 g
s
.49473 .50725 m .49558 .50766 L .49623 .50653 L p .655 .618 .801 r
F P
0 g
s
.49558 .50766 m .49636 .50819 L .49711 .50713 L p .631 .588 .787 r
F P
0 g
s
.49711 .50713 m .49623 .50653 L .49558 .50766 L p .631 .588 .787 r
F P
0 g
s
.49623 .49347 m .49711 .49287 L .49636 .49181 L p .631 .442 .609 r
F P
0 g
s
.49709 .49115 m .49636 .49181 L .49711 .49287 L p .608 .437 .624 r
F P
0 g
s
.50891 .49906 m .50912 .4981 L .50783 .49786 L p .806 .691 .739 r
F P
0 g
s
.50783 .49786 m .50762 .49894 L .50891 .49906 L p .806 .691 .739 r
F P
0 g
s
.49473 .49275 m .49379 .49306 L .49423 .49428 L p .679 .461 .583 r
F P
0 g
s
.49423 .49428 m .49527 .49394 L .49473 .49275 L p .679 .461 .583 r
F P
0 g
s
.50754 .5 m .50762 .50106 L .50891 .50094 L p .809 .65 .685 r
F P
0 g
s
.50912 .5019 m .50891 .50094 L .50762 .50106 L p .806 .624 .657 r
F P
0 g
s
.49623 .50653 m .49527 .50606 L .49473 .50725 L p .655 .618 .801 r
F P
0 g
s
.49379 .50694 m .49473 .50725 L .49527 .50606 L p .679 .648 .812 r
F P
0 g
s
.49636 .50819 m .49709 .50885 L .49793 .50785 L p .608 .556 .771 r
F P
0 g
s
.49793 .50785 m .49711 .50713 L .49636 .50819 L p .608 .556 .771 r
F P
0 g
s
.49878 .48837 m .49913 .48716 L .4982 .48648 L p .422 .345 .664 r
F P
0 g
s
.49829 .48507 m .4982 .48648 L .49913 .48716 L p .386 .348 .693 r
F P
0 g
s
.51261 .4948 m .51378 .49402 L .51266 .49347 L p .752 .82 .905 r
F P
0 g
s
.51266 .49347 m .51156 .49434 L .51261 .4948 L p .752 .82 .905 r
F P
0 g
s
.48919 .49168 m .48793 .49106 L .48802 .4923 L p .822 .498 .442 r
F P
0 g
s
.48802 .4923 m .48931 .49282 L .48919 .49168 L p .822 .498 .442 r
F P
0 g
s
.49054 .50687 m .48931 .50718 L .48919 .50832 L p .786 .813 .874 r
F P
0 g
s
.48793 .50894 m .48919 .50832 L .48931 .50718 L p .822 .844 .865 r
F P
0 g
s
.51068 .50476 m .51156 .50566 L .51261 .5052 L p .785 .47 .454 r
F P
0 g
s
.51378 .50598 m .51261 .5052 L .51156 .50566 L p .752 .409 .401 r
F P
0 g
s
.4982 .51352 m .49829 .51493 L .49932 .51423 L p .386 .282 .613 r
F P
0 g
s
.49932 .51423 m .49913 .51284 L .4982 .51352 L p .386 .282 .613 r
F P
0 g
s
.49711 .49287 m .49793 .49215 L .49709 .49115 L p .608 .437 .624 r
F P
0 g
s
.49775 .49036 m .49709 .49115 L .49793 .49215 L p .585 .433 .642 r
F P
0 g
s
.50912 .4981 m .50947 .49713 L .5082 .49679 L p .799 .709 .766 r
F P
0 g
s
.5082 .49679 m .50783 .49786 L .50912 .4981 L p .799 .709 .766 r
F P
0 g
s
.49379 .49306 m .49278 .49323 L .49312 .4945 L p .705 .474 .572 r
F P
0 g
s
.49312 .4945 m .49423 .49428 L .49379 .49306 L p .705 .474 .572 r
F P
0 g
s
.50762 .50106 m .50783 .50214 L .50912 .5019 L p .806 .624 .657 r
F P
0 g
s
.50947 .50287 m .50912 .5019 L .50783 .50214 L p .799 .596 .627 r
F P
0 g
s
.49527 .50606 m .49423 .50572 L .49379 .50694 L p .679 .648 .812 r
F P
0 g
s
.49278 .50677 m .49379 .50694 L .49423 .50572 L p .705 .677 .82 r
F P
0 g
s
.49709 .50885 m .49775 .50964 L .49868 .50871 L p .585 .522 .75 r
F P
0 g
s
.49868 .50871 m .49793 .50785 L .49709 .50885 L p .585 .522 .75 r
F P
0 g
s
.49793 .49215 m .49868 .49129 L .49775 .49036 L p .585 .433 .642 r
F P
0 g
s
.49832 .48944 m .49775 .49036 L .49868 .49129 L p .561 .431 .661 r
F P
0 g
s
.50947 .49713 m .50999 .49618 L .50872 .49574 L p .788 .725 .793 r
F P
0 g
s
.50872 .49574 m .5082 .49679 L .50947 .49713 L p .788 .725 .793 r
F P
0 g
s
.49278 .49323 m .49169 .49326 L .49195 .49458 L p .732 .491 .562 r
F P
0 g
s
.49195 .49458 m .49312 .4945 L .49278 .49323 L p .732 .491 .562 r
F P
0 g
s
.49423 .50572 m .49312 .5055 L .49278 .50677 L p .705 .677 .82 r
F P
0 g
s
.49169 .50674 m .49278 .50677 L .49312 .5055 L p .732 .705 .825 r
F P
0 g
s
.50783 .50214 m .5082 .50321 L .50947 .50287 L p .799 .596 .627 r
F P
0 g
s
.50999 .50382 m .50947 .50287 L .5082 .50321 L p .788 .563 .595 r
F P
0 g
s
.49775 .50964 m .49832 .51056 L .49933 .50968 L p .561 .484 .726 r
F P
0 g
s
.49933 .50968 m .49868 .50871 L .49775 .50964 L p .561 .484 .726 r
F P
0 g
s
.54926 .49552 m .56182 .49721 L .56003 .49607 L p .126 .646 .886 r
F P
0 g
s
.56003 .49607 m .54784 .49463 L .54926 .49552 L p .126 .646 .886 r
F P
0 g
s
.4861 .46301 m .48073 .45588 L .47925 .4551 L p 0 .089 .636 r
F P
0 g
s
.4715 .44507 m .47925 .4551 L .48073 .45588 L p 0 .088 .636 r
F P
0 g
s
.47149 .45958 m .46668 .44785 L .46658 .44998 L p .844 .485 0 r
F P
0 g
s
.46658 .44998 m .47143 .46125 L .47149 .45958 L p .844 .485 0 r
F P
0 g
s
.47492 .53053 m .47143 .53875 L .47149 .54042 L p .844 .891 .466 r
F P
0 g
s
.46668 .55215 m .47149 .54042 L .47143 .53875 L p .844 .894 .471 r
F P
0 g
s
.53898 .50646 m .54784 .50537 L .54926 .50448 L p .121 0 0 r
F P
0 g
s
.56182 .50279 m .54926 .50448 L .54784 .50537 L p .126 0 0 r
F P
0 g
s
.47925 .5449 m .4715 .55493 L .47339 .55396 L p 0 0 0 r
F P
0 g
s
.47339 .55396 m .48073 .54412 L .47925 .5449 L p 0 0 0 r
F P
0 g
s
.4978 .48155 m .4971 .47933 L .49603 .47869 L p .071 .222 .715 r
F P
0 g
s
.49471 .47594 m .49603 .47869 L .4971 .47933 L p .025 .23 .735 r
F P
0 g
s
.52044 .49278 m .52349 .49255 L .52221 .49182 L p .483 .82 .999 r
F P
0 g
s
.52221 .49182 m .51935 .49217 L .52044 .49278 L p .483 .82 .999 r
F P
0 g
s
.48353 .48591 m .48181 .48338 L .48181 .48485 L p .927 .541 .214 r
F P
0 g
s
.48181 .48485 m .48354 .48715 L .48353 .48591 L p .927 .541 .214 r
F P
0 g
s
.48512 .51113 m .48354 .51285 L .48353 .51409 L p .909 .973 .796 r
F P
0 g
s
.48181 .51662 m .48353 .51409 L .48354 .51285 L p .927 .973 .743 r
F P
0 g
s
.49603 .52131 m .49471 .52406 L .49598 .52333 L p .025 0 .223 r
F P
0 g
s
.49598 .52333 m .4971 .52067 L .49603 .52131 L p .025 0 .223 r
F P
0 g
s
.51708 .50732 m .51935 .50783 L .52044 .50722 L p .56 .062 .029 r
F P
0 g
s
.52349 .50745 m .52044 .50722 L .51935 .50783 L p .483 0 0 r
F P
0 g
s
.49868 .49129 m .49933 .49032 L .49832 .48944 L p .561 .431 .661 r
F P
0 g
s
.49878 .48837 m .49832 .48944 L .49933 .49032 L p .536 .432 .683 r
F P
0 g
s
.50999 .49618 m .51068 .49524 L .50939 .49472 L p .773 .738 .82 r
F P
0 g
s
.50939 .49472 m .50872 .49574 L .50999 .49618 L p .773 .738 .82 r
F P
0 g
s
.49169 .49326 m .49054 .49313 L .49073 .49451 L p .761 .509 .553 r
F P
0 g
s
.49073 .49451 m .49195 .49458 L .49169 .49326 L p .761 .509 .553 r
F P
0 g
s
.49312 .5055 m .49195 .50542 L .49169 .50674 L p .732 .705 .825 r
F P
0 g
s
.49054 .50687 m .49169 .50674 L .49195 .50542 L p .761 .733 .827 r
F P
0 g
s
.5082 .50321 m .50872 .50426 L .50999 .50382 L p .788 .563 .595 r
F P
0 g
s
.51068 .50476 m .50999 .50382 L .50872 .50426 L p .773 .525 .56 r
F P
0 g
s
.49832 .51056 m .49878 .51163 L .49988 .51077 L p .536 .443 .697 r
F P
0 g
s
.49988 .51077 m .49933 .50968 L .49832 .51056 L p .536 .443 .697 r
F P
0 g
s
.49913 .48716 m .49932 .48577 L .49829 .48507 L p .386 .348 .693 r
F P
0 g
s
.49818 .48344 m .49829 .48507 L .49932 .48577 L p .347 .351 .722 r
F P
0 g
s
.51378 .49402 m .51525 .4933 L .51402 .49267 L p .712 .822 .933 r
F P
0 g
s
.51402 .49267 m .51266 .49347 L .51378 .49402 L p .712 .822 .933 r
F P
0 g
s
.48793 .49106 m .48657 .49014 L .48664 .49152 L p .857 .527 .428 r
F P
0 g
s
.48664 .49152 m .48802 .4923 L .48793 .49106 L p .857 .527 .428 r
F P
0 g
s
.48931 .50718 m .48802 .5077 L .48793 .50894 L p .822 .844 .865 r
F P
0 g
s
.48657 .50986 m .48793 .50894 L .48802 .5077 L p .857 .872 .85 r
F P
0 g
s
.51156 .50566 m .51266 .50653 L .51378 .50598 L p .752 .409 .401 r
F P
0 g
s
.51525 .5067 m .51378 .50598 L .51266 .50653 L p .712 .341 .344 r
F P
0 g
s
.49829 .51493 m .49818 .51656 L .49934 .51581 L p .347 .215 .555 r
F P
0 g
s
.49934 .51581 m .49932 .51423 L .49829 .51493 L p .347 .215 .555 r
F P
0 g
s
.06156 .51256 m .06194 .50398 L .06206 .50503 L p .869 .681 .154 r
F P
0 g
s
.06206 .50503 m .06193 .51587 L .06156 .51256 L p .869 .681 .154 r
F P
0 g
s
.71462 .88178 m .70529 .88731 L .70281 .88822 L p 0 0 0 r
F P
0 g
s
.70529 .88731 m .71462 .88178 L .71559 .88136 L p 0 0 0 r
F P
0 g
s
.7301 .87342 m .72247 .87738 L .72332 .87675 L p 0 0 0 r
F P
0 g
s
.72332 .87675 m .73278 .87144 L .7301 .87342 L p 0 0 0 r
F P
0 g
s
.06206 .49497 m .06193 .48413 L .06238 .48153 L p .889 .759 .258 r
F P
0 g
s
.06193 .48413 m .06206 .49497 L .06194 .49602 L p .869 .737 .222 r
F P
0 g
s
.70834 .11402 m .71559 .11864 L .71462 .11822 L p 0 .395 .795 r
F P
0 g
s
.71462 .11822 m .70529 .11269 L .70834 .11402 L p 0 .395 .795 r
F P
0 g
s
.72332 .12325 m .73278 .12856 L .73481 .13025 L p 0 .332 .778 r
F P
0 g
s
.73278 .12856 m .72332 .12325 L .72247 .12262 L p 0 .319 .76 r
F P
0 g
s
.49711 .49287 m .49623 .49347 L .49706 .4949 L p .661 .497 .651 r
F P
0 g
s
.49623 .49347 m .49527 .49394 L .49594 .49545 L p .68 .503 .641 r
F P
0 g
s
.49594 .49545 m .49706 .4949 L .49623 .49347 L p .68 .503 .641 r
F P
0 g
s
.50754 .5 m .50762 .49894 L .50597 .49876 L p .771 .638 .715 r
F P
0 g
s
.50597 .49876 m .50588 .5 L .50754 .5 L p .771 .638 .715 r
F P
0 g
s
.50762 .50106 m .50754 .5 L .50588 .5 L p .771 .621 .693 r
F P
0 g
s
.49527 .50606 m .49623 .50653 L .49706 .5051 L p .68 .606 .767 r
F P
0 g
s
.49623 .50653 m .49711 .50713 L .49809 .5058 L p .661 .583 .756 r
F P
0 g
s
.49809 .5058 m .49706 .5051 L .49623 .50653 L p .661 .583 .756 r
F P
0 g
s
.49706 .4949 m .49809 .4942 L .49711 .49287 L p .661 .497 .651 r
F P
0 g
s
.49793 .49215 m .49711 .49287 L .49809 .4942 L p .643 .493 .664 r
F P
0 g
s
.50762 .49894 m .50783 .49786 L .50624 .49752 L p .768 .653 .736 r
F P
0 g
s
.50624 .49752 m .50597 .49876 L .50762 .49894 L p .768 .653 .736 r
F P
0 g
s
.49527 .49394 m .49423 .49428 L .49473 .49584 L p .699 .512 .632 r
F P
0 g
s
.49473 .49584 m .49594 .49545 L .49527 .49394 L p .699 .512 .632 r
F P
0 g
s
.50588 .5 m .50597 .50124 L .50762 .50106 L p .771 .621 .693 r
F P
0 g
s
.50783 .50214 m .50762 .50106 L .50597 .50124 L p .768 .601 .671 r
F P
0 g
s
.49706 .5051 m .49594 .50455 L .49527 .50606 L p .68 .606 .767 r
F P
0 g
s
.49423 .50572 m .49527 .50606 L .49594 .50455 L p .699 .63 .775 r
F P
0 g
s
.49711 .50713 m .49793 .50785 L .49903 .50664 L p .643 .558 .743 r
F P
0 g
s
.49903 .50664 m .49809 .5058 L .49711 .50713 L p .643 .558 .743 r
F P
0 g
s
.49933 .49032 m .49988 .48923 L .49878 .48837 L p .536 .432 .683 r
F P
0 g
s
.49913 .48716 m .49878 .48837 L .49988 .48923 L p .509 .433 .706 r
F P
0 g
s
.51068 .49524 m .51156 .49434 L .51022 .49373 L p .754 .748 .847 r
F P
0 g
s
.51022 .49373 m .50939 .49472 L .51068 .49524 L p .754 .748 .847 r
F P
0 g
s
.49054 .49313 m .48931 .49282 L .48946 .49429 L p .791 .53 .544 r
F P
0 g
s
.48946 .49429 m .49073 .49451 L .49054 .49313 L p .791 .53 .544 r
F P
0 g
s
.49195 .50542 m .49073 .50549 L .49054 .50687 L p .761 .733 .827 r
F P
0 g
s
.48931 .50718 m .49054 .50687 L .49073 .50549 L p .791 .761 .826 r
F P
0 g
s
.50872 .50426 m .50939 .50528 L .51068 .50476 L p .773 .525 .56 r
F P
0 g
s
.51156 .50566 m .51068 .50476 L .50939 .50528 L p .754 .483 .522 r
F P
0 g
s
.49878 .51163 m .49913 .51284 L .50032 .51199 L p .509 .399 .663 r
F P
0 g
s
.50032 .51199 m .49988 .51077 L .49878 .51163 L p .509 .399 .663 r
F P
0 g
s
.49809 .4942 m .49903 .49336 L .49793 .49215 L p .643 .493 .664 r
F P
0 g
s
.49868 .49129 m .49793 .49215 L .49903 .49336 L p .625 .491 .678 r
F P
0 g
s
.50783 .49786 m .5082 .49679 L .50665 .49632 L p .762 .667 .757 r
F P
0 g
s
.50665 .49632 m .50624 .49752 L .50783 .49786 L p .762 .667 .757 r
F P
0 g
s
.49423 .49428 m .49312 .4945 L .49349 .49607 L p .72 .524 .624 r
F P
0 g
s
.49349 .49607 m .49473 .49584 L .49423 .49428 L p .72 .524 .624 r
F P
0 g
s
.50597 .50124 m .50624 .50248 L .50783 .50214 L p .768 .601 .671 r
F P
0 g
s
.5082 .50321 m .50783 .50214 L .50624 .50248 L p .762 .577 .648 r
F P
0 g
s
.49594 .50455 m .49473 .50416 L .49423 .50572 L p .699 .63 .775 r
F P
0 g
s
.49312 .5055 m .49423 .50572 L .49473 .50416 L p .72 .653 .781 r
F P
0 g
s
.49793 .50785 m .49868 .50871 L .49986 .5076 L p .625 .53 .726 r
F P
0 g
s
.49986 .5076 m .49903 .50664 L .49793 .50785 L p .625 .53 .726 r
F P
0 g
s
.49903 .49336 m .49986 .4924 L .49868 .49129 L p .625 .491 .678 r
F P
0 g
s
.49933 .49032 m .49868 .49129 L .49986 .4924 L p .607 .491 .695 r
F P
0 g
s
.5082 .49679 m .50872 .49574 L .5072 .49517 L p .753 .679 .78 r
F P
0 g
s
.5072 .49517 m .50665 .49632 L .5082 .49679 L p .753 .679 .78 r
F P
0 g
s
.49312 .4945 m .49195 .49458 L .49222 .49618 L p .743 .538 .616 r
F P
0 g
s
.49222 .49618 m .49349 .49607 L .49312 .4945 L p .743 .538 .616 r
F P
0 g
s
.49473 .50416 m .49349 .50393 L .49312 .5055 L p .72 .653 .781 r
F P
0 g
s
.49195 .50542 m .49312 .5055 L .49349 .50393 L p .743 .676 .785 r
F P
0 g
s
.50624 .50248 m .50665 .50368 L .5082 .50321 L p .762 .577 .648 r
F P
0 g
s
.50872 .50426 m .5082 .50321 L .50665 .50368 L p .753 .55 .622 r
F P
0 g
s
.49868 .50871 m .49933 .50968 L .50058 .50865 L p .606 .5 .706 r
F P
0 g
s
.50058 .50865 m .49986 .5076 L .49868 .50871 L p .606 .5 .706 r
F P
0 g
s
.49932 .48577 m .49934 .48419 L .49818 .48344 L p .347 .351 .722 r
F P
0 g
s
.4978 .48155 m .49818 .48344 L .49934 .48419 L p .305 .355 .75 r
F P
0 g
s
.51525 .4933 m .51708 .49268 L .5157 .49193 L p .664 .818 .957 r
F P
0 g
s
.5157 .49193 m .51402 .49267 L .51525 .4933 L p .664 .818 .957 r
F P
0 g
s
.48657 .49014 m .48512 .48887 L .48516 .49044 L p .89 .557 .412 r
F P
0 g
s
.48516 .49044 m .48664 .49152 L .48657 .49014 L p .89 .557 .412 r
F P
0 g
s
.48802 .5077 m .48664 .50848 L .48657 .50986 L p .857 .872 .85 r
F P
0 g
s
.48512 .51113 m .48657 .50986 L .48664 .50848 L p .89 .896 .827 r
F P
0 g
s
.49818 .51656 m .4978 .51845 L .49914 .51763 L p .305 .143 .49 r
F P
0 g
s
.49914 .51763 m .49934 .51581 L .49818 .51656 L p .305 .143 .49 r
F P
0 g
s
.51266 .50653 m .51402 .50733 L .51525 .5067 L p .712 .341 .344 r
F P
0 g
s
.51708 .50732 m .51525 .5067 L .51402 .50733 L p .664 .267 .282 r
F P
0 g
s
.4971 .47933 m .49598 .47667 L .49471 .47594 L p .025 .23 .735 r
F P
0 g
s
.49276 .47258 m .49471 .47594 L .49598 .47667 L p 0 .236 .748 r
F P
0 g
s
.52349 .49255 m .52737 .49256 L .52584 .49167 L p .41 .784 .993 r
F P
0 g
s
.52584 .49167 m .52221 .49182 L .52349 .49255 L p .41 .784 .993 r
F P
0 g
s
.48354 .51285 m .48181 .51515 L .48181 .51662 L p .927 .973 .743 r
F P
0 g
s
.47987 .51998 m .48181 .51662 L .48181 .51515 L p .936 .965 .689 r
F P
0 g
s
.48181 .48338 m .47987 .48002 L .47987 .48178 L p .936 .564 .198 r
F P
0 g
s
.47987 .48178 m .48181 .48485 L .48181 .48338 L p .936 .564 .198 r
F P
0 g
s
.51935 .50783 m .52221 .50818 L .52349 .50745 L p .483 0 0 r
F P
0 g
s
.52737 .50744 m .52349 .50745 L .52221 .50818 L p .41 0 0 r
F P
0 g
s
.49471 .52406 m .49276 .52742 L .49429 .52654 L p 0 0 .14 r
F P
0 g
s
.49429 .52654 m .49598 .52333 L .49471 .52406 L p 0 0 .14 r
F P
0 g
s
.49988 .48923 m .50032 .48801 L .49913 .48716 L p .509 .433 .706 r
F P
0 g
s
.49932 .48577 m .49913 .48716 L .50032 .48801 L p .481 .436 .73 r
F P
0 g
s
.51156 .49434 m .51266 .49347 L .51124 .49277 L p .729 .756 .874 r
F P
0 g
s
.51124 .49277 m .51022 .49373 L .51156 .49434 L p .729 .756 .874 r
F P
0 g
s
.48931 .49282 m .48802 .4923 L .48812 .49389 L p .821 .554 .534 r
F P
0 g
s
.48812 .49389 m .48946 .49429 L .48931 .49282 L p .821 .554 .534 r
F P
0 g
s
.49073 .50549 m .48946 .50571 L .48931 .50718 L p .791 .761 .826 r
F P
0 g
s
.48802 .5077 m .48931 .50718 L .48946 .50571 L p .821 .788 .821 r
F P
0 g
s
.50939 .50528 m .51022 .50627 L .51156 .50566 L p .754 .483 .522 r
F P
0 g
s
.51266 .50653 m .51156 .50566 L .51022 .50627 L p .729 .435 .481 r
F P
0 g
s
.49913 .51284 m .49932 .51423 L .50065 .51335 L p .481 .349 .624 r
F P
0 g
s
.50065 .51335 m .50032 .51199 L .49913 .51284 L p .481 .349 .624 r
F P
0 g
s
.49809 .4942 m .49706 .4949 L .49812 .49675 L p .682 .537 .681 r
F P
0 g
s
.49706 .4949 m .49594 .49545 L .49668 .49739 L p .697 .542 .673 r
F P
0 g
s
.49668 .49739 m .49812 .49675 L .49706 .4949 L p .697 .542 .673 r
F P
0 g
s
.50588 .5 m .50597 .49876 L .50392 .49843 L p .74 .611 .715 r
F P
0 g
s
.50392 .49843 m .50375 .5 L .50588 .5 L p .74 .611 .715 r
F P
0 g
s
.50597 .50124 m .50588 .5 L .50375 .5 L p .74 .597 .698 r
F P
0 g
s
.49594 .50455 m .49706 .5051 L .49812 .50325 L p .697 .596 .739 r
F P
0 g
s
.49706 .5051 m .49809 .5058 L .4994 .50418 L p .682 .577 .731 r
F P
0 g
s
.4994 .50418 m .49812 .50325 L .49706 .5051 L p .682 .577 .731 r
F P
0 g
s
.08683 .59603 m .06754 .54882 L .06883 .5509 L p .747 .388 0 r
F P
0 g
s
.06883 .5509 m .08925 .59983 L .08683 .59603 L p .747 .388 0 r
F P
0 g
s
.06289 .52026 m .06754 .54882 L .06632 .54458 L p .812 .564 .006 r
F P
0 g
s
.08454 .58793 m .06632 .54458 L .06754 .54882 L p 0 0 .375 r
F P
0 g
s
.78975 .8098 m .75851 .85011 L .75967 .84795 L p 0 0 0 r
F P
0 g
s
.75967 .84795 m .79183 .8058 L .78975 .8098 L p 0 0 0 r
F P
0 g
s
.7361 .86841 m .75851 .85011 L .75545 .85328 L p 0 0 0 r
F P
0 g
s
.78388 .81583 m .75545 .85328 L .75851 .85011 L p .665 .897 .553 r
F P
0 g
s
.61892 .90563 m .6715 .89885 L .67395 .89893 L p .015 0 0 r
F P
0 g
s
.701 .88868 m .67395 .89893 L .6715 .89885 L p .004 0 0 r
F P
0 g
s
.62342 .09417 m .67395 .10107 L .6715 .10115 L p .015 .579 .797 r
F P
0 g
s
.6715 .10115 m .61892 .09437 L .62342 .09417 L p .015 .579 .797 r
F P
0 g
s
.701 .11132 m .67395 .10107 L .67823 .10213 L p 0 .445 .782 r
F P
0 g
s
.63158 .09623 m .67823 .10213 L .67395 .10107 L p .223 0 0 r
F P
0 g
s
.08925 .40017 m .06883 .4491 L .06754 .45118 L p .747 .832 .374 r
F P
0 g
s
.06289 .47974 m .06754 .45118 L .06883 .4491 L p .883 .824 .35 r
F P
0 g
s
.79183 .1942 m .75967 .15205 L .75851 .14989 L p 0 0 .525 r
F P
0 g
s
.7361 .13159 m .75851 .14989 L .75967 .15205 L p 0 .241 .732 r
F P
0 g
s
.49812 .49675 m .4994 .49582 L .49809 .4942 L p .682 .537 .681 r
F P
0 g
s
.49903 .49336 m .49809 .4942 L .4994 .49582 L p .669 .535 .692 r
F P
0 g
s
.50597 .49876 m .50624 .49752 L .50434 .49699 L p .737 .622 .731 r
F P
0 g
s
.50434 .49699 m .50392 .49843 L .50597 .49876 L p .737 .622 .731 r
F P
0 g
s
.49594 .49545 m .49473 .49584 L .49522 .49774 L p .713 .55 .667 r
F P
0 g
s
.49522 .49774 m .49668 .49739 L .49594 .49545 L p .713 .55 .667 r
F P
0 g
s
.50375 .5 m .50392 .50157 L .50597 .50124 L p .74 .597 .698 r
F P
0 g
s
.50624 .50248 m .50597 .50124 L .50392 .50157 L p .737 .581 .681 r
F P
0 g
s
.49812 .50325 m .49668 .50261 L .49594 .50455 L p .697 .596 .739 r
F P
0 g
s
.49473 .50416 m .49594 .50455 L .49668 .50261 L p .712 .614 .745 r
F P
0 g
s
.49809 .5058 m .49903 .50664 L .50044 .50527 L p .669 .557 .72 r
F P
0 g
s
.50044 .50527 m .4994 .50418 L .49809 .5058 L p .669 .557 .72 r
F P
0 g
s
.49986 .4924 m .50058 .49135 L .49933 .49032 L p .607 .491 .695 r
F P
0 g
s
.49988 .48923 m .49933 .49032 L .50058 .49135 L p .587 .492 .714 r
F P
0 g
s
.50872 .49574 m .50939 .49472 L .50786 .49406 L p .74 .69 .802 r
F P
0 g
s
.50786 .49406 m .5072 .49517 L .50872 .49574 L p .74 .69 .802 r
F P
0 g
s
.49195 .49458 m .49073 .49451 L .49092 .49616 L p .767 .554 .609 r
F P
0 g
s
.49092 .49616 m .49222 .49618 L .49195 .49458 L p .767 .554 .609 r
F P
0 g
s
.49349 .50393 m .49222 .50382 L .49195 .50542 L p .743 .676 .785 r
F P
0 g
s
.49073 .50549 m .49195 .50542 L .49222 .50382 L p .767 .699 .787 r
F P
0 g
s
.50665 .50368 m .5072 .50483 L .50872 .50426 L p .753 .55 .622 r
F P
0 g
s
.50939 .50528 m .50872 .50426 L .5072 .50483 L p .74 .52 .594 r
F P
0 g
s
.49933 .50968 m .49988 .51077 L .50122 .50978 L p .587 .467 .683 r
F P
0 g
s
.50122 .50978 m .50058 .50865 L .49933 .50968 L p .587 .467 .683 r
F P
0 g
s
.56182 .49721 m .57949 .49899 L .57722 .49749 L p .163 .674 .898 r
F P
0 g
s
.57722 .49749 m .56003 .49607 L .56182 .49721 L p .163 .674 .898 r
F P
0 g
s
.48073 .45588 m .47339 .44604 L .4715 .44507 L p 0 .088 .636 r
F P
0 g
s
.46112 .43065 m .4715 .44507 L .47339 .44604 L p 0 .075 .629 r
F P
0 g
s
.46668 .44785 m .45938 .43166 L .45922 .43438 L p .845 .471 0 r
F P
0 g
s
.45922 .43438 m .46658 .44998 L .46668 .44785 L p .845 .471 0 r
F P
0 g
s
.47143 .53875 m .46658 .55002 L .46668 .55215 L p .844 .894 .471 r
F P
0 g
s
.45938 .56834 m .46668 .55215 L .46658 .55002 L p .845 .91 .504 r
F P
0 g
s
.54784 .50537 m .56003 .50393 L .56182 .50279 L p .126 0 0 r
F P
0 g
s
.57949 .50101 m .56182 .50279 L .56003 .50393 L p .163 0 0 r
F P
0 g
s
.4715 .55493 m .46112 .56935 L .46356 .56812 L p 0 0 0 r
F P
0 g
s
.46356 .56812 m .47339 .55396 L .4715 .55493 L p 0 0 0 r
F P
0 g
s
.71559 .88136 m .70834 .88598 L .70529 .88731 L p 0 0 0 r
F P
0 g
s
.70834 .88598 m .71559 .88136 L .71669 .88082 L p 0 0 0 r
F P
0 g
s
.72689 .8756 m .72146 .87807 L .72247 .87738 L p 0 0 0 r
F P
0 g
s
.72247 .87738 m .7301 .87342 L .72689 .8756 L p 0 0 0 r
F P
0 g
s
.06194 .49602 m .06156 .48744 L .06193 .48413 L p .869 .737 .222 r
F P
0 g
s
.06156 .48744 m .06194 .49602 L .06185 .49725 L p .852 .717 .19 r
F P
0 g
s
.72247 .12262 m .7301 .12658 L .73278 .12856 L p 0 .319 .76 r
F P
0 g
s
.7301 .12658 m .72247 .12262 L .72146 .12193 L p 0 .311 .747 r
F P
0 g
s
.71183 .11571 m .71669 .11918 L .71559 .11864 L p 0 .369 .773 r
F P
0 g
s
.71559 .11864 m .70834 .11402 L .71183 .11571 L p 0 .369 .773 r
F P
0 g
s
.06128 .5087 m .06185 .50275 L .06194 .50398 L p .852 .674 .139 r
F P
0 g
s
.06194 .50398 m .06156 .51256 L .06128 .5087 L p .852 .674 .139 r
F P
0 g
s
.4994 .49582 m .50044 .49473 L .49903 .49336 L p .669 .535 .692 r
F P
0 g
s
.49986 .4924 m .49903 .49336 L .50044 .49473 L p .655 .534 .705 r
F P
0 g
s
.50624 .49752 m .50665 .49632 L .50489 .49567 L p .731 .632 .749 r
F P
0 g
s
.50489 .49567 m .50434 .49699 L .50624 .49752 L p .731 .632 .749 r
F P
0 g
s
.49473 .49584 m .49349 .49607 L .4938 .49793 L p .73 .56 .661 r
F P
0 g
s
.4938 .49793 m .49522 .49774 L .49473 .49584 L p .73 .56 .661 r
F P
0 g
s
.50392 .50157 m .50434 .50301 L .50624 .50248 L p .737 .581 .681 r
F P
0 g
s
.50665 .50368 m .50624 .50248 L .50434 .50301 L p .731 .561 .662 r
F P
0 g
s
.49668 .50261 m .49522 .50226 L .49473 .50416 L p .712 .614 .745 r
F P
0 g
s
.49349 .50393 m .49473 .50416 L .49522 .50226 L p .73 .632 .749 r
F P
0 g
s
.49903 .50664 m .49986 .5076 L .50131 .5064 L p .655 .535 .706 r
F P
0 g
s
.50131 .5064 m .50044 .50527 L .49903 .50664 L p .655 .535 .706 r
F P
0 g
s
.4994 .49582 m .49812 .49675 L .50001 .49999 L p .699 .568 .704 r
F P
0 g
s
.49812 .49675 m .49668 .49739 L .49718 .5 L p .709 .571 .698 r
F P
0 g
s
.49718 .5 m .49999 .5 L .49812 .49675 L p .709 .571 .698 r
F P
0 g
s
.50375 .5 m .50392 .49843 L .50141 .49756 L p .714 .588 .714 r
F P
0 g
s
.50141 .49756 m .50001 .49999 L .50375 .5 L p .714 .588 .714 r
F P
0 g
s
.50392 .50157 m .50375 .5 L .50001 .50001 L p .714 .579 .702 r
F P
0 g
s
.49668 .50261 m .49812 .50325 L .49999 .5 L p .708 .586 .716 r
F P
0 g
s
.49812 .50325 m .4994 .50418 L .50141 .50244 L p .698 .572 .71 r
F P
0 g
s
.50141 .50244 m .50001 .50001 L .49812 .50325 L p .698 .572 .71 r
F P
0 g
s
.50044 .49473 m .50131 .4936 L .49986 .4924 L p .655 .534 .705 r
F P
0 g
s
.50058 .49135 m .49986 .4924 L .50131 .4936 L p .64 .536 .72 r
F P
0 g
s
.50665 .49632 m .5072 .49517 L .5055 .49443 L p .722 .641 .767 r
F P
0 g
s
.5055 .49443 m .50489 .49567 L .50665 .49632 L p .722 .641 .767 r
F P
0 g
s
.49349 .49607 m .49222 .49618 L .49243 .49802 L p .75 .573 .657 r
F P
0 g
s
.49243 .49802 m .4938 .49793 L .49349 .49607 L p .75 .573 .657 r
F P
0 g
s
.49522 .50226 m .4938 .50207 L .49349 .50393 L p .73 .632 .749 r
F P
0 g
s
.49222 .50382 m .49349 .50393 L .4938 .50207 L p .75 .651 .751 r
F P
0 g
s
.50434 .50301 m .50489 .50433 L .50665 .50368 L p .731 .561 .662 r
F P
0 g
s
.5072 .50483 m .50665 .50368 L .50489 .50433 L p .722 .538 .641 r
F P
0 g
s
.49986 .5076 m .50058 .50865 L .50207 .50755 L p .64 .51 .688 r
F P
0 g
s
.50207 .50755 m .50131 .5064 L .49986 .5076 L p .64 .51 .688 r
F P
0 g
s
.50001 .49999 m .50141 .49756 L .4994 .49582 L p .699 .568 .704 r
F P
0 g
s
.50044 .49473 m .4994 .49582 L .50141 .49756 L p .69 .567 .712 r
F P
0 g
s
.50392 .49843 m .50434 .49699 L .50227 .49606 L p .711 .595 .725 r
F P
0 g
s
.50227 .49606 m .50141 .49756 L .50392 .49843 L p .711 .595 .725 r
F P
0 g
s
.49668 .49739 m .49522 .49774 L .49545 .5 L p .72 .578 .695 r
F P
0 g
s
.49545 .5 m .49718 .5 L .49668 .49739 L p .72 .578 .695 r
F P
0 g
s
.50001 .50001 m .50141 .50244 L .50392 .50157 L p .714 .579 .702 r
F P
0 g
s
.50434 .50301 m .50392 .50157 L .50141 .50244 L p .711 .566 .689 r
F P
0 g
s
.49999 .5 m .49718 .5 L .49668 .50261 L p .708 .586 .716 r
F P
0 g
s
.49522 .50226 m .49668 .50261 L .49718 .5 L p .72 .598 .719 r
F P
0 g
s
.4994 .50418 m .50044 .50527 L .50227 .50394 L p .689 .558 .701 r
F P
0 g
s
.50227 .50394 m .50141 .50244 L .4994 .50418 L p .689 .558 .701 r
F P
0 g
s
.50058 .49135 m .50122 .49022 L .49988 .48923 L p .587 .492 .714 r
F P
0 g
s
.50032 .48801 m .49988 .48923 L .50122 .49022 L p .566 .494 .734 r
F P
0 g
s
.50939 .49472 m .51022 .49373 L .50865 .49297 L p .724 .698 .825 r
F P
0 g
s
.50865 .49297 m .50786 .49406 L .50939 .49472 L p .724 .698 .825 r
F P
0 g
s
.49073 .49451 m .48946 .49429 L .48959 .49602 L p .793 .572 .603 r
F P
0 g
s
.48959 .49602 m .49092 .49616 L .49073 .49451 L p .793 .572 .603 r
F P
0 g
s
.49222 .50382 m .49092 .50384 L .49073 .50549 L p .767 .699 .787 r
F P
0 g
s
.48946 .50571 m .49073 .50549 L .49092 .50384 L p .793 .722 .786 r
F P
0 g
s
.5072 .50483 m .50786 .50594 L .50939 .50528 L p .74 .52 .594 r
F P
0 g
s
.51022 .50627 m .50939 .50528 L .50786 .50594 L p .724 .484 .563 r
F P
0 g
s
.49988 .51077 m .50032 .51199 L .50176 .511 L p .566 .43 .655 r
F P
0 g
s
.50176 .511 m .50122 .50978 L .49988 .51077 L p .566 .43 .655 r
F P
0 g
s
.50141 .49756 m .50227 .49606 L .50044 .49473 L p .69 .567 .712 r
F P
0 g
s
.50131 .4936 m .50044 .49473 L .50227 .49606 L p .68 .57 .724 r
F P
0 g
s
.50434 .49699 m .50489 .49567 L .50303 .49475 L p .704 .601 .738 r
F P
0 g
s
.50303 .49475 m .50227 .49606 L .50434 .49699 L p .704 .601 .738 r
F P
0 g
s
.49522 .49774 m .4938 .49793 L .49394 .5 L p .735 .589 .692 r
F P
0 g
s
.49394 .5 m .49545 .5 L .49522 .49774 L p .735 .589 .692 r
F P
0 g
s
.49718 .5 m .49545 .5 L .49522 .50226 L p .72 .598 .719 r
F P
0 g
s
.4938 .50207 m .49522 .50226 L .49545 .5 L p .735 .612 .72 r
F P
0 g
s
.50141 .50244 m .50227 .50394 L .50434 .50301 L p .711 .566 .689 r
F P
0 g
s
.50489 .50433 m .50434 .50301 L .50227 .50394 L p .704 .549 .674 r
F P
0 g
s
.50044 .50527 m .50131 .5064 L .50303 .50525 L p .68 .54 .688 r
F P
0 g
s
.50303 .50525 m .50227 .50394 L .50044 .50527 L p .68 .54 .688 r
F P
0 g
s
.49934 .48419 m .49914 .48237 L .4978 .48155 L p .305 .355 .75 r
F P
0 g
s
.4971 .47933 m .4978 .48155 L .49914 .48237 L p .261 .359 .775 r
F P
0 g
s
.51708 .49268 m .51935 .49217 L .51777 .49129 L p .61 .808 .976 r
F P
0 g
s
.51777 .49129 m .5157 .49193 L .51708 .49268 L p .61 .808 .976 r
F P
0 g
s
.48512 .48887 m .48354 .48715 L .48357 .48896 L p .918 .585 .395 r
F P
0 g
s
.48357 .48896 m .48516 .49044 L .48512 .48887 L p .918 .585 .395 r
F P
0 g
s
.48664 .50848 m .48516 .50956 L .48512 .51113 L p .89 .896 .827 r
F P
0 g
s
.48354 .51285 m .48512 .51113 L .48516 .50956 L p .918 .914 .798 r
F P
0 g
s
.51402 .50733 m .5157 .50807 L .51708 .50732 L p .664 .267 .282 r
F P
0 g
s
.51935 .50783 m .51708 .50732 L .5157 .50807 L p .61 .188 .217 r
F P
0 g
s
.4978 .51845 m .4971 .52067 L .49866 .51975 L p .261 .068 .418 r
F P
0 g
s
.49866 .51975 m .49914 .51763 L .4978 .51845 L p .261 .068 .418 r
F P
0 g
s
.50032 .48801 m .50065 .48665 L .49932 .48577 L p .481 .436 .73 r
F P
0 g
s
.49934 .48419 m .49932 .48577 L .50065 .48665 L p .45 .439 .755 r
F P
0 g
s
.51266 .49347 m .51402 .49267 L .51246 .49185 L p .699 .761 .899 r
F P
0 g
s
.51246 .49185 m .51124 .49277 L .51266 .49347 L p .699 .761 .899 r
F P
0 g
s
.48802 .4923 m .48664 .49152 L .48671 .49328 L p .852 .578 .523 r
F P
0 g
s
.48671 .49328 m .48812 .49389 L .48802 .4923 L p .852 .578 .523 r
F P
0 g
s
.48946 .50571 m .48812 .50611 L .48802 .5077 L p .821 .788 .821 r
F P
0 g
s
.48664 .50848 m .48802 .5077 L .48812 .50611 L p .852 .814 .811 r
F P
0 g
s
.51022 .50627 m .51124 .50723 L .51266 .50653 L p .729 .435 .481 r
F P
0 g
s
.51402 .50733 m .51266 .50653 L .51124 .50723 L p .699 .381 .435 r
F P
0 g
s
.49932 .51423 m .49934 .51581 L .50083 .51487 L p .45 .295 .579 r
F P
0 g
s
.50083 .51487 m .50065 .51335 L .49932 .51423 L p .45 .295 .579 r
F P
0 g
s
.50227 .49606 m .50303 .49475 L .50131 .4936 L p .68 .57 .724 r
F P
0 g
s
.49545 .5 m .49394 .5 L .4938 .50207 L p .735 .612 .72 r
F P
0 g
s
.50227 .50394 m .50303 .50525 L .50489 .50433 L p .704 .549 .674 r
F P
0 g
s
.50131 .4936 m .50207 .49245 L .50058 .49135 L p .64 .536 .72 r
F P
0 g
s
.50122 .49022 m .50058 .49135 L .50207 .49245 L p .624 .538 .737 r
F P
0 g
s
.5072 .49517 m .50786 .49406 L .50618 .49325 L p .711 .65 .787 r
F P
0 g
s
.50618 .49325 m .5055 .49443 L .5072 .49517 L p .711 .65 .787 r
F P
0 g
s
.49222 .49618 m .49092 .49616 L .49106 .49802 L p .771 .589 .652 r
F P
0 g
s
.49106 .49802 m .49243 .49802 L .49222 .49618 L p .771 .589 .652 r
F P
0 g
s
.4938 .50207 m .49243 .50198 L .49222 .50382 L p .75 .651 .751 r
F P
0 g
s
.49092 .50384 m .49222 .50382 L .49243 .50198 L p .771 .67 .752 r
F P
0 g
s
.50489 .50433 m .5055 .50557 L .5072 .50483 L p .722 .538 .641 r
F P
0 g
s
.50786 .50594 m .5072 .50483 L .5055 .50557 L p .711 .511 .617 r
F P
0 g
s
.50058 .50865 m .50122 .50978 L .50276 .50873 L p .624 .481 .667 r
F P
0 g
s
.50276 .50873 m .50207 .50755 L .50058 .50865 L p .624 .481 .667 r
F P
0 g
s
.50207 .49245 m .50131 .4936 L .50303 .49475 L p .668 .573 .739 r
F P
0 g
s
.50489 .49567 m .5055 .49443 L .50375 .49351 L p .695 .607 .754 r
F P
0 g
s
.50375 .49351 m .50303 .49475 L .50489 .49567 L p .695 .607 .754 r
F P
0 g
s
.4938 .49793 m .49243 .49802 L .49251 .5 L p .753 .602 .69 r
F P
0 g
s
.49251 .5 m .49394 .5 L .4938 .49793 L p .753 .602 .69 r
F P
0 g
s
.49243 .50198 m .4938 .50207 L .49394 .5 L p .753 .627 .721 r
F P
0 g
s
.5055 .50557 m .50489 .50433 L .50303 .50525 L p .695 .527 .656 r
F P
0 g
s
.50131 .5064 m .50207 .50755 L .50375 .50649 L p .668 .518 .672 r
F P
0 g
s
.50375 .50649 m .50303 .50525 L .50131 .5064 L p .668 .518 .672 r
F P
0 g
s
.71669 .88082 m .71183 .88429 L .70834 .88598 L p 0 0 0 r
F P
0 g
s
.71183 .88429 m .71669 .88082 L .71788 .8802 L p 0 0 0 r
F P
0 g
s
.0611 .50445 m .0618 .50141 L .06185 .50275 L p .839 .672 .132 r
F P
0 g
s
.06185 .50275 m .06128 .5087 L .0611 .50445 L p .839 .672 .132 r
F P
0 g
s
.7233 .87787 m .72032 .87879 L .72146 .87807 L p 0 0 0 r
F P
0 g
s
.72146 .87807 m .72689 .8756 L .7233 .87787 L p 0 0 0 r
F P
0 g
s
.06185 .49725 m .06128 .4913 L .06156 .48744 L p .852 .717 .19 r
F P
0 g
s
.06128 .4913 m .06185 .49725 L .0618 .49859 L p .839 .698 .164 r
F P
0 g
s
.7156 .11768 m .71788 .1198 L .71669 .11918 L p 0 .345 .754 r
F P
0 g
s
.71669 .11918 m .71183 .11571 L .7156 .11768 L p 0 .345 .754 r
F P
0 g
s
.72146 .12193 m .72689 .1244 L .7301 .12658 L p 0 .311 .747 r
F P
0 g
s
.72689 .1244 m .72146 .12193 L .72032 .12121 L p 0 .309 .738 r
F P
0 g
s
.50303 .49475 m .50375 .49351 L .50207 .49245 L p .668 .573 .739 r
F P
0 g
s
.49394 .5 m .49251 .5 L .49243 .50198 L p .753 .627 .721 r
F P
0 g
s
.50303 .50525 m .50375 .50649 L .5055 .50557 L p .695 .527 .656 r
F P
0 g
s
.49598 .47667 m .49429 .47346 L .49276 .47258 L p 0 .236 .748 r
F P
0 g
s
.48998 .46839 m .49276 .47258 L .49429 .47346 L p 0 .24 .755 r
F P
0 g
s
.52737 .49256 m .53238 .49287 L .53052 .49177 L p .347 .749 .983 r
F P
0 g
s
.53052 .49177 m .52584 .49167 L .52737 .49256 L p .347 .749 .983 r
F P
0 g
s
.47987 .48002 m .47763 .47552 L .47761 .47768 L p .94 .581 .184 r
F P
0 g
s
.47761 .47768 m .47987 .48178 L .47987 .48002 L p .94 .581 .184 r
F P
0 g
s
.48181 .51515 m .47987 .51822 L .47987 .51998 L p .936 .965 .689 r
F P
0 g
s
.47763 .52448 m .47987 .51998 L .47987 .51822 L p .94 .953 .641 r
F P
0 g
s
.49276 .52742 m .48998 .53161 L .49186 .53055 L p 0 0 .07 r
F P
0 g
s
.49186 .53055 m .49429 .52654 L .49276 .52742 L p 0 0 .07 r
F P
0 g
s
.52221 .50818 m .52584 .50833 L .52737 .50744 L p .41 0 0 r
F P
0 g
s
.53238 .50713 m .52737 .50744 L .52584 .50833 L p .347 0 0 r
F P
0 g
s
.50122 .49022 m .50176 .489 L .50032 .48801 L p .566 .494 .734 r
F P
0 g
s
.50065 .48665 m .50032 .48801 L .50176 .489 L p .542 .497 .755 r
F P
0 g
s
.51022 .49373 m .51124 .49277 L .50957 .49191 L p .704 .706 .849 r
F P
0 g
s
.50957 .49191 m .50865 .49297 L .51022 .49373 L p .704 .706 .849 r
F P
0 g
s
.48946 .49429 m .48812 .49389 L .48821 .49575 L p .819 .593 .595 r
F P
0 g
s
.48821 .49575 m .48959 .49602 L .48946 .49429 L p .819 .593 .595 r
F P
0 g
s
.49092 .50384 m .48959 .50398 L .48946 .50571 L p .793 .722 .786 r
F P
0 g
s
.48812 .50611 m .48946 .50571 L .48959 .50398 L p .819 .745 .782 r
F P
0 g
s
.50786 .50594 m .50865 .50703 L .51022 .50627 L p .724 .484 .563 r
F P
0 g
s
.51124 .50723 m .51022 .50627 L .50865 .50703 L p .704 .444 .529 r
F P
0 g
s
.50032 .51199 m .50065 .51335 L .50222 .51233 L p .542 .388 .622 r
F P
0 g
s
.50222 .51233 m .50176 .511 L .50032 .51199 L p .542 .388 .622 r
F P
0 g
s
.50276 .49127 m .50207 .49245 L .50375 .49351 L p .655 .577 .755 r
F P
0 g
s
.50207 .49245 m .50276 .49127 L .50122 .49022 L p .624 .538 .737 r
F P
0 g
s
.5055 .49443 m .50618 .49325 L .50444 .49231 L p .683 .613 .772 r
F P
0 g
s
.50444 .49231 m .50375 .49351 L .5055 .49443 L p .683 .613 .772 r
F P
0 g
s
.49243 .49802 m .49106 .49802 L .49112 .5 L p .773 .618 .687 r
F P
0 g
s
.49112 .5 m .49251 .5 L .49243 .49802 L p .773 .618 .687 r
F P
0 g
s
.49106 .50198 m .49243 .50198 L .49251 .5 L p .773 .644 .72 r
F P
0 g
s
.49243 .50198 m .49106 .50198 L .49092 .50384 L p .771 .67 .752 r
F P
0 g
s
.50618 .50675 m .5055 .50557 L .50375 .50649 L p .683 .502 .636 r
F P
0 g
s
.5055 .50557 m .50618 .50675 L .50786 .50594 L p .711 .511 .617 r
F P
0 g
s
.50207 .50755 m .50276 .50873 L .50444 .50769 L p .655 .492 .652 r
F P
0 g
s
.50444 .50769 m .50375 .50649 L .50207 .50755 L p .655 .492 .652 r
F P
0 g
s
.75545 .85328 m .73481 .86975 L .7361 .86841 L p 0 0 0 r
F P
0 g
s
.67395 .89893 m .701 .88868 L .70281 .88822 L p 0 0 0 r
F P
0 g
s
.06754 .45118 m .06289 .47974 L .06238 .48153 L p .812 .763 .25 r
F P
0 g
s
.06632 .54458 m .06238 .51847 L .06289 .52026 L p .812 .564 .006 r
F P
0 g
s
.67823 .10213 m .70281 .11178 L .701 .11132 L p 0 .445 .782 r
F P
0 g
s
.75851 .14989 m .7361 .13159 L .73481 .13025 L p 0 .173 .66 r
F P
0 g
s
.50176 .489 m .50122 .49022 L .50276 .49127 L p .606 .541 .755 r
F P
0 g
s
.50786 .49406 m .50865 .49297 L .50693 .49209 L p .696 .657 .807 r
F P
0 g
s
.50693 .49209 m .50618 .49325 L .50786 .49406 L p .696 .657 .807 r
F P
0 g
s
.49092 .49616 m .48959 .49602 L .48969 .49796 L p .794 .606 .647 r
F P
0 g
s
.48969 .49796 m .49106 .49802 L .49092 .49616 L p .794 .606 .647 r
F P
0 g
s
.48959 .50398 m .49092 .50384 L .49106 .50198 L p .794 .69 .751 r
F P
0 g
s
.50865 .50703 m .50786 .50594 L .50618 .50675 L p .696 .48 .591 r
F P
0 g
s
.50122 .50978 m .50176 .511 L .50339 .50995 L p .606 .449 .642 r
F P
0 g
s
.50339 .50995 m .50276 .50873 L .50122 .50978 L p .606 .449 .642 r
F P
0 g
s
.0618 .49859 m .0611 .49555 L .06128 .4913 L p .839 .698 .164 r
F P
0 g
s
.0611 .49555 m .0618 .49859 L .06178 .5 L p .832 .684 .144 r
F P
0 g
s
.71948 .88015 m .71911 .87951 L .72032 .87879 L p 0 0 0 r
F P
0 g
s
.72032 .87879 m .7233 .87787 L .71948 .88015 L p 0 0 0 r
F P
0 g
s
.06105 .5 m .06178 .5 L .0618 .50141 L p .832 .675 .134 r
F P
0 g
s
.0618 .50141 m .0611 .50445 L .06105 .5 L p .832 .675 .134 r
F P
0 g
s
.71788 .8802 m .7156 .88232 L .71183 .88429 L p 0 0 0 r
F P
0 g
s
.7156 .88232 m .71788 .8802 L .71911 .87951 L p 0 0 0 r
F P
0 g
s
.71948 .11985 m .71911 .12049 L .71788 .1198 L p 0 .327 .742 r
F P
0 g
s
.71788 .1198 m .7156 .11768 L .71948 .11985 L p 0 .327 .742 r
F P
0 g
s
.72032 .12121 m .7233 .12213 L .72689 .1244 L p 0 .309 .738 r
F P
0 g
s
.7233 .12213 m .72032 .12121 L .71911 .12049 L p 0 .315 .737 r
F P
0 g
s
.50375 .49351 m .50444 .49231 L .50276 .49127 L p .655 .577 .755 r
F P
0 g
s
.49251 .5 m .49112 .5 L .49106 .50198 L p .773 .644 .72 r
F P
0 g
s
.50375 .50649 m .50444 .50769 L .50618 .50675 L p .683 .502 .636 r
F P
0 g
s
.71911 .87951 m .71948 .88015 L .7156 .88232 L p 0 0 0 r
F P
0 g
s
.06178 .5 m .06105 .5 L .0611 .49555 L p .832 .684 .144 r
F P
0 g
s
.71911 .12049 m .71948 .11985 L .7233 .12213 L p 0 .315 .737 r
F P
0 g
s
.50065 .48665 m .50083 .48513 L .49934 .48419 L p .45 .439 .755 r
F P
0 g
s
.49914 .48237 m .49934 .48419 L .50083 .48513 L p .415 .442 .78 r
F P
0 g
s
.51402 .49267 m .5157 .49193 L .51395 .49098 L p .663 .762 .923 r
F P
0 g
s
.51395 .49098 m .51246 .49185 L .51402 .49267 L p .663 .762 .923 r
F P
0 g
s
.48812 .50611 m .48671 .50672 L .48664 .50848 L p .852 .814 .811 r
F P
0 g
s
.48516 .50956 m .48664 .50848 L .48671 .50672 L p .883 .837 .797 r
F P
0 g
s
.48664 .49152 m .48516 .49044 L .48521 .49243 L p .883 .604 .51 r
F P
0 g
s
.48521 .49243 m .48671 .49328 L .48664 .49152 L p .883 .604 .51 r
F P
0 g
s
.51124 .50723 m .51246 .50815 L .51402 .50733 L p .699 .381 .435 r
F P
0 g
s
.5157 .50807 m .51402 .50733 L .51246 .50815 L p .663 .321 .384 r
F P
0 g
s
.49934 .51581 m .49914 .51763 L .50083 .51659 L p .415 .235 .527 r
F P
0 g
s
.50083 .51659 m .50083 .51487 L .49934 .51581 L p .415 .235 .527 r
F P
0 g
s
.49914 .48237 m .49866 .48025 L .4971 .47933 L p .261 .359 .775 r
F P
0 g
s
.49598 .47667 m .4971 .47933 L .49866 .48025 L p .216 .361 .795 r
F P
0 g
s
.51935 .49217 m .52221 .49182 L .52036 .49077 L p .551 .792 .988 r
F P
0 g
s
.52036 .49077 m .51777 .49129 L .51935 .49217 L p .551 .792 .988 r
F P
0 g
s
.48354 .48715 m .48181 .48485 L .48182 .48699 L p .941 .611 .376 r
F P
0 g
s
.48182 .48699 m .48357 .48896 L .48354 .48715 L p .941 .611 .376 r
F P
0 g
s
.48516 .50956 m .48357 .51104 L .48354 .51285 L p .918 .914 .798 r
F P
0 g
s
.48181 .51515 m .48354 .51285 L .48357 .51104 L p .941 .927 .763 r
F P
0 g
s
.5157 .50807 m .51777 .50871 L .51935 .50783 L p .61 .188 .217 r
F P
0 g
s
.52221 .50818 m .51935 .50783 L .51777 .50871 L p .551 .108 .15 r
F P
0 g
s
.4971 .52067 m .49598 .52333 L .49782 .52225 L p .216 0 .344 r
F P
0 g
s
.49782 .52225 m .49866 .51975 L .4971 .52067 L p .216 0 .344 r
F P
0 g
s
.50339 .49005 m .50276 .49127 L .50444 .49231 L p .639 .581 .773 r
F P
0 g
s
.50276 .49127 m .50339 .49005 L .50176 .489 L p .606 .541 .755 r
F P
0 g
s
.50618 .49325 m .50693 .49209 L .50514 .4911 L p .668 .619 .79 r
F P
0 g
s
.50514 .4911 m .50444 .49231 L .50618 .49325 L p .668 .619 .79 r
F P
0 g
s
.48969 .50204 m .49106 .50198 L .49112 .5 L p .794 .662 .717 r
F P
0 g
s
.49106 .50198 m .48969 .50204 L .48959 .50398 L p .794 .69 .751 r
F P
0 g
s
.49106 .49802 m .48969 .49796 L .48972 .5 L p .794 .635 .684 r
F P
0 g
s
.48972 .5 m .49112 .5 L .49106 .49802 L p .794 .635 .684 r
F P
0 g
s
.50693 .50791 m .50618 .50675 L .50444 .50769 L p .668 .473 .611 r
F P
0 g
s
.50618 .50675 m .50693 .50791 L .50865 .50703 L p .696 .48 .591 r
F P
0 g
s
.50276 .50873 m .50339 .50995 L .50514 .5089 L p .639 .463 .628 r
F P
0 g
s
.50514 .5089 m .50444 .50769 L .50276 .50873 L p .639 .463 .628 r
F P
0 g
s
.47339 .44604 m .46356 .43188 L .46112 .43065 L p 0 .075 .629 r
F P
0 g
s
.44783 .40906 m .46112 .43065 L .46356 .43188 L p 0 .046 .612 r
F P
0 g
s
.57949 .49899 m .60484 .49971 L .60195 .49772 L p .238 .73 .919 r
F P
0 g
s
.60195 .49772 m .57722 .49749 L .57949 .49899 L p .238 .73 .919 r
F P
0 g
s
.45938 .43166 m .44733 .40935 L .44705 .41285 L p .843 .438 0 r
F P
0 g
s
.44705 .41285 m .45922 .43438 L .45938 .43166 L p .843 .438 0 r
F P
0 g
s
.46658 .55002 m .45922 .56562 L .45938 .56834 L p .845 .91 .504 r
F P
0 g
s
.44733 .59065 m .45938 .56834 L .45922 .56562 L p .843 .939 .569 r
F P
0 g
s
.56003 .50393 m .57722 .50251 L .57949 .50101 L p .163 0 0 r
F P
0 g
s
.60484 .50029 m .57949 .50101 L .57722 .50251 L p .238 0 0 r
F P
0 g
s
.46112 .56935 m .44783 .59094 L .451 .58943 L p 0 0 0 r
F P
0 g
s
.451 .58943 m .46356 .56812 L .46112 .56935 L p 0 0 0 r
F P
0 g
s
.50444 .49231 m .50514 .4911 L .50339 .49005 L p .639 .581 .773 r
F P
0 g
s
.49112 .5 m .48972 .5 L .48969 .50204 L p .794 .662 .717 r
F P
0 g
s
.50444 .50769 m .50514 .5089 L .50693 .50791 L p .668 .473 .611 r
F P
0 g
s
.50176 .489 m .50222 .48767 L .50065 .48665 L p .542 .497 .755 r
F P
0 g
s
.50083 .48513 m .50065 .48665 L .50222 .48767 L p .516 .5 .778 r
F P
0 g
s
.51124 .49277 m .51246 .49185 L .51065 .49088 L p .679 .711 .872 r
F P
0 g
s
.51065 .49088 m .50957 .49191 L .51124 .49277 L p .679 .711 .872 r
F P
0 g
s
.48812 .49389 m .48671 .49328 L .48678 .49534 L p .847 .615 .587 r
F P
0 g
s
.48678 .49534 m .48821 .49575 L .48812 .49389 L p .847 .615 .587 r
F P
0 g
s
.48959 .50398 m .48821 .50425 L .48812 .50611 L p .819 .745 .782 r
F P
0 g
s
.48671 .50672 m .48812 .50611 L .48821 .50425 L p .847 .769 .775 r
F P
0 g
s
.50865 .50703 m .50957 .50809 L .51124 .50723 L p .704 .444 .529 r
F P
0 g
s
.51246 .50815 m .51124 .50723 L .50957 .50809 L p .679 .398 .49 r
F P
0 g
s
.50065 .51335 m .50083 .51487 L .50258 .51378 L p .516 .342 .584 r
F P
0 g
s
.50258 .51378 m .50222 .51233 L .50065 .51335 L p .516 .342 .584 r
F P
0 g
s
.50222 .48767 m .50176 .489 L .50339 .49005 L p .586 .545 .775 r
F P
0 g
s
.50865 .49297 m .50957 .49191 L .50774 .49094 L p .678 .663 .828 r
F P
0 g
s
.50774 .49094 m .50693 .49209 L .50865 .49297 L p .678 .663 .828 r
F P
0 g
s
.48959 .49602 m .48821 .49575 L .48828 .49782 L p .818 .625 .641 r
F P
0 g
s
.48828 .49782 m .48969 .49796 L .48959 .49602 L p .818 .625 .641 r
F P
0 g
s
.48821 .50425 m .48959 .50398 L .48969 .50204 L p .818 .711 .747 r
F P
0 g
s
.50957 .50809 m .50865 .50703 L .50693 .50791 L p .678 .444 .56 r
F P
0 g
s
.50176 .511 m .50222 .51233 L .50398 .51124 L p .586 .413 .613 r
F P
0 g
s
.50398 .51124 m .50339 .50995 L .50176 .511 L p .586 .413 .613 r
F P
0 g
s
.50398 .48876 m .50339 .49005 L .50514 .4911 L p .621 .586 .793 r
F P
0 g
s
.50339 .49005 m .50398 .48876 L .50222 .48767 L p .586 .545 .775 r
F P
0 g
s
.50693 .49209 m .50774 .49094 L .50585 .48987 L p .651 .624 .81 r
F P
0 g
s
.50585 .48987 m .50514 .4911 L .50693 .49209 L p .651 .624 .81 r
F P
0 g
s
.48969 .49796 m .48828 .49782 L .4883 .5 L p .817 .653 .679 r
F P
0 g
s
.4883 .5 m .48972 .5 L .48969 .49796 L p .817 .653 .679 r
F P
0 g
s
.48828 .50218 m .48969 .50204 L .48972 .5 L p .817 .681 .714 r
F P
0 g
s
.48969 .50204 m .48828 .50218 L .48821 .50425 L p .818 .711 .747 r
F P
0 g
s
.50339 .50995 m .50398 .51124 L .50585 .51013 L p .621 .429 .6 r
F P
0 g
s
.50585 .51013 m .50514 .5089 L .50339 .50995 L p .621 .429 .6 r
F P
0 g
s
.50774 .50906 m .50693 .50791 L .50514 .5089 L p .651 .439 .583 r
F P
0 g
s
.50693 .50791 m .50774 .50906 L .50957 .50809 L p .678 .444 .56 r
F P
0 g
s
.49429 .47346 m .49186 .46945 L .48998 .46839 L p 0 .24 .755 r
F P
0 g
s
.4861 .46301 m .48998 .46839 L .49186 .46945 L p 0 .243 .758 r
F P
0 g
s
.53238 .49287 m .53898 .49354 L .53668 .49218 L p .3 .721 .973 r
F P
0 g
s
.53668 .49218 m .53052 .49177 L .53238 .49287 L p .3 .721 .973 r
F P
0 g
s
.47763 .47552 m .47492 .46947 L .47489 .47215 L p .939 .592 .174 r
F P
0 g
s
.47489 .47215 m .47761 .47768 L .47763 .47552 L p .939 .592 .174 r
F P
0 g
s
.47987 .51822 m .47761 .52232 L .47763 .52448 L p .94 .953 .641 r
F P
0 g
s
.47492 .53053 m .47763 .52448 L .47761 .52232 L p .939 .942 .604 r
F P
0 g
s
.52584 .50833 m .53052 .50823 L .53238 .50713 L p .347 0 0 r
F P
0 g
s
.53898 .50646 m .53238 .50713 L .53052 .50823 L p .3 0 0 r
F P
0 g
s
.48998 .53161 m .4861 .53699 L .48844 .53567 L p 0 0 .02 r
F P
0 g
s
.48844 .53567 m .49186 .53055 L .48998 .53161 L p 0 0 .02 r
F P
0 g
s
.5157 .49193 m .51777 .49129 L .51577 .49017 L p .621 .758 .944 r
F P
0 g
s
.51577 .49017 m .51395 .49098 L .5157 .49193 L p .621 .758 .944 r
F P
0 g
s
.50083 .48513 m .50083 .48341 L .49914 .48237 L p .415 .442 .78 r
F P
0 g
s
.49866 .48025 m .49914 .48237 L .50083 .48341 L p .377 .445 .804 r
F P
0 g
s
.48516 .49044 m .48357 .48896 L .4836 .49126 L p .911 .629 .496 r
F P
0 g
s
.4836 .49126 m .48521 .49243 L .48516 .49044 L p .911 .629 .496 r
F P
0 g
s
.48671 .50672 m .48521 .50757 L .48516 .50956 L p .883 .837 .797 r
F P
0 g
s
.48357 .51104 m .48516 .50956 L .48521 .50757 L p .911 .859 .777 r
F P
0 g
s
.51246 .50815 m .51395 .50902 L .5157 .50807 L p .663 .321 .384 r
F P
0 g
s
.51777 .50871 m .5157 .50807 L .51395 .50902 L p .621 .255 .328 r
F P
0 g
s
.49914 .51763 m .49866 .51975 L .50063 .51857 L p .377 .171 .469 r
F P
0 g
s
.50063 .51857 m .50083 .51659 L .49914 .51763 L p .377 .171 .469 r
F P
0 g
s
.50514 .4911 m .50585 .48987 L .50398 .48876 L p .621 .586 .793 r
F P
0 g
s
.48972 .5 m .4883 .5 L .48828 .50218 L p .817 .681 .714 r
F P
0 g
s
.50514 .5089 m .50585 .51013 L .50774 .50906 L p .651 .439 .583 r
F P
0 g
s
.50258 .48622 m .50222 .48767 L .50398 .48876 L p .563 .548 .796 r
F P
0 g
s
.50222 .48767 m .50258 .48622 L .50083 .48513 L p .516 .5 .778 r
F P
0 g
s
.50957 .49191 m .51065 .49088 L .50865 .48978 L p .656 .668 .85 r
F P
0 g
s
.50865 .48978 m .50774 .49094 L .50957 .49191 L p .656 .668 .85 r
F P
0 g
s
.48821 .49575 m .48678 .49534 L .48682 .49761 L p .844 .645 .634 r
F P
0 g
s
.48682 .49761 m .48828 .49782 L .48821 .49575 L p .844 .645 .634 r
F P
0 g
s
.48678 .50466 m .48821 .50425 L .48828 .50218 L p .844 .733 .741 r
F P
0 g
s
.48821 .50425 m .48678 .50466 L .48671 .50672 L p .847 .769 .775 r
F P
0 g
s
.51065 .50912 m .50957 .50809 L .50774 .50906 L p .656 .403 .526 r
F P
0 g
s
.50957 .50809 m .51065 .50912 L .51246 .50815 L p .679 .398 .49 r
F P
0 g
s
.50222 .51233 m .50258 .51378 L .50452 .51261 L p .563 .371 .579 r
F P
0 g
s
.50452 .51261 m .50398 .51124 L .50222 .51233 L p .563 .371 .579 r
F P
0 g
s
.50083 .48341 m .50083 .48513 L .50258 .48622 L p .486 .503 .801 r
F P
0 g
s
.51246 .49185 m .51395 .49098 L .51192 .48986 L p .649 .713 .895 r
F P
0 g
s
.51192 .48986 m .51065 .49088 L .51246 .49185 L p .649 .713 .895 r
F P
0 g
s
.48671 .49328 m .48521 .49243 L .48526 .49475 L p .875 .638 .576 r
F P
0 g
s
.48526 .49475 m .48678 .49534 L .48671 .49328 L p .875 .638 .576 r
F P
0 g
s
.48521 .50757 m .48671 .50672 L .48678 .50466 L p .875 .791 .764 r
F P
0 g
s
.51395 .50902 m .51246 .50815 L .51065 .50912 L p .649 .347 .446 r
F P
0 g
s
.50083 .51487 m .50083 .51659 L .50283 .51539 L p .486 .291 .54 r
F P
0 g
s
.50283 .51539 m .50258 .51378 L .50083 .51487 L p .486 .291 .54 r
F P
0 g
s
.49866 .48025 m .49782 .47775 L .49598 .47667 L p .216 .361 .795 r
F P
0 g
s
.49429 .47346 m .49598 .47667 L .49782 .47775 L p .172 .361 .81 r
F P
0 g
s
.52221 .49182 m .52584 .49167 L .52362 .49039 L p .49 .771 .994 r
F P
0 g
s
.52362 .49039 m .52036 .49077 L .52221 .49182 L p .49 .771 .994 r
F P
0 g
s
.48181 .48485 m .47987 .48178 L .47987 .48435 L p .958 .632 .356 r
F P
0 g
s
.47987 .48435 m .48182 .48699 L .48181 .48485 L p .958 .632 .356 r
F P
0 g
s
.48357 .51104 m .48182 .51301 L .48181 .51515 L p .941 .927 .763 r
F P
0 g
s
.47987 .51822 m .48181 .51515 L .48182 .51301 L p .958 .932 .724 r
F P
0 g
s
.51777 .50871 m .52036 .50923 L .52221 .50818 L p .551 .108 .15 r
F P
0 g
s
.52584 .50833 m .52221 .50818 L .52036 .50923 L p .49 .03 .087 r
F P
0 g
s
.49598 .52333 m .49429 .52654 L .49651 .52526 L p .172 0 .27 r
F P
0 g
s
.49651 .52526 m .49782 .52225 L .49598 .52333 L p .172 0 .27 r
F P
0 g
s
.50452 .48739 m .50398 .48876 L .50585 .48987 L p .6 .59 .813 r
F P
0 g
s
.50398 .48876 m .50452 .48739 L .50258 .48622 L p .563 .548 .796 r
F P
0 g
s
.50774 .49094 m .50865 .48978 L .50658 .4886 L p .63 .628 .83 r
F P
0 g
s
.50658 .4886 m .50585 .48987 L .50774 .49094 L p .63 .628 .83 r
F P
0 g
s
.48828 .49782 m .48682 .49761 L .48684 .5 L p .842 .673 .673 r
F P
0 g
s
.48684 .5 m .4883 .5 L .48828 .49782 L p .842 .673 .673 r
F P
0 g
s
.48682 .50239 m .48828 .50218 L .4883 .5 L p .842 .702 .708 r
F P
0 g
s
.48828 .50218 m .48682 .50239 L .48678 .50466 L p .844 .733 .741 r
F P
0 g
s
.50865 .51022 m .50774 .50906 L .50585 .51013 L p .63 .4 .551 r
F P
0 g
s
.50774 .50906 m .50865 .51022 L .51065 .50912 L p .656 .403 .526 r
F P
0 g
s
.50398 .51124 m .50452 .51261 L .50658 .5114 L p .6 .39 .568 r
F P
0 g
s
.50658 .5114 m .50585 .51013 L .50398 .51124 L p .6 .39 .568 r
F P
0 g
s
.50585 .48987 m .50658 .4886 L .50452 .48739 L p .6 .59 .813 r
F P
0 g
s
.4883 .5 m .48684 .5 L .48682 .50239 L p .842 .702 .708 r
F P
0 g
s
.50585 .51013 m .50658 .5114 L .50865 .51022 L p .63 .4 .551 r
F P
0 g
s
.51065 .49088 m .51192 .48986 L .50968 .4886 L p .629 .671 .871 r
F P
0 g
s
.50968 .4886 m .50865 .48978 L .51065 .49088 L p .629 .671 .871 r
F P
0 g
s
.50283 .48461 m .50258 .48622 L .50452 .48739 L p .537 .551 .817 r
F P
0 g
s
.50258 .48622 m .50283 .48461 L .50083 .48341 L p .486 .503 .801 r
F P
0 g
s
.48678 .49534 m .48526 .49475 L .48529 .49732 L p .87 .666 .625 r
F P
0 g
s
.48529 .49732 m .48682 .49761 L .48678 .49534 L p .87 .666 .625 r
F P
0 g
s
.48526 .50525 m .48678 .50466 L .48682 .50239 L p .87 .754 .732 r
F P
0 g
s
.48678 .50466 m .48526 .50525 L .48521 .50757 L p .875 .791 .764 r
F P
0 g
s
.51192 .51014 m .51065 .50912 L .50865 .51022 L p .629 .357 .486 r
F P
0 g
s
.51065 .50912 m .51192 .51014 L .51395 .50902 L p .649 .347 .446 r
F P
0 g
s
.50258 .51378 m .50283 .51539 L .50503 .51408 L p .537 .325 .54 r
F P
0 g
s
.50503 .51408 m .50452 .51261 L .50258 .51378 L p .537 .325 .54 r
F P
0 g
s
.50083 .48341 m .50063 .48143 L .49866 .48025 L p .377 .445 .804 r
F P
0 g
s
.49782 .47775 m .49866 .48025 L .50063 .48143 L p .337 .446 .824 r
F P
0 g
s
.51777 .49129 m .52036 .49077 L .518 .48943 L p .573 .751 .961 r
F P
0 g
s
.518 .48943 m .51577 .49017 L .51777 .49129 L p .573 .751 .961 r
F P
0 g
s
.48357 .48896 m .48182 .48699 L .48184 .4897 L p .936 .652 .478 r
F P
0 g
s
.48184 .4897 m .4836 .49126 L .48357 .48896 L p .936 .652 .478 r
F P
0 g
s
.48521 .50757 m .4836 .50874 L .48357 .51104 L p .911 .859 .777 r
F P
0 g
s
.48182 .51301 m .48357 .51104 L .4836 .50874 L p .936 .876 .752 r
F P
0 g
s
.51395 .50902 m .51577 .50983 L .51777 .50871 L p .621 .255 .328 r
F P
0 g
s
.52036 .50923 m .51777 .50871 L .51577 .50983 L p .573 .186 .269 r
F P
0 g
s
.49866 .51975 m .49782 .52225 L .50016 .52088 L p .337 .104 .406 r
F P
0 g
s
.50016 .52088 m .50063 .51857 L .49866 .51975 L p .337 .104 .406 r
F P
0 g
s
.46356 .43188 m .451 .41057 L .44783 .40906 L p 0 .046 .612 r
F P
0 g
s
.43262 .37566 m .44783 .40906 L .451 .41057 L p 0 0 .574 r
F P
0 g
s
.60484 .49971 m .64137 .49619 L .63779 .49351 L p .358 .812 .94 r
F P
0 g
s
.63779 .49351 m .60195 .49772 L .60484 .49971 L p .358 .812 .94 r
F P
0 g
s
.44733 .40935 m .42601 .37947 L .42549 .38392 L p .827 .377 0 r
F P
0 g
s
.42549 .38392 m .44705 .41285 L .44733 .40935 L p .827 .377 0 r
F P
0 g
s
.45922 .56562 m .44705 .58715 L .44733 .59065 L p .843 .939 .569 r
F P
0 g
s
.42601 .62053 m .44733 .59065 L .44705 .58715 L p .827 .974 .669 r
F P
0 g
s
.57722 .50251 m .60195 .50228 L .60484 .50029 L p .238 0 0 r
F P
0 g
s
.64137 .50381 m .60484 .50029 L .60195 .50228 L p .358 0 0 r
F P
0 g
s
.44783 .59094 m .43262 .62434 L .43673 .62257 L p 0 0 .033 r
F P
0 g
s
.43673 .62257 m .451 .58943 L .44783 .59094 L p 0 0 .033 r
F P
0 g
s
.51395 .49098 m .51577 .49017 L .51343 .48885 L p .614 .713 .916 r
F P
0 g
s
.51343 .48885 m .51192 .48986 L .51395 .49098 L p .614 .713 .916 r
F P
0 g
s
.50063 .48143 m .50083 .48341 L .50283 .48461 L p .453 .506 .823 r
F P
0 g
s
.48521 .49243 m .4836 .49126 L .48363 .49395 L p .902 .661 .563 r
F P
0 g
s
.48363 .49395 m .48526 .49475 L .48521 .49243 L p .902 .661 .563 r
F P
0 g
s
.4836 .50874 m .48521 .50757 L .48526 .50525 L p .902 .813 .75 r
F P
0 g
s
.51577 .50983 m .51395 .50902 L .51192 .51014 L p .614 .29 .397 r
F P
0 g
s
.50083 .51659 m .50063 .51857 L .50294 .5172 L p .453 .234 .49 r
F P
0 g
s
.50294 .5172 m .50283 .51539 L .50083 .51659 L p .453 .234 .49 r
F P
0 g
s
.53898 .49354 m .54784 .49463 L .54494 .49289 L p .276 .707 .967 r
F P
0 g
s
.54494 .49289 m .53668 .49218 L .53898 .49354 L p .276 .707 .967 r
F P
0 g
s
.49186 .46945 m .48844 .46433 L .4861 .46301 L p 0 .243 .758 r
F P
0 g
s
.48073 .45588 m .4861 .46301 L .48844 .46433 L p 0 .244 .759 r
F P
0 g
s
.47492 .46947 m .47143 .46125 L .47137 .46464 L p .938 .596 .169 r
F P
0 g
s
.47137 .46464 m .47489 .47215 L .47492 .46947 L p .938 .596 .169 r
F P
0 g
s
.47761 .52232 m .47489 .52785 L .47492 .53053 L p .939 .942 .604 r
F P
0 g
s
.47143 .53875 m .47492 .53053 L .47489 .52785 L p .938 .935 .584 r
F P
0 g
s
.53052 .50823 m .53668 .50782 L .53898 .50646 L p .3 0 0 r
F P
0 g
s
.54784 .50537 m .53898 .50646 L .53668 .50782 L p .276 0 0 r
F P
0 g
s
.4861 .53699 m .48073 .54412 L .48369 .54247 L p 0 0 0 r
F P
0 g
s
.48369 .54247 m .48844 .53567 L .4861 .53699 L p 0 0 0 r
F P
0 g
s
.50865 .48978 m .50968 .4886 L .50735 .48727 L p .605 .632 .851 r
F P
0 g
s
.50735 .48727 m .50658 .4886 L .50865 .48978 L p .605 .632 .851 r
F P
0 g
s
.50503 .48592 m .50452 .48739 L .50658 .4886 L p .575 .593 .834 r
F P
0 g
s
.50452 .48739 m .50503 .48592 L .50283 .48461 L p .537 .551 .817 r
F P
0 g
s
.48682 .49761 m .48529 .49732 L .4853 .5 L p .867 .694 .665 r
F P
0 g
s
.4853 .5 m .48684 .5 L .48682 .49761 L p .867 .694 .665 r
F P
0 g
s
.48529 .50268 m .48682 .50239 L .48684 .5 L p .867 .722 .7 r
F P
0 g
s
.48682 .50239 m .48529 .50268 L .48526 .50525 L p .87 .754 .732 r
F P
0 g
s
.50968 .5114 m .50865 .51022 L .50658 .5114 L p .605 .356 .513 r
F P
0 g
s
.50865 .51022 m .50968 .5114 L .51192 .51014 L p .629 .357 .486 r
F P
0 g
s
.50452 .51261 m .50503 .51408 L .50735 .51273 L p .575 .345 .531 r
F P
0 g
s
.50735 .51273 m .50658 .5114 L .50452 .51261 L p .575 .345 .531 r
F P
0 g
s
.50658 .4886 m .50735 .48727 L .50503 .48592 L p .575 .593 .834 r
F P
0 g
s
.48684 .5 m .4853 .5 L .48529 .50268 L p .867 .722 .7 r
F P
0 g
s
.50658 .5114 m .50735 .51273 L .50968 .5114 L p .605 .356 .513 r
F P
0 g
s
.49782 .47775 m .49651 .47474 L .49429 .47346 L p .172 .361 .81 r
F P
0 g
s
.49186 .46945 m .49429 .47346 L .49651 .47474 L p .133 .36 .819 r
F P
0 g
s
.52584 .49167 m .53052 .49177 L .52781 .49019 L p .435 .749 .994 r
F P
0 g
s
.52781 .49019 m .52362 .49039 L .52584 .49167 L p .435 .749 .994 r
F P
0 g
s
.47987 .48178 m .47761 .47768 L .4776 .48082 L p .968 .648 .338 r
F P
0 g
s
.4776 .48082 m .47987 .48435 L .47987 .48178 L p .968 .648 .338 r
F P
0 g
s
.48182 .51301 m .47987 .51565 L .47987 .51822 L p .958 .932 .724 r
F P
0 g
s
.47761 .52232 m .47987 .51822 L .47987 .51565 L p .968 .932 .686 r
F P
0 g
s
.52036 .50923 m .52362 .50961 L .52584 .50833 L p .49 .03 .087 r
F P
0 g
s
.53052 .50823 m .52584 .50833 L .52362 .50961 L p .435 0 .03 r
F P
0 g
s
.49429 .52654 m .49186 .53055 L .49459 .52899 L p .133 0 .205 r
F P
0 g
s
.49459 .52899 m .49651 .52526 L .49429 .52654 L p .133 0 .205 r
F P
0 g
s
.67395 .89893 m .62342 .90583 L .61892 .90563 L p .015 0 0 r
F P
0 g
s
.54202 .88929 m .61892 .90563 L .62342 .90583 L p 0 .523 .784 r
F P
0 g
s
.81304 .7367 m .78975 .8098 L .79183 .8058 L p .764 .802 .317 r
F P
0 g
s
.79183 .8058 m .81612 .73104 L .81304 .7367 L p .764 .802 .317 r
F P
0 g
s
.06754 .45118 m .08683 .40397 L .08925 .40017 L p .747 .832 .374 r
F P
0 g
s
.14185 .34175 m .08925 .40017 L .08683 .40397 L p 0 0 0 r
F P
0 g
s
.13849 .65275 m .08683 .59603 L .08925 .59983 L p 0 .036 .566 r
F P
0 g
s
.08925 .59983 m .14185 .65825 L .13849 .65275 L p 0 .036 .566 r
F P
0 g
s
.75851 .14989 m .78975 .1902 L .79183 .1942 L p 0 0 .525 r
F P
0 g
s
.81612 .26896 m .79183 .1942 L .78975 .1902 L p .764 .446 0 r
F P
0 g
s
.54846 .11055 m .62342 .09417 L .61892 .09437 L p 0 0 0 r
F P
0 g
s
.61892 .09437 m .54202 .11071 L .54846 .11055 L p 0 0 0 r
F P
0 g
s
.75059 .85734 m .73278 .87144 L .73481 .86975 L p 0 0 0 r
F P
0 g
s
.73481 .86975 m .75545 .85328 L .75059 .85734 L p 0 0 0 r
F P
0 g
s
.74415 .86209 m .7301 .87342 L .73278 .87144 L p .481 .85 .613 r
F P
0 g
s
.06524 .53835 m .06193 .51587 L .06238 .51847 L p .73 .506 0 r
F P
0 g
s
.06238 .51847 m .06632 .54458 L .06524 .53835 L p .73 .506 0 r
F P
0 g
s
.06434 .5304 m .06156 .51256 L .06193 .51587 L p 0 0 .144 r
F P
0 g
s
.70281 .88822 m .67823 .89787 L .67395 .89893 L p 0 0 0 r
F P
0 g
s
.67823 .89787 m .70281 .88822 L .70529 .88731 L p 0 0 0 r
F P
0 g
s
.06238 .48153 m .06632 .45542 L .06754 .45118 L p .812 .763 .25 r
F P
0 g
s
.06632 .45542 m .06238 .48153 L .06193 .48413 L p .73 .685 .142 r
F P
0 g
s
.68417 .10431 m .70529 .11269 L .70281 .11178 L p 0 .357 .691 r
F P
0 g
s
.70281 .11178 m .67823 .10213 L .68417 .10431 L p 0 .357 .691 r
F P
0 g
s
.6915 .10751 m .70834 .11402 L .70529 .11269 L p .323 0 0 r
F P
0 g
s
.73481 .13025 m .75545 .14672 L .75851 .14989 L p 0 .173 .66 r
F P
0 g
s
.75545 .14672 m .73481 .13025 L .73278 .12856 L p 0 .112 .581 r
F P
0 g
s
.51192 .48986 m .51343 .48885 L .51085 .48739 L p .598 .672 .892 r
F P
0 g
s
.51085 .48739 m .50968 .4886 L .51192 .48986 L p .598 .672 .892 r
F P
0 g
s
.50294 .4828 m .50283 .48461 L .50503 .48592 L p .506 .554 .839 r
F P
0 g
s
.50283 .48461 m .50294 .4828 L .50063 .48143 L p .453 .506 .823 r
F P
0 g
s
.48526 .49475 m .48363 .49395 L .48365 .4969 L p .896 .688 .614 r
F P
0 g
s
.48365 .4969 m .48529 .49732 L .48526 .49475 L p .896 .688 .614 r
F P
0 g
s
.48363 .50605 m .48526 .50525 L .48529 .50268 L p .896 .775 .72 r
F P
0 g
s
.48526 .50525 m .48363 .50605 L .4836 .50874 L p .902 .813 .75 r
F P
0 g
s
.50283 .51539 m .50294 .5172 L .50549 .5157 L p .506 .273 .495 r
F P
0 g
s
.50549 .5157 m .50503 .51408 L .50283 .51539 L p .506 .273 .495 r
F P
0 g
s
.51343 .51115 m .51192 .51014 L .50968 .5114 L p .598 .305 .442 r
F P
0 g
s
.51192 .51014 m .51343 .51115 L .51577 .50983 L p .614 .29 .397 r
F P
0 g
s
.52036 .49077 m .52362 .49039 L .52079 .48877 L p .524 .739 .973 r
F P
0 g
s
.52079 .48877 m .518 .48943 L .52036 .49077 L p .524 .739 .973 r
F P
0 g
s
.50063 .48143 m .50016 .47912 L .49782 .47775 L p .337 .446 .824 r
F P
0 g
s
.49651 .47474 m .49782 .47775 L .50016 .47912 L p .295 .445 .841 r
F P
0 g
s
.48182 .48699 m .47987 .48435 L .47988 .48761 L p .956 .673 .46 r
F P
0 g
s
.47988 .48761 m .48184 .4897 L .48182 .48699 L p .956 .673 .46 r
F P
0 g
s
.4836 .50874 m .48184 .5103 L .48182 .51301 L p .936 .876 .752 r
F P
0 g
s
.47987 .51565 m .48182 .51301 L .48184 .5103 L p .956 .888 .724 r
F P
0 g
s
.51577 .50983 m .518 .51057 L .52036 .50923 L p .573 .186 .269 r
F P
0 g
s
.52362 .50961 m .52036 .50923 L .518 .51057 L p .524 .117 .211 r
F P
0 g
s
.49782 .52225 m .49651 .52526 L .49933 .52362 L p .295 .038 .342 r
F P
0 g
s
.49933 .52362 m .50016 .52088 L .49782 .52225 L p .295 .038 .342 r
F P
0 g
s
.51577 .49017 m .518 .48943 L .51525 .48786 L p .574 .71 .934 r
F P
0 g
s
.51525 .48786 m .51343 .48885 L .51577 .49017 L p .574 .71 .934 r
F P
0 g
s
.50016 .47912 m .50063 .48143 L .50294 .4828 L p .417 .506 .843 r
F P
0 g
s
.4836 .49126 m .48184 .4897 L .48186 .49287 L p .927 .683 .548 r
F P
0 g
s
.48186 .49287 m .48363 .49395 L .4836 .49126 L p .927 .683 .548 r
F P
0 g
s
.48184 .5103 m .4836 .50874 L .48363 .50605 L p .927 .832 .731 r
F P
0 g
s
.50063 .51857 m .50016 .52088 L .50289 .51928 L p .417 .174 .436 r
F P
0 g
s
.50289 .51928 m .50294 .5172 L .50063 .51857 L p .417 .174 .436 r
F P
0 g
s
.518 .51057 m .51577 .50983 L .51343 .51115 L p .574 .228 .345 r
F P
0 g
s
.50968 .4886 m .51085 .48739 L .50817 .48585 L p .575 .634 .872 r
F P
0 g
s
.50817 .48585 m .50735 .48727 L .50968 .4886 L p .575 .634 .872 r
F P
0 g
s
.50549 .4843 m .50503 .48592 L .50735 .48727 L p .545 .595 .855 r
F P
0 g
s
.50503 .48592 m .50549 .4843 L .50294 .4828 L p .506 .554 .839 r
F P
0 g
s
.48365 .5031 m .48529 .50268 L .4853 .5 L p .893 .743 .689 r
F P
0 g
s
.48529 .50268 m .48365 .5031 L .48363 .50605 L p .896 .775 .72 r
F P
0 g
s
.48529 .49732 m .48365 .4969 L .48366 .5 L p .893 .715 .654 r
F P
0 g
s
.48366 .5 m .4853 .5 L .48529 .49732 L p .893 .715 .654 r
F P
0 g
s
.51085 .51261 m .50968 .5114 L .50735 .51273 L p .575 .306 .471 r
F P
0 g
s
.50968 .5114 m .51085 .51261 L .51343 .51115 L p .598 .305 .442 r
F P
0 g
s
.50503 .51408 m .50549 .5157 L .50817 .51415 L p .545 .296 .488 r
F P
0 g
s
.50817 .51415 m .50735 .51273 L .50503 .51408 L p .545 .296 .488 r
F P
0 g
s
.50735 .48727 m .50817 .48585 L .50549 .4843 L p .545 .595 .855 r
F P
0 g
s
.4853 .5 m .48366 .5 L .48365 .5031 L p .893 .743 .689 r
F P
0 g
s
.50735 .51273 m .50817 .51415 L .51085 .51261 L p .575 .306 .471 r
F P
0 g
s
.48844 .46433 m .48369 .45753 L .48073 .45588 L p 0 .244 .759 r
F P
0 g
s
.47339 .44604 m .48073 .45588 L .48369 .45753 L p 0 .244 .759 r
F P
0 g
s
.54784 .49463 m .56003 .49607 L .55632 .49382 L p .282 .71 .968 r
F P
0 g
s
.55632 .49382 m .54494 .49289 L .54784 .49463 L p .282 .71 .968 r
F P
0 g
s
.47143 .46125 m .46658 .44998 L .46649 .45432 L p .938 .595 .17 r
F P
0 g
s
.46649 .45432 m .47137 .46464 L .47143 .46125 L p .938 .595 .17 r
F P
0 g
s
.47489 .52785 m .47137 .53536 L .47143 .53875 L p .938 .935 .584 r
F P
0 g
s
.46658 .55002 m .47143 .53875 L .47137 .53536 L p .938 .937 .589 r
F P
0 g
s
.53668 .50782 m .54494 .50711 L .54784 .50537 L p .276 0 0 r
F P
0 g
s
.56003 .50393 m .54784 .50537 L .54494 .50711 L p .282 0 0 r
F P
0 g
s
.48073 .54412 m .47339 .55396 L .47719 .55186 L p 0 0 .001 r
F P
0 g
s
.47719 .55186 m .48369 .54247 L .48073 .54412 L p 0 0 .001 r
F P
0 g
s
.64137 .49619 m .69212 .48082 L .68792 .47719 L p .522 .908 .94 r
F P
0 g
s
.68792 .47719 m .63779 .49351 L .64137 .49619 L p .522 .908 .94 r
F P
0 g
s
.451 .41057 m .43673 .37743 L .43262 .37566 L p 0 0 .574 r
F P
0 g
s
.42055 .32403 m .43262 .37566 L .43673 .37743 L p 0 0 .497 r
F P
0 g
s
.42601 .37947 m .38733 .34321 L .38629 .34867 L p .775 .271 0 r
F P
0 g
s
.38629 .34867 m .42549 .38392 L .42601 .37947 L p .775 .271 0 r
F P
0 g
s
.44705 .58715 m .42549 .61608 L .42601 .62053 L p .827 .974 .669 r
F P
0 g
s
.38733 .65679 m .42601 .62053 L .42549 .61608 L p .775 .995 .794 r
F P
0 g
s
.60195 .50228 m .63779 .50649 L .64137 .50381 L p .358 0 0 r
F P
0 g
s
.69212 .51918 m .64137 .50381 L .63779 .50649 L p .522 0 0 r
F P
0 g
s
.43262 .62434 m .42055 .67597 L .4258 .67415 L p 0 0 .205 r
F P
0 g
s
.4258 .67415 m .43673 .62257 L .43262 .62434 L p 0 0 .205 r
F P
0 g
s
.53052 .49177 m .53668 .49218 L .5333 .4902 L p .392 .729 .99 r
F P
0 g
s
.5333 .4902 m .52781 .49019 L .53052 .49177 L p .392 .729 .99 r
F P
0 g
s
.49651 .47474 m .49459 .47101 L .49186 .46945 L p .133 .36 .819 r
F P
0 g
s
.48844 .46433 m .49186 .46945 L .49459 .47101 L p .104 .358 .824 r
F P
0 g
s
.47761 .47768 m .47489 .47215 L .47486 .47606 L p .972 .658 .323 r
F P
0 g
s
.47486 .47606 m .4776 .48082 L .47761 .47768 L p .972 .658 .323 r
F P
0 g
s
.47987 .51565 m .4776 .51918 L .47761 .52232 L p .968 .932 .686 r
F P
0 g
s
.47489 .52785 m .47761 .52232 L .4776 .51918 L p .972 .929 .656 r
F P
0 g
s
.52362 .50961 m .52781 .50981 L .53052 .50823 L p .435 0 .03 r
F P
0 g
s
.53668 .50782 m .53052 .50823 L .52781 .50981 L p .392 0 0 r
F P
0 g
s
.49186 .53055 m .48844 .53567 L .49184 .53374 L p .104 0 .155 r
F P
0 g
s
.49184 .53374 m .49459 .52899 L .49186 .53055 L p .104 0 .155 r
F P
0 g
s
.51343 .48885 m .51525 .48786 L .51222 .48613 L p .563 .671 .911 r
F P
0 g
s
.51222 .48613 m .51085 .48739 L .51343 .48885 L p .563 .671 .911 r
F P
0 g
s
.50289 .48072 m .50294 .4828 L .50549 .4843 L p .472 .554 .858 r
F P
0 g
s
.50294 .4828 m .50289 .48072 L .50016 .47912 L p .417 .506 .843 r
F P
0 g
s
.48363 .49395 m .48186 .49287 L .48187 .49635 L p .921 .709 .6 r
F P
0 g
s
.48187 .49635 m .48365 .4969 L .48363 .49395 L p .921 .709 .6 r
F P
0 g
s
.48186 .50713 m .48363 .50605 L .48365 .5031 L p .921 .794 .704 r
F P
0 g
s
.48363 .50605 m .48186 .50713 L .48184 .5103 L p .927 .832 .731 r
F P
0 g
s
.51525 .51214 m .51343 .51115 L .51085 .51261 L p .563 .248 .393 r
F P
0 g
s
.51343 .51115 m .51525 .51214 L .518 .51057 L p .574 .228 .345 r
F P
0 g
s
.50294 .5172 m .50289 .51928 L .5059 .51752 L p .472 .217 .445 r
F P
0 g
s
.5059 .51752 m .50549 .5157 L .50294 .5172 L p .472 .217 .445 r
F P
0 g
s
.49933 .47638 m .50016 .47912 L .50289 .48072 L p .379 .505 .86 r
F P
0 g
s
.50016 .47912 m .49933 .47638 L .49651 .47474 L p .295 .445 .841 r
F P
0 g
s
.518 .48943 m .52079 .48877 L .51749 .48687 L p .532 .703 .949 r
F P
0 g
s
.51749 .48687 m .51525 .48786 L .518 .48943 L p .532 .703 .949 r
F P
0 g
s
.48184 .4897 m .47988 .48761 L .47988 .49142 L p .948 .702 .531 r
F P
0 g
s
.47988 .49142 m .48186 .49287 L .48184 .4897 L p .948 .702 .531 r
F P
0 g
s
.47988 .51239 m .48184 .5103 L .48186 .50713 L p .948 .847 .708 r
F P
0 g
s
.48184 .5103 m .47988 .51239 L .47987 .51565 L p .956 .888 .724 r
F P
0 g
s
.52079 .51123 m .518 .51057 L .51525 .51214 L p .532 .166 .291 r
F P
0 g
s
.518 .51057 m .52079 .51123 L .52362 .50961 L p .524 .117 .211 r
F P
0 g
s
.50016 .52088 m .49933 .52362 L .50263 .52171 L p .379 .113 .379 r
F P
0 g
s
.50263 .52171 m .50289 .51928 L .50016 .52088 L p .379 .113 .379 r
F P
0 g
s
.49459 .47101 m .49651 .47474 L .49933 .47638 L p .258 .442 .852 r
F P
0 g
s
.52362 .49039 m .52781 .49019 L .52435 .48819 L p .477 .725 .979 r
F P
0 g
s
.52435 .48819 m .52079 .48877 L .52362 .49039 L p .477 .725 .979 r
F P
0 g
s
.47987 .48435 m .4776 .48082 L .4776 .48481 L p .97 .688 .441 r
F P
0 g
s
.4776 .48481 m .47988 .48761 L .47987 .48435 L p .97 .688 .441 r
F P
0 g
s
.4776 .51918 m .47987 .51565 L .47988 .51239 L p .97 .895 .695 r
F P
0 g
s
.52781 .50981 m .52362 .50961 L .52079 .51123 L p .477 .054 .157 r
F P
0 g
s
.49651 .52526 m .49459 .52899 L .49805 .52699 L p .258 0 .284 r
F P
0 g
s
.49805 .52699 m .49933 .52362 L .49651 .52526 L p .258 0 .284 r
F P
0 g
s
.51085 .48739 m .51222 .48613 L .50906 .48431 L p .542 .633 .891 r
F P
0 g
s
.50906 .48431 m .50817 .48585 L .51085 .48739 L p .542 .633 .891 r
F P
0 g
s
.5059 .48248 m .50549 .4843 L .50817 .48585 L p .513 .595 .874 r
F P
0 g
s
.50549 .4843 m .5059 .48248 L .50289 .48072 L p .472 .554 .858 r
F P
0 g
s
.48187 .50365 m .48365 .5031 L .48366 .5 L p .917 .763 .674 r
F P
0 g
s
.48365 .5031 m .48187 .50365 L .48186 .50713 L p .921 .794 .704 r
F P
0 g
s
.48365 .4969 m .48187 .49635 L .48188 .5 L p .917 .735 .64 r
F P
0 g
s
.48188 .5 m .48366 .5 L .48365 .4969 L p .917 .735 .64 r
F P
0 g
s
.51222 .51387 m .51085 .51261 L .50817 .51415 L p .542 .252 .424 r
F P
0 g
s
.51085 .51261 m .51222 .51387 L .51525 .51214 L p .563 .248 .393 r
F P
0 g
s
.50549 .5157 m .5059 .51752 L .50906 .51569 L p .513 .242 .441 r
F P
0 g
s
.50906 .51569 m .50817 .51415 L .50549 .5157 L p .513 .242 .441 r
F P
0 g
s
.50817 .48585 m .50906 .48431 L .5059 .48248 L p .513 .595 .874 r
F P
0 g
s
.48366 .5 m .48188 .5 L .48187 .50365 L p .917 .763 .674 r
F P
0 g
s
.50817 .51415 m .50906 .51569 L .51222 .51387 L p .542 .252 .424 r
F P
0 g
s
.73278 .87144 m .75059 .85734 L .74415 .86209 L p .481 .85 .613 r
F P
0 g
s
.06193 .51587 m .06524 .53835 L .06434 .5304 L p 0 0 .144 r
F P
0 g
s
.70529 .88731 m .68417 .89569 L .67823 .89787 L p 0 0 0 r
F P
0 g
s
.68417 .89569 m .70529 .88731 L .70834 .88598 L p .323 .796 .704 r
F P
0 g
s
.06193 .48413 m .06524 .46165 L .06632 .45542 L p .73 .685 .142 r
F P
0 g
s
.06524 .46165 m .06193 .48413 L .06156 .48744 L p 0 0 0 r
F P
0 g
s
.70529 .11269 m .68417 .10431 L .6915 .10751 L p .323 0 0 r
F P
0 g
s
.73278 .12856 m .75059 .14266 L .75545 .14672 L p 0 .112 .581 r
F P
0 g
s
.75059 .14266 m .73278 .12856 L .7301 .12658 L p .481 0 0 r
F P
0 g
s
.50263 .47829 m .50289 .48072 L .5059 .48248 L p .437 .553 .875 r
F P
0 g
s
.50289 .48072 m .50263 .47829 L .49933 .47638 L p .379 .505 .86 r
F P
0 g
s
.51525 .48786 m .51749 .48687 L .51386 .48478 L p .525 .667 .927 r
F P
0 g
s
.51386 .48478 m .51222 .48613 L .51525 .48786 L p .525 .667 .927 r
F P
0 g
s
.48186 .49287 m .47988 .49142 L .47989 .49561 L p .942 .728 .584 r
F P
0 g
s
.47989 .49561 m .48187 .49635 L .48186 .49287 L p .942 .728 .584 r
F P
0 g
s
.47988 .50858 m .48186 .50713 L .48187 .50365 L p .942 .811 .686 r
F P
0 g
s
.48186 .50713 m .47988 .50858 L .47988 .51239 L p .948 .847 .708 r
F P
0 g
s
.51749 .51313 m .51525 .51214 L .51222 .51387 L p .525 .19 .343 r
F P
0 g
s
.51525 .51214 m .51749 .51313 L .52079 .51123 L p .532 .166 .291 r
F P
0 g
s
.50289 .51928 m .50263 .52171 L .50626 .51961 L p .437 .16 .394 r
F P
0 g
s
.50626 .51961 m .5059 .51752 L .50289 .51928 L p .437 .16 .394 r
F P
0 g
s
.75851 .85011 m .78975 .8098 L .78388 .81583 L p .665 .897 .553 r
F P
0 g
s
.62342 .90583 m .67395 .89893 L .67823 .89787 L p .223 .744 .809 r
F P
0 g
s
.08683 .40397 m .06754 .45118 L .06632 .45542 L p 0 0 0 r
F P
0 g
s
.06754 .54882 m .08683 .59603 L .08454 .58793 L p 0 0 .375 r
F P
0 g
s
.78975 .1902 m .75851 .14989 L .75545 .14672 L p .665 .188 0 r
F P
0 g
s
.67395 .10107 m .62342 .09417 L .63158 .09623 L p .223 0 0 r
F P
0 g
s
.49459 .47101 m .49184 .46626 L .48844 .46433 L p .104 .358 .824 r
F P
0 g
s
.48369 .45753 m .48844 .46433 L .49184 .46626 L p .089 .357 .826 r
F P
0 g
s
.53668 .49218 m .54494 .49289 L .54067 .49037 L p .37 .719 .988 r
F P
0 g
s
.54067 .49037 m .5333 .4902 L .53668 .49218 L p .37 .719 .988 r
F P
0 g
s
.47489 .47215 m .47137 .46464 L .47133 .46959 L p .973 .662 .315 r
F P
0 g
s
.47133 .46959 m .47486 .47606 L .47489 .47215 L p .973 .662 .315 r
F P
0 g
s
.4776 .51918 m .47486 .52394 L .47489 .52785 L p .972 .929 .656 r
F P
0 g
s
.47137 .53536 m .47489 .52785 L .47486 .52394 L p .973 .927 .64 r
F P
0 g
s
.52781 .50981 m .5333 .5098 L .53668 .50782 L p .392 0 0 r
F P
0 g
s
.54494 .50711 m .53668 .50782 L .5333 .5098 L p .37 0 0 r
F P
0 g
s
.48844 .53567 m .48369 .54247 L .488 .54003 L p .089 0 .129 r
F P
0 g
s
.488 .54003 m .49184 .53374 L .48844 .53567 L p .089 0 .129 r
F P
0 g
s
.48369 .45753 m .47719 .44814 L .47339 .44604 L p 0 .244 .759 r
F P
0 g
s
.46356 .43188 m .47339 .44604 L .47719 .44814 L p 0 .241 .756 r
F P
0 g
s
.56003 .49607 m .57722 .49749 L .5724 .49455 L p .323 .735 .978 r
F P
0 g
s
.5724 .49455 m .55632 .49382 L .56003 .49607 L p .323 .735 .978 r
F P
0 g
s
.46658 .44998 m .45922 .43438 L .45907 .44002 L p .939 .586 .179 r
F P
0 g
s
.45907 .44002 m .46649 .45432 L .46658 .44998 L p .939 .586 .179 r
F P
0 g
s
.47137 .53536 m .46649 .54568 L .46658 .55002 L p .938 .937 .589 r
F P
0 g
s
.45922 .56562 m .46658 .55002 L .46649 .54568 L p .939 .948 .622 r
F P
0 g
s
.54494 .50711 m .55632 .50618 L .56003 .50393 L p .282 0 0 r
F P
0 g
s
.57722 .50251 m .56003 .50393 L .55632 .50618 L p .323 0 0 r
F P
0 g
s
.47339 .55396 m .46356 .56812 L .46852 .56543 L p 0 0 .044 r
F P
0 g
s
.46852 .56543 m .47719 .55186 L .47339 .55396 L p 0 0 .044 r
F P
0 g
s
.43673 .37743 m .4258 .32585 L .42055 .32403 L p 0 0 .497 r
F P
0 g
s
.42527 .25052 m .42055 .32403 L .4258 .32585 L p 0 0 .354 r
F P
0 g
s
.69212 .48082 m .75342 .43998 L .74903 .43512 L p .711 .985 .882 r
F P
0 g
s
.74903 .43512 m .68792 .47719 L .69212 .48082 L p .711 .985 .882 r
F P
0 g
s
.38733 .34321 m .32131 .31054 L .3193 .31678 L p .653 .102 0 r
F P
0 g
s
.3193 .31678 m .38629 .34867 L .38733 .34321 L p .653 .102 0 r
F P
0 g
s
.63779 .50649 m .68792 .52281 L .69212 .51918 L p .522 0 0 r
F P
0 g
s
.75342 .56002 m .69212 .51918 L .68792 .52281 L p .711 .177 0 r
F P
0 g
s
.42549 .61608 m .38629 .65133 L .38733 .65679 L p .775 .995 .794 r
F P
0 g
s
.32131 .68946 m .38733 .65679 L .38629 .65133 L p .653 .965 .915 r
F P
0 g
s
.42055 .67597 m .42527 .74948 L .43168 .7481 L p 0 0 .42 r
F P
0 g
s
.43168 .7481 m .4258 .67415 L .42055 .67597 L p 0 0 .42 r
F P
0 g
s
.51222 .48613 m .51386 .48478 L .51005 .48259 L p .507 .631 .907 r
F P
0 g
s
.51005 .48259 m .50906 .48431 L .51222 .48613 L p .507 .631 .907 r
F P
0 g
s
.50626 .48039 m .5059 .48248 L .50906 .48431 L p .478 .594 .891 r
F P
0 g
s
.5059 .48248 m .50626 .48039 L .50263 .47829 L p .437 .553 .875 r
F P
0 g
s
.48187 .49635 m .47989 .49561 L .47989 .5 L p .939 .753 .624 r
F P
0 g
s
.47989 .5 m .48188 .5 L .48187 .49635 L p .939 .753 .624 r
F P
0 g
s
.47989 .50439 m .48187 .50365 L .48188 .5 L p .939 .78 .658 r
F P
0 g
s
.48187 .50365 m .47989 .50439 L .47988 .50858 L p .942 .811 .686 r
F P
0 g
s
.5059 .51752 m .50626 .51961 L .51005 .51741 L p .478 .186 .392 r
F P
0 g
s
.51005 .51741 m .50906 .51569 L .5059 .51752 L p .478 .186 .392 r
F P
0 g
s
.51386 .51522 m .51222 .51387 L .50906 .51569 L p .507 .196 .375 r
F P
0 g
s
.51222 .51387 m .51386 .51522 L .51749 .51313 L p .525 .19 .343 r
F P
0 g
s
.80034 .64252 m .81304 .7367 L .81612 .73104 L p .931 .697 .214 r
F P
0 g
s
.81612 .73104 m .80428 .63662 L .80034 .64252 L p .931 .697 .214 r
F P
0 g
s
.46618 .83183 m .54202 .88929 L .54846 .88945 L p 0 .343 .807 r
F P
0 g
s
.62342 .90583 m .54846 .88945 L .54202 .88929 L p 0 .523 .784 r
F P
0 g
s
.22954 .30479 m .14185 .34175 L .13849 .34725 L p .039 0 0 r
F P
0 g
s
.08683 .40397 m .13849 .34725 L .14185 .34175 L p 0 0 0 r
F P
0 g
s
.2264 .68884 m .13849 .65275 L .14185 .65825 L p .039 .515 .884 r
F P
0 g
s
.14185 .65825 m .22954 .69521 L .2264 .68884 L p .039 .515 .884 r
F P
0 g
s
.80428 .36338 m .81612 .26896 L .81304 .2633 L p .931 .823 .369 r
F P
0 g
s
.78975 .1902 m .81304 .2633 L .81612 .26896 L p .764 .446 0 r
F P
0 g
s
.47326 .16864 m .54846 .11055 L .54202 .11071 L p 0 0 0 r
F P
0 g
s
.54202 .11071 m .46618 .16817 L .47326 .16864 L p 0 0 0 r
F P
0 g
s
.52079 .48877 m .52435 .48819 L .52031 .48586 L p .491 .694 .959 r
F P
0 g
s
.52031 .48586 m .51749 .48687 L .52079 .48877 L p .491 .694 .959 r
F P
0 g
s
.49805 .47301 m .49933 .47638 L .50263 .47829 L p .343 .503 .873 r
F P
0 g
s
.49933 .47638 m .49805 .47301 L .49459 .47101 L p .258 .442 .852 r
F P
0 g
s
.47988 .48761 m .4776 .48481 L .4776 .48948 L p .964 .717 .514 r
F P
0 g
s
.4776 .48948 m .47988 .49142 L .47988 .48761 L p .964 .717 .514 r
F P
0 g
s
.4776 .51519 m .47988 .51239 L .47988 .50858 L p .964 .858 .685 r
F P
0 g
s
.47988 .51239 m .4776 .51519 L .4776 .51918 L p .97 .895 .695 r
F P
0 g
s
.49933 .52362 m .49805 .52699 L .50209 .52466 L p .343 .057 .326 r
F P
0 g
s
.50209 .52466 m .50263 .52171 L .49933 .52362 L p .343 .057 .326 r
F P
0 g
s
.52435 .51181 m .52079 .51123 L .51749 .51313 L p .491 .108 .241 r
F P
0 g
s
.52079 .51123 m .52435 .51181 L .52781 .50981 L p .477 .054 .157 r
F P
0 g
s
.50906 .48431 m .51005 .48259 L .50626 .48039 L p .478 .594 .891 r
F P
0 g
s
.48188 .5 m .47989 .5 L .47989 .50439 L p .939 .78 .658 r
F P
0 g
s
.50906 .51569 m .51005 .51741 L .51386 .51522 L p .507 .196 .375 r
F P
0 g
s
.49184 .46626 m .49459 .47101 L .49805 .47301 L p .228 .44 .859 r
F P
0 g
s
.52781 .49019 m .5333 .4902 L .529 .48769 L p .44 .713 .981 r
F P
0 g
s
.529 .48769 m .52435 .48819 L .52781 .49019 L p .44 .713 .981 r
F P
0 g
s
.4776 .48082 m .47486 .47606 L .47484 .48104 L p .978 .698 .426 r
F P
0 g
s
.47484 .48104 m .4776 .48481 L .4776 .48082 L p .978 .698 .426 r
F P
0 g
s
.47486 .52394 m .4776 .51918 L .4776 .51519 L p .978 .898 .671 r
F P
0 g
s
.5333 .5098 m .52781 .50981 L .52435 .51181 L p .44 .006 .116 r
F P
0 g
s
.49459 .52899 m .49184 .53374 L .49616 .53126 L p .228 0 .238 r
F P
0 g
s
.49616 .53126 m .49805 .52699 L .49459 .52899 L p .228 0 .238 r
F P
0 g
s
.73641 .86734 m .72689 .8756 L .7301 .87342 L p .524 .891 .686 r
F P
0 g
s
.7301 .87342 m .74415 .86209 L .73641 .86734 L p .524 .891 .686 r
F P
0 g
s
.70834 .88598 m .6915 .89249 L .68417 .89569 L p .323 .796 .704 r
F P
0 g
s
.6915 .89249 m .70834 .88598 L .71183 .88429 L p .407 .851 .753 r
F P
0 g
s
.06367 .52107 m .06128 .5087 L .06156 .51256 L p 0 0 .186 r
F P
0 g
s
.06156 .51256 m .06434 .5304 L .06367 .52107 L p 0 0 .186 r
F P
0 g
s
.06156 .48744 m .06434 .4696 L .06524 .46165 L p 0 0 0 r
F P
0 g
s
.06434 .4696 m .06156 .48744 L .06128 .4913 L p 0 0 .051 r
F P
0 g
s
.69992 .11159 m .71183 .11571 L .70834 .11402 L p .407 0 0 r
F P
0 g
s
.70834 .11402 m .6915 .10751 L .69992 .11159 L p .407 0 0 r
F P
0 g
s
.7301 .12658 m .74415 .13791 L .75059 .14266 L p .481 0 0 r
F P
0 g
s
.74415 .13791 m .7301 .12658 L .72689 .1244 L p .524 0 0 r
F P
0 g
s
.50209 .47534 m .50263 .47829 L .50626 .48039 L p .402 .55 .888 r
F P
0 g
s
.50263 .47829 m .50209 .47534 L .49805 .47301 L p .343 .503 .873 r
F P
0 g
s
.51749 .48687 m .52031 .48586 L .51586 .48329 L p .488 .661 .938 r
F P
0 g
s
.51586 .48329 m .51386 .48478 L .51749 .48687 L p .488 .661 .938 r
F P
0 g
s
.47988 .49142 m .4776 .48948 L .4776 .49462 L p .959 .743 .567 r
F P
0 g
s
.4776 .49462 m .47989 .49561 L .47988 .49142 L p .959 .743 .567 r
F P
0 g
s
.4776 .51052 m .47988 .50858 L .47989 .50439 L p .959 .824 .666 r
F P
0 g
s
.47988 .50858 m .4776 .51052 L .4776 .51519 L p .964 .858 .685 r
F P
0 g
s
.50263 .52171 m .50209 .52466 L .50654 .52209 L p .402 .107 .345 r
F P
0 g
s
.50654 .52209 m .50626 .51961 L .50263 .52171 L p .402 .107 .345 r
F P
0 g
s
.52031 .51414 m .51749 .51313 L .51386 .51522 L p .488 .136 .295 r
F P
0 g
s
.51749 .51313 m .52031 .51414 L .52435 .51181 L p .491 .108 .241 r
F P
0 g
s
.72771 .87285 m .7233 .87787 L .72689 .8756 L p .542 .911 .737 r
F P
0 g
s
.72689 .8756 m .73641 .86734 L .72771 .87285 L p .542 .911 .737 r
F P
0 g
s
.06325 .51078 m .0611 .50445 L .06128 .5087 L p 0 0 .204 r
F P
0 g
s
.06128 .5087 m .06367 .52107 L .06325 .51078 L p 0 0 .204 r
F P
0 g
s
.71183 .88429 m .69992 .88841 L .6915 .89249 L p .407 .851 .753 r
F P
0 g
s
.69992 .88841 m .71183 .88429 L .7156 .88232 L p .471 .887 .778 r
F P
0 g
s
.06128 .4913 m .06367 .47893 L .06434 .4696 L p 0 0 .051 r
F P
0 g
s
.06367 .47893 m .06128 .4913 L .0611 .49555 L p 0 0 .122 r
F P
0 g
s
.70904 .11638 m .7156 .11768 L .71183 .11571 L p .471 0 0 r
F P
0 g
s
.71183 .11571 m .69992 .11159 L .70904 .11638 L p .471 0 0 r
F P
0 g
s
.72689 .1244 m .73641 .13266 L .74415 .13791 L p .524 0 0 r
F P
0 g
s
.73641 .13266 m .72689 .1244 L .7233 .12213 L p .542 0 0 r
F P
0 g
s
.75342 .43998 m .80428 .36338 L .80034 .35748 L p .877 .986 .712 r
F P
0 g
s
.80034 .35748 m .74903 .43512 L .75342 .43998 L p .877 .986 .712 r
F P
0 g
s
.4258 .32585 m .43168 .2519 L .42527 .25052 L p 0 0 .354 r
F P
0 g
s
.46618 .16817 m .42527 .25052 L .43168 .2519 L p 0 0 .118 r
F P
0 g
s
.32131 .31054 m .22954 .30479 L .2264 .31116 L p .42 0 0 r
F P
0 g
s
.2264 .31116 m .3193 .31678 L .32131 .31054 L p .42 0 0 r
F P
0 g
s
.68792 .52281 m .74903 .56488 L .75342 .56002 L p .711 .177 0 r
F P
0 g
s
.80428 .63662 m .75342 .56002 L .74903 .56488 L p .877 .447 .052 r
F P
0 g
s
.42527 .74948 m .46618 .83183 L .47326 .83136 L p 0 .092 .646 r
F P
0 g
s
.47326 .83136 m .43168 .7481 L .42527 .74948 L p 0 .092 .646 r
F P
0 g
s
.38629 .65133 m .3193 .68322 L .32131 .68946 L p .653 .965 .915 r
F P
0 g
s
.22954 .69521 m .32131 .68946 L .3193 .68322 L p .42 .828 .976 r
F P
0 g
s
.51386 .48478 m .51586 .48329 L .5112 .4806 L p .472 .627 .92 r
F P
0 g
s
.5112 .4806 m .51005 .48259 L .51386 .48478 L p .472 .627 .92 r
F P
0 g
s
.50654 .47791 m .50626 .48039 L .51005 .48259 L p .444 .591 .903 r
F P
0 g
s
.50626 .48039 m .50654 .47791 L .50209 .47534 L p .402 .55 .888 r
F P
0 g
s
.47989 .49561 m .4776 .49462 L .4776 .5 L p .956 .767 .608 r
F P
0 g
s
.4776 .5 m .47989 .5 L .47989 .49561 L p .956 .767 .608 r
F P
0 g
s
.4776 .50538 m .47989 .50439 L .47989 .5 L p .956 .794 .64 r
F P
0 g
s
.47989 .50439 m .4776 .50538 L .4776 .51052 L p .959 .824 .666 r
F P
0 g
s
.51586 .51671 m .51386 .51522 L .51005 .51741 L p .472 .144 .328 r
F P
0 g
s
.51386 .51522 m .51586 .51671 L .52031 .51414 L p .488 .136 .295 r
F P
0 g
s
.50626 .51961 m .50654 .52209 L .5112 .5194 L p .444 .134 .345 r
F P
0 g
s
.5112 .5194 m .51005 .51741 L .50626 .51961 L p .444 .134 .345 r
F P
0 g
s
.54494 .49289 m .55632 .49382 L .55083 .49057 L p .376 .722 .989 r
F P
0 g
s
.55083 .49057 m .54067 .49037 L .54494 .49289 L p .376 .722 .989 r
F P
0 g
s
.49184 .46626 m .488 .45997 L .48369 .45753 L p .089 .357 .826 r
F P
0 g
s
.47719 .44814 m .48369 .45753 L .488 .45997 L p .093 .357 .825 r
F P
0 g
s
.47137 .46464 m .46649 .45432 L .46642 .4607 L p .973 .661 .317 r
F P
0 g
s
.46642 .4607 m .47133 .46959 L .47137 .46464 L p .973 .661 .317 r
F P
0 g
s
.47486 .52394 m .47133 .53041 L .47137 .53536 L p .973 .927 .64 r
F P
0 g
s
.46649 .54568 m .47137 .53536 L .47133 .53041 L p .973 .928 .644 r
F P
0 g
s
.5333 .5098 m .54067 .50963 L .54494 .50711 L p .37 0 0 r
F P
0 g
s
.55632 .50618 m .54494 .50711 L .54067 .50963 L p .376 0 0 r
F P
0 g
s
.48369 .54247 m .47719 .55186 L .48276 .54874 L p .093 0 .136 r
F P
0 g
s
.48276 .54874 m .488 .54003 L .48369 .54247 L p .093 0 .136 r
F P
0 g
s
.43168 .2519 m .47326 .16864 L .46618 .16817 L p 0 0 .118 r
F P
0 g
s
.74903 .56488 m .80034 .64252 L .80428 .63662 L p .877 .447 .052 r
F P
0 g
s
.81304 .2633 m .80034 .35748 L .80428 .36338 L p .931 .823 .369 r
F P
0 g
s
.13849 .34725 m .2264 .31116 L .22954 .30479 L p .039 0 0 r
F P
0 g
s
.54846 .88945 m .47326 .83136 L .46618 .83183 L p 0 .343 .807 r
F P
0 g
s
.3193 .68322 m .2264 .68884 L .22954 .69521 L p .42 .828 .976 r
F P
0 g
s
.49616 .46874 m .49805 .47301 L .50209 .47534 L p .314 .5 .88 r
F P
0 g
s
.49805 .47301 m .49616 .46874 L .49184 .46626 L p .228 .44 .859 r
F P
0 g
s
.52435 .48819 m .529 .48769 L .52396 .48477 L p .459 .686 .964 r
F P
0 g
s
.52396 .48477 m .52031 .48586 L .52435 .48819 L p .459 .686 .964 r
F P
0 g
s
.4776 .48481 m .47484 .48104 L .47483 .48687 L p .975 .728 .499 r
F P
0 g
s
.47483 .48687 m .4776 .48948 L .4776 .48481 L p .975 .728 .499 r
F P
0 g
s
.47484 .51896 m .4776 .51519 L .4776 .51052 L p .975 .864 .666 r
F P
0 g
s
.4776 .51519 m .47484 .51896 L .47486 .52394 L p .978 .898 .671 r
F P
0 g
s
.49805 .52699 m .49616 .53126 L .50121 .52836 L p .314 .013 .284 r
F P
0 g
s
.50121 .52836 m .50209 .52466 L .49805 .52699 L p .314 .013 .284 r
F P
0 g
s
.529 .51231 m .52435 .51181 L .52031 .51414 L p .459 .063 .201 r
F P
0 g
s
.52435 .51181 m .529 .51231 L .5333 .5098 L p .44 .006 .116 r
F P
0 g
s
.51005 .48259 m .5112 .4806 L .50654 .47791 L p .444 .591 .903 r
F P
0 g
s
.47989 .5 m .4776 .5 L .4776 .50538 L p .956 .794 .64 r
F P
0 g
s
.51005 .51741 m .5112 .5194 L .51586 .51671 L p .472 .144 .328 r
F P
0 g
s
.7156 .88232 m .70904 .88362 L .69992 .88841 L p .471 .887 .778 r
F P
0 g
s
.70904 .88362 m .7156 .88232 L .71948 .88015 L p .514 .908 .783 r
F P
0 g
s
.71844 .87836 m .71948 .88015 L .7233 .87787 L p .538 .916 .769 r
F P
0 g
s
.7233 .87787 m .72771 .87285 L .71844 .87836 L p .538 .916 .769 r
F P
0 g
s
.0611 .49555 m .06325 .48922 L .06367 .47893 L p 0 0 .122 r
F P
0 g
s
.06325 .48922 m .0611 .49555 L .06105 .5 L p 0 0 .171 r
F P
0 g
s
.06311 .5 m .06105 .5 L .0611 .50445 L p 0 0 .199 r
F P
0 g
s
.0611 .50445 m .06325 .51078 L .06311 .5 L p 0 0 .199 r
F P
0 g
s
.7233 .12213 m .72771 .12715 L .73641 .13266 L p .542 0 0 r
F P
0 g
s
.72771 .12715 m .7233 .12213 L .71948 .11985 L p .538 0 0 r
F P
0 g
s
.71844 .12164 m .71948 .11985 L .7156 .11768 L p .514 0 0 r
F P
0 g
s
.7156 .11768 m .70904 .11638 L .71844 .12164 L p .514 0 0 r
F P
0 g
s
.47719 .44814 m .46852 .43457 L .46356 .43188 L p 0 .241 .756 r
F P
0 g
s
.451 .41057 m .46356 .43188 L .46852 .43457 L p 0 .233 .747 r
F P
0 g
s
.57722 .49749 m .60195 .49772 L .59568 .4938 L p .402 .78 .992 r
F P
0 g
s
.59568 .4938 m .5724 .49455 L .57722 .49749 L p .402 .78 .992 r
F P
0 g
s
.45922 .43438 m .44705 .41285 L .44679 .42024 L p .936 .564 .193 r
F P
0 g
s
.44679 .42024 m .45907 .44002 L .45922 .43438 L p .936 .564 .193 r
F P
0 g
s
.46649 .54568 m .45907 .55998 L .45922 .56562 L p .939 .948 .622 r
F P
0 g
s
.44705 .58715 m .45922 .56562 L .45907 .55998 L p .936 .965 .684 r
F P
0 g
s
.55632 .50618 m .5724 .50545 L .57722 .50251 L p .323 0 0 r
F P
0 g
s
.60195 .50228 m .57722 .50251 L .5724 .50545 L p .402 0 0 r
F P
0 g
s
.46356 .56812 m .451 .58943 L .45753 .58596 L p 0 0 .131 r
F P
0 g
s
.45753 .58596 m .46852 .56543 L .46356 .56812 L p 0 0 .131 r
F P
0 g
s
.5333 .4902 m .54067 .49037 L .53521 .48719 L p .42 .705 .982 r
F P
0 g
s
.53521 .48719 m .529 .48769 L .5333 .4902 L p .42 .705 .982 r
F P
0 g
s
.488 .45997 m .49184 .46626 L .49616 .46874 L p .212 .438 .862 r
F P
0 g
s
.47486 .47606 m .47133 .46959 L .4713 .47591 L p .981 .703 .418 r
F P
0 g
s
.4713 .47591 m .47484 .48104 L .47486 .47606 L p .981 .703 .418 r
F P
0 g
s
.47133 .53041 m .47486 .52394 L .47484 .51896 L p .981 .899 .658 r
F P
0 g
s
.54067 .50963 m .5333 .5098 L .529 .51231 L p .42 0 .094 r
F P
0 g
s
.49184 .53374 m .488 .54003 L .49349 .5369 L p .212 0 .214 r
F P
0 g
s
.49349 .5369 m .49616 .53126 L .49184 .53374 L p .212 0 .214 r
F P
0 g
s
.71948 .88015 m .71844 .87836 L .70904 .88362 L p .514 .908 .783 r
F P
0 g
s
.06105 .5 m .06311 .5 L .06325 .48922 L p 0 0 .171 r
F P
0 g
s
.71948 .11985 m .71844 .12164 L .72771 .12715 L p .538 0 0 r
F P
0 g
s
.50121 .47164 m .50209 .47534 L .50654 .47791 L p .374 .547 .897 r
F P
0 g
s
.50209 .47534 m .50121 .47164 L .49616 .46874 L p .314 .5 .88 r
F P
0 g
s
.52031 .48586 m .52396 .48477 L .5184 .48156 L p .458 .655 .945 r
F P
0 g
s
.5184 .48156 m .51586 .48329 L .52031 .48586 L p .458 .655 .945 r
F P
0 g
s
.4776 .48948 m .47483 .48687 L .47483 .49328 L p .97 .753 .553 r
F P
0 g
s
.47483 .49328 m .4776 .49462 L .4776 .48948 L p .97 .753 .553 r
F P
0 g
s
.47483 .51313 m .4776 .51052 L .4776 .50538 L p .97 .832 .65 r
F P
0 g
s
.4776 .51052 m .47483 .51313 L .47484 .51896 L p .975 .864 .666 r
F P
0 g
s
.52396 .51523 m .52031 .51414 L .51586 .51671 L p .458 .093 .257 r
F P
0 g
s
.52031 .51414 m .52396 .51523 L .529 .51231 L p .459 .063 .201 r
F P
0 g
s
.50209 .52466 m .50121 .52836 L .50677 .52516 L p .374 .064 .306 r
F P
0 g
s
.50677 .52516 m .50654 .52209 L .50209 .52466 L p .374 .064 .306 r
F P
0 g
s
.50677 .47484 m .50654 .47791 L .5112 .4806 L p .416 .587 .912 r
F P
0 g
s
.50654 .47791 m .50677 .47484 L .50121 .47164 L p .374 .547 .897 r
F P
0 g
s
.51586 .48329 m .5184 .48156 L .51259 .4782 L p .444 .622 .928 r
F P
0 g
s
.51259 .4782 m .5112 .4806 L .51586 .48329 L p .444 .622 .928 r
F P
0 g
s
.4776 .49462 m .47483 .49328 L .47483 .5 L p .968 .777 .593 r
F P
0 g
s
.47483 .5 m .4776 .5 L .4776 .49462 L p .968 .777 .593 r
F P
0 g
s
.47483 .50672 m .4776 .50538 L .4776 .5 L p .968 .803 .625 r
F P
0 g
s
.4776 .50538 m .47483 .50672 L .47483 .51313 L p .97 .832 .65 r
F P
0 g
s
.5184 .51844 m .51586 .51671 L .5112 .5194 L p .444 .103 .291 r
F P
0 g
s
.51586 .51671 m .5184 .51844 L .52396 .51523 L p .458 .093 .257 r
F P
0 g
s
.50654 .52209 m .50677 .52516 L .51259 .5218 L p .416 .093 .307 r
F P
0 g
s
.51259 .5218 m .5112 .5194 L .50654 .52209 L p .416 .093 .307 r
F P
0 g
s
.5112 .4806 m .51259 .4782 L .50677 .47484 L p .416 .587 .912 r
F P
0 g
s
.4776 .5 m .47483 .5 L .47483 .50672 L p .968 .803 .625 r
F P
0 g
s
.5112 .5194 m .51259 .5218 L .5184 .51844 L p .444 .103 .291 r
F P
0 g
s
.77442 .82366 m .75059 .85734 L .75545 .85328 L p .785 .982 .718 r
F P
0 g
s
.75545 .85328 m .78388 .81583 L .77442 .82366 L p .785 .982 .718 r
F P
0 g
s
.67823 .89787 m .63158 .90377 L .62342 .90583 L p .223 .744 .809 r
F P
0 g
s
.63158 .90377 m .67823 .89787 L .68417 .89569 L p .42 .856 .929 r
F P
0 g
s
.08249 .57583 m .06524 .53835 L .06632 .54458 L p 0 0 .511 r
F P
0 g
s
.06632 .54458 m .08454 .58793 L .08249 .57583 L p 0 0 .511 r
F P
0 g
s
.06632 .45542 m .08454 .41207 L .08683 .40397 L p 0 0 0 r
F P
0 g
s
.08454 .41207 m .06632 .45542 L .06524 .46165 L p 0 0 .089 r
F P
0 g
s
.64309 .10051 m .68417 .10431 L .67823 .10213 L p .42 0 0 r
F P
0 g
s
.67823 .10213 m .63158 .09623 L .64309 .10051 L p .42 0 0 r
F P
0 g
s
.75545 .14672 m .78388 .18417 L .78975 .1902 L p .665 .188 0 r
F P
0 g
s
.78388 .18417 m .75545 .14672 L .75059 .14266 L p .785 .299 0 r
F P
0 g
s
.49349 .4631 m .49616 .46874 L .50121 .47164 L p .299 .498 .884 r
F P
0 g
s
.49616 .46874 m .49349 .4631 L .488 .45997 L p .212 .438 .862 r
F P
0 g
s
.529 .48769 m .53521 .48719 L .52882 .48347 L p .441 .681 .966 r
F P
0 g
s
.52882 .48347 m .52396 .48477 L .529 .48769 L p .441 .681 .966 r
F P
0 g
s
.47484 .48104 m .4713 .47591 L .47127 .48331 L p .979 .732 .491 r
F P
0 g
s
.47127 .48331 m .47483 .48687 L .47484 .48104 L p .979 .732 .491 r
F P
0 g
s
.4713 .52409 m .47484 .51896 L .47483 .51313 L p .979 .866 .655 r
F P
0 g
s
.47484 .51896 m .4713 .52409 L .47133 .53041 L p .981 .899 .658 r
F P
0 g
s
.53521 .51281 m .529 .51231 L .52396 .51523 L p .441 .039 .18 r
F P
0 g
s
.529 .51231 m .53521 .51281 L .54067 .50963 L p .42 0 .094 r
F P
0 g
s
.49616 .53126 m .49349 .5369 L .49991 .53322 L p .299 0 .262 r
F P
0 g
s
.49991 .53322 m .50121 .52836 L .49616 .53126 L p .299 0 .262 r
F P
0 g
s
.55632 .49382 m .5724 .49455 L .56525 .49027 L p .414 .74 .992 r
F P
0 g
s
.56525 .49027 m .55083 .49057 L .55632 .49382 L p .414 .74 .992 r
F P
0 g
s
.488 .45997 m .48276 .45126 L .47719 .44814 L p .093 .357 .825 r
F P
0 g
s
.46852 .43457 m .47719 .44814 L .48276 .45126 L p .119 .359 .822 r
F P
0 g
s
.46649 .45432 m .45907 .44002 L .45895 .44836 L p .97 .652 .33 r
F P
0 g
s
.45895 .44836 m .46642 .4607 L .46649 .45432 L p .97 .652 .33 r
F P
0 g
s
.47133 .53041 m .46642 .5393 L .46649 .54568 L p .973 .928 .644 r
F P
0 g
s
.45907 .55998 m .46649 .54568 L .46642 .5393 L p .97 .931 .672 r
F P
0 g
s
.54067 .50963 m .55083 .50943 L .55632 .50618 L p .376 0 0 r
F P
0 g
s
.5724 .50545 m .55632 .50618 L .55083 .50943 L p .414 0 .009 r
F P
0 g
s
.47719 .55186 m .46852 .56543 L .4758 .56137 L p .119 0 .18 r
F P
0 g
s
.4758 .56137 m .48276 .54874 L .47719 .55186 L p .119 0 .18 r
F P
0 g
s
.48276 .45126 m .488 .45997 L .49349 .4631 L p .216 .438 .861 r
F P
0 g
s
.54067 .49037 m .55083 .49057 L .5438 .48644 L p .425 .707 .982 r
F P
0 g
s
.5438 .48644 m .53521 .48719 L .54067 .49037 L p .425 .707 .982 r
F P
0 g
s
.47133 .46959 m .46642 .4607 L .46636 .46885 L p .98 .702 .42 r
F P
0 g
s
.46636 .46885 m .4713 .47591 L .47133 .46959 L p .98 .702 .42 r
F P
0 g
s
.46642 .5393 m .47133 .53041 L .4713 .52409 L p .98 .899 .661 r
F P
0 g
s
.55083 .50943 m .54067 .50963 L .53521 .51281 L p .425 0 .1 r
F P
0 g
s
.488 .54003 m .48276 .54874 L .48984 .54471 L p .216 0 .22 r
F P
0 g
s
.48984 .54471 m .49349 .5369 L .488 .54003 L p .216 0 .22 r
F P
0 g
s
.46852 .43457 m .45753 .41404 L .451 .41057 L p 0 .233 .747 r
F P
0 g
s
.43673 .37743 m .451 .41057 L .45753 .41404 L p .035 .217 .721 r
F P
0 g
s
.60195 .49772 m .63779 .49351 L .62966 .48825 L p .518 .838 .999 r
F P
0 g
s
.62966 .48825 m .59568 .4938 L .60195 .49772 L p .518 .838 .999 r
F P
0 g
s
.44705 .41285 m .42549 .38392 L .42499 .39359 L p .917 .521 .211 r
F P
0 g
s
.42499 .39359 m .44679 .42024 L .44705 .41285 L p .917 .521 .211 r
F P
0 g
s
.45907 .55998 m .44679 .57976 L .44705 .58715 L p .936 .965 .684 r
F P
0 g
s
.42549 .61608 m .44705 .58715 L .44679 .57976 L p .917 .976 .768 r
F P
0 g
s
.5724 .50545 m .59568 .5062 L .60195 .50228 L p .402 0 0 r
F P
0 g
s
.63779 .50649 m .60195 .50228 L .59568 .5062 L p .518 .007 0 r
F P
0 g
s
.451 .58943 m .43673 .62257 L .44535 .61817 L p .035 0 .259 r
F P
0 g
s
.44535 .61817 m .45753 .58596 L .451 .58943 L p .035 0 .259 r
F P
0 g
s
.52396 .48477 m .52882 .48347 L .52177 .47938 L p .442 .652 .948 r
F P
0 g
s
.52177 .47938 m .5184 .48156 L .52396 .48477 L p .442 .652 .948 r
F P
0 g
s
.49991 .46678 m .50121 .47164 L .50677 .47484 L p .36 .545 .9 r
F P
0 g
s
.50121 .47164 m .49991 .46678 L .49349 .4631 L p .299 .498 .884 r
F P
0 g
s
.47483 .48687 m .47127 .48331 L .47126 .49146 L p .975 .757 .545 r
F P
0 g
s
.47126 .49146 m .47483 .49328 L .47483 .48687 L p .975 .757 .545 r
F P
0 g
s
.47127 .51669 m .47483 .51313 L .47483 .50672 L p .975 .835 .64 r
F P
0 g
s
.47483 .51313 m .47127 .51669 L .4713 .52409 L p .979 .866 .655 r
F P
0 g
s
.52882 .51653 m .52396 .51523 L .5184 .51844 L p .442 .071 .237 r
F P
0 g
s
.52396 .51523 m .52882 .51653 L .53521 .51281 L p .441 .039 .18 r
F P
0 g
s
.50121 .52836 m .49991 .53322 L .50698 .52916 L p .36 .042 .285 r
F P
0 g
s
.50698 .52916 m .50677 .52516 L .50121 .52836 L p .36 .042 .285 r
F P
0 g
s
.80388 .74568 m .78388 .81583 L .78975 .8098 L p .95 .938 .606 r
F P
0 g
s
.78975 .8098 m .81304 .7367 L .80388 .74568 L p .95 .938 .606 r
F P
0 g
s
.54846 .88945 m .62342 .90583 L .63158 .90377 L p .307 .716 .977 r
F P
0 g
s
.1353 .64033 m .08454 .58793 L .08683 .59603 L p 0 .273 .778 r
F P
0 g
s
.08683 .59603 m .13849 .65275 L .1353 .64033 L p 0 .273 .778 r
F P
0 g
s
.13849 .34725 m .08683 .40397 L .08454 .41207 L p 0 0 .036 r
F P
0 g
s
.56083 .11399 m .63158 .09623 L .62342 .09417 L p .307 0 0 r
F P
0 g
s
.62342 .09417 m .54846 .11055 L .56083 .11399 L p .307 0 0 r
F P
0 g
s
.81304 .2633 m .78975 .1902 L .78388 .18417 L p .95 .613 .208 r
F P
0 g
s
.50698 .47084 m .50677 .47484 L .51259 .4782 L p .402 .585 .915 r
F P
0 g
s
.50677 .47484 m .50698 .47084 L .49991 .46678 L p .36 .545 .9 r
F P
0 g
s
.5184 .48156 m .52177 .47938 L .51437 .4751 L p .429 .62 .931 r
F P
0 g
s
.51437 .4751 m .51259 .4782 L .5184 .48156 L p .429 .62 .931 r
F P
0 g
s
.47483 .49328 m .47126 .49146 L .47125 .5 L p .973 .782 .586 r
F P
0 g
s
.47125 .5 m .47483 .5 L .47483 .49328 L p .973 .782 .586 r
F P
0 g
s
.47126 .50854 m .47483 .50672 L .47483 .5 L p .973 .807 .617 r
F P
0 g
s
.47483 .50672 m .47126 .50854 L .47127 .51669 L p .975 .835 .64 r
F P
0 g
s
.52177 .52062 m .5184 .51844 L .51259 .5218 L p .429 .081 .271 r
F P
0 g
s
.5184 .51844 m .52177 .52062 L .52882 .51653 L p .442 .071 .237 r
F P
0 g
s
.50677 .52516 m .50698 .52916 L .51437 .5249 L p .402 .071 .287 r
F P
0 g
s
.51437 .5249 m .51259 .5218 L .50677 .52516 L p .402 .071 .287 r
F P
0 g
s
.51259 .4782 m .51437 .4751 L .50698 .47084 L p .402 .585 .915 r
F P
0 g
s
.47483 .5 m .47125 .5 L .47126 .50854 L p .973 .807 .617 r
F P
0 g
s
.51259 .5218 m .51437 .5249 L .52177 .52062 L p .429 .081 .271 r
F P
0 g
s
.48984 .45529 m .49349 .4631 L .49991 .46678 L p .303 .498 .883 r
F P
0 g
s
.49349 .4631 m .48984 .45529 L .48276 .45126 L p .216 .438 .861 r
F P
0 g
s
.53521 .48719 m .5438 .48644 L .53554 .48162 L p .446 .682 .965 r
F P
0 g
s
.53554 .48162 m .52882 .48347 L .53521 .48719 L p .446 .682 .965 r
F P
0 g
s
.4713 .47591 m .46636 .46885 L .46631 .47841 L p .978 .731 .493 r
F P
0 g
s
.46631 .47841 m .47127 .48331 L .4713 .47591 L p .978 .731 .493 r
F P
0 g
s
.46636 .53115 m .4713 .52409 L .47127 .51669 L p .978 .866 .658 r
F P
0 g
s
.4713 .52409 m .46636 .53115 L .46642 .5393 L p .98 .899 .661 r
F P
0 g
s
.5438 .51356 m .53521 .51281 L .52882 .51653 L p .446 .046 .186 r
F P
0 g
s
.53521 .51281 m .5438 .51356 L .55083 .50943 L p .425 0 .1 r
F P
0 g
s
.49349 .5369 m .48984 .54471 L .49815 .53997 L p .303 0 .268 r
F P
0 g
s
.49815 .53997 m .49991 .53322 L .49349 .5369 L p .303 0 .268 r
F P
0 g
s
.68417 .89569 m .64309 .89949 L .63158 .90377 L p .42 .856 .929 r
F P
0 g
s
.64309 .89949 m .68417 .89569 L .6915 .89249 L p .555 .905 .972 r
F P
0 g
s
.76176 .83294 m .74415 .86209 L .75059 .85734 L p .829 1 .814 r
F P
0 g
s
.75059 .85734 m .77442 .82366 L .76176 .83294 L p .829 1 .814 r
F P
0 g
s
.06524 .46165 m .08249 .42417 L .08454 .41207 L p 0 0 .089 r
F P
0 g
s
.08249 .42417 m .06524 .46165 L .06434 .4696 L p 0 0 .26 r
F P
0 g
s
.08078 .56022 m .06434 .5304 L .06524 .53835 L p 0 .023 .576 r
F P
0 g
s
.06524 .53835 m .08249 .57583 L .08078 .56022 L p 0 .023 .576 r
F P
0 g
s
.65746 .10684 m .6915 .10751 L .68417 .10431 L p .555 .002 0 r
F P
0 g
s
.68417 .10431 m .64309 .10051 L .65746 .10684 L p .555 .002 0 r
F P
0 g
s
.75059 .14266 m .77442 .17634 L .78388 .18417 L p .785 .299 0 r
F P
0 g
s
.77442 .17634 m .75059 .14266 L .74415 .13791 L p .829 .354 .023 r
F P
0 g
s
.5724 .49455 m .59568 .4938 L .58626 .4881 L p .485 .77 .994 r
F P
0 g
s
.58626 .4881 m .56525 .49027 L .5724 .49455 L p .485 .77 .994 r
F P
0 g
s
.48276 .45126 m .4758 .43863 L .46852 .43457 L p .119 .359 .822 r
F P
0 g
s
.45753 .41404 m .46852 .43457 L .4758 .43863 L p .166 .359 .81 r
F P
0 g
s
.45907 .44002 m .44679 .42024 L .44656 .43125 L p .959 .632 .353 r
F P
0 g
s
.44656 .43125 m .45895 .44836 L .45907 .44002 L p .959 .632 .353 r
F P
0 g
s
.46642 .5393 m .45895 .55164 L .45907 .55998 L p .97 .931 .672 r
F P
0 g
s
.44679 .57976 m .45907 .55998 L .45895 .55164 L p .959 .933 .721 r
F P
0 g
s
.55083 .50943 m .56525 .50973 L .5724 .50545 L p .414 0 .009 r
F P
0 g
s
.59568 .5062 m .5724 .50545 L .56525 .50973 L p .485 .023 .079 r
F P
0 g
s
.46852 .56543 m .45753 .58596 L .46718 .58065 L p .166 0 .264 r
F P
0 g
s
.46718 .58065 m .4758 .56137 L .46852 .56543 L p .166 0 .264 r
F P
0 g
s
.4758 .43863 m .48276 .45126 L .48984 .45529 L p .243 .441 .856 r
F P
0 g
s
.55083 .49057 m .56525 .49027 L .55605 .48484 L p .46 .72 .981 r
F P
0 g
s
.55605 .48484 m .5438 .48644 L .55083 .49057 L p .46 .72 .981 r
F P
0 g
s
.46642 .4607 m .45895 .44836 L .45884 .45904 L p .974 .693 .434 r
F P
0 g
s
.45884 .45904 m .46636 .46885 L .46642 .4607 L p .974 .693 .434 r
F P
0 g
s
.45895 .55164 m .46642 .5393 L .46636 .53115 L p .974 .897 .684 r
F P
0 g
s
.56525 .50973 m .55083 .50943 L .5438 .51356 L p .46 .031 .137 r
F P
0 g
s
.48276 .54874 m .4758 .56137 L .48511 .55612 L p .243 0 .262 r
F P
0 g
s
.48511 .55612 m .48984 .54471 L .48276 .54874 L p .243 0 .262 r
F P
0 g
s
.52882 .48347 m .53554 .48162 L .52643 .47633 L p .447 .653 .947 r
F P
0 g
s
.52643 .47633 m .52177 .47938 L .52882 .48347 L p .447 .653 .947 r
F P
0 g
s
.49815 .46003 m .49991 .46678 L .50698 .47084 L p .364 .546 .899 r
F P
0 g
s
.49991 .46678 m .49815 .46003 L .48984 .45529 L p .303 .498 .883 r
F P
0 g
s
.47127 .48331 m .46631 .47841 L .46629 .48895 L p .974 .756 .547 r
F P
0 g
s
.46629 .48895 m .47126 .49146 L .47127 .48331 L p .974 .756 .547 r
F P
0 g
s
.46631 .52159 m .47127 .51669 L .47126 .50854 L p .974 .835 .643 r
F P
0 g
s
.47127 .51669 m .46631 .52159 L .46636 .53115 L p .978 .866 .658 r
F P
0 g
s
.53554 .51838 m .52882 .51653 L .52177 .52062 L p .447 .077 .243 r
F P
0 g
s
.52882 .51653 m .53554 .51838 L .5438 .51356 L p .446 .046 .186 r
F P
0 g
s
.49991 .53322 m .49815 .53997 L .50729 .53472 L p .364 .049 .291 r
F P
0 g
s
.50729 .53472 m .50698 .52916 L .49991 .53322 L p .364 .049 .291 r
F P
0 g
s
.45753 .41404 m .44535 .38183 L .43673 .37743 L p .035 .217 .721 r
F P
0 g
s
.4258 .32585 m .43673 .37743 L .44535 .38183 L p .107 .187 .666 r
F P
0 g
s
.63779 .49351 m .68792 .47719 L .67774 .47017 L p .655 .893 .982 r
F P
0 g
s
.67774 .47017 m .62966 .48825 L .63779 .49351 L p .655 .893 .982 r
F P
0 g
s
.42549 .38392 m .38629 .34867 L .38529 .36099 L p .867 .45 .227 r
F P
0 g
s
.38529 .36099 m .42499 .39359 L .42549 .38392 L p .867 .45 .227 r
F P
0 g
s
.44679 .57976 m .42499 .60641 L .42549 .61608 L p .917 .976 .768 r
F P
0 g
s
.38629 .65133 m .42549 .61608 L .42499 .60641 L p .867 .966 .859 r
F P
0 g
s
.59568 .5062 m .62966 .51175 L .63779 .50649 L p .518 .007 0 r
F P
0 g
s
.68792 .52281 m .63779 .50649 L .62966 .51175 L p .655 .176 .104 r
F P
0 g
s
.43673 .62257 m .4258 .67415 L .43696 .66884 L p .107 0 .42 r
F P
0 g
s
.43696 .66884 m .44535 .61817 L .43673 .62257 L p .107 0 .42 r
F P
0 g
s
.50729 .46528 m .50698 .47084 L .51437 .4751 L p .406 .585 .914 r
F P
0 g
s
.50698 .47084 m .50729 .46528 L .49815 .46003 L p .364 .546 .899 r
F P
0 g
s
.52177 .47938 m .52643 .47633 L .51686 .47079 L p .433 .62 .93 r
F P
0 g
s
.51686 .47079 m .51437 .4751 L .52177 .47938 L p .433 .62 .93 r
F P
0 g
s
.47126 .49146 m .46629 .48895 L .46628 .5 L p .972 .78 .588 r
F P
0 g
s
.46628 .5 m .47125 .5 L .47126 .49146 L p .972 .78 .588 r
F P
0 g
s
.46629 .51105 m .47126 .50854 L .47125 .5 L p .972 .806 .619 r
F P
0 g
s
.47126 .50854 m .46629 .51105 L .46631 .52159 L p .974 .835 .643 r
F P
0 g
s
.52643 .52367 m .52177 .52062 L .51437 .5249 L p .433 .087 .277 r
F P
0 g
s
.52177 .52062 m .52643 .52367 L .53554 .51838 L p .447 .077 .243 r
F P
0 g
s
.50698 .52916 m .50729 .53472 L .51686 .52921 L p .406 .078 .293 r
F P
0 g
s
.51686 .52921 m .51437 .5249 L .50698 .52916 L p .406 .078 .293 r
F P
0 g
s
.51437 .4751 m .51686 .47079 L .50729 .46528 L p .406 .585 .914 r
F P
0 g
s
.47125 .5 m .46628 .5 L .46629 .51105 L p .972 .806 .619 r
F P
0 g
s
.51437 .5249 m .51686 .52921 L .52643 .52367 L p .433 .087 .277 r
F P
0 g
s
.74645 .84327 m .73641 .86734 L .74415 .86209 L p .831 .989 .867 r
F P
0 g
s
.74415 .86209 m .76176 .83294 L .74645 .84327 L p .831 .989 .867 r
F P
0 g
s
.6915 .89249 m .65746 .89316 L .64309 .89949 L p .555 .905 .972 r
F P
0 g
s
.65746 .89316 m .6915 .89249 L .69992 .88841 L p .645 .924 .975 r
F P
0 g
s
.06434 .4696 m .08078 .43978 L .08249 .42417 L p 0 0 .26 r
F P
0 g
s
.08078 .43978 m .06434 .4696 L .06367 .47893 L p 0 0 .38 r
F P
0 g
s
.07949 .5418 m .06367 .52107 L .06434 .5304 L p 0 .078 .596 r
F P
0 g
s
.06434 .5304 m .08078 .56022 L .07949 .5418 L p 0 .078 .596 r
F P
0 g
s
.74415 .13791 m .76176 .16706 L .77442 .17634 L p .829 .354 .023 r
F P
0 g
s
.76176 .16706 m .74415 .13791 L .73641 .13266 L p .831 .369 .109 r
F P
0 g
s
.67405 .11493 m .69992 .11159 L .6915 .10751 L p .645 .129 .001 r
F P
0 g
s
.6915 .10751 m .65746 .10684 L .67405 .11493 L p .645 .129 .001 r
F P
0 g
s
.5438 .48644 m .55605 .48484 L .54522 .47849 L p .477 .691 .961 r
F P
0 g
s
.54522 .47849 m .53554 .48162 L .5438 .48644 L p .477 .691 .961 r
F P
0 g
s
.48511 .44388 m .48984 .45529 L .49815 .46003 L p .33 .501 .876 r
F P
0 g
s
.48984 .45529 m .48511 .44388 L .4758 .43863 L p .243 .441 .856 r
F P
0 g
s
.46636 .46885 m .45884 .45904 L .45877 .4716 L p .969 .722 .507 r
F P
0 g
s
.45877 .4716 m .46631 .47841 L .46636 .46885 L p .969 .722 .507 r
F P
0 g
s
.45884 .54096 m .46636 .53115 L .46631 .52159 L p .969 .861 .677 r
F P
0 g
s
.46636 .53115 m .45884 .54096 L .45895 .55164 L p .974 .897 .684 r
F P
0 g
s
.55605 .51516 m .5438 .51356 L .53554 .51838 L p .477 .088 .222 r
F P
0 g
s
.5438 .51356 m .55605 .51516 L .56525 .50973 L p .46 .031 .137 r
F P
0 g
s
.48984 .54471 m .48511 .55612 L .49602 .54991 L p .33 .037 .307 r
F P
0 g
s
.49602 .54991 m .49815 .53997 L .48984 .54471 L p .33 .037 .307 r
F P
0 g
s
.4758 .43863 m .46718 .41935 L .45753 .41404 L p .166 .359 .81 r
F P
0 g
s
.44535 .38183 m .45753 .41404 L .46718 .41935 L p .232 .354 .782 r
F P
0 g
s
.59568 .4938 m .62966 .48825 L .61728 .48059 L p .581 .804 .984 r
F P
0 g
s
.61728 .48059 m .58626 .4881 L .59568 .4938 L p .581 .804 .984 r
F P
0 g
s
.44679 .42024 m .42499 .39359 L .42455 .40814 L p .93 .595 .379 r
F P
0 g
s
.42455 .40814 m .44656 .43125 L .44679 .42024 L p .93 .595 .379 r
F P
0 g
s
.45895 .55164 m .44656 .56875 L .44679 .57976 L p .959 .933 .721 r
F P
0 g
s
.42499 .60641 m .44679 .57976 L .44656 .56875 L p .93 .924 .783 r
F P
0 g
s
.56525 .50973 m .58626 .5119 L .59568 .5062 L p .485 .023 .079 r
F P
0 g
s
.62966 .51175 m .59568 .5062 L .58626 .5119 L p .581 .145 .178 r
F P
0 g
s
.45753 .58596 m .44535 .61817 L .45817 .61127 L p .232 .025 .379 r
F P
0 g
s
.45817 .61127 m .46718 .58065 L .45753 .58596 L p .232 .025 .379 r
F P
0 g
s
.46718 .41935 m .4758 .43863 L .48511 .44388 L p .292 .443 .841 r
F P
0 g
s
.56525 .49027 m .58626 .4881 L .57408 .48085 L p .521 .739 .974 r
F P
0 g
s
.57408 .48085 m .55605 .48484 L .56525 .49027 L p .521 .739 .974 r
F P
0 g
s
.45895 .44836 m .44656 .43125 L .44637 .44542 L p .957 .673 .457 r
F P
0 g
s
.44637 .44542 m .45884 .45904 L .45895 .44836 L p .957 .673 .457 r
F P
0 g
s
.44656 .56875 m .45895 .55164 L .45884 .54096 L p .957 .889 .722 r
F P
0 g
s
.58626 .5119 m .56525 .50973 L .55605 .51516 L p .521 .112 .206 r
F P
0 g
s
.4758 .56137 m .46718 .58065 L .47954 .57373 L p .292 .033 .338 r
F P
0 g
s
.47954 .57373 m .48511 .55612 L .4758 .56137 L p .292 .033 .338 r
F P
0 g
s
.72919 .85416 m .72771 .87285 L .73641 .86734 L p .814 .971 .9 r
F P
0 g
s
.73641 .86734 m .74645 .84327 L .72919 .85416 L p .814 .971 .9 r
F P
0 g
s
.69992 .88841 m .67405 .88507 L .65746 .89316 L p .645 .924 .975 r
F P
0 g
s
.67405 .88507 m .69992 .88841 L .70904 .88362 L p .706 .933 .963 r
F P
0 g
s
.0787 .52141 m .06325 .51078 L .06367 .52107 L p .057 .098 .588 r
F P
0 g
s
.06367 .52107 m .07949 .5418 L .0787 .52141 L p .057 .098 .588 r
F P
0 g
s
.06367 .47893 m .07949 .4582 L .08078 .43978 L p 0 0 .38 r
F P
0 g
s
.07949 .4582 m .06367 .47893 L .06325 .48922 L p .057 0 .463 r
F P
0 g
s
.69211 .12444 m .70904 .11638 L .69992 .11159 L p .706 .22 .089 r
F P
0 g
s
.69992 .11159 m .67405 .11493 L .69211 .12444 L p .706 .22 .089 r
F P
0 g
s
.73641 .13266 m .74645 .15673 L .76176 .16706 L p .831 .369 .109 r
F P
0 g
s
.74645 .15673 m .73641 .13266 L .72771 .12715 L p .814 .359 .151 r
F P
0 g
s
.49602 .45009 m .49815 .46003 L .50729 .46528 L p .39 .549 .892 r
F P
0 g
s
.49815 .46003 m .49602 .45009 L .48511 .44388 L p .33 .501 .876 r
F P
0 g
s
.53554 .48162 m .54522 .47849 L .53323 .47152 L p .475 .659 .941 r
F P
0 g
s
.53323 .47152 m .52643 .47633 L .53554 .48162 L p .475 .659 .941 r
F P
0 g
s
.46631 .47841 m .45877 .4716 L .45872 .48546 L p .964 .747 .561 r
F P
0 g
s
.45872 .48546 m .46629 .48895 L .46631 .47841 L p .964 .747 .561 r
F P
0 g
s
.45877 .5284 m .46631 .52159 L .46629 .51105 L p .964 .828 .659 r
F P
0 g
s
.46631 .52159 m .45877 .5284 L .45884 .54096 L p .969 .861 .677 r
F P
0 g
s
.54522 .52151 m .53554 .51838 L .52643 .52367 L p .475 .117 .278 r
F P
0 g
s
.53554 .51838 m .54522 .52151 L .55605 .51516 L p .477 .088 .222 r
F P
0 g
s
.49815 .53997 m .49602 .54991 L .50805 .54302 L p .39 .088 .328 r
F P
0 g
s
.50805 .54302 m .50729 .53472 L .49815 .53997 L p .39 .088 .328 r
F P
0 g
s
.44535 .38183 m .43696 .33116 L .4258 .32585 L p .107 .187 .666 r
F P
0 g
s
.43168 .2519 m .4258 .32585 L .43696 .33116 L p .183 .14 .571 r
F P
0 g
s
.68792 .47719 m .74903 .43512 L .73733 .42615 L p .793 .926 .924 r
F P
0 g
s
.73733 .42615 m .67774 .47017 L .68792 .47719 L p .793 .926 .924 r
F P
0 g
s
.38629 .34867 m .3193 .31678 L .31738 .33139 L p .773 .344 .231 r
F P
0 g
s
.31738 .33139 m .38529 .36099 L .38629 .34867 L p .773 .344 .231 r
F P
0 g
s
.62966 .51175 m .67774 .52983 L .68792 .52281 L p .655 .176 .104 r
F P
0 g
s
.74903 .56488 m .68792 .52281 L .67774 .52983 L p .793 .369 .242 r
F P
0 g
s
.42499 .60641 m .38529 .63901 L .38629 .65133 L p .867 .966 .859 r
F P
0 g
s
.3193 .68322 m .38629 .65133 L .38529 .63901 L p .773 .919 .935 r
F P
0 g
s
.4258 .67415 m .43168 .7481 L .44529 .74246 L p .183 .158 .594 r
F P
0 g
s
.44529 .74246 m .43696 .66884 L .4258 .67415 L p .183 .158 .594 r
F P
0 g
s
.78885 .65262 m .80388 .74568 L .81304 .7367 L p .991 .775 .514 r
F P
0 g
s
.81304 .7367 m .80034 .64252 L .78885 .65262 L p .991 .775 .514 r
F P
0 g
s
.47326 .83136 m .54846 .88945 L .56083 .88601 L p .302 .538 .912 r
F P
0 g
s
.63158 .90377 m .56083 .88601 L .54846 .88945 L p .307 .716 .977 r
F P
0 g
s
.2264 .31116 m .13849 .34725 L .1353 .35967 L p .374 0 .158 r
F P
0 g
s
.08454 .41207 m .1353 .35967 L .13849 .34725 L p 0 0 .036 r
F P
0 g
s
.22341 .67384 m .1353 .64033 L .13849 .65275 L p .374 .63 .953 r
F P
0 g
s
.13849 .65275 m .2264 .68884 L .22341 .67384 L p .374 .63 .953 r
F P
0 g
s
.48775 .17354 m .56083 .11399 L .54846 .11055 L p .302 0 .2 r
F P
0 g
s
.54846 .11055 m .47326 .16864 L .48775 .17354 L p .302 0 .2 r
F P
0 g
s
.80034 .35748 m .81304 .2633 L .80388 .25432 L p .991 .843 .597 r
F P
0 g
s
.78388 .18417 m .80388 .25432 L .81304 .2633 L p .95 .613 .208 r
F P
0 g
s
.71079 .86509 m .71844 .87836 L .72771 .87285 L p .787 .954 .925 r
F P
0 g
s
.72771 .87285 m .72919 .85416 L .71079 .86509 L p .787 .954 .925 r
F P
0 g
s
.70904 .88362 m .69211 .87556 L .67405 .88507 L p .706 .933 .963 r
F P
0 g
s
.69211 .87556 m .70904 .88362 L .71844 .87836 L p .751 .942 .945 r
F P
0 g
s
.06325 .48922 m .0787 .47859 L .07949 .4582 L p .057 0 .463 r
F P
0 g
s
.0787 .47859 m .06325 .48922 L .06311 .5 L p .089 .056 .522 r
F P
0 g
s
.07842 .5 m .06311 .5 L .06325 .51078 L p .089 .09 .563 r
F P
0 g
s
.06325 .51078 m .0787 .52141 L .07842 .5 L p .089 .09 .563 r
F P
0 g
s
.72771 .12715 m .72919 .14584 L .74645 .15673 L p .814 .359 .151 r
F P
0 g
s
.72919 .14584 m .72771 .12715 L .71844 .12164 L p .787 .33 .16 r
F P
0 g
s
.71079 .13491 m .71844 .12164 L .70904 .11638 L p .751 .285 .14 r
F P
0 g
s
.70904 .11638 m .69211 .12444 L .71079 .13491 L p .751 .285 .14 r
F P
0 g
s
.7889 .75765 m .77442 .82366 L .78388 .81583 L p .957 .924 .73 r
F P
0 g
s
.78388 .81583 m .80388 .74568 L .7889 .75765 L p .957 .924 .73 r
F P
0 g
s
.56083 .88601 m .63158 .90377 L .64309 .89949 L p .506 .768 .99 r
F P
0 g
s
.1353 .35967 m .08454 .41207 L .08249 .42417 L p .204 0 .295 r
F P
0 g
s
.13242 .62137 m .08249 .57583 L .08454 .58793 L p .204 .379 .816 r
F P
0 g
s
.08454 .58793 m .1353 .64033 L .13242 .62137 L p .204 .379 .816 r
F P
0 g
s
.57868 .12098 m .64309 .10051 L .63158 .09623 L p .506 .058 .121 r
F P
0 g
s
.63158 .09623 m .56083 .11399 L .57868 .12098 L p .506 .058 .121 r
F P
0 g
s
.80388 .25432 m .78388 .18417 L .77442 .17634 L p .957 .639 .381 r
F P
0 g
s
.50805 .45698 m .50729 .46528 L .51686 .47079 L p .432 .589 .907 r
F P
0 g
s
.50729 .46528 m .50805 .45698 L .49602 .45009 L p .39 .549 .892 r
F P
0 g
s
.52643 .47633 m .53323 .47152 L .52065 .46424 L p .46 .625 .923 r
F P
0 g
s
.52065 .46424 m .51686 .47079 L .52643 .47633 L p .46 .625 .923 r
F P
0 g
s
.46629 .48895 m .45872 .48546 L .4587 .5 L p .961 .772 .602 r
F P
0 g
s
.4587 .5 m .46628 .5 L .46629 .48895 L p .961 .772 .602 r
F P
0 g
s
.45872 .51454 m .46629 .51105 L .46628 .5 L p .961 .798 .634 r
F P
0 g
s
.46629 .51105 m .45872 .51454 L .45877 .5284 L p .964 .828 .659 r
F P
0 g
s
.53323 .52848 m .52643 .52367 L .51686 .52921 L p .46 .126 .312 r
F P
0 g
s
.52643 .52367 m .53323 .52848 L .54522 .52151 L p .475 .117 .278 r
F P
0 g
s
.50729 .53472 m .50805 .54302 L .52065 .53576 L p .432 .116 .328 r
F P
0 g
s
.52065 .53576 m .51686 .52921 L .50729 .53472 L p .432 .116 .328 r
F P
0 g
s
.71844 .87836 m .71079 .86509 L .69211 .87556 L p .751 .942 .945 r
F P
0 g
s
.06311 .5 m .07842 .5 L .0787 .47859 L p .089 .056 .522 r
F P
0 g
s
.71844 .12164 m .71079 .13491 L .72919 .14584 L p .787 .33 .16 r
F P
0 g
s
.51686 .47079 m .52065 .46424 L .50805 .45698 L p .432 .589 .907 r
F P
0 g
s
.46628 .5 m .4587 .5 L .45872 .51454 L p .961 .798 .634 r
F P
0 g
s
.51686 .52921 m .52065 .53576 L .53323 .52848 L p .46 .126 .312 r
F P
0 g
s
.47954 .42627 m .48511 .44388 L .49602 .45009 L p .376 .504 .86 r
F P
0 g
s
.48511 .44388 m .47954 .42627 L .46718 .41935 L p .292 .443 .841 r
F P
0 g
s
.55605 .48484 m .57408 .48085 L .55968 .47237 L p .531 .703 .95 r
F P
0 g
s
.55968 .47237 m .54522 .47849 L .55605 .48484 L p .531 .703 .95 r
F P
0 g
s
.45884 .45904 m .44637 .44542 L .44623 .46213 L p .949 .702 .53 r
F P
0 g
s
.44623 .46213 m .45877 .4716 L .45884 .45904 L p .949 .702 .53 r
F P
0 g
s
.44637 .55458 m .45884 .54096 L .45877 .5284 L p .949 .848 .708 r
F P
0 g
s
.45884 .54096 m .44637 .55458 L .44656 .56875 L p .957 .889 .722 r
F P
0 g
s
.57408 .51915 m .55605 .51516 L .54522 .52151 L p .531 .163 .288 r
F P
0 g
s
.55605 .51516 m .57408 .51915 L .58626 .5119 L p .521 .112 .206 r
F P
0 g
s
.48511 .55612 m .47954 .57373 L .49408 .5655 L p .376 .11 .377 r
F P
0 g
s
.49408 .5655 m .49602 .54991 L .48511 .55612 L p .376 .11 .377 r
F P
0 g
s
.43696 .33116 m .44529 .25754 L .43168 .2519 L p .183 .14 .571 r
F P
0 g
s
.47326 .16864 m .43168 .2519 L .44529 .25754 L p .251 .068 .427 r
F P
0 g
s
.74903 .43512 m .80034 .35748 L .78885 .34738 L p .912 .919 .808 r
F P
0 g
s
.78885 .34738 m .73733 .42615 L .74903 .43512 L p .912 .919 .808 r
F P
0 g
s
.3193 .31678 m .2264 .31116 L .22341 .32616 L p .621 .195 .213 r
F P
0 g
s
.22341 .32616 m .31738 .33139 L .3193 .31678 L p .621 .195 .213 r
F P
0 g
s
.67774 .52983 m .73733 .57385 L .74903 .56488 L p .793 .369 .242 r
F P
0 g
s
.80034 .64252 m .74903 .56488 L .73733 .57385 L p .912 .571 .382 r
F P
0 g
s
.38529 .63901 m .31738 .66861 L .3193 .68322 L p .773 .919 .935 r
F P
0 g
s
.2264 .68884 m .3193 .68322 L .31738 .66861 L p .621 .818 .976 r
F P
0 g
s
.43168 .7481 m .47326 .83136 L .48775 .82646 L p .251 .343 .763 r
F P
0 g
s
.48775 .82646 m .44529 .74246 L .43168 .7481 L p .251 .343 .763 r
F P
0 g
s
.73733 .57385 m .78885 .65262 L .80034 .64252 L p .912 .571 .382 r
F P
0 g
s
.44529 .25754 m .48775 .17354 L .47326 .16864 L p .251 .068 .427 r
F P
0 g
s
.80388 .25432 m .78885 .34738 L .80034 .35748 L p .991 .843 .597 r
F P
0 g
s
.1353 .35967 m .22341 .32616 L .2264 .31116 L p .374 0 .158 r
F P
0 g
s
.56083 .88601 m .48775 .82646 L .47326 .83136 L p .302 .538 .912 r
F P
0 g
s
.31738 .66861 m .22341 .67384 L .2264 .68884 L p .621 .818 .976 r
F P
0 g
s
.62966 .48825 m .67774 .47017 L .66191 .46 L p .685 .829 .952 r
F P
0 g
s
.66191 .46 m .61728 .48059 L .62966 .48825 L p .685 .829 .952 r
F P
0 g
s
.46718 .41935 m .45817 .38873 L .44535 .38183 L p .232 .354 .782 r
F P
0 g
s
.43696 .33116 m .44535 .38183 L .45817 .38873 L p .305 .339 .733 r
F P
0 g
s
.42499 .39359 m .38529 .36099 L .3844 .37978 L p .876 .536 .403 r
F P
0 g
s
.3844 .37978 m .42455 .40814 L .42499 .39359 L p .876 .536 .403 r
F P
0 g
s
.44656 .56875 m .42455 .59186 L .42499 .60641 L p .93 .924 .783 r
F P
0 g
s
.38529 .63901 m .42499 .60641 L .42455 .59186 L p .876 .895 .842 r
F P
0 g
s
.58626 .5119 m .61728 .51941 L .62966 .51175 L p .581 .145 .178 r
F P
0 g
s
.67774 .52983 m .62966 .51175 L .61728 .51941 L p .685 .29 .292 r
F P
0 g
s
.44535 .61817 m .43696 .66884 L .45368 .66022 L p .305 .159 .512 r
F P
0 g
s
.45368 .66022 m .45817 .61127 L .44535 .61817 L p .305 .159 .512 r
F P
0 g
s
.45817 .38873 m .46718 .41935 L .47954 .42627 L p .354 .442 .812 r
F P
0 g
s
.58626 .4881 m .61728 .48059 L .60114 .47085 L p .6 .758 .954 r
F P
0 g
s
.60114 .47085 m .57408 .48085 L .58626 .4881 L p .6 .758 .954 r
F P
0 g
s
.44656 .43125 m .42455 .40814 L .42418 .42698 L p .923 .638 .484 r
F P
0 g
s
.42418 .42698 m .44637 .44542 L .44656 .43125 L p .923 .638 .484 r
F P
0 g
s
.42455 .59186 m .44656 .56875 L .44637 .55458 L p .923 .869 .768 r
F P
0 g
s
.61728 .51941 m .58626 .5119 L .57408 .51915 L p .6 .222 .298 r
F P
0 g
s
.46718 .58065 m .45817 .61127 L .47467 .60217 L p .354 .137 .44 r
F P
0 g
s
.47467 .60217 m .47954 .57373 L .46718 .58065 L p .354 .137 .44 r
F P
0 g
s
.49408 .4345 m .49602 .45009 L .50805 .45698 L p .435 .553 .876 r
F P
0 g
s
.49602 .45009 m .49408 .4345 L .47954 .42627 L p .376 .504 .86 r
F P
0 g
s
.54522 .47849 m .55968 .47237 L .54372 .46306 L p .525 .667 .927 r
F P
0 g
s
.54372 .46306 m .53323 .47152 L .54522 .47849 L p .525 .667 .927 r
F P
0 g
s
.45877 .4716 m .44623 .46213 L .44615 .48061 L p .943 .728 .583 r
F P
0 g
s
.44615 .48061 m .45872 .48546 L .45877 .4716 L p .943 .728 .583 r
F P
0 g
s
.44623 .53787 m .45877 .5284 L .45872 .51454 L p .943 .812 .686 r
F P
0 g
s
.45877 .5284 m .44623 .53787 L .44637 .55458 L p .949 .848 .708 r
F P
0 g
s
.55968 .52763 m .54522 .52151 L .53323 .52848 L p .525 .189 .341 r
F P
0 g
s
.54522 .52151 m .55968 .52763 L .57408 .51915 L p .531 .163 .288 r
F P
0 g
s
.49602 .54991 m .49408 .5655 L .51013 .55634 L p .435 .158 .393 r
F P
0 g
s
.51013 .55634 m .50805 .54302 L .49602 .54991 L p .435 .158 .393 r
F P
0 g
s
.53323 .47152 m .54372 .46306 L .52694 .45333 L p .506 .631 .908 r
F P
0 g
s
.52694 .45333 m .52065 .46424 L .53323 .47152 L p .506 .631 .908 r
F P
0 g
s
.51013 .44366 m .50805 .45698 L .52065 .46424 L p .477 .594 .891 r
F P
0 g
s
.50805 .45698 m .51013 .44366 L .49408 .4345 L p .435 .553 .876 r
F P
0 g
s
.45872 .48546 m .44615 .48061 L .44612 .5 L p .939 .753 .624 r
F P
0 g
s
.44612 .5 m .4587 .5 L .45872 .48546 L p .939 .753 .624 r
F P
0 g
s
.44615 .51939 m .45872 .51454 L .4587 .5 L p .939 .781 .658 r
F P
0 g
s
.45872 .51454 m .44615 .51939 L .44623 .53787 L p .943 .812 .686 r
F P
0 g
s
.54372 .53694 m .53323 .52848 L .52065 .53576 L p .506 .196 .374 r
F P
0 g
s
.53323 .52848 m .54372 .53694 L .55968 .52763 L p .525 .189 .341 r
F P
0 g
s
.50805 .54302 m .51013 .55634 L .52694 .54667 L p .477 .186 .391 r
F P
0 g
s
.52694 .54667 m .52065 .53576 L .50805 .54302 L p .477 .186 .391 r
F P
0 g
s
.76868 .77211 m .76176 .83294 L .77442 .82366 L p .918 .882 .782 r
F P
0 g
s
.77442 .82366 m .7889 .75765 L .76868 .77211 L p .918 .882 .782 r
F P
0 g
s
.64309 .89949 m .57868 .87902 L .56083 .88601 L p .506 .768 .99 r
F P
0 g
s
.57868 .87902 m .64309 .89949 L .65746 .89316 L p .612 .776 .959 r
F P
0 g
s
.08249 .42417 m .13242 .37863 L .1353 .35967 L p .204 0 .295 r
F P
0 g
s
.13242 .37863 m .08249 .42417 L .08078 .43978 L p .332 .127 .444 r
F P
0 g
s
.13 .59663 m .08078 .56022 L .08249 .57583 L p .332 .415 .798 r
F P
0 g
s
.08249 .57583 m .13242 .62137 L .13 .59663 L p .332 .415 .798 r
F P
0 g
s
.60132 .13126 m .65746 .10684 L .64309 .10051 L p .612 .223 .282 r
F P
0 g
s
.64309 .10051 m .57868 .12098 L .60132 .13126 L p .612 .223 .282 r
F P
0 g
s
.77442 .17634 m .7889 .24235 L .80388 .25432 L p .957 .639 .381 r
F P
0 g
s
.7889 .24235 m .77442 .17634 L .76176 .16706 L p .918 .618 .459 r
F P
0 g
s
.52065 .46424 m .52694 .45333 L .51013 .44366 L p .477 .594 .891 r
F P
0 g
s
.4587 .5 m .44612 .5 L .44615 .51939 L p .939 .781 .658 r
F P
0 g
s
.52065 .53576 m .52694 .54667 L .54372 .53694 L p .506 .196 .374 r
F P
0 g
s
.47467 .39783 m .47954 .42627 L .49408 .4345 L p .435 .504 .831 r
F P
0 g
s
.47954 .42627 m .47467 .39783 L .45817 .38873 L p .354 .442 .812 r
F P
0 g
s
.57408 .48085 m .60114 .47085 L .58197 .45946 L p .599 .714 .925 r
F P
0 g
s
.58197 .45946 m .55968 .47237 L .57408 .48085 L p .599 .714 .925 r
F P
0 g
s
.44637 .44542 m .42418 .42698 L .42391 .44928 L p .913 .669 .555 r
F P
0 g
s
.42391 .44928 m .44623 .46213 L .44637 .44542 L p .913 .669 .555 r
F P
0 g
s
.42418 .57302 m .44637 .55458 L .44623 .53787 L p .913 .823 .743 r
F P
0 g
s
.44637 .55458 m .42418 .57302 L .42455 .59186 L p .923 .869 .768 r
F P
0 g
s
.60114 .52915 m .57408 .51915 L .55968 .52763 L p .599 .264 .373 r
F P
0 g
s
.57408 .51915 m .60114 .52915 L .61728 .51941 L p .6 .222 .298 r
F P
0 g
s
.47954 .57373 m .47467 .60217 L .49412 .59126 L p .435 .207 .468 r
F P
0 g
s
.49412 .59126 m .49408 .5655 L .47954 .57373 L p .435 .207 .468 r
F P
0 g
s
.45817 .38873 m .45368 .33978 L .43696 .33116 L p .305 .339 .733 r
F P
0 g
s
.44529 .25754 m .43696 .33116 L .45368 .33978 L p .375 .312 .658 r
F P
0 g
s
.67774 .47017 m .73733 .42615 L .71867 .41338 L p .783 .837 .893 r
F P
0 g
s
.71867 .41338 m .66191 .46 L .67774 .47017 L p .783 .837 .893 r
F P
0 g
s
.38529 .36099 m .31738 .33139 L .31565 .35394 L p .795 .457 .415 r
F P
0 g
s
.31565 .35394 m .3844 .37978 L .38529 .36099 L p .795 .457 .415 r
F P
0 g
s
.42455 .59186 m .3844 .62022 L .38529 .63901 L p .876 .895 .842 r
F P
0 g
s
.31738 .66861 m .38529 .63901 L .3844 .62022 L p .795 .841 .887 r
F P
0 g
s
.61728 .51941 m .66191 .54 L .67774 .52983 L p .685 .29 .292 r
F P
0 g
s
.73733 .57385 m .67774 .52983 L .66191 .54 L p .783 .442 .409 r
F P
0 g
s
.43696 .66884 m .44529 .74246 L .46568 .73269 L p .375 .301 .644 r
F P
0 g
s
.46568 .73269 m .45368 .66022 L .43696 .66884 L p .375 .301 .644 r
F P
0 g
s
.77011 .66656 m .7889 .75765 L .80388 .74568 L p .936 .753 .63 r
F P
0 g
s
.80388 .74568 m .78885 .65262 L .77011 .66656 L p .936 .753 .63 r
F P
0 g
s
.48775 .82646 m .56083 .88601 L .57868 .87902 L p .485 .598 .89 r
F P
0 g
s
.22341 .32616 m .1353 .35967 L .13242 .37863 L p .509 .203 .383 r
F P
0 g
s
.2207 .65064 m .13242 .62137 L .1353 .64033 L p .509 .628 .904 r
F P
0 g
s
.1353 .64033 m .22341 .67384 L .2207 .65064 L p .509 .628 .904 r
F P
0 g
s
.50919 .1828 m .57868 .12098 L .56083 .11399 L p .485 .195 .397 r
F P
0 g
s
.56083 .11399 m .48775 .17354 L .50919 .1828 L p .485 .195 .397 r
F P
0 g
s
.78885 .34738 m .80388 .25432 L .7889 .24235 L p .936 .776 .657 r
F P
0 g
s
.61728 .48059 m .66191 .46 L .64106 .4471 L p .683 .769 .916 r
F P
0 g
s
.64106 .4471 m .60114 .47085 L .61728 .48059 L p .683 .769 .916 r
F P
0 g
s
.45368 .33978 m .45817 .38873 L .47467 .39783 L p .421 .432 .765 r
F P
0 g
s
.42455 .40814 m .3844 .37978 L .38366 .40429 L p .869 .586 .507 r
F P
0 g
s
.38366 .40429 m .42418 .42698 L .42455 .40814 L p .869 .586 .507 r
F P
0 g
s
.3844 .62022 m .42455 .59186 L .42418 .57302 L p .869 .833 .809 r
F P
0 g
s
.66191 .54 m .61728 .51941 L .60114 .52915 L p .683 .346 .399 r
F P
0 g
s
.45817 .61127 m .45368 .66022 L .47528 .64861 L p .421 .256 .55 r
F P
0 g
s
.47528 .64861 m .47467 .60217 L .45817 .61127 L p .421 .256 .55 r
F P
0 g
s
.7441 .78841 m .74645 .84327 L .76176 .83294 L p .876 .845 .811 r
F P
0 g
s
.76176 .83294 m .76868 .77211 L .7441 .78841 L p .876 .845 .811 r
F P
0 g
s
.65746 .89316 m .60132 .86874 L .57868 .87902 L p .612 .776 .959 r
F P
0 g
s
.60132 .86874 m .65746 .89316 L .67405 .88507 L p .677 .777 .926 r
F P
0 g
s
.08078 .43978 m .13 .40337 L .13242 .37863 L p .332 .127 .444 r
F P
0 g
s
.13 .40337 m .08078 .43978 L .07949 .4582 L p .401 .233 .537 r
F P
0 g
s
.12818 .56719 m .07949 .5418 L .08078 .56022 L p .401 .421 .766 r
F P
0 g
s
.08078 .56022 m .13 .59663 L .12818 .56719 L p .401 .421 .766 r
F P
0 g
s
.62772 .1444 m .67405 .11493 L .65746 .10684 L p .677 .329 .377 r
F P
0 g
s
.65746 .10684 m .60132 .13126 L .62772 .1444 L p .677 .329 .377 r
F P
0 g
s
.76176 .16706 m .76868 .22789 L .7889 .24235 L p .918 .618 .459 r
F P
0 g
s
.76868 .22789 m .76176 .16706 L .74645 .15673 L p .876 .585 .492 r
F P
0 g
s
.49412 .40874 m .49408 .4345 L .51013 .44366 L p .492 .553 .846 r
F P
0 g
s
.49408 .4345 m .49412 .40874 L .47467 .39783 L p .435 .504 .831 r
F P
0 g
s
.55968 .47237 m .58197 .45946 L .56063 .44695 L p .586 .673 .9 r
F P
0 g
s
.56063 .44695 m .54372 .46306 L .55968 .47237 L p .586 .673 .9 r
F P
0 g
s
.44623 .46213 m .42391 .44928 L .42374 .47402 L p .906 .696 .607 r
F P
0 g
s
.42374 .47402 m .44615 .48061 L .44623 .46213 L p .906 .696 .607 r
F P
0 g
s
.42391 .55072 m .44623 .53787 L .44615 .51939 L p .906 .784 .715 r
F P
0 g
s
.44623 .53787 m .42391 .55072 L .42418 .57302 L p .913 .823 .743 r
F P
0 g
s
.58197 .54054 m .55968 .52763 L .54372 .53694 L p .586 .283 .422 r
F P
0 g
s
.55968 .52763 m .58197 .54054 L .60114 .52915 L p .599 .264 .373 r
F P
0 g
s
.49408 .5655 m .49412 .59126 L .51563 .57904 L p .492 .251 .476 r
F P
0 g
s
.51563 .57904 m .51013 .55634 L .49408 .5655 L p .492 .251 .476 r
F P
0 g
s
.51563 .42096 m .51013 .44366 L .52694 .45333 L p .533 .595 .862 r
F P
0 g
s
.51013 .44366 m .51563 .42096 L .49412 .40874 L p .492 .553 .846 r
F P
0 g
s
.54372 .46306 m .56063 .44695 L .53816 .4339 L p .564 .634 .879 r
F P
0 g
s
.53816 .4339 m .52694 .45333 L .54372 .46306 L p .564 .634 .879 r
F P
0 g
s
.44615 .48061 m .42374 .47402 L .42368 .5 L p .902 .722 .649 r
F P
0 g
s
.42368 .5 m .44612 .5 L .44615 .48061 L p .902 .722 .649 r
F P
0 g
s
.42374 .52598 m .44615 .51939 L .44612 .5 L p .902 .751 .684 r
F P
0 g
s
.44615 .51939 m .42374 .52598 L .42391 .55072 L p .906 .784 .715 r
F P
0 g
s
.56063 .55305 m .54372 .53694 L .52694 .54667 L p .564 .286 .453 r
F P
0 g
s
.54372 .53694 m .56063 .55305 L .58197 .54054 L p .586 .283 .422 r
F P
0 g
s
.51013 .55634 m .51563 .57904 L .53816 .5661 L p .533 .276 .471 r
F P
0 g
s
.53816 .5661 m .52694 .54667 L .51013 .55634 L p .533 .276 .471 r
F P
0 g
s
.52694 .45333 m .53816 .4339 L .51563 .42096 L p .533 .595 .862 r
F P
0 g
s
.44612 .5 m .42368 .5 L .42374 .52598 L p .902 .751 .684 r
F P
0 g
s
.52694 .54667 m .53816 .5661 L .56063 .55305 L p .564 .286 .453 r
F P
0 g
s
.71632 .80577 m .72919 .85416 L .74645 .84327 L p .836 .818 .832 r
F P
0 g
s
.74645 .84327 m .7441 .78841 L .71632 .80577 L p .836 .818 .832 r
F P
0 g
s
.67405 .88507 m .62772 .8556 L .60132 .86874 L p .677 .777 .926 r
F P
0 g
s
.62772 .8556 m .67405 .88507 L .69211 .87556 L p .724 .78 .896 r
F P
0 g
s
.07949 .4582 m .12818 .43281 L .13 .40337 L p .401 .233 .537 r
F P
0 g
s
.12818 .43281 m .07949 .4582 L .0787 .47859 L p .437 .304 .601 r
F P
0 g
s
.12704 .53445 m .0787 .52141 L .07949 .5418 L p .437 .41 .731 r
F P
0 g
s
.07949 .5418 m .12818 .56719 L .12704 .53445 L p .437 .41 .731 r
F P
0 g
s
.65664 .15978 m .69211 .12444 L .67405 .11493 L p .724 .403 .435 r
F P
0 g
s
.67405 .11493 m .62772 .1444 L .65664 .15978 L p .724 .403 .435 r
F P
0 g
s
.74645 .15673 m .7441 .21159 L .76868 .22789 L p .876 .585 .492 r
F P
0 g
s
.7441 .21159 m .74645 .15673 L .72919 .14584 L p .836 .548 .5 r
F P
0 g
s
.45368 .33978 m .46568 .26731 L .44529 .25754 L p .375 .312 .658 r
F P
0 g
s
.48775 .17354 m .44529 .25754 L .46568 .26731 L p .436 .268 .554 r
F P
0 g
s
.73733 .42615 m .78885 .34738 L .77011 .33344 L p .868 .824 .803 r
F P
0 g
s
.77011 .33344 m .71867 .41338 L .73733 .42615 L p .868 .824 .803 r
F P
0 g
s
.31738 .33139 m .22341 .32616 L .2207 .34936 L p .681 .352 .412 r
F P
0 g
s
.2207 .34936 m .31565 .35394 L .31738 .33139 L p .681 .352 .412 r
F P
0 g
s
.66191 .54 m .71867 .58662 L .73733 .57385 L p .783 .442 .409 r
F P
0 g
s
.78885 .65262 m .73733 .57385 L .71867 .58662 L p .868 .593 .52 r
F P
0 g
s
.3844 .62022 m .31565 .64606 L .31738 .66861 L p .795 .841 .887 r
F P
0 g
s
.22341 .67384 m .31738 .66861 L .31565 .64606 L p .681 .759 .911 r
F P
0 g
s
.44529 .74246 m .48775 .82646 L .50919 .8172 L p .436 .444 .769 r
F P
0 g
s
.50919 .8172 m .46568 .73269 L .44529 .74246 L p .436 .444 .769 r
F P
0 g
s
.13242 .37863 m .2207 .34936 L .22341 .32616 L p .509 .203 .383 r
F P
0 g
s
.7889 .24235 m .77011 .33344 L .78885 .34738 L p .936 .776 .657 r
F P
0 g
s
.71867 .58662 m .77011 .66656 L .78885 .65262 L p .868 .593 .52 r
F P
0 g
s
.46568 .26731 m .50919 .1828 L .48775 .17354 L p .436 .268 .554 r
F P
0 g
s
.57868 .87902 m .50919 .8172 L .48775 .82646 L p .485 .598 .89 r
F P
0 g
s
.31565 .64606 m .2207 .65064 L .22341 .67384 L p .681 .759 .911 r
F P
0 g
s
.47528 .35139 m .47467 .39783 L .49412 .40874 L p .496 .496 .786 r
F P
0 g
s
.47467 .39783 m .47528 .35139 L .45368 .33978 L p .421 .432 .765 r
F P
0 g
s
.60114 .47085 m .64106 .4471 L .61609 .43203 L p .668 .717 .885 r
F P
0 g
s
.61609 .43203 m .58197 .45946 L .60114 .47085 L p .668 .717 .885 r
F P
0 g
s
.42418 .42698 m .38366 .40429 L .38309 .43345 L p .861 .622 .576 r
F P
0 g
s
.38309 .43345 m .42391 .44928 L .42418 .42698 L p .861 .622 .576 r
F P
0 g
s
.38366 .59571 m .42418 .57302 L .42391 .55072 L p .861 .784 .774 r
F P
0 g
s
.42418 .57302 m .38366 .59571 L .3844 .62022 L p .869 .833 .809 r
F P
0 g
s
.64106 .5529 m .60114 .52915 L .58197 .54054 L p .668 .374 .465 r
F P
0 g
s
.60114 .52915 m .64106 .5529 L .66191 .54 L p .683 .346 .399 r
F P
0 g
s
.47467 .60217 m .47528 .64861 L .50082 .63452 L p .496 .315 .564 r
F P
0 g
s
.50082 .63452 m .49412 .59126 L .47467 .60217 L p .496 .315 .564 r
F P
0 g
s
.68667 .82333 m .71079 .86509 L .72919 .85416 L p .8 .799 .851 r
F P
0 g
s
.72919 .85416 m .71632 .80577 L .68667 .82333 L p .8 .799 .851 r
F P
0 g
s
.69211 .87556 m .65664 .84022 L .62772 .8556 L p .724 .78 .896 r
F P
0 g
s
.65664 .84022 m .69211 .87556 L .71079 .86509 L p .763 .787 .872 r
F P
0 g
s
.0787 .47859 m .12704 .46555 L .12818 .43281 L p .437 .304 .601 r
F P
0 g
s
.12704 .46555 m .0787 .47859 L .07842 .5 L p .453 .353 .651 r
F P
0 g
s
.12665 .5 m .07842 .5 L .0787 .52141 L p .453 .387 .693 r
F P
0 g
s
.0787 .52141 m .12704 .53445 L .12665 .5 L p .453 .387 .693 r
F P
0 g
s
.68667 .17667 m .71079 .13491 L .69211 .12444 L p .763 .46 .472 r
F P
0 g
s
.69211 .12444 m .65664 .15978 L .68667 .17667 L p .763 .46 .472 r
F P
0 g
s
.72919 .14584 m .71632 .19423 L .7441 .21159 L p .836 .548 .5 r
F P
0 g
s
.71632 .19423 m .72919 .14584 L .71079 .13491 L p .8 .507 .493 r
F P
0 g
s
.71079 .86509 m .68667 .82333 L .65664 .84022 L p .763 .787 .872 r
F P
0 g
s
.07842 .5 m .12665 .5 L .12704 .46555 L p .453 .353 .651 r
F P
0 g
s
.71079 .13491 m .68667 .17667 L .71632 .19423 L p .8 .507 .493 r
F P
0 g
s
.46568 .26731 m .45368 .33978 L .47528 .35139 L p .483 .412 .701 r
F P
0 g
s
.66191 .46 m .71867 .41338 L .69375 .39731 L p .758 .767 .86 r
F P
0 g
s
.69375 .39731 m .64106 .4471 L .66191 .46 L p .758 .767 .86 r
F P
0 g
s
.3844 .37978 m .31565 .35394 L .31419 .38355 L p .796 .52 .52 r
F P
0 g
s
.31419 .38355 m .38366 .40429 L .3844 .37978 L p .796 .52 .52 r
F P
0 g
s
.31565 .64606 m .3844 .62022 L .38366 .59571 L p .796 .78 .838 r
F P
0 g
s
.71867 .58662 m .66191 .54 L .64106 .5529 L p .758 .471 .498 r
F P
0 g
s
.45368 .66022 m .46568 .73269 L .49206 .71914 L p .483 .376 .657 r
F P
0 g
s
.49206 .71914 m .47528 .64861 L .45368 .66022 L p .483 .376 .657 r
F P
0 g
s
.74482 .6838 m .76868 .77211 L .7889 .75765 L p .881 .725 .684 r
F P
0 g
s
.7889 .75765 m .77011 .66656 L .74482 .6838 L p .881 .725 .684 r
F P
0 g
s
.50919 .8172 m .57868 .87902 L .60132 .86874 L p .581 .622 .857 r
F P
0 g
s
.2207 .34936 m .13242 .37863 L .13 .40337 L p .569 .324 .504 r
F P
0 g
s
.21842 .62012 m .13 .59663 L .13242 .62137 L p .569 .606 .85 r
F P
0 g
s
.13242 .62137 m .2207 .65064 L .21842 .62012 L p .569 .606 .85 r
F P
0 g
s
.53676 .19608 m .60132 .13126 L .57868 .12098 L p .581 .328 .497 r
F P
0 g
s
.57868 .12098 m .50919 .1828 L .53676 .19608 L p .581 .328 .497 r
F P
0 g
s
.77011 .33344 m .7889 .24235 L .76868 .22789 L p .881 .713 .67 r
F P
0 g
s
.50082 .36548 m .49412 .40874 L .51563 .42096 L p .549 .546 .804 r
F P
0 g
s
.49412 .40874 m .50082 .36548 L .47528 .35139 L p .496 .496 .786 r
F P
0 g
s
.58197 .45946 m .61609 .43203 L .58818 .41552 L p .647 .672 .86 r
F P
0 g
s
.58818 .41552 m .56063 .44695 L .58197 .45946 L p .647 .672 .86 r
F P
0 g
s
.42391 .44928 m .38309 .43345 L .38274 .46588 L p .855 .652 .627 r
F P
0 g
s
.38274 .46588 m .42374 .47402 L .42391 .44928 L p .855 .652 .627 r
F P
0 g
s
.38309 .56655 m .42391 .55072 L .42374 .52598 L p .855 .744 .74 r
F P
0 g
s
.42391 .55072 m .38309 .56655 L .38366 .59571 L p .861 .784 .774 r
F P
0 g
s
.61609 .56797 m .58197 .54054 L .56063 .55305 L p .647 .384 .508 r
F P
0 g
s
.58197 .54054 m .61609 .56797 L .64106 .5529 L p .668 .374 .465 r
F P
0 g
s
.49412 .59126 m .50082 .63452 L .52908 .61861 L p .549 .351 .564 r
F P
0 g
s
.52908 .61861 m .51563 .57904 L .49412 .59126 L p .549 .351 .564 r
F P
0 g
s
.52908 .38139 m .51563 .42096 L .53816 .4339 L p .589 .59 .821 r
F P
0 g
s
.51563 .42096 m .52908 .38139 L .50082 .36548 L p .549 .546 .804 r
F P
0 g
s
.56063 .44695 m .58818 .41552 L .55869 .39835 L p .621 .631 .839 r
F P
0 g
s
.55869 .39835 m .53816 .4339 L .56063 .44695 L p .621 .631 .839 r
F P
0 g
s
.42374 .47402 m .38274 .46588 L .38263 .5 L p .852 .681 .669 r
F P
0 g
s
.38263 .5 m .42368 .5 L .42374 .47402 L p .852 .681 .669 r
F P
0 g
s
.38274 .53412 m .42374 .52598 L .42368 .5 L p .852 .71 .706 r
F P
0 g
s
.42374 .52598 m .38274 .53412 L .38309 .56655 L p .855 .744 .74 r
F P
0 g
s
.58818 .58448 m .56063 .55305 L .53816 .5661 L p .621 .384 .536 r
F P
0 g
s
.56063 .55305 m .58818 .58448 L .61609 .56797 L p .647 .384 .508 r
F P
0 g
s
.51563 .57904 m .52908 .61861 L .55869 .60165 L p .589 .373 .554 r
F P
0 g
s
.55869 .60165 m .53816 .5661 L .51563 .57904 L p .589 .373 .554 r
F P
0 g
s
.53816 .4339 m .55869 .39835 L .52908 .38139 L p .589 .59 .821 r
F P
0 g
s
.42368 .5 m .38263 .5 L .38274 .53412 L p .852 .71 .706 r
F P
0 g
s
.53816 .5661 m .55869 .60165 L .58818 .58448 L p .621 .384 .536 r
F P
0 g
s
.47528 .35139 m .49206 .28086 L .46568 .26731 L p .483 .412 .701 r
F P
0 g
s
.50919 .1828 m .46568 .26731 L .49206 .28086 L p .536 .381 .618 r
F P
0 g
s
.71867 .41338 m .77011 .33344 L .74482 .3162 L p .823 .751 .784 r
F P
0 g
s
.74482 .3162 m .69375 .39731 L .71867 .41338 L p .823 .751 .784 r
F P
0 g
s
.31565 .35394 m .2207 .34936 L .21842 .37988 L p .703 .438 .521 r
F P
0 g
s
.21842 .37988 m .31419 .38355 L .31565 .35394 L p .703 .438 .521 r
F P
0 g
s
.64106 .5529 m .69375 .60269 L .71867 .58662 L p .758 .471 .498 r
F P
0 g
s
.77011 .66656 m .71867 .58662 L .69375 .60269 L p .823 .593 .591 r
F P
0 g
s
.38366 .59571 m .31419 .61645 L .31565 .64606 L p .796 .78 .838 r
F P
0 g
s
.2207 .65064 m .31565 .64606 L .31419 .61645 L p .703 .709 .853 r
F P
0 g
s
.46568 .73269 m .50919 .8172 L .53676 .80392 L p .536 .494 .757 r
F P
0 g
s
.53676 .80392 m .49206 .71914 L .46568 .73269 L p .536 .494 .757 r
F P
0 g
s
.49206 .28086 m .47528 .35139 L .50082 .36548 L p .552 .48 .729 r
F P
0 g
s
.64106 .4471 m .69375 .39731 L .66365 .37866 L p .731 .711 .832 r
F P
0 g
s
.66365 .37866 m .61609 .43203 L .64106 .4471 L p .731 .711 .832 r
F P
0 g
s
.38366 .40429 m .31419 .38355 L .31309 .41894 L p .794 .564 .589 r
F P
0 g
s
.31309 .41894 m .38309 .43345 L .38366 .40429 L p .794 .564 .589 r
F P
0 g
s
.31419 .61645 m .38366 .59571 L .38309 .56655 L p .794 .733 .795 r
F P
0 g
s
.69375 .60269 m .64106 .5529 L .61609 .56797 L p .731 .482 .552 r
F P
0 g
s
.47528 .64861 m .49206 .71914 L .52326 .7024 L p .552 .42 .655 r
F P
0 g
s
.52326 .7024 m .50082 .63452 L .47528 .64861 L p .552 .42 .655 r
F P
0 g
s
.71408 .70354 m .7441 .78841 L .76868 .77211 L p .835 .702 .717 r
F P
0 g
s
.76868 .77211 m .74482 .6838 L .71408 .70354 L p .835 .702 .717 r
F P
0 g
s
.60132 .86874 m .53676 .80392 L .50919 .8172 L p .581 .622 .857 r
F P
0 g
s
.53676 .80392 m .60132 .86874 L .62772 .8556 L p .642 .635 .828 r
F P
0 g
s
.13 .40337 m .21842 .37988 L .2207 .34936 L p .569 .324 .504 r
F P
0 g
s
.21842 .37988 m .13 .40337 L .12818 .43281 L p .599 .399 .581 r
F P
0 g
s
.21669 .58363 m .12818 .56719 L .13 .59663 L p .599 .58 .803 r
F P
0 g
s
.13 .59663 m .21842 .62012 L .21669 .58363 L p .599 .58 .803 r
F P
0 g
s
.56923 .21283 m .62772 .1444 L .60132 .13126 L p .642 .413 .556 r
F P
0 g
s
.60132 .13126 m .53676 .19608 L .56923 .21283 L p .642 .413 .556 r
F P
0 g
s
.76868 .22789 m .74482 .3162 L .77011 .33344 L p .881 .713 .67 r
F P
0 g
s
.74482 .3162 m .76868 .22789 L .7441 .21159 L p .835 .661 .667 r
F P
0 g
s
.49206 .28086 m .53676 .19608 L .50919 .1828 L p .536 .381 .618 r
F P
0 g
s
.69375 .60269 m .74482 .6838 L .77011 .66656 L p .823 .593 .591 r
F P
0 g
s
.31419 .61645 m .21842 .62012 L .2207 .65064 L p .703 .709 .853 r
F P
0 g
s
.52326 .2976 m .50082 .36548 L .52908 .38139 L p .601 .533 .75 r
F P
0 g
s
.50082 .36548 m .52326 .2976 L .49206 .28086 L p .552 .48 .729 r
F P
0 g
s
.61609 .43203 m .66365 .37866 L .62982 .35833 L p .702 .663 .809 r
F P
0 g
s
.62982 .35833 m .58818 .41552 L .61609 .43203 L p .702 .663 .809 r
F P
0 g
s
.38309 .43345 m .31309 .41894 L .3124 .45841 L p .792 .599 .64 r
F P
0 g
s
.3124 .45841 m .38274 .46588 L .38309 .43345 L p .792 .599 .64 r
F P
0 g
s
.31309 .58106 m .38309 .56655 L .38274 .53412 L p .792 .694 .757 r
F P
0 g
s
.38309 .56655 m .31309 .58106 L .31419 .61645 L p .794 .733 .795 r
F P
0 g
s
.66365 .62134 m .61609 .56797 L .58818 .58448 L p .702 .484 .588 r
F P
0 g
s
.61609 .56797 m .66365 .62134 L .69375 .60269 L p .731 .482 .552 r
F P
0 g
s
.50082 .63452 m .52326 .7024 L .55778 .68326 L p .601 .449 .647 r
F P
0 g
s
.55778 .68326 m .52908 .61861 L .50082 .63452 L p .601 .449 .647 r
F P
0 g
s
.67936 .72483 m .71632 .80577 L .7441 .78841 L p .796 .684 .741 r
F P
0 g
s
.7441 .78841 m .71408 .70354 L .67936 .72483 L p .796 .684 .741 r
F P
0 g
s
.62772 .8556 m .56923 .78717 L .53676 .80392 L p .642 .635 .828 r
F P
0 g
s
.56923 .78717 m .62772 .8556 L .65664 .84022 L p .687 .647 .804 r
F P
0 g
s
.12818 .43281 m .21669 .41637 L .21842 .37988 L p .599 .399 .581 r
F P
0 g
s
.21669 .41637 m .12818 .43281 L .12704 .46555 L p .615 .451 .637 r
F P
0 g
s
.21561 .54291 m .12704 .53445 L .12818 .56719 L p .615 .553 .762 r
F P
0 g
s
.12818 .56719 m .21669 .58363 L .21561 .54291 L p .615 .553 .762 r
F P
0 g
s
.7441 .21159 m .71408 .29646 L .74482 .3162 L p .835 .661 .667 r
F P
0 g
s
.71408 .29646 m .7441 .21159 L .71632 .19423 L p .796 .615 .657 r
F P
0 g
s
.60503 .23226 m .65664 .15978 L .62772 .1444 L p .687 .476 .595 r
F P
0 g
s
.62772 .1444 m .56923 .21283 L .60503 .23226 L p .687 .476 .595 r
F P
0 g
s
.53676 .19608 m .49206 .28086 L .52326 .2976 L p .599 .455 .657 r
F P
0 g
s
.69375 .39731 m .74482 .3162 L .71408 .29646 L p .785 .694 .764 r
F P
0 g
s
.71408 .29646 m .66365 .37866 L .69375 .39731 L p .785 .694 .764 r
F P
0 g
s
.31419 .38355 m .21842 .37988 L .21669 .41637 L p .712 .494 .592 r
F P
0 g
s
.21669 .41637 m .31309 .41894 L .31419 .38355 L p .712 .494 .592 r
F P
0 g
s
.74482 .6838 m .69375 .60269 L .66365 .62134 L p .785 .588 .634 r
F P
0 g
s
.21842 .62012 m .31419 .61645 L .31309 .58106 L p .712 .669 .806 r
F P
0 g
s
.49206 .71914 m .53676 .80392 L .56923 .78717 L p .599 .524 .741 r
F P
0 g
s
.56923 .78717 m .52326 .7024 L .49206 .71914 L p .599 .524 .741 r
F P
0 g
s
.55778 .31674 m .52908 .38139 L .55869 .39835 L p .64 .578 .769 r
F P
0 g
s
.52908 .38139 m .55778 .31674 L .52326 .2976 L p .601 .533 .75 r
F P
0 g
s
.58818 .41552 m .62982 .35833 L .59392 .33733 L p .673 .62 .788 r
F P
0 g
s
.59392 .33733 m .55869 .39835 L .58818 .41552 L p .673 .62 .788 r
F P
0 g
s
.38274 .46588 m .3124 .45841 L .31217 .5 L p .791 .63 .682 r
F P
0 g
s
.31217 .5 m .38263 .5 L .38274 .46588 L p .791 .63 .682 r
F P
0 g
s
.3124 .54159 m .38274 .53412 L .38263 .5 L p .791 .661 .72 r
F P
0 g
s
.38274 .53412 m .3124 .54159 L .31309 .58106 L p .792 .694 .757 r
F P
0 g
s
.62982 .64167 m .58818 .58448 L .55869 .60165 L p .673 .478 .614 r
F P
0 g
s
.58818 .58448 m .62982 .64167 L .66365 .62134 L p .702 .484 .588 r
F P
0 g
s
.52908 .61861 m .55778 .68326 L .59392 .66267 L p .64 .467 .633 r
F P
0 g
s
.59392 .66267 m .55869 .60165 L .52908 .61861 L p .64 .467 .633 r
F P
0 g
s
.64238 .7466 m .68667 .82333 L .71632 .80577 L p .76 .67 .762 r
F P
0 g
s
.71632 .80577 m .67936 .72483 L .64238 .7466 L p .76 .67 .762 r
F P
0 g
s
.65664 .84022 m .60503 .76774 L .56923 .78717 L p .687 .647 .804 r
F P
0 g
s
.60503 .76774 m .65664 .84022 L .68667 .82333 L p .725 .657 .782 r
F P
0 g
s
.12704 .46555 m .21561 .45709 L .21669 .41637 L p .615 .451 .637 r
F P
0 g
s
.21561 .45709 m .12704 .46555 L .12665 .5 L p .621 .491 .682 r
F P
0 g
s
.21525 .5 m .12665 .5 L .12704 .53445 L p .621 .524 .722 r
F P
0 g
s
.12704 .53445 m .21561 .54291 L .21525 .5 L p .621 .524 .722 r
F P
0 g
s
.64238 .2534 m .68667 .17667 L .65664 .15978 L p .725 .527 .622 r
F P
0 g
s
.65664 .15978 m .60503 .23226 L .64238 .2534 L p .725 .527 .622 r
F P
0 g
s
.71632 .19423 m .67936 .27517 L .71408 .29646 L p .796 .615 .657 r
F P
0 g
s
.67936 .27517 m .71632 .19423 L .68667 .17667 L p .76 .572 .642 r
F P
0 g
s
.55869 .39835 m .59392 .33733 L .55778 .31674 L p .64 .578 .769 r
F P
0 g
s
.38263 .5 m .31217 .5 L .3124 .54159 L p .791 .661 .72 r
F P
0 g
s
.55869 .60165 m .59392 .66267 L .62982 .64167 L p .673 .478 .614 r
F P
0 g
s
.52326 .2976 m .56923 .21283 L .53676 .19608 L p .599 .455 .657 r
F P
0 g
s
.66365 .62134 m .71408 .70354 L .74482 .6838 L p .785 .588 .634 r
F P
0 g
s
.31309 .58106 m .21669 .58363 L .21842 .62012 L p .712 .669 .806 r
F P
0 g
s
.68667 .82333 m .64238 .7466 L .60503 .76774 L p .725 .657 .782 r
F P
0 g
s
.12665 .5 m .21525 .5 L .21561 .45709 L p .621 .491 .682 r
F P
0 g
s
.68667 .17667 m .64238 .2534 L .67936 .27517 L p .76 .572 .642 r
F P
0 g
s
.56923 .21283 m .52326 .2976 L .55778 .31674 L p .646 .511 .685 r
F P
0 g
s
.66365 .37866 m .71408 .29646 L .67936 .27517 L p .751 .646 .745 r
F P
0 g
s
.67936 .27517 m .62982 .35833 L .66365 .37866 L p .751 .646 .745 r
F P
0 g
s
.31309 .41894 m .21669 .41637 L .21561 .45709 L p .717 .536 .644 r
F P
0 g
s
.21561 .45709 m .3124 .45841 L .31309 .41894 L p .717 .536 .644 r
F P
0 g
s
.21669 .58363 m .31309 .58106 L .3124 .54159 L p .717 .634 .765 r
F P
0 g
s
.71408 .70354 m .66365 .62134 L .62982 .64167 L p .751 .58 .664 r
F P
0 g
s
.52326 .7024 m .56923 .78717 L .60503 .76774 L p .646 .543 .724 r
F P
0 g
s
.60503 .76774 m .55778 .68326 L .52326 .7024 L p .646 .543 .724 r
F P
0 g
s
.55778 .31674 m .60503 .23226 L .56923 .21283 L p .646 .511 .685 r
F P
0 g
s
.62982 .64167 m .67936 .72483 L .71408 .70354 L p .751 .58 .664 r
F P
0 g
s
.3124 .54159 m .21561 .54291 L .21669 .58363 L p .717 .634 .765 r
F P
0 g
s
.60503 .23226 m .55778 .31674 L .59392 .33733 L p .684 .559 .707 r
F P
0 g
s
.62982 .35833 m .67936 .27517 L .64238 .2534 L p .718 .602 .727 r
F P
0 g
s
.64238 .2534 m .59392 .33733 L .62982 .35833 L p .718 .602 .727 r
F P
0 g
s
.3124 .45841 m .21561 .45709 L .21525 .5 L p .718 .571 .687 r
F P
0 g
s
.21525 .5 m .31217 .5 L .3124 .45841 L p .718 .571 .687 r
F P
0 g
s
.21561 .54291 m .3124 .54159 L .31217 .5 L p .718 .603 .726 r
F P
0 g
s
.67936 .72483 m .62982 .64167 L .59392 .66267 L p .718 .57 .687 r
F P
0 g
s
.55778 .68326 m .60503 .76774 L .64238 .7466 L p .684 .558 .706 r
F P
0 g
s
.64238 .7466 m .59392 .66267 L .55778 .68326 L p .684 .558 .706 r
F P
0 g
s
.59392 .33733 m .64238 .2534 L .60503 .23226 L p .684 .559 .707 r
F P
0 g
s
.31217 .5 m .21525 .5 L .21561 .54291 L p .718 .603 .726 r
F P
0 g
s
.59392 .66267 m .64238 .7466 L .67936 .72483 L p .718 .57 .687 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
      ImageSize->{288, 288},
      ImageMargins->{{0, 0}, {0, 0}},
      ImageRegion->{{0, 1}, {0, 1}},
      ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ROooo`d0002:
oooo001ooooo2P0000goool:0000P?ooo`00NOooo`H0000Qoooo1P0007[oool007Coool50000;Ooo
o`D0001eoooo001aoooo0`0003Ooool30000L_ooo`00KOooo`@0000moooo100006koool006[oool3
0000AOooo`<0001[oooo001Woooo0`0004_oool30000J?ooo`00I?ooo`<0001Aoooo0`0006Goool0
067oool30000Eoooo`<0001Roooo001Noooo0`0004koool:00001Oooo`<0001Ooooo001Koooo0`00
04_oool:0000184>7PP00002oooo0`0005coool005Woool20000BOooo`/00005P@hN0`0000>L>DP2
00000hh000L0001Joooo001Goooo0P0004Goool700000Th000@00006P@hN0`0000NL>DP=0000F?oo
o`00EOooo`800014oooo1@0000=>000400001h4>7P<00008W3U80P0000>]E60200001jDQ00<0001F
oooo001Coooo0P0004Goool300000Td0<`@00008P@hN0`0000VL>DP200001jeDH0`0001Doooo001A
oooo0P0004Goool400000dd0<`030000O35UO35U00<00003P@hN0`0000VL>DP300002:eDH0800000
0kUWK`0000000006]3PF100005;oool0053oool00`000?ooooooo`14oooo0`0000==03<200001W`a
I@<0000:W3U80P0000Z]E6000`000;UWKkUWK`03^FM_0P0000:d>1H200000l188`<0001@oooo001>
oooo0P0004Koool300000dd0<`030000O35UO35U00Il<FD00`0009ACOiACO`0200001Y`iB080000:
[EAP0P0000RiIfl200001L188`040000bE@X00000000Coooo`00COooo`030000oooooooo04Coool4
00000dd0<`030000O35UO35U00Il<FD00`0009ACOiACO`03U5=o0P0000:L>DP200002jeDH0030000
^FM_^FM_00NiIfl010000<=eN000000000C0B2<00`000<UD:<UD:0030000COooo`00Boooo`800016
oooo0`0000A=03<00`0007`aIG`aI@06O35U00<0002DDgnDDgl01YACO`80000<[EAP00<0002iIfni
Ifl01kUWK`030000`gEh`gEh00;3MGP2000000?0B2<00039E2P00/UD:0@0001<oooo0019oooo0P00
04Ooool300000dd0<`800007O35U0P0000RDDgl00`000:AYSZAYSP0200002:eDH0800009^FM_00<0
0033MGS3MGP01L=eN0800003bE@X00<0003@FbK@FbH00`0004[oool004Soool00`000?ooooooo`15
oooo100000==03<00`0007`aIG`aI@06O35U00<0002DDgnDDgl01iACO`030000Y6V>Y6V>00>TJHh2
00001JeDH0030000^FM_^FM_00RiIfl00`000<=eN<=eN006`gEh00@0003<PGh000000002bE@X00@0
003@FbH0003DGQ/20000BOooo`00A_ooo`800017oooo0`0000A=03<00`0007`aIG`aI@06O35U00<0
002DDgnDDgl01iACO`030000Y6V>Y6V>00JTJHh2000000>]E600000000002[UWK`030000`gEh`gEh
00K3MGP00`000<b1O/b1OP02c85n0`0000;@FbH00`000=AN6`0000020000Aoooo`00AOooo`030000
oooooooo04Koool3000014d0<`030000O35UO35U00Il<FD00`0009ACOiACO`07U5=o00<0002TJHjT
JHh02JAYSP80000:^FM_00<00033MGS3MGP01l=eN0030000c85nc85n00C<PGh01`000=1K9]1K9P00
0=AN6`000=AJ1@020000A_ooo`00A?ooo`030000oooooooo04Koool3000014d0<`030000O35UO35U
00Il<FD00`0009ACOiACO`07U5=o00<0002TJHjTJHh02JAYSP030000[gVH[gVH00800007^FM_00<0
0033MGS3MGP01l=eN0030000c85nc85n00G<PGh3000000?@FbH0003DGQ/0100004Goool004?oool0
0`000?ooooooo`15oooo100000==03<2000027`aI@030000U5=oU5=o00NDDgl00`000:AYSZAYSP09
Y6V>00<0002_NIR_NIP00jmiV0800004^FM_00<00033MGS3MGP02<=eN0030000c85nc85n00C<PGh0
10000=J<OmJ<OmJ<O`8000000mAN6`000=AJ1@030000A?ooo`00@_ooo`030000oooooooo04Goool3
000014d0<`030000O35UO35U00Ml<FD00`0009ACOiACO`07U5=o00<0002TJHjTJHh02JAYSP030000
[gVH[gVH00J_NIP2000000>iIfl00033MGP02L=eN0030000c85nc85n00G<PGh00`000=J<OmJ<O`03
eXao00@0003DGQ/0003DFPD30000@oooo`00@?ooo`800017oooo0`0000A=03<00`0007`aIG`aI@07
O35U00<0002DDgnDDgl01iACO`030000Y6V>Y6V>00ZTJHh00`000:miV:miV008[gVH00<00033MGS3
MGP02L=eN0030000c85nc85n00G<PGh00`000=J<OmJ<O`03eXao1P000003oooo00000000047oool0
03ooool00`000?ooooooo`15oooo100000A=03<00`0007`aIG`aI@07O35U00<0002DDgnDDgl01iAC
O`030000Y6V>Y6V>00ZTJHh00`000:miV:miV008[gVH00@0002iQYl000000008`gEh00<0003<PGk<
PGh01/b1OP030000eXaoeXao00?FS7l01@000>2EON2EO@000=AJ1@0200000_ooo`030000oooooooo
03koool003koool00`000?ooooooo`15oooo0`0000A=03<2000027`aI@80000:U5=o00<0002TJHjT
JHh02JAYSP030000[gVH[gVH00V_NIP010000;V6WkV6WkV6W`800006`gEh00<0003<PGk<PGh01Lb1
OP030000eXaoeXao00CFS7l01P000>2EON2EON2EO@000=AJ1@800002oooo00<0003oooooool0?Ooo
o`00?Oooo`030000oooooooo04Goool500000Td0<`030000O35UO35U00Ml<FD00`0009ACOiACO`09
U5=o00<0002TJHjTJHh02JAYSP030000[gVH[gVH00V_NIP00`000;V6WkV6W`04^HJO0P0000?3MGP0
0`000<b1O/b1OP06c85n00<0003FS7oFS7l01=J<O`040000h9Emh9Emh9Em1@0000;oool00`000?oo
ooooo`0loooo000loooo00<0003oooooool0A_ooo`8001h3@15]0`0000Ql<FD00`0009ACOiACO`09
U5=o00<0002TJHjTJHh02JAYSP030000[gVH[gVH00V_NIP00`000;V6WkV6W`07^HJO0P000003`gEh
0000c85n00O<PGh00`000=J<OmJ<O`04eXao00D0003PUGgPUGgPUGd000000^^NM@800003oooo00<0
003oooooool0>oooo`00>oooo`030000oooooooo04Koool00`0000007P000004@15]0Vm4S@800005
O35U00<0002DDgnDDgl02IACO`030000Y6V>Y6V>00VTJHh00`000:miV:miV009[gVH00<0002iQYni
QYl02[V6W`030000c85nc85n00K<PGh00`000=J<OmJ<O`05eXao00D0003PUGgPUGgPUGd000000n^N
M@800003oooo00<0003oooooool0>_ooo`00>_ooo`030000oooooooo04Ooool2000N00D000104Fe0
4Fe04Fd0000016m4S@800002O35U00<0002DDgnDDgl02IACO`030000Y6V>Y6V>00ZTJHh00`000:mi
V:miV009[gVH00<0002iQYniQYl02KV6W`040000`Y:T000000001/b1OP030000eXaoeXao00GFS7l0
1@000>2EON2EON2EO@000003jiie0`0000?oool00`000?ooooooo`0ioooo000ioooo00<0003ooooo
ool0Aoooo`030000000N000000A04Fd00`0006m4SFm4S@04KdB=0`0000ZDDgl00`000:AYSZAYSP0:
Y6V>00<0002_NIR_NIP02JmiV0030000^HJO^HJO00ZiQYl010000<:BY<:BY<:BY0800004c85n00<0
003FS7oFS7l01MJ<O`030000h9Emh9Em00;PUGd01@000>^NMN^NM@000?BSH@0200000oooo`030000
oooooooo03Soool003Soool00`000?ooooooo`18oooo0P007P050000@15]@15]@15]000000M_A8d0
0`0008UQWXUQWP0200001iACO`030000Y6V>Y6V>00ZTJHh00`000:miV:miV009[gVH00<0002iQYni
QYl02[V6W`030000`Y:T`Y:T00C2TZ@01@000<b1O/b1O/b1OP000006eXao00<0003PUGgPUGd00n2E
O@040000jiiejiiejiie0`0000Coool00`000?ooooooo`0goooo000goooo00<0003oooooool0B?oo
o`030000000N000000A04Fd00`0006m4SFm4S@05KdB=00<00029HIj9HIh00XUQWP800004U5=o00<0
002TJHjTJHh02ZAYSP030000[gVH[gVH00Z_NIP00`000;V6WkV6W`0:^HJO00<00032TZC2TZ@01L:B
Y0<00007eXao00<0003PUGgPUGd00n2EO@060000jiiejiiejiie0000m:=Q0P0000Coool00`000?oo
ooooo`0foooo000foooo00<0003oooooool0BOooo`030000000N000000=04Fd00`0006m4SFm4S@05
KdB=00<00029HIj9HIh01HUQWP8000000iACO`000:AYSP0;Y6V>00<0002_NIR_NIP02ZmiV0030000
^HJO^HJO00ZiQYl00`000<:BY<:BY008`Y:T00<0003FS7oFS7l01MJ<O`030000h9Emh9Em00?PUGd0
1P000>^NMN^NMN^NM@000?BSH@<00004oooo00<0003oooooool0=Oooo`00=Oooo`030000oooooooo
04Woool00`0000007P000004@15]00<0001_A8e_A8d01Fm4S@030000RF6NRF6N00N9HIh00`000:AY
SZAYSP0:Y6V>00<0002_NIR_NIP02ZmiV0030000^HJO^HJO00ZiQYl00`000<:BY<:BY009`Y:T0`00
00GFS7l00`000>2EON2EO@03h9Em00T0003[WWG[WWG[WWD0003dXf40003cW3D000001Oooo`030000
oooooooo03Coool003Coool00`000?ooooooo`1:oooo00<0000001h000000d0AK@030000KdB=KdB=
00E_A8d00`0008UQWXUQWP07RF6N00@0002IM:P000000009Y6V>00<0002_NIR_NIP02ZmiV0030000
^HJO^HJO00^iQYl00`000<:BY<:BY008`Y:T00@0003;WJS;WJS;WJP200000mJ<O`030000h9Emh9Em
00?PUGd020000>^NMN^NMN^NM@000?BSH@000?>L=@800005oooo00<0003oooooool0<oooo`00<ooo
o`030000oooooooo04[oool00`0000007P000004@15]00<0001_A8e_A8d01Fm4S@030000RF6NRF6N
00N9HIh0100009UdZ9UdZ9UdZ0800007Y6V>00<0002_NIR_NIP02ZmiV0030000^HJO^HJO00ZiQYl0
0`000<:BY<:BY009`Y:T00<0003;WJS;WJP00l^MZ0040000eXaoeXao00001N2EO@030000jiiejiie
00;[WWD00`000?BSH@00000200001_ooo`030000oooooooo03;oool003;oool00`000?ooooooo`1;
oooo00<0000001h000000d0AK@030000KdB=KdB=00E_A8d00`0008UQWXUQWP07RF6N00<0002IM:RI
M:P019UdZ0800004Y6V>00<0002_NIR_NIP02ZmiV0030000^HJO^HJO00^iQYl00`000<:BY<:BY008
`Y:T00<0003;WJS;WJP01L^MZ0<00005h9Em00<0003[WWG[WWD00^^NM@050000m:=Q0000li`e0000
00Ooool00`000?ooooooo`0aoooo000aoooo00<0003oooooool0Boooo`030000000N000000A04Fd0
0`0006m4SFm4S@05KdB=00<00029HIj9HIh01hUQWP030000VGBXVGBX00JIM:P2000000>TJHh0002_
NIP02jmiV0030000^HJO^HJO00^iQYl00`000<:BY<:BY009`Y:T00<0003;WJS;WJP01l^MZ0030000
h9Emh9Em00?PUGd00`000>^NMN^NM@02jiie00@0003dXf40003cW3D200001oooo`030000oooooooo
033oool0033oool00`000?ooooooo`1<oooo00<0000001h000000d0AK@030000KdB=KdB=00E_A8d0
0`0008UQWXUQWP07RF6N00<0002IM:RIM:P02IUdZ080000<[gVH00<0002iQYniQYl02kV6W`030000
`Y:T`Y:T00S2TZ@00`000<^MZ<^MZ008bifX0`0000CPUGd01@000>^NMN^NMN^NM@000002m:=Q0`00
00Soool00`000?ooooooo`0_oooo000_oooo00<0003oooooool0C?ooo`030000000N000000A04Fd0
0`0006m4SFm4S@05KdB=00<00029HIj9HIh01hUQWP030000VGBXVGBX00RIM:P00`000:F2[jF2[`02
00002JmiV0030000^HJO^HJO00^iQYl00`000<:BY<:BY009`Y:T00<0003;WJS;WJP01l^MZ0050000
eJVZeJVZeJVZ000000?PUGd00`000>^NMN^NM@02jiie00D0003dXf40003cW3D000002Oooo`030000
oooooooo02koool002koool00`000?ooooooo`1=oooo00<0000001h000000d0AK@030000KdB=KdB=
00E_A8d00`0008UQWXUQWP07RF6N00<0002IM:RIM:P02IUdZ0030000YH:_YH:_00:UPZl200001Zmi
V0030000^HJO^HJO00^iQYl00`000<:BY<:BY009`Y:T00<0003;WJS;WJP02<^MZ0030000eJVZeJVZ
00;EZJX010000>2EON2EO@0000C[WWD010000?BSH@000?>L=@800009oooo00<0003oooooool0;Ooo
o`00;_ooo`030000oooooooo04coool00`0000007P000004@15]00<0001_A8e_A8d01Fm4S@030000
RF6NRF6N00N9HIh00`0009UdZ9UdZ008VGBX00<0002UPZnUPZl01JF2[`800003[gVH00<0002iQYni
QYl03;V6W`030000`Y:T`Y:T00W2TZ@00`000<^MZ<^MZ008bifX00<0003EZJ[EZJX00mFYZP<00004
jiie00<0003dXf7dXf400`0000Woool00`000?ooooooo`0]oooo000]oooo00<0003oooooool0COoo
o`030000000N000000=04Fd00`0006m4SFm4S@05KdB=00<00029HIj9HIh01hUQWP030000VGBXVGBX
00VIM:P00`000:F2[jF2[`07YH:_0P000003[gVH0000^HJO00biQYl00`000<:BY<:BY009`Y:T00<0
003;WJS;WJP02<^MZ0030000eJVZeJVZ00KEZJX00`000>^NMN^NM@02jiie00H0003dXf7dXf40003c
W3D0000:oooo00<0003oooooool0;?ooo`00;?ooo`030000oooooooo04goool00`0000007P000004
@15]00<0001_A8e_A8d016m4S@030000RF6NRF6N00R9HIh00`0009UdZ9UdZ008VGBX00<0002UPZnU
PZl02ZF2[`030000^HJO^HJO00biQYl00`000<:BY<:BY009`Y:T00<0003;WJS;WJP02<^MZ0030000
eJVZeJVZ00KEZJX300000^^NM@060000m:=Qm:=Q0000li`e00002oooo`030000oooooooo02_oool0
02_oool00`000?ooooooo`1>oooo00<0000001h000000d0AK@030000KdB=KdB=00E_A8d00`0008UQ
WXUQWP07RF6N00<0002IM:RIM:P02IUdZ0030000YH:_YH:_00VUPZl010000:n?]000000000^iQYl0
0`000<:BY<:BY009`Y:T00<0003;WJS;WJP02<^MZ0030000eJVZeJVZ00KEZJX01@000>6fZn6fZn6f
Z`000002jiie00@0003dXf7dXf7cW3D200002oooo`030000oooooooo02[oool002[oool00`000?oo
ooooo`1>oooo00<0000001h00000140AK@030000KdB=KdB=00A_A8d00`0008UQWXUQWP08RF6N00<0
002IM:RIM:P029UdZ0030000YH:_YH:_00ZUPZl010000:n?]:n?]:n?]0800008^HJO00<00032TZC2
TZ@02/:BY0030000bifXbifX00S;WJP00`000=FYZ]FYZP06eJVZ00<0003Q]Z_Q]Z/00^6fZ`<00002
m:=Q00<0003cW3D000003?ooo`030000oooooooo02Woool002Woool00`000?ooooooo`1?oooo00<0
000001h000000d0AK@030000KdB=KdB=00E_A8d00`0008UQWXUQWP07RF6N00<0002IM:RIM:P02IUd
Z0030000YH:_YH:_00VUPZl00`000:n?]:n?]004[hnd0P0000JiQYl00`000<:BY<:BY009`Y:T00<0
003;WJS;WJP02L^MZ0030000eJVZeJVZ00KEZJX00`000>6fZn6fZ`04hKJ[00H0003dXf7dXf40003c
W3D0000=oooo00<0003oooooool0:?ooo`00:?ooo`030000oooooooo04ooool00`0000007P000004
@15]00<0001_A8e_A8d016m4S@030000RF6NRF6N00N9HIh00`0009UdZ9UdZ009VGBX00<0002UPZnU
PZl02ZF2[`030000[hnd[hnd00J_Sk@200000kV6W`030000`Y:T`Y:T00[2TZ@00`000<^MZ<^MZ008
bifX00<0003EZJ[EZJX01mFYZP030000hKJ[hKJ[00CQ]Z/3000000CdXf7cW3GcW3D0000=oooo00<0
003oooooool09oooo`00:?ooo`030000oooooooo04ooool00`0000007P000003@15]00<0001_A8e_
A8d01Fm4S@030000RF6NRF6N00N9HIh00`0009UdZ9UdZ009VGBX00<0002UPZnUPZl02JF2[`030000
[hnd[hnd00V_Sk@2000000>iQYl00032TZ@02/:BY0030000bifXbifX00W;WJP00`000=FYZ]FYZP06
eJVZ00<0003Q]Z_Q]Z/01N6fZ`030000klJXklJX008000000o>L=@000?ooo`0<oooo00<0003ooooo
ool09oooo`009oooo`030000oooooooo053oool01000FP000000000000904Fd00`0006m4SFm4S@04
KdB=00<00029HIj9HIh01hUQWP030000VGBXVGBX00VIM:P00`000:F2[jF2[`0:YH:_00<0002_SkB_
Sk@02jn?]0030000`Y:T`Y:T00[2TZ@00`000<^MZ<^MZ009bifX00<0003EZJ[EZJX01]FYZP030000
hKJ[hKJ[00CQ]Z/00`000>o6Z>o6Z002klJX00<0003cW3D000003_ooo`030000oooooooo02Koool0
02Koool00`000?ooooooo`1Aoooo00@005X0000^8i8^8i8300001Vm4S@030000RF6NRF6N00N9HIh0
0`0009UdZ9UdZ009VGBX00<0002UPZnUPZl02JF2[`030000[hnd[hnd00^_Sk@010000;NJ^P000000
00W2TZ@00`000<^MZ<^MZ009bifX00<0003EZJ[EZJX01mFYZP030000hKJ[hKJ[00CQ]Z/00`000>o6
Z>o6Z002klJX0P000003li`e0000oooo00goool00`000?ooooooo`0Uoooo000Voooo00<0003ooooo
ool0DOooo`03001J0000;R>B008^8i80100005m?Z000000000=_A8d00`0008UQWXUQWP07RF6N00<0
002IM:RIM:P02IUdZ0030000YH:_YH:_00ZUPZl00`000:n?]:n?]00;[hnd00@0002gV[ZgV[ZgV[X2
00001l:BY0030000bifXbifX00W;WJP00`000=FYZ]FYZP06eJVZ00<0003Q]Z_Q]Z/01N6fZ`030000
klJXklJX00;_aZP010000?gGV000000000koool00`000?ooooooo`0Uoooo000Uoooo00<0003ooooo
ool0D_ooo`03001J0000;R>B008^8i80100005m?Z5m?Z5m?Z08000000fm4S@0008UQWP08RF6N00<0
002IM:RIM:P029UdZ0030000YH:_YH:_00ZUPZl00`000:n?]:n?]00;[hnd00<0002gV[ZgV[X01;NJ
^P030000`Y:T`Y:T00?2TZ@00`000<^MZ<^MZ00:bifX00<0003EZJ[EZJX01]FYZP030000hKJ[hKJ[
00GQ]Z/00`000>o6Z>o6Z002klJX00@0003meiSmeiP0000?oooo00<0003oooooool09?ooo`009Ooo
o`030000oooooooo05;oool00`00FP0002hSTP02;R>B00<0001OCjQOCjP00em?Z0800008RF6N00<0
002IM:RIM:P02IUdZ0030000YH:_YH:_00ZUPZl00`000:n?]:n?]00;[hnd00<0002gV[ZgV[X01KNJ
^P800003`Y:T00<0003;WJS;WJP02L^MZ0030000eJVZeJVZ00OEZJX00`000>6fZn6fZ`05hKJ[00D0
003_aZS_aZS_aZP000000ogGV080000>oooo00<0003oooooool09?ooo`009?ooo`030000oooooooo
05;oool00`000000FP000003;R>B00<0001OCjQOCjP00em?Z0040000NfVc000000001XUQWP030000
VGBXVGBX00RIM:P00`000:F2[jF2[`0:YH:_00<0002_SkB_Sk@02jn?]0030000]iZj]iZj00RgV[X2
000000?2TZC;WJS;WJP02/^MZ0030000eJVZeJVZ00OEZJX00`000>6fZn6fZ`04hKJ[00<0003_aZS_
aZP00^o6Z0040000oMNHoMNHoMNH0P0000ooool00`000?ooooooo`0Soooo000Soooo00<0003ooooo
ool0Doooo`030000001J000000<^8i800`0005m?Z5m?Z003GdnX00@0001kJK=kJK=kJK<200000hUQ
WP030000VGBXVGBX00VIM:P00`000:F2[jF2[`0:YH:_00<0002_SkB_Sk@02jn?]0030000]iZj]iZj
00ZgV[X00`000<^MZ<^MZ00:bifX00<0003EZJ[EZJX01]FYZP030000hKJ[hKJ[00GQ]Z/00`000>o6
Z>o6Z002klJX00@0003meiSmeiSmeiP200004?ooo`030000oooooooo02;oool002?oool00`000?oo
ooooo`1Coooo00<0000005X000000RhSTP030000GdnXGdnX00AOCjP00`0007]Y/g]Y/`03NfVc0P00
0003RF6N0000VGBX00VIM:P00`000:F2[jF2[`0:YH:_00<0002_SkB_Sk@02jn?]0030000]iZj]iZj
00ZgV[X010000<2U_P00000000W;WJP00`000=FYZ]FYZP07eJVZ00<0003Q]Z_Q]Z/01N6fZ`030000
klJXklJX00;_aZP01P000?gGV?gGV0000>kBGP00013oool00`000?ooooooo`0Roooo000Roooo00<0
003oooooool0E?ooo`030000001J0000008^8i800`0005m?Z5m?Z003GdnX00<0001kJK=kJK<01W]Y
/`030000VGBXVGBX00VIM:P00`000:F2[jF2[`09YH:_00<0002_SkB_Sk@02jn?]0030000]iZj]iZj
00^gV[X01@000<2U_/2U_/2U_P000008bifX00<0003EZJ[EZJX01mFYZP030000hKJ[hKJ[00GQ]Z/0
0`000>o6Z>o6Z002klJX00H0003meiSmeiP0003^dUh0000Aoooo00<0003oooooool08Oooo`008_oo
o`030000oooooooo05Coool00`000000FP000002;R>B00<0001OCjQOCjP00em?Z0030000NfVcNfVc
00IkJK<3000029UdZ0030000YH:_YH:_00ZUPZl00`000:n?]:n?]00;[hnd00<0002gV[ZgV[X02[NJ
^P030000`:Fn`:Fn00?0YKh200001L^MZ0030000eJVZeJVZ00SEZJX00`000>6fZn6fZ`05hKJ[00<0
003_aZS_aZP00^o6Z0030000oMNHoMNH0080000Boooo00<0003oooooool08Oooo`008Oooo`030000
oooooooo05Goool00`000000FP000002;R>B00<0001OCjQOCjP00em?Z0030000NfVcNfVc00IkJK<0
0`0008ej^Xej^P0200001YUdZ0030000YH:_YH:_00VUPZl00`000:n?]:n?]00;[hnd00<0002gV[Zg
V[X02kNJ^P030000`:Fn`:Fn00G0YKh00`000<^MZ<^MZ002bifX00<0003EZJ[EZJX01mFYZP030000
hKJ[hKJ[00KQ]Z/00`000>o6Z>o6Z002klJX00<0003meiSmeiP00P0001?oool00`000?ooooooo`0P
oooo000Qoooo00<0003oooooool0EOooo`800003;R>B00<0001OCjQOCjP00em?Z0030000NfVcNfVc
00EkJK<00`0008ej^Xej^P03SGZj0P0000>IM:P00`000:F2[jF2[`0:YH:_00<0002_SkB_Sk@02jn?
]0030000]iZj]iZj00ZgV[X00`000<2U_/2U_P07`:Fn00D0003;WJS;WJS;WJP000002MFYZP030000
hKJ[hKJ[00GQ]Z/00`000>o6Z>o6Z002klJX00@0003meiSmeiSmeiP200004oooo`030000oooooooo
023oool0023oool00`000?ooooooo`1Foooo0P0000<^8i800`0005m?Z5m?Z003GdnX00<0001kJK=k
JK<01G]Y/`030000SGZjSGZj00F=N[X2000000>IM:P0002UPZl02ZF2[`030000[hnd[hnd00^_Sk@0
0`000;NJ^[NJ^P0;]iZj00<00030YKk0YKh02<2U_P8000000l^MZ=FYZ]FYZP08eJVZ00<0003Q]Z_Q
]Z/01N6fZ`030000klJXklJX00;_aZP010000?gGV?gGV?gGV080000Doooo00<0003oooooool07ooo
o`008?ooo`030000oooooooo05Koool200000bhSTP030000GdnXGdnX00=OCjP00`0007]Y/g]Y/`05
NfVc00<0002=N[Z=N[X01hej^P80000;YH:_00<0002_SkB_Sk@02Zn?]0030000]iZj]iZj00^gV[X0
0`000<2U_/2U_P0;`:Fn00<0003EZJ[EZJX01mFYZP030000hKJ[hKJ[00KQ]Z/00`000>o6Z>o6Z002
klJX00@0003meiSmeiSmeiP200005?ooo`030000oooooooo01ooool001ooool00`000?ooooooo`1G
oooo0P0000<^8i800`0005m?Z5m?Z003GdnX00<0001kJK=kJK<01G]Y/`030000SGZjSGZj00N=N[X0
100009V8_`00000000RUPZl00`000:n?]:n?]00;[hnd00<0002gV[ZgV[X02[NJ^P030000`:Fn`:Fn
00_0YKh010000<Ra``00000000OEZJX00`000>6fZn6fZ`06hKJ[00<0003_aZS_aZP00^o6Z0060000
oMNHoMNH0000k]9N00005Oooo`030000oooooooo01koool001ooool00`000?ooooooo`0Noooo2000
033oool00`000000FP000003;R>B00<0001OCjQOCjP00Um?Z0030000NfVcNfVc00EkJK<00`0008ej
^Xej^P07SGZj00<0002IR;nIR;l00YV8_`800006YH:_00<0002_SkB_Sk@02Zn?]0030000]iZj]iZj
00^gV[X00`000<2U_/2U_P0;`:Fn00@00038/L?8/L?8/L<200001MFYZP030000hKJ[hKJ[00KQ]Z/0
0`000>o6Z>o6Z002klJX00H0003meiSmeiP0003^dUh0000Eoooo00<0003oooooool07_ooo`007_oo
o`030000oooooooo01goool0100000T000T0000000I[000>00008_ooo`030000001J000000<^8i80
0`0005m?Z5m?Z002GdnX00<0001kJK=kJK<01G]Y/`030000SGZjSGZj00N=N[X00`0009V8_iV8_`04
VHRo0P0000>UPZl00`000:n?]:n?]00;[hnd00<0002gV[ZgV[X02[NJ^P030000`:Fn`:Fn00_0YKh0
0`000<Ra`lRa``04b;730P0000?EZJX00`000>6fZn6fZ`05hKJ[00<0003_aZS_aZP00no6Z0030000
oMNHoMNH0080000Goooo00<0003oooooool07Oooo`007_ooo`030000oooooooo01_oool00`0000T0
00T0000?000026/000P0000Joooo00<0000005X000000bhSTP030000GdnXGdnX009OCjP00`0007]Y
/g]Y/`05NfVc00<0002=N[Z=N[X01hej^P030000VHRoVHRo00JIR;l2000000>UPZl0002_Sk@02jn?
]0030000]iZj]iZj00^gV[X00`000<2U_/2U_P0;`:Fn00<00038/L?8/L<01/Ra``<00008hKJ[00<0
003_aZS_aZP00^o6Z0040000oMNHoMNHoMNH0P0001Ooool00`000?ooooooo`0Moooo000Moooo00<0
003oooooool06_ooo`0300002@002@00008000000el0:00009ha=P0<WS4f3P0000:W6P0200006?oo
o`030000001J0000008^8i800`0005m?Z5m?Z003GdnX00<0001kJK=kJK<01G]Y/`030000SGZjSGZj
00J=N[X00`0009V8_iV8_`09VHRo00<0002_SkB_Sk@02jn?]0030000]iZj]iZj00ZgV[X00`000<2U
_/2U_P0;`:Fn00<00038/L?8/L<02LRa``030000hKJ[hKJ[00KQ]Z/00`000>o6Z>o6Z002klJX00@0
003meiSmeiSmeiP200006?ooo`030000oooooooo01coool001goool00`000?ooooooo`0Goooo0P00
00042@000000000000000el0:0030000WS4fWS4f01RN<CH300000ZLJ0080000Foooo00<0000005X0
00000RhSTP030000GdnXGdnX00=OCjP00`0007]Y/g]Y/`04NfVc00<0002=N[Z=N[X01hej^P030000
VHRoVHRo00VIR;l00j>Ca0000000000:[hnd00<0002gV[ZgV[X02[NJ^P030000`:Fn`:Fn00_0YKh0
0`000<Ra`lRa``09b;7300@0003B`<P000000006hKJ[00<0003_aZS_aZP00^o6Z0040000oMNHoMNH
oMNH0P0001Soool00`000?ooooooo`0Loooo000Loooo00<0003oooooool05_ooo`8000000`T00000
00000006G`0X00<0002N<CJN<CH069ha=P030000aEPkaEPk00800002YaX00P0001Coool300000RhS
TP030000GdnXGdnX00=OCjP00`0007]Y/g]Y/`04NfVc00<0002=N[Z=N[X01Xej^P030000VHRoVHRo
00VIR;l010000:>Ca:>Ca:>Ca0800007[hnd00<0002gV[ZgV[X02kNJ^P030000`:Fn`:Fn00_0YKh0
0`000<Ra`lRa``09b;7300@0003B`<SB`<SB`<P200001>6fZ`030000klJXklJX00;_aZP01P000?gG
V?gGV0000>kBGP0001Woool00`000?ooooooo`0Koooo000Loooo00<0003oooooool05?ooo`030000
2@00000000800007G`0X200001BN<CH00`000<EH>lEH>`02aEPk0P0000:W6P0200004_ooo`030000
001o0000008^8i800`0005m?Z5m?Z003GdnX00<0001kJK=kJK<017]Y/`030000SGZjSGZj00J=N[X0
0`0009V8_iV8_`09VHRo00<0002STlBSTl@00j>Ca0030000[hnd[hnd00B_Sk@00`000;NJ^[NJ^P0:
]iZj00<00030YKk0YKh02l2U_P030000b;73b;7300W8/L<00`000=;0b=;0b004d/3800@0003Q]Z_Q
]Z/00005klJX00H0003meiSmeiP0003^dUh0000Ioooo00<0003oooooool06oooo`006oooo`030000
oooooooo01;oool2000000<900000000000025l0:08000000h8cHP000:iJJ@05[UYY3P0000JN<CH0
0`000<EH>lEH>`04aEPk0P0000:W6P0200004?ooo`030000001o000000<00004GdnX00<0001kJK=k
JK<01G]Y/`030000SGZjSGZj00J=N[X00`0009V8_iV8_`08VHRo00<0002STlBSTl@01J>Ca0800003
[hnd00<0002gV[ZgV[X02kNJ^P030000`:Fn`:Fn00_0YKh00`000<Ra`lRa``09b;7300<0003B`<SB
`<P01M;0b0<00005klJX00D0003meiSmeiP0003^dUh06oooo`030000oooooooo01[oool001_oool0
0`000?ooooooo`0@oooo1@0000MO02P300000h8cHP030000[UYY[UYY01:^FVT800001lEH>`800002
YaX00P0000ooool01000O`0001/_ZQ/_ZP800003GdnX00<0001kJK=kJK<017]Y/`030000SGZjSGZj
00J=N[X00`0009V8_iV8_`09VHRo00<0002STlBSTl@01j>Ca08000000jn?]0000;NJ^P0;]iZj00<0
0030YKk0YKh02l2U_P030000b;73b;7300W8/L<00`000=;0b=;0b008d/3800<0003_aZS_aZP00no6
Z0030000oMNHoMNH0080000Koooo00<0003oooooool06_ooo`006oooo`030000oooooooo00koool4
00001el0:0<00006PS=R00<0002^FVV^FVT06:iJJ@040000bgAZ000000001lEH>`800002YaX00P00
00goool01P000000Oa/_ZQ/_ZP0004iF^`8000000em?Z00007]Y/`05NfVc00<0002=N[Z=N[X01Xej
^P030000VHRoVHRo00RIR;l00`000:>Ca:>Ca00:Xi?400<0002gV[ZgV[X02kNJ^P030000`:Fn`:Fn
00[0YKh00`000<Ra`lRa``0:b;7300<0003B`<SB`<P01m;0b0030000g];=000000?_aZP010000?gG
V?gGV?gGV080000Koooo00<0003oooooool06_ooo`006_ooo`030000oooooooo00goool400001el0
:0800008PS=R00<0002^FVV^FVT06JiJJ@040000bgAZbgAZbgAZ0P0000O5F3/200000jLJ00030000
oooooooo00Woool01@000000O`0001/_ZP000003CUJk0`0000EkJK<00`0008ej^Xej^P06SGZj00<0
002IR;nIR;l029V8_`030000Xi?4Xi?400VSTl@010000:bNb@00000000ZgV[X00`000<2U_/2U_P0;
`:Fn00<00038/L?8/L<02LRa``030000d/38d/3800SB`<P00`000=kBcMkBc@02000000?_aZP0003m
eiP00_gGV080000Loooo00<0003oooooool06Oooo`006_ooo`030000oooooooo00_oool300001el0
:0<0000:PS=R00<0002^FVV^FVT06JiJJ@030000bgAZbgAZ00?;M6X300001/EH>`800003YaX000<0
003oooooool01oooo`050000001o00006bnZ000000A>E[/0100006]^``00000000=kJK<00`0008ej
^Xej^P05SGZj00<0002IR;nIR;l029V8_`030000Xi?4Xi?400ZSTl@010000:bNbJbNbJbNb@800007
]iZj00<00030YKk0YKh02l2U_P030000b;73b;7300W8/L<00`000=;0b=;0b008d/3800<0003Nd/gN
d/d00mkBc@800003oMNH0P0001coool00`000?ooooooo`0Ioooo000Joooo00<0003oooooool02_oo
o`800007G`0X0P0000f2<f800`000:iJJJiJJ@0H[UYY00<0003;M6[;M6X01l]dJP800006aEPk0P00
0003YaX00000000000Woool200000Q/_ZP050000CUJkCUJkCUJk000000=[K/<3000028ej^P030000
VHRoVHRo00RIR;l00`000:>Ca:>Ca009Xi?400<0002/W/V/W/T01:bNb@030000]iZj]iZj00BgV[X0
0`000<2U_/2U_P0:`:Fn00<00038/L?8/L<02/Ra``030000d/38d/3800OB`<P00`000=kBcMkBc@05
g];=00H0003meiSmeiSmeiS^dUh0000Loooo00<0003oooooool06Oooo`006Oooo`030000oooooooo
00[oool200001El0:0<0000>PS=R3`0000f^FVT00`000<]dJ/]dJP09bgAZ0`0000G5F3/010000<I5
0<I5000000Soool200000Q/_ZP050000CUJkCUJkCUJk000000E[K/<00`0008ej^Xej^P05SGZj00<0
002IR;nIR;l029V8_`030000Xi?4Xi?400ZSTl@00`000:bNbJbNb@05[9k90P0000>gV[X00`000<2U
_/2U_P0;`:Fn00<00038/L?8/L<02LRa``030000d/38d/3800SB`<P00`000=kBcMkBc@04g];=00<0
003Yjlh000000_gGV003k]9N0000oooo01coool00`000?ooooooo`0Hoooo000Ioooo00<0003ooooo
ool02Oooo`03000000090000009O02P300003X8cHP<000000i5BP@000;=`Q@0</g253`0000g;M6X2
00000lEH>`800002aTD000<0003oooooool01Oooo`050000001o00006bnZ000000=>E[/00`0006]^
`f]^``03Jfk30`0000F=N[X00`0009V8_iV8_`08VHRo00<0002STlBSTl@02J>Ca0030000[9k9[9k9
00R/W/T2000000>gV[X00030YKh02l2U_P030000b;73b;7300[8/L<00`000=;0b=;0b007d/3800<0
003Nd/gNd/d01MkBc@060000jN_>jN_>0000oMNHk]9N7_ooo`030000oooooooo01Soool001Woool0
0`000?ooooooo`08oooo00@0000000T0001O02P200003X8cHP<00004TE:100<0002cL8FcL8D06;=`
Q@030000bhF500000080000<bgAZ0P000003aEPk0000gG<j008000000lI500000?ooo`05oooo0`00
00036bnZ0000CUJk009>E[/00`0006]^`f]^``03Jfk300<0001nO/UnO/T00P0000>=N[X00`0009V8
_iV8_`07VHRo00<0002STlBSTl@02Z>Ca0030000[9k9[9k900Z/W/T00`000<2U_/2U_P0;`:Fn00<0
0038/L?8/L<02LRa``030000d/38d/3800OB`<P00`000=kBcMkBc@05g];=00<0003YjlkYjlh00^W[
cP030000k]9Noooo01goool00`000?ooooooo`0Hoooo000Hoooo00<0003oooooool02?ooo`030000
000900090080000=PS=R0`0000NADX400`000;=`QK=`Q@0H/g2500<0003;QHG;QHD00/^5Q@<0000<
bgAZ00H0003MLc[MLc[MLcX00036A@0200001Oooo`8000000a/_ZP0004iF^`02CUJk00<0001[K/=[
K/<00f]^``030000OWk9OWk9009nO/T300002YV8_`030000Xi?4Xi?400VSTl@00`000:bNbJbNb@0:
[9k900@0002cZLl00000000:`:Fn00<00038/L?8/L<02LRa``030000d/38d/3800SB`<P00`000=kB
cMkBc@04g];=00<0003YjlkYjlh00^W[cP8000000nkBG_ooooooo`0Moooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo00Ooool00`0000002@002@0200002X8cHP@0000:TE:100<0002cL8Fc
L8D06;=`Q@030000bhF5bhF500G;QHD300002L]dJP800003gG<j00@00036A@36A@000004oooo0P00
00036bnZ0000CUJk009>E[/00`0006]^`f]^``03Jfk300<0001nO/UnO/T017inb@030000VHRoVHRo
00NIR;l00`000:>Ca:>Ca00:Xi?400<0002/W/V/W/T02ZbNb@040000/jW?/jW?/jW?0P0000O0YKh0
0`000<Ra`lRa``0:b;7300<0003B`<SB`<P01m;0b0030000g];=g];=00GNd/d00`000>W[c^W[cP02
jN_>00<0003Po;H000007oooo`030000oooooooo01Ooool001Soool00`000?ooooooo`06oooo00H0
000000T000T0000d04/00007PS=R0`0000fADX400`000;=`QK=`Q@0I/g2500<0003;QHG;QHD02<^5
Q@800007bgAZ00@0003PRFL000000002gG<j00@00036A@36A@000003oooo0P0000036bnZ0000CUJk
00=>E[/00`0006]^`f]^``02Jfk300<0001nO/UnO/T017inb@<00007VHRo00<0002STlBSTl@02J>C
a0030000[9k9[9k900Z/W/T00`000;>Yck>Yc`04/jW?00<00030YKk0YKh01<2U_P030000b;73b;73
00W8/L<00`000=;0b=;0b007d/3800<0003Nd/gNd/d01MkBc@030000jN_>jN_>00;Yjlh00`000>3l
]P00000Poooo00<0003oooooool05oooo`005oooo`030000oooooooo00Koool0100000002@002@00
008d04/00`00088cHX8cHP02PS=R0`00012ADX400`000;=`QK=`Q@0I/g2500<0003;QHG;QHD02/^5
Q@<00004bgAZ00D0003PRFOPRFOPRFL000000]ec>P040000aTD0aTD000000_ooo`<000000a/_ZP00
04iF^`02CUJk00<0001[K/=[K/<00V]^``030000OWk9OWk900AnO/T00`0008b;cHb;c@02000019V8
_`030000Xi?4Xi?400VSTl@00`000:bNbJbNb@0:[9k900<0002cZLncZLl01[>Yc`800003`:Fn00<0
0038/L?8/L<02/Ra``030000d/38d/3800OB`<P00`000=kBcMkBc@04g];=00<0003YjlkYjlh00^W[
cP040000h?bfh?bf00008Oooo`030000oooooooo01Koool001Ooool00`000?ooooooo`06oooo00<0
000000T000000c@0B`030000PS=R00000080000CTE:100<0002cL8FcL8D06K=`Q@030000bhF5bhF5
00g;QHD3000000?;M6X0003PRFL00n29I`030000gG<jgG<j008000001<I500000?ooooooo`800000
0a/_ZP0004iF^`02CUJk00<0001[K/=[K/<00V]^``030000OWk9OWk900AnO/T00`0008b;cHb;c@02
S8_=00D0002IR;nIR;nIR;l000002j>Ca0030000[9k9[9k900V/W/T00`000;>Yck>Yc`09/jW?0P00
0003`:Fn0000b;7300[8/L<00`000=;0b=;0b007d/3800<0003Nd/gNd/d01MkBc@030000jN_>jN_>
00;Yjlh00`000>3l]P00000Roooo00<0003oooooool05_ooo`005oooo`030000oooooooo00Goool0
0`0000002@000004=01;0P0001JADX400`000;=`QK=`Q@0I/g2500<0003;QHG;QHD04<^5Q@800005
h8UW00P0003MLc[MLc[MLcX00036A@00003oool400000diF^`030000Jfk3Jfk3009[K/<00`0007in
bGinb@03OWk900<0002<Rlf<Rld018b;c@<0000;Xi?400<0002/W/V/W/T02ZbNb@030000/jW?/jW?
00^cZLl00`000<Ra`lRa``0:b;7300<0003B`<SB`<P01m;0b0030000g];=g];=00CNd/d00`000>W[
c^W[cP02jN_>00<0003Po;H000008oooo`030000oooooooo01Koool001Koool00`000?ooooooo`05
oooo00<0000000T0000013@0B`80000ETE:14@0000fcL8D00`000<^5QL^5Q@0AbhF50P0000GPRFL0
10000=ec>]ec>]ec>PD000000`Pg^00000000002CUJk00<0001[K/=[K/<00V]^``030000OWk9OWk9
00=nO/T00`0008b;cHb;c@06S8_=00<0002STlBSTl@02J>Ca0030000[9k9[9k900V/W/T00`000;>Y
ck>Yc`0;/jW?00@0002k]]@000000009b;7300<0003B`<SB`<P01m;0b0030000g];=g];=00CNd/d0
0`000>W[c^W[cP02jN_>00@0003Po;KPo;H0000Toooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo00Coool00`0000002@000004=01;00<0001D874000004I5BP@@00002VFJD00<0002fOYNf
OYL03;InU`l0000BbhF500@0003NUX4000000004h8UW0P0000;MLcX2000000Goool000000000000k
F/P00`0000A[K/<00`0007inbGinb@03OWk900<0002<Rlf<Rld01Xb;c@<00008Xi?400<0002/W/V/
W/T02JbNb@030000/jW?/jW?00^cZLl00`000;^fe;^fe002^kKD00<00038/L?8/L<01LRa``030000
d/38d/3800OB`<P00`000=kBcMkBc@05g];=00<0003YjlkYjlh00^W[cP030000h?bf000002Goool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool00oooo`0400000009000900000S@0B`800002
E21a00<0002ADX6ADX402i5BP@@00006VFJD00<0002fOYNfOYL06KInU`030000bi2F000000<0000>
bhF500D0003NUX7NUX7NUX4000001N29I`030000gG<j000000@000001@Pg^00003]Jb3]Jb0000004
Jfk300<0001nO/UnO/T00ginb@030000S8_=S8_=00F<Rld0100009JGdYJGdYJGdP800006Xi?400<0
002/W/V/W/T02JbNb@030000/jW?/jW?00ZcZLl00`000;^fe;^fe004^kKD0P0000G8/L<00`000=;0
b=;0b007d/3800<0003Nd/gNd/d01=kBc@030000jN_>jN_>00;Yjlh010000>3l]^3l]P0002Goool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool00_ooo`0400000009000900000S@0B`050000
E21aE21aE21a000000ZADX4400002YUVU0030000]WjG]WjG01VfOYL00`000<^@U/^@UP03bi2F0`00
00_;QHD00`000=jFPMjFP@02gYJ100<0003PRFOPRFL00n29I`040000jXDf0000df001000008kF/P3
00000V]^``030000OWk9OWk900=nO/T00`0008b;cHb;c@05S8_=00<0002FUm:FUm800iJGdP800003
Xi?400<0002/W/V/W/T02JbNb@030000/jW?/jW?00ZcZLl00`000;^fe;^fe007^kKD00D00038/L?8
/L?8/L<000002M;0b0030000g];=g];=00GNd/d01@000>W[c^W[c^W[cP000002h?bf00<0003ooooo
ool09?ooo`030000oooooooo01Goool001Goool00`000?ooooooo`02oooo00@0000000T000T00002
=01;00<0001D875D87400U@PL@030000TE:1TE:100BADX4400003YUVU0030000]WjG]WjG01VfOYL0
0`000<^@U/^@UP06bi2F0`0000S;QHD00`000=jFPMjFP@03gYJ100<0003PRFOPRFL00^29I`800000
0nZ5=P0000000002000000H8=kP0000kF/PkF/P0001JLLl300001Ginb@030000S8_=S8_=00F<Rld0
0`0009JGdYJGdP05UYOB0P000003Xi?40000[9k900V/W/T00`000;>Yck>Yc`0:/jW?00<0002k]]Bk
]]@02K^fe08000000lRa``000=;0b007d/3800<0003Nd/gNd/d01MkBc@030000jN_>jN_>00;Yjlh0
0`000>3l]P00000Xoooo00<0003oooooool05?ooo`005Oooo`050000oooooooooooo0000008000T0
100003@0Bc@0B`0000ED87400`00095BPI5BP@0400004YUVU0030000]WjG]WjG01VfOYL00`000<^@
U/^@UP09bi2F100000C;QHD00`000=jFPMjFP@04gYJ100P0003PRFOPRFOPRFL0003^V640003ZQCH5
00000S]Jb0050000FW7?FW7?FW7?000000AnO/T00`0008b;cHb;c@05S8_=00<0002FUm:FUm8029JG
dP030000[9k9[9k900V/W/T00`000;>Yck>Yc`09/jW?00<0002k]]Bk]]@03;^fe0030000d/38d/38
00OB`<P00`000=kBcMkBc@04g];=00<0003YjlkYjlh00^W[cP040000h?bfh?bf0000:?ooo`030000
oooooooo01Coool001Goool010000?ooooooo`00008000T0100003@0Bc@0B`0000ID874300005YUV
U0030000]WjG]WjG01VfOYL00`000<^@U/^@UP0=bi2F0`000003bhF50000gYJ100KNUX42000000KP
RFL0003^V67^V640003ZQCH3000000@8=kP0000kF/P00003FW7?0`00009nO/T00`0008b;cHb;c@05
S8_=00<0002FUm:FUm801iJGdP040000WZ7F000000002:bNb@030000/jW?/jW?00VcZLl00`000;^f
e;^fe00<^kKD00@00032a=`000000006d/3800<0003Nd/gNd/d01MkBc@050000jN_>jN_>jN_>0000
00;Po;H00`000?ooooooo`0Woooo00<0003oooooool05?ooo`005?ooo`070000oooooooooooo0000
00090000008d04/00`0005@PLE@PL@04E21a0P0001RIIY@00`000;InUkInU`0H]WjG00<0003;T9K;
T9H04L^@UP800009gYJ10P0000;^V64010000>Z5=P000==P00<00002>e[800@0001JLLmJLLl00002
Kh7D0`0000J<Rld00`0009JGdYJGdP08UYOB00@0002NXMJNXMJNXMH200001JbNb@030000/jW?/jW?
00ZcZLl00`000;^fe;^fe00;^kKD00<00032a=c2a=`00/;4g0800003d/3800<0003Nd/gNd/d01MkB
c@050000jN_>jN_>jN_>000000;Po;H00`000?ooooooo`0Yoooo00<0003oooooool04oooo`005?oo
o`030000oooooooo00<00002=01;00<0001D875D87400e@PL@8000000fHkR@0009UVU00GVFJD00<0
002fOYNfOYL06;InU`030000bi2Fbi2F01;;T9H300002=jFP@060000kYQQkYQQkYQQ0000jXDf1@00
0005>e[80000FW7?FW7?000000A_PM@200001Hb;c@030000UYOBUYOB00NFUm800`0009jQeYjQeP04
WZ7F00D0002/W/V/W/V/W/T000003;>Yc`030000^kKD^kKD00Zk]]@200001l;4g08000000m;0b000
0=kBc@05g];=00<0003YjlkYjlh00^W[cP040000h?bfh?bf0000:oooo`030000oooooooo01?oool0
01Coool00`000?ooooooo`02000000<d04/0000000001E@PL@050000IS^9IS^9IS^9000001RIIY@0
0`000;InUkInU`0H]WjG00<0003;T9K;T9H04/^@UP030000g9nCg9nC00800006gYJ10P0000?^V640
20000>Z5=P00000;W00k_`0003]Jb000009JLLl00`0006n1e6n1e002Kh7D00@0001mSMP000000003
S8_=00<0002FUm:FUm801iJGdP030000WZ7FWZ7F00FNXMH2000000>/W/T0002cZLl02[>Yc`030000
^kKD^kKD00Zk]]@00`000<;4g<;4g009`/CL00<0003Nd/gNd/d01MkBc@050000jN_>jN_>jN_>0000
00;Po;H00`000?ooooooo`0Zoooo00<0003oooooool04oooo`005?ooo`030000oooooooo00<00006
E21a00<0001V>hUV>hT00VHkR@030000VFJDVFJD01BIIY@@00003KInU`030000bi2Fbi2F01;;T9H0
0`000=bOTmbOT`02g9nC0P0000CNUX400`000>bSN`000003kYQQ2000009JLLl01@0006n1e6n1e6n1
e0000003OHgH0`0000VFUm800`0009jQeYjQeP08WZ7F0P0000ZcZLl00`000;^fe;^fe00:^kKD00<0
0032a=c2a=`02L;4g0030000b=KT000000GNd/d01@000>W[c^W[c^W[cP000002h?bf00<0003ooooo
ool0:oooo`030000oooooooo01?oool001Coool00`000?ooo`00000200001E@PL@800004IS^900<0
002IIYBIIY@049UVU0D00002WG>S00<0002gRJBgRJ@02kN9Y100000Bbi2F00<0003LWi?LWi<01=bO
T`800002gYJ100<0003/Xg_/Xg/00P0000;^V645000000DZFll0001JLLmJLLl000000fn1e0030000
OHgHOHgH00=mSMP00`0009JGdYJGdP06UYOB00<0002NXMJNXMH029jQeP030000YJcLYJcL00800007
/jW?00<0002k]]Bk]]@02[^fe0030000`/CL`/CL00S2a=`200000lSFi0800002g];=00<0003YjlkY
jlh00^W[cP040000h?bfh?bf0000;Oooo`030000oooooooo01?oool001?oool00`000?ooooooo`02
00001E@PL@030000IS^9IS^900AV>hT00`0009UVU9UVU00:VFJD1P0000NMLj<00`000;N9Y;N9Y00H
]hVT00<0003:VJ?:VJ<01@0000c;T9H00`000=bOTmbOT`07g9nC0`0000C/Xg/00`000>jHH@000004
000000<ZFll0000000000P0000=_PM@00`0007f=f7f=f003OHgH0`0000JFUm800`0009jQeYjQeP07
WZ7F00<0002U[=bU[=`00jF/g0800004/jW?00<0002k]]Bk]]@02[^fe0030000`/CL`/CL00S2a=`0
0`000<SFi<SFi005b=KT00<0003Nd/d000000nW[cP040000h?bfh?bf0000;oooo`030000oooooooo
01;oool001?oool00`000?ooooooo`02000015@PL@030000IS^9IS^900EV>hT00`0009UVU9UVU005
VFJD1@0000fMLj<00`000;N9Y;N9Y00H]hVT00<0003:VJ?:VJ<01LZIX`D00007bi2F00<0003LWi?L
Wi<02MbOT`030000k:=kk:=k00?/Xg/7000000<ZFll0001:LML00P00009_PM@00`0007f=f7f=f003
OHgH00<00028V=b8V=`00P0000>FUm800`0009jQeYjQeP07WZ7F00<0002U[=bU[=`01ZF/g0800000
0k>Yc`000;^fe00;^kKD00<00032a=c2a=`02<;4g0030000b=KTb=KT00O8e^@01@000>W[c^W[c^W[
cP000003h?bf00<0003oooooool0;Oooo`030000oooooooo01;oool001?oool00`000?ooo`000002
00000e@PL@030000IS^9IS^900IV>hT00`0009UVU9UVU00500004YecX`030000]hVT]hVT01RgRJ@0
0`000<ZIXlZIX`0:bYVS1@0000;;T9H00`000=bOTmbOT`09g9nC0`0000C/Xg/2000000W_T3400000
0000000ZFll0001:LML0001PPM`00`0000EmSMP00`0008RHg8RHg002R9SL0P000003UYOB0000WZ7F
00NNXMH00`000:F/g:F/g009YJcL00<0002k]]Bk]]@02[^fe0030000`/CL`/CL00S2a=`00`000<SF
i<SFi006b=KT0P000005bng/00000000jN_>000000;Po;H00`000?ooooooo`0^oooo00<0003ooooo
ool04_ooo`004oooo`060000oooo000000120000E21a0P0000QV>hT400005iecX`030000]hVT]hVT
01RgRJ@00`000<ZIXlZIX`0?bYVS100000[LWi<010000>V[S^V[SP0000?/Xg/4000000?oool00000
00000P000005BW7G0000H87LH87L000000AmSMP00`0008RHg8RHg005R9SL00<0002NXMJNXMH01ijQ
eP030000YJcLYJcL00RU[=`010000:^ghP00000000Rk]]@200002/;4g0030000b=KTb=KT00K8e^@0
0`000<_]k<_]k003bng/00@0003Po;KPo;KPo;Haoooo00<0003oooooool04_ooo`004oooo`<00000
0`00@P0000000008IS^90P000003KdfI0000WG>S01RMLj<00`000;N9Y;N9Y00H]hVT00<0003:VJ?:
VJ<04LZIX`030000fZJP000000800007g9nC00D0003YZhkYZhkYZhh000000^bSN`L0000011iKdP00
04Yae`00009PPM`300000Wf=f0030000R9SLR9SL00F8V=`300001YjQeP030000YJcLYJcL00RU[=`0
0`000:^ghZ^ghP02ZkOR00<0002k]]Bk]]@01;^fe0030000`/CL`/CL00S2a=`200002<SFi0030000
bng/bng/00;;kN`2000000Bfo>40003Po;H0000aoooo00<0003oooooool04_ooo`004oooo`<00000
0`00@P0006HkR@06IS^90P0000=_CIT00`0009ecXiecX`0FWG>S00<0002gRJBgRJ@06KN9Y0030000
bYVSbYVS017:VJ<00`000=ZVX=ZVX002fZJP0`0000CLWi<00`000>V[S^V[SP02jJ^>0`000005m:ad
000000000000oooo00H000001621g00006n=h6n=h0<00006R9SL00D0002@X^6@X^6@X^40000019jQ
eP030000YJcLYJcL00RU[=`00`000:^ghZ^ghP04ZkOR00<0002k]]Bk]]@00[^fe0030000`/CL`/CL
00S2a=`00`000<SFi<SFi006b=KT0P0000C;kN`00`000;KlhKKlh@02]_cQ00<0003oooooool0<?oo
o`030000oooooooo01;oool001;oool3000000<00480000000001FHkR@800005KdfI00<0002MLj>M
Lj<05YecX`030000]hVT]hVT01VgRJ@00`000<ZIXlZIX`0AbYVS00<0003JYZ3JYZ001MZVX0<00000
0mbOT`000>V[SP05jJ^>00<0003d[7@000001@0000047U_B0000?W3K00000V21g0050000KhgPKhgP
KhgP000000J8V=`00`00092RhI2Rh@02T:;Q0P000003WZ7F0000YJcL00RU[=`200002:^ghP800000
0k^fe0000<;4g009`/CL00<00038e^C8e^@01/SFi0030000bng/bng/00?;kN`010000;KlhKKlhKKl
h@80000doooo00<0003oooooool04Oooo`004_ooo`<000000`00@P0000000003IS^90P0000M_CIT0
0`0009ecXiecX`0FWG>S00<0002gRJBgRJ@06KN9Y0030000bYVSbYVS017:VJ<00`000=ZVX=ZVX008
fZJP0P0000KYZhh2000000Gd[7@000000000003oool00`000003?W3K0000000000800003KhgP0`00
00>8V=`00`00092RhI2Rh@05T:;Q0P0000RU[=`00`000:^ghZ^ghP0:ZkOR00<00032a=c2a=`02<;4
g0030000b=KTb=KT00G8e^@200001<_]k0800002]_cQ0P0003Koool00`000?ooooooo`0Aoooo000B
oooo0P000003001200000000009V>hT200002Fm=V@030000WG>SWG>S01JMLj<00`000;N9Y;N9Y00I
]hVT00<0003:VJ?:VJ<04LZIX`030000fZJPfZJP00WJYZ0300001>V[SP8000000oB/M00000000002
000000?oool0?/8GFm<00`000003E83P0000KhgP009_SN000`0007ZHi7ZHi002000000>8V=`0002@
X^401I2Rh@030000UZcVUZcV00800005YJcL00<0002[]n:[]n802J^ghP8000000jk4jP0000000007
`/CL00<00038e^C8e^@01LSFi0030000bng/bng/00?;kN`01@000;KlhKKlhKKlh@00000hoooo00<0
003oooooool04Oooo`004_ooo`8000000`00@P000000000200002fm=V@030000WG>SWG>S01JMLj<0
0`000;N9Y;N9Y00I]hVT00<0003:VJ?:VJ<04LZIX`030000fZJPfZJP00WJYZ000`000>NbVnNbV`02
00000^V[SP030000l[>7000000@00002oooo00D0000GFm<gL=`0001DP>00100000EjV>@200001I2R
h@030000UZcVUZcV00>F[>H200000ZF/g0030000ZkORZkOR00V[]n800`000:k4jZk4jP03[/CZ00<0
0032a=c2a=`00/;4g0800006b=KT0P0000C;kN`200000[Klh@80000ioooo00<0003oooooool04Ooo
o`004_ooo`05000000120000001Q000000e_CIT00`0009ecXiecX`0@WG>S:00000k:VJ<00`000=ZV
X=ZVX009fZJP00<0003W/Y_W/Y/00^NbV`<00002l[>71@0000;oool500000V><i0800003NYST00<0
0021XNR1XNP00P0000:@X^400`0009J/iYJ/iP06UZcV0P0000Z[]n8200001jk4jP8000000l;4g000
0<SFi006b=KT00<0003;kNc;kN`00l_]k0030000]_cQ]_cQ0080000koooo00<0003oooooool04Ooo
o`004_ooo`8000000`00H@000000000=KdfI00<0002MLj>MLj<019ecX``00006WWf^00<0002gTZng
TZl06KNB[`030000bZ6^bZ6^00?:XJh:00001<ZIX`030000fZJPfZJP00WJYZ000`000>NbVnNbV`04
ik:K00<0003b/hOb/hL01@0000?oool5000000=SS>@0001^U^P00P000003NYST0000PJ7X00>1XNP2
000029J/iP8000000iVfk0000:^ghP06ZkOR0P0000Z^a>X300001/SFi0030000bng/bng/00;;kN`2
00000[Klh@80000loooo00<0003oooooool04Oooo`004_ooo`8000000`00H@000000000<KdfI2000
01:NOJh00`000;NB[kNB[`0I]i:_00<0003:XJk:XJh03LZQ[PL00009fZJP00<0003W/Y_W/Y/01>Nb
V`8000000o:cQ`000000000400000_ooo`<0000014aohUf;iP00000000=^U^P20000186Qj0040000
QZ[]0000000019J/iP800004VKK/0P0000B[]n800`000:k4jZk4jP08[/CZ0P0000>_e?<200000/SF
i0800004bng/00<0002fo>6fo>400P0003koool00`000?ooooooo`0Aoooo000Boooo00D000000640
000>07H0000026m=V@@000000g=JYP0009im[P0GWWf^00<0002gTZngTZl06KNB[`030000bZ6^bZ6^
017:XJh00`000=Z^ZmZ^Z`0400001MZVX0030000ik:Kik:K00CW/Y/01`000?6jU@0000000?RhP@00
0?ZcJ`0200000oooo`@000001ef;iP000000000006jFj00007FOk002000000>1XNP00026Z^d00hJZ
k@040000UZcV0000000029Vfk0040000ZkOR000000002:k4jP<00007[mCc0P0000G;kN`00`000;Kl
hKKlh@020000?oooo`030000oooooooo017oool001;oool200000Ph0MP030000KdfIKdfI00=_CIT3
00001G=JYP030000WWf^WWf^01JNOJh00`000;NB[kNB[`0I]i:_00<0003:XJk:XJh04LZQ[P030000
fZj[fZj[00CJ[Z/4000000?JYZ00003W/Y/01NNbV`050000lKZElKZE0000n;R100D00003oooo1P00
0003IiGY00000000009eWn`200001HJZk@80000:VKK/0`0000N^a>X200002:oDl`800002YnCk0P00
0004bng/00000000]_cQ0P00047oool00`000?ooooooo`0Aoooo000Aoooo0`00008>07H00`0006m=
V@000003000027=JYP030000WWf^WWf^01JNOJh00`000;NB[kNB[`0I]i:_00<0003:XJk:XJh04LZQ
[P030000fZj[fZj[00SJ[Z/500000nNbV`030000lKZElKZE00<000001?ZkOP000000000000?oool2
000000AGP=mOS>D0001VUNX2000000=^W^h0000000000WVXl08000000hJZk@0000000002Qk?c0P00
00FI]^`300000iW2m0800003[/CZ0P0000R_e?<200001JOTn`800002]_cQ0P0004;oool00`000?oo
ooooo`0Aoooo000Aoooo0P0000<>07H2000037=JYP030000WWf^WWf^01JNOJh00`000;NB[kNB[`0I
]i:_00<0003:XJk:XJh04LZQ[P030000fZj[fZj[00WJ[Z/010000>JhY^JhY^JhYP@00002lKZE00<0
003f_hl00000100000Coool6000000E]W^h00000001bYo8000000WVXl0800006Qk?c00<0002I]^bI
]^`00P0000RI`_@300001joDl`<00004YnCk0`000003QNS`0000000000800014oooo00<0003ooooo
ool04?ooo`004Oooo`80000010h0MP000000000000ecFZH00`0009im[Yim[P0FWWf^00<0002gTZng
TZl06KNB[`030000bZ6^bZ6^017:XJh00`000=Z^ZmZ^Z`09fZj[00<0003V^:KV^:H01>JhYP@00000
0oJoS`000?W1S00400000oooo`D0000017RPj`000000076VlP@00002N[3f0P0000>7/o<400001iW2
m0<00002U<gk00<0002_e?>_e?<00joDl`800004YnCk0`000003QNS`0000000000<00016oooo00<0
003oooooool04?ooo`004Oooo`<000025Pj500<0001cFZIcFZH02g=JYP030000WWf^WWf^01JNOJh0
0`000;NB[kNB[`0I]i:_00<0003:XJk:XJh04LZQ[P030000fZj[fZj[00WJ[Z/00`000>JhY^JhYP04
i[RV00<0003``9o``9l00`000003nL6<0000000000<00002oooo500000B5_OT200000YW2m0<00006
U<gk00<0002_e?>_e?<00P0000BWi?/2000000>5j?0000000000100004Soool00`000?ooooooo`0@
oooo000Aoooo0P0000<F3XD00`0007=JYW=JYP0;LeZV00<0002NOJjNOJh05Yim[P030000]i:_]i:_
01VgTZl00`000<ZQ[/ZQ[P0AbZ6^00<0003J[Z_J[Z/02MZ^Z`030000i[RVi[RV00CV^:H01@000?30
Wo30W`000?K5VP0U00001IC=n`L00003YnCk0`000003QNS`000000000080001<oooo00<0003ooooo
ool04?ooo`004Oooo`8000035Pj500<0001cFZIcFZH02g=JYP030000WWf^WWf^01JNOJh00`000;NB
[kNB[`0I]i:_00<0003:XJk:XJh04LZQ[P030000fZj[fZj[00WJ[Z/00`000>JhY^JhYP04i[RV00L0
003``9o``9l0003faIX0003haiH0:00000>4e_l700000XGXl080001@oooo00<0003oooooool04?oo
o`004Oooo`8000035Pj500<0001cFZIcFZH02g=JYP030000WWf^WWf^01JNOJh00`000;NB[kNB[`0I
]i:_00<0003:XJk:XJh04LZQ[P030000fZj[fZj[00WJ[Z/00`000>JhY^JhYP04i[RV00L0003``9o`
`9l0003faIX0003haiH03@0000Soool2000000<PYN80000000004@000003Flo`0000000000D0001C
oooo00<0003oooooool04?ooo`004Ooooh<0000@oooo3`0005[oool00`000?ooooooo`0@oooo000A
oooo0P0000<F5i000`0007=S/G=S/@0;Lf>a00<0002NQ[RNQ[P05Yj6^0030000]iZi]iZi01VgV[T0
0`000<ZY^<ZY^00AbZVh00<0003J]KCJ]K@02MZe]0030000i/2_i/2_00CV`:l01`000?37Z?37Z000
0?K<XP000?S>WP0>00001ooooaH000000e/00000000000050000Doooo`030000oooooooo013oool0
017oool200000aHGT0030000Lf>aLf>a00]cHk400`0009j6^9j6^00FWXJh00<0002gV[VgV[T06KNJ
^@030000bZVhbZVh017:ZKP00`000=Ze]=Ze]009f[Fd00<0003V`:oV`:l01>K0[`050000l<NXl<NX
0000m/bR02/00002Q0401`000004Q@00000000000000D?ooo`030000oooooooo013oool0017oool2
00000aHGT0030000Lf>aLf>a00]cHk400`0009j6^9j6^00FWXJh00<0002gV[VgV[T06KNJ^@030000
bZVhbZVh017:ZKP00`000=Ze]=Ze]009f[Fd00<0003V`:oV`:l01>K0[`030000l<NXl<NX00<00000
0oWEY0000000000Q00001Y@U;@H00003YbdJ0`000003Q@00000000000080001<oooo00<0003ooooo
ool04?ooo`004Oooo`@000000aHGT00007=S/@0<Lf>a00<0002NQ[RNQ[P05Yj6^0030000]iZi]iZi
01VgV[T00`000<ZY^<ZY^00AbZVh00<0003J]KCJ]K@02MZe]0030000i/2_i/2_00CV`:l01`000?37
Z?37Z0000?KCZ0000?WEY00500000_oooa@00003QA`d0P0000>I>4`300001Y@U;@030000[dY:[dY:
00800004YbdJ0`000003Q@000000000000<00018oooo00<0003oooooool04?ooo`004Oooo`800002
3QVF0P0000ecHk400`0009j6^9j6^00FWXJh00<0002gV[VgV[T06KNJ^@030000bZVhbZVh017:ZKP0
0`000=Ze]=Ze]009f[Fd00<0003V`:oV`:l01>K0[`@000000oKCZ0000000000400000oooo`L00000
0g4B?0000000000300000WXF>0800003QbU9100000NI>4`300000Y@U;@030000[dY:[dY:00>_BTX2
00001JL]6P800002Q@00100004Koool00`000?ooooooo`0@oooo000Aoooo0P0000<>6IH2000037=S
/@030000WXJhWXJh01JNQ[P00`000;NJ^KNJ^@0I]iZi00<0003:ZKS:ZKP04LZY^0030000f[Fdf[Fd
00WJ]K@010000>K0[nK0[nK0[`@00002lLn_00@0003fdjP0003jgJP300001?ooo`T00000178C?P00
07TMAgTMA`<00004QbU90P0000:I@el300001iThC0<00007[dY:0`0000BW;AX300000XD000<00014
oooo00<0003oooooool04?ooo`004Oooo`<000023QVF00<0001_J;/000000`0000QcHk400`0009j6
^9j6^00FWXJh00<0002gV[VgV[T06KNJ^@030000bZVhbZVh017:ZKP00`000=Ze]=Ze]007f[Fd1P00
00?Wb;L00`000?7?[o7?[`03000000CjgJP0000000000003oooo1`00009^5TH3000000=i7DL00000
00000XH`E`8000000hLYB@0009U3G`06VD=O0P0000>I>4`200000jiHIP800008[dY:0P0000JW;AX0
0`000;H]000000020000@_ooo`030000oooooooo017oool0017oool300000PhIUP030000KfRkKfRk
00=_J;/300001G=S/@030000WXJhWXJh01JNQ[P00`000;NJ^KNJ^@0I]iZi00<0003:ZKS:ZKP04LZY
^0030000f[Fdf[Fd00?J]K@400000]Zn_@030000ilRgilRg00CWb;L01@000?7?[o7?[`000?SL[@05
00000oooo`<0000015`:B00006LCBfLCB`800002MB1?0P0000J6<5L00`0009U3GiU3G`08VD=O0`00
00N^F6H300001jm:BP800002YbdJ0P000004behm00000000]Rd00P00047oool00`000?ooooooo`0A
oooo000Boooo00D000004iP0000>6IH0000026mX^`@000000g=S/@0009j6^00GWXJh00<0002gV[Vg
V[T06KNJ^@030000bZVhbZVh017:ZKP00`000=Ze]000000300001]Zn_@030000ilRgilRg00CWb;L0
1`000?7?[`0000000?SL[@000?[VZ@0200000oooo`T000000gDPC`0000000002PC9O00@00026<5N6
<5N6<5L2000000>FB6`00000000029U3G`040000Zemg000000002JiHIP800007[dY:0P0000G;GSd0
0`000;H]0;H]00020000?oooo`030000oooooooo017oool001;oool2000000<04iP00000000036mX
^`P0000BWXJh00<0002gV[VgV[T06KNJ^@030000bZVhbZVh00c:ZKP700002]Zn_@030000ilRgilRg
00CWb;L2000000?bfKD000000000100000?oool600000VhMD`800005PC9O00<00026<5L000001II8
K0800004VD=O0P0000B[GgL00`000:iHIZiHIP08[UQV0P0000>_BTX200000/QaJ0800004behm00<0
002f;@2f;@000P0003koool00`000?ooooooo`0Aoooo000Boooo0P00000301>H0000000000e_J;/0
0`0009f=`if=``04WHg3300000JNQ[P00`000;NJ^KNJ^@0I]iZi00<0003:ZKS:ZKP00/ZY^0X00005
b[7100<0003J_[gJ_[d02MZn_@030000ilRgilRg00CWb;L00`000?;I]O;I]@0500000oooo`D00000
16<FD`0000000000009j;f@00`00084bGh4bG`02PC9O0P0000RFB6`2000000>I@el0002[GgL01Z]O
M`80000;[UQV0P0000K8LFP00`000<]N?L]N?@02behm0P0000:f;@020000??ooo`030000oooooooo
017oool001;oool010000005T`00000CV080000<KfRk00<0002MSL>MSL<049f=`bL0000?b[7100<0
003J_[gJ_[d02MZn_@030000ilRgilRg00;Wb;L300000_;I]@030000nNF_000000800002oooo0P00
0003=`0h00000000009S5U<00`0007X_I7X_I002NRmT00<00021<Un1<Ul00P0000:@BG<00`0009I8
K9I8K006UTQ/0P0000Z[GgL200001jiHIP8000000l9hO`000<QaJ006b75X00<0003;GSg;GSd00l]N
?@050000]Rd0]Rd0]Rd0000003_oool00`000?ooooooo`0Aoooo000Boooo0`00000301>H0000IV_4
0080000:KfRk00<0002MSL>MSL<05Yf=``030000]j;3]j;301VgX/<00`000<Za`LZa`@0Ab[7100<0
003J_[gJ_[d02MZn_@030000ilRgilRg00800002jM:n00<0003bfKD00000100000;oool01@0001L0
8P00000005@9CP0400001GX_I0800005T4Uc00<0002FB6bFB6`00iI8K0800002YF:200<0002[GgN[
GgL02J]OM`030000[UQV[UQV00>^F6H00`000<9hOl9hO`02`WQo0P0000K8LFP200001<]N?@800002
]Rd00P0003Woool00`000?ooooooo`0Aoooo000Boooo0P00000300FC0000000000=VJl@2000026mX
^`030000WHg3WHg301JMSL<00`000;NR`kNR``0I]j;300<0003:/L7:/L404LZa`@030000f[jmf[jm
00WJ_[d300001>WB_P030000l]Ve000000@000002?ooo`000000000003h0@`0005@9CP00009_:6@0
100007X_I7X_I7X_I0<00007T4Uc00<0002FB6bFB6`00P0000FUHX800`000:]OMj]OM`09Zemg0P00
0003[UQV0000000000O2N7l00`000<QaJ<QaJ005b75X00<0003;GSg;GSd00l]N?@050000]Rd0]Rd0
]Rd0000003Soool00`000?ooooooo`0Aoooo000Boooo0`00000300FC0000000000AVJl@200001VmX
^`030000WHg3WHg301JMSL<00`000;NR`kNR``0I]j;300<0003:/L7:/L404LZa`@030000f[jmf[jm
00SJ_[d200001^WB_P8000001OCS^000000000000?ooo`02000000<N02h0000000000`0000=_:6@3
00000hQ6N0030000T4UcT4Uc00F@BG<200002:ERPP030000ZemgZemg00Z[GgL00`000<9hOl9hO`08
`WQo00<00038LFS8LFP01LQaJ0800004behm0P0000>f;@000`000?ooooooo`0doooo00<0003ooooo
ool04Oooo`004_ooo`<000000`05T`0000000006IV_40P0000A_J;/00`0009f=`if=``0FWHg300<0
002gX/>gX/<06KNR``030000b[71b[71017:/L400`000=Zn_MZn_@05f[jm0`000003g<S60000jM:n
00GYd[h00`000?CS^0000003000000Koool000/N02h0000n04<00002H1aP00D0001_:6A_:6A_:6@0
00001HQ6N0030000T4UcT4Uc00>@BG<2000000>NHXT0002UHX802:ERPP800008Zemg0P000003^g^=
0000`WQo00W2N7l00`000<QaJ<QaJ006b75X00<0003;GSg;GSd00l]N?@030000]Rd0]Rd000:f;@00
0`000?ooooooo`0boooo00<0003oooooool04Oooo`004oooo`<000000`05T`0006I[a007IV_40P00
009_J;/00`0009f=`if=``0FWHg300<0002gX/>gX/<06KNR``030000b[71b[71017:/L400`000=Zn
_MZn_@02f[jm0`0000CLb<H00`000>WB_^WB_P02jM:n0`000005m>>h000000000000oooo00800000
1Qh0;P0000000000060LH000009_:6@300001XQ6N0050000T4UcT4UcT4Uc000000BNHXT00`000:ER
PZERPP08YF:200<0002[GgN[GgL01:]OM`030000^g^=^g^=00:kNhd00`000<9hOl9hO`08`WQo00<0
0038LFS8LFP01/QaJ0800004behm00<0002f;@2f;@000[H]00030000oooooooo033oool00`000?oo
ooooo`0Boooo000Coooo0`00000300FC0000000000UVJl@3000069f=``030000]j;3]j;301VgX/<0
0`000<Za`LZa`@0Ab[7100<0003J_[d000000P0000OLb<H01@000>WB_^WB_^WB_P000002k=k40P00
0004mNjh00000000oooo0`000004BPQF0000H1aPH1aP0`00009m@7T00`0008Q6N8Q6N004R4Ih00@0
002@BG<000000006WV:900<0002UHX:UHX802:ERPP030000ZemgZemg00:[GgL00`000;]kSK]kS@04
^g^=0P0000W2N7l200002<QaJ0030000behmbehm00;;GSd2000000Bf;@00003PLPd0000aoooo00<0
003oooooool04_ooo`004oooo`030000oooo0000008000000eAZc00000000009IV_40`0001NMSL<0
0`000;NR`kNR``0H]j;300<0003:/L7:/L403lZa`@@0000:g<S600@0003Yd[kYd[h00003k=k41000
0008oooo00000000:P130000BPQF0000H1aP0P0000Am@7T00`0008Q6N8Q6N005R4Ih00<0002NHXVN
HXT01iiRR@030000YF:2YF:200RUHX8010000:]OM`00000000VkNhd00`000<9hOl9hO`08`WQo00<0
0038LFS8LFP01/QaJ0030000behmbehm00?;GSd010000>1b3N1b3@00037oool00`000?ooooooo`0B
oooo000Coooo00<0003oool000000P0000=DJ/`00`0006I[a6I[a006IV_400<0002IU<fIU<d01@00
01:MSL<00`000;NR`kNR``0H]j;300<0003:/L7:/L402/Za`@D00002bk_;00<0003Lb<KLb<H02Mc8
aP<00004k=k400<0003ek[P000000`000003:P130000BPQF00<000000fldM`0007e0N@04OD1i00<0
0028AWR8AWP00XQ6N08000000iIOS@0009iRR@07WV:900<0002UHX:UHX802:ERPP80000<^g^=00<0
0032N7o2N7l02<9hO`030000b75Xb75X00K8LFP2000000G;GSd00000003YTV4000000^1b3@030000
oooooooo02koool00`000?ooooooo`0Boooo000Coooo00<0003oool000000P0000ADJ/`00`0006I[
a6I[a005IV_400<0002IU<fIU<d01IVDc@H0000<WHg300<0002gX/>gX/<06;NR``030000b[71b[71
00G:/L4500001l^kb`030000g<S6g<S600WLb<H00`000>cNa>cNa003k=k41`000004:P130000BPQF
00000fldM`030000OD1iOD1i00=m@7T00`0008Q6N8Q6N00200000iIOS@030000WV:9WV:900NNHXT0
0`000:ERPZERPP05YF:20P0000:cNiH00`000;]kSK]kS@0:^g^=00<00032N7o2N7l02<9hO`030000
b75Xb75X00O8LFP01@000>VBHNVBHNVBH@000003h78=00<0003oooooool0;Oooo`030000oooooooo
01;oool001?oool00`000?ooooooo`0200001EAZc0800005IV_400<0002IU<fIU<d02iVDc@D00007
WHg300<0002gX/>gX/<06;NR``030000b[71b[7100D0000<bk_;00<0003Lb<KLb<H01mc8aP<00004
k=k400<0003^k<P000002@0000=_=7L00`0007e0NGe0N@03OD1i0`0000JFGhd00`0009iRRIiRR@07
WV:900<0002UHX:UHX800ZERPP800005/g^F00<0002kNhfkNhd02[]kS@030000`WQo`WQo00S2N7l0
0`000<QaJ<QaJ005b75X00<0003NUhD000000nVBH@040000h78=h78=0000;oooo`030000oooooooo
01;oool001Coool00`000?ooo`00000200001UAZc0030000IV_4IV_4009VJl@00`0009VDcIVDc@0@
VIC=1@0000:MSL<00`000;NR`kNR``0;]j;34000017;^l/00`000=c8a]c8aP05g<S60P0000;NeLl0
0`000>cNa>cNa00200000^k/b0D000001BX0@`0005XSL5XSL0000003KcAg00<0001m@7Um@7T00We0
N@800008UUn=00<0002NHXVNHXT029iRR@040000YF:2000000002;=kUP030000^g^=^g^=00ZkNhd0
0`000<9hOl9hO`08`WQo0P0000?8LFP200000]jGQ@030000jI9QjI9Q00;YTV4010000>1b3N1b3@00
02goool00`000?ooooooo`0Coooo000Doooo00<0003oooooool00`0000IDJ/`00`0006I[a6I[a002
IV_400<0002IU<fIU<d059VDcA00000=]Z_>00<0003;^l_;^l/04/^kb`030000g<S6g<S600;Lb<H2
00001=kEc`030000k=k4000000?^k<P4000000@00240000000000002FR=`00D0001_=7M_=7M_=7L0
00000We0N@8000000haIT00009IOS@08UUn=00<0002NHXVNHXT029iRR@030000/g^F/g^F00VcNiH0
0`000;]kSK]kS@0:^g^=00<00032N7o2N7l02L9hO`030000b75X000000GNUhD01@000>VBHNVBHNVB
H@000002h78=00<0003oooooool0:oooo`030000oooooooo01?oool001Coool00`000?ooooooo`02
000000<dHM00000000001EAZc0050000IV_4IV_4IV_4000001RIU<d00`000;J[c[J[cP0H]Z_>00<0
003;^l_;^l/04/^kb`030000g<S6g<S600800006g]G?0P0000?^k<P00`000>[ia0000003000000<k
1V40001J8g000UXSL0040000KcAgKcAgKcAg0`0000B<FI000`0009IOSIIOS@07UUn=00<0002NHXVN
HXT01IiRR@8000000jajW@000;=kUP0:/g^F00<0002kNhfkNhd02[]kS@80000:`WQo00<0003NUhGN
UhD01MjGQ@050000jI9QjI9QjI9Q000000;PLPd00`000?ooooooo`0Zoooo00<0003oooooool04ooo
o`005?ooo`030000oooooooo00<00002=67@00<0001DJ/aDJ/`00eAZc08000000fI[a00009VDc@0G
VIC=00<0002fZljfZlh06;J[cP030000bk_;bk_;01;;^l/300002=kEc`060000k^c8k^c8k^c80000
j_W40`0000042012>`IQ>`IQ00000UXSL0030000KcAgKcAg009_=7L00`0008aIT8aIT004S5V@00<0
002FGhfFGhd01iIOS@030000WV:9WV:900>NHXT200000jajW@030000/g^F/g^F00ZcNiH00`000;]k
SK]kS@0;^g^=00<00032N7o2N7l01L9hO`8000000m:GU`000=jGQ@05gYN500<0003YTV7YTV400^VB
H@040000h78=h78=0000:oooo`030000oooooooo01?oool001Coool01`000?ooooooooooo`000015
a`000002=67@00<0001DJ/aDJ/`015AZc080000HVIC=00<0002fZljfZlh06;J[cP030000bk_;bk_;
017;^l/200002MkEc`800003k^c800H0003ZnL@0000000P804800002>`IQ00@0001J8g1J8g000002
KcAg0`0000J<FI000`0009IOSIIOS@08UUn=00D0002NHXVNHXVNHXT000001ZajW@030000/g^F/g^F
00ZcNiH00`000;]kSK]kS@0;^g^=00<00032N7o2N7l00/9hO`800003dYNG00<0003NUhGNUhD01MjG
Q@050000jI9QjI9QjI9Q000000;PLPd00`000?ooooooo`0Yoooo00<0003oooooool04oooo`005Ooo
o`040000oooooooo00000P15a`040000=67@=67@00001UAZc0<0000FVIC=00<0002fZljfZlh06;J[
cP030000bk_;bk_;00g;^l/4000000?;amH0003NeLl01]kEc`8000001^3Ue`000>k/b>k/b0000>[i
a0<0000010P0@P0003/6H@0000=J8g0300000Wi@T0030000S5V@S5V@00F<FI000`0009IOSIIOS@07
UUn=00@0002NHXT000000008[7ZM00<0002cNiJcNiH02K=kUP030000^g^=^g^=00bkNhd010000<9h
O`00000000KBUiL00`000=jGQMjGQ@05gYN500D0003YTV7YTV7YTV4000000^1b3@030000oooooooo
02Ooool00`000?ooooooo`0Doooo000Eoooo00D0003oooooooooool000000P15a`040000=67@=67@
00001EAZc0030000TI_ITI_I00@0000BVIC=00<0002fZljfZlh06KJ[cP030000bk_;bk_;00W;^l/3
00001L_7eP030000g]G?g]G?00CNeLl020000>3Uen3Uen3Ue`000>k/b0000>[ia08000000`002000
00000002>`IQ00D0001J8g1J8g1J8g00000017i@T0030000S5V@S5V@00F<FI000`0009IOSIIOS@08
UUn=00<0002/NYf/NYd02JajW@030000/g^F/g^F00VcNiH00`000;]kSK]kS@0<^g^=00<0003BUiOB
UiL01m:GU`030000gYN5gYN500CNUhD00`000>VBHNVBH@02jI9Q00@0003PLPgPLPd0000Xoooo00<0
003oooooool05?ooo`005Oooo`030000oooooooo00;oool010000015a`15a`00008dHM000`0005AZ
c5AZc002E6[<00<0002AVmVAVmT0196Kf@@0000>VIC=00<0002fZljfZlh06KJ[cP030000bk_;bk_;
00K;^l/300002<_7eP030000g]G?g]G?00?NeLl00`000>3Uen3Ue`02h>GG0P000003j_W400000000
008000001PP0@P0003/6HC/6H@0005XSL0<00005OU2@00<0002<FI2<FI001HaIT0030000UUn=UUn=
00FFGhd2000000>SMj80002/NYd02JajW@030000/g^F/g^F00ZcNiH00`000;]kSK]kS@09^g^=0P00
0003b9JR0000dYNG00OBUiL00`000=jGQMjGQ@05gYN500D0003YTV7YTV7YTV4000000^1b3@030000
oooooooo02Koool00`000?ooooooo`0Doooo000Foooo00<0003oooooool00_ooo`04000004G704G7
00000SAQd0050000E6[<E6[<E6[<000000ZAVmT400002YVDc@030000]Z_>]Z_>01VfZlh00`000<^k
bl^kb`02bk_;100000_;amH00`000=kEcmkEc`02g]G?00<0003PiMOPiML00n3Ue`030000j_W4j_W4
00D00002>`IQ0`00009[@H`00`0007i@T7i@T003OU2@00<0002<FI2<FI001HaIT0030000UUn=UUn=
00>FGhd200000j=gXP030000[7ZM[7ZM00V/NYd00`000;=kU[=kUP0:/g^F00<0002kNhfkNhd01k]k
S@050000b9JRb9JRb9JR000000WBUiL00`000=jGQMjGQ@05gYN500D0003YTV7YTV7YTV4000000^1b
3@030000oooooooo02Coool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool00oooo`040000
04G704G700000SAQd0800002E6[<00<0002AVmVAVmT02i6Kf@@00006VIC=00<0002fZljfZlh06KJ[
cP030000bk_;00000080000?blOF00D0003NeLoNeLoNeLl000001N3Ue`8000000n[ia00000000002
000000<80480000k1V400P0000A[@H`00`0007i@T7i@T003OU2@00<0002<FI2<FI001HaIT0040000
UUn=UUn=UUn=0P0000JSMj800`000:ajWJajW@09[7ZM00<0002cNiJcNiH02[=kUP030000^g^=^g^=
00BkNhd200001LRFXP030000dYNGdYNG00OBUiL00`000=jGQMjGQ@04gYN500<0003YTV7YTV400^VB
H@040000h78=h78=00009Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`04oooo00<0
0000ALL0000013AQd0030000E6[<0000016AVmT400000YVDc@030000]Z_>]Z_>00^fZlh@00004/_7
eP040000g]G?000000001>3Ue`800002gOOK00<0003CnJ_oool01@000003CRR30000Jd6<00=[@H`0
0`0007i@T7i@T003OU2@00<0002<FI2<FI001XaIT0<00008XgNR00<0002/NYf/NYd02JajW@030000
/g^F/g^F00^cNiH00`000;]kSK]kS@02^g^=00<00038UZ;8UZ801LRFXP030000dYNGdYNG00OBUiL0
0`000=jGQMjGQ@05gYN500<0003YTV7YTV400^VBH@030000h78=000002Goool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool01Oooo`03000004G7000000@dHM0200005I6KfA00000>/kGJ00<0
003;amK;amH04L_7eP800005h>GG00@0003Mmm_Mmm_Mmm/700000dhXP`030000Jd6<Jd6<009[@H`0
0`0007i@T7i@T003OU2@00<0002<FI2<FI001XaIT0030000XgNRXgNR00VSMj800`000:ajWJajW@09
[7ZM00<0002cNiJcNiH02k=kUP040000^g^=000000002LRFXP030000dYNGdYNG00OBUiL00`000=jG
QMjGQ@04gYN500<0003YTV7YTV400^VBH@040000h78=h78=00009?ooo`030000oooooooo01Goool0
01Ooool00`000?ooooooo`05oooo00<00000ALL0000013AQd080000FTI_I00<0002c]MZc]MX06K>e
fP030000blOFblOF013;amH200001N3Ue`030000gOOKgOOK008000000lKnb`000?ooo`02000000<K
06/0001>:8<00ThXP`030000Jd6<Jd6<009[@H`00`0007i@T7i@T003OU2@00<0002<FI2<FI0018aI
T0<0000;XgNR00<0002/NYf/NYd02ZajW@030000/g^F/g^F00^cNiH00`000<RFX/RFXP09b9JR00<0
003BUiOBUiL02=:GU`030000gYN5gYN500CNUhD00`000>VBHNVBH@02jI9Q00<0003PLPd000008ooo
o`030000oooooooo01Koool001Ooool00`000?ooooooo`05oooo00@00000ALL0ALL00003=67@00<0
0022X>L000000P0001>AVmT00`000;>ef[>efP0I/kGJ00<0003;amK;amH03L_7eP<000000l_Gh`00
0>3Ue`03h>GG00@0003Mmm_Mmm/00002a_k;00@0003oooooool000026`1[00D0001>:8=>:8=>:8<0
000016]1S0030000OU2@OU2@00AnD900100008aIT8aIT8aIT0800003VG:U00<0002SMj:SMj802J=g
XP030000[7ZM[7ZM00V/NYd00`000;=kU[=kUP09/g^F0P000003`9BY0000b9JR00[8UZ800`000=:G
Um:GU`07dYNG00<0003NUhGNUhD01MjGQ@030000jI9QjI9Q00;YTV400`000>1b3@00000Roooo00<0
003oooooool05_ooo`005oooo`030000oooooooo00Koool010000015a`15a`00008dHM000`0008:P
ih:Pi`02PZ3W0`00012AVmT00`000;>ef[>efP0I/kGJ00<0003;amK;amH02/_7eP<00004bmOS00D0
003PiMOPiMOPiML000000]ggf`040000a_k;a_k;00000_ooo`050000000d6`1[6`1[000000=>:8<0
0`0006]1S6]1S002Jd6<00<0001nD91nD90017i@T0040000S5V@S5V@00001IUbY@030000XgNRXgNR
00VSMj800`000:ajWJajW@0:[7ZM00<0002cNiJcNiH01[=kUP800003`9BY00<00038UZ;8UZ802/RF
XP030000dYNGdYNG00OBUiL00`000=jGQMjGQ@04gYN500<0003YTV7YTV400^VBH@040000h78=h78=
00008Oooo`030000oooooooo01Koool001Soool00`000?ooooooo`06oooo00H00000ALL0ALL0000d
HM000007PZ3W0`0000fAVmT00`000;>ef[>efP0I/kGJ00<0003;amK;amH01l_7eP<00007bmOS00@0
003PiML000000002gOOK00@00036o/_6o//00003oooo0P0000036`1[0000CRR300=>:8<00`0006]1
S6]1S002Jd6<00<0001nD91nD90017i@T0<00007VG:U00<0002SMj:SMj802J=gXP030000[7ZM[7ZM
00Z/NYd00`000;=kU[=kUP04/g^F00<00030U:W0U:T01<2DZ@030000b9JRb9JR00W8UZ800`000=:G
Um:GU`07dYNG00<0003NUhGNUhD01MjGQ@030000jI9QjI9Q00;YTV400`000>1b3N1b3@0Poooo00<0
003oooooool05oooo`006?ooo`030000oooooooo00Ooool00`000015a`15a`0200002X:Pi`@0000:
TI_I00<0002c]MZc]MX06;>efP030000blOFblOF00G;amH200002/_Gh`800003gOOK00@00036o/_6
o//00004oooo0P0000036`1[0000CRR300=>:8<00`0006]1S6]1S002Jd6<00<0001nD91nD90017i@
T0030000VG:UVG:U00NILZD00`000:=gXZ=gXP0:XgNR00<0002/NYf/NYd02ZajW@040000/g^F/g^F
/g^F0P0000O0U:T00`000<RFX/RFXP0:b9JR00<0003BUiOBUiL01m:GU`030000gYN5gYN500GNUhD0
0`000>VBHNVBH@02jI9Q00<0003PLPd000007oooo`030000oooooooo01Ooool001Soool00`000?oo
ooooo`08oooo00<00000ALL0ALL00P0000f2X>L300001i6Kf@030000/kGJ/kGJ01Rc]MX00`000<_7
e/_7eP02blOF0`0000_;en<200000]ggf`8000000lKnb`0000000005oooo0P0000036`1[0000CRR3
009>:8<00`0006]1S6]1S003Jd6<00<0001nD91nD9000Wi@T0<0000:VG:U00<0002SMj:SMj802J=g
XP030000[7ZM[7ZM00Z/NYd010000;=kUP00000000[0U:T00`000<RFX/RFXP09b9JR00<0003BUiOB
UiL02=:GU`030000gYN5gYN500CNUhD00`000>VBHNVBH@03jI9Q00?PLPd0003oool07_ooo`030000
oooooooo01Ooool001Woool00`000?ooooooo`08oooo00@00000ALL0001OXO<200003X:Pi`<00004
TI_I00<0002c]MZc]MX06;>efP030000blOF00000080000<bmOS0P000004aN__0000gOOK00000/Kn
b`030000oooooooo00Coool3000000<K06/0001>:8<00ThXP`030000Jd6<Jd6<00=[@H`00`0007i@
T7i@T00200000he[Y`030000VG:UVG:U00NILZD00`000:=gXZ=gXP0:XgNR00<0002/NYf/NYd02Zaj
W@030000`9BY`9BY00_0U:T00`000<RFX/RFXP09b9JR00<0003BUiOBUiL01m:GU`030000gYN5gYN5
00GNUhD00`000>VBHNVBH@02jI9Q0P0001koool00`000?ooooooo`0Hoooo000Ioooo00<0003ooooo
ool02Oooo`800003Gj7c0`0000j2X>L3000000>AVmT0002c]MX03;>efPl0000=bmOS0P0000?5jnl2
00000/Knb`030000oooooooo00Goool01@000000=00001/0J`000003CRR300<0001[@Ha[@H`00f]1
S0<00005SF^W00<0002ILZFILZD029UbY@030000XgNRXgNR00VSMj800`000:ajWJajW@08[7ZM0P00
0003]i6_0000`9BY00_0U:T00`000<RFX/RFXP0:b9JR00<0003BUiOBUiL01m:GU`030000gYN5gYN5
00GNUhD00`000>VBHNVBH@0300007_ooo`030000oooooooo01Soool001Woool00`000?ooooooo`0:
oooo0P0000EOXO<300003X:Pi`l0000=[/;Y00<0003;en?;en<02L_Gh`<00005aN__00@00036o/_6
o//00008oooo0P00008K06/01@0004hXPdhXPdhXP`000004Jd6<0P0000N=JjL00`0009UbYIUbY@08
VG:U00<0002SMj:SMj802Z=gXP030000[7ZM[7ZM00F/NYd200000kNA[`030000`9BY`9BY00_0U:T0
0`000<RFX/RFXP09b9JR00<0003BUiOBUiL02=:GU`030000gYN5gYN500CNUhD01`000>VBH@000?g6
P`000>jb=P00000Moooo00<0003oooooool06?ooo`006_ooo`030000oooooooo00[oool200001enQ
l`80000=PZ3W00<0002^`^V^`^T06:k2j@030000bmOSbmOS00O;en<200001/G[k`<000000lKnb`00
0?ooo`08oooo0P00008K06/01@0004hXPdhXPdhXP`000002Jd6<0P000003Nf2X0000SF^W00N=JjL0
0`0009UbYIUbY@08VG:U00<0002SMj:SMj802J=gXP030000[7ZM[7ZM00B/NYd00`000;NA[kNA[`04
]i6_00<00030U:W0U:T02/2DZ@030000b9JRb9JR00[8UZ800`000=:GUm:GU`07dYNG00<0003NUhGN
UhD01MjGQ@060000oLJ3oLJ30000k[8f00007?ooo`030000oooooooo01Woool001[oool00`000?oo
ooooo`0;oooo0`0000MOXO<300002X:Pi`030000[/;Y[/;Y01R^`^T00`000<_Ghl_Gh`04bmOS0`00
00K5jnl200000ZOgjP800009oooo0`0000036`1[0000CRR300=>:8<300000g]PZ0030000SF^WSF^W
00J=JjL00`0009UbYIUbY@08VG:U00<0002SMj:SMj802Z=gXP040000[7ZM[7ZM[7ZM0P0000NgTJl0
0`000<2DZL2DZ@0;`9BY00<00038UZ;8UZ802LRFXP030000dYNGdYNG00SBUiL00`000=jGQMjGQ@03
gYN50P0000?maX<200007?ooo`030000oooooooo01Woool001[oool00`000?ooooooo`0=oooo1000
00MOXO<2000028:Pi`030000[/;Y[/;Y01V^`^T010000<_Ghl_Ghl_Gh`800007aN__0P0000:WmnX2
00002oooo`050000000d00006`1[000000=>:8<200001W]PZ0030000SF^WSF^W00J=JjL00`0009Ub
YIUbY@08VG:U00<0002SMj:SMj802J=gXP040000[7ZM000000002[NA[`030000`9BY`9BY00_0U:T0
0`000<RFX/RFXP09b9JR00<0003BUiOBUiL02=:GU`030000gYN5gYN5008000000no0X@000?g6P`02
oLJ30P0001coool00`000?ooooooo`0Ioooo000Koooo00<0003oooooool03_ooo`@00007Gj7c0`00
00J2X>L00`000:k2jJk2j@0H[/;Y00@0003;en<000000007aN__0P0000:WmnX200003Oooo`060000
000d00006`1[0000CRR30P000003GdfT0000Nf2X00EkH:P00`0008e[Yhe[Y`06SF^W00<0002ILZFI
LZD029UbY@030000XgNRXgNR00ZSMj800`000;NA[kNA[`0:]i6_00<00030U:W0U:T02l2DZ@030000
b9JRb9JR00W8UZ800`000=:GUm:GU`08dYNG00<0003NUhD000000no0X@040000oLJ3oLJ3oLJ30P00
01_oool00`000?ooooooo`0Joooo000Koooo00<0003oooooool04?ooo`D00007Gj7c0`0000>2X>L0
0`000:k2jJk2j@0B[/;Y200000O5jnl200000ZOgjP80000?oooo0P00008K06/200000em=Y0030000
Nf2XNf2X00AkH:P00`0008e[Yhe[Y`06SF^W00<0002ILZFILZD02IUbY@030000XgNRXgNR00NSMj82
000000>_S[@0002gTJl02kNA[`030000`9BY`9BY00_0U:T00`000<RFX/RFXP09b9JR00<0003BUiOB
UiL02=:GU`030000kl2Qkl2Q00?_`:400`000?g6Pog6P`0200006oooo`030000oooooooo01[oool0
01_oool00`000?ooooooo`0Boooo1@0000QOXO<2000000>2X>L0002^`^T01Jk2j@h00006W]7i00<0
0035jno5jnl01<G[k`800002YoOZ0P00013oool6000015m=Y0030000Nf2XNf2X00AkH:P00`0008e[
Yhe[Y`07SF^W00<0002ILZFILZD029UbY@030000XgNRXgNR00FSMj8200000jn>]0030000]i6_]i6_
00^gTJl00`000<2DZL2DZ@0;`9BY00<00038UZ;8UZ802LRFXP030000dYNGdYNG00GBUiL300001No0
X@030000oLJ3oLJ30080000Koooo00<0003oooooool06_ooo`007?ooo`030000oooooooo01Coool5
00001enQl`P0000DW]7i00<00035jno5jnl00/G[k`800002YoOZ0P0001;oool300000RhXV0030000
GdfTGdfT00=OCJ@00`0007]PZ7]PZ004Nf2X00<0002=JjN=JjL01Xe[Y`030000VG:UVG:U00VILZD0
0`000:=gXZ=gXP03XgNR00<0002_S[B_S[@01:n>]0030000]i6_]i6_00ZgTJl00`000<2DZL2DZ@0;
`9BY00<00038UZ;8UZ802LRFXP030000dYNGdYNG00?BUiL200000^6i[`030000kl2Qkl2Q00?_`:40
1P000?g6Pog6P`000>jb=P0001Woool00`000?ooooooo`0Koooo000Loooo00<0003oooooool05_oo
o`8000000`V3hP0000000006Gj7c00<0002NdOVNdOT069kAn@030000aN__aN__00800002YoOZ0P00
01Coool00`000000J`000002;RRH00<0001OCJAOCJ@00em=Y0030000Nf2XNf2X00AkH:P00`0008e[
Yhe[Y`06SF^W00<0002ILZFILZD02IUbY@040000XgNRXgNRXgNR0P0000N_S[@00`000;NA[kNA[`0;
]i6_00<00030U:W0U:T02l2DZ@030000b9JRb9JR00W8UZ801@000=:GUm:GUm:GU`000005hKV_00<0
003_`:7_`:400^o0X@060000oLJ3oLJ30000k[8f00006Oooo`030000oooooooo01_oool001coool0
0`000?ooooooo`0Hoooo1P0000=OXO<00`0009kAnIkAn@0HW]7i00<00035jnl000000ZOgjP80000F
oooo00<0000006/000000RhXV0030000GdfTGdfT00=OCJ@00`0007]PZ7]PZ004Nf2X00<0002=JjN=
JjL01he[Y`030000VG:UVG:U00VILZD300002Zn>]0030000]i6_]i6_00ZgTJl00`000<2DZL2DZ@0;
`9BY00<00038UZ;8UZ802LRFXP040000dYNG000000001^6i[`030000kl2Qkl2Q00;_`:4010000?g6
Pog6Pog6P`80000Ioooo00<0003oooooool06oooo`007Oooo`030000oooooooo01[oool2000000D9
Pn800000001OXO<000003IkAn@h00002YoOZ0P0001Soool00`000000J`000002;RRH00<0001OCJAO
CJ@00em=Y0030000Nf2XNf2X00AkH:P00`0008e[Yhe[Y`07SF^W00<0002ILZFILZD029UbY@80000<
[hjd00<0002gTJngTJl02kNA[`030000`9BY`9BY00_0U:T00`000<RFX/RFXP09b9JR00<0003Q^JoQ
^Jl01^6i[`030000kl2Qkl2Q00;_`:4010000?g6Pog6Pog6P`80000Hoooo00<0003oooooool07?oo
o`007Oooo`030000oooooooo01coool2000000<9Pn80000000003@0000Q[doT800006_ooo`030000
001[000000<^:9P00`0005m=Y5m=Y002GdfT00<0001kH:QkH:P01G]PZ0030000SF^WSF^W00N=JjL0
0`0009UbYIUbY@05VG:U0P0000:URkT00`000:n>]:n>]00:[hjd00<0002gTJngTJl02kNA[`030000
`9BY`9BY00_0U:T00`000<RFX/RFXP06b9JR0`0000SQ^Jl00`000>o0XNo0X@02kl2Q00@0003maX?m
aX?maX<200006?ooo`030000oooooooo01coool001koool00`000?ooooooo`0Moooo0`0000U[doT<
00008_ooo`030000001[000000<^:9P00`0005m=Y5m=Y002GdfT00<0001kH:QkH:P01G]PZ0030000
SF^WSF^W00N=JjL00`0009UbYIUbY@03VG:U0P0000BURkT00`000:n>]:n>]00;[hjd00<0002gTJng
TJl02[NA[`030000`9BY`9BY00_0U:T00`000<RFX/RFXP04b9JR0P0000?E/kL00`000>6i[n6i[`05
hKV_00<0003_`:7_`:400no0X@030000oLJ3oLJ30080000Goooo00<0003oooooool07Oooo`007_oo
o`030000oooooooo01ooool80000<?ooo`030000001[000000<^:9P00`0005m=Y5m=Y002GdfT00<0
001kH:QkH:P01G]PZ0030000SF^WSF^W00N=JjL0100009UbYIUbYIUbY@800007YH^i00<0002_S[B_
S[@02Zn>]0030000]i6_]i6_00^gTJl00`000<2DZL2DZ@0;`9BY00@00038UZ;8UZ;8UZ8200001MFc
]`030000hKV_hKV_00KQ^Jl00`000>o0XNo0X@02kl2Q00H0003maX?maX<0003^/SH0000Foooo00<0
003oooooool07Oooo`007oooo`030000oooooooo05Ooool00`00J`0002hXV002;RRH00<0001OCJAO
CJ@00em=Y0030000Nf2XNf2X00AkH:P00`0008e[Yhe[Y`08SF^W0`0000VURkT00`000:n>]:n>]00;
[hjd00<0002gTJngTJl02[NA[`030000`9BY`9BY00_0U:T010000<RFXP00000000OE/kL00`000>6i
[n6i[`06hKV_00<0003_`:7_`:400^o0X@060000oLJ3oLJ30000k[8f00005Oooo`030000oooooooo
01koool001ooool00`000?ooooooo`1Goooo0P0000<^:9P00`0005m=Y5m=Y003GdfT00<0001kH:Qk
H:P01G]PZ0030000SF^WSF^W00N=JjL00`000:F;^JF;^@0:YH^i00<0002_S[B_S[@02Zn>]0030000
]i6_]i6_00^gTJl00`000<2DZL2DZ@0;`9BY00<0003E/kOE/kL01mFc]`030000hKV_hKV_00KQ^Jl0
0`000>o0XNo0X@02kl2Q00@0003maX?maX?maX<200005Oooo`030000oooooooo01koool0023oool0
0`000?ooooooo`1Foooo0P0000<^:9P00`0005m=Y5m=Y003GdfT00<0001kH:QkH:P01G]PZ0030000
SF^WSF^W00F=JjL2000000>IQ[d0002URkT02ZF;^@030000[hjd[hjd00^_S[@00`000;NA[kNA[`0:
]i6_00<00030U:W0U:T02L2DZ@<0000:eK>g00<0003Q^JoQ^Jl01N6i[`030000kl2Qkl2Q00;_`:40
10000?g6Pog6Pog6P`80000Doooo00<0003oooooool07oooo`008?ooo`030000oooooooo05Koool2
00000bhXV0030000GdfTGdfT00=OCJ@00`0007]PZ7]PZ005Nf2X00<0002=JjN=JjL00he[Y`800003
VHJm00<0002URkVURkT02ZF;^@030000[hjd[hjd00^_S[@00`000;NA[kNA[`0:]i6_00<00030U:W0
U:T01l2DZ@050000bjnmbjnmbjnm000000WE/kL00`000>6i[n6i[`05hKV_00<0003_`:7_`:400^o0
X@040000oLJ3oLJ3oLJ30P0001Coool00`000?ooooooo`0Ooooo000Qoooo00<0003oooooool0EOoo
o`030000001[0000008^:9P00`0005m=Y5m=Y003GdfT00<0001kH:QkH:P01G]PZ0040000SF^WSF^W
SF^W0P0000JIQ[d00`000:F;^JF;^@09YH^i00<0002_S[B_S[@02jn>]0030000]i6_]i6_00^gTJl0
0`000<2DZL2DZ@04`9BY0P0000C;[kd00`000=Fc]mFc]`07eK>g00<0003Q^JoQ^Jl01N6i[`030000
kl2Qkl2Q00?_`:400`000?g6Pog6P`0200004oooo`030000oooooooo023oool0027oool00`000?oo
ooooo`1Eoooo00<0000006/000000RhXV0030000GdfTGdfT00=OCJ@00`0007]PZ7]PZ006Nf2X0`00
00RIQ[d00`000:F;^JF;^@0:YH^i00<0002_S[B_S[@02jn>]0030000]i6_]i6_00ZgTJl00`000<2D
ZL2DZ@03`9BY00<0003;[kg;[kd01<^__@030000eK>geK>g00SE/kL00`000>6i[n6i[`05hKV_00<0
003_`:7_`:400^o0X@030000oLJ3oLJ30080000Coooo00<0003oooooool08?ooo`008_ooo`030000
oooooooo05Coool00`000000J`000002;RRH00<0001OCJAOCJ@00em=Y0030000Nf2XNf2X00EkH:P2
00002iV6_@030000YH^iYH^i00VURkT00`000:n>]:n>]00;[hjd00<0002gTJngTJl02kNA[`050000
`9BY`9BY`9BY000000S;[kd00`000=Fc]mFc]`07eK>g00<0003Q^JoQ^Jl01N6i[`030000kl2Qkl2Q
00;_`:401P000?g6Pog6P`000>jb=P00017oool00`000?ooooooo`0Qoooo000Soooo00<0003ooooo
ool0Doooo`030000001[0000008^:9P00`0005m=Y5m=Y004GdfT00<0001kH:QkH:P00W]PZ0800002
RGk100<0002IQ[fIQ[d029V6_@030000YH^iYH^i00ZURkT00`000:n>]:n>]00;[hjd00<0002gTJng
TJl02[NA[`040000`9BY000000002L^__@030000eK>geK>g00OE/kL00`000>6i[n6i[`05hKV_00<0
003_`:7_`:400^o0X@060000oLJ3oLJ30000k[8f00004?ooo`030000oooooooo02;oool002?oool0
0`000?ooooooo`1Coooo00<0000006/000000bhXV0030000GdfTGdfT00=OCJ@00`0007]PZ7]PZ002
000018Un`@030000VHJmVHJm00VIQ[d00`000:F;^JF;^@09YH^i00<0002_S[B_S[@02jn>]0030000
]i6_]i6_00^gTJl00`000<^__L^__@0:bjnm00<0003E/kOE/kL01]Fc]`030000hKV_hKV_00GQ^Jl0
0`000>o0XNo0X@02kl2Q00@0003maX?maX?maX<200004?ooo`030000oooooooo02;oool002Coool0
0`000?ooooooo`1Boooo00<0000006/000000bhXV0030000GdfTGdfT00=OCJ@300001hUn`@030000
VHJmVHJm00RIQ[d00`000:F;^JF;^@0:YH^i00<0002_S[B_S[@02jn>]0030000]i6_]i6_00RgTJl3
00003<^__@030000eK>geK>g00OE/kL00`000>6i[n6i[`04hKV_00<0003_`:7_`:400^o0X@040000
oLJ3oLJ3oLJ30P0000ooool00`000?ooooooo`0Soooo000Uoooo00<0003oooooool0D_ooo`800003
;RRH00<0001OCJAOCJ@00Um=Y0800009RGk100<0002IQ[fIQ[d02IV6_@030000YH^iYH^i00ZURkT0
0`000:n>]:n>]00;[hjd00<0002gTJngTJl01KNA[`800003`Z_300<0003;[kg;[kd02L^__@030000
eK>geK>g00OE/kL00`000>6i[n6i[`05hKV_00D0003_`:7_`:7_`:4000000og6P`80000>oooo00<0
003oooooool09?ooo`009Oooo`030000oooooooo05;oool200000bhXV0030000GdfTGdfT00800002
Kg7400<00029O/69O/401hUn`@030000VHJmVHJm00RIQ[d00`000:F;^JF;^@0:YH^i00<0002_S[B_
S[@02jn>]0030000]i6_]i6_00BgTJl00`000<:[`l:[``03`Z_300<0003;[kg;[kd02/^__@030000
eK>geK>g00KE/kL00`000>6i[n6i[`05hKV_00<0003_`:7_`:400^o0X@040000oLJ3oLJ300003ooo
o`030000oooooooo02Coool002Koool00`000?ooooooo`1Aoooo0P0000<^:9P3000016maa0030000
RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002URkVURkT02ZF;^@030000[hjd[hjd00^_S[@0
10000;NA[kNA[kNA[`800007`Z_300<0003;[kg;[kd02L^__@030000eK>geK>g00KE/kL00`000>6i
[n6i[`05hKV_00<0003_`:7_`:400^o0X@040000oLJ3000000003_ooo`030000oooooooo02Goool0
02Koool00`000?ooooooo`1Aoooo0P000004;RRH0000000000001fmaa0030000RGk1RGk100N9O/40
0`0009V6_IV6_@08VHJm00<0002URkVURkT02ZF;^@030000[hjd[hjd00^_S[@010000;NA[`000000
00W2Zl<00`000<^__L^__@09bjnm00<0003E/kOE/kL01mFc]`030000hKV_hKV_00CQ^Jl00`000>o0
XNo0X@02kl2Q100000koool00`000?ooooooo`0Uoooo000Woooo00<0003oooooool0D?ooo`<00002
@5O300<0001_LLA_LL@01Fmaa0030000RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002URkVU
RkT02ZF;^@030000[hjd[hjd00^_S[@00`000<:[`l:[``0:`Z_300<0003;[kg;[kd02L^__@030000
eK>geK>g00KE/kL00`000>6i[n6i[`04hKV_00<0003_`:7_`:400^o0X@030000lo2K000000koool0
0`000?ooooooo`0Voooo000Xoooo00<0003oooooool0Coooo`800004@5O300<0001_LLA_LL@01Fma
a0030000RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002URkVURkT02JF;^@030000[hjd[hjd
00V_S[@2000000>iZ<P00032Zl<02/:[``030000bjnmbjnm00W;[kd00`000=Fc]mFc]`06eK>g00<0
003Q^JoQ^Jl01N6i[`030000kl2Q0000008000000o?`V`000?ooo`0<oooo00<0003oooooool09ooo
o`00:?ooo`030000oooooooo04ooool00`00000GY@000003@5O300<0001_LLA_LL@01Fmaa0030000
RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002URkVURkT02ZF;^@030000[hjd[hjd00J_S[@2
00000kVXb0030000`Z_3`Z_300[2Zl<00`000<^__L^__@08bjnm00<0003E/kOE/kL01mFc]`030000
hKV_hKV_00CQ^Jl2000000?dk;X0003cl9/00P0000goool00`000?ooooooo`0Woooo000Yoooo00<0
003oooooool0Coooo`800004@5O300<0001_LLA_LL@01Fmaa0030000RGk1RGk100N9O/400`0009V6
_IV6_@09VHJm00<0002URkVURkT02JF;^@030000[hjd[hjd00B_S[@200001[VXb0030000`Z_3`Z_3
00W2Zl<00`000<^__L^__@09bjnm00<0003E/kOE/kL01]Fc]`030000hKV_hKV_00CQ^Jl01P000?C/
^_C/^P000??`V`0000goool00`000?ooooooo`0Xoooo000Zoooo00<0003oooooool0C_ooo`030000
01NU000000=0El<00`0006maa6maa005Kg7400<00029O/69O/401hUn`@030000VHJmVHJm00VIQ[d0
0`000:F;^JF;^@0:YH^i00@0002_S[B_S[B_S[@200002;VXb0030000`Z_3`Z_300[2Zl<00`000<^_
_L^__@08bjnm00<0003E/kOE/kL01]Fc]`030000hKV_hKV_00;Q^Jl300000_C/^P030000lo2K0000
00coool00`000?ooooooo`0Yoooo000[oooo00<0003oooooool0C_ooo`800004@5O300<0001_LLA_
LL@01Fmaa0030000RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002URkVURkT02JF;^@040000
[hjd000000002kVXb0030000`Z_3`Z_300W2Zl<00`000<^__L^__@08bjnm00<0003E/kOE/kL01]Fc
]`050000hKV_hKV_hKV_000000;[hLP00`000?C/^_C/^P0300002oooo`030000oooooooo02[oool0
02coool00`000?ooooooo`1=oooo00<000005jD000000d1G``030000Kg74Kg7400E_LL@00`0008Un
`HUn`@08RGk100<0002IQ[fIQ[d029V6_@030000YH^iYH^i00VURkT200003[VXb0030000`Z_3`Z_3
00W2Zl<00`000<^__L^__@08bjnm00<0003E/kOE/kL01]Fc]`<00002jn7800D0003dk;[dk;X0003c
l9/00P0000[oool00`000?ooooooo`0[oooo000]oooo00<0003oooooool0COooo`800004@5O300<0
001_LLA_LL@01Fmaa0030000RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002URkVURkT01ZF;
^@800002[jG=00<0002iZ<RiZ<P02kVXb0030000`Z_3`Z_300W2Zl<00`000<^__L^__@08bjnm00<0
003E/kOE/kL01]Fc]`030000jn78jn7800;[hLP01P000?C/^_C/^P000??`V`0000[oool00`000?oo
ooooo`0/oooo000]oooo00<0003oooooool0COooo`03000001NU000000=0El<00`0006maa6maa005
Kg7400<00029O/69O/4028Un`@030000VHJmVHJm00RIQ[d00`000:F;^JF;^@04YH^i0P0000B_YLd0
0`000;VXb;VXb00<^JS800<00032Zl?2Zl<02L:[``030000bjnmbjnm00S;[kd00`000=Fc]mFc]`03
eK>g0`0000C[hLP00`000?C/^_C/^P0300002_ooo`030000oooooooo02coool002koool00`000?oo
ooooo`1=oooo0P0000A0El<00`0006maa6maa005Kg7400<00029O/69O/401hUn`@030000VHJmVHJm
00VIQ[d010000:F;^JF;^JF;^@800007[jG=00<0002iZ<RiZ<P02kVXb0030000`Z_3`Z_300W2Zl<0
0`000<^__L^__@08bjnm00<0003E/kOE/kL00]Fc]`040000h=S?h=S?00001>_Qb0040000m>bj0000
lo2K0P0000Woool00`000?ooooooo`0]oooo000_oooo00<0003oooooool0C?ooo`03000001NU0000
00=0El<00`0006maa6maa006Kg7400<00029O/69O/401hUn`@030000VHJmVHJm00RIQ[d010000:F;
^@00000000Z_YLd00`000;VXb;VXb00;^JS800<00032Zl?2Zl<02L:[``030000bjnmbjnm00O;[kd0
1@000=Fc]mFc]mFc]`000003h=S?00<0003[hLS[hLP00^_Qb0050000m>bj0000lo2K000000Woool0
0`000?ooooooo`0^oooo000`oooo00<0003oooooool0C?ooo`800004@5O300<0001_LLA_LL@01Fma
a0030000RGk1RGk100N9O/400`0009V6_IV6_@09VHJm00<0002_YLf_YLd02jnUc@030000^JS8^JS8
00ZiZ<P00`000<:[`l:[``09`Z_300<0003;[kg;[kd02<^__@<00004h=S?00D0003[hLS[hLS[hLP0
00000_C/^P<00008oooo00<0003oooooool0;oooo`00<Oooo`030000oooooooo04_oool00`00000G
Y@000003@5O300<0001_LLA_LL@01Vmaa0030000RGk1RGk100N9O/400`0009V6_IV6_@06VHJm0P00
0003Y:;C0000[jG=00^_YLd00`000;VXb;VXb00;^JS800<00032Zl?2Zl<02L:[``030000bjnmbjnm
00O;[kd00`000>3Hcn3Hc`03h=S?00<0003[hLS[hLP00^_Qb0040000m>bj0000lo2K0P0000Ooool0
0`000?ooooooo`0`oooo000boooo00<0003oooooool0Boooo`800004@5O300<0001_LLA_LL@01Fma
a0030000RGk1RGk100N9O/400`0009V6_IV6_@04VHJm0P0000BTX]<00`000:nUcJnUc@0:[jG=00<0
002iZ<RiZ<P02kVXb0030000`Z_3`Z_300S2Zl<00`000<^__L^__@05bjnm0`0000GPf<l00`000>_Q
b>_Qb002jn7800D0003dk;X0003cl9/000001oooo`030000oooooooo037oool003?oool00`000?oo
ooooo`1:oooo00<000005jD000000d1G``030000Kg74Kg7400I_LL@00`0008Un`HUn`@07RGk100@0
002IQ[fIQ[fIQ[d200001jBRd`030000[jG=[jG=00Z_YLd00`000;VXb;VXb00:^JS800<00032Zl?2
Zl<02L:[``030000bjnmbjnm00;;[kd200000]KAe0030000h=S?h=S?00?Pf<l00`000>_Qb>_Qb002
jn7800<0003dk;X000000P0000Koool00`000?ooooooo`0boooo000doooo00<0003oooooool0B_oo
o`800004@5O300<0001_LLA_LL@01Fmaa0030000RGk1RGk100N9O/40100009V6_@00000000VTX]<0
0`000:nUcJnUc@0:[jG=00<0002iZ<RiZ<P02kVXb0030000`Z_3`Z_300S2Zl<01@000<^__L^__L^_
_@000004e]7D00<0003Pf<oPf<l00n3Hc`050000jn78jn78jn78000000;dk;X300001Oooo`030000
oooooooo03?oool003Goool00`000?ooooooo`19oooo00<000005jD000000d1G``030000Kg74Kg74
00I_LL@00`0008Un`HUn`@06RGk10P0000bTX]<00`000:nUcJnUc@0:[jG=00<0002iZ<RiZ<P02[VX
b0030000`Z_3`Z_300W2Zl<300001MKAe0030000h=S?h=S?00?Pf<l02@000>_Qb>_Qb>_Qb0000?C/
^P000??`V`000005oooo00<0003oooooool0=?ooo`00=_ooo`030000oooooooo04Woool20000141G
``030000Kg74Kg7400E_LL@00`0008Un`HUn`@04RGk10P0000:DWm/00`000:BRdjBRd`0:Y:;C00<0
002_YLf_YLd02ZnUc@030000^JS8^JS800ZiZ<P00`000<:[`l:[``08`Z_300<0003FdMCFdM@01MKA
e0030000h=S?h=S?00?Pf<l01P000>_Qb>_Qb>_Qb0000?C/^P<00004oooo00<0003oooooool0=Ooo
o`00=oooo`030000oooooooo04Soool00`00000GY@000003@5O300<0001_LLA_LL@01Vmaa0040000
RGk1RGk1RGk10P0000FDWm/00`000:BRdjBRd`0:Y:;C00<0002_YLf_YLd02ZnUc@030000^JS8^JS8
00ZiZ<P00`000<:[`l:[``05`Z_30`0000OFdM@00`000>3Hcn3Hc`03h=S?00H0003[hLS[hLS[hLP0
003dk;X200001?ooo`030000oooooooo03Koool003Soool00`000?ooooooo`18oooo0P0000A0El<0
0`0006maa6maa005Kg7400@00029O/4000000008U9oK00<0002TX]>TX]<02ZBRd`030000[jG=[jG=
00V_YLd00`000;VXb;VXb00:^JS800<00032Zl?2Zl<00l:[``800003c<cI00<0003FdMCFdM@01=KA
e0030000h=S?h=S?00?Pf<l010000>_Qb>_Qb>_Qb0@00003oooo00<0003oooooool0=oooo`00>Ooo
o`030000oooooooo04Ooool00`00000GY@000003@5O300<0001_LLA_LL@01Fmaa080000;U9oK00<0
002TX]>TX]<02ZBRd`030000[jG=[jG=00V_YLd00`000;VXb;VXb00:^JS800D00032Zl?2Zl?2Zl<0
00001Lc<f@030000e]7De]7D00CFdM@00`000>3Hcn3Hc`03h=S?00D0003[hLS[hLP0003dk;X00P00
00?oool00`000?ooooooo`0hoooo000joooo00<0003oooooool0Aoooo`800004@5O300<0001_LLA_
LL@00Vmaa0800002O9WS00<0002DWm^DWm/02IBOf`030000Y:;CY:;C00VTX]<00`000:nUcJnUc@0:
[jG=00<0002iZ<RiZ<P02KVXb0040000`Z_3000000001/c<f@030000e]7De]7D00GFdM@01@000>3H
cn3Hcn3Hc`000003jn780`0000?oool00`000?ooooooo`0ioooo000koooo00<0003oooooool0A_oo
o`03000001NU000000=0El<00`0006maa6maa00200001GbIh`030000U9oKU9oK00VDWm/00`000:BR
djBRd`09Y:;C00<0002_YLf_YLd02JnUc@030000^JS8^JS800ZiZ<P00`000<c<fLc<f@06c<cI00<0
003FdMCFdM@01MKAe0050000h=S?h=S?h=S?000000?[hLP200000oooo`030000oooooooo03[oool0
03coool00`000?ooooooo`16oooo0P000090El<4000027bIh`030000U9oKU9oK00VDWm/00`000:BR
djBRd`09Y:;C00<0002_YLf_YLd02JnUc@030000^JS8^JS800NiZ<P300002Lc<f@030000e]7De]7D
00CFdM@01P000>3Hcn3Hcn3Hc`000>_Qb0@00002oooo00<0003oooooool0>oooo`00?Oooo`030000
oooooooo04Goool400000df9j@030000O9WSO9WS00MlVN<200002YBOf`030000Y:;CY:;C00VTX]<0
0`000:nUcJnUc@09[jG=00<0002iZ<RiZ<P01;VXb0800003`lWO00<0003<c=W<c=T01/c<f@030000
e]7De]7D00CFdM@010000>3Hcn3Hcn3Hc`8000000mCod00000000002oooo00<0003oooooool0??oo
o`00?_ooo`030000oooooooo04Goool00`00001GcP000004CHWY0P0000UlVN<00`0009BOfiBOf`08
U9oK00<0002TX]>TX]<02JBRd`030000[jG=[jG=00V_YLd010000;VXb;VXb;VXb0800005`lWO00<0
003<c=W<c=T01/c<f@030000e]7De]7D00CFdM@01P000>3Hcn3Hcn3Hc`000=Cod0800002oooo00<0
003oooooool0?Oooo`00?oooo`800016oooo00@00000Elh000000004CHWY00<0001lVN=lVN<01gbI
h`030000U9oKU9oK00NDWm/00`000:BRdjBRd`0:Y:;C00<0002_YLf_YLd02:nUc@040000^JS80000
00002<?9g`030000c<cIc<cI00K<c=T00`000=KAe=KAe003e]7D00D0003Pf<l00000003Dom000P00
0003oooo00000000043oool0047oool00`000?ooooooo`15oooo00<00000Elh0000014f9j@030000
O9WSO9WS00MlVN<00`0009BOfiBOf`07U9oK00<0002TX]>TX]<02ZBRd`030000[jG=[jG=00N_YLd2
00002/?9g`030000c<cIc<cI00K<c=T00`000=KAe=KAe003e]7D0P000003e?gM0000e?o@00<00012
oooo0012oooo00<0003oooooool0AOooo`03000005O>000000A=RNT00`0007bIhgbIh`07O9WS00<0
002DWm^DWm/01iBOf`030000Y:;CY:;C00VTX]<00`000:nUcJnUc@05[jG=0P0000:ianD00`000<?9
gl?9g`08`lWO00<0003<c=W<c=T01Lc<f@030000e]7De]7D00?FdM@010000=Cmg@000=Cod0<00013
oooo0013oooo00<0003oooooool0AOooo`@00003CHWY0P0000QlVN<00`0009BOfiBOf`07U9oK00<0
002TX]>TX]<02JBRd`030000[jG=[jG=00:_YLd200001KW7i@030000`lWO`lWO00O3bMl00`000<c<
fLc<f@05c<cI00@0003FdMCFdMCFdM@3000000?DoMd0000000000P0004Coool004Coool00`000?oo
ooooo`16oooo00<00000Elh0000014f9j@030000O9WSO9WS00IlVN<00`0009BOfiBOf`07U9oK00<0
002TX]>TX]<02JBRd`040000[jG=000000002;W7i@030000`lWO`lWO00O3bMl00`000<c<fLc<f@05
c<cI0`000003d?SV0000e?gM00@00015oooo0015oooo00<0003oooooool0A_ooo`03000005O>0000
00A=RNT00`0007bIhgbIh`06O9WS00<0002DWm^DWm/01iBOf`030000Y:;CY:;C00RTX]<200002kW7
i@030000`lWO`lWO00K3bMl00`000<c<fLc<f@04c<cI0P0000?@n>H2000000?Dom0000000000A_oo
o`00A_ooo`800017oooo100000==RNT00`0007bIhgbIh`06O9WS00<0002DWm^DWm/01iBOf`030000
Y:;CY:;C00FTX]<200000Zg6k@80000:^LOU00<00033bMo3bMl01/?9g`040000c<cIc<cIc<cI0P00
0006bOC/0000d?SVd?SV0000e?gM0P0004Soool004Soool00`000?ooooooo`16oooo00<00000Elh0
00000df9j@030000O9WSO9WS00IlVN<2000029BOf`030000Y:;CY:;C00:TX]<200001Zg6k@030000
^LOU^LOU00RianD00`000<?9gl?9g`05`lWO00@0003<c=T000000003bOC/00<0003@n>K@n>H00`00
04Woool004Woool20000Aoooo`03000005O>000000==RNT2000027bIh`030000U9oKU9oK00JDWm/0
10000:BRd`00000000V]a^d200002KW7i@030000`lWO`lWO00G3bMl00`000<Wdk<Wdk002bOC/00<0
003@n>K@n>H00`0004[oool004_oool20000A_ooo`03000005O>000000A=RNT00`0007bIhgbIh`06
O9WS00<0002DWm^DWm/01IBOf`80000=[LK]00<0002ianFianD01kW7i@030000`lWO`lWO00;3bMl2
000000?0lO400039m>`00/Wdk0@0001<oooo001=oooo00<0003oooooool0A?ooo`@00003CHWY00<0
001lVN=lVN<01WbIh`030000U9oKU9oK00:DWm/200000ic6m@80000;[LK]00<0002ianFianD01kW7
i@040000`lWO000000000l3al@040000bOC/bOC/bOC/0`0004goool004koool20000A_ooo`030000
05O>000000==RNT00`0007bIhgbIh`06O9WS00@0002DWm/000000007W<Ke0P0000Z]a^d200002;W7
i@030000`?7a`?7a00C0lO4010000<Wdk000000004ooool0053oool20000AOooo`03000005O>0000
00==RNT200001WbIh`80000;W<Ke0`0000V]a^d00`000;W7iKW7i@03^LOU0P0000:dk_H200000l3a
l@<0001@oooo001Boooo0P0004Coool400000df9j@030000O9WSO9WS00<00003PLCm0`0000ZLa_D2
00002:g6k@8000000kW7i@0000000006]>kf100005;oool005Coool20000A?ooo`03000005O>0000
009=RNT300002H74o@<00009W<Ke0P0000N]a^d<0000E?ooo`00E_ooo`800013oooo100000A>]oX3
00002874o@<00008W<Ke0P0000>]a^d200001jG/n@<0001Foooo001Hoooo0P0004Coool5000014jg
nP@00006PLCm0`0000NLa_D=0000F?ooo`00F_ooo`800018oooo1@00009>]oX400001H74o@<00002
W<Ke0P0000B>ioP60000Foooo`00G?ooo`80001;oooo2P0000B1a?d800000_ooo`80001Moooo001N
oooo0`0004koool:00001Oooo`<0001Ooooo001Qoooo0`0005Ooool30000H_ooo`00I?ooo`<0001A
oooo0`0006Goool006Ooool30000Boooo`<0001Xoooo001Zoooo0`0004Goool30000Joooo`00KOoo
o`@0000moooo100006koool0077oool30000=oooo`<0001boooo001doooo1@0002goool50000MOoo
o`00NOooo`H0000Qoooo1P0007[oool007ooool:00003Oooo`X00020oooo0029oooo3@0008[oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
      ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}]}], "Input",
  Editable->False,
  CellDingbat->None,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(Symmetric\ non - embedded\ trinoids\),
        FontSize->14,
        FontTracking->"Plain",
        FontColor->RGBColor[0, 0, 1],
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Masked"->False,
        "CompatibilityType"->0,
        "RotationAngle"->0}]}]], "Input",
  Editable->False,
  CellDingbat->None],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.49;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\n", 
    StyleBox[\(\(\[CapitalDelta]1 = 0.49;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\n", 
    StyleBox[\(\(\[CapitalDelta]8 = 0.49;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\n", 
    StyleBox[\(\(kembed = 0;\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\n", 
    RowBox[{Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.38994 .38592 m .33839 .29948 L .37292 .2799 L p .716 .569 .688 r
F P
0 g
s
.37292 .2799 m .42318 .36694 L .38994 .38592 L p .716 .569 .688 r
F P
0 g
s
.42318 .36694 m .37292 .2799 L .40715 .25978 L p .686 .558 .705 r
F P
0 g
s
.32384 .19487 m .37292 .2799 L .33839 .29948 L p .756 .666 .762 r
F P
0 g
s
.37292 .2799 m .32384 .19487 L .35016 .1793 L p .727 .656 .779 r
F P
0 g
s
.35016 .1793 m .40715 .25978 L .37292 .2799 L p .727 .656 .779 r
F P
0 g
s
.45624 .65236 m .40715 .74022 L .37292 .7201 L p .686 .561 .708 r
F P
0 g
s
.37292 .7201 m .42318 .63306 L .45624 .65236 L p .686 .561 .708 r
F P
0 g
s
.42318 .63306 m .37292 .7201 L .33839 .70052 L p .716 .6 .726 r
F P
0 g
s
.32384 .80513 m .37292 .7201 L .40715 .74022 L p .727 .531 .626 r
F P
0 g
s
.37292 .7201 m .32384 .80513 L .29719 .79012 L p .756 .569 .643 r
F P
0 g
s
.29719 .79012 m .33839 .70052 L .37292 .7201 L p .756 .569 .643 r
F P
0 g
s
.65383 .46172 m .75446 .4603 L .75415 .5 L p .719 .601 .724 r
F P
0 g
s
.75415 .5 m .65365 .5 L .65383 .46172 L p .719 .601 .724 r
F P
0 g
s
.65365 .5 m .75415 .5 L .75446 .5397 L p .719 .572 .689 r
F P
0 g
s
.85233 .5 m .75415 .5 L .75446 .4603 L p .624 .523 .719 r
F P
0 g
s
.75415 .5 m .85233 .5 L .85265 .53058 L p .624 .496 .686 r
F P
0 g
s
.85265 .53058 m .75446 .5397 L .75415 .5 L p .624 .496 .686 r
F P
0 g
s
.35775 .4039 m .30483 .31782 L .33839 .29948 L p .746 .578 .667 r
F P
0 g
s
.33839 .29948 m .38994 .38592 L .35775 .4039 L p .746 .578 .667 r
F P
0 g
s
.29719 .20988 m .33839 .29948 L .30483 .31782 L p .786 .678 .745 r
F P
0 g
s
.33839 .29948 m .29719 .20988 L .32384 .19487 L p .756 .666 .762 r
F P
0 g
s
.40715 .25978 m .45624 .34764 L .42318 .36694 L p .686 .558 .705 r
F P
0 g
s
.45624 .34764 m .40715 .25978 L .43981 .23989 L p .652 .545 .721 r
F P
0 g
s
.40715 .25978 m .35016 .1793 L .37514 .16377 L p .696 .647 .797 r
F P
0 g
s
.37514 .16377 m .43981 .23989 L .40715 .25978 L p .696 .647 .797 r
F P
0 g
s
.33839 .70052 m .38994 .61408 L .42318 .63306 L p .716 .6 .726 r
F P
0 g
s
.38994 .61408 m .33839 .70052 L .30483 .68218 L p .746 .64 .743 r
F P
0 g
s
.33839 .70052 m .29719 .79012 L .27124 .77624 L p .786 .605 .656 r
F P
0 g
s
.27124 .77624 m .30483 .68218 L .33839 .70052 L p .786 .605 .656 r
F P
0 g
s
.65435 .42486 m .75536 .42207 L .75446 .4603 L p .717 .63 .759 r
F P
0 g
s
.75446 .4603 m .65383 .46172 L .65435 .42486 L p .717 .63 .759 r
F P
0 g
s
.85265 .46942 m .75446 .4603 L .75536 .42207 L p .619 .548 .752 r
F P
0 g
s
.75446 .4603 m .85265 .46942 L .85233 .5 L p .624 .523 .719 r
F P
0 g
s
.4879 .67124 m .43981 .76011 L .40715 .74022 L p .652 .519 .689 r
F P
0 g
s
.40715 .74022 m .45624 .65236 L .4879 .67124 L p .652 .519 .689 r
F P
0 g
s
.35016 .8207 m .40715 .74022 L .43981 .76011 L p .696 .49 .604 r
F P
0 g
s
.40715 .74022 m .35016 .8207 L .32384 .80513 L p .727 .531 .626 r
F P
0 g
s
.75446 .5397 m .65383 .53828 L .65365 .5 L p .719 .572 .689 r
F P
0 g
s
.65383 .53828 m .75446 .5397 L .75536 .57793 L p .717 .541 .651 r
F P
0 g
s
.75446 .5397 m .85265 .53058 L .85361 .55999 L p .619 .463 .649 r
F P
0 g
s
.85361 .55999 m .75536 .57793 L .75446 .5397 L p .619 .463 .649 r
F P
0 g
s
.42987 .43964 m .38994 .38592 L .42318 .36694 L p .667 .468 .607 r
F P
0 g
s
.42318 .36694 m .45637 .42443 L .42987 .43964 L p .667 .468 .607 r
F P
0 g
s
.45637 .42443 m .42318 .36694 L .45624 .34764 L p .636 .457 .624 r
F P
0 g
s
.58734 .46944 m .65383 .46172 L .65365 .5 L p .798 .666 .718 r
F P
0 g
s
.65365 .5 m .58726 .5 L .58734 .46944 L p .798 .666 .718 r
F P
0 g
s
.58726 .5 m .65365 .5 L .65383 .53828 L p .798 .637 .682 r
F P
0 g
s
.48279 .59092 m .45624 .65236 L .42318 .63306 L p .636 .581 .776 r
F P
0 g
s
.42318 .63306 m .45637 .57557 L .48279 .59092 L p .636 .581 .776 r
F P
0 g
s
.45637 .57557 m .42318 .63306 L .38994 .61408 L p .667 .621 .794 r
F P
0 g
s
.4043 .45413 m .35775 .4039 L .38994 .38592 L p .694 .473 .582 r
F P
0 g
s
.38994 .38592 m .42987 .43964 L .4043 .45413 L p .694 .473 .582 r
F P
0 g
s
.45624 .34764 m .48279 .40908 L .45637 .42443 L p .636 .457 .624 r
F P
0 g
s
.48279 .40908 m .45624 .34764 L .4879 .32876 L p .599 .44 .637 r
F P
0 g
s
.43981 .23989 m .4879 .32876 L .45624 .34764 L p .652 .545 .721 r
F P
0 g
s
.58758 .44006 m .65435 .42486 L .65383 .46172 L p .799 .698 .753 r
F P
0 g
s
.65383 .46172 m .58734 .46944 L .58758 .44006 L p .799 .698 .753 r
F P
0 g
s
.38994 .61408 m .42987 .56036 L .45637 .57557 L p .667 .621 .794 r
F P
0 g
s
.42987 .56036 m .38994 .61408 L .35775 .5961 L p .694 .661 .813 r
F P
0 g
s
.30483 .68218 m .35775 .5961 L .38994 .61408 L p .746 .64 .743 r
F P
0 g
s
.65383 .53828 m .58734 .53056 L .58726 .5 L p .798 .637 .682 r
F P
0 g
s
.58734 .53056 m .65383 .53828 L .65435 .57514 L p .799 .608 .643 r
F P
0 g
s
.75536 .57793 m .65435 .57514 L .65383 .53828 L p .717 .541 .651 r
F P
0 g
s
.50812 .60582 m .4879 .67124 L .45624 .65236 L p .599 .539 .758 r
F P
0 g
s
.45624 .65236 m .48279 .59092 L .50812 .60582 L p .599 .539 .758 r
F P
0 g
s
.32783 .42018 m .27349 .33422 L .30483 .31782 L p .776 .585 .641 r
F P
0 g
s
.30483 .31782 m .35775 .4039 L .32783 .42018 L p .776 .585 .641 r
F P
0 g
s
.27124 .22376 m .30483 .31782 L .27349 .33422 L p .818 .693 .727 r
F P
0 g
s
.30483 .31782 m .27124 .22376 L .29719 .20988 L p .786 .678 .745 r
F P
0 g
s
.4879 .32876 m .43981 .23989 L .46968 .22094 L p .611 .528 .737 r
F P
0 g
s
.43981 .23989 m .37514 .16377 L .39782 .14887 L p .661 .639 .817 r
F P
0 g
s
.39782 .14887 m .46968 .22094 L .43981 .23989 L p .661 .639 .817 r
F P
0 g
s
.35775 .5961 m .30483 .68218 L .27349 .66578 L p .776 .682 .76 r
F P
0 g
s
.30483 .68218 m .27124 .77624 L .247 .76406 L p .818 .643 .665 r
F P
0 g
s
.247 .76406 m .27349 .66578 L .30483 .68218 L p .818 .643 .665 r
F P
0 g
s
.65521 .39081 m .75683 .38673 L .75536 .42207 L p .714 .661 .796 r
F P
0 g
s
.75536 .42207 m .65435 .42486 L .65521 .39081 L p .714 .661 .796 r
F P
0 g
s
.85361 .44001 m .75536 .42207 L .75683 .38673 L p .608 .57 .786 r
F P
0 g
s
.75536 .42207 m .85361 .44001 L .85265 .46942 L p .619 .548 .752 r
F P
0 g
s
.51696 .68901 m .46968 .77906 L .43981 .76011 L p .611 .47 .665 r
F P
0 g
s
.43981 .76011 m .4879 .67124 L .51696 .68901 L p .611 .47 .665 r
F P
0 g
s
.37514 .83623 m .43981 .76011 L .46968 .77906 L p .661 .441 .574 r
F P
0 g
s
.43981 .76011 m .37514 .83623 L .35016 .8207 L p .696 .49 .604 r
F P
0 g
s
.65435 .57514 m .75536 .57793 L .75683 .61327 L p .714 .505 .605 r
F P
0 g
s
.75536 .57793 m .85361 .55999 L .85518 .58707 L p .608 .422 .605 r
F P
0 g
s
.85518 .58707 m .75683 .61327 L .75536 .57793 L p .608 .422 .605 r
F P
0 g
s
.38066 .46732 m .32783 .42018 L .35775 .4039 L p .72 .47 .548 r
F P
0 g
s
.35775 .4039 m .4043 .45413 L .38066 .46732 L p .72 .47 .548 r
F P
0 g
s
.4879 .32876 m .50812 .39418 L .48279 .40908 L p .599 .44 .637 r
F P
0 g
s
.50812 .39418 m .4879 .32876 L .51696 .31099 L p .553 .413 .644 r
F P
0 g
s
.46968 .22094 m .51696 .31099 L .4879 .32876 L p .611 .528 .737 r
F P
0 g
s
.58797 .41299 m .65521 .39081 L .65435 .42486 L p .802 .734 .788 r
F P
0 g
s
.65435 .42486 m .58758 .44006 L .58797 .41299 L p .802 .734 .788 r
F P
0 g
s
.35775 .5961 m .4043 .54587 L .42987 .56036 L p .694 .661 .813 r
F P
0 g
s
.4043 .54587 m .35775 .5961 L .32783 .57982 L p .72 .706 .836 r
F P
0 g
s
.27349 .66578 m .32783 .57982 L .35775 .5961 L p .776 .682 .76 r
F P
0 g
s
.65435 .57514 m .58758 .55994 L .58734 .53056 L p .799 .608 .643 r
F P
0 g
s
.58758 .55994 m .65435 .57514 L .65521 .60919 L p .802 .576 .595 r
F P
0 g
s
.75683 .61327 m .65521 .60919 L .65435 .57514 L p .714 .505 .605 r
F P
0 g
s
.53137 .61969 m .51696 .68901 L .4879 .67124 L p .553 .49 .739 r
F P
0 g
s
.4879 .67124 m .50812 .60582 L .53137 .61969 L p .553 .49 .739 r
F P
0 g
s
.32783 .57982 m .27349 .66578 L .2456 .65198 L p .81 .732 .778 r
F P
0 g
s
.27349 .66578 m .247 .76406 L .22545 .75405 L p .855 .684 .669 r
F P
0 g
s
.22545 .75405 m .2456 .65198 L .27349 .66578 L p .855 .684 .669 r
F P
0 g
s
.65637 .36091 m .75882 .35568 L .75683 .38673 L p .707 .696 .837 r
F P
0 g
s
.75683 .38673 m .65521 .39081 L .65637 .36091 L p .707 .696 .837 r
F P
0 g
s
.85518 .41293 m .75683 .38673 L .75882 .35568 L p .587 .591 .824 r
F P
0 g
s
.75683 .38673 m .85518 .41293 L .85361 .44001 L p .608 .57 .786 r
F P
0 g
s
.30136 .43412 m .2456 .34802 L .27349 .33422 L p .81 .591 .606 r
F P
0 g
s
.27349 .33422 m .32783 .42018 L .30136 .43412 L p .81 .591 .606 r
F P
0 g
s
.247 .23594 m .27349 .33422 L .2456 .34802 L p .855 .712 .704 r
F P
0 g
s
.27349 .33422 m .247 .23594 L .27124 .22376 L p .818 .693 .727 r
F P
0 g
s
.51696 .31099 m .46968 .22094 L .49558 .20369 L p .558 .504 .751 r
F P
0 g
s
.46968 .22094 m .39782 .14887 L .41726 .1352 L p .618 .63 .841 r
F P
0 g
s
.41726 .1352 m .49558 .20369 L .46968 .22094 L p .618 .63 .841 r
F P
0 g
s
.54227 .70496 m .49558 .79631 L .46968 .77906 L p .558 .407 .632 r
F P
0 g
s
.46968 .77906 m .51696 .68901 L .54227 .70496 L p .558 .407 .632 r
F P
0 g
s
.39782 .85113 m .46968 .77906 L .49558 .79631 L p .618 .378 .532 r
F P
0 g
s
.46968 .77906 m .39782 .85113 L .37514 .83623 L p .661 .441 .574 r
F P
0 g
s
.65521 .60919 m .75683 .61327 L .75882 .64432 L p .707 .459 .546 r
F P
0 g
s
.75683 .61327 m .85518 .58707 L .85729 .61074 L p .587 .367 .549 r
F P
0 g
s
.85729 .61074 m .75882 .64432 L .75683 .61327 L p .587 .367 .549 r
F P
0 g
s
.35992 .47869 m .30136 .43412 L .32783 .42018 L p .745 .459 .497 r
F P
0 g
s
.32783 .42018 m .38066 .46732 L .35992 .47869 L p .745 .459 .497 r
F P
0 g
s
.51696 .31099 m .53137 .38031 L .50812 .39418 L p .553 .413 .644 r
F P
0 g
s
.53137 .38031 m .51696 .31099 L .54227 .29504 L p .489 .371 .645 r
F P
0 g
s
.49558 .20369 m .54227 .29504 L .51696 .31099 L p .558 .504 .751 r
F P
0 g
s
.58849 .38934 m .65637 .36091 L .65521 .39081 L p .806 .778 .827 r
F P
0 g
s
.65521 .39081 m .58797 .41299 L .58849 .38934 L p .806 .778 .827 r
F P
0 g
s
.32783 .57982 m .38066 .53268 L .4043 .54587 L p .72 .706 .836 r
F P
0 g
s
.38066 .53268 m .32783 .57982 L .30136 .56588 L p .745 .757 .863 r
F P
0 g
s
.2456 .65198 m .30136 .56588 L .32783 .57982 L p .81 .732 .778 r
F P
0 g
s
.65521 .60919 m .58797 .58701 L .58758 .55994 L p .802 .576 .595 r
F P
0 g
s
.58797 .58701 m .65521 .60919 L .65637 .63909 L p .806 .538 .533 r
F P
0 g
s
.75882 .64432 m .65637 .63909 L .65521 .60919 L p .707 .459 .546 r
F P
0 g
s
.55159 .63197 m .54227 .70496 L .51696 .68901 L p .489 .428 .715 r
F P
0 g
s
.51696 .68901 m .53137 .61969 L .55159 .63197 L p .489 .428 .715 r
F P
0 g
s
.29563 .85398 m .32384 .80513 L .35016 .8207 L p .763 .481 .506 r
F P
0 g
s
.32384 .80513 m .29563 .85398 L .28055 .84552 L p .79 .515 .521 r
F P
0 g
s
.28055 .84552 m .29719 .79012 L .32384 .80513 L p .79 .515 .521 r
F P
0 g
s
.90874 .5 m .85233 .5 L .85265 .46942 L p .488 .411 .695 r
F P
0 g
s
.85233 .5 m .90874 .5 L .90895 .51729 L p .488 .386 .665 r
F P
0 g
s
.90895 .51729 m .85265 .53058 L .85233 .5 L p .488 .386 .665 r
F P
0 g
s
.29563 .14602 m .32384 .19487 L .29719 .20988 L p .79 .775 .839 r
F P
0 g
s
.32384 .19487 m .29563 .14602 L .3105 .13719 L p .763 .766 .854 r
F P
0 g
s
.3105 .13719 m .35016 .1793 L .32384 .19487 L p .763 .766 .854 r
F P
0 g
s
.45426 .46588 m .42987 .43964 L .45637 .42443 L p .603 .352 .51 r
F P
0 g
s
.45637 .42443 m .47381 .45464 L .45426 .46588 L p .603 .352 .51 r
F P
0 g
s
.47381 .45464 m .45637 .42443 L .48279 .40908 L p .572 .342 .528 r
F P
0 g
s
.55241 .47745 m .58734 .46944 L .58726 .5 L p .869 .724 .699 r
F P
0 g
s
.58726 .5 m .55238 .5 L .55241 .47745 L p .869 .724 .699 r
F P
0 g
s
.55238 .5 m .58726 .5 L .58734 .53056 L p .869 .695 .664 r
F P
0 g
s
.49332 .55667 m .48279 .59092 L .45637 .57557 L p .572 .593 .835 r
F P
0 g
s
.45637 .57557 m .47381 .54536 L .49332 .55667 L p .572 .593 .835 r
F P
0 g
s
.47381 .54536 m .45637 .57557 L .42987 .56036 L p .603 .632 .853 r
F P
0 g
s
.29719 .79012 m .28055 .84552 L .26587 .83777 L p .816 .545 .528 r
F P
0 g
s
.26587 .83777 m .27124 .77624 L .29719 .79012 L p .816 .545 .528 r
F P
0 g
s
.90895 .48271 m .85265 .46942 L .85361 .44001 L p .478 .428 .723 r
F P
0 g
s
.85265 .46942 m .90895 .48271 L .90874 .5 L p .488 .411 .695 r
F P
0 g
s
.3105 .86281 m .35016 .8207 L .37514 .83623 L p .737 .442 .482 r
F P
0 g
s
.35016 .8207 m .3105 .86281 L .29563 .85398 L p .763 .481 .506 r
F P
0 g
s
.85265 .53058 m .90895 .51729 L .90958 .53388 L p .478 .353 .631 r
F P
0 g
s
.90958 .53388 m .85361 .55999 L .85265 .53058 L p .478 .353 .631 r
F P
0 g
s
.35016 .1793 m .3105 .13719 L .32455 .12836 L p .737 .761 .872 r
F P
0 g
s
.32455 .12836 m .37514 .16377 L .35016 .1793 L p .737 .761 .872 r
F P
0 g
s
.28055 .15448 m .29719 .20988 L .27124 .22376 L p .816 .788 .826 r
F P
0 g
s
.29719 .20988 m .28055 .15448 L .29563 .14602 L p .79 .775 .839 r
F P
0 g
s
.43546 .47662 m .4043 .45413 L .42987 .43964 L p .627 .352 .481 r
F P
0 g
s
.42987 .43964 m .45426 .46588 L .43546 .47662 L p .627 .352 .481 r
F P
0 g
s
.48279 .40908 m .49332 .44333 L .47381 .45464 L p .572 .342 .528 r
F P
0 g
s
.49332 .44333 m .48279 .40908 L .50812 .39418 L p .533 .319 .536 r
F P
0 g
s
.55252 .4558 m .58758 .44006 L .58734 .46944 L p .873 .757 .732 r
F P
0 g
s
.58734 .46944 m .55241 .47745 L .55252 .4558 L p .873 .757 .732 r
F P
0 g
s
.42987 .56036 m .45426 .53412 L .47381 .54536 L p .603 .632 .853 r
F P
0 g
s
.45426 .53412 m .42987 .56036 L .4043 .54587 L p .627 .672 .874 r
F P
0 g
s
.58734 .53056 m .55241 .52255 L .55238 .5 L p .869 .695 .664 r
F P
0 g
s
.55241 .52255 m .58734 .53056 L .58758 .55994 L p .873 .668 .623 r
F P
0 g
s
.51202 .56759 m .50812 .60582 L .48279 .59092 L p .533 .551 .819 r
F P
0 g
s
.48279 .59092 m .49332 .55667 L .51202 .56759 L p .533 .551 .819 r
F P
0 g
s
.27124 .77624 m .26587 .83777 L .2522 .83105 L p .845 .572 .525 r
F P
0 g
s
.2522 .83105 m .247 .76406 L .27124 .77624 L p .845 .572 .525 r
F P
0 g
s
.90958 .46612 m .85361 .44001 L .85518 .41293 L p .457 .438 .749 r
F P
0 g
s
.85361 .44001 m .90958 .46612 L .90895 .48271 L p .478 .428 .723 r
F P
0 g
s
.32455 .87164 m .37514 .83623 L .39782 .85113 L p .707 .394 .446 r
F P
0 g
s
.37514 .83623 m .32455 .87164 L .3105 .86281 L p .737 .442 .482 r
F P
0 g
s
.85361 .55999 m .90958 .53388 L .9106 .54908 L p .457 .308 .59 r
F P
0 g
s
.9106 .54908 m .85518 .58707 L .85361 .55999 L p .457 .308 .59 r
F P
0 g
s
.26587 .16223 m .27124 .22376 L .247 .23594 L p .845 .808 .814 r
F P
0 g
s
.27124 .22376 m .26587 .16223 L .28055 .15448 L p .816 .788 .826 r
F P
0 g
s
.37514 .16377 m .32455 .12836 L .3372 .11987 L p .707 .76 .894 r
F P
0 g
s
.3372 .11987 m .39782 .14887 L .37514 .16377 L p .707 .76 .894 r
F P
0 g
s
.41815 .48641 m .38066 .46732 L .4043 .45413 L p .645 .338 .438 r
F P
0 g
s
.4043 .45413 m .43546 .47662 L .41815 .48641 L p .645 .338 .438 r
F P
0 g
s
.50812 .39418 m .51202 .43241 L .49332 .44333 L p .533 .319 .536 r
F P
0 g
s
.51202 .43241 m .50812 .39418 L .53137 .38031 L p .48 .282 .533 r
F P
0 g
s
.55269 .43591 m .58797 .41299 L .58758 .44006 L p .879 .795 .763 r
F P
0 g
s
.58758 .44006 m .55252 .4558 L .55269 .43591 L p .879 .795 .763 r
F P
0 g
s
.4043 .54587 m .43546 .52338 L .45426 .53412 L p .627 .672 .874 r
F P
0 g
s
.43546 .52338 m .4043 .54587 L .38066 .53268 L p .645 .714 .898 r
F P
0 g
s
.58758 .55994 m .55252 .5442 L .55241 .52255 L p .873 .668 .623 r
F P
0 g
s
.55252 .5442 m .58758 .55994 L .58797 .58701 L p .879 .64 .573 r
F P
0 g
s
.52915 .57768 m .53137 .61969 L .50812 .60582 L p .48 .503 .804 r
F P
0 g
s
.50812 .60582 m .51202 .56759 L .52915 .57768 L p .48 .503 .804 r
F P
0 g
s
.30136 .56588 m .2456 .65198 L .22233 .64138 L p .849 .794 .797 r
F P
0 g
s
.2456 .65198 m .22545 .75405 L .20748 .74667 L p .899 .731 .664 r
F P
0 g
s
.20748 .74667 m .22233 .64138 L .2456 .65198 L p .899 .731 .664 r
F P
0 g
s
.6578 .33644 m .76127 .33022 L .75882 .35568 L p .693 .74 .887 r
F P
0 g
s
.75882 .35568 m .65637 .36091 L .6578 .33644 L p .693 .74 .887 r
F P
0 g
s
.85729 .38926 m .75882 .35568 L .76127 .33022 L p .549 .61 .866 r
F P
0 g
s
.75882 .35568 m .85729 .38926 L .85518 .41293 L p .587 .591 .824 r
F P
0 g
s
.27945 .44512 m .22233 .35862 L .2456 .34802 L p .849 .593 .551 r
F P
0 g
s
.2456 .34802 m .30136 .43412 L .27945 .44512 L p .849 .593 .551 r
F P
0 g
s
.22545 .24595 m .2456 .34802 L .22233 .35862 L p .899 .737 .672 r
F P
0 g
s
.2456 .34802 m .22545 .24595 L .247 .23594 L p .855 .712 .704 r
F P
0 g
s
.54227 .29504 m .49558 .20369 L .5164 .18884 L p .48 .466 .764 r
F P
0 g
s
.49558 .20369 m .41726 .1352 L .43263 .12334 L p .556 .619 .87 r
F P
0 g
s
.43263 .12334 m .5164 .18884 L .49558 .20369 L p .556 .619 .87 r
F P
0 g
s
.56275 .71844 m .5164 .81116 L .49558 .79631 L p .48 .318 .584 r
F P
0 g
s
.49558 .79631 m .54227 .70496 L .56275 .71844 L p .48 .318 .584 r
F P
0 g
s
.41726 .8648 m .49558 .79631 L .5164 .81116 L p .556 .289 .466 r
F P
0 g
s
.49558 .79631 m .41726 .8648 L .39782 .85113 L p .618 .378 .532 r
F P
0 g
s
.65637 .63909 m .75882 .64432 L .76127 .66978 L p .693 .392 .461 r
F P
0 g
s
.75882 .64432 m .85729 .61074 L .85989 .62999 L p .549 .287 .47 r
F P
0 g
s
.85989 .62999 m .76127 .66978 L .75882 .64432 L p .549 .287 .47 r
F P
0 g
s
.34294 .48775 m .27945 .44512 L .30136 .43412 L p .767 .431 .417 r
F P
0 g
s
.30136 .43412 m .35992 .47869 L .34294 .48775 L p .767 .431 .417 r
F P
0 g
s
.54227 .29504 m .55159 .36803 L .53137 .38031 L p .489 .371 .645 r
F P
0 g
s
.55159 .36803 m .54227 .29504 L .56275 .28156 L p .394 .302 .632 r
F P
0 g
s
.5164 .18884 m .56275 .28156 L .54227 .29504 L p .48 .466 .764 r
F P
0 g
s
.58914 .37011 m .6578 .33644 L .65637 .36091 L p .808 .836 .871 r
F P
0 g
s
.65637 .36091 m .58849 .38934 L .58914 .37011 L p .808 .836 .871 r
F P
0 g
s
.30136 .56588 m .35992 .52131 L .38066 .53268 L p .745 .757 .863 r
F P
0 g
s
.35992 .52131 m .30136 .56588 L .27945 .55488 L p .767 .821 .895 r
F P
0 g
s
.22233 .64138 m .27945 .55488 L .30136 .56588 L p .849 .794 .797 r
F P
0 g
s
.65637 .63909 m .58849 .61066 L .58797 .58701 L p .806 .538 .533 r
F P
0 g
s
.58849 .61066 m .65637 .63909 L .6578 .66356 L p .808 .484 .441 r
F P
0 g
s
.76127 .66978 m .6578 .66356 L .65637 .63909 L p .693 .392 .461 r
F P
0 g
s
.56792 .64214 m .56275 .71844 L .54227 .70496 L p .394 .341 .68 r
F P
0 g
s
.54227 .70496 m .55159 .63197 L .56792 .64214 L p .394 .341 .68 r
F P
0 g
s
.247 .76406 m .2522 .83105 L .2401 .82565 L p .876 .597 .511 r
F P
0 g
s
.2401 .82565 m .22545 .75405 L .247 .76406 L p .876 .597 .511 r
F P
0 g
s
.9106 .45092 m .85518 .41293 L .85729 .38926 L p .42 .44 .774 r
F P
0 g
s
.85518 .41293 m .9106 .45092 L .90958 .46612 L p .457 .438 .749 r
F P
0 g
s
.3372 .88013 m .39782 .85113 L .41726 .8648 L p .671 .333 .392 r
F P
0 g
s
.39782 .85113 m .3372 .88013 L .32455 .87164 L p .707 .394 .446 r
F P
0 g
s
.85518 .58707 m .9106 .54908 L .91198 .56225 L p .42 .246 .538 r
F P
0 g
s
.91198 .56225 m .85729 .61074 L .85518 .58707 L p .42 .246 .538 r
F P
0 g
s
.2522 .16895 m .247 .23594 L .22545 .24595 L p .876 .834 .801 r
F P
0 g
s
.247 .23594 m .2522 .16895 L .26587 .16223 L p .845 .808 .814 r
F P
0 g
s
.39782 .14887 m .3372 .11987 L .34793 .11209 L p .671 .763 .92 r
F P
0 g
s
.34793 .11209 m .41726 .1352 L .39782 .14887 L p .671 .763 .92 r
F P
0 g
s
.40306 .49485 m .35992 .47869 L .38066 .46732 L p .655 .307 .372 r
F P
0 g
s
.38066 .46732 m .41815 .48641 L .40306 .49485 L p .655 .307 .372 r
F P
0 g
s
.53137 .38031 m .52915 .42232 L .51202 .43241 L p .48 .282 .533 r
F P
0 g
s
.52915 .42232 m .53137 .38031 L .55159 .36803 L p .406 .222 .515 r
F P
0 g
s
.55293 .41862 m .58849 .38934 L .58797 .41299 L p .889 .843 .793 r
F P
0 g
s
.58797 .41299 m .55269 .43591 L .55293 .41862 L p .889 .843 .793 r
F P
0 g
s
.38066 .53268 m .41815 .51359 L .43546 .52338 L p .645 .714 .898 r
F P
0 g
s
.41815 .51359 m .38066 .53268 L .35992 .52131 L p .655 .762 .928 r
F P
0 g
s
.58797 .58701 m .55269 .56409 L .55252 .5442 L p .879 .64 .573 r
F P
0 g
s
.55269 .56409 m .58797 .58701 L .58849 .61066 L p .889 .608 .506 r
F P
0 g
s
.54401 .58653 m .55159 .63197 L .53137 .61969 L p .406 .442 .785 r
F P
0 g
s
.53137 .61969 m .52915 .57768 L .54401 .58653 L p .406 .442 .785 r
F P
0 g
s
.46831 .47781 m .45426 .46588 L .47381 .45464 L p .524 .224 .399 r
F P
0 g
s
.47381 .45464 m .48248 .46965 L .46831 .47781 L p .524 .224 .399 r
F P
0 g
s
.48248 .46965 m .47381 .45464 L .49332 .44333 L p .495 .214 .416 r
F P
0 g
s
.53506 .48365 m .55241 .47745 L .55238 .5 L p .929 .772 .666 r
F P
0 g
s
.55238 .5 m .53505 .5 L .53506 .48365 L p .929 .772 .666 r
F P
0 g
s
.53505 .5 m .55238 .5 L .55241 .52255 L p .929 .744 .632 r
F P
0 g
s
.49662 .53854 m .49332 .55667 L .47381 .54536 L p .495 .595 .883 r
F P
0 g
s
.47381 .54536 m .48248 .53035 L .49662 .53854 L p .495 .595 .883 r
F P
0 g
s
.48248 .53035 m .47381 .54536 L .45426 .53412 L p .524 .633 .9 r
F P
0 g
s
.45471 .4856 m .43546 .47662 L .45426 .46588 L p .544 .218 .367 r
F P
0 g
s
.45426 .46588 m .46831 .47781 L .45471 .4856 L p .544 .218 .367 r
F P
0 g
s
.49332 .44333 m .49662 .46146 L .48248 .46965 L p .495 .214 .416 r
F P
0 g
s
.49662 .46146 m .49332 .44333 L .51202 .43241 L p .454 .187 .419 r
F P
0 g
s
.53512 .46797 m .55252 .4558 L .55241 .47745 L p .932 .804 .695 r
F P
0 g
s
.55241 .47745 m .53506 .48365 L .53512 .46797 L p .932 .804 .695 r
F P
0 g
s
.55241 .52255 m .53506 .51635 L .53505 .5 L p .929 .744 .632 r
F P
0 g
s
.53506 .51635 m .55241 .52255 L .55252 .5442 L p .932 .719 .591 r
F P
0 g
s
.45426 .53412 m .46831 .52219 L .48248 .53035 L p .524 .633 .9 r
F P
0 g
s
.46831 .52219 m .45426 .53412 L .43546 .52338 L p .544 .67 .92 r
F P
0 g
s
.51018 .54643 m .51202 .56759 L .49332 .55667 L p .454 .554 .868 r
F P
0 g
s
.49332 .55667 m .49662 .53854 L .51018 .54643 L p .454 .554 .868 r
F P
0 g
s
.22545 .75405 m .2401 .82565 L .23009 .82181 L p .911 .618 .478 r
F P
0 g
s
.23009 .82181 m .20748 .74667 L .22545 .75405 L p .911 .618 .478 r
F P
0 g
s
.76127 .33022 m .85989 .37001 L .85729 .38926 L p .549 .61 .866 r
F P
0 g
s
.91198 .43775 m .85729 .38926 L .85989 .37001 L p .358 .428 .797 r
F P
0 g
s
.85729 .38926 m .91198 .43775 L .9106 .45092 L p .42 .44 .774 r
F P
0 g
s
.5164 .81116 m .43263 .87666 L .41726 .8648 L p .556 .289 .466 r
F P
0 g
s
.34793 .88791 m .41726 .8648 L .43263 .87666 L p .624 .249 .312 r
F P
0 g
s
.41726 .8648 m .34793 .88791 L .3372 .88013 L p .671 .333 .392 r
F P
0 g
s
.85729 .61074 m .91198 .56225 L .91365 .57284 L p .358 .158 .466 r
F P
0 g
s
.91365 .57284 m .85989 .62999 L .85729 .61074 L p .358 .158 .466 r
F P
0 g
s
.22233 .35862 m .20748 .25333 L .22545 .24595 L p .899 .737 .672 r
F P
0 g
s
.2401 .17435 m .22545 .24595 L .20748 .25333 L p .911 .869 .785 r
F P
0 g
s
.22545 .24595 m .2401 .17435 L .2522 .16895 L p .876 .834 .801 r
F P
0 g
s
.41726 .1352 m .34793 .11209 L .35626 .10535 L p .624 .77 .95 r
F P
0 g
s
.35626 .10535 m .43263 .12334 L .41726 .1352 L p .624 .77 .95 r
F P
0 g
s
.33051 .49408 m .34294 .48775 L p .36651 .49894 L .613 .13 .084 r
F P
0 g
s
.34294 .51225 m .38534 .5 L p .40306 .50515 L .651 .816 .963 r
F P
0 g
s
.32326 .50266 m .32163 .50269 L p .32396 .50221 L .174 .706 .719 r
F P
0 g
s
.32326 .49734 m .33051 .49408 L p .34427 .49842 L .483 0 0 r
F P
0 g
s
.34427 .49842 m .34167 .4989 L .32326 .49734 L .483 0 0 r
F
.34294 .51225 m .33051 .50592 L p .36954 .50107 L .613 .87 .991 r
F P
0 g
s
.36954 .50107 m .37405 .50141 L .34294 .51225 L .613 .87 .991 r
F
.38534 .5 m .34294 .51225 L p .37809 .5 L F P
0 g
s
.40306 .50515 m .35992 .52131 L .34294 .51225 L p .651 .816 .963 r
F P
0 g
s
.34294 .48775 m .35992 .47869 L p .38869 .5 L .651 .247 .265 r
F P
0 g
s
.38534 .5 m .34294 .48775 L p .38811 .49984 L .651 .247 .265 r
F P
0 g
s
.38869 .5 m .38534 .5 L .38811 .49984 L .651 .247 .265 r
F
.35992 .47869 m .40306 .49485 L .39371 .5 L p F P
0 g
s
.39371 .5 m .39371 .5 L p .38869 .5 L .651 .816 .963 r
F P
0 g
s
.39371 .5 m .39466 .50053 L p .39055 .50029 L .651 .816 .963 r
F P
0 g
s
.39466 .50053 m .40306 .50515 L p .38534 .5 L .651 .816 .963 r
F P
0 g
s
.40306 .50515 m .43139 .50117 L .44222 .50729 L p .546 .745 .969 r
F P
0 g
s
.39371 .5 m .40306 .49485 L p .41092 .4984 L .515 .061 .111 r
F P
0 g
s
.40306 .49485 m .43139 .49883 L .4293 .5 L p .515 .061 .111 r
F P
0 g
s
.40306 .49485 m .4293 .5 L .41446 .5 L .515 .061 .111 r
F
.41092 .4984 m .41446 .5 L .39371 .5 L F
.35992 .47869 m .39371 .5 L .38869 .5 L .651 .247 .265 r
F
.39083 .49841 m .4293 .5 L .41446 .5 L .515 .78 .992 r
F
.43139 .49883 m .40306 .49485 L .41815 .48641 L p .546 .146 .235 r
F P
0 g
s
.39083 .49841 m .42267 .49629 L .4293 .5 L p .515 .78 .992 r
F P
0 g
s
.41418 .5 m .41446 .5 L .42212 .50053 L .515 .78 .992 r
F
.42205 .50053 m .42212 .50053 L .43139 .50117 L F
.41418 .5 m .42212 .50053 L .42205 .50053 L F
.4293 .5 m .43139 .50117 L p .41446 .5 L F P
0 g
s
.43139 .50117 m .40306 .50515 L .39371 .5 L p .515 .78 .992 r
F P
0 g
s
.41418 .5 m .43139 .50117 L .39371 .5 L .515 .78 .992 r
F
.4576 .50575 m .44222 .50729 L .43139 .50117 L p .436 .712 .982 r
F P
0 g
s
.43139 .50117 m .44974 .50129 L .4576 .50575 L p .436 .712 .982 r
F P
0 g
s
.4293 .5 m .43139 .49883 L p .43422 .49964 L .387 0 0 r
F P
0 g
s
.43139 .49883 m .44974 .49871 L .44746 .5 L p .387 0 0 r
F P
0 g
s
.41815 .48641 m .44222 .49271 L .43139 .49883 L p .546 .146 .235 r
F P
0 g
s
.44974 .49871 m .43139 .49883 L .44222 .49271 L p .436 0 .11 r
F P
0 g
s
.42267 .49629 m .44344 .49774 L .44746 .5 L p .387 .728 .99 r
F P
0 g
s
.44746 .5 m .44974 .50129 L p .44381 .50019 L .387 .728 .99 r
F P
0 g
s
.44974 .50129 m .43139 .50117 L .4293 .5 L p .387 .728 .99 r
F P
0 g
s
.44277 .5 m .44974 .50129 L .4293 .5 L .387 .728 .99 r
F
.46772 .50573 m .4576 .50575 L .44974 .50129 L p .35 .678 .978 r
F P
0 g
s
.44974 .50129 m .4619 .50242 L .46772 .50573 L p .35 .678 .978 r
F P
0 g
s
.44746 .5 m .44974 .49871 L p .4544 .49964 L .292 0 0 r
F P
0 g
s
.4619 .50242 m .44974 .50129 L .44746 .5 L p .292 .681 .974 r
F P
0 g
s
.4544 .49964 m .45624 .5 L .44746 .5 L .292 0 0 r
F
.46674 .49842 m .45847 .49998 L p .4619 .49758 L .241 0 0 r
F P
0 g
s
.47023 .50356 m .4619 .50242 L .45762 .5 L p .241 .653 .961 r
F P
0 g
s
.44974 .49871 m .4619 .49758 L .45762 .5 L p .292 0 0 r
F P
0 g
s
.45762 .5 m .45726 .4998 L p .45796 .5 L .241 .653 .961 r
F P
0 g
s
.45796 .5 m .47023 .50356 L .45762 .5 L .241 .653 .961 r
F
.46674 .50158 m .47023 .50356 L p .458 .50001 L F P
0 g
s
.45802 .50001 m .46674 .50158 L .458 .50001 L .241 .653 .961 r
F
.45834 .5 m .46674 .50158 L p .45796 .5 L F P
0 g
s
.45762 .5 m .4619 .50242 L p .4529 .50014 L .292 .681 .974 r
F P
0 g
s
.46073 .5 m .45834 .5 L .46172 .49988 L .143 0 0 r
F
.47157 .50184 m .4643 .50021 L .464 .50005 L p 0 .543 .828 r
F P
0 g
s
.45834 .5 m .46674 .49842 L .46431 .49978 L p .143 0 0 r
F P
0 g
s
.46431 .49978 m .4643 .49979 L p .46172 .49988 L .143 0 0 r
F P
0 g
s
.45834 .5 m .46168 .49988 L .46172 .49988 L .143 0 0 r
F
.46168 .49988 m .46431 .49978 L .46172 .49988 L F
.46227 .49991 m .46186 .49988 L .4643 .49979 L F
.45762 .5 m .4619 .49758 L p .45847 .49998 L .241 0 0 r
F P
0 g
s
.44222 .49271 m .4576 .49425 L .44974 .49871 L p .436 0 .11 r
F P
0 g
s
.4619 .49758 m .44974 .49871 L .4576 .49425 L p .35 0 .016 r
F P
0 g
s
.45726 .4998 m .454 .49797 L p .46116 .5 L .143 .623 .921 r
F P
0 g
s
.46674 .50158 m .45834 .5 L p .46116 .5 L .143 .623 .921 r
F P
0 g
s
.45236 .5 m .4619 .50242 L .44746 .5 L .292 .681 .974 r
F
.454 .50203 m .45726 .5002 L p .46073 .5 L .143 0 0 r
F P
0 g
s
.4643 .50021 m .46674 .50158 L p .46161 .50013 L .143 .623 .921 r
F P
0 g
s
.4623 .50008 m .4643 .50021 L .46161 .50013 L .143 .623 .921 r
F
.46334 .5 m .46335 .5 L p .46116 .5 L F P
0 g
s
.46335 .5 m .4643 .50021 L p .46238 .50008 L .143 .623 .921 r
F P
0 g
s
.46335 .5 m .46238 .50008 L .46116 .5 L .143 .623 .921 r
F
.47059 .4987 m .46597 .49979 L p .4643 .49979 L 0 0 0 r
F P
0 g
s
.464 .50005 m .4643 .50021 L p .46357 .50002 L .004 .55 .832 r
F P
0 g
s
.464 .50005 m .46391 .5 L p .46542 .50016 L 0 .543 .828 r
F P
0 g
s
.46391 .5 m .464 .49995 L p .4651 .5 L 0 0 0 r
F P
0 g
s
.4651 .5 m .4651 .5 L .46483 .5 L 0 0 0 r
F
.4651 .5 m .46483 .5 L .46391 .5 L F
.46483 .5 m .46497 .50003 L .46496 .50004 L 0 .543 .828 r
F
.46483 .5 m .46542 .50016 L .46391 .5 L F
.46542 .50016 m .47157 .50184 L .464 .50005 L F
.4651 .5 m .463 .5005 L .46391 .5 L p 0 0 0 r
F P
0 g
s
.464 .49995 m .4643 .49979 L p .46597 .49979 L 0 0 0 r
F P
0 g
s
.463 .4995 m .4651 .5 L p .46483 .5 L 0 .543 .828 r
F P
0 g
s
.463 .4995 m .46293 .4995 L p .46505 .5 L .169 0 0 r
F P
0 g
s
.4651 .5 m .47059 .5013 L p .46497 .50003 L 0 .543 .828 r
F P
0 g
s
.4651 .5 m .46497 .50003 L .46483 .5 L 0 .543 .828 r
F
.47059 .4987 m .47055 .4987 L p .46529 .49995 L .169 .7 .695 r
F P
0 g
s
.47055 .5013 m .47059 .5013 L p .46505 .5 L .169 0 0 r
F P
0 g
s
.46293 .4995 m .46504 .5 L p .46505 .5 L .169 0 0 r
F P
0 g
s
.46504 .5 m .47055 .5013 L p .46505 .5 L .169 0 0 r
F P
0 g
s
.46597 .49979 m .4651 .5 L p .464 .49995 L 0 0 0 r
F P
0 g
s
.46508 .5 m .4651 .5 L .46529 .49995 L .169 .7 .695 r
F
.463 .5005 m .4651 .5 L p .46508 .5 L F P
0 g
s
.4651 .5 m .47059 .4987 L p .46529 .49995 L .169 .7 .695 r
F P
0 g
s
.47059 .5013 m .4651 .5 L p .46505 .5 L .169 0 0 r
F P
0 g
s
.4651 .5 m .463 .4995 L p .46505 .5 L .169 0 0 r
F P
0 g
s
.46293 .5005 m .463 .5005 L p .46508 .5 L .169 .7 .695 r
F P
0 g
s
.46508 .5 m .46529 .49995 L .46508 .5 L .169 .7 .695 r
F
.46508 .5 m .46508 .5 L .46293 .5005 L F
.47055 .4987 m .46584 .49981 L p .46529 .49995 L F P
0 g
s
.46584 .49981 m .46293 .5005 L p .46529 .49995 L .169 .7 .695 r
F P
0 g
s
.47059 .5013 m .47157 .50184 L p .46496 .50004 L 0 .543 .828 r
F P
0 g
s
.46497 .50003 m .47059 .5013 L .46496 .50004 L 0 .543 .828 r
F
.46334 .5 m .4643 .49979 L .464 .49995 L p .004 0 0 r
F P
0 g
s
.4643 .49979 m .46334 .5 L p .46218 .49992 L .143 0 0 r
F P
0 g
s
.46391 .5 m .463 .4995 L p .46483 .5 L 0 .543 .828 r
F P
0 g
s
.454 .50203 m .46334 .5 L p .463 .5005 L .004 0 0 r
F P
0 g
s
.4643 .50021 m .46334 .5 L p .46357 .50002 L .004 .55 .832 r
F P
0 g
s
.464 .49995 m .463 .5005 L p .46334 .5 L .004 0 0 r
F P
0 g
s
.46116 .5 m .4623 .50008 L .46161 .50013 L .143 .623 .921 r
F
.46073 .5 m .46218 .49992 L .46185 .5 L .143 0 0 r
F
.46073 .5 m .46185 .5 L .46116 .5 L F
.46218 .49992 m .46172 .49988 L .46186 .49988 L F
.46218 .49992 m .46186 .49988 L .46227 .49991 L F
.46073 .5 m .46172 .49988 L .46218 .49992 L F
.454 .49797 m .46334 .5 L p .46116 .5 L .143 .623 .921 r
F P
0 g
s
.46116 .5 m .46185 .5 L .46185 .5 L .143 0 0 r
F
.46073 .5 m .46185 .5 L .454 .50203 L F
.46334 .5 m .454 .50203 L p .46218 .49992 L F P
0 g
s
.454 .49797 m .45226 .49704 L p .46357 .50002 L .004 .55 .832 r
F P
0 g
s
.45226 .49704 m .463 .4995 L .464 .50005 L p .004 .55 .832 r
F P
0 g
s
.45226 .49704 m .464 .50005 L .46357 .50002 L .004 .55 .832 r
F
.46334 .5 m .454 .49797 L p .46357 .50002 L F P
0 g
s
.45834 .5 m .45726 .4998 L p .46116 .5 L .143 .623 .921 r
F P
0 g
s
.45726 .5002 m .45834 .5 L p .46073 .5 L .143 0 0 r
F P
0 g
s
.45796 .5 m .45802 .50001 L .458 .50001 L .241 .653 .961 r
F
.45847 .49998 m .45834 .5 L p .45762 .5 L .241 0 0 r
F P
0 g
s
.45726 .4998 m .45834 .5 L p .45796 .5 L .241 .653 .961 r
F P
0 g
s
.45834 .5 m .45726 .5002 L .45762 .5 L p .241 0 0 r
F P
0 g
s
.45236 .5 m .45762 .5 L .4529 .50014 L .292 .681 .974 r
F
.45762 .5 m .45762 .5 L .4529 .50014 L F
.45236 .5 m .45624 .5 L .45236 .5 L F
.45624 .5 m .45762 .5 L .45236 .5 L F
.45762 .5 m .45726 .5002 L p .45624 .5 L .292 0 0 r
F P
0 g
s
.44974 .49871 m .45762 .5 L .45624 .5 L .292 0 0 r
F
.45624 .5 m .45624 .5 L .45236 .5 L F
.45624 .5 m .45236 .5 L .44746 .5 L F
.44344 .49774 m .45726 .4998 L .45762 .5 L p .292 .681 .974 r
F P
0 g
s
.44344 .49774 m .45762 .5 L .45236 .5 L .292 .681 .974 r
F
.44746 .5 m .44344 .49774 L p .45236 .5 L F P
0 g
s
.45624 .5 m .45726 .5002 L .44746 .5 L .292 0 0 r
F
.45726 .5002 m .44344 .50226 L .44746 .5 L p F P
0 g
s
.44277 .5 m .44746 .5 L .44381 .50019 L .387 .728 .99 r
F
.43139 .49883 m .44746 .5 L .43549 .5 L .387 0 0 r
F
.42267 .49629 m .44746 .5 L .44277 .5 L .387 .728 .99 r
F
.44746 .5 m .44344 .50226 L p .43549 .5 L .387 0 0 r
F P
0 g
s
.43422 .49964 m .43549 .5 L .4293 .5 L .387 0 0 r
F
.4293 .5 m .42267 .49629 L p .44277 .5 L .387 .728 .99 r
F P
0 g
s
.43549 .5 m .44344 .50226 L .4293 .5 L .387 0 0 r
F
.44344 .50226 m .42267 .50371 L .4293 .5 L p F P
0 g
s
.41446 .5 m .42267 .50371 L .39371 .5 L .515 .061 .111 r
F
.41418 .5 m .39371 .5 L .39371 .5 L F
.41446 .5 m .39371 .5 L .41418 .5 L F
.4293 .5 m .4293 .5 L p .41446 .5 L .515 .78 .992 r
F P
0 g
s
.4293 .5 m .42267 .50371 L p .41446 .5 L .515 .061 .111 r
F P
0 g
s
.39371 .5 m .39083 .49841 L p .41418 .5 L .515 .78 .992 r
F P
0 g
s
.42267 .50371 m .39083 .50159 L .39371 .5 L p .515 .061 .111 r
F P
0 g
s
.38534 .5 m .39371 .5 L .39055 .50029 L .651 .816 .963 r
F
.39371 .5 m .39371 .5 L .39055 .50029 L F
.33051 .50592 m .35547 .5 L p .35547 .5 L .613 .87 .991 r
F P
0 g
s
.33051 .50592 m .35547 .5 L .36954 .50107 L .613 .87 .991 r
F
.32163 .49731 m .32326 .49734 L p .33397 .49966 L .174 0 0 r
F P
0 g
s
.33051 .50592 m .32326 .50266 L p .338 .50041 L .483 .88 .958 r
F P
0 g
s
.338 .50041 m .33951 .50069 L .33051 .50592 L .483 .88 .958 r
F
.34733 .49938 m .34928 .5 L .32489 .49769 L .483 0 0 r
F
.34071 .5 m .34928 .5 L .33051 .50592 L .483 .88 .958 r
F
.35547 .5 m .33051 .50592 L p .34928 .5 L F P
0 g
s
.338 .50041 m .34071 .5 L .33951 .50069 L .483 .88 .958 r
F
.33579 .5 m .32489 .49769 L p .34928 .5 L .483 0 0 r
F P
0 g
s
.33051 .49408 m .35547 .5 L p .34733 .49938 L .483 0 0 r
F P
0 g
s
.34294 .48775 m .38534 .5 L p .36651 .49894 L .613 .13 .084 r
F P
0 g
s
.36651 .49894 m .36874 .5 L .34617 .49779 L .613 .13 .084 r
F
.34427 .49842 m .34733 .49938 L .34167 .4989 L .483 0 0 r
F
.32489 .49769 m .32326 .49734 L p .34733 .49938 L F P
0 g
s
.35547 .5 m .35547 .5 L p .36874 .5 L .613 .87 .991 r
F P
0 g
s
.35547 .5 m .34617 .49779 L p .36874 .5 L .613 .13 .084 r
F P
0 g
s
.34617 .49779 m .33051 .49408 L p .36651 .49894 L .613 .13 .084 r
F P
0 g
s
.37705 .49124 m .38201 .4937 L p .34071 .5 L .483 .88 .958 r
F P
0 g
s
.32326 .50266 m .33579 .5 L p .338 .50041 L .483 .88 .958 r
F P
0 g
s
.32396 .50221 m .33464 .5 L .33579 .5 L .174 .706 .719 r
F
.33397 .49966 m .33558 .5 L .33554 .5 L .174 0 0 r
F
.32326 .49734 m .33579 .5 L p .33397 .49966 L F P
0 g
s
.33579 .5 m .32326 .50266 L p .32396 .50221 L .174 .706 .719 r
F P
0 g
s
.33579 .5 m .37705 .50876 L p .33558 .5 L .174 0 0 r
F P
0 g
s
.33579 .5 m .33558 .5 L .33397 .49966 L .174 0 0 r
F
.32163 .50269 m .33438 .5 L p .33464 .5 L .174 .706 .719 r
F P
0 g
s
.37623 .50882 m .32356 .49772 L p .33397 .49966 L .174 0 0 r
F P
0 g
s
.37623 .49118 m .37705 .49124 L p .33464 .5 L .174 .706 .719 r
F P
0 g
s
.33438 .5 m .37623 .49118 L p .33464 .5 L .174 .706 .719 r
F P
0 g
s
.37705 .49124 m .33579 .5 L p .33464 .5 L .174 .706 .719 r
F P
0 g
s
.37705 .50876 m .37623 .50882 L p .33554 .5 L .174 0 0 r
F P
0 g
s
.33558 .5 m .37705 .50876 L .33554 .5 L .174 0 0 r
F
.338 .50041 m .33579 .5 L .34071 .5 L .483 .88 .958 r
F
.33579 .5 m .37705 .49124 L p .34071 .5 L F P
0 g
s
.37705 .50876 m .33579 .5 L p .34071 .5 L .483 0 0 r
F P
0 g
s
.34733 .49938 m .35042 .5 L .34928 .5 L .483 0 0 r
F
.35547 .5 m .35547 .5 L p .34928 .5 L .483 .88 .958 r
F P
0 g
s
.35547 .5 m .38201 .5063 L p .34733 .49938 L .483 0 0 r
F P
0 g
s
.38201 .4937 m .35547 .5 L p .34071 .5 L .483 .88 .958 r
F P
0 g
s
.34928 .5 m .34928 .5 L .34071 .5 L .483 0 0 r
F
.34928 .5 m .37705 .50876 L .34071 .5 L F
.32356 .49772 m .32163 .49731 L p .33397 .49966 L .174 0 0 r
F P
0 g
s
.38201 .5063 m .37705 .50876 L p .34928 .5 L .483 0 0 r
F P
0 g
s
.35042 .5 m .38201 .5063 L .34928 .5 L .483 0 0 r
F
.36954 .50107 m .35547 .5 L .37809 .5 L .613 .87 .991 r
F
.35547 .5 m .36874 .5 L .37809 .5 L F
.36954 .50107 m .37809 .5 L .37405 .50141 L F
.39083 .50159 m .38201 .5063 L p .36874 .5 L .613 .13 .084 r
F P
0 g
s
.36651 .49894 m .37626 .5 L .36874 .5 L .613 .13 .084 r
F
.37626 .5 m .39083 .50159 L .36874 .5 L F
.39083 .49841 m .38534 .5 L p .38534 .5 L .613 .87 .991 r
F P
0 g
s
.37809 .5 m .37809 .5 L .38534 .5 L .613 .87 .991 r
F
.38534 .5 m .37809 .5 L .36651 .49894 L .613 .13 .084 r
F
.37809 .5 m .37626 .5 L .36651 .49894 L F
.35547 .5 m .38201 .4937 L p .37809 .5 L .613 .87 .991 r
F P
0 g
s
.37809 .5 m .37626 .5 L .37626 .5 L .613 .13 .084 r
F
.38201 .4937 m .39083 .49841 L p .37809 .5 L .613 .87 .991 r
F P
0 g
s
.37809 .5 m .39083 .49841 L .38534 .5 L .613 .87 .991 r
F
.38534 .5 m .39083 .50159 L p .37626 .5 L .613 .13 .084 r
F P
0 g
s
.39371 .5 m .39083 .50159 L p .38869 .5 L .651 .247 .265 r
F P
0 g
s
.38534 .5 m .39083 .49841 L .39371 .5 L p .651 .816 .963 r
F P
0 g
s
.38534 .5 m .39371 .5 L .38869 .5 L .651 .816 .963 r
F
.38201 .5063 m .35547 .5 L p .36874 .5 L .613 .13 .084 r
F P
0 g
s
.39083 .50159 m .38534 .5 L p .38869 .5 L .651 .247 .265 r
F P
0 g
s
.55159 .36803 m .54401 .41347 L .52915 .42232 L p .406 .222 .515 r
F P
0 g
s
.54401 .41347 m .55159 .36803 L .56792 .35786 L p .294 .123 .472 r
F P
0 g
s
.56275 .28156 m .56792 .35786 L .55159 .36803 L p .394 .302 .632 r
F P
0 g
s
.58988 .35618 m .58914 .37011 L p .56766 .38492 L .893 .967 .829 r
F P
0 g
s
.56792 .35786 m .55733 .4007 L p .54401 .41347 L .294 .123 .472 r
F P
0 g
s
.58607 .3456 m .58686 .34419 L p .58611 .34644 L 0 0 0 r
F P
0 g
s
.59068 .34827 m .58988 .35618 L p .57923 .36593 L .819 .996 .764 r
F P
0 g
s
.57923 .36593 m .58011 .36343 L .59068 .34827 L .819 .996 .764 r
F
.56792 .35786 m .57961 .35026 L p .56431 .38648 L .108 0 .376 r
F P
0 g
s
.56431 .38648 m .56175 .39022 L .56792 .35786 L .108 0 .376 r
F
.55733 .4007 m .56792 .35786 L p .56095 .39443 L F P
0 g
s
.58914 .37011 m .58849 .38934 L p .55566 .4036 L .898 .901 .82 r
F P
0 g
s
.55733 .4007 m .58914 .37011 L p .55608 .40318 L .898 .901 .82 r
F P
0 g
s
.55566 .4036 m .55733 .4007 L .55608 .40318 L .898 .901 .82 r
F
.58849 .38934 m .55293 .41862 L .55315 .40795 L p F P
0 g
s
.55315 .40795 m .55315 .40795 L p .55566 .4036 L .294 .123 .472 r
F P
0 g
s
.55315 .40795 m .55221 .40851 L p .55447 .40507 L .294 .123 .472 r
F P
0 g
s
.55221 .40851 m .54401 .41347 L p .55733 .4007 L .294 .123 .472 r
F P
0 g
s
.54401 .41347 m .53329 .44 L .52257 .44632 L p .312 .066 .37 r
F P
0 g
s
.55315 .40795 m .55293 .41862 L p .54593 .42365 L .952 .931 .74 r
F P
0 g
s
.55293 .41862 m .53532 .44116 L .53535 .43877 L p .952 .931 .74 r
F P
0 g
s
.55293 .41862 m .53535 .43877 L .54277 .42592 L .952 .931 .74 r
F
.54593 .42365 m .54277 .42592 L .55315 .40795 L F
.58849 .38934 m .55315 .40795 L .55566 .4036 L .898 .901 .82 r
F
.55596 .40625 m .53535 .43877 L .54277 .42592 L .189 0 .299 r
F
.53532 .44116 m .55293 .41862 L .55269 .43591 L p .948 .884 .737 r
F P
0 g
s
.55596 .40625 m .54188 .43488 L .53535 .43877 L p .189 0 .299 r
F P
0 g
s
.54291 .42568 m .54277 .42592 L .53848 .43229 L .189 0 .299 r
F
.53851 .43222 m .53848 .43229 L .53329 .44 L F
.54291 .42568 m .53848 .43229 L .53851 .43222 L F
.53535 .43877 m .53329 .44 L p .54277 .42592 L F P
0 g
s
.53329 .44 m .54401 .41347 L .55315 .40795 L p .189 0 .299 r
F P
0 g
s
.54291 .42568 m .53329 .44 L .55315 .40795 L .189 0 .299 r
F
.51622 .46041 m .52257 .44632 L .53329 .44 L p .223 0 .233 r
F P
0 g
s
.53329 .44 m .52402 .45583 L .51622 .46041 L p .223 0 .233 r
F P
0 g
s
.53535 .43877 m .53532 .44116 L p .5332 .44321 L .972 .93 .653 r
F P
0 g
s
.53532 .44116 m .52624 .45712 L .52627 .4545 L p .972 .93 .653 r
F P
0 g
s
.55269 .43591 m .5352 .45361 L .53532 .44116 L p .948 .884 .737 r
F P
0 g
s
.52624 .45712 m .53532 .44116 L .5352 .45361 L p .978 .899 .669 r
F P
0 g
s
.54188 .43488 m .53024 .45215 L .52627 .4545 L p .097 0 .148 r
F P
0 g
s
.52627 .4545 m .52402 .45583 L p .52793 .45124 L .097 0 .148 r
F P
0 g
s
.52402 .45583 m .53329 .44 L .53535 .43877 L p .097 0 .148 r
F P
0 g
s
.52862 .45044 m .52402 .45583 L .53535 .43877 L .097 0 .148 r
F
.51118 .46917 m .51622 .46041 L .52402 .45583 L p .154 0 .129 r
F P
0 g
s
.52402 .45583 m .51695 .4658 L .51118 .46917 L p .154 0 .129 r
F P
0 g
s
.52627 .4545 m .52624 .45712 L p .52312 .46069 L .971 .916 .582 r
F P
0 g
s
.51695 .4658 m .52402 .45583 L .52627 .4545 L p .032 0 .04 r
F P
0 g
s
.52312 .46069 m .52188 .46211 L .52627 .4545 L .971 .916 .582 r
F
.518 .47199 m .52079 .46405 L p .52115 .46822 L .967 .904 .542 r
F P
0 g
s
.5118 .47244 m .51695 .4658 L .52119 .4633 L p 0 0 0 r
F P
0 g
s
.52624 .45712 m .52115 .46822 L .52119 .4633 L p .971 .916 .582 r
F P
0 g
s
.52119 .4633 m .52154 .46309 L p .52102 .46359 L 0 0 0 r
F P
0 g
s
.52102 .46359 m .5118 .47244 L .52119 .4633 L 0 0 0 r
F
.51526 .47041 m .5118 .47244 L p .52099 .46362 L F P
0 g
s
.52098 .46364 m .51526 .47041 L .52099 .46362 L 0 0 0 r
F
.52083 .46392 m .51526 .47041 L p .52102 .46359 L F P
0 g
s
.52119 .4633 m .51695 .4658 L p .52343 .45914 L .032 0 .04 r
F P
0 g
s
.51964 .46599 m .52083 .46392 L .51924 .46691 L .917 .89 .474 r
F
.51262 .47446 m .51767 .46897 L .51796 .4688 L p 0 0 0 r
F P
0 g
s
.52083 .46392 m .518 .47199 L .51803 .4692 L p .917 .89 .474 r
F P
0 g
s
.51803 .4692 m .51803 .46918 L p .51924 .46691 L .917 .89 .474 r
F P
0 g
s
.52083 .46392 m .51927 .46687 L .51924 .46691 L .917 .89 .474 r
F
.51927 .46687 m .51803 .4692 L .51924 .46691 L F
.51894 .46737 m .51918 .46703 L .51803 .46918 L F
.52119 .4633 m .52115 .46822 L p .52079 .46405 L .967 .904 .542 r
F P
0 g
s
.5352 .45361 m .52618 .46616 L .52624 .45712 L p .978 .899 .669 r
F P
0 g
s
.52115 .46822 m .52624 .45712 L .52618 .46616 L p .987 .898 .61 r
F P
0 g
s
.52154 .46309 m .52475 .46118 L p .51942 .46636 L 0 0 0 r
F P
0 g
s
.51526 .47041 m .52083 .46392 L p .51942 .46636 L 0 0 0 r
F P
0 g
s
.52382 .45874 m .51695 .4658 L .52627 .4545 L .032 0 .04 r
F
.52125 .45915 m .52119 .46289 L p .51964 .46599 L .917 .89 .474 r
F P
0 g
s
.51767 .46897 m .51526 .47041 L p .51909 .46669 L 0 0 0 r
F P
0 g
s
.51878 .46731 m .51767 .46897 L .51909 .46669 L 0 0 0 r
F
.51833 .46825 m .51832 .46826 L p .51942 .46636 L F P
0 g
s
.51832 .46826 m .51767 .46897 L p .51874 .46738 L 0 0 0 r
F P
0 g
s
.51832 .46826 m .51874 .46738 L .51942 .46636 L 0 0 0 r
F
.51583 .47518 m .51719 .47063 L p .51803 .46918 L .82 .828 .352 r
F P
0 g
s
.51796 .4688 m .51767 .46897 L p .5182 .46844 L 0 0 0 r
F P
0 g
s
.51796 .4688 m .51804 .46875 L p .51715 .46997 L 0 0 0 r
F P
0 g
s
.51804 .46875 m .51804 .46885 L p .51745 .46977 L .82 .828 .352 r
F P
0 g
s
.51745 .46977 m .51745 .46977 L .51759 .46954 L .82 .828 .352 r
F
.51745 .46977 m .51759 .46954 L .51804 .46875 L F
.51759 .46954 m .51749 .46965 L .51749 .46963 L 0 0 0 r
F
.51759 .46954 m .51715 .46997 L .51804 .46875 L F
.51715 .46997 m .51262 .47446 L .51796 .4688 L F
.51745 .46977 m .51807 .46771 L .51804 .46875 L p .82 .828 .352 r
F P
0 g
s
.51804 .46885 m .51803 .46918 L p .51719 .47063 L .82 .828 .352 r
F P
0 g
s
.51893 .46821 m .51745 .46977 L p .51759 .46954 L 0 0 0 r
F P
0 g
s
.51893 .46821 m .51896 .46815 L p .51747 .46973 L .521 .821 .492 r
F P
0 g
s
.51745 .46977 m .51358 .47388 L p .51749 .46965 L 0 0 0 r
F P
0 g
s
.51745 .46977 m .51749 .46965 L .51759 .46954 L 0 0 0 r
F
.51583 .47518 m .51585 .47514 L p .5174 .46996 L F P
0 g
s
.5136 .47384 m .51358 .47388 L p .51747 .46973 L .521 .821 .492 r
F P
0 g
s
.51896 .46815 m .51748 .46972 L p .51747 .46973 L .521 .821 .492 r
F P
0 g
s
.51748 .46972 m .5136 .47384 L p .51747 .46973 L .521 .821 .492 r
F P
0 g
s
.51719 .47063 m .51745 .46977 L p .51804 .46885 L .82 .828 .352 r
F P
0 g
s
.51746 .46976 m .51745 .46977 L .5174 .46996 L 0 0 0 r
F
.51807 .46771 m .51745 .46977 L p .51746 .46976 L F P
0 g
s
.51745 .46977 m .51583 .47518 L p .5174 .46996 L 0 0 0 r
F P
0 g
s
.51358 .47388 m .51745 .46977 L p .51747 .46973 L .521 .821 .492 r
F P
0 g
s
.51745 .46977 m .51893 .46821 L p .51747 .46973 L .521 .821 .492 r
F P
0 g
s
.5181 .46765 m .51807 .46771 L p .51746 .46976 L 0 0 0 r
F P
0 g
s
.51746 .46976 m .5174 .46996 L .51746 .46976 L 0 0 0 r
F
.51746 .46976 m .51746 .46976 L .5181 .46765 L F
.51585 .47514 m .51724 .47051 L p .5174 .46996 L F P
0 g
s
.51724 .47051 m .5181 .46765 L p .5174 .46996 L 0 0 0 r
F P
0 g
s
.51358 .47388 m .51262 .47446 L p .51749 .46963 L 0 0 0 r
F P
0 g
s
.51749 .46965 m .51358 .47388 L .51749 .46963 L 0 0 0 r
F
.51833 .46825 m .51803 .46918 L .51804 .46885 L p .821 .832 .36 r
F P
0 g
s
.51803 .46918 m .51833 .46825 L p .51898 .46729 L .917 .89 .474 r
F P
0 g
s
.51804 .46875 m .51893 .46821 L p .51759 .46954 L 0 0 0 r
F P
0 g
s
.52125 .45915 m .51833 .46825 L p .51807 .46771 L .821 .832 .36 r
F P
0 g
s
.51767 .46897 m .51833 .46825 L p .5182 .46844 L 0 0 0 r
F P
0 g
s
.51804 .46885 m .51807 .46771 L p .51833 .46825 L .821 .832 .36 r
F P
0 g
s
.51942 .46636 m .51878 .46731 L .51909 .46669 L 0 0 0 r
F
.51964 .46599 m .51898 .46729 L .51907 .46696 L .917 .89 .474 r
F
.51964 .46599 m .51907 .46696 L .51942 .46636 L F
.51898 .46729 m .51924 .46691 L .51918 .46703 L F
.51898 .46729 m .51918 .46703 L .51894 .46737 L F
.51964 .46599 m .51924 .46691 L .51898 .46729 L F
.52475 .46118 m .51833 .46825 L p .51942 .46636 L 0 0 0 r
F P
0 g
s
.51942 .46636 m .51907 .46696 L .51907 .46696 L .917 .89 .474 r
F
.51964 .46599 m .51907 .46696 L .52125 .45915 L F
.51833 .46825 m .52125 .45915 L p .51898 .46729 L F P
0 g
s
.52475 .46118 m .52644 .46014 L p .5182 .46844 L 0 0 0 r
F P
0 g
s
.52644 .46014 m .51893 .46821 L .51796 .4688 L p 0 0 0 r
F P
0 g
s
.52644 .46014 m .51796 .4688 L .5182 .46844 L 0 0 0 r
F
.51833 .46825 m .52475 .46118 L p .5182 .46844 L F P
0 g
s
.52083 .46392 m .52154 .46309 L p .51942 .46636 L 0 0 0 r
F P
0 g
s
.52119 .46289 m .52083 .46392 L p .51964 .46599 L .917 .89 .474 r
F P
0 g
s
.52102 .46359 m .52098 .46364 L .52099 .46362 L 0 0 0 r
F
.52079 .46405 m .52083 .46392 L p .52119 .4633 L .967 .904 .542 r
F P
0 g
s
.52154 .46309 m .52083 .46392 L p .52102 .46359 L 0 0 0 r
F P
0 g
s
.52083 .46392 m .52119 .46289 L .52119 .4633 L p .967 .904 .542 r
F P
0 g
s
.52382 .45874 m .52119 .4633 L .52343 .45914 L .032 0 .04 r
F
.52119 .4633 m .52119 .4633 L .52343 .45914 L F
.52382 .45874 m .52188 .46211 L .52382 .45874 L F
.52188 .46211 m .52119 .4633 L .52382 .45874 L F
.52119 .4633 m .52119 .46289 L p .52188 .46211 L .971 .916 .582 r
F P
0 g
s
.52624 .45712 m .52119 .4633 L .52188 .46211 L .971 .916 .582 r
F
.52188 .46211 m .52188 .46211 L .52382 .45874 L F
.52188 .46211 m .52382 .45874 L .52627 .4545 L F
.53024 .45215 m .52154 .46309 L .52119 .4633 L p .032 0 .04 r
F P
0 g
s
.53024 .45215 m .52119 .4633 L .52382 .45874 L .032 0 .04 r
F
.52627 .4545 m .53024 .45215 L p .52382 .45874 L F P
0 g
s
.52188 .46211 m .52119 .46289 L .52627 .4545 L .971 .916 .582 r
F
.52119 .46289 m .52632 .44989 L .52627 .4545 L p F P
0 g
s
.52862 .45044 m .52627 .4545 L .52793 .45124 L .097 0 .148 r
F
.53532 .44116 m .52627 .4545 L .53225 .44413 L .972 .93 .653 r
F
.54188 .43488 m .52627 .4545 L .52862 .45044 L .097 0 .148 r
F
.52627 .4545 m .52632 .44989 L p .53225 .44413 L .972 .93 .653 r
F P
0 g
s
.5332 .44321 m .53225 .44413 L .53535 .43877 L .972 .93 .653 r
F
.53535 .43877 m .54188 .43488 L p .52862 .45044 L .097 0 .148 r
F P
0 g
s
.53225 .44413 m .52632 .44989 L .53535 .43877 L .972 .93 .653 r
F
.52632 .44989 m .53546 .43117 L .53535 .43877 L p F P
0 g
s
.54277 .42592 m .53546 .43117 L .55315 .40795 L .952 .931 .74 r
F
.54291 .42568 m .55315 .40795 L .55315 .40795 L F
.54277 .42592 m .55315 .40795 L .54291 .42568 L F
.53535 .43877 m .53535 .43877 L p .54277 .42592 L .189 0 .299 r
F P
0 g
s
.53535 .43877 m .53546 .43117 L p .54277 .42592 L .952 .931 .74 r
F P
0 g
s
.55315 .40795 m .55596 .40625 L p .54291 .42568 L .189 0 .299 r
F P
0 g
s
.53546 .43117 m .55321 .40466 L .55315 .40795 L p .952 .931 .74 r
F P
0 g
s
.55733 .4007 m .55315 .40795 L .55447 .40507 L .294 .123 .472 r
F
.55315 .40795 m .55315 .40795 L .55447 .40507 L F
.57961 .35026 m .57227 .37483 L p .57227 .37483 L .108 0 .376 r
F P
0 g
s
.57961 .35026 m .57227 .37483 L .56431 .38648 L .108 0 .376 r
F
.59151 .34687 m .59068 .34827 L p .58331 .35638 L .553 .837 .5 r
F P
0 g
s
.57961 .35026 m .58607 .3456 L p .58064 .3595 L 0 0 .17 r
F P
0 g
s
.58064 .3595 m .57964 .36067 L .57961 .35026 L 0 0 .17 r
F
.57687 .36809 m .57536 .36947 L .58956 .34951 L .819 .996 .764 r
F
.57965 .36205 m .57536 .36947 L .57961 .35026 L 0 0 .17 r
F
.57227 .37483 m .57961 .35026 L p .57536 .36947 L F P
0 g
s
.58064 .3595 m .57965 .36205 L .57964 .36067 L 0 0 .17 r
F
.5821 .35779 m .58956 .34951 L p .57536 .36947 L .819 .996 .764 r
F P
0 g
s
.58988 .35618 m .57227 .37483 L p .57687 .36809 L .819 .996 .764 r
F P
0 g
s
.58914 .37011 m .55733 .4007 L p .56766 .38492 L .893 .967 .829 r
F P
0 g
s
.56766 .38492 m .56563 .38633 L .57882 .36789 L .893 .967 .829 r
F
.57923 .36593 m .57687 .36809 L .58011 .36343 L .819 .996 .764 r
F
.58956 .34951 m .59068 .34827 L p .57687 .36809 L F P
0 g
s
.57227 .37483 m .57227 .37483 L p .56563 .38633 L .108 0 .376 r
F P
0 g
s
.57227 .37483 m .57882 .36789 L p .56563 .38633 L .893 .967 .829 r
F P
0 g
s
.57882 .36789 m .58988 .35618 L p .56766 .38492 L .893 .967 .829 r
F P
0 g
s
.56907 .3979 m .56445 .40097 L p .57965 .36205 L 0 0 .17 r
F P
0 g
s
.58607 .3456 m .5821 .35779 L p .58064 .3595 L 0 0 .17 r
F P
0 g
s
.58611 .34644 m .58268 .35679 L .5821 .35779 L 0 0 0 r
F
.58331 .35638 m .58221 .35761 L .58223 .35757 L .553 .837 .5 r
F
.59068 .34827 m .5821 .35779 L p .58331 .35638 L F P
0 g
s
.5821 .35779 m .58607 .3456 L p .58611 .34644 L 0 0 0 r
F P
0 g
s
.5821 .35779 m .55389 .38914 L p .58221 .35761 L .553 .837 .5 r
F P
0 g
s
.5821 .35779 m .58221 .35761 L .58331 .35638 L .553 .837 .5 r
F
.58686 .34419 m .58281 .35657 L p .58268 .35679 L 0 0 0 r
F P
0 g
s
.55425 .3884 m .5902 .34834 L p .58331 .35638 L .553 .837 .5 r
F P
0 g
s
.56953 .39722 m .56907 .3979 L p .58268 .35679 L 0 0 0 r
F P
0 g
s
.58281 .35657 m .56953 .39722 L p .58268 .35679 L 0 0 0 r
F P
0 g
s
.56907 .3979 m .5821 .35779 L p .58268 .35679 L 0 0 0 r
F P
0 g
s
.55389 .38914 m .55425 .3884 L p .58223 .35757 L .553 .837 .5 r
F P
0 g
s
.58221 .35761 m .55389 .38914 L .58223 .35757 L .553 .837 .5 r
F
.58064 .3595 m .5821 .35779 L .57965 .36205 L 0 0 .17 r
F
.5821 .35779 m .56907 .3979 L p .57965 .36205 L F P
0 g
s
.55389 .38914 m .5821 .35779 L p .57965 .36205 L .819 .996 .764 r
F P
0 g
s
.57687 .36809 m .57479 .37046 L .57536 .36947 L .819 .996 .764 r
F
.57227 .37483 m .57227 .37483 L p .57536 .36947 L 0 0 .17 r
F P
0 g
s
.57227 .37483 m .55354 .39467 L p .57687 .36809 L .819 .996 .764 r
F P
0 g
s
.56445 .40097 m .57227 .37483 L p .57965 .36205 L 0 0 .17 r
F P
0 g
s
.57536 .36947 m .57536 .36947 L .57965 .36205 L .819 .996 .764 r
F
.57536 .36947 m .55389 .38914 L .57965 .36205 L F
.5902 .34834 m .59151 .34687 L p .58331 .35638 L .553 .837 .5 r
F P
0 g
s
.55354 .39467 m .55389 .38914 L p .57536 .36947 L .819 .996 .764 r
F P
0 g
s
.57479 .37046 m .55354 .39467 L .57536 .36947 L .819 .996 .764 r
F
.56431 .38648 m .57227 .37483 L .56095 .39443 L .108 0 .376 r
F
.57227 .37483 m .56563 .38633 L .56095 .39443 L F
.56431 .38648 m .56095 .39443 L .56175 .39022 L F
.55321 .40466 m .55354 .39467 L p .56563 .38633 L .893 .967 .829 r
F P
0 g
s
.56766 .38492 m .56187 .39284 L .56563 .38633 L .893 .967 .829 r
F
.56187 .39284 m .55321 .40466 L .56563 .38633 L F
.55596 .40625 m .55733 .4007 L p .55733 .4007 L .108 0 .376 r
F P
0 g
s
.56095 .39443 m .56095 .39443 L .55733 .4007 L .108 0 .376 r
F
.55733 .4007 m .56095 .39443 L .56766 .38492 L .893 .967 .829 r
F
.56095 .39443 m .56187 .39284 L .56766 .38492 L F
.57227 .37483 m .56445 .40097 L p .56095 .39443 L .108 0 .376 r
F P
0 g
s
.56095 .39443 m .56187 .39284 L .56187 .39284 L .893 .967 .829 r
F
.56445 .40097 m .55596 .40625 L p .56095 .39443 L .108 0 .376 r
F P
0 g
s
.56095 .39443 m .55596 .40625 L .55733 .4007 L .108 0 .376 r
F
.55733 .4007 m .55321 .40466 L p .56187 .39284 L .893 .967 .829 r
F P
0 g
s
.55315 .40795 m .55321 .40466 L p .55566 .4036 L .898 .901 .82 r
F P
0 g
s
.55733 .4007 m .55596 .40625 L .55315 .40795 L p .294 .123 .472 r
F P
0 g
s
.55733 .4007 m .55315 .40795 L .55566 .4036 L .294 .123 .472 r
F
.55354 .39467 m .57227 .37483 L p .56563 .38633 L .893 .967 .829 r
F P
0 g
s
.55321 .40466 m .55733 .4007 L p .55566 .4036 L .898 .901 .82 r
F P
0 g
s
.35992 .52131 m .40306 .50515 L .41815 .51359 L p .655 .762 .928 r
F P
0 g
s
.27945 .55488 m .34294 .51225 L .35992 .52131 L p .767 .821 .895 r
F P
0 g
s
.58849 .61066 m .55293 .58138 L .55269 .56409 L p .889 .608 .506 r
F P
0 g
s
.55293 .58138 m .58849 .61066 L .58914 .62989 L p .898 .565 .408 r
F P
0 g
s
.6578 .66356 m .58914 .62989 L .58849 .61066 L p .808 .484 .441 r
F P
0 g
s
.57961 .64974 m .56792 .64214 L p .56583 .61614 L .108 .22 .699 r
F P
0 g
s
.58914 .62989 m .55733 .5993 L p .55293 .58138 L .898 .565 .408 r
F P
0 g
s
.59068 .65173 m .59151 .65313 L p .58993 .65135 L .553 .066 0 r
F P
0 g
s
.58607 .6544 m .57961 .64974 L p .57649 .63566 L 0 0 .558 r
F P
0 g
s
.57649 .63566 m .57821 .63766 L .58607 .6544 L 0 0 .558 r
F
.58914 .62989 m .58988 .64382 L p .56615 .61245 L .893 .491 .246 r
F P
0 g
s
.56615 .61245 m .56419 .60837 L .58914 .62989 L .893 .491 .246 r
F
.55733 .5993 m .58914 .62989 L p .56095 .60557 L F P
0 g
s
.56792 .64214 m .55159 .63197 L p .55566 .5964 L .294 .356 .757 r
F P
0 g
s
.55733 .5993 m .56792 .64214 L p .55581 .59698 L .294 .356 .757 r
F P
0 g
s
.55566 .5964 m .55733 .5993 L .55581 .59698 L .294 .356 .757 r
F
.55159 .63197 m .54401 .58653 L .55315 .59205 L p F P
0 g
s
.55315 .59205 m .55315 .59205 L p .55566 .5964 L .898 .565 .408 r
F P
0 g
s
.55315 .59205 m .55312 .59096 L p .55498 .59464 L .898 .565 .408 r
F P
0 g
s
.55312 .59096 m .55293 .58138 L p .55733 .5993 L .898 .565 .408 r
F P
0 g
s
.55293 .58138 m .53532 .55884 L .5352 .54639 L p .948 .664 .467 r
F P
0 g
s
.55315 .59205 m .54401 .58653 L p .54316 .57795 L .189 .36 .804 r
F P
0 g
s
.54401 .58653 m .53329 .56 L .53535 .56123 L p .189 .36 .804 r
F P
0 g
s
.54401 .58653 m .53535 .56123 L .54277 .57408 L .189 .36 .804 r
F
.54316 .57795 m .54277 .57408 L .55315 .59205 L F
.55159 .63197 m .55315 .59205 L .55566 .5964 L .294 .356 .757 r
F
.55321 .59534 m .53535 .56123 L .54277 .57408 L .952 .624 .364 r
F
.53329 .56 m .54401 .58653 L .52915 .57768 L p .312 .445 .834 r
F P
0 g
s
.55321 .59534 m .53546 .56883 L .53535 .56123 L p .952 .624 .364 r
F P
0 g
s
.54291 .57432 m .54277 .57408 L .5394 .56718 L .952 .624 .364 r
F
.53944 .56724 m .5394 .56718 L .53532 .55884 L F
.54291 .57432 m .5394 .56718 L .53944 .56724 L F
.53535 .56123 m .53532 .55884 L p .54277 .57408 L F P
0 g
s
.53532 .55884 m .55293 .58138 L .55315 .59205 L p .952 .624 .364 r
F P
0 g
s
.54291 .57432 m .53532 .55884 L .55315 .59205 L .952 .624 .364 r
F
.52618 .53384 m .5352 .54639 L .53532 .55884 L p .978 .698 .423 r
F P
0 g
s
.53532 .55884 m .52624 .54288 L .52618 .53384 L p .978 .698 .423 r
F P
0 g
s
.53535 .56123 m .53329 .56 L p .53258 .55715 L .097 .355 .823 r
F P
0 g
s
.53329 .56 m .52402 .54417 L .52627 .5455 L p .097 .355 .823 r
F P
0 g
s
.52915 .57768 m .52257 .55368 L .53329 .56 L p .312 .445 .834 r
F P
0 g
s
.52402 .54417 m .53329 .56 L .52257 .55368 L p .223 .438 .859 r
F P
0 g
s
.53546 .56883 m .52632 .55011 L .52627 .5455 L p .972 .657 .318 r
F P
0 g
s
.52627 .5455 m .52624 .54288 L p .52826 .54857 L .972 .657 .318 r
F P
0 g
s
.52624 .54288 m .53532 .55884 L .53535 .56123 L p .972 .657 .318 r
F P
0 g
s
.52862 .54956 m .52624 .54288 L .53535 .56123 L .972 .657 .318 r
F
.52111 .52509 m .52618 .53384 L .52624 .54288 L p .987 .714 .384 r
F P
0 g
s
.52624 .54288 m .52115 .53178 L .52111 .52509 L p .987 .714 .384 r
F P
0 g
s
.52627 .5455 m .52402 .54417 L p .52248 .53967 L .032 .346 .824 r
F P
0 g
s
.52115 .53178 m .52624 .54288 L .52627 .5455 L p .971 .67 .282 r
F P
0 g
s
.52248 .53967 m .52188 .53789 L .52627 .5455 L .032 .346 .824 r
F
.51526 .52959 m .52074 .53598 L p .51695 .5342 L 0 .34 .821 r
F P
0 g
s
.51796 .524 m .52115 .53178 L .52119 .5367 L p .967 .675 .262 r
F P
0 g
s
.52402 .54417 m .51695 .5342 L .52119 .5367 L p .032 .346 .824 r
F P
0 g
s
.52119 .5367 m .52119 .53711 L p .52102 .53641 L .967 .675 .262 r
F P
0 g
s
.52102 .53641 m .51796 .524 L .52119 .5367 L .967 .675 .262 r
F
.518 .52801 m .51796 .524 L p .52101 .53637 L F P
0 g
s
.521 .53635 m .518 .52801 L .52101 .53637 L .967 .675 .262 r
F
.52083 .53608 m .518 .52801 L p .52102 .53641 L F P
0 g
s
.52119 .5367 m .52115 .53178 L p .52367 .54072 L .971 .67 .282 r
F P
0 g
s
.51964 .53401 m .52083 .53608 L .51904 .53321 L 0 .238 .748 r
F
.51581 .5237 m .51803 .53082 L .51804 .53115 L p .82 .511 0 r
F P
0 g
s
.52083 .53608 m .51526 .52959 L .51766 .53102 L p 0 .238 .748 r
F P
0 g
s
.51766 .53102 m .51767 .53103 L p .51904 .53321 L 0 .238 .748 r
F P
0 g
s
.52083 .53608 m .51906 .53325 L .51904 .53321 L 0 .238 .748 r
F
.51906 .53325 m .51766 .53102 L .51904 .53321 L F
.51879 .53272 m .51896 .53309 L .51767 .53103 L F
.52119 .5367 m .51695 .5342 L p .52074 .53598 L 0 .34 .821 r
F P
0 g
s
.52257 .55368 m .51622 .53959 L .52402 .54417 L p .223 .438 .859 r
F P
0 g
s
.51695 .5342 m .52402 .54417 L .51622 .53959 L p .154 .427 .865 r
F P
0 g
s
.52119 .53711 m .52125 .54085 L p .51942 .53364 L .917 .608 .129 r
F P
0 g
s
.518 .52801 m .52083 .53608 L p .51942 .53364 L .917 .608 .129 r
F P
0 g
s
.52382 .54126 m .52115 .53178 L .52627 .5455 L .971 .67 .282 r
F
.52475 .53882 m .52154 .53691 L p .51964 .53401 L 0 .238 .748 r
F P
0 g
s
.51803 .53082 m .518 .52801 L p .51931 .53319 L .917 .608 .129 r
F P
0 g
s
.51891 .53261 m .51803 .53082 L .51931 .53319 L .917 .608 .129 r
F
.51833 .53175 m .51833 .53173 L p .51942 .53364 L F P
0 g
s
.51833 .53173 m .51803 .53082 L p .51888 .53254 L .917 .608 .129 r
F P
0 g
s
.51833 .53173 m .51888 .53254 L .51942 .53364 L .917 .608 .129 r
F
.51358 .52612 m .51684 .52958 L p .51767 .53103 L 0 .111 .634 r
F P
0 g
s
.51804 .53115 m .51803 .53082 L p .51823 .53154 L .821 .509 0 r
F P
0 g
s
.51804 .53115 m .51804 .53125 L p .51743 .52987 L .82 .511 0 r
F P
0 g
s
.51804 .53125 m .51796 .5312 L p .51745 .53023 L 0 .111 .634 r
F P
0 g
s
.51745 .53023 m .51745 .53023 L .51759 .53046 L 0 .111 .634 r
F
.51745 .53023 m .51759 .53046 L .51804 .53125 L F
.51759 .53046 m .51754 .53032 L .51755 .53033 L .82 .511 0 r
F
.51759 .53046 m .51743 .52987 L .51804 .53125 L F
.51743 .52987 m .51581 .5237 L .51804 .53115 L F
.51745 .53023 m .51893 .53179 L .51804 .53125 L p 0 .111 .634 r
F P
0 g
s
.51796 .5312 m .51767 .53103 L p .51684 .52958 L 0 .111 .634 r
F P
0 g
s
.51807 .53229 m .51745 .53023 L p .51759 .53046 L .82 .511 0 r
F P
0 g
s
.51807 .53229 m .5181 .53235 L p .51747 .53027 L 0 0 .21 r
F P
0 g
s
.51745 .53023 m .51583 .52482 L p .51754 .53032 L .82 .511 0 r
F P
0 g
s
.51745 .53023 m .51754 .53032 L .51759 .53046 L .82 .511 0 r
F
.51358 .52612 m .5136 .52616 L p .51731 .53009 L .521 .029 0 r
F P
0 g
s
.51585 .52486 m .51583 .52482 L p .51747 .53027 L 0 0 .21 r
F P
0 g
s
.5181 .53235 m .51748 .53028 L p .51747 .53027 L 0 0 .21 r
F P
0 g
s
.51748 .53028 m .51585 .52486 L p .51747 .53027 L 0 0 .21 r
F P
0 g
s
.51684 .52958 m .51745 .53023 L p .51796 .5312 L 0 .111 .634 r
F P
0 g
s
.51746 .53024 m .51745 .53023 L .51731 .53009 L .521 .029 0 r
F
.51893 .53179 m .51745 .53023 L p .51746 .53024 L F P
0 g
s
.51745 .53023 m .51358 .52612 L p .51731 .53009 L .521 .029 0 r
F P
0 g
s
.51583 .52482 m .51745 .53023 L p .51747 .53027 L 0 0 .21 r
F P
0 g
s
.51745 .53023 m .51807 .53229 L p .51747 .53027 L 0 0 .21 r
F P
0 g
s
.51896 .53185 m .51893 .53179 L p .51746 .53024 L .521 .029 0 r
F P
0 g
s
.51746 .53024 m .51731 .53009 L .51746 .53024 L .521 .029 0 r
F
.51746 .53024 m .51746 .53024 L .51896 .53185 L F
.5136 .52616 m .51692 .52968 L p .51731 .53009 L F P
0 g
s
.51692 .52968 m .51896 .53185 L p .51731 .53009 L .521 .029 0 r
F P
0 g
s
.51583 .52482 m .51581 .5237 L p .51755 .53033 L .82 .511 0 r
F P
0 g
s
.51754 .53032 m .51583 .52482 L .51755 .53033 L .82 .511 0 r
F
.51833 .53175 m .51767 .53103 L .51796 .5312 L p 0 .108 .634 r
F P
0 g
s
.51767 .53103 m .51833 .53175 L p .51884 .5328 L 0 .238 .748 r
F P
0 g
s
.51804 .53125 m .51807 .53229 L p .51759 .53046 L .82 .511 0 r
F P
0 g
s
.52475 .53882 m .51833 .53175 L p .51893 .53179 L 0 .108 .634 r
F P
0 g
s
.51803 .53082 m .51833 .53175 L p .51823 .53154 L .821 .509 0 r
F P
0 g
s
.51796 .5312 m .51893 .53179 L p .51833 .53175 L 0 .108 .634 r
F P
0 g
s
.51942 .53364 m .51891 .53261 L .51931 .53319 L .917 .608 .129 r
F
.51964 .53401 m .51884 .5328 L .51907 .53304 L 0 .238 .748 r
F
.51964 .53401 m .51907 .53304 L .51942 .53364 L F
.51884 .5328 m .51904 .53321 L .51896 .53309 L F
.51884 .5328 m .51896 .53309 L .51879 .53272 L F
.51964 .53401 m .51904 .53321 L .51884 .5328 L F
.52125 .54085 m .51833 .53175 L p .51942 .53364 L .917 .608 .129 r
F P
0 g
s
.51942 .53364 m .51907 .53304 L .51907 .53304 L 0 .238 .748 r
F
.51964 .53401 m .51907 .53304 L .52475 .53882 L F
.51833 .53175 m .52475 .53882 L p .51884 .5328 L F P
0 g
s
.52125 .54085 m .5213 .54282 L p .51823 .53154 L .821 .509 0 r
F P
0 g
s
.5213 .54282 m .51807 .53229 L .51804 .53115 L p .821 .509 0 r
F P
0 g
s
.5213 .54282 m .51804 .53115 L .51823 .53154 L .821 .509 0 r
F
.51833 .53175 m .52125 .54085 L p .51823 .53154 L F P
0 g
s
.52083 .53608 m .52119 .53711 L p .51942 .53364 L .917 .608 .129 r
F P
0 g
s
.52154 .53691 m .52083 .53608 L p .51964 .53401 L 0 .238 .748 r
F P
0 g
s
.52102 .53641 m .521 .53635 L .52101 .53637 L .967 .675 .262 r
F
.52074 .53598 m .52083 .53608 L p .52119 .5367 L 0 .34 .821 r
F P
0 g
s
.52119 .53711 m .52083 .53608 L p .52102 .53641 L .967 .675 .262 r
F P
0 g
s
.52083 .53608 m .52154 .53691 L .52119 .5367 L p 0 .34 .821 r
F P
0 g
s
.52382 .54126 m .52119 .5367 L .52367 .54072 L .971 .67 .282 r
F
.52119 .5367 m .52119 .5367 L .52367 .54072 L F
.52382 .54126 m .52188 .53789 L .52382 .54126 L F
.52188 .53789 m .52119 .5367 L .52382 .54126 L F
.52119 .5367 m .52154 .53691 L p .52188 .53789 L .032 .346 .824 r
F P
0 g
s
.52402 .54417 m .52119 .5367 L .52188 .53789 L .032 .346 .824 r
F
.52188 .53789 m .52188 .53789 L .52382 .54126 L F
.52188 .53789 m .52382 .54126 L .52627 .5455 L F
.52632 .55011 m .52119 .53711 L .52119 .5367 L p .971 .67 .282 r
F P
0 g
s
.52632 .55011 m .52119 .5367 L .52382 .54126 L .971 .67 .282 r
F
.52627 .5455 m .52632 .55011 L p .52382 .54126 L F P
0 g
s
.52188 .53789 m .52154 .53691 L .52627 .5455 L .032 .346 .824 r
F
.52154 .53691 m .53024 .54785 L .52627 .5455 L p F P
0 g
s
.52862 .54956 m .52627 .5455 L .52826 .54857 L .972 .657 .318 r
F
.53329 .56 m .52627 .5455 L .53225 .55587 L .097 .355 .823 r
F
.53546 .56883 m .52627 .5455 L .52862 .54956 L .972 .657 .318 r
F
.52627 .5455 m .53024 .54785 L p .53225 .55587 L .097 .355 .823 r
F P
0 g
s
.53258 .55715 m .53225 .55587 L .53535 .56123 L .097 .355 .823 r
F
.53535 .56123 m .53546 .56883 L p .52862 .54956 L .972 .657 .318 r
F P
0 g
s
.53225 .55587 m .53024 .54785 L .53535 .56123 L .097 .355 .823 r
F
.53024 .54785 m .54188 .56512 L .53535 .56123 L p F P
0 g
s
.54277 .57408 m .54188 .56512 L .55315 .59205 L .189 .36 .804 r
F
.54291 .57432 m .55315 .59205 L .55315 .59205 L F
.54277 .57408 m .55315 .59205 L .54291 .57432 L F
.53535 .56123 m .53535 .56123 L p .54277 .57408 L .952 .624 .364 r
F P
0 g
s
.53535 .56123 m .54188 .56512 L p .54277 .57408 L .189 .36 .804 r
F P
0 g
s
.55315 .59205 m .55321 .59534 L p .54291 .57432 L .952 .624 .364 r
F P
0 g
s
.54188 .56512 m .55596 .59375 L .55315 .59205 L p .189 .36 .804 r
F P
0 g
s
.55733 .5993 m .55315 .59205 L .55498 .59464 L .898 .565 .408 r
F
.55315 .59205 m .55315 .59205 L .55498 .59464 L F
.58988 .64382 m .57227 .62517 L p .57227 .62517 L .893 .491 .246 r
F P
0 g
s
.58988 .64382 m .57227 .62517 L .56615 .61245 L .893 .491 .246 r
F
.58686 .65581 m .58607 .6544 L p .58272 .64396 L 0 0 .247 r
F P
0 g
s
.58988 .64382 m .59068 .65173 L p .58136 .64009 L .819 .342 0 r
F P
0 g
s
.58136 .64009 m .58084 .63864 L .58988 .64382 L .819 .342 0 r
F
.5758 .63253 m .57536 .63053 L .58555 .6528 L 0 0 .558 r
F
.57965 .63795 m .57536 .63053 L .58988 .64382 L .819 .342 0 r
F
.57227 .62517 m .58988 .64382 L p .57536 .63053 L F P
0 g
s
.58136 .64009 m .57965 .63795 L .58084 .63864 L .819 .342 0 r
F
.5821 .64221 m .58555 .6528 L p .57536 .63053 L 0 0 .558 r
F P
0 g
s
.57961 .64974 m .57227 .62517 L p .5758 .63253 L 0 0 .558 r
F P
0 g
s
.56792 .64214 m .55733 .5993 L p .56583 .61614 L .108 .22 .699 r
F P
0 g
s
.56583 .61614 m .56563 .61367 L .575 .63432 L .108 .22 .699 r
F
.57649 .63566 m .5758 .63253 L .57821 .63766 L 0 0 .558 r
F
.58555 .6528 m .58607 .6544 L p .5758 .63253 L F P
0 g
s
.57227 .62517 m .57227 .62517 L p .56563 .61367 L .893 .491 .246 r
F P
0 g
s
.57227 .62517 m .575 .63432 L p .56563 .61367 L .108 .22 .699 r
F P
0 g
s
.575 .63432 m .57961 .64974 L p .56583 .61614 L .108 .22 .699 r
F P
0 g
s
.55389 .61086 m .55354 .60533 L p .57965 .63795 L .819 .342 0 r
F P
0 g
s
.59068 .65173 m .5821 .64221 L p .58136 .64009 L .819 .342 0 r
F P
0 g
s
.58993 .65135 m .58268 .64321 L .5821 .64221 L .553 .066 0 r
F
.58272 .64396 m .58221 .64239 L .58223 .64243 L 0 0 .247 r
F
.58607 .6544 m .5821 .64221 L p .58272 .64396 L F P
0 g
s
.5821 .64221 m .59068 .65173 L p .58993 .65135 L .553 .066 0 r
F P
0 g
s
.5821 .64221 m .56907 .6021 L p .58221 .64239 L 0 0 .247 r
F P
0 g
s
.5821 .64221 m .58221 .64239 L .58272 .64396 L 0 0 .247 r
F
.59151 .65313 m .58281 .64343 L p .58268 .64321 L .553 .066 0 r
F P
0 g
s
.56953 .60278 m .58625 .65394 L p .58272 .64396 L 0 0 .247 r
F P
0 g
s
.55425 .6116 m .55389 .61086 L p .58268 .64321 L .553 .066 0 r
F P
0 g
s
.58281 .64343 m .55425 .6116 L p .58268 .64321 L .553 .066 0 r
F P
0 g
s
.55389 .61086 m .5821 .64221 L p .58268 .64321 L .553 .066 0 r
F P
0 g
s
.56907 .6021 m .56953 .60278 L p .58223 .64243 L 0 0 .247 r
F P
0 g
s
.58221 .64239 m .56907 .6021 L .58223 .64243 L 0 0 .247 r
F
.58136 .64009 m .5821 .64221 L .57965 .63795 L .819 .342 0 r
F
.5821 .64221 m .55389 .61086 L p .57965 .63795 L F P
0 g
s
.56907 .6021 m .5821 .64221 L p .57965 .63795 L 0 0 .558 r
F P
0 g
s
.5758 .63253 m .57479 .62954 L .57536 .63053 L 0 0 .558 r
F
.57227 .62517 m .57227 .62517 L p .57536 .63053 L .819 .342 0 r
F P
0 g
s
.57227 .62517 m .56445 .59903 L p .5758 .63253 L 0 0 .558 r
F P
0 g
s
.55354 .60533 m .57227 .62517 L p .57965 .63795 L .819 .342 0 r
F P
0 g
s
.57536 .63053 m .57536 .63053 L .57965 .63795 L 0 0 .558 r
F
.57536 .63053 m .56907 .6021 L .57965 .63795 L F
.58625 .65394 m .58686 .65581 L p .58272 .64396 L 0 0 .247 r
F P
0 g
s
.56445 .59903 m .56907 .6021 L p .57536 .63053 L 0 0 .558 r
F P
0 g
s
.57479 .62954 m .56445 .59903 L .57536 .63053 L 0 0 .558 r
F
.56615 .61245 m .57227 .62517 L .56095 .60557 L .893 .491 .246 r
F
.57227 .62517 m .56563 .61367 L .56095 .60557 L F
.56615 .61245 m .56095 .60557 L .56419 .60837 L F
.55596 .59375 m .56445 .59903 L p .56563 .61367 L .108 .22 .699 r
F P
0 g
s
.56583 .61614 m .56187 .60716 L .56563 .61367 L .108 .22 .699 r
F
.56187 .60716 m .55596 .59375 L .56563 .61367 L F
.56095 .60557 m .56095 .60557 L .55733 .5993 L .893 .491 .246 r
F
.55733 .5993 m .56095 .60557 L .56583 .61614 L .108 .22 .699 r
F
.56095 .60557 m .56187 .60716 L .56583 .61614 L F
.57227 .62517 m .55354 .60533 L p .56095 .60557 L .893 .491 .246 r
F P
0 g
s
.56095 .60557 m .56187 .60716 L .56187 .60716 L .108 .22 .699 r
F
.55354 .60533 m .55321 .59534 L p .56095 .60557 L .893 .491 .246 r
F P
0 g
s
.55321 .59534 m .55733 .5993 L p .56095 .60557 L .893 .491 .246 r
F P
0 g
s
.55733 .5993 m .55596 .59375 L p .56187 .60716 L .108 .22 .699 r
F P
0 g
s
.55315 .59205 m .55596 .59375 L p .55566 .5964 L .294 .356 .757 r
F P
0 g
s
.55733 .5993 m .55321 .59534 L .55315 .59205 L p .898 .565 .408 r
F P
0 g
s
.55733 .5993 m .55315 .59205 L .55566 .5964 L .898 .565 .408 r
F
.56445 .59903 m .57227 .62517 L p .56563 .61367 L .108 .22 .699 r
F P
0 g
s
.55596 .59375 m .55733 .5993 L p .55566 .5964 L .294 .356 .757 r
F P
0 g
s
.51202 .43241 m .51018 .45357 L .49662 .46146 L p .454 .187 .419 r
F P
0 g
s
.51018 .45357 m .51202 .43241 L .52915 .42232 L p .396 .14 .405 r
F P
0 g
s
.44222 .49271 m .41815 .48641 L .43546 .47662 L p .552 .194 .315 r
F P
0 g
s
.43546 .47662 m .45471 .4856 L .44222 .49271 L p .552 .194 .315 r
F P
0 g
s
.5352 .45361 m .55269 .43591 L .55252 .4558 L p .939 .841 .719 r
F P
0 g
s
.55252 .4558 m .53512 .46797 L .5352 .45361 L p .939 .841 .719 r
F P
0 g
s
.43546 .52338 m .45471 .5144 L .46831 .52219 L p .544 .67 .92 r
F P
0 g
s
.45471 .5144 m .43546 .52338 L .41815 .51359 L p .552 .707 .943 r
F P
0 g
s
.55252 .5442 m .53512 .53203 L .53506 .51635 L p .932 .719 .591 r
F P
0 g
s
.53512 .53203 m .55252 .5442 L .55269 .56409 L p .939 .693 .539 r
F P
0 g
s
.52257 .55368 m .52915 .57768 L .51202 .56759 L p .396 .506 .853 r
F P
0 g
s
.51202 .56759 m .51018 .54643 L .52257 .55368 L p .396 .506 .853 r
F P
0 g
s
.65944 .31851 m .7641 .31153 L .76127 .33022 L p .657 .794 .948 r
F P
0 g
s
.76127 .33022 m .6578 .33644 L .65944 .31851 L p .657 .794 .948 r
F P
0 g
s
.85989 .37001 m .76127 .33022 L .7641 .31153 L p .476 .623 .915 r
F P
0 g
s
.27945 .55488 m .22233 .64138 L .20473 .63448 L p .893 .875 .811 r
F P
0 g
s
.22233 .64138 m .20748 .74667 L .19392 .74228 L p .952 .787 .64 r
F P
0 g
s
.19392 .74228 m .20473 .63448 L .22233 .64138 L p .952 .787 .64 r
F P
0 g
s
.2631 .45266 m .20473 .36552 L .22233 .35862 L p .893 .583 .454 r
F P
0 g
s
.22233 .35862 m .27945 .44512 L .2631 .45266 L p .893 .583 .454 r
F P
0 g
s
.20748 .25333 m .22233 .35862 L .20473 .36552 L p .952 .768 .617 r
F P
0 g
s
.56275 .28156 m .5164 .18884 L .53117 .17705 L p .348 .395 .769 r
F P
0 g
s
.5164 .18884 m .43263 .12334 L .44322 .11379 L p .457 .597 .903 r
F P
0 g
s
.44322 .11379 m .53117 .17705 L .5164 .18884 L p .457 .597 .903 r
F P
0 g
s
.57746 .72883 m .53117 .82295 L .5164 .81116 L p .348 .172 .496 r
F P
0 g
s
.5164 .81116 m .56275 .71844 L .57746 .72883 L p .348 .172 .496 r
F P
0 g
s
.43263 .87666 m .5164 .81116 L .53117 .82295 L p .457 .148 .354 r
F P
0 g
s
.6578 .66356 m .76127 .66978 L .7641 .68847 L p .657 .279 .318 r
F P
0 g
s
.76127 .66978 m .85989 .62999 L .86286 .64393 L p .476 .155 .342 r
F P
0 g
s
.86286 .64393 m .7641 .68847 L .76127 .66978 L p .476 .155 .342 r
F P
0 g
s
.33051 .49408 m .2631 .45266 L .27945 .44512 L p .776 .365 .273 r
F P
0 g
s
.27945 .44512 m .34294 .48775 L .33051 .49408 L p .776 .365 .273 r
F P
0 g
s
.56792 .35786 m .56275 .28156 L .57746 .27117 L p .23 .177 .588 r
F P
0 g
s
.53117 .17705 m .57746 .27117 L .56275 .28156 L p .348 .395 .769 r
F P
0 g
s
.58988 .35618 m .65944 .31851 L .6578 .33644 L p .799 .91 .917 r
F P
0 g
s
.6578 .33644 m .58914 .37011 L .58988 .35618 L p .799 .91 .917 r
F P
0 g
s
.34294 .51225 m .27945 .55488 L .2631 .54734 L p .776 .902 .93 r
F P
0 g
s
.20473 .63448 m .2631 .54734 L .27945 .55488 L p .893 .875 .811 r
F P
0 g
s
.58914 .62989 m .6578 .66356 L .65944 .68149 L p .799 .395 .286 r
F P
0 g
s
.7641 .68847 m .65944 .68149 L .6578 .66356 L p .657 .279 .318 r
F P
0 g
s
.57961 .64974 m .57746 .72883 L .56275 .71844 L p .23 .198 .614 r
F P
0 g
s
.56275 .71844 m .56792 .64214 L .57961 .64974 L p .23 .198 .614 r
F P
0 g
s
.52915 .42232 m .52257 .44632 L .51018 .45357 L p .396 .14 .405 r
F P
0 g
s
.52257 .44632 m .52915 .42232 L .54401 .41347 L p .312 .066 .37 r
F P
0 g
s
.41815 .51359 m .44222 .50729 L .45471 .5144 L p .552 .707 .943 r
F P
0 g
s
.44222 .50729 m .41815 .51359 L .40306 .50515 L p .546 .745 .969 r
F P
0 g
s
.55269 .56409 m .5352 .54639 L .53512 .53203 L p .939 .693 .539 r
F P
0 g
s
.5352 .54639 m .55269 .56409 L .55293 .58138 L p .948 .664 .467 r
F P
0 g
s
.28514 .87215 m .29563 .85398 L .3105 .86281 L p .78 .387 .31 r
F P
0 g
s
.29563 .85398 m .28514 .87215 L .27862 .8685 L p .8 .413 .322 r
F P
0 g
s
.27862 .8685 m .28055 .84552 L .29563 .85398 L p .8 .413 .322 r
F P
0 g
s
.92972 .5 m .90874 .5 L .90895 .48271 L p .27 .23 .628 r
F P
0 g
s
.90874 .5 m .92972 .5 L .92982 .50747 L p .27 .211 .605 r
F P
0 g
s
.92982 .50747 m .90895 .51729 L .90874 .5 L p .27 .211 .605 r
F P
0 g
s
.28514 .12785 m .29563 .14602 L .28055 .15448 L p .8 .893 .911 r
F P
0 g
s
.29563 .14602 m .28514 .12785 L .29156 .12403 L p .78 .886 .922 r
F P
0 g
s
.29156 .12403 m .3105 .13719 L .29563 .14602 L p .78 .886 .922 r
F P
0 g
s
.28055 .84552 m .27862 .8685 L .27228 .86517 L p .818 .432 .321 r
F P
0 g
s
.27228 .86517 m .26587 .83777 L .28055 .84552 L p .818 .432 .321 r
F P
0 g
s
.29156 .87597 m .3105 .86281 L .32455 .87164 L p .758 .354 .286 r
F P
0 g
s
.3105 .86281 m .29156 .87597 L .28514 .87215 L p .78 .387 .31 r
F P
0 g
s
.92982 .49253 m .90895 .48271 L .90958 .46612 L p .256 .238 .646 r
F P
0 g
s
.90895 .48271 m .92982 .49253 L .92972 .5 L p .27 .23 .628 r
F P
0 g
s
.90895 .51729 m .92982 .50747 L .93011 .51462 L p .256 .181 .576 r
F P
0 g
s
.93011 .51462 m .90958 .53388 L .90895 .51729 L p .256 .181 .576 r
F P
0 g
s
.3105 .13719 m .29156 .12403 L .29761 .12021 L p .758 .884 .935 r
F P
0 g
s
.29761 .12021 m .32455 .12836 L .3105 .13719 L p .758 .884 .935 r
F P
0 g
s
.27862 .1315 m .28055 .15448 L .26587 .16223 L p .818 .905 .9 r
F P
0 g
s
.28055 .15448 m .27862 .1315 L .28514 .12785 L p .8 .893 .911 r
F P
0 g
s
.47661 .48336 m .46831 .47781 L .48248 .46965 L p .442 .1 .288 r
F P
0 g
s
.48248 .46965 m .48695 .4774 L .47661 .48336 L p .442 .1 .288 r
F P
0 g
s
.48695 .4774 m .48248 .46965 L .49662 .46146 L p .414 .09 .304 r
F P
0 g
s
.5261 .48806 m .53506 .48365 L .53505 .5 L p .968 .804 .624 r
F P
0 g
s
.53505 .5 m .52609 .5 L .5261 .48806 L p .968 .804 .624 r
F P
0 g
s
.52609 .5 m .53505 .5 L .53506 .51635 L p .968 .778 .592 r
F P
0 g
s
.49729 .52857 m .49662 .53854 L .48248 .53035 L p .414 .586 .912 r
F P
0 g
s
.48248 .53035 m .48695 .5226 L .49729 .52857 L p .414 .586 .912 r
F P
0 g
s
.48695 .5226 m .48248 .53035 L .46831 .52219 L p .442 .622 .928 r
F P
0 g
s
.46669 .48906 m .45471 .4856 L .46831 .47781 L p .456 .09 .254 r
F P
0 g
s
.46831 .47781 m .47661 .48336 L .46669 .48906 L p .456 .09 .254 r
F P
0 g
s
.49662 .46146 m .49729 .47143 L .48695 .4774 L p .414 .09 .304 r
F P
0 g
s
.49729 .47143 m .49662 .46146 L .51018 .45357 L p .372 .061 .303 r
F P
0 g
s
.52613 .47662 m .53512 .46797 L .53506 .48365 L p .971 .833 .649 r
F P
0 g
s
.53506 .48365 m .5261 .48806 L .52613 .47662 L p .971 .833 .649 r
F P
0 g
s
.53506 .51635 m .5261 .51194 L .52609 .5 L p .968 .778 .592 r
F P
0 g
s
.5261 .51194 m .53506 .51635 L .53512 .53203 L p .971 .753 .551 r
F P
0 g
s
.46831 .52219 m .47661 .51664 L .48695 .5226 L p .442 .622 .928 r
F P
0 g
s
.47661 .51664 m .46831 .52219 L .45471 .5144 L p .456 .655 .946 r
F P
0 g
s
.50718 .53432 m .51018 .54643 L .49662 .53854 L p .372 .546 .897 r
F P
0 g
s
.49662 .53854 m .49729 .52857 L .50718 .53432 L p .372 .546 .897 r
F P
0 g
s
.26587 .83777 m .27228 .86517 L .26639 .86231 L p .836 .444 .307 r
F P
0 g
s
.26639 .86231 m .2522 .83105 L .26587 .83777 L p .836 .444 .307 r
F P
0 g
s
.93011 .48538 m .90958 .46612 L .9106 .45092 L p .228 .235 .658 r
F P
0 g
s
.90958 .46612 m .93011 .48538 L .92982 .49253 L p .256 .238 .646 r
F P
0 g
s
.29761 .87979 m .32455 .87164 L .3372 .88013 L p .733 .312 .248 r
F P
0 g
s
.32455 .87164 m .29761 .87979 L .29156 .87597 L p .758 .354 .286 r
F P
0 g
s
.90958 .53388 m .93011 .51462 L .93057 .52116 L p .228 .138 .54 r
F P
0 g
s
.93057 .52116 m .9106 .54908 L .90958 .53388 L p .228 .138 .54 r
F P
0 g
s
.27228 .13483 m .26587 .16223 L .2522 .16895 L p .836 .921 .891 r
F P
0 g
s
.26587 .16223 m .27228 .13483 L .27862 .1315 L p .818 .905 .9 r
F P
0 g
s
.32455 .12836 m .29761 .12021 L .30304 .11654 L p .733 .885 .95 r
F P
0 g
s
.30304 .11654 m .3372 .11987 L .32455 .12836 L p .733 .885 .95 r
F P
0 g
s
.20748 .74667 m .23009 .82181 L .22262 .8197 L p .944 .63 .411 r
F P
0 g
s
.22262 .8197 m .19392 .74228 L .20748 .74667 L p .944 .63 .411 r
F P
0 g
s
.7641 .31153 m .86286 .35607 L .85989 .37001 L p .476 .623 .915 r
F P
0 g
s
.91365 .42716 m .85989 .37001 L .86286 .35607 L p .254 .392 .809 r
F P
0 g
s
.85989 .37001 m .91365 .42716 L .91198 .43775 L p .358 .428 .797 r
F P
0 g
s
.53117 .82295 m .44322 .88621 L .43263 .87666 L p .457 .148 .354 r
F P
0 g
s
.35626 .89465 m .43263 .87666 L .44322 .88621 L p .553 .126 .185 r
F P
0 g
s
.43263 .87666 m .35626 .89465 L .34793 .88791 L p .624 .249 .312 r
F P
0 g
s
.85989 .62999 m .91365 .57284 L .91556 .58036 L p .254 .023 .358 r
F P
0 g
s
.91556 .58036 m .86286 .64393 L .85989 .62999 L p .254 .023 .358 r
F P
0 g
s
.20473 .36552 m .19392 .25772 L .20748 .25333 L p .952 .768 .617 r
F P
0 g
s
.23009 .17819 m .20748 .25333 L .19392 .25772 L p .944 .911 .756 r
F P
0 g
s
.20748 .25333 m .23009 .17819 L .2401 .17435 L p .911 .869 .785 r
F P
0 g
s
.43263 .12334 m .35626 .10535 L .36182 .09993 L p .553 .776 .982 r
F P
0 g
s
.36182 .09993 m .44322 .11379 L .43263 .12334 L p .553 .776 .982 r
F P
0 g
s
.57746 .27117 m .57961 .35026 L .56792 .35786 L p .23 .177 .588 r
F P
0 g
s
.2631 .54734 m .33051 .50592 L .34294 .51225 L p .776 .902 .93 r
F P
0 g
s
.65944 .68149 m .58988 .64382 L .58914 .62989 L p .799 .395 .286 r
F P
0 g
s
.51018 .45357 m .50718 .46568 L .49729 .47143 L p .372 .061 .303 r
F P
0 g
s
.50718 .46568 m .51018 .45357 L .52257 .44632 L p .31 .009 .281 r
F P
0 g
s
.4576 .49425 m .44222 .49271 L .45471 .4856 L p .456 .059 .197 r
F P
0 g
s
.45471 .4856 m .46669 .48906 L .4576 .49425 L p .456 .059 .197 r
F P
0 g
s
.52618 .46616 m .5352 .45361 L .53512 .46797 L p .975 .865 .665 r
F P
0 g
s
.53512 .46797 m .52613 .47662 L .52618 .46616 L p .975 .865 .665 r
F P
0 g
s
.45471 .5144 m .46669 .51094 L .47661 .51664 L p .456 .655 .946 r
F P
0 g
s
.46669 .51094 m .45471 .5144 L .44222 .50729 L p .456 .686 .964 r
F P
0 g
s
.53512 .53203 m .52613 .52338 L .5261 .51194 L p .971 .753 .551 r
F P
0 g
s
.52613 .52338 m .53512 .53203 L .5352 .54639 L p .975 .728 .497 r
F P
0 g
s
.51622 .53959 m .52257 .55368 L .51018 .54643 L p .31 .498 .881 r
F P
0 g
s
.51018 .54643 m .50718 .53432 L .51622 .53959 L p .31 .498 .881 r
F P
0 g
s
.2522 .83105 m .26639 .86231 L .26121 .86003 L p .851 .449 .277 r
F P
0 g
s
.26121 .86003 m .2401 .82565 L .2522 .83105 L p .851 .449 .277 r
F P
0 g
s
.93057 .47884 m .9106 .45092 L .91198 .43775 L p .182 .218 .664 r
F P
0 g
s
.9106 .45092 m .93057 .47884 L .93011 .48538 L p .228 .235 .658 r
F P
0 g
s
.30304 .88346 m .3372 .88013 L .34793 .88791 L p .704 .259 .193 r
F P
0 g
s
.3372 .88013 m .30304 .88346 L .29761 .87979 L p .733 .312 .248 r
F P
0 g
s
.9106 .54908 m .93057 .52116 L .93119 .52679 L p .182 .079 .494 r
F P
0 g
s
.93119 .52679 m .91198 .56225 L .9106 .54908 L p .182 .079 .494 r
F P
0 g
s
.3372 .11987 m .30304 .11654 L .3076 .11319 L p .704 .89 .965 r
F P
0 g
s
.3076 .11319 m .34793 .11209 L .3372 .11987 L p .704 .89 .965 r
F P
0 g
s
.26639 .13769 m .2522 .16895 L .2401 .17435 L p .851 .941 .88 r
F P
0 g
s
.2522 .16895 m .26639 .13769 L .27228 .13483 L p .836 .921 .891 r
F P
0 g
s
.52257 .44632 m .51622 .46041 L .50718 .46568 L p .31 .009 .281 r
F P
0 g
s
.44222 .50729 m .4576 .50575 L .46669 .51094 L p .456 .686 .964 r
F P
0 g
s
.5352 .54639 m .52618 .53384 L .52613 .52338 L p .975 .728 .497 r
F P
0 g
s
.2631 .54734 m .20473 .63448 L .19373 .6317 L p .916 .97 .787 r
F P
0 g
s
.20473 .63448 m .19392 .74228 L .18544 .74112 L p .998 .839 .555 r
F P
0 g
s
.18544 .74112 m .19373 .6317 L .20473 .63448 L p .998 .839 .555 r
F P
0 g
s
.66124 .30807 m .76719 .30061 L .7641 .31153 L p .549 .844 .998 r
F P
0 g
s
.7641 .31153 m .65944 .31851 L .66124 .30807 L p .549 .844 .998 r
F P
0 g
s
.86286 .35607 m .7641 .31153 L .76719 .30061 L p .314 .603 .949 r
F P
0 g
s
.25317 .45632 m .19373 .3683 L .20473 .36552 L p .916 .525 .242 r
F P
0 g
s
.20473 .36552 m .2631 .45266 L .25317 .45632 L p .916 .525 .242 r
F P
0 g
s
.19392 .25772 m .20473 .36552 L .19373 .3683 L p .998 .79 .495 r
F P
0 g
s
.57746 .27117 m .53117 .17705 L .53908 .16891 L p .078 .236 .726 r
F P
0 g
s
.53117 .17705 m .44322 .11379 L .44846 .10703 L p .263 .537 .92 r
F P
0 g
s
.44846 .10703 m .53908 .16891 L .53117 .17705 L p .263 .537 .92 r
F P
0 g
s
.65944 .68149 m .7641 .68847 L .76719 .69939 L p .549 .053 .03 r
F P
0 g
s
.7641 .68847 m .86286 .64393 L .86609 .65185 L p .314 0 .101 r
F P
0 g
s
.86609 .65185 m .76719 .69939 L .7641 .68847 L p .314 0 .101 r
F P
0 g
s
.58559 .7356 m .53908 .83109 L .53117 .82295 L p .078 0 .303 r
F P
0 g
s
.53117 .82295 m .57746 .72883 L .58559 .7356 L p .078 0 .303 r
F P
0 g
s
.44322 .88621 m .53117 .82295 L .53908 .83109 L p .263 0 .13 r
F P
0 g
s
.32326 .49734 m .25317 .45632 L .2631 .45266 L p .722 .205 0 r
F P
0 g
s
.2631 .45266 m .33051 .49408 L .32326 .49734 L p .722 .205 0 r
F P
0 g
s
.57961 .35026 m .57746 .27117 L .58559 .2644 L p 0 0 .451 r
F P
0 g
s
.53908 .16891 m .58559 .2644 L .57746 .27117 L p .078 .236 .726 r
F P
0 g
s
.59068 .34827 m .66124 .30807 L .65944 .31851 L p .727 .976 .922 r
F P
0 g
s
.65944 .31851 m .58988 .35618 L .59068 .34827 L p .727 .976 .922 r
F P
0 g
s
.33051 .50592 m .2631 .54734 L .25317 .54368 L p .722 .975 .925 r
F P
0 g
s
.19373 .6317 m .25317 .54368 L .2631 .54734 L p .916 .97 .787 r
F P
0 g
s
.58988 .64382 m .65944 .68149 L .66124 .69193 L p .727 .211 0 r
F P
0 g
s
.76719 .69939 m .66124 .69193 L .65944 .68149 L p .549 .053 .03 r
F P
0 g
s
.58607 .6544 m .58559 .7356 L .57746 .72883 L p 0 0 .456 r
F P
0 g
s
.57746 .72883 m .57961 .64974 L .58607 .6544 L p 0 0 .456 r
F P
0 g
s
.4818 .48619 m .47661 .48336 L .48695 .4774 L p .373 .003 .199 r
F P
0 g
s
.48695 .4774 m .48947 .48177 L .4818 .48619 L p .373 .003 .199 r
F P
0 g
s
.48947 .48177 m .48695 .4774 L .49729 .47143 L p .347 0 .214 r
F P
0 g
s
.52106 .49114 m .5261 .48806 L .52609 .5 L p .988 .819 .585 r
F P
0 g
s
.52609 .5 m .52105 .5 L .52106 .49114 L p .988 .819 .585 r
F P
0 g
s
.52105 .5 m .52609 .5 L .5261 .51194 L p .988 .795 .555 r
F P
0 g
s
.49714 .52266 m .49729 .52857 L .48695 .5226 L p .347 .573 .925 r
F P
0 g
s
.48695 .5226 m .48947 .51823 L .49714 .52266 L p .347 .573 .925 r
F P
0 g
s
.48947 .51823 m .48695 .5226 L .47661 .51664 L p .373 .607 .94 r
F P
0 g
s
.49729 .47143 m .49714 .47734 L .48947 .48177 L p .347 0 .214 r
F P
0 g
s
.49714 .47734 m .49729 .47143 L .50718 .46568 L p .305 0 .21 r
F P
0 g
s
.47444 .49042 m .46669 .48906 L .47661 .48336 L p .384 0 .164 r
F P
0 g
s
.47661 .48336 m .4818 .48619 L .47444 .49042 L p .384 0 .164 r
F P
0 g
s
.52108 .48266 m .52613 .47662 L .5261 .48806 L p .989 .845 .605 r
F P
0 g
s
.5261 .48806 m .52106 .49114 L .52108 .48266 L p .989 .845 .605 r
F P
0 g
s
.5261 .51194 m .52106 .50886 L .52105 .5 L p .988 .795 .555 r
F P
0 g
s
.52106 .50886 m .5261 .51194 L .52613 .52338 L p .989 .771 .514 r
F P
0 g
s
.47661 .51664 m .4818 .51381 L .48947 .51823 L p .373 .607 .94 r
F P
0 g
s
.4818 .51381 m .47661 .51664 L .46669 .51094 L p .384 .636 .955 r
F P
0 g
s
.50448 .52692 m .50718 .53432 L .49729 .52857 L p .305 .534 .909 r
F P
0 g
s
.49729 .52857 m .49714 .52266 L .50448 .52692 L p .305 .534 .909 r
F P
0 g
s
.2401 .82565 m .26121 .86003 L .25695 .85844 L p .861 .442 .227 r
F P
0 g
s
.25695 .85844 m .23009 .82181 L .2401 .82565 L p .861 .442 .227 r
F P
0 g
s
.93119 .47321 m .91198 .43775 L .91365 .42716 L p .113 .183 .659 r
F P
0 g
s
.91198 .43775 m .93119 .47321 L .93057 .47884 L p .182 .218 .664 r
F P
0 g
s
.3076 .88681 m .34793 .88791 L .35626 .89465 L p .667 .192 .115 r
F P
0 g
s
.34793 .88791 m .3076 .88681 L .30304 .88346 L p .704 .259 .193 r
F P
0 g
s
.91198 .56225 m .93119 .52679 L .93194 .53127 L p .113 0 .435 r
F P
0 g
s
.93194 .53127 m .91365 .57284 L .91198 .56225 L p .113 0 .435 r
F P
0 g
s
.34793 .11209 m .3076 .11319 L .31111 .11029 L p .667 .897 .979 r
F P
0 g
s
.31111 .11029 m .35626 .10535 L .34793 .11209 L p .667 .897 .979 r
F P
0 g
s
.26121 .13997 m .2401 .17435 L .23009 .17819 L p .861 .964 .867 r
F P
0 g
s
.2401 .17435 m .26121 .13997 L .26639 .13769 L p .851 .941 .88 r
F P
0 g
s
.41645 .50711 m .38201 .5063 L .39083 .50159 L p .438 0 0 r
F P
0 g
s
.39083 .50159 m .42267 .50371 L .41645 .50711 L p .438 0 0 r
F P
0 g
s
.54188 .43488 m .55596 .40625 L .56445 .40097 L p 0 0 .171 r
F P
0 g
s
.53561 .42409 m .55354 .39467 L .55321 .40466 L p .933 .969 .71 r
F P
0 g
s
.55321 .40466 m .53546 .43117 L .53561 .42409 L p .933 .969 .71 r
F P
0 g
s
.42267 .49629 m .39083 .49841 L .38201 .4937 L p .438 .798 .996 r
F P
0 g
s
.53546 .56883 m .55321 .59534 L .55354 .60533 L p .933 .555 .203 r
F P
0 g
s
.54794 .5688 m .56445 .59903 L .55596 .59375 L p 0 .233 .743 r
F P
0 g
s
.55596 .59375 m .54188 .56512 L .54794 .5688 L p 0 .233 .743 r
F P
0 g
s
.46772 .49427 m .4576 .49425 L .46669 .48906 L p .378 0 .105 r
F P
0 g
s
.46669 .48906 m .47444 .49042 L .46772 .49427 L p .378 0 .105 r
F P
0 g
s
.50718 .46568 m .50448 .47308 L .49714 .47734 L p .305 0 .21 r
F P
0 g
s
.50448 .47308 m .50718 .46568 L .51622 .46041 L p .242 0 .183 r
F P
0 g
s
.52111 .47491 m .52618 .46616 L .52613 .47662 L p .99 .872 .615 r
F P
0 g
s
.52613 .47662 m .52108 .48266 L .52111 .47491 L p .99 .872 .615 r
F P
0 g
s
.52613 .52338 m .52108 .51734 L .52106 .50886 L p .989 .771 .514 r
F P
0 g
s
.52108 .51734 m .52613 .52338 L .52618 .53384 L p .99 .745 .459 r
F P
0 g
s
.46669 .51094 m .47444 .50958 L .4818 .51381 L p .384 .636 .955 r
F P
0 g
s
.47444 .50958 m .46669 .51094 L .4576 .50575 L p .378 .661 .969 r
F P
0 g
s
.51118 .53083 m .51622 .53959 L .50718 .53432 L p .242 .487 .891 r
F P
0 g
s
.50718 .53432 m .50448 .52692 L .51118 .53083 L p .242 .487 .891 r
F P
0 g
s
.19392 .74228 m .22262 .8197 L .21805 .81944 L p .956 .612 .28 r
F P
0 g
s
.21805 .81944 m .18544 .74112 L .19392 .74228 L p .956 .612 .28 r
F P
0 g
s
.76719 .30061 m .86609 .34815 L .86286 .35607 L p .314 .603 .949 r
F P
0 g
s
.91556 .41964 m .86286 .35607 L .86609 .34815 L p .072 .307 .79 r
F P
0 g
s
.86286 .35607 m .91556 .41964 L .91365 .42716 L p .254 .392 .809 r
F P
0 g
s
.53908 .83109 m .44846 .89297 L .44322 .88621 L p .263 0 .13 r
F P
0 g
s
.36182 .90007 m .44322 .88621 L .44846 .89297 L p .43 0 0 r
F P
0 g
s
.44322 .88621 m .36182 .90007 L .35626 .89465 L p .553 .126 .185 r
F P
0 g
s
.86286 .64393 m .91556 .58036 L .91762 .58445 L p .072 0 .183 r
F P
0 g
s
.91762 .58445 m .86609 .65185 L .86286 .64393 L p .072 0 .183 r
F P
0 g
s
.19373 .3683 m .18544 .25888 L .19392 .25772 L p .998 .79 .495 r
F P
0 g
s
.22262 .1803 m .19392 .25772 L .18544 .25888 L p .956 .949 .693 r
F P
0 g
s
.19392 .25772 m .22262 .1803 L .23009 .17819 L p .944 .911 .756 r
F P
0 g
s
.44322 .11379 m .36182 .09993 L .36433 .0961 L p .43 .768 .997 r
F P
0 g
s
.36433 .0961 m .44846 .10703 L .44322 .11379 L p .43 .768 .997 r
F P
0 g
s
.58559 .2644 m .58607 .3456 L .57961 .35026 L p 0 0 .451 r
F P
0 g
s
.25317 .54368 m .32326 .50266 L .33051 .50592 L p .722 .975 .925 r
F P
0 g
s
.66124 .69193 m .59068 .65173 L .58988 .64382 L p .727 .211 0 r
F P
0 g
s
.51622 .46041 m .51118 .46917 L .50448 .47308 L p .242 0 .183 r
F P
0 g
s
.4576 .49425 m .46772 .49427 L .4619 .49758 L p .35 0 .016 r
F P
0 g
s
.52618 .46616 m .52111 .47491 L .52115 .46822 L p .987 .898 .61 r
F P
0 g
s
.52618 .53384 m .52111 .52509 L .52108 .51734 L p .99 .745 .459 r
F P
0 g
s
.4576 .50575 m .46772 .50573 L .47444 .50958 L p .378 .661 .969 r
F P
0 g
s
.51622 .53959 m .51118 .53083 L .51695 .5342 L p .154 .427 .865 r
F P
0 g
s
.48525 .48784 m .4818 .48619 L .48947 .48177 L p .332 0 .148 r
F P
0 g
s
.48947 .48177 m .49105 .4845 L .48525 .48784 L p .332 0 .148 r
F P
0 g
s
.49105 .4845 m .48947 .48177 L .49714 .47734 L p .307 0 .162 r
F P
0 g
s
.5179 .4933 m .52106 .49114 L .52105 .5 L p .995 .824 .559 r
F P
0 g
s
.52105 .5 m .5179 .5 L .5179 .4933 L p .995 .824 .559 r
F P
0 g
s
.5179 .5 m .52105 .5 L .52106 .50886 L p .995 .801 .53 r
F P
0 g
s
.49685 .51885 m .49714 .52266 L .48947 .51823 L p .307 .563 .928 r
F P
0 g
s
.48947 .51823 m .49105 .5155 L .49685 .51885 L p .307 .563 .928 r
F P
0 g
s
.49105 .5155 m .48947 .51823 L .4818 .51381 L p .332 .596 .942 r
F P
0 g
s
.23009 .82181 m .25695 .85844 L .25381 .85761 L p .86 .418 .149 r
F P
0 g
s
.25381 .85761 m .22262 .8197 L .23009 .82181 L p .86 .418 .149 r
F P
0 g
s
.93194 .46873 m .91365 .42716 L .91556 .41964 L p .014 .126 .638 r
F P
0 g
s
.91365 .42716 m .93194 .46873 L .93119 .47321 L p .113 .183 .659 r
F P
0 g
s
.31111 .88971 m .35626 .89465 L .36182 .90007 L p .616 .104 .008 r
F P
0 g
s
.35626 .89465 m .31111 .88971 L .3076 .88681 L p .667 .192 .115 r
F P
0 g
s
.91365 .57284 m .93194 .53127 L .93279 .53441 L p .014 0 .356 r
F P
0 g
s
.93279 .53441 m .91556 .58036 L .91365 .57284 L p .014 0 .356 r
F P
0 g
s
.25695 .14156 m .23009 .17819 L .22262 .1803 L p .86 .987 .845 r
F P
0 g
s
.23009 .17819 m .25695 .14156 L .26121 .13997 L p .861 .964 .867 r
F P
0 g
s
.35626 .10535 m .31111 .11029 L .3134 .10799 L p .616 .902 .986 r
F P
0 g
s
.3134 .10799 m .36182 .09993 L .35626 .10535 L p .616 .902 .986 r
F P
0 g
s
.49714 .47734 m .49685 .48115 L .49105 .4845 L p .307 0 .162 r
F P
0 g
s
.49685 .48115 m .49714 .47734 L .50448 .47308 L p .265 0 .156 r
F P
0 g
s
.47969 .49104 m .47444 .49042 L .4818 .48619 L p .341 0 .112 r
F P
0 g
s
.4818 .48619 m .48525 .48784 L .47969 .49104 L p .341 0 .112 r
F P
0 g
s
.51792 .48689 m .52108 .48266 L .52106 .49114 L p .995 .849 .578 r
F P
0 g
s
.52106 .49114 m .5179 .4933 L .51792 .48689 L p .995 .849 .578 r
F P
0 g
s
.52106 .50886 m .5179 .5067 L .5179 .5 L p .995 .801 .53 r
F P
0 g
s
.5179 .5067 m .52106 .50886 L .52108 .51734 L p .995 .777 .49 r
F P
0 g
s
.4818 .51381 m .48525 .51216 L .49105 .5155 L p .332 .596 .942 r
F P
0 g
s
.48525 .51216 m .4818 .51381 L .47444 .50958 L p .341 .623 .956 r
F P
0 g
s
.50239 .52207 m .50448 .52692 L .49714 .52266 L p .265 .525 .912 r
F P
0 g
s
.49714 .52266 m .49685 .51885 L .50239 .52207 L p .265 .525 .912 r
F P
0 g
s
.53024 .45215 m .54188 .43488 L .54794 .4312 L p 0 0 .01 r
F P
0 g
s
.56445 .40097 m .54794 .4312 L .54188 .43488 L p 0 0 .171 r
F P
0 g
s
.43899 .50474 m .41645 .50711 L .42267 .50371 L p .292 0 0 r
F P
0 g
s
.42267 .50371 m .44344 .50226 L .43899 .50474 L p .292 0 0 r
F P
0 g
s
.52641 .44479 m .53561 .42409 L .53546 .43117 L p .937 .941 .598 r
F P
0 g
s
.53546 .43117 m .52632 .44989 L .52641 .44479 L p .937 .941 .598 r
F P
0 g
s
.44344 .49774 m .42267 .49629 L .41645 .49289 L p .292 .718 .97 r
F P
0 g
s
.38201 .4937 m .41645 .49289 L .42267 .49629 L p .438 .798 .996 r
F P
0 g
s
.52632 .55011 m .53546 .56883 L .53561 .57591 L p .937 .589 .167 r
F P
0 g
s
.55354 .60533 m .53561 .57591 L .53546 .56883 L p .933 .555 .203 r
F P
0 g
s
.53461 .55047 m .54794 .5688 L .54188 .56512 L p 0 .238 .755 r
F P
0 g
s
.54188 .56512 m .53024 .54785 L .53461 .55047 L p 0 .238 .755 r
F P
0 g
s
.47461 .49395 m .46772 .49427 L .47444 .49042 L p .332 0 .053 r
F P
0 g
s
.47444 .49042 m .47969 .49104 L .47461 .49395 L p .332 0 .053 r
F P
0 g
s
.50448 .47308 m .50239 .47793 L .49685 .48115 L p .265 0 .156 r
F P
0 g
s
.50239 .47793 m .50448 .47308 L .51118 .46917 L p .203 0 .127 r
F P
0 g
s
.51794 .48104 m .52111 .47491 L .52108 .48266 L p .994 .872 .584 r
F P
0 g
s
.52108 .48266 m .51792 .48689 L .51794 .48104 L p .994 .872 .584 r
F P
0 g
s
.52108 .51734 m .51792 .51311 L .5179 .5067 L p .995 .777 .49 r
F P
0 g
s
.51792 .51311 m .52108 .51734 L .52111 .52509 L p .994 .751 .435 r
F P
0 g
s
.47444 .50958 m .47969 .50896 L .48525 .51216 L p .341 .623 .956 r
F P
0 g
s
.47969 .50896 m .47444 .50958 L .46772 .50573 L p .332 .644 .966 r
F P
0 g
s
.50745 .52501 m .51118 .53083 L .50448 .52692 L p .203 .478 .892 r
F P
0 g
s
.50448 .52692 m .50239 .52207 L .50745 .52501 L p .203 .478 .892 r
F P
0 g
s
.28214 .87734 m .28514 .87215 L .29156 .87597 L p .742 .247 .056 r
F P
0 g
s
.28514 .87215 m .28214 .87734 L .28005 .87617 L p .753 .261 .062 r
F P
0 g
s
.28005 .87617 m .27862 .8685 L .28514 .87215 L p .753 .261 .062 r
F P
0 g
s
.93572 .5 m .92972 .5 L .92982 .49253 L p 0 0 .502 r
F P
0 g
s
.92972 .5 m .93572 .5 L .93575 .5024 L p 0 0 .489 r
F P
0 g
s
.93575 .5024 m .92982 .50747 L .92972 .5 L p 0 0 .489 r
F P
0 g
s
.28214 .12266 m .28514 .12785 L .27862 .1315 L p .753 .969 .929 r
F P
0 g
s
.28514 .12785 m .28214 .12266 L .2842 .12143 L p .742 .965 .936 r
F P
0 g
s
.2842 .12143 m .29156 .12403 L .28514 .12785 L p .742 .965 .936 r
F P
0 g
s
.27862 .8685 m .28005 .87617 L .27801 .8751 L p .761 .269 .059 r
F P
0 g
s
.27801 .8751 m .27228 .86517 L .27862 .8685 L p .761 .269 .059 r
F P
0 g
s
.2842 .87857 m .29156 .87597 L .29761 .87979 L p .728 .227 .04 r
F P
0 g
s
.29156 .87597 m .2842 .87857 L .28214 .87734 L p .742 .247 .056 r
F P
0 g
s
.92982 .50747 m .93575 .5024 L .93584 .5047 L p 0 0 .471 r
F P
0 g
s
.93584 .5047 m .93011 .51462 L .92982 .50747 L p 0 0 .471 r
F P
0 g
s
.93575 .4976 m .92982 .49253 L .93011 .48538 L p 0 0 .509 r
F P
0 g
s
.92982 .49253 m .93575 .4976 L .93572 .5 L p 0 0 .502 r
F P
0 g
s
.29156 .12403 m .2842 .12143 L .28615 .1202 L p .728 .963 .941 r
F P
0 g
s
.28615 .1202 m .29761 .12021 L .29156 .12403 L p .728 .963 .941 r
F P
0 g
s
.28005 .12383 m .27862 .1315 L .27228 .13483 L p .761 .974 .922 r
F P
0 g
s
.27862 .1315 m .28005 .12383 L .28214 .12266 L p .753 .969 .929 r
F P
0 g
s
.47023 .49644 m .4619 .49758 L .46772 .49427 L p .301 0 0 r
F P
0 g
s
.46772 .49427 m .47461 .49395 L .47023 .49644 L p .301 0 0 r
F P
0 g
s
.51118 .46917 m .50745 .47499 L .50239 .47793 L p .203 0 .127 r
F P
0 g
s
.50745 .47499 m .51118 .46917 L .51695 .4658 L p .116 0 .072 r
F P
0 g
s
.51796 .476 m .52115 .46822 L .52111 .47491 L p .987 .893 .575 r
F P
0 g
s
.52111 .47491 m .51794 .48104 L .51796 .476 L p .987 .893 .575 r
F P
0 g
s
.52111 .52509 m .51794 .51896 L .51792 .51311 L p .994 .751 .435 r
F P
0 g
s
.51794 .51896 m .52111 .52509 L .52115 .53178 L p .987 .719 .362 r
F P
0 g
s
.46772 .50573 m .47461 .50605 L .47969 .50896 L p .332 .644 .966 r
F P
0 g
s
.47461 .50605 m .46772 .50573 L .4619 .50242 L p .301 .656 .971 r
F P
0 g
s
.5118 .52756 m .51695 .5342 L .51118 .53083 L p .116 .419 .864 r
F P
0 g
s
.51118 .53083 m .50745 .52501 L .5118 .52756 L p .116 .419 .864 r
F P
0 g
s
.41304 .50889 m .37705 .50876 L .38201 .5063 L p .276 0 0 r
F P
0 g
s
.38201 .5063 m .41645 .50711 L .41304 .50889 L p .276 0 0 r
F P
0 g
s
.54794 .4312 m .56445 .40097 L .56907 .3979 L p 0 0 0 r
F P
0 g
s
.53578 .42025 m .55389 .38914 L .55354 .39467 L p .844 .952 .601 r
F P
0 g
s
.55354 .39467 m .53561 .42409 L .53578 .42025 L p .844 .952 .601 r
F P
0 g
s
.41645 .49289 m .38201 .4937 L .37705 .49124 L p .276 .755 .929 r
F P
0 g
s
.53561 .57591 m .55354 .60533 L .55389 .61086 L p .844 .427 0 r
F P
0 g
s
.55118 .57086 m .56907 .6021 L .56445 .59903 L p 0 .039 .608 r
F P
0 g
s
.56445 .59903 m .54794 .5688 L .55118 .57086 L p 0 .039 .608 r
F P
0 g
s
.93584 .4953 m .93011 .48538 L .93057 .47884 L p 0 0 .51 r
F P
0 g
s
.93011 .48538 m .93584 .4953 L .93575 .4976 L p 0 0 .509 r
F P
0 g
s
.28615 .8798 m .29761 .87979 L .30304 .88346 L p .711 .2 .013 r
F P
0 g
s
.29761 .87979 m .28615 .8798 L .2842 .87857 L p .728 .227 .04 r
F P
0 g
s
.27228 .86517 m .27801 .8751 L .27612 .87419 L p .766 .271 .044 r
F P
0 g
s
.27612 .87419 m .26639 .86231 L .27228 .86517 L p .766 .271 .044 r
F P
0 g
s
.93011 .51462 m .93584 .5047 L .93599 .50679 L p 0 0 .447 r
F P
0 g
s
.93599 .50679 m .93057 .52116 L .93011 .51462 L p 0 0 .447 r
F P
0 g
s
.27801 .1249 m .27228 .13483 L .26639 .13769 L p .766 .98 .913 r
F P
0 g
s
.27228 .13483 m .27801 .1249 L .28005 .12383 L p .761 .974 .922 r
F P
0 g
s
.29761 .12021 m .28615 .1202 L .28788 .11902 L p .711 .961 .944 r
F P
0 g
s
.28788 .11902 m .30304 .11654 L .29761 .12021 L p .711 .961 .944 r
F P
0 g
s
.48768 .48897 m .48525 .48784 L .49105 .4845 L p .323 0 .136 r
F P
0 g
s
.49105 .4845 m .49215 .4864 L .48768 .48897 L p .323 0 .136 r
F P
0 g
s
.49215 .4864 m .49105 .4845 L .49685 .48115 L p .298 0 .15 r
F P
0 g
s
.51571 .49484 m .5179 .4933 L .5179 .5 L p .996 .825 .554 r
F P
0 g
s
.5179 .5 m .51571 .5 L .51571 .49484 L p .996 .825 .554 r
F P
0 g
s
.51571 .5 m .5179 .5 L .5179 .5067 L p .996 .802 .525 r
F P
0 g
s
.49661 .51618 m .49685 .51885 L .49105 .5155 L p .298 .561 .928 r
F P
0 g
s
.49105 .5155 m .49215 .5136 L .49661 .51618 L p .298 .561 .928 r
F P
0 g
s
.49215 .5136 m .49105 .5155 L .48525 .51216 L p .323 .593 .942 r
F P
0 g
s
.4834 .49143 m .47969 .49104 L .48525 .48784 L p .331 0 .101 r
F P
0 g
s
.48525 .48784 m .48768 .48897 L .4834 .49143 L p .331 0 .101 r
F P
0 g
s
.49685 .48115 m .49661 .48382 L .49215 .4864 L p .298 0 .15 r
F P
0 g
s
.49661 .48382 m .49685 .48115 L .50239 .47793 L p .256 0 .144 r
F P
0 g
s
.51572 .48991 m .51792 .48689 L .5179 .4933 L p .996 .849 .571 r
F P
0 g
s
.5179 .4933 m .51571 .49484 L .51572 .48991 L p .996 .849 .571 r
F P
0 g
s
.5179 .5067 m .51571 .50516 L .51571 .5 L p .996 .802 .525 r
F P
0 g
s
.51571 .50516 m .5179 .5067 L .51792 .51311 L p .996 .778 .485 r
F P
0 g
s
.48525 .51216 m .48768 .51103 L .49215 .5136 L p .323 .593 .942 r
F P
0 g
s
.48768 .51103 m .48525 .51216 L .47969 .50896 L p .331 .619 .955 r
F P
0 g
s
.50088 .51866 m .50239 .52207 L .49685 .51885 L p .256 .523 .912 r
F P
0 g
s
.49685 .51885 m .49661 .51618 L .50088 .51866 L p .256 .523 .912 r
F P
0 g
s
.50239 .47793 m .50088 .48134 L .49661 .48382 L p .256 0 .144 r
F P
0 g
s
.50088 .48134 m .50239 .47793 L .50745 .47499 L p .195 0 .115 r
F P
0 g
s
.47949 .49367 m .47461 .49395 L .47969 .49104 L p .322 0 .042 r
F P
0 g
s
.47969 .49104 m .4834 .49143 L .47949 .49367 L p .322 0 .042 r
F P
0 g
s
.51574 .4854 m .51794 .48104 L .51792 .48689 L p .995 .872 .577 r
F P
0 g
s
.51792 .48689 m .51572 .48991 L .51574 .4854 L p .995 .872 .577 r
F P
0 g
s
.51792 .51311 m .51572 .51009 L .51571 .50516 L p .996 .778 .485 r
F P
0 g
s
.51572 .51009 m .51792 .51311 L .51794 .51896 L p .995 .752 .43 r
F P
0 g
s
.47969 .50896 m .4834 .50857 L .48768 .51103 L p .331 .619 .955 r
F P
0 g
s
.4834 .50857 m .47969 .50896 L .47461 .50605 L p .322 .64 .965 r
F P
0 g
s
.50477 .52093 m .50745 .52501 L .50239 .52207 L p .195 .476 .892 r
F P
0 g
s
.50239 .52207 m .50088 .51866 L .50477 .52093 L p .195 .476 .892 r
F P
0 g
s
.26639 .86231 m .27612 .87419 L .27447 .87346 L p .766 .265 .019 r
F P
0 g
s
.27447 .87346 m .26121 .86003 L .26639 .86231 L p .766 .265 .019 r
F P
0 g
s
.28788 .88098 m .30304 .88346 L .3076 .88681 L p .69 .168 0 r
F P
0 g
s
.30304 .88346 m .28788 .88098 L .28615 .8798 L p .711 .2 .013 r
F P
0 g
s
.93599 .49321 m .93057 .47884 L .93119 .47321 L p 0 0 .504 r
F P
0 g
s
.93057 .47884 m .93599 .49321 L .93584 .4953 L p 0 0 .51 r
F P
0 g
s
.93057 .52116 m .93599 .50679 L .93619 .50859 L p 0 0 .417 r
F P
0 g
s
.93619 .50859 m .93119 .52679 L .93057 .52116 L p 0 0 .417 r
F P
0 g
s
.27612 .12581 m .26639 .13769 L .26121 .13997 L p .766 .985 .902 r
F P
0 g
s
.26639 .13769 m .27612 .12581 L .27801 .1249 L p .766 .98 .913 r
F P
0 g
s
.30304 .11654 m .28788 .11902 L .28934 .11795 L p .69 .96 .945 r
F P
0 g
s
.28934 .11795 m .3076 .11319 L .30304 .11654 L p .69 .96 .945 r
F P
0 g
s
.454 .50203 m .43899 .50474 L .44344 .50226 L p .194 0 0 r
F P
0 g
s
.44344 .50226 m .45726 .5002 L .454 .50203 L p .194 0 0 r
F P
0 g
s
.52154 .46309 m .53024 .45215 L .53461 .44953 L p 0 0 0 r
F P
0 g
s
.54794 .4312 m .53461 .44953 L .53024 .45215 L p 0 0 .01 r
F P
0 g
s
.52125 .45915 m .52641 .44479 L .52632 .44989 L p .926 .91 .517 r
F P
0 g
s
.52632 .44989 m .52119 .46289 L .52125 .45915 L p .926 .91 .517 r
F P
0 g
s
.45726 .4998 m .44344 .49774 L .43899 .49526 L p .194 .657 .94 r
F P
0 g
s
.41645 .49289 m .43899 .49526 L .44344 .49774 L p .292 .718 .97 r
F P
0 g
s
.52119 .53711 m .52632 .55011 L .52641 .55521 L p .926 .603 .142 r
F P
0 g
s
.53561 .57591 m .52641 .55521 L .52632 .55011 L p .937 .589 .167 r
F P
0 g
s
.52475 .53882 m .53461 .55047 L .53024 .54785 L p 0 .238 .753 r
F P
0 g
s
.53024 .54785 m .52154 .53691 L .52475 .53882 L p 0 .238 .753 r
F P
0 g
s
.4619 .49758 m .47023 .49644 L .46674 .49842 L p .241 0 0 r
F P
0 g
s
.51695 .4658 m .5118 .47244 L .50745 .47499 L p .116 0 .072 r
F P
0 g
s
.52115 .46822 m .51796 .476 L .518 .47199 L p .967 .904 .542 r
F P
0 g
s
.4619 .50242 m .47023 .50356 L .47461 .50605 L p .301 .656 .971 r
F P
0 g
s
.52115 .53178 m .51796 .524 L .51794 .51896 L p .987 .719 .362 r
F P
0 g
s
.51695 .5342 m .5118 .52756 L .51526 .52959 L p 0 .34 .821 r
F P
0 g
s
.22262 .8197 m .25381 .85761 L .25192 .85758 L p .838 .37 .035 r
F P
0 g
s
.25192 .85758 m .21805 .81944 L .22262 .8197 L p .838 .37 .035 r
F P
0 g
s
.86609 .34815 m .91762 .41555 L .91556 .41964 L p .072 .307 .79 r
F P
0 g
s
.93279 .46559 m .91556 .41964 L .91762 .41555 L p 0 .038 .59 r
F P
0 g
s
.91556 .41964 m .93279 .46559 L .93194 .46873 L p .014 .126 .638 r
F P
0 g
s
.91556 .58036 m .93279 .53441 L .93371 .53606 L p 0 0 .251 r
F P
0 g
s
.93371 .53606 m .91762 .58445 L .91556 .58036 L p 0 0 .251 r
F P
0 g
s
.44846 .89297 m .36433 .9039 L .36182 .90007 L p .43 0 0 r
F P
0 g
s
.3134 .89201 m .36182 .90007 L .36433 .9039 L p .545 0 0 r
F P
0 g
s
.36182 .90007 m .3134 .89201 L .31111 .88971 L p .616 .104 .008 r
F P
0 g
s
.18544 .25888 m .21805 .18056 L .22262 .1803 L p .956 .949 .693 r
F P
0 g
s
.25381 .14239 m .22262 .1803 L .21805 .18056 L p .838 .999 .806 r
F P
0 g
s
.22262 .1803 m .25381 .14239 L .25695 .14156 L p .86 .987 .845 r
F P
0 g
s
.36182 .09993 m .3134 .10799 L .31437 .10637 L p .545 .898 .975 r
F P
0 g
s
.31437 .10637 m .36433 .0961 L .36182 .09993 L p .545 .898 .975 r
F P
0 g
s
.50745 .47499 m .50477 .47907 L .50088 .48134 L p .195 0 .115 r
F P
0 g
s
.50477 .47907 m .50745 .47499 L .5118 .47244 L p .108 0 .06 r
F P
0 g
s
.47612 .49559 m .47023 .49644 L .47461 .49395 L p .29 0 0 r
F P
0 g
s
.47461 .49395 m .47949 .49367 L .47612 .49559 L p .29 0 0 r
F P
0 g
s
.51576 .48153 m .51796 .476 L .51794 .48104 L p .987 .892 .567 r
F P
0 g
s
.51794 .48104 m .51574 .4854 L .51576 .48153 L p .987 .892 .567 r
F P
0 g
s
.51794 .51896 m .51574 .5146 L .51572 .51009 L p .995 .752 .43 r
F P
0 g
s
.51574 .5146 m .51794 .51896 L .51796 .524 L p .987 .72 .357 r
F P
0 g
s
.47461 .50605 m .47949 .50633 L .4834 .50857 L p .322 .64 .965 r
F P
0 g
s
.47949 .50633 m .47461 .50605 L .47023 .50356 L p .29 .651 .969 r
F P
0 g
s
.50812 .52288 m .5118 .52756 L .50745 .52501 L p .108 .417 .864 r
F P
0 g
s
.50745 .52501 m .50477 .52093 L .50812 .52288 L p .108 .417 .864 r
F P
0 g
s
.48948 .48987 m .48768 .48897 L .49215 .4864 L p .342 0 .159 r
F P
0 g
s
.49215 .4864 m .49298 .48785 L .48948 .48987 L p .342 0 .159 r
F P
0 g
s
.49298 .48785 m .49215 .4864 L .49661 .48382 L p .316 0 .174 r
F P
0 g
s
.51404 .49595 m .51571 .49484 L .51571 .5 L p .994 .824 .565 r
F P
0 g
s
.51571 .5 m .51403 .5 L .51404 .49595 L p .994 .824 .565 r
F P
0 g
s
.51403 .5 m .51571 .5 L .51571 .50516 L p .994 .8 .536 r
F P
0 g
s
.49649 .51418 m .49661 .51618 L .49215 .5136 L p .316 .566 .927 r
F P
0 g
s
.49215 .5136 m .49298 .51215 L .49649 .51418 L p .316 .566 .927 r
F P
0 g
s
.49298 .51215 m .49215 .5136 L .48768 .51103 L p .342 .598 .942 r
F P
0 g
s
.53461 .44953 m .54794 .4312 L .55118 .42914 L p 0 0 0 r
F P
0 g
s
.56907 .3979 m .55118 .42914 L .54794 .4312 L p 0 0 0 r
F P
0 g
s
.43659 .50602 m .41304 .50889 L .41645 .50711 L p .132 0 0 r
F P
0 g
s
.41645 .50711 m .43899 .50474 L .43659 .50602 L p .132 0 0 r
F P
0 g
s
.5265 .44207 m .53578 .42025 L .53561 .42409 L p .839 .896 .477 r
F P
0 g
s
.53561 .42409 m .52641 .44479 L .5265 .44207 L p .839 .896 .477 r
F P
0 g
s
.43899 .49526 m .41645 .49289 L .41304 .49111 L p .132 .652 .885 r
F P
0 g
s
.37705 .49124 m .41304 .49111 L .41645 .49289 L p .276 .755 .929 r
F P
0 g
s
.52641 .55521 m .53561 .57591 L .53578 .57975 L p .839 .474 0 r
F P
0 g
s
.55389 .61086 m .53578 .57975 L .53561 .57591 L p .844 .427 0 r
F P
0 g
s
.53692 .55191 m .55118 .57086 L .54794 .5688 L p 0 .076 .627 r
F P
0 g
s
.54794 .5688 m .53461 .55047 L .53692 .55191 L p 0 .076 .627 r
F P
0 g
s
.48612 .4918 m .4834 .49143 L .48768 .48897 L p .351 0 .124 r
F P
0 g
s
.48768 .48897 m .48948 .48987 L .48612 .4918 L p .351 0 .124 r
F P
0 g
s
.49661 .48382 m .49649 .48582 L .49298 .48785 L p .316 0 .174 r
F P
0 g
s
.49649 .48582 m .49661 .48382 L .50088 .48134 L p .274 0 .168 r
F P
0 g
s
.51405 .49208 m .51572 .48991 L .51571 .49484 L p .994 .848 .584 r
F P
0 g
s
.51571 .49484 m .51404 .49595 L .51405 .49208 L p .994 .848 .584 r
F P
0 g
s
.51571 .50516 m .51404 .50405 L .51403 .5 L p .994 .8 .536 r
F P
0 g
s
.51404 .50405 m .51571 .50516 L .51572 .51009 L p .994 .776 .496 r
F P
0 g
s
.48768 .51103 m .48948 .51013 L .49298 .51215 L p .342 .598 .942 r
F P
0 g
s
.48948 .51013 m .48768 .51103 L .4834 .50857 L p .351 .626 .956 r
F P
0 g
s
.49983 .51612 m .50088 .51866 L .49661 .51618 L p .274 .527 .911 r
F P
0 g
s
.49661 .51618 m .49649 .51418 L .49983 .51612 L p .274 .527 .911 r
F P
0 g
s
.93619 .49141 m .93119 .47321 L .93194 .46873 L p 0 0 .49 r
F P
0 g
s
.93119 .47321 m .93619 .49141 L .93599 .49321 L p 0 0 .504 r
F P
0 g
s
.28934 .88205 m .3076 .88681 L .31111 .88971 L p .666 .13 0 r
F P
0 g
s
.3076 .88681 m .28934 .88205 L .28788 .88098 L p .69 .168 0 r
F P
0 g
s
.26121 .86003 m .27447 .87346 L .27311 .87296 L p .76 .251 0 r
F P
0 g
s
.27311 .87296 m .25695 .85844 L .26121 .86003 L p .76 .251 0 r
F P
0 g
s
.93119 .52679 m .93619 .50859 L .93644 .51001 L p 0 0 .381 r
F P
0 g
s
.93644 .51001 m .93194 .53127 L .93119 .52679 L p 0 0 .381 r
F P
0 g
s
.27447 .12654 m .26121 .13997 L .25695 .14156 L p .76 .99 .889 r
F P
0 g
s
.26121 .13997 m .27447 .12654 L .27612 .12581 L p .766 .985 .902 r
F P
0 g
s
.3076 .11319 m .28934 .11795 L .29045 .11703 L p .666 .958 .943 r
F P
0 g
s
.29045 .11703 m .31111 .11029 L .3076 .11319 L p .666 .958 .943 r
F P
0 g
s
.50088 .48134 m .49983 .48388 L .49649 .48582 L p .274 0 .168 r
F P
0 g
s
.49983 .48388 m .50088 .48134 L .50477 .47907 L p .212 0 .14 r
F P
0 g
s
.48306 .49355 m .47949 .49367 L .4834 .49143 L p .343 0 .065 r
F P
0 g
s
.4834 .49143 m .48612 .4918 L .48306 .49355 L p .343 0 .065 r
F P
0 g
s
.51406 .48855 m .51574 .4854 L .51572 .48991 L p .994 .873 .591 r
F P
0 g
s
.51572 .48991 m .51405 .49208 L .51406 .48855 L p .994 .873 .591 r
F P
0 g
s
.51572 .51009 m .51405 .50792 L .51404 .50405 L p .994 .776 .496 r
F P
0 g
s
.51405 .50792 m .51572 .51009 L .51574 .5146 L p .994 .75 .441 r
F P
0 g
s
.4834 .50857 m .48612 .5082 L .48948 .51013 L p .351 .626 .956 r
F P
0 g
s
.48612 .5082 m .4834 .50857 L .47949 .50633 L p .343 .648 .967 r
F P
0 g
s
.50289 .5179 m .50477 .52093 L .50088 .51866 L p .212 .48 .892 r
F P
0 g
s
.50088 .51866 m .49983 .51612 L .50289 .5179 L p .212 .48 .892 r
F P
0 g
s
.47344 .49711 m .46674 .49842 L .47023 .49644 L p .23 0 0 r
F P
0 g
s
.47023 .49644 m .47612 .49559 L .47344 .49711 L p .23 0 0 r
F P
0 g
s
.5118 .47244 m .50812 .47712 L .50477 .47907 L p .108 0 .06 r
F P
0 g
s
.50812 .47712 m .5118 .47244 L .51526 .47041 L p 0 0 0 r
F P
0 g
s
.51578 .47845 m .518 .47199 L .51796 .476 L p .965 .901 .534 r
F P
0 g
s
.51796 .476 m .51576 .48153 L .51578 .47845 L p .965 .901 .534 r
F P
0 g
s
.51796 .524 m .51576 .51847 L .51574 .5146 L p .987 .72 .357 r
F P
0 g
s
.51576 .51847 m .51796 .524 L .518 .52801 L p .965 .675 .257 r
F P
0 g
s
.47023 .50356 m .47612 .50441 L .47949 .50633 L p .29 .651 .969 r
F P
0 g
s
.47612 .50441 m .47023 .50356 L .46674 .50158 L p .23 .647 .958 r
F P
0 g
s
.51078 .52444 m .51526 .52959 L .5118 .52756 L p 0 .339 .82 r
F P
0 g
s
.5118 .52756 m .50812 .52288 L .51078 .52444 L p 0 .339 .82 r
F P
0 g
s
.53461 .44953 m .52475 .46118 L .52154 .46309 L p 0 0 0 r
F P
0 g
s
.43899 .49526 m .454 .49797 L .45726 .4998 L p .194 .657 .94 r
F P
0 g
s
.52641 .55521 m .52125 .54085 L .52119 .53711 L p .926 .603 .142 r
F P
0 g
s
.25317 .54368 m .19373 .6317 L .19002 .6333 L p .717 .902 .531 r
F P
0 g
s
.19373 .6317 m .18544 .74112 L .18255 .74334 L p .896 .77 .276 r
F P
0 g
s
.18255 .74334 m .19002 .6333 L .19373 .6317 L p .896 .77 .276 r
F P
0 g
s
.66312 .30584 m .77043 .2982 L .76719 .30061 L p .192 .721 .834 r
F P
0 g
s
.76719 .30061 m .66124 .30807 L .66312 .30584 L p .192 .721 .834 r
F P
0 g
s
.86609 .34815 m .76719 .30061 L .77043 .2982 L p 0 .439 .83 r
F P
0 g
s
.58559 .2644 m .53908 .16891 L .53955 .1649 L p 0 0 .446 r
F P
0 g
s
.53908 .16891 m .44846 .10703 L .44799 .10341 L p 0 .332 .782 r
F P
0 g
s
.44799 .10341 m .53955 .1649 L .53908 .16891 L p 0 .332 .782 r
F P
0 g
s
.25029 .45581 m .19002 .3667 L .19373 .3683 L p .717 .269 0 r
F P
0 g
s
.19373 .3683 m .25317 .45632 L .25029 .45581 L p .717 .269 0 r
F P
0 g
s
.18544 .25888 m .19373 .3683 L .19002 .3667 L p .896 .692 .18 r
F P
0 g
s
.66124 .69193 m .76719 .69939 L .77043 .7018 L p .192 0 0 r
F P
0 g
s
.76719 .69939 m .86609 .65185 L .86946 .65325 L p 0 0 0 r
F P
0 g
s
.86946 .65325 m .77043 .7018 L .76719 .69939 L p 0 0 0 r
F P
0 g
s
.58659 .73835 m .53955 .8351 L .53908 .83109 L p 0 0 0 r
F P
0 g
s
.53908 .83109 m .58559 .7356 L .58659 .73835 L p 0 0 0 r
F P
0 g
s
.44846 .89297 m .53908 .83109 L .53955 .8351 L p 0 0 0 r
F P
0 g
s
.32163 .49731 m .25029 .45581 L .25317 .45632 L p .425 0 0 r
F P
0 g
s
.25317 .45632 m .32326 .49734 L .32163 .49731 L p .425 0 0 r
F P
0 g
s
.58607 .3456 m .58559 .2644 L .58659 .26165 L p 0 0 .073 r
F P
0 g
s
.53955 .1649 m .58659 .26165 L .58559 .2644 L p 0 0 .446 r
F P
0 g
s
.59151 .34687 m .66312 .30584 L .66124 .30807 L p .419 .841 .681 r
F P
0 g
s
.66124 .30807 m .59068 .34827 L .59151 .34687 L p .419 .841 .681 r
F P
0 g
s
.32326 .50266 m .25317 .54368 L .25029 .54419 L p .425 .843 .678 r
F P
0 g
s
.19002 .6333 m .25029 .54419 L .25317 .54368 L p .717 .902 .531 r
F P
0 g
s
.59068 .65173 m .66124 .69193 L .66312 .69416 L p .419 0 0 r
F P
0 g
s
.77043 .7018 m .66312 .69416 L .66124 .69193 L p .192 0 0 r
F P
0 g
s
.58686 .65581 m .58659 .73835 L .58559 .7356 L p 0 0 .067 r
F P
0 g
s
.58559 .7356 m .58607 .6544 L .58686 .65581 L p 0 0 .067 r
F P
0 g
s
.48042 .49505 m .47612 .49559 L .47949 .49367 L p .312 0 0 r
F P
0 g
s
.47949 .49367 m .48306 .49355 L .48042 .49505 L p .312 0 0 r
F P
0 g
s
.50477 .47907 m .50289 .4821 L .49983 .48388 L p .212 0 .14 r
F P
0 g
s
.50289 .4821 m .50477 .47907 L .50812 .47712 L p .125 0 .085 r
F P
0 g
s
.51408 .48552 m .51576 .48153 L .51574 .4854 L p .988 .895 .583 r
F P
0 g
s
.51574 .4854 m .51406 .48855 L .51408 .48552 L p .988 .895 .583 r
F P
0 g
s
.51574 .5146 m .51406 .51145 L .51405 .50792 L p .994 .75 .441 r
F P
0 g
s
.51406 .51145 m .51574 .5146 L .51576 .51847 L p .988 .718 .367 r
F P
0 g
s
.47949 .50633 m .48306 .50645 L .48612 .5082 L p .343 .648 .967 r
F P
0 g
s
.48306 .50645 m .47949 .50633 L .47612 .50441 L p .312 .662 .973 r
F P
0 g
s
.50551 .51943 m .50812 .52288 L .50477 .52093 L p .125 .421 .865 r
F P
0 g
s
.50477 .52093 m .50289 .5179 L .50551 .51943 L p .125 .421 .865 r
F P
0 g
s
.49087 .49065 m .48948 .48987 L .49298 .48785 L p .379 .011 .207 r
F P
0 g
s
.49298 .48785 m .49367 .48904 L .49087 .49065 L p .379 .011 .207 r
F P
0 g
s
.49367 .48904 m .49298 .48785 L .49649 .48582 L p .353 .002 .222 r
F P
0 g
s
.51266 .49677 m .51404 .49595 L .51403 .5 L p .987 .818 .588 r
F P
0 g
s
.51403 .5 m .51266 .5 L .51266 .49677 L p .987 .818 .588 r
F P
0 g
s
.51266 .5 m .51403 .5 L .51404 .50405 L p .987 .794 .558 r
F P
0 g
s
.49647 .51258 m .49649 .51418 L .49298 .51215 L p .353 .575 .924 r
F P
0 g
s
.49298 .51215 m .49367 .51096 L .49647 .51258 L p .353 .575 .924 r
F P
0 g
s
.49367 .51096 m .49298 .51215 L .48948 .51013 L p .379 .608 .939 r
F P
0 g
s
.48819 .49219 m .48612 .4918 L .48948 .48987 L p .39 0 .172 r
F P
0 g
s
.48948 .48987 m .49087 .49065 L .48819 .49219 L p .39 0 .172 r
F P
0 g
s
.49649 .48582 m .49647 .48742 L .49367 .48904 L p .353 .002 .222 r
F P
0 g
s
.49647 .48742 m .49649 .48582 L .49983 .48388 L p .311 0 .218 r
F P
0 g
s
.51267 .49368 m .51405 .49208 L .51404 .49595 L p .988 .845 .609 r
F P
0 g
s
.51404 .49595 m .51266 .49677 L .51267 .49368 L p .988 .845 .609 r
F P
0 g
s
.51404 .50405 m .51266 .50323 L .51266 .5 L p .987 .794 .558 r
F P
0 g
s
.51266 .50323 m .51404 .50405 L .51405 .50792 L p .988 .769 .517 r
F P
0 g
s
.48948 .51013 m .49087 .50935 L .49367 .51096 L p .379 .608 .939 r
F P
0 g
s
.49087 .50935 m .48948 .51013 L .48612 .5082 L p .39 .638 .954 r
F P
0 g
s
.49914 .51414 m .49983 .51612 L .49649 .51418 L p .311 .535 .908 r
F P
0 g
s
.49649 .51418 m .49647 .51258 L .49914 .51414 L p .311 .535 .908 r
F P
0 g
s
.93644 .48999 m .93194 .46873 L .93279 .46559 L p 0 0 .467 r
F P
0 g
s
.93194 .46873 m .93644 .48999 L .93619 .49141 L p 0 0 .49 r
F P
0 g
s
.29045 .88297 m .31111 .88971 L .3134 .89201 L p .637 .085 0 r
F P
0 g
s
.31111 .88971 m .29045 .88297 L .28934 .88205 L p .666 .13 0 r
F P
0 g
s
.25695 .85844 m .27311 .87296 L .27211 .8727 L p .747 .228 0 r
F P
0 g
s
.27211 .8727 m .25381 .85761 L .25695 .85844 L p .747 .228 0 r
F P
0 g
s
.93194 .53127 m .93644 .51001 L .93671 .511 L p 0 0 .339 r
F P
0 g
s
.93671 .511 m .93279 .53441 L .93194 .53127 L p 0 0 .339 r
F P
0 g
s
.27311 .12704 m .25695 .14156 L .25381 .14239 L p .747 .992 .871 r
F P
0 g
s
.25695 .14156 m .27311 .12704 L .27447 .12654 L p .76 .99 .889 r
F P
0 g
s
.31111 .11029 m .29045 .11703 L .29117 .11629 L p .637 .954 .935 r
F P
0 g
s
.29117 .11629 m .3134 .10799 L .31111 .11029 L p .637 .954 .935 r
F P
0 g
s
.45226 .50296 m .43659 .50602 L .43899 .50474 L p .045 0 0 r
F P
0 g
s
.43899 .50474 m .454 .50203 L .45226 .50296 L p .045 0 0 r
F P
0 g
s
.52475 .46118 m .53461 .44953 L .53692 .44809 L p 0 0 0 r
F P
0 g
s
.55118 .42914 m .53692 .44809 L .53461 .44953 L p 0 0 0 r
F P
0 g
s
.5213 .45718 m .5265 .44207 L .52641 .44479 L p .828 .855 .399 r
F P
0 g
s
.52641 .44479 m .52125 .45915 L .5213 .45718 L p .828 .855 .399 r
F P
0 g
s
.454 .49797 m .43899 .49526 L .43659 .49398 L p .045 .584 .851 r
F P
0 g
s
.41304 .49111 m .43659 .49398 L .43899 .49526 L p .132 .652 .885 r
F P
0 g
s
.52125 .54085 m .52641 .55521 L .5265 .55793 L p .828 .498 0 r
F P
0 g
s
.53578 .57975 m .5265 .55793 L .52641 .55521 L p .839 .474 0 r
F P
0 g
s
.52644 .53986 m .53692 .55191 L .53461 .55047 L p 0 .098 .633 r
F P
0 g
s
.53461 .55047 m .52475 .53882 L .52644 .53986 L p 0 .098 .633 r
F P
0 g
s
.49983 .48388 m .49914 .48586 L .49647 .48742 L p .311 0 .218 r
F P
0 g
s
.49914 .48586 m .49983 .48388 L .50289 .4821 L p .249 0 .192 r
F P
0 g
s
.48574 .49359 m .48306 .49355 L .48612 .4918 L p .385 0 .113 r
F P
0 g
s
.48612 .4918 m .48819 .49219 L .48574 .49359 L p .385 0 .113 r
F P
0 g
s
.51268 .49086 m .51406 .48855 L .51405 .49208 L p .989 .872 .62 r
F P
0 g
s
.51405 .49208 m .51267 .49368 L .51268 .49086 L p .989 .872 .62 r
F P
0 g
s
.51405 .50792 m .51267 .50632 L .51266 .50323 L p .988 .769 .517 r
F P
0 g
s
.51267 .50632 m .51405 .50792 L .51406 .51145 L p .989 .744 .462 r
F P
0 g
s
.48612 .5082 m .48819 .50781 L .49087 .50935 L p .39 .638 .954 r
F P
0 g
s
.48819 .50781 m .48612 .5082 L .48306 .50645 L p .385 .663 .969 r
F P
0 g
s
.50158 .51556 m .50289 .5179 L .49983 .51612 L p .249 .488 .89 r
F P
0 g
s
.49983 .51612 m .49914 .51414 L .50158 .51556 L p .249 .488 .89 r
F P
0 g
s
.47832 .49624 m .47344 .49711 L .47612 .49559 L p .253 0 0 r
F P
0 g
s
.47612 .49559 m .48042 .49505 L .47832 .49624 L p .253 0 0 r
F P
0 g
s
.50812 .47712 m .50551 .48057 L .50289 .4821 L p .125 0 .085 r
F P
0 g
s
.50551 .48057 m .50812 .47712 L .51078 .47556 L p .006 0 0 r
F P
0 g
s
.51526 .47041 m .51078 .47556 L .50812 .47712 L p 0 0 0 r
F P
0 g
s
.5141 .4831 m .51578 .47845 L .51576 .48153 L p .968 .907 .552 r
F P
0 g
s
.51576 .48153 m .51408 .48552 L .5141 .4831 L p .968 .907 .552 r
F P
0 g
s
.51576 .51847 m .51408 .51448 L .51406 .51145 L p .988 .718 .367 r
F P
0 g
s
.51408 .51448 m .51576 .51847 L .51578 .52155 L p .968 .674 .266 r
F P
0 g
s
.518 .52801 m .51578 .52155 L .51576 .51847 L p .965 .675 .257 r
F P
0 g
s
.47612 .50441 m .48042 .50495 L .48306 .50645 L p .312 .662 .973 r
F P
0 g
s
.48042 .50495 m .47612 .50441 L .47344 .50289 L p .253 .66 .964 r
F P
0 g
s
.46674 .50158 m .47344 .50289 L .47612 .50441 L p .23 .647 .958 r
F P
0 g
s
.50758 .52065 m .51078 .52444 L .50812 .52288 L p .006 .342 .822 r
F P
0 g
s
.50812 .52288 m .50551 .51943 L .50758 .52065 L p .006 .342 .822 r
F P
0 g
s
.47157 .49816 m .4643 .49979 L .46674 .49842 L p .133 0 0 r
F P
0 g
s
.46674 .49842 m .47344 .49711 L .47157 .49816 L p .133 0 0 r
F P
0 g
s
.51078 .47556 m .51526 .47041 L .51767 .46897 L p 0 0 0 r
F P
0 g
s
.51581 .4763 m .51803 .46918 L .518 .47199 L p .915 .886 .465 r
F P
0 g
s
.518 .47199 m .51578 .47845 L .51581 .4763 L p .915 .886 .465 r
F P
0 g
s
.51578 .52155 m .518 .52801 L .51803 .53082 L p .915 .609 .126 r
F P
0 g
s
.47344 .50289 m .46674 .50158 L .4643 .50021 L p .133 .616 .917 r
F P
0 g
s
.51262 .52554 m .51767 .53103 L .51526 .52959 L p 0 .237 .747 r
F P
0 g
s
.51526 .52959 m .51078 .52444 L .51262 .52554 L p 0 .237 .747 r
F P
0 g
s
.18544 .74112 m .21805 .81944 L .21661 .82107 L p .88 .511 .031 r
F P
0 g
s
.21661 .82107 m .18255 .74334 L .18544 .74112 L p .88 .511 .031 r
F P
0 g
s
.77043 .2982 m .86946 .34675 L .86609 .34815 L p 0 .439 .83 r
F P
0 g
s
.91762 .41555 m .86609 .34815 L .86946 .34675 L p 0 .127 .673 r
F P
0 g
s
.86609 .65185 m .91762 .58445 L .91975 .58488 L p 0 0 0 r
F P
0 g
s
.91975 .58488 m .86946 .65325 L .86609 .65185 L p 0 0 0 r
F P
0 g
s
.53955 .8351 m .44799 .89659 L .44846 .89297 L p 0 0 0 r
F P
0 g
s
.36433 .9039 m .44846 .89297 L .44799 .89659 L p .208 0 0 r
F P
0 g
s
.44846 .10703 m .36433 .0961 L .36364 .09404 L p .208 .694 .928 r
F P
0 g
s
.36364 .09404 m .44799 .10341 L .44846 .10703 L p .208 .694 .928 r
F P
0 g
s
.19002 .3667 m .18255 .25666 L .18544 .25888 L p .896 .692 .18 r
F P
0 g
s
.21805 .18056 m .18544 .25888 L .18255 .25666 L p .88 .926 .539 r
F P
0 g
s
.58659 .26165 m .58686 .34419 L .58607 .3456 L p 0 0 .073 r
F P
0 g
s
.25029 .54419 m .32163 .50269 L .32326 .50266 L p .425 .843 .678 r
F P
0 g
s
.66312 .69416 m .59151 .65313 L .59068 .65173 L p .419 0 0 r
F P
0 g
s
.48363 .49478 m .48042 .49505 L .48306 .49355 L p .358 0 .025 r
F P
0 g
s
.48306 .49355 m .48574 .49359 L .48363 .49478 L p .358 0 .025 r
F P
0 g
s
.50289 .4821 m .50158 .48444 L .49914 .48586 L p .249 0 .192 r
F P
0 g
s
.50158 .48444 m .50289 .4821 L .50551 .48057 L p .161 0 .139 r
F P
0 g
s
.5127 .48843 m .51408 .48552 L .51406 .48855 L p .987 .899 .616 r
F P
0 g
s
.51406 .48855 m .51268 .49086 L .5127 .48843 L p .987 .899 .616 r
F P
0 g
s
.51406 .51145 m .51268 .50914 L .51267 .50632 L p .989 .744 .462 r
F P
0 g
s
.51268 .50914 m .51406 .51145 L .51408 .51448 L p .987 .713 .388 r
F P
0 g
s
.48306 .50645 m .48574 .50641 L .48819 .50781 L p .385 .663 .969 r
F P
0 g
s
.48574 .50641 m .48306 .50645 L .48042 .50495 L p .358 .682 .979 r
F P
0 g
s
.50367 .51678 m .50551 .51943 L .50289 .5179 L p .161 .428 .865 r
F P
0 g
s
.50289 .5179 m .50158 .51556 L .50367 .51678 L p .161 .428 .865 r
F P
0 g
s
.49199 .49138 m .49087 .49065 L .49367 .48904 L p .426 .077 .268 r
F P
0 g
s
.49367 .48904 m .49426 .49006 L .49199 .49138 L p .426 .077 .268 r
F P
0 g
s
.49426 .49006 m .49367 .48904 L .49647 .48742 L p .399 .068 .284 r
F P
0 g
s
.51148 .49737 m .51266 .49677 L .51266 .5 L p .974 .808 .616 r
F P
0 g
s
.51266 .5 m .51147 .5 L .51148 .49737 L p .974 .808 .616 r
F P
0 g
s
.51147 .5 m .51266 .5 L .51266 .50323 L p .974 .782 .584 r
F P
0 g
s
.49654 .51125 m .49647 .51258 L .49367 .51096 L p .399 .584 .916 r
F P
0 g
s
.49367 .51096 m .49426 .50994 L .49654 .51125 L p .399 .584 .916 r
F P
0 g
s
.49426 .50994 m .49367 .51096 L .49087 .50935 L p .426 .619 .932 r
F P
0 g
s
.49647 .48742 m .49654 .48875 L .49426 .49006 L p .399 .068 .284 r
F P
0 g
s
.49654 .48875 m .49647 .48742 L .49914 .48586 L p .357 .038 .281 r
F P
0 g
s
.4898 .49263 m .48819 .49219 L .49087 .49065 L p .44 .067 .233 r
F P
0 g
s
.49087 .49065 m .49199 .49138 L .4898 .49263 L p .44 .067 .233 r
F P
0 g
s
.51148 .49486 m .51267 .49368 L .51266 .49677 L p .976 .836 .639 r
F P
0 g
s
.51266 .49677 m .51148 .49737 L .51148 .49486 L p .976 .836 .639 r
F P
0 g
s
.51266 .50323 m .51148 .50263 L .51147 .5 L p .974 .782 .584 r
F P
0 g
s
.51148 .50263 m .51266 .50323 L .51267 .50632 L p .976 .758 .543 r
F P
0 g
s
.49087 .50935 m .49199 .50862 L .49426 .50994 L p .426 .619 .932 r
F P
0 g
s
.49199 .50862 m .49087 .50935 L .48819 .50781 L p .44 .651 .949 r
F P
0 g
s
.49871 .51252 m .49914 .51414 L .49647 .51258 L p .357 .544 .901 r
F P
0 g
s
.49647 .51258 m .49654 .51125 L .49871 .51252 L p .357 .544 .901 r
F P
0 g
s
.49914 .48586 m .49871 .48748 L .49654 .48875 L p .357 .038 .281 r
F P
0 g
s
.49871 .48748 m .49914 .48586 L .50158 .48444 L p .295 0 .259 r
F P
0 g
s
.48781 .49376 m .48574 .49359 L .48819 .49219 L p .439 .036 .176 r
F P
0 g
s
.48819 .49219 m .4898 .49263 L .48781 .49376 L p .439 .036 .176 r
F P
0 g
s
.5115 .49256 m .51268 .49086 L .51267 .49368 L p .98 .867 .654 r
F P
0 g
s
.51267 .49368 m .51148 .49486 L .5115 .49256 L p .98 .867 .654 r
F P
0 g
s
.51267 .50632 m .51148 .50514 L .51148 .50263 L p .976 .758 .543 r
F P
0 g
s
.51148 .50514 m .51267 .50632 L .51268 .50914 L p .98 .732 .489 r
F P
0 g
s
.48819 .50781 m .4898 .50737 L .49199 .50862 L p .44 .651 .949 r
F P
0 g
s
.4898 .50737 m .48819 .50781 L .48574 .50641 L p .439 .681 .966 r
F P
0 g
s
.50069 .51368 m .50158 .51556 L .49914 .51414 L p .295 .496 .884 r
F P
0 g
s
.49914 .51414 m .49871 .51252 L .50069 .51368 L p .295 .496 .884 r
F P
0 g
s
.463 .5005 m .45226 .50296 L .454 .50203 L p .004 0 0 r
F P
0 g
s
.53692 .44809 m .52644 .46014 L .52475 .46118 L p 0 0 0 r
F P
0 g
s
.51807 .46771 m .5213 .45718 L .52125 .45915 L p .821 .832 .36 r
F P
0 g
s
.43659 .49398 m .45226 .49704 L .454 .49797 L p .045 .584 .851 r
F P
0 g
s
.5265 .55793 m .5213 .54282 L .52125 .54085 L p .828 .498 0 r
F P
0 g
s
.51893 .53179 m .52644 .53986 L .52475 .53882 L p 0 .108 .634 r
F P
0 g
s
.50551 .48057 m .50367 .48322 L .50158 .48444 L p .161 0 .139 r
F P
0 g
s
.50367 .48322 m .50551 .48057 L .50758 .47935 L p .038 0 .05 r
F P
0 g
s
.51078 .47556 m .50758 .47935 L .50551 .48057 L p .006 0 0 r
F P
0 g
s
.48196 .49573 m .47832 .49624 L .48042 .49505 L p .302 0 0 r
F P
0 g
s
.48042 .49505 m .48363 .49478 L .48196 .49573 L p .302 0 0 r
F P
0 g
s
.51272 .48651 m .5141 .4831 L .51408 .48552 L p .972 .918 .589 r
F P
0 g
s
.51408 .48552 m .5127 .48843 L .51272 .48651 L p .972 .918 .589 r
F P
0 g
s
.51408 .51448 m .5127 .51157 L .51268 .50914 L p .987 .713 .388 r
F P
0 g
s
.5127 .51157 m .51408 .51448 L .5141 .5169 L p .972 .669 .285 r
F P
0 g
s
.51578 .52155 m .5141 .5169 L .51408 .51448 L p .968 .674 .266 r
F P
0 g
s
.48042 .50495 m .48363 .50522 L .48574 .50641 L p .358 .682 .979 r
F P
0 g
s
.48363 .50522 m .48042 .50495 L .47832 .50376 L p .302 .686 .976 r
F P
0 g
s
.47344 .50289 m .47832 .50376 L .48042 .50495 L p .253 .66 .964 r
F P
0 g
s
.50532 .51776 m .50758 .52065 L .50551 .51943 L p .038 .347 .824 r
F P
0 g
s
.50551 .51943 m .50367 .51678 L .50532 .51776 L p .038 .347 .824 r
F P
0 g
s
.4861 .49473 m .48363 .49478 L .48574 .49359 L p .418 0 .089 r
F P
0 g
s
.48574 .49359 m .48781 .49376 L .4861 .49473 L p .418 0 .089 r
F P
0 g
s
.50158 .48444 m .50069 .48632 L .49871 .48748 L p .295 0 .259 r
F P
0 g
s
.50069 .48632 m .50158 .48444 L .50367 .48322 L p .208 0 .21 r
F P
0 g
s
.51152 .4906 m .5127 .48843 L .51268 .49086 L p .981 .9 .657 r
F P
0 g
s
.51268 .49086 m .5115 .49256 L .51152 .4906 L p .981 .9 .657 r
F P
0 g
s
.51268 .50914 m .5115 .50744 L .51148 .50514 L p .98 .732 .489 r
F P
0 g
s
.5115 .50744 m .51268 .50914 L .5127 .51157 L p .981 .702 .415 r
F P
0 g
s
.48574 .50641 m .48781 .50624 L .4898 .50737 L p .439 .681 .966 r
F P
0 g
s
.48781 .50624 m .48574 .50641 L .48363 .50522 L p .418 .705 .982 r
F P
0 g
s
.50239 .51468 m .50367 .51678 L .50158 .51556 L p .208 .435 .861 r
F P
0 g
s
.50158 .51556 m .50069 .51368 L .50239 .51468 L p .208 .435 .861 r
F P
0 g
s
.50758 .47935 m .51078 .47556 L .51262 .47446 L p 0 0 0 r
F P
0 g
s
.51767 .46897 m .51262 .47446 L .51078 .47556 L p 0 0 0 r
F P
0 g
s
.47686 .49706 m .47157 .49816 L .47344 .49711 L p .155 0 0 r
F P
0 g
s
.47344 .49711 m .47832 .49624 L .47686 .49706 L p .155 0 0 r
F P
0 g
s
.51412 .48143 m .51581 .4763 L .51578 .47845 L p .92 .895 .485 r
F P
0 g
s
.51578 .47845 m .5141 .4831 L .51412 .48143 L p .92 .895 .485 r
F P
0 g
s
.5141 .5169 m .51578 .52155 L .51581 .5237 L p .92 .607 .132 r
F P
0 g
s
.51803 .53082 m .51581 .5237 L .51578 .52155 L p .915 .609 .126 r
F P
0 g
s
.47832 .50376 m .47344 .50289 L .47157 .50184 L p .155 .631 .926 r
F P
0 g
s
.4643 .50021 m .47157 .50184 L .47344 .50289 L p .133 .616 .917 r
F P
0 g
s
.50903 .52151 m .51262 .52554 L .51078 .52444 L p 0 .238 .75 r
F P
0 g
s
.51078 .52444 m .50758 .52065 L .50903 .52151 L p 0 .238 .75 r
F P
0 g
s
.49291 .49207 m .49199 .49138 L .49426 .49006 L p .475 .149 .333 r
F P
0 g
s
.49426 .49006 m .4948 .49099 L .49291 .49207 L p .475 .149 .333 r
F P
0 g
s
.4948 .49099 m .49426 .49006 L .49654 .48875 L p .447 .139 .349 r
F P
0 g
s
.51041 .49782 m .51148 .49737 L .51147 .5 L p .955 .793 .642 r
F P
0 g
s
.51147 .5 m .51041 .5 L .51041 .49782 L p .955 .793 .642 r
F P
0 g
s
.51041 .5 m .51147 .5 L .51148 .50263 L p .955 .766 .609 r
F P
0 g
s
.49668 .51011 m .49654 .51125 L .49426 .50994 L p .447 .591 .902 r
F P
0 g
s
.49426 .50994 m .4948 .50901 L .49668 .51011 L p .447 .591 .902 r
F P
0 g
s
.4948 .50901 m .49426 .50994 L .49199 .50862 L p .475 .627 .919 r
F P
0 g
s
.49654 .48875 m .49668 .48989 L .4948 .49099 L p .447 .139 .349 r
F P
0 g
s
.49668 .48989 m .49654 .48875 L .49871 .48748 L p .405 .111 .349 r
F P
0 g
s
.4911 .49311 m .4898 .49263 L .49199 .49138 L p .492 .141 .299 r
F P
0 g
s
.49199 .49138 m .49291 .49207 L .4911 .49311 L p .492 .141 .299 r
F P
0 g
s
.51042 .49574 m .51148 .49486 L .51148 .49737 L p .958 .823 .668 r
F P
0 g
s
.51148 .49737 m .51041 .49782 L .51042 .49574 L p .958 .823 .668 r
F P
0 g
s
.51148 .50263 m .51041 .50218 L .51041 .5 L p .955 .766 .609 r
F P
0 g
s
.51041 .50218 m .51148 .50263 L .51148 .50514 L p .958 .741 .568 r
F P
0 g
s
.49199 .50862 m .49291 .50793 L .4948 .50901 L p .475 .627 .919 r
F P
0 g
s
.49291 .50793 m .49199 .50862 L .4898 .50737 L p .492 .662 .937 r
F P
0 g
s
.49848 .51116 m .49871 .51252 L .49654 .51125 L p .405 .55 .887 r
F P
0 g
s
.49654 .51125 m .49668 .51011 L .49848 .51116 L p .405 .55 .887 r
F P
0 g
s
.41262 .50893 m .37623 .50882 L .37705 .50876 L p .01 0 0 r
F P
0 g
s
.37705 .50876 m .41304 .50889 L .41262 .50893 L p .01 0 0 r
F P
0 g
s
.55118 .42914 m .56907 .3979 L .56953 .39722 L p 0 0 0 r
F P
0 g
s
.53595 .41986 m .55425 .3884 L .55389 .38914 L p .619 .795 .363 r
F P
0 g
s
.55389 .38914 m .53578 .42025 L .53595 .41986 L p .619 .795 .363 r
F P
0 g
s
.41304 .49111 m .37705 .49124 L .37623 .49118 L p .01 .585 .714 r
F P
0 g
s
.53578 .57975 m .55389 .61086 L .55425 .6116 L p .619 .215 0 r
F P
0 g
s
.55142 .5712 m .56953 .60278 L .56907 .6021 L p 0 0 .359 r
F P
0 g
s
.56907 .6021 m .55118 .57086 L .55142 .5712 L p 0 0 .359 r
F P
0 g
s
.2814 .87863 m .28214 .87734 L .2842 .87857 L p .677 .131 0 r
F P
0 g
s
.28214 .87734 m .2814 .87863 L .28098 .87839 L p .681 .136 0 r
F P
0 g
s
.28098 .87839 m .28005 .87617 L .28214 .87734 L p .681 .136 0 r
F P
0 g
s
.9372 .5 m .93572 .5 L .93575 .4976 L p 0 0 .384 r
F P
0 g
s
.93572 .5 m .9372 .5 L .93721 .50048 L p 0 0 .379 r
F P
0 g
s
.93721 .50048 m .93575 .5024 L .93572 .5 L p 0 0 .379 r
F P
0 g
s
.2814 .12137 m .28214 .12266 L .28005 .12383 L p .681 .976 .896 r
F P
0 g
s
.28214 .12266 m .2814 .12137 L .28181 .12113 L p .677 .975 .898 r
F P
0 g
s
.28181 .12113 m .2842 .12143 L .28214 .12266 L p .677 .975 .898 r
F P
0 g
s
.28181 .87887 m .2842 .87857 L .28615 .8798 L p .672 .124 0 r
F P
0 g
s
.2842 .87857 m .28181 .87887 L .2814 .87863 L p .677 .131 0 r
F P
0 g
s
.28005 .87617 m .28098 .87839 L .28058 .87818 L p .683 .138 0 r
F P
0 g
s
.28058 .87818 m .27801 .8751 L .28005 .87617 L p .683 .138 0 r
F P
0 g
s
.93575 .5024 m .93721 .50048 L .93722 .50093 L p 0 0 .372 r
F P
0 g
s
.93722 .50093 m .93584 .5047 L .93575 .5024 L p 0 0 .372 r
F P
0 g
s
.93721 .49952 m .93575 .4976 L .93584 .4953 L p 0 0 .385 r
F P
0 g
s
.93575 .4976 m .93721 .49952 L .9372 .5 L p 0 0 .384 r
F P
0 g
s
.28098 .12161 m .28005 .12383 L .27801 .1249 L p .683 .977 .893 r
F P
0 g
s
.28005 .12383 m .28098 .12161 L .2814 .12137 L p .681 .976 .896 r
F P
0 g
s
.2842 .12143 m .28181 .12113 L .2822 .12089 L p .672 .973 .899 r
F P
0 g
s
.2822 .12089 m .28615 .1202 L .2842 .12143 L p .672 .973 .899 r
F P
0 g
s
.48944 .49404 m .48781 .49376 L .4898 .49263 L p .496 .114 .245 r
F P
0 g
s
.4898 .49263 m .4911 .49311 L .48944 .49404 L p .496 .114 .245 r
F P
0 g
s
.49871 .48748 m .49848 .48884 L .49668 .48989 L p .405 .111 .349 r
F P
0 g
s
.49848 .48884 m .49871 .48748 L .50069 .48632 L p .346 .062 .332 r
F P
0 g
s
.51044 .49384 m .5115 .49256 L .51148 .49486 L p .963 .857 .688 r
F P
0 g
s
.51148 .49486 m .51042 .49574 L .51044 .49384 L p .963 .857 .688 r
F P
0 g
s
.51148 .50514 m .51042 .50426 L .51041 .50218 L p .958 .741 .568 r
F P
0 g
s
.51042 .50426 m .51148 .50514 L .5115 .50744 L p .963 .716 .515 r
F P
0 g
s
.4898 .50737 m .4911 .50689 L .49291 .50793 L p .492 .662 .937 r
F P
0 g
s
.4911 .50689 m .4898 .50737 L .48781 .50624 L p .496 .696 .958 r
F P
0 g
s
.50012 .51212 m .50069 .51368 L .49871 .51252 L p .346 .503 .871 r
F P
0 g
s
.49871 .51252 m .49848 .51116 L .50012 .51212 L p .346 .503 .871 r
F P
0 g
s
.25381 .85761 m .27211 .8727 L .27152 .8727 L p .726 .196 0 r
F P
0 g
s
.27152 .8727 m .25192 .85758 L .25381 .85761 L p .726 .196 0 r
F P
0 g
s
.91762 .41555 m .93371 .46394 L .93279 .46559 L p 0 .038 .59 r
F P
0 g
s
.93671 .489 m .93279 .46559 L .93371 .46394 L p 0 0 .434 r
F P
0 g
s
.93279 .46559 m .93671 .489 L .93644 .48999 L p 0 0 .467 r
F P
0 g
s
.36433 .9039 m .31437 .89363 L .3134 .89201 L p .545 0 0 r
F P
0 g
s
.29117 .88371 m .3134 .89201 L .31437 .89363 L p .602 .036 0 r
F P
0 g
s
.3134 .89201 m .29117 .88371 L .29045 .88297 L p .637 .085 0 r
F P
0 g
s
.93279 .53441 m .93671 .511 L .93701 .51151 L p 0 0 .291 r
F P
0 g
s
.93701 .51151 m .93371 .53606 L .93279 .53441 L p 0 0 .291 r
F P
0 g
s
.21805 .18056 m .25192 .14242 L .25381 .14239 L p .838 .999 .806 r
F P
0 g
s
.27211 .1273 m .25381 .14239 L .25192 .14242 L p .726 .99 .849 r
F P
0 g
s
.25381 .14239 m .27211 .1273 L .27311 .12704 L p .747 .992 .871 r
F P
0 g
s
.3134 .10799 m .29117 .11629 L .29147 .11578 L p .602 .947 .921 r
F P
0 g
s
.29147 .11578 m .31437 .10637 L .3134 .10799 L p .602 .947 .921 r
F P
0 g
s
.27801 .8751 m .28058 .87818 L .28021 .878 L p .683 .137 0 r
F P
0 g
s
.28021 .878 m .27612 .87419 L .27801 .8751 L p .683 .137 0 r
F P
0 g
s
.93722 .49907 m .93584 .4953 L .93599 .49321 L p 0 0 .384 r
F P
0 g
s
.93584 .4953 m .93722 .49907 L .93721 .49952 L p 0 0 .385 r
F P
0 g
s
.2822 .87911 m .28615 .8798 L .28788 .88098 L p .665 .114 0 r
F P
0 g
s
.28615 .8798 m .2822 .87911 L .28181 .87887 L p .672 .124 0 r
F P
0 g
s
.93584 .5047 m .93722 .50093 L .93725 .50135 L p 0 0 .363 r
F P
0 g
s
.93725 .50135 m .93599 .50679 L .93584 .5047 L p 0 0 .363 r
F P
0 g
s
.28058 .12182 m .27801 .1249 L .27612 .12581 L p .683 .978 .888 r
F P
0 g
s
.27801 .1249 m .28058 .12182 L .28098 .12161 L p .683 .977 .893 r
F P
0 g
s
.28615 .1202 m .2822 .12089 L .28254 .12065 L p .665 .971 .899 r
F P
0 g
s
.28254 .12065 m .28788 .11902 L .28615 .1202 L p .665 .971 .899 r
F P
0 g
s
.48474 .49549 m .48196 .49573 L .48363 .49478 L p .367 0 0 r
F P
0 g
s
.48363 .49478 m .4861 .49473 L .48474 .49549 L p .367 0 0 r
F P
0 g
s
.50367 .48322 m .50239 .48532 L .50069 .48632 L p .208 0 .21 r
F P
0 g
s
.50239 .48532 m .50367 .48322 L .50532 .48224 L p .083 0 .125 r
F P
0 g
s
.50758 .47935 m .50532 .48224 L .50367 .48322 L p .038 0 .05 r
F P
0 g
s
.51153 .48903 m .51272 .48651 L .5127 .48843 L p .972 .928 .638 r
F P
0 g
s
.5127 .48843 m .51152 .4906 L .51153 .48903 L p .972 .928 .638 r
F P
0 g
s
.5127 .51157 m .51152 .5094 L .5115 .50744 L p .981 .702 .415 r
F P
0 g
s
.51152 .5094 m .5127 .51157 L .51272 .51349 L p .972 .66 .31 r
F P
0 g
s
.5141 .5169 m .51272 .51349 L .5127 .51157 L p .972 .669 .285 r
F P
0 g
s
.48363 .50522 m .4861 .50527 L .48781 .50624 L p .418 .705 .982 r
F P
0 g
s
.4861 .50527 m .48363 .50522 L .48196 .50427 L p .367 .719 .988 r
F P
0 g
s
.47832 .50376 m .48196 .50427 L .48363 .50522 L p .302 .686 .976 r
F P
0 g
s
.50373 .51547 m .50532 .51776 L .50367 .51678 L p .083 .353 .824 r
F P
0 g
s
.50367 .51678 m .50239 .51468 L .50373 .51547 L p .083 .353 .824 r
F P
0 g
s
.49369 .49275 m .49291 .49207 L .4948 .49099 L p .521 .219 .395 r
F P
0 g
s
.4948 .49099 m .49529 .49184 L .49369 .49275 L p .521 .219 .395 r
F P
0 g
s
.49529 .49184 m .4948 .49099 L .49668 .48989 L p .492 .209 .412 r
F P
0 g
s
.50943 .49816 m .51041 .49782 L .51041 .5 L p .931 .774 .665 r
F P
0 g
s
.51041 .5 m .50943 .5 L .50943 .49816 L p .931 .774 .665 r
F P
0 g
s
.50943 .5 m .51041 .5 L .51041 .50218 L p .931 .746 .631 r
F P
0 g
s
.49688 .50909 m .49668 .51011 L .4948 .50901 L p .492 .595 .884 r
F P
0 g
s
.4948 .50901 m .49529 .50816 L .49688 .50909 L p .492 .595 .884 r
F P
0 g
s
.49529 .50816 m .4948 .50901 L .49291 .50793 L p .521 .632 .901 r
F P
0 g
s
.50069 .48632 m .50012 .48788 L .49848 .48884 L p .346 .062 .332 r
F P
0 g
s
.50012 .48788 m .50069 .48632 L .50239 .48532 L p .26 0 .29 r
F P
0 g
s
.48802 .49484 m .4861 .49473 L .48781 .49376 L p .482 .06 .161 r
F P
0 g
s
.48781 .49376 m .48944 .49404 L .48802 .49484 L p .482 .06 .161 r
F P
0 g
s
.51046 .49221 m .51152 .4906 L .5115 .49256 L p .968 .895 .698 r
F P
0 g
s
.5115 .49256 m .51044 .49384 L .51046 .49221 L p .968 .895 .698 r
F P
0 g
s
.5115 .50744 m .51044 .50616 L .51042 .50426 L p .963 .716 .515 r
F P
0 g
s
.51044 .50616 m .5115 .50744 L .51152 .5094 L p .968 .686 .442 r
F P
0 g
s
.48781 .50624 m .48944 .50596 L .4911 .50689 L p .496 .696 .958 r
F P
0 g
s
.48944 .50596 m .48781 .50624 L .4861 .50527 L p .482 .727 .979 r
F P
0 g
s
.50152 .51295 m .50239 .51468 L .50069 .51368 L p .26 .442 .851 r
F P
0 g
s
.50069 .51368 m .50012 .51212 L .50152 .51295 L p .26 .442 .851 r
F P
0 g
s
.4643 .49979 m .47157 .49816 L .47059 .4987 L p 0 0 0 r
F P
0 g
s
.51803 .46918 m .51581 .4763 L .51583 .47518 L p .82 .828 .352 r
F P
0 g
s
.51767 .53103 m .51262 .52554 L .51358 .52612 L p 0 .111 .634 r
F P
0 g
s
.49215 .49362 m .4911 .49311 L .49291 .49207 L p .541 .214 .363 r
F P
0 g
s
.49291 .49207 m .49369 .49275 L .49215 .49362 L p .541 .214 .363 r
F P
0 g
s
.49668 .48989 m .49688 .49091 L .49529 .49184 L p .492 .209 .412 r
F P
0 g
s
.49688 .49091 m .49668 .48989 L .49848 .48884 L p .451 .183 .415 r
F P
0 g
s
.51041 .50218 m .50943 .50184 L .50943 .5 L p .931 .746 .631 r
F P
0 g
s
.50943 .50184 m .51041 .50218 L .51042 .50426 L p .934 .72 .59 r
F P
0 g
s
.50945 .49639 m .51042 .49574 L .51041 .49782 L p .934 .805 .694 r
F P
0 g
s
.51041 .49782 m .50943 .49816 L .50945 .49639 L p .934 .805 .694 r
F P
0 g
s
.49291 .50793 m .49369 .50725 L .49529 .50816 L p .521 .632 .901 r
F P
0 g
s
.49369 .50725 m .49291 .50793 L .4911 .50689 L p .541 .669 .921 r
F P
0 g
s
.4984 .50998 m .49848 .51116 L .49668 .51011 L p .451 .554 .869 r
F P
0 g
s
.49668 .51011 m .49688 .50909 L .4984 .50998 L p .451 .554 .869 r
F P
0 g
s
.50532 .48224 m .50758 .47935 L .50903 .47849 L p 0 0 0 r
F P
0 g
s
.51262 .47446 m .50903 .47849 L .50758 .47935 L p 0 0 0 r
F P
0 g
s
.48079 .49638 m .47686 .49706 L .47832 .49624 L p .203 0 0 r
F P
0 g
s
.47832 .49624 m .48196 .49573 L .48079 .49638 L p .203 0 0 r
F P
0 g
s
.51274 .48518 m .51412 .48143 L .5141 .4831 L p .928 .913 .525 r
F P
0 g
s
.5141 .4831 m .51272 .48651 L .51274 .48518 L p .928 .913 .525 r
F P
0 g
s
.51272 .51349 m .5141 .5169 L .51412 .51857 L p .928 .602 .144 r
F P
0 g
s
.51581 .5237 m .51412 .51857 L .5141 .5169 L p .92 .607 .132 r
F P
0 g
s
.48196 .50427 m .47832 .50376 L .47686 .50294 L p .203 .663 .944 r
F P
0 g
s
.47157 .50184 m .47686 .50294 L .47832 .50376 L p .155 .631 .926 r
F P
0 g
s
.50647 .51844 m .50903 .52151 L .50758 .52065 L p 0 .238 .753 r
F P
0 g
s
.50758 .52065 m .50532 .51776 L .50647 .51844 L p 0 .238 .753 r
F P
0 g
s
.93599 .50679 m .93725 .50135 L .93729 .5017 L p 0 0 .352 r
F P
0 g
s
.93729 .5017 m .93619 .50859 L .93599 .50679 L p 0 0 .352 r
F P
0 g
s
.27612 .87419 m .28021 .878 L .27988 .87786 L p .681 .134 0 r
F P
0 g
s
.27988 .87786 m .27447 .87346 L .27612 .87419 L p .681 .134 0 r
F P
0 g
s
.93725 .49865 m .93599 .49321 L .93619 .49141 L p 0 0 .38 r
F P
0 g
s
.93599 .49321 m .93725 .49865 L .93722 .49907 L p 0 0 .384 r
F P
0 g
s
.28254 .87935 m .28788 .88098 L .28934 .88205 L p .656 .102 0 r
F P
0 g
s
.28788 .88098 m .28254 .87935 L .2822 .87911 L p .665 .114 0 r
F P
0 g
s
.28788 .11902 m .28254 .12065 L .28283 .12044 L p .656 .969 .897 r
F P
0 g
s
.28283 .12044 m .28934 .11795 L .28788 .11902 L p .656 .969 .897 r
F P
0 g
s
.28021 .122 m .27612 .12581 L .27447 .12654 L p .681 .978 .883 r
F P
0 g
s
.27612 .12581 m .28021 .122 L .28058 .12182 L p .683 .978 .888 r
F P
0 g
s
.49075 .49441 m .48944 .49404 L .4911 .49311 L p .55 .191 .313 r
F P
0 g
s
.4911 .49311 m .49215 .49362 L .49075 .49441 L p .55 .191 .313 r
F P
0 g
s
.49848 .48884 m .4984 .49002 L .49688 .49091 L p .451 .183 .415 r
F P
0 g
s
.4984 .49002 m .49848 .48884 L .50012 .48788 L p .394 .138 .403 r
F P
0 g
s
.50947 .49479 m .51044 .49384 L .51042 .49574 L p .94 .841 .718 r
F P
0 g
s
.51042 .49574 m .50945 .49639 L .50947 .49479 L p .94 .841 .718 r
F P
0 g
s
.51042 .50426 m .50945 .50361 L .50943 .50184 L p .934 .72 .59 r
F P
0 g
s
.50945 .50361 m .51042 .50426 L .51044 .50616 L p .94 .694 .538 r
F P
0 g
s
.4911 .50689 m .49215 .50638 L .49369 .50725 L p .541 .669 .921 r
F P
0 g
s
.49215 .50638 m .4911 .50689 L .48944 .50596 L p .55 .706 .943 r
F P
0 g
s
.49978 .51081 m .50012 .51212 L .49848 .51116 L p .394 .506 .854 r
F P
0 g
s
.49848 .51116 m .4984 .50998 L .49978 .51081 L p .394 .506 .854 r
F P
0 g
s
.86946 .34675 m .91975 .41512 L .91762 .41555 L p 0 .127 .673 r
F P
0 g
s
.93371 .46394 m .91762 .41555 L .91975 .41512 L p 0 0 .502 r
F P
0 g
s
.21805 .81944 m .25192 .85758 L .25138 .85835 L p .779 .287 0 r
F P
0 g
s
.25138 .85835 m .21661 .82107 L .21805 .81944 L p .779 .287 0 r
F P
0 g
s
.44799 .89659 m .36364 .90596 L .36433 .9039 L p .208 0 0 r
F P
0 g
s
.31437 .89363 m .36433 .9039 L .36364 .90596 L p .444 0 0 r
F P
0 g
s
.91762 .58445 m .93371 .53606 L .93465 .53613 L p 0 0 .115 r
F P
0 g
s
.93465 .53613 m .91975 .58488 L .91762 .58445 L p 0 0 .115 r
F P
0 g
s
.18255 .25666 m .21661 .17893 L .21805 .18056 L p .88 .926 .539 r
F P
0 g
s
.25192 .14242 m .21805 .18056 L .21661 .17893 L p .779 .986 .737 r
F P
0 g
s
.36433 .0961 m .31437 .10637 L .31397 .10551 L p .444 .87 .93 r
F P
0 g
s
.31397 .10551 m .36364 .09404 L .36433 .0961 L p .444 .87 .93 r
F P
0 g
s
.49436 .49342 m .49369 .49275 L .49529 .49184 L p .561 .283 .451 r
F P
0 g
s
.49529 .49184 m .49575 .49263 L .49436 .49342 L p .561 .283 .451 r
F P
0 g
s
.49575 .49263 m .49529 .49184 L .49688 .49091 L p .532 .273 .468 r
F P
0 g
s
.50852 .49841 m .50943 .49816 L .50943 .5 L p .904 .752 .683 r
F P
0 g
s
.50943 .5 m .50851 .5 L .50852 .49841 L p .904 .752 .683 r
F P
0 g
s
.50851 .5 m .50943 .5 L .50943 .50184 L p .904 .724 .648 r
F P
0 g
s
.49712 .50817 m .49688 .50909 L .49529 .50816 L p .532 .595 .863 r
F P
0 g
s
.49529 .50816 m .49575 .50737 L .49712 .50817 L p .532 .595 .863 r
F P
0 g
s
.49575 .50737 m .49529 .50816 L .49369 .50725 L p .561 .634 .88 r
F P
0 g
s
.43637 .50604 m .41262 .50893 L .41304 .50889 L p .087 .644 .703 r
F P
0 g
s
.41304 .50889 m .43659 .50602 L .43637 .50604 L p .087 .644 .703 r
F P
0 g
s
.56953 .39722 m .55142 .4288 L .55118 .42914 L p 0 0 0 r
F P
0 g
s
.53692 .44809 m .55118 .42914 L .55142 .4288 L p .566 .81 .426 r
F P
0 g
s
.52659 .44187 m .53595 .41986 L .53578 .42025 L p 0 0 0 r
F P
0 g
s
.53578 .42025 m .5265 .44207 L .52659 .44187 L p 0 0 0 r
F P
0 g
s
.37623 .49118 m .41262 .49107 L .41304 .49111 L p .01 .585 .714 r
F P
0 g
s
.43659 .49398 m .41304 .49111 L .41262 .49107 L p .087 0 0 r
F P
0 g
s
.55425 .6116 m .53595 .58014 L .53578 .57975 L p .619 .215 0 r
F P
0 g
s
.5265 .55793 m .53578 .57975 L .53595 .58014 L p 0 0 .278 r
F P
0 g
s
.53705 .55209 m .55142 .5712 L .55118 .57086 L p .566 .115 0 r
F P
0 g
s
.55118 .57086 m .53692 .55191 L .53705 .55209 L p .566 .115 0 r
F P
0 g
s
.48689 .49547 m .48474 .49549 L .4861 .49473 L p .441 0 .034 r
F P
0 g
s
.4861 .49473 m .48802 .49484 L .48689 .49547 L p .441 0 .034 r
F P
0 g
s
.50239 .48532 m .50152 .48705 L .50012 .48788 L p .26 0 .29 r
F P
0 g
s
.50152 .48705 m .50239 .48532 L .50373 .48453 L p .135 0 .211 r
F P
0 g
s
.50532 .48224 m .50373 .48453 L .50239 .48532 L p .083 0 .125 r
F P
0 g
s
.51048 .49092 m .51153 .48903 L .51152 .4906 L p .966 .933 .691 r
F P
0 g
s
.51152 .4906 m .51046 .49221 L .51048 .49092 L p .966 .933 .691 r
F P
0 g
s
.51152 .5094 m .51046 .50779 L .51044 .50616 L p .968 .686 .442 r
F P
0 g
s
.51046 .50779 m .51152 .5094 L .51153 .51097 L p .966 .645 .337 r
F P
0 g
s
.51272 .51349 m .51153 .51097 L .51152 .5094 L p .972 .66 .31 r
F P
0 g
s
.4861 .50527 m .48802 .50516 L .48944 .50596 L p .482 .727 .979 r
F P
0 g
s
.48802 .50516 m .4861 .50527 L .48474 .50451 L p .441 .752 .994 r
F P
0 g
s
.48196 .50427 m .48474 .50451 L .4861 .50527 L p .367 .719 .988 r
F P
0 g
s
.50263 .51362 m .50373 .51547 L .50239 .51468 L p .135 .358 .817 r
F P
0 g
s
.50239 .51468 m .50152 .51295 L .50263 .51362 L p .135 .358 .817 r
F P
0 g
s
.49688 .49091 m .49712 .49183 L .49575 .49263 L p .532 .273 .468 r
F P
0 g
s
.49712 .49183 m .49688 .49091 L .4984 .49002 L p .492 .249 .474 r
F P
0 g
s
.49303 .49417 m .49215 .49362 L .49369 .49275 L p .583 .281 .421 r
F P
0 g
s
.49369 .49275 m .49436 .49342 L .49303 .49417 L p .583 .281 .421 r
F P
0 g
s
.50943 .50184 m .50852 .50159 L .50851 .5 L p .904 .724 .648 r
F P
0 g
s
.50852 .50159 m .50943 .50184 L .50945 .50361 L p .907 .697 .608 r
F P
0 g
s
.50854 .49688 m .50945 .49639 L .50943 .49816 L p .907 .784 .713 r
F P
0 g
s
.50943 .49816 m .50852 .49841 L .50854 .49688 L p .907 .784 .713 r
F P
0 g
s
.49369 .50725 m .49436 .50658 L .49575 .50737 L p .561 .634 .88 r
F P
0 g
s
.49436 .50658 m .49369 .50725 L .49215 .50638 L p .583 .672 .9 r
F P
0 g
s
.49843 .50895 m .4984 .50998 L .49688 .50909 L p .492 .554 .848 r
F P
0 g
s
.49688 .50909 m .49712 .50817 L .49843 .50895 L p .492 .554 .848 r
F P
0 g
s
.50012 .48788 m .49978 .48919 L .4984 .49002 L p .394 .138 .403 r
F P
0 g
s
.49978 .48919 m .50012 .48788 L .50152 .48705 L p .312 .065 .369 r
F P
0 g
s
.48955 .49507 m .48802 .49484 L .48944 .49404 L p .545 .145 .234 r
F P
0 g
s
.48944 .49404 m .49075 .49441 L .48955 .49507 L p .545 .145 .234 r
F P
0 g
s
.50949 .49341 m .51046 .49221 L .51044 .49384 L p .948 .884 .736 r
F P
0 g
s
.51044 .49384 m .50947 .49479 L .50949 .49341 L p .948 .884 .736 r
F P
0 g
s
.51044 .50616 m .50947 .50521 L .50945 .50361 L p .94 .694 .538 r
F P
0 g
s
.50947 .50521 m .51044 .50616 L .51046 .50779 L p .948 .664 .467 r
F P
0 g
s
.48944 .50596 m .49075 .50559 L .49215 .50638 L p .55 .706 .943 r
F P
0 g
s
.49075 .50559 m .48944 .50596 L .48802 .50516 L p .545 .745 .969 r
F P
0 g
s
.50096 .51152 m .50152 .51295 L .50012 .51212 L p .312 .445 .834 r
F P
0 g
s
.50012 .51212 m .49978 .51081 L .50096 .51152 L p .312 .445 .834 r
F P
0 g
s
.93729 .4983 m .93619 .49141 L .93644 .48999 L p 0 0 .374 r
F P
0 g
s
.93619 .49141 m .93729 .4983 L .93725 .49865 L p 0 0 .38 r
F P
0 g
s
.27447 .87346 m .27988 .87786 L .27961 .87776 L p .677 .128 0 r
F P
0 g
s
.27961 .87776 m .27311 .87296 L .27447 .87346 L p .677 .128 0 r
F P
0 g
s
.28283 .87956 m .28934 .88205 L .29045 .88297 L p .646 .089 0 r
F P
0 g
s
.28934 .88205 m .28283 .87956 L .28254 .87935 L p .656 .102 0 r
F P
0 g
s
.93619 .50859 m .93729 .5017 L .93734 .50199 L p 0 0 .339 r
F P
0 g
s
.93734 .50199 m .93644 .51001 L .93619 .50859 L p 0 0 .339 r
F P
0 g
s
.27988 .12214 m .27447 .12654 L .27311 .12704 L p .677 .977 .876 r
F P
0 g
s
.27447 .12654 m .27988 .12214 L .28021 .122 L p .681 .978 .883 r
F P
0 g
s
.28934 .11795 m .28283 .12044 L .28305 .12026 L p .646 .967 .894 r
F P
0 g
s
.28305 .12026 m .29045 .11703 L .28934 .11795 L p .646 .967 .894 r
F P
0 g
s
.50373 .48453 m .50532 .48224 L .50647 .48156 L p 0 0 0 r
F P
0 g
s
.50903 .47849 m .50647 .48156 L .50532 .48224 L p 0 0 0 r
F P
0 g
s
.48379 .49602 m .48079 .49638 L .48196 .49573 L p .271 0 0 r
F P
0 g
s
.48196 .49573 m .48474 .49549 L .48379 .49602 L p .271 0 0 r
F P
0 g
s
.51155 .48795 m .51274 .48518 L .51272 .48651 L p .935 .935 .581 r
F P
0 g
s
.51272 .48651 m .51153 .48903 L .51155 .48795 L p .935 .935 .581 r
F P
0 g
s
.51153 .51097 m .51272 .51349 L .51274 .51482 L p .935 .592 .161 r
F P
0 g
s
.51412 .51857 m .51274 .51482 L .51272 .51349 L p .928 .602 .144 r
F P
0 g
s
.48474 .50451 m .48196 .50427 L .48079 .50362 L p .271 .706 .965 r
F P
0 g
s
.47686 .50294 m .48079 .50362 L .48196 .50427 L p .203 .663 .944 r
F P
0 g
s
.50466 .51603 m .50647 .51844 L .50532 .51776 L p 0 .237 .754 r
F P
0 g
s
.50532 .51776 m .50373 .51547 L .50466 .51603 L p 0 .237 .754 r
F P
0 g
s
.4984 .49002 m .49843 .49105 L .49712 .49183 L p .492 .249 .474 r
F P
0 g
s
.49843 .49105 m .4984 .49002 L .49978 .48919 L p .438 .209 .467 r
F P
0 g
s
.49182 .49483 m .49075 .49441 L .49215 .49362 L p .598 .264 .375 r
F P
0 g
s
.49215 .49362 m .49303 .49417 L .49182 .49483 L p .598 .264 .375 r
F P
0 g
s
.50857 .4955 m .50947 .49479 L .50945 .49639 L p .913 .821 .742 r
F P
0 g
s
.50945 .49639 m .50854 .49688 L .50857 .4955 L p .913 .821 .742 r
F P
0 g
s
.50945 .50361 m .50854 .50312 L .50852 .50159 L p .907 .697 .608 r
F P
0 g
s
.50854 .50312 m .50945 .50361 L .50947 .50521 L p .913 .67 .557 r
F P
0 g
s
.49215 .50638 m .49303 .50583 L .49436 .50658 L p .583 .672 .9 r
F P
0 g
s
.49303 .50583 m .49215 .50638 L .49075 .50559 L p .598 .712 .924 r
F P
0 g
s
.49962 .50967 m .49978 .51081 L .4984 .50998 L p .438 .506 .832 r
F P
0 g
s
.4984 .50998 m .49843 .50895 L .49962 .50967 L p .438 .506 .832 r
F P
0 g
s
.47609 .49748 m .47059 .4987 L .47157 .49816 L p .014 0 0 r
F P
0 g
s
.47157 .49816 m .47686 .49706 L .47609 .49748 L p .014 0 0 r
F P
0 g
s
.50903 .47849 m .51262 .47446 L .51358 .47388 L p 0 0 0 r
F P
0 g
s
.51413 .48056 m .51583 .47518 L .51581 .4763 L p .823 .838 .369 r
F P
0 g
s
.51581 .4763 m .51412 .48143 L .51413 .48056 L p .823 .838 .369 r
F P
0 g
s
.51412 .51857 m .51581 .5237 L .51583 .52482 L p .823 .506 0 r
F P
0 g
s
.47686 .50294 m .47157 .50184 L .47059 .5013 L p .014 .558 .836 r
F P
0 g
s
.50977 .52196 m .51358 .52612 L .51262 .52554 L p 0 .106 .634 r
F P
0 g
s
.51262 .52554 m .50903 .52151 L .50977 .52196 L p 0 .106 .634 r
F P
0 g
s
.49495 .49408 m .49436 .49342 L .49575 .49263 L p .595 .339 .499 r
F P
0 g
s
.49575 .49263 m .49618 .49339 L .49495 .49408 L p .595 .339 .499 r
F P
0 g
s
.49618 .49339 m .49575 .49263 L .49712 .49183 L p .565 .329 .517 r
F P
0 g
s
.50765 .49859 m .50852 .49841 L .50851 .5 L p .876 .729 .696 r
F P
0 g
s
.50851 .5 m .50764 .5 L .50765 .49859 L p .876 .729 .696 r
F P
0 g
s
.50764 .5 m .50851 .5 L .50852 .50159 L p .876 .701 .661 r
F P
0 g
s
.4974 .50733 m .49712 .50817 L .49575 .50737 L p .565 .594 .841 r
F P
0 g
s
.49575 .50737 m .49618 .50661 L .4974 .50733 L p .565 .594 .841 r
F P
0 g
s
.49618 .50661 m .49575 .50737 L .49436 .50658 L p .595 .633 .858 r
F P
0 g
s
.49712 .49183 m .4974 .49267 L .49618 .49339 L p .565 .329 .517 r
F P
0 g
s
.4974 .49267 m .49712 .49183 L .49843 .49105 L p .527 .308 .525 r
F P
0 g
s
.49377 .49473 m .49303 .49417 L .49436 .49342 L p .619 .34 .472 r
F P
0 g
s
.49436 .49342 m .49495 .49408 L .49377 .49473 L p .619 .34 .472 r
F P
0 g
s
.50767 .49724 m .50854 .49688 L .50852 .49841 L p .879 .761 .728 r
F P
0 g
s
.50852 .49841 m .50765 .49859 L .50767 .49724 L p .879 .761 .728 r
F P
0 g
s
.50852 .50159 m .50765 .50141 L .50764 .5 L p .876 .701 .661 r
F P
0 g
s
.50765 .50141 m .50852 .50159 L .50854 .50312 L p .879 .674 .622 r
F P
0 g
s
.49436 .50658 m .49495 .50592 L .49618 .50661 L p .595 .633 .858 r
F P
0 g
s
.49495 .50592 m .49436 .50658 L .49303 .50583 L p .619 .671 .878 r
F P
0 g
s
.49855 .50803 m .49843 .50895 L .49712 .50817 L p .527 .553 .825 r
F P
0 g
s
.49712 .50817 m .4974 .50733 L .49855 .50803 L p .527 .553 .825 r
F P
0 g
s
.49978 .48919 m .49962 .49033 L .49843 .49105 L p .438 .209 .467 r
F P
0 g
s
.49962 .49033 m .49978 .48919 L .50096 .48848 L p .361 .143 .443 r
F P
0 g
s
.50152 .48705 m .50096 .48848 L .49978 .48919 L p .312 .065 .369 r
F P
0 g
s
.49077 .4954 m .48955 .49507 L .49075 .49441 L p .601 .226 .304 r
F P
0 g
s
.49075 .49441 m .49182 .49483 L .49077 .4954 L p .601 .226 .304 r
F P
0 g
s
.5086 .49431 m .50949 .49341 L .50947 .49479 L p .922 .866 .767 r
F P
0 g
s
.50947 .49479 m .50857 .4955 L .5086 .49431 L p .922 .866 .767 r
F P
0 g
s
.50947 .50521 m .50857 .5045 L .50854 .50312 L p .913 .67 .557 r
F P
0 g
s
.50857 .5045 m .50947 .50521 L .50949 .50659 L p .922 .639 .489 r
F P
0 g
s
.51046 .50779 m .50949 .50659 L .50947 .50521 L p .948 .664 .467 r
F P
0 g
s
.49075 .50559 m .49182 .50517 L .49303 .50583 L p .598 .712 .924 r
F P
0 g
s
.49182 .50517 m .49075 .50559 L .48955 .50493 L p .601 .756 .952 r
F P
0 g
s
.48802 .50516 m .48955 .50493 L .49075 .50559 L p .545 .745 .969 r
F P
0 g
s
.50063 .51029 m .50096 .51152 L .49978 .51081 L p .36 .446 .813 r
F P
0 g
s
.49978 .51081 m .49962 .50967 L .50063 .51029 L p .36 .446 .813 r
F P
0 g
s
.48859 .4956 m .48689 .49547 L .48802 .49484 L p .516 .062 .112 r
F P
0 g
s
.48802 .49484 m .48955 .49507 L .48859 .4956 L p .516 .062 .112 r
F P
0 g
s
.50096 .48848 m .50152 .48705 L .50263 .48638 L p .189 0 .3 r
F P
0 g
s
.50373 .48453 m .50263 .48638 L .50152 .48705 L p .135 0 .211 r
F P
0 g
s
.50952 .49232 m .51048 .49092 L .51046 .49221 L p .952 .931 .741 r
F P
0 g
s
.51046 .49221 m .50949 .49341 L .50952 .49232 L p .952 .931 .741 r
F P
0 g
s
.50949 .50659 m .51046 .50779 L .51048 .50908 L p .952 .623 .364 r
F P
0 g
s
.51153 .51097 m .51048 .50908 L .51046 .50779 L p .966 .645 .337 r
F P
0 g
s
.48955 .50493 m .48802 .50516 L .48689 .50453 L p .516 .781 .992 r
F P
0 g
s
.48474 .50451 m .48689 .50453 L .48802 .50516 L p .441 .752 .994 r
F P
0 g
s
.50189 .51208 m .50263 .51362 L .50152 .51295 L p .189 .36 .804 r
F P
0 g
s
.50152 .51295 m .50096 .51152 L .50189 .51208 L p .189 .36 .804 r
F P
0 g
s
.49843 .49105 m .49855 .49197 L .4974 .49267 L p .527 .308 .525 r
F P
0 g
s
.49855 .49197 m .49843 .49105 L .49962 .49033 L p .476 .273 .524 r
F P
0 g
s
.49269 .49531 m .49182 .49483 L .49303 .49417 L p .638 .329 .431 r
F P
0 g
s
.49303 .49417 m .49377 .49473 L .49269 .49531 L p .638 .329 .431 r
F P
0 g
s
.50771 .49602 m .50857 .4955 L .50854 .49688 L p .884 .798 .76 r
F P
0 g
s
.50854 .49688 m .50767 .49724 L .50771 .49602 L p .884 .798 .76 r
F P
0 g
s
.50854 .50312 m .50767 .50276 L .50765 .50141 L p .879 .674 .622 r
F P
0 g
s
.50767 .50276 m .50854 .50312 L .50857 .5045 L p .884 .646 .573 r
F P
0 g
s
.49303 .50583 m .49377 .50527 L .49495 .50592 L p .619 .671 .878 r
F P
0 g
s
.49377 .50527 m .49303 .50583 L .49182 .50517 L p .638 .713 .902 r
F P
0 g
s
.49959 .50867 m .49962 .50967 L .49843 .50895 L p .476 .505 .808 r
F P
0 g
s
.49843 .50895 m .49855 .50803 L .49959 .50867 L p .476 .505 .808 r
F P
0 g
s
.48611 .4959 m .48379 .49602 L .48474 .49549 L p .352 0 0 r
F P
0 g
s
.48474 .49549 m .48689 .49547 L .48611 .4959 L p .352 0 0 r
F P
0 g
s
.50263 .48638 m .50373 .48453 L .50466 .48397 L p 0 0 .075 r
F P
0 g
s
.50647 .48156 m .50466 .48397 L .50373 .48453 L p 0 0 0 r
F P
0 g
s
.5105 .49002 m .51155 .48795 L .51153 .48903 L p .938 .956 .646 r
F P
0 g
s
.51153 .48903 m .51048 .49092 L .5105 .49002 L p .938 .956 .646 r
F P
0 g
s
.51048 .50908 m .51153 .51097 L .51155 .51205 L p .938 .576 .181 r
F P
0 g
s
.51274 .51482 m .51155 .51205 L .51153 .51097 L p .935 .592 .161 r
F P
0 g
s
.48689 .50453 m .48474 .50451 L .48379 .50398 L p .352 .753 .984 r
F P
0 g
s
.48079 .50362 m .48379 .50398 L .48474 .50451 L p .271 .706 .965 r
F P
0 g
s
.50339 .51408 m .50466 .51603 L .50373 .51547 L p 0 .235 .751 r
F P
0 g
s
.50373 .51547 m .50263 .51362 L .50339 .51408 L p 0 .235 .751 r
F P
0 g
s
.52644 .46014 m .53692 .44809 L .53705 .44791 L p .539 .819 .469 r
F P
0 g
s
.55142 .4288 m .53705 .44791 L .53692 .44809 L p .566 .81 .426 r
F P
0 g
s
.45214 .50297 m .43637 .50604 L .43659 .50602 L p .14 .681 .699 r
F P
0 g
s
.43659 .50602 m .45226 .50296 L .45214 .50297 L p .14 .681 .699 r
F P
0 g
s
.52136 .45707 m .52659 .44187 L .5265 .44207 L p 0 0 0 r
F P
0 g
s
.5265 .44207 m .5213 .45718 L .52136 .45707 L p 0 0 0 r
F P
0 g
s
.45226 .49704 m .43659 .49398 L .43637 .49396 L p .14 0 0 r
F P
0 g
s
.41262 .49107 m .43637 .49396 L .43659 .49398 L p .087 0 0 r
F P
0 g
s
.5213 .54282 m .5265 .55793 L .52659 .55813 L p 0 0 .235 r
F P
0 g
s
.53595 .58014 m .52659 .55813 L .5265 .55793 L p 0 0 .278 r
F P
0 g
s
.5265 .53996 m .53705 .55209 L .53692 .55191 L p .539 .061 0 r
F P
0 g
s
.53692 .55191 m .52644 .53986 L .5265 .53996 L p .539 .061 0 r
F P
0 g
s
.49548 .49474 m .49495 .49408 L .49618 .49339 L p .623 .388 .541 r
F P
0 g
s
.49618 .49339 m .4966 .49411 L .49548 .49474 L p .623 .388 .541 r
F P
0 g
s
.4966 .49411 m .49618 .49339 L .4974 .49267 L p .593 .378 .558 r
F P
0 g
s
.50681 .49872 m .50765 .49859 L .50764 .5 L p .849 .707 .706 r
F P
0 g
s
.50764 .5 m .5068 .5 L .50681 .49872 L p .849 .707 .706 r
F P
0 g
s
.5068 .5 m .50764 .5 L .50765 .50141 L p .849 .679 .671 r
F P
0 g
s
.49771 .50654 m .4974 .50733 L .49618 .50661 L p .593 .591 .819 r
F P
0 g
s
.49618 .50661 m .4966 .50589 L .49771 .50654 L p .593 .591 .819 r
F P
0 g
s
.4966 .50589 m .49618 .50661 L .49495 .50592 L p .623 .629 .836 r
F P
0 g
s
.50647 .48156 m .50903 .47849 L .50977 .47804 L p 0 0 0 r
F P
0 g
s
.51358 .47388 m .50977 .47804 L .50903 .47849 L p 0 0 0 r
F P
0 g
s
.48019 .49671 m .47609 .49748 L .47686 .49706 L p .054 0 0 r
F P
0 g
s
.47686 .49706 m .48079 .49638 L .48019 .49671 L p .054 0 0 r
F P
0 g
s
.51275 .48449 m .51413 .48056 L .51412 .48143 L p .829 .859 .406 r
F P
0 g
s
.51412 .48143 m .51274 .48518 L .51275 .48449 L p .829 .859 .406 r
F P
0 g
s
.51274 .51482 m .51412 .51857 L .51413 .51944 L p .829 .496 0 r
F P
0 g
s
.51583 .52482 m .51413 .51944 L .51412 .51857 L p .823 .506 0 r
F P
0 g
s
.48079 .50362 m .47686 .50294 L .47609 .50252 L p .054 .591 .854 r
F P
0 g
s
.47059 .5013 m .47609 .50252 L .47686 .50294 L p .014 .558 .836 r
F P
0 g
s
.50706 .5188 m .50977 .52196 L .50903 .52151 L p 0 .095 .632 r
F P
0 g
s
.50903 .52151 m .50647 .51844 L .50706 .5188 L p 0 .095 .632 r
F P
0 g
s
.4974 .49267 m .49771 .49346 L .4966 .49411 L p .593 .378 .558 r
F P
0 g
s
.49771 .49346 m .4974 .49267 L .49855 .49197 L p .557 .359 .569 r
F P
0 g
s
.4944 .49532 m .49377 .49473 L .49495 .49408 L p .649 .391 .516 r
F P
0 g
s
.49495 .49408 m .49548 .49474 L .4944 .49532 L p .649 .391 .516 r
F P
0 g
s
.50685 .49749 m .50767 .49724 L .50765 .49859 L p .851 .738 .739 r
F P
0 g
s
.50765 .49859 m .50681 .49872 L .50685 .49749 L p .851 .738 .739 r
F P
0 g
s
.50765 .50141 m .50681 .50128 L .5068 .5 L p .849 .679 .671 r
F P
0 g
s
.50681 .50128 m .50765 .50141 L .50767 .50276 L p .851 .651 .632 r
F P
0 g
s
.49495 .50592 m .49548 .50526 L .4966 .50589 L p .623 .629 .836 r
F P
0 g
s
.49548 .50526 m .49495 .50592 L .49377 .50527 L p .649 .668 .855 r
F P
0 g
s
.49874 .50719 m .49855 .50803 L .4974 .50733 L p .557 .55 .802 r
F P
0 g
s
.4974 .50733 m .49771 .50654 L .49874 .50719 L p .557 .55 .802 r
F P
0 g
s
.27311 .87296 m .27961 .87776 L .27941 .87771 L p .67 .119 0 r
F P
0 g
s
.27941 .87771 m .27211 .8727 L .27311 .87296 L p .67 .119 0 r
F P
0 g
s
.93644 .51001 m .93734 .50199 L .9374 .50218 L p 0 0 .324 r
F P
0 g
s
.9374 .50218 m .93671 .511 L .93644 .51001 L p 0 0 .324 r
F P
0 g
s
.93734 .49801 m .93644 .48999 L .93671 .489 L p 0 0 .364 r
F P
0 g
s
.93644 .48999 m .93734 .49801 L .93729 .4983 L p 0 0 .374 r
F P
0 g
s
.28305 .87974 m .29045 .88297 L .29117 .88371 L p .636 .074 0 r
F P
0 g
s
.29045 .88297 m .28305 .87974 L .28283 .87956 L p .646 .089 0 r
F P
0 g
s
.29045 .11703 m .28305 .12026 L .28319 .12011 L p .636 .964 .889 r
F P
0 g
s
.28319 .12011 m .29117 .11629 L .29045 .11703 L p .636 .964 .889 r
F P
0 g
s
.27961 .12224 m .27311 .12704 L .27211 .1273 L p .67 .976 .869 r
F P
0 g
s
.27311 .12704 m .27961 .12224 L .27988 .12214 L p .677 .977 .876 r
F P
0 g
s
.49962 .49033 m .49959 .49133 L .49855 .49197 L p .476 .273 .524 r
F P
0 g
s
.49959 .49133 m .49962 .49033 L .50063 .48971 L p .404 .216 .509 r
F P
0 g
s
.50096 .48848 m .50063 .48971 L .49962 .49033 L p .361 .143 .443 r
F P
0 g
s
.49177 .49579 m .49077 .4954 L .49182 .49483 L p .65 .3 .367 r
F P
0 g
s
.49182 .49483 m .49269 .49531 L .49177 .49579 L p .65 .3 .367 r
F P
0 g
s
.50776 .49497 m .5086 .49431 L .50857 .4955 L p .892 .844 .79 r
F P
0 g
s
.50857 .4955 m .50771 .49602 L .50776 .49497 L p .892 .844 .79 r
F P
0 g
s
.50857 .5045 m .50771 .50398 L .50767 .50276 L p .884 .646 .573 r
F P
0 g
s
.50771 .50398 m .50857 .5045 L .5086 .50569 L p .892 .612 .507 r
F P
0 g
s
.50949 .50659 m .5086 .50569 L .50857 .5045 L p .922 .639 .489 r
F P
0 g
s
.49182 .50517 m .49269 .50469 L .49377 .50527 L p .638 .713 .902 r
F P
0 g
s
.49269 .50469 m .49182 .50517 L .49077 .5046 L p .65 .76 .93 r
F P
0 g
s
.48955 .50493 m .49077 .5046 L .49182 .50517 L p .601 .756 .952 r
F P
0 g
s
.50047 .50923 m .50063 .51029 L .49962 .50967 L p .404 .444 .788 r
F P
0 g
s
.49962 .50967 m .49959 .50867 L .50047 .50923 L p .404 .444 .788 r
F P
0 g
s
.50063 .48971 m .50096 .48848 L .50189 .48792 L p .242 .036 .388 r
F P
0 g
s
.50263 .48638 m .50189 .48792 L .50096 .48848 L p .189 0 .3 r
F P
0 g
s
.48995 .49584 m .48859 .4956 L .48955 .49507 L p .586 .155 .189 r
F P
0 g
s
.48955 .49507 m .49077 .4954 L .48995 .49584 L p .586 .155 .189 r
F P
0 g
s
.50863 .49337 m .50952 .49232 L .50949 .49341 L p .929 .92 .784 r
F P
0 g
s
.50949 .49341 m .5086 .49431 L .50863 .49337 L p .929 .92 .784 r
F P
0 g
s
.5086 .50569 m .50949 .50659 L .50952 .50768 L p .929 .597 .387 r
F P
0 g
s
.51048 .50908 m .50952 .50768 L .50949 .50659 L p .952 .623 .364 r
F P
0 g
s
.49077 .5046 m .48955 .50493 L .48859 .5044 L p .586 .802 .982 r
F P
0 g
s
.48689 .50453 m .48859 .5044 L .48955 .50493 L p .516 .781 .992 r
F P
0 g
s
.50142 .51079 m .50189 .51208 L .50096 .51152 L p .242 .36 .784 r
F P
0 g
s
.50096 .51152 m .50063 .51029 L .50142 .51079 L p .242 .36 .784 r
F P
0 g
s
.49855 .49197 m .49874 .49281 L .49771 .49346 L p .557 .359 .569 r
F P
0 g
s
.49874 .49281 m .49855 .49197 L .49959 .49133 L p .509 .33 .573 r
F P
0 g
s
.49342 .49582 m .49269 .49531 L .49377 .49473 L p .671 .385 .479 r
F P
0 g
s
.49377 .49473 m .4944 .49532 L .49342 .49582 L p .671 .385 .479 r
F P
0 g
s
.50691 .49639 m .50771 .49602 L .50767 .49724 L p .855 .774 .772 r
F P
0 g
s
.50767 .49724 m .50685 .49749 L .50691 .49639 L p .855 .774 .772 r
F P
0 g
s
.50767 .50276 m .50685 .50251 L .50681 .50128 L p .851 .651 .632 r
F P
0 g
s
.50685 .50251 m .50767 .50276 L .50771 .50398 L p .854 .621 .585 r
F P
0 g
s
.49377 .50527 m .4944 .50468 L .49548 .50526 L p .649 .668 .855 r
F P
0 g
s
.4944 .50468 m .49377 .50527 L .49269 .50469 L p .671 .711 .878 r
F P
0 g
s
.49967 .50779 m .49959 .50867 L .49855 .50803 L p .509 .502 .784 r
F P
0 g
s
.49855 .50803 m .49874 .50719 L .49967 .50779 L p .509 .502 .784 r
F P
0 g
s
.49596 .4954 m .49548 .49474 L .4966 .49411 L p .646 .43 .576 r
F P
0 g
s
.4966 .49411 m .49701 .49482 L .49596 .4954 L p .646 .43 .576 r
F P
0 g
s
.49701 .49482 m .4966 .49411 L .49771 .49346 L p .617 .42 .593 r
F P
0 g
s
.506 .4988 m .50681 .49872 L .5068 .5 L p .823 .686 .712 r
F P
0 g
s
.5068 .5 m .50598 .5 L .506 .4988 L p .823 .686 .712 r
F P
0 g
s
.50598 .5 m .5068 .5 L .50681 .50128 L p .823 .658 .678 r
F P
0 g
s
.49804 .5058 m .49771 .50654 L .4966 .50589 L p .617 .587 .797 r
F P
0 g
s
.4966 .50589 m .49701 .50518 L .49804 .5058 L p .617 .587 .797 r
F P
0 g
s
.49701 .50518 m .4966 .50589 L .49548 .50526 L p .646 .625 .814 r
F P
0 g
s
.49494 .49592 m .4944 .49532 L .49548 .49474 L p .673 .436 .553 r
F P
0 g
s
.49548 .49474 m .49596 .4954 L .49494 .49592 L p .673 .436 .553 r
F P
0 g
s
.49771 .49346 m .49804 .4942 L .49701 .49482 L p .617 .42 .593 r
F P
0 g
s
.49804 .4942 m .49771 .49346 L .49874 .49281 L p .582 .404 .606 r
F P
0 g
s
.50606 .49766 m .50685 .49749 L .50681 .49872 L p .824 .715 .746 r
F P
0 g
s
.50681 .49872 m .506 .4988 L .50606 .49766 L p .824 .715 .746 r
F P
0 g
s
.50681 .50128 m .506 .5012 L .50598 .5 L p .823 .658 .678 r
F P
0 g
s
.506 .5012 m .50681 .50128 L .50685 .50251 L p .824 .63 .64 r
F P
0 g
s
.49548 .50526 m .49596 .5046 L .49701 .50518 L p .646 .625 .814 r
F P
0 g
s
.49596 .5046 m .49548 .50526 L .4944 .50468 L p .673 .664 .832 r
F P
0 g
s
.499 .50642 m .49874 .50719 L .49771 .50654 L p .582 .546 .78 r
F P
0 g
s
.49771 .50654 m .49804 .5058 L .499 .50642 L p .582 .546 .78 r
F P
0 g
s
.48793 .49596 m .48611 .4959 L .48689 .49547 L p .44 0 0 r
F P
0 g
s
.48689 .49547 m .48859 .4956 L .48793 .49596 L p .44 0 0 r
F P
0 g
s
.50189 .48792 m .50263 .48638 L .50339 .48592 L p 0 0 .173 r
F P
0 g
s
.50466 .48397 m .50339 .48592 L .50263 .48638 L p 0 0 .075 r
F P
0 g
s
.50954 .49157 m .5105 .49002 L .51048 .49092 L p .932 .97 .712 r
F P
0 g
s
.51048 .49092 m .50952 .49232 L .50954 .49157 L p .932 .97 .712 r
F P
0 g
s
.50952 .50768 m .51048 .50908 L .5105 .50998 L p .932 .553 .202 r
F P
0 g
s
.51155 .51205 m .5105 .50998 L .51048 .50908 L p .938 .576 .181 r
F P
0 g
s
.48859 .5044 m .48689 .50453 L .48611 .5041 L p .44 .8 .996 r
F P
0 g
s
.48379 .50398 m .48611 .5041 L .48689 .50453 L p .352 .753 .984 r
F P
0 g
s
.50253 .51248 m .50339 .51408 L .50263 .51362 L p 0 .231 .741 r
F P
0 g
s
.50263 .51362 m .50189 .51208 L .50253 .51248 L p 0 .231 .741 r
F P
0 g
s
.49257 .49624 m .49177 .49579 L .49269 .49531 L p .69 .367 .423 r
F P
0 g
s
.49269 .49531 m .49342 .49582 L .49257 .49624 L p .69 .367 .423 r
F P
0 g
s
.49959 .49133 m .49967 .49221 L .49874 .49281 L p .509 .33 .573 r
F P
0 g
s
.49967 .49221 m .49959 .49133 L .50047 .49077 L p .442 .281 .566 r
F P
0 g
s
.50063 .48971 m .50047 .49077 L .49959 .49133 L p .404 .216 .509 r
F P
0 g
s
.50697 .49545 m .50776 .49497 L .50771 .49602 L p .86 .819 .807 r
F P
0 g
s
.50771 .49602 m .50691 .49639 L .50697 .49545 L p .86 .819 .807 r
F P
0 g
s
.50771 .50398 m .50691 .50361 L .50685 .50251 L p .854 .621 .585 r
F P
0 g
s
.50691 .50361 m .50771 .50398 L .50776 .50503 L p .86 .586 .521 r
F P
0 g
s
.5086 .50569 m .50776 .50503 L .50771 .50398 L p .892 .612 .507 r
F P
0 g
s
.49269 .50469 m .49342 .50418 L .4944 .50468 L p .671 .711 .878 r
F P
0 g
s
.49342 .50418 m .49269 .50469 L .49177 .50421 L p .69 .76 .905 r
F P
0 g
s
.49077 .5046 m .49177 .50421 L .49269 .50469 L p .65 .76 .93 r
F P
0 g
s
.50046 .50831 m .50047 .50923 L .49959 .50867 L p .442 .441 .762 r
F P
0 g
s
.49959 .50867 m .49967 .50779 L .50046 .50831 L p .442 .441 .762 r
F P
0 g
s
.49402 .49637 m .49342 .49582 L .4944 .49532 L p .698 .435 .521 r
F P
0 g
s
.4944 .49532 m .49494 .49592 L .49402 .49637 L p .698 .435 .521 r
F P
0 g
s
.49874 .49281 m .499 .49358 L .49804 .4942 L p .582 .404 .606 r
F P
0 g
s
.499 .49358 m .49874 .49281 L .49967 .49221 L p .538 .379 .614 r
F P
0 g
s
.50614 .49664 m .50691 .49639 L .50685 .49749 L p .825 .75 .78 r
F P
0 g
s
.50685 .49749 m .50606 .49766 L .50614 .49664 L p .825 .75 .78 r
F P
0 g
s
.50685 .50251 m .50606 .50234 L .506 .5012 L p .824 .63 .64 r
F P
0 g
s
.50606 .50234 m .50685 .50251 L .50691 .50361 L p .825 .598 .595 r
F P
0 g
s
.4944 .50468 m .49494 .50408 L .49596 .5046 L p .673 .664 .832 r
F P
0 g
s
.49494 .50408 m .4944 .50468 L .49342 .50418 L p .699 .706 .853 r
F P
0 g
s
.49985 .507 m .49967 .50779 L .49874 .50719 L p .538 .499 .761 r
F P
0 g
s
.49874 .50719 m .499 .50642 L .49985 .507 L p .538 .499 .761 r
F P
0 g
s
.4833 .49629 m .48019 .49671 L .48079 .49638 L p .112 0 0 r
F P
0 g
s
.48079 .49638 m .48379 .49602 L .4833 .49629 L p .112 0 0 r
F P
0 g
s
.50466 .48397 m .50647 .48156 L .50706 .4812 L p 0 0 0 r
F P
0 g
s
.50977 .47804 m .50706 .4812 L .50647 .48156 L p 0 0 0 r
F P
0 g
s
.51156 .48739 m .51275 .48449 L .51274 .48518 L p .836 .888 .46 r
F P
0 g
s
.51274 .48518 m .51155 .48795 L .51156 .48739 L p .836 .888 .46 r
F P
0 g
s
.51155 .51205 m .51274 .51482 L .51275 .51551 L p .836 .478 0 r
F P
0 g
s
.51413 .51944 m .51275 .51551 L .51274 .51482 L p .829 .496 0 r
F P
0 g
s
.48379 .50398 m .48079 .50362 L .48019 .50329 L p .112 .638 .878 r
F P
0 g
s
.47609 .50252 m .48019 .50329 L .48079 .50362 L p .054 .591 .854 r
F P
0 g
s
.50514 .51632 m .50706 .5188 L .50647 .51844 L p 0 .079 .627 r
F P
0 g
s
.50647 .51844 m .50466 .51603 L .50514 .51632 L p 0 .079 .627 r
F P
0 g
s
.50047 .49077 m .50063 .48971 L .50142 .48921 L p .293 .12 .468 r
F P
0 g
s
.50189 .48792 m .50142 .48921 L .50063 .48971 L p .242 .036 .388 r
F P
0 g
s
.49103 .49617 m .48995 .49584 L .49077 .4954 L p .648 .243 .263 r
F P
0 g
s
.49077 .4954 m .49177 .49579 L .49103 .49617 L p .648 .243 .263 r
F P
0 g
s
.5078 .49415 m .50863 .49337 L .5086 .49431 L p .899 .902 .818 r
F P
0 g
s
.5086 .49431 m .50776 .49497 L .5078 .49415 L p .899 .902 .818 r
F P
0 g
s
.50776 .50503 m .5086 .50569 L .50863 .50663 L p .899 .567 .408 r
F P
0 g
s
.50952 .50768 m .50863 .50663 L .5086 .50569 L p .929 .597 .387 r
F P
0 g
s
.49177 .50421 m .49077 .5046 L .48995 .50416 L p .648 .815 .964 r
F P
0 g
s
.48859 .5044 m .48995 .50416 L .49077 .5046 L p .586 .802 .982 r
F P
0 g
s
.50117 .50968 m .50142 .51079 L .50063 .51029 L p .293 .358 .759 r
F P
0 g
s
.50063 .51029 m .50047 .50923 L .50117 .50968 L p .293 .358 .759 r
F P
0 g
s
.49639 .49607 m .49596 .4954 L .49701 .49482 L p .665 .467 .606 r
F P
0 g
s
.49701 .49482 m .49741 .49552 L .49639 .49607 L p .665 .467 .606 r
F P
0 g
s
.49741 .49552 m .49701 .49482 L .49804 .4942 L p .636 .457 .623 r
F P
0 g
s
.50521 .49884 m .506 .4988 L .50598 .5 L p .799 .666 .717 r
F P
0 g
s
.50598 .5 m .50517 .5 L .50521 .49884 L p .799 .666 .717 r
F P
0 g
s
.50517 .5 m .50598 .5 L .506 .5012 L p .799 .638 .683 r
F P
0 g
s
.4984 .50509 m .49804 .5058 L .49701 .50518 L p .636 .582 .777 r
F P
0 g
s
.49701 .50518 m .49741 .50448 L .4984 .50509 L p .636 .582 .777 r
F P
0 g
s
.49741 .50448 m .49701 .50518 L .49596 .5046 L p .665 .62 .794 r
F P
0 g
s
.49804 .4942 m .4984 .49491 L .49741 .49552 L p .636 .457 .623 r
F P
0 g
s
.4984 .49491 m .49804 .4942 L .499 .49358 L p .604 .443 .637 r
F P
0 g
s
.4954 .49655 m .49494 .49592 L .49596 .4954 L p .693 .474 .586 r
F P
0 g
s
.49596 .4954 m .49639 .49607 L .4954 .49655 L p .693 .474 .586 r
F P
0 g
s
.50529 .49775 m .50606 .49766 L .506 .4988 L p .798 .694 .749 r
F P
0 g
s
.506 .4988 m .50521 .49884 L .50529 .49775 L p .798 .694 .749 r
F P
0 g
s
.506 .5012 m .50521 .50116 L .50517 .5 L p .799 .638 .683 r
F P
0 g
s
.50521 .50116 m .506 .5012 L .50606 .50234 L p .798 .61 .647 r
F P
0 g
s
.49596 .5046 m .49639 .50393 L .49741 .50448 L p .665 .62 .794 r
F P
0 g
s
.49639 .50393 m .49596 .5046 L .49494 .50408 L p .693 .657 .81 r
F P
0 g
s
.49931 .50571 m .499 .50642 L .49804 .5058 L p .604 .543 .759 r
F P
0 g
s
.49804 .5058 m .4984 .50509 L .49931 .50571 L p .604 .543 .759 r
F P
0 g
s
.46293 .5005 m .45214 .50297 L .45226 .50296 L p .165 .697 .695 r
F P
0 g
s
.45226 .50296 m .463 .5005 L .46293 .5005 L p .165 .697 .695 r
F P
0 g
s
.51893 .46821 m .52644 .46014 L .5265 .46004 L p .524 .821 .488 r
F P
0 g
s
.53705 .44791 m .5265 .46004 L .52644 .46014 L p .539 .819 .469 r
F P
0 g
s
.5181 .46765 m .52136 .45707 L .5213 .45718 L p 0 0 0 r
F P
0 g
s
.5213 .45718 m .51807 .46771 L .5181 .46765 L p 0 0 0 r
F P
0 g
s
.463 .4995 m .45226 .49704 L .45214 .49703 L p .165 0 0 r
F P
0 g
s
.43637 .49396 m .45214 .49703 L .45226 .49704 L p .14 0 0 r
F P
0 g
s
.51807 .53229 m .5213 .54282 L .52136 .54293 L p 0 0 .214 r
F P
0 g
s
.52659 .55813 m .52136 .54293 L .5213 .54282 L p 0 0 .235 r
F P
0 g
s
.51896 .53185 m .5265 .53996 L .52644 .53986 L p .524 .035 0 r
F P
0 g
s
.52644 .53986 m .51893 .53179 L .51896 .53185 L p .524 .035 0 r
F P
0 g
s
.49451 .49694 m .49402 .49637 L .49494 .49592 L p .72 .477 .558 r
F P
0 g
s
.49494 .49592 m .4954 .49655 L .49451 .49694 L p .72 .477 .558 r
F P
0 g
s
.499 .49358 m .49931 .49429 L .4984 .49491 L p .604 .443 .637 r
F P
0 g
s
.49931 .49429 m .499 .49358 L .49985 .493 L p .563 .423 .649 r
F P
0 g
s
.49967 .49221 m .49985 .493 L .499 .49358 L p .538 .379 .614 r
F P
0 g
s
.5054 .49678 m .50614 .49664 L .50606 .49766 L p .797 .725 .784 r
F P
0 g
s
.50606 .49766 m .50529 .49775 L .5054 .49678 L p .797 .725 .784 r
F P
0 g
s
.49494 .50408 m .4954 .50345 L .49639 .50393 L p .693 .657 .81 r
F P
0 g
s
.4954 .50345 m .49494 .50408 L .49402 .50363 L p .72 .699 .829 r
F P
0 g
s
.49342 .50418 m .49402 .50363 L .49494 .50408 L p .699 .706 .853 r
F P
0 g
s
.50606 .50234 m .50529 .50225 L .50521 .50116 L p .798 .61 .647 r
F P
0 g
s
.50529 .50225 m .50606 .50234 L .50614 .50336 L p .797 .577 .603 r
F P
0 g
s
.50691 .50361 m .50614 .50336 L .50606 .50234 L p .825 .598 .595 r
F P
0 g
s
.50009 .50629 m .49985 .507 L .499 .50642 L p .563 .496 .738 r
F P
0 g
s
.499 .50642 m .49931 .50571 L .50009 .50629 L p .563 .496 .738 r
F P
0 g
s
.49985 .493 m .49967 .49221 L .50046 .49169 L p .476 .34 .615 r
F P
0 g
s
.50047 .49077 m .50046 .49169 L .49967 .49221 L p .442 .281 .566 r
F P
0 g
s
.49323 .49673 m .49257 .49624 L .49342 .49582 L p .723 .425 .473 r
F P
0 g
s
.49342 .49582 m .49402 .49637 L .49323 .49673 L p .723 .425 .473 r
F P
0 g
s
.50622 .49577 m .50697 .49545 L .50691 .49639 L p .828 .792 .818 r
F P
0 g
s
.50691 .49639 m .50614 .49664 L .50622 .49577 L p .828 .792 .818 r
F P
0 g
s
.50614 .50336 m .50691 .50361 L .50697 .50455 L p .828 .56 .533 r
F P
0 g
s
.50776 .50503 m .50697 .50455 L .50691 .50361 L p .86 .586 .521 r
F P
0 g
s
.49402 .50363 m .49342 .50418 L .49257 .50376 L p .723 .756 .879 r
F P
0 g
s
.49177 .50421 m .49257 .50376 L .49342 .50418 L p .69 .76 .905 r
F P
0 g
s
.50055 .5075 m .50046 .50831 L .49967 .50779 L p .476 .438 .736 r
F P
0 g
s
.49967 .50779 m .49985 .507 L .50055 .5075 L p .476 .438 .736 r
F P
0 g
s
.49679 .49676 m .49639 .49607 L .49741 .49552 L p .681 .497 .632 r
F P
0 g
s
.49741 .49552 m .49782 .49622 L .49679 .49676 L p .681 .497 .632 r
F P
0 g
s
.49782 .49622 m .49741 .49552 L .4984 .49491 L p .653 .488 .648 r
F P
0 g
s
.50441 .49884 m .50521 .49884 L .50517 .5 L p .776 .647 .719 r
F P
0 g
s
.50517 .5 m .50436 .5 L .50441 .49884 L p .776 .647 .719 r
F P
0 g
s
.50436 .5 m .50517 .5 L .50521 .50116 L p .776 .621 .687 r
F P
0 g
s
.4988 .5044 m .4984 .50509 L .49741 .50448 L p .653 .578 .758 r
F P
0 g
s
.49741 .50448 m .49782 .50378 L .4988 .5044 L p .653 .578 .758 r
F P
0 g
s
.49782 .50378 m .49741 .50448 L .49639 .50393 L p .681 .614 .774 r
F P
0 g
s
.48937 .49614 m .48793 .49596 L .48859 .4956 L p .528 .023 0 r
F P
0 g
s
.48859 .4956 m .48995 .49584 L .48937 .49614 L p .528 .023 0 r
F P
0 g
s
.50142 .48921 m .50189 .48792 L .50253 .48752 L p .051 0 .274 r
F P
0 g
s
.50339 .48592 m .50253 .48752 L .50189 .48792 L p 0 0 .173 r
F P
0 g
s
.50866 .49273 m .50954 .49157 L .50952 .49232 L p .917 .974 .774 r
F P
0 g
s
.50952 .49232 m .50863 .49337 L .50866 .49273 L p .917 .974 .774 r
F P
0 g
s
.50863 .50663 m .50952 .50768 L .50954 .50843 L p .917 .524 .223 r
F P
0 g
s
.5105 .50998 m .50954 .50843 L .50952 .50768 L p .932 .553 .202 r
F P
0 g
s
.48995 .50416 m .48859 .5044 L .48793 .50404 L p .528 .84 .999 r
F P
0 g
s
.48611 .5041 m .48793 .50404 L .48859 .5044 L p .44 .8 .996 r
F P
0 g
s
.50197 .51113 m .50253 .51248 L .50189 .51208 L p .051 .225 .723 r
F P
0 g
s
.50189 .51208 m .50142 .51079 L .50197 .51113 L p .051 .225 .723 r
F P
0 g
s
.4984 .49491 m .4988 .4956 L .49782 .49622 L p .653 .488 .648 r
F P
0 g
s
.4988 .4956 m .4984 .49491 L .49931 .49429 L p .622 .477 .663 r
F P
0 g
s
.49579 .49719 m .4954 .49655 L .49639 .49607 L p .708 .506 .614 r
F P
0 g
s
.49639 .49607 m .49679 .49676 L .49579 .49719 L p .708 .506 .614 r
F P
0 g
s
.50453 .49776 m .50529 .49775 L .50521 .49884 L p .774 .673 .751 r
F P
0 g
s
.50521 .49884 m .50441 .49884 L .50453 .49776 L p .774 .673 .751 r
F P
0 g
s
.50521 .50116 m .50441 .50116 L .50436 .5 L p .776 .621 .687 r
F P
0 g
s
.50441 .50116 m .50521 .50116 L .50529 .50225 L p .774 .592 .652 r
F P
0 g
s
.49639 .50393 m .49679 .50324 L .49782 .50378 L p .681 .614 .774 r
F P
0 g
s
.49679 .50324 m .49639 .50393 L .4954 .50345 L p .708 .65 .789 r
F P
0 g
s
.49967 .50505 m .49931 .50571 L .4984 .50509 L p .622 .539 .74 r
F P
0 g
s
.4984 .50509 m .4988 .5044 L .49967 .50505 L p .622 .539 .74 r
F P
0 g
s
.50046 .49169 m .50047 .49077 L .50117 .49032 L p .339 .199 .54 r
F P
0 g
s
.50142 .48921 m .50117 .49032 L .50047 .49077 L p .293 .12 .468 r
F P
0 g
s
.49191 .49656 m .49103 .49617 L .49177 .49579 L p .701 .324 .331 r
F P
0 g
s
.49177 .49579 m .49257 .49624 L .49191 .49656 L p .701 .324 .331 r
F P
0 g
s
.50702 .49471 m .5078 .49415 L .50776 .49497 L p .866 .877 .844 r
F P
0 g
s
.50776 .49497 m .50697 .49545 L .50702 .49471 L p .866 .877 .844 r
F P
0 g
s
.50697 .50455 m .50776 .50503 L .5078 .50585 L p .866 .536 .426 r
F P
0 g
s
.50863 .50663 m .5078 .50585 L .50776 .50503 L p .899 .567 .408 r
F P
0 g
s
.49257 .50376 m .49177 .50421 L .49103 .50383 L p .701 .82 .939 r
F P
0 g
s
.48995 .50416 m .49103 .50383 L .49177 .50421 L p .648 .815 .964 r
F P
0 g
s
.50107 .50873 m .50117 .50968 L .50047 .50923 L p .339 .354 .73 r
F P
0 g
s
.50047 .50923 m .50046 .50831 L .50107 .50873 L p .339 .354 .73 r
F P
0 g
s
.49715 .49748 m .49679 .49676 L .49782 .49622 L p .693 .524 .654 r
F P
0 g
s
.49782 .49622 m .49823 .49694 L .49715 .49748 L p .693 .524 .654 r
F P
0 g
s
.49823 .49694 m .49782 .49622 L .4988 .4956 L p .667 .515 .669 r
F P
0 g
s
.50361 .49879 m .50441 .49884 L .50436 .5 L p .756 .629 .72 r
F P
0 g
s
.50436 .5 m .50353 .5 L .50361 .49879 L p .756 .629 .72 r
F P
0 g
s
.50353 .5 m .50436 .5 L .50441 .50116 L p .756 .605 .69 r
F P
0 g
s
.49924 .50373 m .4988 .5044 L .49782 .50378 L p .667 .574 .741 r
F P
0 g
s
.49782 .50378 m .49823 .50306 L .49924 .50373 L p .667 .574 .741 r
F P
0 g
s
.49823 .50306 m .49782 .50378 L .49679 .50324 L p .693 .608 .756 r
F P
0 g
s
.49931 .49429 m .49967 .49495 L .4988 .4956 L p .622 .477 .663 r
F P
0 g
s
.49967 .49495 m .49931 .49429 L .50009 .49371 L p .585 .462 .678 r
F P
0 g
s
.49985 .493 m .50009 .49371 L .49931 .49429 L p .563 .423 .649 r
F P
0 g
s
.4949 .49753 m .49451 .49694 L .4954 .49655 L p .737 .514 .591 r
F P
0 g
s
.4954 .49655 m .49579 .49719 L .4949 .49753 L p .737 .514 .591 r
F P
0 g
s
.50469 .49682 m .5054 .49678 L .50529 .49775 L p .771 .701 .786 r
F P
0 g
s
.50529 .49775 m .50453 .49776 L .50469 .49682 L p .771 .701 .786 r
F P
0 g
s
.4954 .50345 m .49579 .50281 L .49679 .50324 L p .708 .65 .789 r
F P
0 g
s
.49579 .50281 m .4954 .50345 L .49451 .50306 L p .737 .69 .805 r
F P
0 g
s
.49402 .50363 m .49451 .50306 L .4954 .50345 L p .72 .699 .829 r
F P
0 g
s
.50529 .50225 m .50453 .50224 L .50441 .50116 L p .774 .592 .652 r
F P
0 g
s
.50453 .50224 m .50529 .50225 L .5054 .50322 L p .771 .558 .61 r
F P
0 g
s
.50614 .50336 m .5054 .50322 L .50529 .50225 L p .797 .577 .603 r
F P
0 g
s
.50041 .50565 m .50009 .50629 L .49931 .50571 L p .585 .494 .717 r
F P
0 g
s
.49931 .50571 m .49967 .50505 L .50041 .50565 L p .585 .494 .717 r
F P
0 g
s
.4857 .49612 m .4833 .49629 L .48379 .49602 L p .188 0 0 r
F P
0 g
s
.48379 .49602 m .48611 .4959 L .4857 .49612 L p .188 0 0 r
F P
0 g
s
.50339 .48592 m .50466 .48397 L .50514 .48368 L p 0 0 0 r
F P
0 g
s
.50706 .4812 m .50514 .48368 L .50466 .48397 L p 0 0 0 r
F P
0 g
s
.51051 .48956 m .51156 .48739 L .51155 .48795 L p .841 .92 .526 r
F P
0 g
s
.51155 .48795 m .5105 .49002 L .51051 .48956 L p .841 .92 .526 r
F P
0 g
s
.5105 .50998 m .51155 .51205 L .51156 .51261 L p .841 .453 0 r
F P
0 g
s
.51275 .51551 m .51156 .51261 L .51155 .51205 L p .836 .478 0 r
F P
0 g
s
.48611 .5041 m .48379 .50398 L .4833 .50371 L p .188 .694 .903 r
F P
0 g
s
.48019 .50329 m .4833 .50371 L .48379 .50398 L p .112 .638 .878 r
F P
0 g
s
.50379 .51432 m .50514 .51632 L .50466 .51603 L p 0 .057 .618 r
F P
0 g
s
.50466 .51603 m .50339 .51408 L .50379 .51432 L p 0 .057 .618 r
F P
0 g
s
.4988 .4956 m .49924 .49627 L .49823 .49694 L p .667 .515 .669 r
F P
0 g
s
.49924 .49627 m .4988 .4956 L .49967 .49495 L p .639 .507 .685 r
F P
0 g
s
.49611 .49786 m .49579 .49719 L .49679 .49676 L p .72 .535 .638 r
F P
0 g
s
.49679 .49676 m .49715 .49748 L .49611 .49786 L p .72 .535 .638 r
F P
0 g
s
.5038 .4977 m .50453 .49776 L .50441 .49884 L p .752 .653 .751 r
F P
0 g
s
.50441 .49884 m .50361 .49879 L .5038 .4977 L p .752 .653 .751 r
F P
0 g
s
.49679 .50324 m .49715 .50252 L .49823 .50306 L p .693 .608 .756 r
F P
0 g
s
.49715 .50252 m .49679 .50324 L .49579 .50281 L p .72 .641 .769 r
F P
0 g
s
.50441 .50116 m .50361 .50121 L .50353 .5 L p .756 .605 .69 r
F P
0 g
s
.50361 .50121 m .50441 .50116 L .50453 .50224 L p .752 .576 .657 r
F P
0 g
s
.50009 .50443 m .49967 .50505 L .4988 .5044 L p .639 .537 .722 r
F P
0 g
s
.4988 .5044 m .49924 .50373 L .50009 .50443 L p .639 .537 .722 r
F P
0 g
s
.25192 .85758 m .27152 .8727 L .27137 .87296 L p .695 .154 0 r
F P
0 g
s
.27137 .87296 m .25138 .85835 L .25192 .85758 L p .695 .154 0 r
F P
0 g
s
.36364 .90596 m .31397 .89449 L .31437 .89363 L p .444 0 0 r
F P
0 g
s
.29147 .88422 m .31437 .89363 L .31397 .89449 L p .563 0 0 r
F P
0 g
s
.31437 .89363 m .29147 .88422 L .29117 .88371 L p .602 .036 0 r
F P
0 g
s
.93371 .53606 m .93701 .51151 L .93731 .51152 L p 0 0 .239 r
F P
0 g
s
.93731 .51152 m .93465 .53613 L .93371 .53606 L p 0 0 .239 r
F P
0 g
s
.91975 .41512 m .93465 .46387 L .93371 .46394 L p 0 0 .502 r
F P
0 g
s
.93701 .48849 m .93371 .46394 L .93465 .46387 L p 0 0 .391 r
F P
0 g
s
.93371 .46394 m .93701 .48849 L .93671 .489 L p 0 0 .434 r
F P
0 g
s
.31437 .10637 m .29147 .11578 L .29132 .11552 L p .563 .935 .897 r
F P
0 g
s
.29132 .11552 m .31397 .10551 L .31437 .10637 L p .563 .935 .897 r
F P
0 g
s
.21661 .17893 m .25138 .14165 L .25192 .14242 L p .779 .986 .737 r
F P
0 g
s
.27152 .1273 m .25192 .14242 L .25138 .14165 L p .695 .981 .821 r
F P
0 g
s
.25192 .14242 m .27152 .1273 L .27211 .1273 L p .726 .99 .849 r
F P
0 g
s
.50009 .49371 m .49985 .493 L .50055 .4925 L p .507 .392 .657 r
F P
0 g
s
.50046 .49169 m .50055 .4925 L .49985 .493 L p .476 .34 .615 r
F P
0 g
s
.49375 .49725 m .49323 .49673 L .49402 .49637 L p .749 .475 .517 r
F P
0 g
s
.49402 .49637 m .49451 .49694 L .49375 .49725 L p .749 .475 .517 r
F P
0 g
s
.50551 .49596 m .50622 .49577 L .50614 .49664 L p .796 .764 .824 r
F P
0 g
s
.50614 .49664 m .5054 .49678 L .50551 .49596 L p .796 .764 .824 r
F P
0 g
s
.49451 .50306 m .49402 .50363 L .49323 .50327 L p .749 .748 .851 r
F P
0 g
s
.49257 .50376 m .49323 .50327 L .49402 .50363 L p .723 .756 .879 r
F P
0 g
s
.5054 .50322 m .50614 .50336 L .50622 .50423 L p .796 .536 .544 r
F P
0 g
s
.50697 .50455 m .50622 .50423 L .50614 .50336 L p .828 .56 .533 r
F P
0 g
s
.50074 .50679 m .50055 .5075 L .49985 .507 L p .507 .436 .711 r
F P
0 g
s
.49985 .507 m .50009 .50629 L .50074 .50679 L p .507 .436 .711 r
F P
0 g
s
.49747 .49824 m .49715 .49748 L .49823 .49694 L p .703 .546 .672 r
F P
0 g
s
.49823 .49694 m .49867 .4977 L .49747 .49824 L p .703 .546 .672 r
F P
0 g
s
.49867 .4977 m .49823 .49694 L .49924 .49627 L p .679 .538 .686 r
F P
0 g
s
.50279 .49868 m .50361 .49879 L .50353 .5 L p .737 .613 .72 r
F P
0 g
s
.50353 .5 m .50265 .5 L .50279 .49868 L p .737 .613 .72 r
F P
0 g
s
.50265 .5 m .50353 .5 L .50361 .50121 L p .737 .591 .692 r
F P
0 g
s
.49975 .50307 m .49924 .50373 L .49823 .50306 L p .679 .571 .726 r
F P
0 g
s
.49823 .50306 m .49867 .5023 L .49975 .50307 L p .679 .571 .726 r
F P
0 g
s
.49867 .5023 m .49823 .50306 L .49715 .50252 L p .703 .601 .74 r
F P
0 g
s
.93671 .511 m .9374 .50218 L .93746 .50228 L p 0 0 .309 r
F P
0 g
s
.93746 .50228 m .93701 .51151 L .93671 .511 L p 0 0 .309 r
F P
0 g
s
.9374 .49782 m .93671 .489 L .93701 .48849 L p 0 0 .352 r
F P
0 g
s
.93671 .489 m .9374 .49782 L .93734 .49801 L p 0 0 .364 r
F P
0 g
s
.27211 .8727 m .27941 .87771 L .2793 .87771 L p .662 .107 0 r
F P
0 g
s
.2793 .87771 m .27152 .8727 L .27211 .8727 L p .662 .107 0 r
F P
0 g
s
.28319 .87989 m .29117 .88371 L .29147 .88422 L p .624 .059 0 r
F P
0 g
s
.29117 .88371 m .28319 .87989 L .28305 .87974 L p .636 .074 0 r
F P
0 g
s
.29117 .11629 m .28319 .12011 L .28325 .12001 L p .624 .96 .882 r
F P
0 g
s
.28325 .12001 m .29147 .11578 L .29117 .11629 L p .624 .96 .882 r
F P
0 g
s
.27941 .12229 m .27211 .1273 L .27152 .1273 L p .662 .973 .861 r
F P
0 g
s
.27211 .1273 m .27941 .12229 L .27961 .12224 L p .67 .976 .869 r
F P
0 g
s
.49924 .49627 m .49975 .49693 L .49867 .4977 L p .679 .538 .686 r
F P
0 g
s
.49975 .49693 m .49924 .49627 L .50009 .49557 L p .654 .533 .704 r
F P
0 g
s
.49967 .49495 m .50009 .49557 L .49924 .49627 L p .639 .507 .685 r
F P
0 g
s
.49636 .49856 m .49611 .49786 L .49715 .49748 L p .729 .559 .66 r
F P
0 g
s
.49715 .49748 m .49747 .49824 L .49636 .49856 L p .729 .559 .66 r
F P
0 g
s
.50307 .49757 m .5038 .4977 L .50361 .49879 L p .732 .633 .749 r
F P
0 g
s
.50361 .49879 m .50279 .49868 L .50307 .49757 L p .732 .633 .749 r
F P
0 g
s
.49715 .50252 m .49747 .50176 L .49867 .5023 L p .703 .601 .74 r
F P
0 g
s
.49747 .50176 m .49715 .50252 L .49611 .50214 L p .729 .632 .75 r
F P
0 g
s
.49579 .50281 m .49611 .50214 L .49715 .50252 L p .72 .641 .769 r
F P
0 g
s
.50361 .50121 m .50279 .50132 L .50265 .5 L p .737 .591 .692 r
F P
0 g
s
.50279 .50132 m .50361 .50121 L .5038 .5023 L p .732 .563 .662 r
F P
0 g
s
.50453 .50224 m .5038 .5023 L .50361 .50121 L p .752 .576 .657 r
F P
0 g
s
.50057 .50388 m .50009 .50443 L .49924 .50373 L p .654 .536 .707 r
F P
0 g
s
.49924 .50373 m .49975 .50307 L .50057 .50388 L p .654 .536 .707 r
F P
0 g
s
.50009 .49557 m .49967 .49495 L .50041 .49435 L p .606 .497 .703 r
F P
0 g
s
.50009 .49371 m .50041 .49435 L .49967 .49495 L p .585 .462 .678 r
F P
0 g
s
.49521 .49814 m .4949 .49753 L .49579 .49719 L p .75 .546 .62 r
F P
0 g
s
.49579 .49719 m .49611 .49786 L .49521 .49814 L p .75 .546 .62 r
F P
0 g
s
.50401 .49678 m .50469 .49682 L .50453 .49776 L p .746 .677 .784 r
F P
0 g
s
.50453 .49776 m .5038 .4977 L .50401 .49678 L p .746 .677 .784 r
F P
0 g
s
.49611 .50214 m .49579 .50281 L .4949 .50247 L p .75 .679 .782 r
F P
0 g
s
.49451 .50306 m .4949 .50247 L .49579 .50281 L p .737 .69 .805 r
F P
0 g
s
.5038 .5023 m .50453 .50224 L .50469 .50318 L p .746 .541 .617 r
F P
0 g
s
.5054 .50322 m .50469 .50318 L .50453 .50224 L p .771 .558 .61 r
F P
0 g
s
.50078 .50508 m .50041 .50565 L .49967 .50505 L p .606 .493 .698 r
F P
0 g
s
.49967 .50505 m .50009 .50443 L .50078 .50508 L p .606 .493 .698 r
F P
0 g
s
.49052 .49642 m .48937 .49614 L .48995 .49584 L p .611 .128 .081 r
F P
0 g
s
.48995 .49584 m .49103 .49617 L .49052 .49642 L p .611 .128 .081 r
F P
0 g
s
.50117 .49032 m .50142 .48921 L .50197 .48887 L p .104 0 .374 r
F P
0 g
s
.50253 .48752 m .50197 .48887 L .50142 .48921 L p .051 0 .274 r
F P
0 g
s
.50783 .49358 m .50866 .49273 L .50863 .49337 L p .892 .968 .829 r
F P
0 g
s
.50863 .49337 m .5078 .49415 L .50783 .49358 L p .892 .968 .829 r
F P
0 g
s
.5078 .50585 m .50863 .50663 L .50866 .50727 L p .892 .49 .243 r
F P
0 g
s
.50954 .50843 m .50866 .50727 L .50863 .50663 L p .917 .524 .223 r
F P
0 g
s
.49103 .50383 m .48995 .50416 L .48937 .50386 L p .611 .871 .991 r
F P
0 g
s
.48793 .50404 m .48937 .50386 L .48995 .50416 L p .528 .84 .999 r
F P
0 g
s
.50164 .50999 m .50197 .51113 L .50142 .51079 L p .104 .218 .698 r
F P
0 g
s
.50142 .51079 m .50117 .50968 L .50164 .50999 L p .104 .218 .698 r
F P
0 g
s
.50055 .4925 m .50046 .49169 L .50107 .49127 L p .381 .271 .602 r
F P
0 g
s
.50117 .49032 m .50107 .49127 L .50046 .49169 L p .339 .199 .54 r
F P
0 g
s
.4926 .497 m .49191 .49656 L .49257 .49624 L p .744 .396 .392 r
F P
0 g
s
.49257 .49624 m .49323 .49673 L .4926 .497 L p .744 .396 .392 r
F P
0 g
s
.5063 .49509 m .50702 .49471 L .50697 .49545 L p .829 .848 .861 r
F P
0 g
s
.50697 .49545 m .50622 .49577 L .5063 .49509 L p .829 .848 .861 r
F P
0 g
s
.50622 .50423 m .50697 .50455 L .50702 .50529 L p .829 .506 .442 r
F P
0 g
s
.5078 .50585 m .50702 .50529 L .50697 .50455 L p .866 .536 .426 r
F P
0 g
s
.49323 .50327 m .49257 .50376 L .49191 .50344 L p .744 .819 .91 r
F P
0 g
s
.49103 .50383 m .49191 .50344 L .49257 .50376 L p .701 .82 .939 r
F P
0 g
s
.5011 .50791 m .50107 .50873 L .50046 .50831 L p .381 .351 .7 r
F P
0 g
s
.50046 .50831 m .50055 .5075 L .5011 .50791 L p .381 .351 .7 r
F P
0 g
s
.49771 .49909 m .49747 .49824 L .49867 .4977 L p .71 .564 .688 r
F P
0 g
s
.49867 .4977 m .49918 .49857 L .49771 .49909 L p .71 .564 .688 r
F P
0 g
s
.49918 .49857 m .49867 .4977 L .49975 .49693 L p .689 .557 .7 r
F P
0 g
s
.50194 .49847 m .50279 .49868 L .50265 .5 L p .722 .599 .719 r
F P
0 g
s
.50265 .5 m .50165 .5 L .50194 .49847 L p .722 .599 .719 r
F P
0 g
s
.50165 .5 m .50265 .5 L .50279 .50132 L p .721 .579 .695 r
F P
0 g
s
.50035 .50244 m .49975 .50307 L .49867 .5023 L p .689 .568 .714 r
F P
0 g
s
.49867 .5023 m .49918 .50143 L .50035 .50244 L p .689 .568 .714 r
F P
0 g
s
.49918 .50143 m .49867 .5023 L .49747 .50176 L p .71 .595 .725 r
F P
0 g
s
.49975 .49693 m .50035 .49756 L .49918 .49857 L p .689 .557 .7 r
F P
0 g
s
.50035 .49756 m .49975 .49693 L .50057 .49612 L p .669 .556 .718 r
F P
0 g
s
.50009 .49557 m .50057 .49612 L .49975 .49693 L p .654 .533 .704 r
F P
0 g
s
.49651 .49928 m .49636 .49856 L .49747 .49824 L p .735 .579 .68 r
F P
0 g
s
.49747 .49824 m .49771 .49909 L .49651 .49928 L p .735 .579 .68 r
F P
0 g
s
.50237 .49734 m .50307 .49757 L .50279 .49868 L p .714 .614 .744 r
F P
0 g
s
.50279 .49868 m .50194 .49847 L .50237 .49734 L p .714 .614 .744 r
F P
0 g
s
.49747 .50176 m .49771 .50091 L .49918 .50143 L p .71 .595 .725 r
F P
0 g
s
.49771 .50091 m .49747 .50176 L .49636 .50144 L p .735 .622 .732 r
F P
0 g
s
.49611 .50214 m .49636 .50144 L .49747 .50176 L p .729 .632 .75 r
F P
0 g
s
.50279 .50132 m .50194 .50153 L .50165 .5 L p .721 .579 .695 r
F P
0 g
s
.50194 .50153 m .50279 .50132 L .50307 .50243 L p .714 .552 .668 r
F P
0 g
s
.5038 .5023 m .50307 .50243 L .50279 .50132 L p .732 .563 .662 r
F P
0 g
s
.50112 .50338 m .50057 .50388 L .49975 .50307 L p .669 .536 .694 r
F P
0 g
s
.49975 .50307 m .50035 .50244 L .50112 .50338 L p .669 .536 .694 r
F P
0 g
s
.50041 .49435 m .50009 .49371 L .50074 .49321 L p .534 .438 .692 r
F P
0 g
s
.50055 .4925 m .50074 .49321 L .50009 .49371 L p .507 .392 .657 r
F P
0 g
s
.49416 .49778 m .49375 .49725 L .49451 .49694 L p .77 .52 .556 r
F P
0 g
s
.49451 .49694 m .4949 .49753 L .49416 .49778 L p .77 .52 .556 r
F P
0 g
s
.50484 .49605 m .50551 .49596 L .5054 .49678 L p .765 .736 .826 r
F P
0 g
s
.5054 .49678 m .50469 .49682 L .50484 .49605 L p .765 .736 .826 r
F P
0 g
s
.4949 .50247 m .49451 .50306 L .49375 .50275 L p .77 .737 .823 r
F P
0 g
s
.49323 .50327 m .49375 .50275 L .49451 .50306 L p .749 .748 .851 r
F P
0 g
s
.50469 .50318 m .5054 .50322 L .50551 .50404 L p .765 .514 .554 r
F P
0 g
s
.50622 .50423 m .50551 .50404 L .5054 .50322 L p .796 .536 .544 r
F P
0 g
s
.501 .50617 m .50074 .50679 L .50009 .50629 L p .534 .434 .687 r
F P
0 g
s
.50009 .50629 m .50041 .50565 L .501 .50617 L p .534 .434 .687 r
F P
0 g
s
.49781 .5 m .49771 .49909 L .49918 .49857 L p .714 .577 .7 r
F P
0 g
s
.49918 .49857 m .5 .49999 L .49781 .5 L p .714 .577 .7 r
F P
0 g
s
.5 .49999 m .49918 .49857 L .50035 .49756 L p .699 .573 .71 r
F P
0 g
s
.50109 .4981 m .50194 .49847 L .50165 .5 L p .71 .587 .716 r
F P
0 g
s
.50165 .5 m .50001 .5 L .50109 .4981 L p .71 .587 .716 r
F P
0 g
s
.50001 .5 m .50165 .5 L .50194 .50153 L p .709 .572 .698 r
F P
0 g
s
.50109 .5019 m .50035 .50244 L .49918 .50143 L p .698 .568 .705 r
F P
0 g
s
.49918 .50143 m .5 .50001 L .50109 .5019 L p .698 .568 .705 r
F P
0 g
s
.5 .50001 m .49918 .50143 L .49771 .50091 L p .714 .587 .713 r
F P
0 g
s
.5265 .46004 m .51896 .46815 L .51893 .46821 L p .524 .821 .488 r
F P
0 g
s
.52136 .54293 m .5181 .53235 L .51807 .53229 L p 0 0 .214 r
F P
0 g
s
.45214 .49703 m .46293 .4995 L .463 .4995 L p .165 0 0 r
F P
0 g
s
.49771 .50091 m .49781 .5 L .5 .50001 L p .714 .587 .713 r
F P
0 g
s
.50194 .50153 m .50109 .5019 L .50001 .5 L p .709 .572 .698 r
F P
0 g
s
.50035 .49756 m .50109 .4981 L .5 .49999 L p .699 .573 .71 r
F P
0 g
s
.50109 .4981 m .50035 .49756 L .50112 .49662 L p .683 .577 .73 r
F P
0 g
s
.50057 .49612 m .50112 .49662 L .50035 .49756 L p .669 .556 .718 r
F P
0 g
s
.49657 .5 m .49651 .49928 L .49771 .49909 L p .738 .596 .698 r
F P
0 g
s
.49771 .49909 m .49781 .5 L .49657 .5 L p .738 .596 .698 r
F P
0 g
s
.50172 .49703 m .50237 .49734 L .50194 .49847 L p .698 .596 .738 r
F P
0 g
s
.50194 .49847 m .50109 .4981 L .50172 .49703 L p .698 .596 .738 r
F P
0 g
s
.49781 .5 m .49771 .50091 L .49651 .50072 L p .738 .61 .715 r
F P
0 g
s
.49636 .50144 m .49651 .50072 L .49771 .50091 L p .735 .622 .732 r
F P
0 g
s
.50109 .5019 m .50194 .50153 L .50237 .50266 L p .698 .544 .674 r
F P
0 g
s
.50307 .50243 m .50237 .50266 L .50194 .50153 L p .714 .552 .668 r
F P
0 g
s
.50172 .50297 m .50112 .50338 L .50035 .50244 L p .683 .538 .683 r
F P
0 g
s
.50035 .50244 m .50109 .5019 L .50172 .50297 L p .683 .538 .683 r
F P
0 g
s
.50057 .49612 m .50009 .49557 L .50078 .49492 L p .625 .528 .724 r
F P
0 g
s
.50041 .49435 m .50078 .49492 L .50009 .49557 L p .606 .497 .703 r
F P
0 g
s
.49543 .49876 m .49521 .49814 L .49611 .49786 L p .76 .574 .646 r
F P
0 g
s
.49611 .49786 m .49636 .49856 L .49543 .49876 L p .76 .574 .646 r
F P
0 g
s
.50336 .49666 m .50401 .49678 L .5038 .4977 L p .723 .654 .78 r
F P
0 g
s
.5038 .4977 m .50307 .49757 L .50336 .49666 L p .723 .654 .78 r
F P
0 g
s
.49636 .50144 m .49611 .50214 L .49521 .50186 L p .76 .666 .759 r
F P
0 g
s
.4949 .50247 m .49521 .50186 L .49611 .50214 L p .75 .679 .782 r
F P
0 g
s
.50307 .50243 m .5038 .5023 L .50401 .50322 L p .723 .527 .625 r
F P
0 g
s
.50469 .50318 m .50401 .50322 L .5038 .5023 L p .746 .541 .617 r
F P
0 g
s
.50121 .50458 m .50078 .50508 L .50009 .50443 L p .625 .493 .681 r
F P
0 g
s
.50009 .50443 m .50057 .50388 L .50121 .50458 L p .625 .493 .681 r
F P
0 g
s
.50112 .49662 m .50172 .49703 L .50109 .4981 L p .683 .577 .73 r
F P
0 g
s
.49651 .50072 m .49657 .5 L .49781 .5 L p .738 .61 .715 r
F P
0 g
s
.50237 .50266 m .50172 .50297 L .50109 .5019 L p .698 .544 .674 r
F P
0 g
s
.50112 .49662 m .50057 .49612 L .50121 .49542 L p .644 .556 .741 r
F P
0 g
s
.50078 .49492 m .50121 .49542 L .50057 .49612 L p .625 .528 .724 r
F P
0 g
s
.49555 .49938 m .49543 .49876 L .49636 .49856 L p .766 .598 .67 r
F P
0 g
s
.49636 .49856 m .49651 .49928 L .49555 .49938 L p .766 .598 .67 r
F P
0 g
s
.50276 .49646 m .50336 .49666 L .50307 .49757 L p .701 .63 .774 r
F P
0 g
s
.50307 .49757 m .50237 .49734 L .50276 .49646 L p .701 .63 .774 r
F P
0 g
s
.49651 .50072 m .49636 .50144 L .49543 .50124 L p .766 .652 .737 r
F P
0 g
s
.49521 .50186 m .49543 .50124 L .49636 .50144 L p .76 .666 .759 r
F P
0 g
s
.50237 .50266 m .50307 .50243 L .50336 .50334 L p .701 .515 .633 r
F P
0 g
s
.50401 .50322 m .50336 .50334 L .50307 .50243 L p .723 .527 .625 r
F P
0 g
s
.50169 .50416 m .50121 .50458 L .50057 .50388 L p .644 .495 .666 r
F P
0 g
s
.50057 .50388 m .50112 .50338 L .50169 .50416 L p .644 .495 .666 r
F P
0 g
s
.50078 .49492 m .50041 .49435 L .501 .49383 L p .56 .481 .722 r
F P
0 g
s
.50074 .49321 m .501 .49383 L .50041 .49435 L p .534 .438 .692 r
F P
0 g
s
.49446 .49834 m .49416 .49778 L .4949 .49753 L p .785 .558 .592 r
F P
0 g
s
.4949 .49753 m .49521 .49814 L .49446 .49834 L p .785 .558 .592 r
F P
0 g
s
.50421 .49604 m .50484 .49605 L .50469 .49682 L p .736 .707 .824 r
F P
0 g
s
.50469 .49682 m .50401 .49678 L .50421 .49604 L p .736 .707 .824 r
F P
0 g
s
.49521 .50186 m .4949 .50247 L .49416 .50222 L p .785 .724 .795 r
F P
0 g
s
.49375 .50275 m .49416 .50222 L .4949 .50247 L p .77 .737 .823 r
F P
0 g
s
.50401 .50322 m .50469 .50318 L .50484 .50395 L p .736 .495 .564 r
F P
0 g
s
.50551 .50404 m .50484 .50395 L .50469 .50318 L p .765 .514 .554 r
F P
0 g
s
.50133 .50563 m .501 .50617 L .50041 .50565 L p .56 .434 .665 r
F P
0 g
s
.50041 .50565 m .50078 .50508 L .50133 .50563 L p .56 .434 .665 r
F P
0 g
s
.48759 .49614 m .4857 .49612 L .48611 .4959 L p .276 0 0 r
F P
0 g
s
.48611 .4959 m .48793 .49596 L .48759 .49614 L p .276 0 0 r
F P
0 g
s
.50253 .48752 m .50339 .48592 L .50379 .48568 L p 0 0 0 r
F P
0 g
s
.50514 .48368 m .50379 .48568 L .50339 .48592 L p 0 0 0 r
F P
0 g
s
.50955 .49118 m .51051 .48956 L .5105 .49002 L p .84 .952 .602 r
F P
0 g
s
.5105 .49002 m .50954 .49157 L .50955 .49118 L p .84 .952 .602 r
F P
0 g
s
.50954 .50843 m .5105 .50998 L .51051 .51044 L p .84 .421 0 r
F P
0 g
s
.51156 .51261 m .51051 .51044 L .5105 .50998 L p .841 .453 0 r
F P
0 g
s
.48793 .50404 m .48611 .5041 L .4857 .50388 L p .276 .757 .927 r
F P
0 g
s
.4833 .50371 m .4857 .50388 L .48611 .5041 L p .188 .694 .903 r
F P
0 g
s
.50286 .51268 m .50379 .51432 L .50339 .51408 L p 0 .032 .602 r
F P
0 g
s
.50339 .51408 m .50253 .51248 L .50286 .51268 L p 0 .032 .602 r
F P
0 g
s
.50074 .49321 m .50055 .4925 L .5011 .49209 L p .419 .336 .656 r
F P
0 g
s
.50107 .49127 m .5011 .49209 L .50055 .4925 L p .381 .271 .602 r
F P
0 g
s
.49315 .49747 m .4926 .497 L .49323 .49673 L p .779 .461 .448 r
F P
0 g
s
.49323 .49673 m .49375 .49725 L .49315 .49747 L p .779 .461 .448 r
F P
0 g
s
.50561 .49533 m .5063 .49509 L .50622 .49577 L p .792 .816 .871 r
F P
0 g
s
.50622 .49577 m .50551 .49596 L .50561 .49533 L p .792 .816 .871 r
F P
0 g
s
.49375 .50275 m .49323 .50327 L .4926 .503 L p .779 .812 .879 r
F P
0 g
s
.49191 .50344 m .4926 .503 L .49323 .50327 L p .744 .819 .91 r
F P
0 g
s
.50551 .50404 m .50622 .50423 L .5063 .50491 L p .792 .477 .456 r
F P
0 g
s
.50702 .50529 m .5063 .50491 L .50622 .50423 L p .829 .506 .442 r
F P
0 g
s
.50124 .50719 m .5011 .50791 L .50055 .5075 L p .419 .348 .671 r
F P
0 g
s
.50055 .5075 m .50074 .50679 L .50124 .50719 L p .419 .348 .671 r
F P
0 g
s
.50172 .49703 m .50112 .49662 L .50169 .49584 L p .662 .582 .755 r
F P
0 g
s
.50121 .49542 m .50169 .49584 L .50112 .49662 L p .644 .556 .741 r
F P
0 g
s
.4956 .5 m .49555 .49938 L .49651 .49928 L p .769 .619 .693 r
F P
0 g
s
.49651 .49928 m .49657 .5 L .4956 .5 L p .769 .619 .693 r
F P
0 g
s
.5022 .49619 m .50276 .49646 L .50237 .49734 L p .681 .606 .766 r
F P
0 g
s
.50237 .49734 m .50172 .49703 L .5022 .49619 L p .681 .606 .766 r
F P
0 g
s
.49657 .5 m .49651 .50072 L .49555 .50062 L p .769 .637 .715 r
F P
0 g
s
.49543 .50124 m .49555 .50062 L .49651 .50072 L p .766 .652 .737 r
F P
0 g
s
.50172 .50297 m .50237 .50266 L .50276 .50354 L p .681 .506 .642 r
F P
0 g
s
.50336 .50334 m .50276 .50354 L .50237 .50266 L p .701 .515 .633 r
F P
0 g
s
.5022 .50381 m .50169 .50416 L .50112 .50338 L p .662 .499 .653 r
F P
0 g
s
.50112 .50338 m .50172 .50297 L .5022 .50381 L p .662 .499 .653 r
F P
0 g
s
.50169 .49584 m .5022 .49619 L .50172 .49703 L p .662 .582 .755 r
F P
0 g
s
.49555 .50062 m .4956 .5 L .49657 .5 L p .769 .637 .715 r
F P
0 g
s
.50276 .50354 m .5022 .50381 L .50172 .50297 L p .681 .506 .642 r
F P
0 g
s
.49144 .49678 m .49052 .49642 L .49103 .49617 L p .686 .23 .163 r
F P
0 g
s
.49103 .49617 m .49191 .49656 L .49144 .49678 L p .686 .23 .163 r
F P
0 g
s
.50107 .49127 m .50117 .49032 L .50164 .49001 L p .158 .048 .468 r
F P
0 g
s
.50197 .48887 m .50164 .49001 L .50117 .49032 L p .104 0 .374 r
F P
0 g
s
.50707 .4942 m .50783 .49358 L .5078 .49415 L p .859 .95 .873 r
F P
0 g
s
.5078 .49415 m .50702 .49471 L .50707 .4942 L p .859 .95 .873 r
F P
0 g
s
.50702 .50529 m .5078 .50585 L .50783 .50642 L p .859 .452 .263 r
F P
0 g
s
.50866 .50727 m .50783 .50642 L .5078 .50585 L p .892 .49 .243 r
F P
0 g
s
.49191 .50344 m .49103 .50383 L .49052 .50358 L p .686 .891 .972 r
F P
0 g
s
.48937 .50386 m .49052 .50358 L .49103 .50383 L p .611 .871 .991 r
F P
0 g
s
.50149 .50902 m .50164 .50999 L .50117 .50968 L p .158 .21 .667 r
F P
0 g
s
.50117 .50968 m .50107 .50873 L .50149 .50902 L p .158 .21 .667 r
F P
0 g
s
.50121 .49542 m .50078 .49492 L .50133 .49437 L p .585 .519 .748 r
F P
0 g
s
.501 .49383 m .50133 .49437 L .50078 .49492 L p .56 .481 .722 r
F P
0 g
s
.49467 .4989 m .49446 .49834 L .49521 .49814 L p .796 .592 .625 r
F P
0 g
s
.49521 .49814 m .49543 .49876 L .49467 .4989 L p .796 .592 .625 r
F P
0 g
s
.50362 .49594 m .50421 .49604 L .50401 .49678 L p .708 .678 .819 r
F P
0 g
s
.50401 .49678 m .50336 .49666 L .50362 .49594 L p .708 .678 .819 r
F P
0 g
s
.49543 .50124 m .49521 .50186 L .49446 .50166 L p .796 .708 .767 r
F P
0 g
s
.49416 .50222 m .49446 .50166 L .49521 .50186 L p .785 .724 .795 r
F P
0 g
s
.50336 .50334 m .50401 .50322 L .50421 .50396 L p .708 .478 .574 r
F P
0 g
s
.50484 .50395 m .50421 .50396 L .50401 .50322 L p .736 .495 .564 r
F P
0 g
s
.50171 .50517 m .50133 .50563 L .50078 .50508 L p .585 .436 .645 r
F P
0 g
s
.50078 .50508 m .50121 .50458 L .50171 .50517 L p .585 .436 .645 r
F P
0 g
s
.501 .49383 m .50074 .49321 L .50124 .49281 L p .455 .396 .702 r
F P
0 g
s
.5011 .49209 m .50124 .49281 L .50074 .49321 L p .419 .336 .656 r
F P
0 g
s
.49358 .49797 m .49315 .49747 L .49375 .49725 L p .807 .518 .499 r
F P
0 g
s
.49375 .49725 m .49416 .49778 L .49358 .49797 L p .807 .518 .499 r
F P
0 g
s
.50497 .49545 m .50561 .49533 L .50551 .49596 L p .755 .782 .875 r
F P
0 g
s
.50551 .49596 m .50484 .49605 L .50497 .49545 L p .755 .782 .875 r
F P
0 g
s
.49416 .50222 m .49375 .50275 L .49315 .50253 L p .807 .8 .845 r
F P
0 g
s
.4926 .503 m .49315 .50253 L .49375 .50275 L p .779 .812 .879 r
F P
0 g
s
.50484 .50395 m .50551 .50404 L .50561 .50467 L p .755 .45 .469 r
F P
0 g
s
.5063 .50491 m .50561 .50467 L .50551 .50404 L p .792 .477 .456 r
F P
0 g
s
.50145 .50658 m .50124 .50719 L .50074 .50679 L p .455 .347 .642 r
F P
0 g
s
.50074 .50679 m .501 .50617 L .50145 .50658 L p .455 .347 .642 r
F P
0 g
s
.50169 .49584 m .50121 .49542 L .50171 .49483 L p .609 .555 .768 r
F P
0 g
s
.50133 .49437 m .50171 .49483 L .50121 .49542 L p .585 .519 .748 r
F P
0 g
s
.49479 .49945 m .49467 .4989 L .49543 .49876 L p .804 .622 .656 r
F P
0 g
s
.49543 .49876 m .49555 .49938 L .49479 .49945 L p .804 .622 .656 r
F P
0 g
s
.50308 .49577 m .50362 .49594 L .50336 .49666 L p .681 .648 .81 r
F P
0 g
s
.50336 .49666 m .50276 .49646 L .50308 .49577 L p .681 .648 .81 r
F P
0 g
s
.49555 .50062 m .49543 .50124 L .49467 .5011 L p .804 .69 .74 r
F P
0 g
s
.49446 .50166 m .49467 .5011 L .49543 .50124 L p .796 .708 .767 r
F P
0 g
s
.50276 .50354 m .50336 .50334 L .50362 .50406 L p .681 .465 .586 r
F P
0 g
s
.50421 .50396 m .50362 .50406 L .50336 .50334 L p .708 .478 .574 r
F P
0 g
s
.50213 .50478 m .50171 .50517 L .50121 .50458 L p .609 .44 .627 r
F P
0 g
s
.50121 .50458 m .50169 .50416 L .50213 .50478 L p .609 .44 .627 r
F P
0 g
s
.5022 .49619 m .50169 .49584 L .50213 .49522 L p .633 .587 .786 r
F P
0 g
s
.50171 .49483 m .50213 .49522 L .50169 .49584 L p .609 .555 .768 r
F P
0 g
s
.49483 .5 m .49479 .49945 L .49555 .49938 L p .807 .648 .685 r
F P
0 g
s
.49555 .49938 m .4956 .5 L .49483 .5 L p .807 .648 .685 r
F P
0 g
s
.50258 .49553 m .50308 .49577 L .50276 .49646 L p .656 .618 .799 r
F P
0 g
s
.50276 .49646 m .5022 .49619 L .50258 .49553 L p .656 .618 .799 r
F P
0 g
s
.4956 .5 m .49555 .50062 L .49479 .50055 L p .807 .67 .712 r
F P
0 g
s
.49467 .5011 m .49479 .50055 L .49555 .50062 L p .804 .69 .74 r
F P
0 g
s
.5022 .50381 m .50276 .50354 L .50308 .50423 L p .656 .454 .598 r
F P
0 g
s
.50362 .50406 m .50308 .50423 L .50276 .50354 L p .681 .465 .586 r
F P
0 g
s
.50258 .50447 m .50213 .50478 L .50169 .50416 L p .633 .446 .612 r
F P
0 g
s
.50169 .50416 m .5022 .50381 L .50258 .50447 L p .633 .446 .612 r
F P
0 g
s
.50213 .49522 m .50258 .49553 L .5022 .49619 L p .633 .587 .786 r
F P
0 g
s
.49479 .50055 m .49483 .5 L .4956 .5 L p .807 .67 .712 r
F P
0 g
s
.50308 .50423 m .50258 .50447 L .5022 .50381 L p .656 .454 .598 r
F P
0 g
s
.5011 .49209 m .50107 .49127 L .50149 .49098 L p .21 .14 .554 r
F P
0 g
s
.50164 .49001 m .50149 .49098 L .50107 .49127 L p .158 .048 .468 r
F P
0 g
s
.49217 .49718 m .49144 .49678 L .49191 .49656 L p .751 .326 .242 r
F P
0 g
s
.49191 .49656 m .4926 .497 L .49217 .49718 L p .751 .326 .242 r
F P
0 g
s
.50635 .49463 m .50707 .4942 L .50702 .49471 L p .819 .923 .905 r
F P
0 g
s
.50702 .49471 m .5063 .49509 L .50635 .49463 L p .819 .923 .905 r
F P
0 g
s
.4926 .503 m .49191 .50344 L .49144 .50322 L p .751 .9 .944 r
F P
0 g
s
.49052 .50358 m .49144 .50322 L .49191 .50344 L p .686 .891 .972 r
F P
0 g
s
.5063 .50491 m .50702 .50529 L .50707 .5058 L p .819 .414 .281 r
F P
0 g
s
.50783 .50642 m .50707 .5058 L .50702 .50529 L p .859 .452 .263 r
F P
0 g
s
.50148 .50819 m .50149 .50902 L .50107 .50873 L p .21 .204 .632 r
F P
0 g
s
.50107 .50873 m .5011 .50791 L .50148 .50819 L p .21 .204 .632 r
F P
0 g
s
.50977 .47804 m .51358 .47388 L .5136 .47384 L p .528 .821 .484 r
F P
0 g
s
.47607 .49748 m .47055 .4987 L .47059 .4987 L p .159 .693 .697 r
F P
0 g
s
.47059 .4987 m .47609 .49748 L .47607 .49748 L p .159 .693 .697 r
F P
0 g
s
.51415 .48053 m .51585 .47514 L .51583 .47518 L p 0 0 0 r
F P
0 g
s
.51583 .47518 m .51413 .48056 L .51415 .48053 L p 0 0 0 r
F P
0 g
s
.51413 .51944 m .51583 .52482 L .51585 .52486 L p 0 0 .219 r
F P
0 g
s
.47609 .50252 m .47059 .5013 L .47055 .5013 L p .159 0 0 r
F P
0 g
s
.50978 .52199 m .5136 .52616 L .51358 .52612 L p .528 .041 0 r
F P
0 g
s
.51358 .52612 m .50977 .52196 L .50978 .52199 L p .528 .041 0 r
F P
0 g
s
.48908 .49629 m .48759 .49614 L .48793 .49596 L p .374 0 0 r
F P
0 g
s
.48793 .49596 m .48937 .49614 L .48908 .49629 L p .374 0 0 r
F P
0 g
s
.50197 .48887 m .50253 .48752 L .50286 .48732 L p 0 0 .052 r
F P
0 g
s
.50379 .48568 m .50286 .48732 L .50253 .48752 L p 0 0 0 r
F P
0 g
s
.50867 .49239 m .50955 .49118 L .50954 .49157 L p .832 .978 .682 r
F P
0 g
s
.50954 .49157 m .50866 .49273 L .50867 .49239 L p .832 .978 .682 r
F P
0 g
s
.50866 .50727 m .50954 .50843 L .50955 .50882 L p .832 .38 0 r
F P
0 g
s
.51051 .51044 m .50955 .50882 L .50954 .50843 L p .84 .421 0 r
F P
0 g
s
.48937 .50386 m .48793 .50404 L .48759 .50386 L p .375 .82 .946 r
F P
0 g
s
.4857 .50388 m .48759 .50386 L .48793 .50404 L p .276 .757 .927 r
F P
0 g
s
.50225 .51131 m .50286 .51268 L .50253 .51248 L p 0 .003 .579 r
F P
0 g
s
.50253 .51248 m .50197 .51113 L .50225 .51131 L p 0 .003 .579 r
F P
0 g
s
.50133 .49437 m .501 .49383 L .50145 .49342 L p .489 .451 .742 r
F P
0 g
s
.50124 .49281 m .50145 .49342 L .501 .49383 L p .455 .396 .702 r
F P
0 g
s
.49389 .49848 m .49358 .49797 L .49416 .49778 L p .828 .568 .546 r
F P
0 g
s
.49416 .49778 m .49446 .49834 L .49389 .49848 L p .828 .568 .546 r
F P
0 g
s
.50437 .49547 m .50497 .49545 L .50484 .49605 L p .718 .746 .874 r
F P
0 g
s
.50484 .49605 m .50421 .49604 L .50437 .49547 L p .718 .746 .874 r
F P
0 g
s
.49446 .50166 m .49416 .50222 L .49358 .50203 L p .828 .784 .811 r
F P
0 g
s
.49315 .50253 m .49358 .50203 L .49416 .50222 L p .807 .8 .845 r
F P
0 g
s
.50421 .50396 m .50484 .50395 L .50497 .50455 L p .718 .427 .483 r
F P
0 g
s
.50561 .50467 m .50497 .50455 L .50484 .50395 L p .755 .45 .469 r
F P
0 g
s
.50174 .50605 m .50145 .50658 L .501 .50617 L p .489 .348 .615 r
F P
0 g
s
.501 .50617 m .50133 .50563 L .50174 .50605 L p .489 .348 .615 r
F P
0 g
s
.50171 .49483 m .50133 .49437 L .50174 .49395 L p .522 .502 .775 r
F P
0 g
s
.50145 .49342 m .50174 .49395 L .50133 .49437 L p .489 .451 .742 r
F P
0 g
s
.4941 .49899 m .49389 .49848 L .49446 .49834 L p .843 .612 .59 r
F P
0 g
s
.49446 .49834 m .49467 .4989 L .4941 .49899 L p .843 .612 .59 r
F P
0 g
s
.50382 .4954 m .50437 .49547 L .50421 .49604 L p .683 .709 .868 r
F P
0 g
s
.50421 .49604 m .50362 .49594 L .50382 .4954 L p .683 .709 .868 r
F P
0 g
s
.49467 .5011 m .49446 .50166 L .49389 .50152 L p .843 .764 .775 r
F P
0 g
s
.49358 .50203 m .49389 .50152 L .49446 .50166 L p .828 .784 .811 r
F P
0 g
s
.50362 .50406 m .50421 .50396 L .50437 .50453 L p .683 .406 .497 r
F P
0 g
s
.50497 .50455 m .50437 .50453 L .50421 .50396 L p .718 .427 .483 r
F P
0 g
s
.50208 .50561 m .50174 .50605 L .50133 .50563 L p .522 .351 .59 r
F P
0 g
s
.50133 .50563 m .50171 .50517 L .50208 .50561 L p .522 .351 .59 r
F P
0 g
s
.49275 .49763 m .49217 .49718 L .4926 .497 L p .804 .414 .316 r
F P
0 g
s
.4926 .497 m .49315 .49747 L .49275 .49763 L p .804 .414 .316 r
F P
0 g
s
.50124 .49281 m .5011 .49209 L .50148 .49181 L p .261 .227 .63 r
F P
0 g
s
.50149 .49098 m .50148 .49181 L .5011 .49209 L p .21 .14 .554 r
F P
0 g
s
.50568 .4949 m .50635 .49463 L .5063 .49509 L p .774 .888 .927 r
F P
0 g
s
.5063 .49509 m .50561 .49533 L .50568 .4949 L p .774 .888 .927 r
F P
0 g
s
.49315 .50253 m .4926 .503 L .49217 .50282 L p .804 .898 .909 r
F P
0 g
s
.49144 .50322 m .49217 .50282 L .4926 .503 L p .751 .9 .944 r
F P
0 g
s
.50561 .50467 m .5063 .50491 L .50635 .50537 L p .774 .376 .299 r
F P
0 g
s
.50707 .5058 m .50635 .50537 L .5063 .50491 L p .819 .414 .281 r
F P
0 g
s
.50157 .50747 m .50148 .50819 L .5011 .50791 L p .261 .199 .596 r
F P
0 g
s
.5011 .50791 m .50124 .50719 L .50157 .50747 L p .261 .199 .596 r
F P
0 g
s
.50213 .49522 m .50171 .49483 L .50208 .49439 L p .554 .548 .802 r
F P
0 g
s
.50174 .49395 m .50208 .49439 L .50171 .49483 L p .522 .502 .775 r
F P
0 g
s
.49422 .4995 m .4941 .49899 L .49467 .4989 L p .852 .651 .63 r
F P
0 g
s
.49467 .4989 m .49479 .49945 L .49422 .4995 L p .852 .651 .63 r
F P
0 g
s
.50332 .49525 m .50382 .4954 L .50362 .49594 L p .649 .67 .857 r
F P
0 g
s
.50362 .49594 m .50308 .49577 L .50332 .49525 L p .649 .67 .857 r
F P
0 g
s
.49479 .50055 m .49467 .5011 L .4941 .50101 L p .852 .74 .74 r
F P
0 g
s
.49389 .50152 m .4941 .50101 L .49467 .5011 L p .843 .764 .775 r
F P
0 g
s
.50308 .50423 m .50362 .50406 L .50382 .5046 L p .649 .389 .513 r
F P
0 g
s
.50437 .50453 m .50382 .5046 L .50362 .50406 L p .683 .406 .497 r
F P
0 g
s
.50246 .50525 m .50208 .50561 L .50171 .50517 L p .554 .356 .568 r
F P
0 g
s
.50171 .50517 m .50213 .50478 L .50246 .50525 L p .554 .356 .568 r
F P
0 g
s
.93748 .5 m .9372 .5 L .93721 .49952 L p 0 0 .329 r
F P
0 g
s
.9372 .5 m .93748 .5 L .93748 .50003 L p 0 0 .328 r
F P
0 g
s
.93748 .50003 m .93721 .50048 L .9372 .5 L p 0 0 .328 r
F P
0 g
s
.28126 .87887 m .2814 .87863 L .28181 .87887 L p .641 .081 0 r
F P
0 g
s
.2814 .87863 m .28126 .87887 L .28123 .87886 L p .642 .082 0 r
F P
0 g
s
.28123 .87886 m .28098 .87839 L .2814 .87863 L p .642 .082 0 r
F P
0 g
s
.28126 .12113 m .2814 .12137 L .28098 .12161 L p .642 .967 .871 r
F P
0 g
s
.2814 .12137 m .28126 .12113 L .28128 .12111 L p .641 .967 .871 r
F P
0 g
s
.28128 .12111 m .28181 .12113 L .2814 .12137 L p .641 .967 .871 r
F P
0 g
s
.50258 .49553 m .50213 .49522 L .50246 .49475 L p .585 .591 .825 r
F P
0 g
s
.50208 .49439 m .50246 .49475 L .50213 .49522 L p .554 .548 .802 r
F P
0 g
s
.49426 .5 m .49422 .4995 L .49479 .49945 L p .857 .685 .668 r
F P
0 g
s
.49479 .49945 m .49483 .5 L .49426 .5 L p .857 .685 .668 r
F P
0 g
s
.50287 .49503 m .50332 .49525 L .50308 .49577 L p .616 .631 .843 r
F P
0 g
s
.50308 .49577 m .50258 .49553 L .50287 .49503 L p .616 .631 .843 r
F P
0 g
s
.49483 .5 m .49479 .50055 L .49422 .5005 L p .857 .714 .704 r
F P
0 g
s
.4941 .50101 m .49422 .5005 L .49479 .50055 L p .852 .74 .74 r
F P
0 g
s
.50258 .50447 m .50308 .50423 L .50332 .50475 L p .616 .375 .529 r
F P
0 g
s
.50382 .5046 m .50332 .50475 L .50308 .50423 L p .649 .389 .513 r
F P
0 g
s
.50287 .50497 m .50246 .50525 L .50213 .50478 L p .585 .365 .547 r
F P
0 g
s
.50213 .50478 m .50258 .50447 L .50287 .50497 L p .585 .365 .547 r
F P
0 g
s
.93721 .50048 m .93748 .50003 L .93748 .50006 L p 0 0 .327 r
F P
0 g
s
.93748 .50006 m .93722 .50093 L .93721 .50048 L p 0 0 .327 r
F P
0 g
s
.28098 .87839 m .28123 .87886 L .28121 .87884 L p .642 .082 0 r
F P
0 g
s
.28121 .87884 m .28058 .87818 L .28098 .87839 L p .642 .082 0 r
F P
0 g
s
.28128 .87889 m .28181 .87887 L .2822 .87911 L p .64 .079 0 r
F P
0 g
s
.28181 .87887 m .28128 .87889 L .28126 .87887 L p .641 .081 0 r
F P
0 g
s
.93748 .49997 m .93721 .49952 L .93722 .49907 L p 0 0 .329 r
F P
0 g
s
.93721 .49952 m .93748 .49997 L .93748 .5 L p 0 0 .329 r
F P
0 g
s
.28123 .12114 m .28098 .12161 L .28058 .12182 L p .642 .967 .87 r
F P
0 g
s
.28098 .12161 m .28123 .12114 L .28126 .12113 L p .642 .967 .871 r
F P
0 g
s
.28181 .12113 m .28128 .12111 L .28131 .1211 L p .64 .966 .871 r
F P
0 g
s
.28131 .1211 m .2822 .12089 L .28181 .12113 L p .64 .966 .871 r
F P
0 g
s
.50246 .49475 m .50287 .49503 L .50258 .49553 L p .585 .591 .825 r
F P
0 g
s
.49422 .5005 m .49426 .5 L .49483 .5 L p .857 .714 .704 r
F P
0 g
s
.50332 .50475 m .50287 .50497 L .50258 .50447 L p .616 .375 .529 r
F P
0 g
s
.49026 .49655 m .48908 .49629 L .48937 .49614 L p .478 0 0 r
F P
0 g
s
.48937 .49614 m .49052 .49642 L .49026 .49655 L p .478 0 0 r
F P
0 g
s
.50164 .49001 m .50197 .48887 L .50225 .48869 L p 0 0 .162 r
F P
0 g
s
.50286 .48732 m .50225 .48869 L .50197 .48887 L p 0 0 .052 r
F P
0 g
s
.50785 .49329 m .50867 .49239 L .50866 .49273 L p .812 .995 .761 r
F P
0 g
s
.50866 .49273 m .50783 .49358 L .50785 .49329 L p .812 .995 .761 r
F P
0 g
s
.50783 .50642 m .50866 .50727 L .50867 .50761 L p .812 .331 0 r
F P
0 g
s
.50955 .50882 m .50867 .50761 L .50866 .50727 L p .832 .38 0 r
F P
0 g
s
.49052 .50358 m .48937 .50386 L .48908 .50371 L p .478 .879 .954 r
F P
0 g
s
.48759 .50386 m .48908 .50371 L .48937 .50386 L p .375 .82 .946 r
F P
0 g
s
.50188 .51016 m .50225 .51131 L .50197 .51113 L p 0 0 .548 r
F P
0 g
s
.50197 .51113 m .50164 .50999 L .50188 .51016 L p 0 0 .548 r
F P
0 g
s
.50145 .49342 m .50124 .49281 L .50157 .49253 L p .31 .309 .697 r
F P
0 g
s
.50148 .49181 m .50157 .49253 L .50124 .49281 L p .261 .227 .63 r
F P
0 g
s
.49318 .49809 m .49275 .49763 L .49315 .49747 L p .847 .494 .387 r
F P
0 g
s
.49315 .49747 m .49358 .49797 L .49318 .49809 L p .847 .494 .387 r
F P
0 g
s
.50506 .49505 m .50568 .4949 L .50561 .49533 L p .727 .847 .938 r
F P
0 g
s
.50561 .49533 m .50497 .49545 L .50506 .49505 L p .727 .847 .938 r
F P
0 g
s
.49358 .50203 m .49315 .50253 L .49275 .50237 L p .847 .888 .869 r
F P
0 g
s
.49217 .50282 m .49275 .50237 L .49315 .50253 L p .804 .898 .909 r
F P
0 g
s
.50497 .50455 m .50561 .50467 L .50568 .5051 L p .727 .34 .318 r
F P
0 g
s
.50635 .50537 m .50568 .5051 L .50561 .50467 L p .774 .376 .299 r
F P
0 g
s
.50176 .50686 m .50157 .50747 L .50124 .50719 L p .31 .196 .559 r
F P
0 g
s
.50124 .50719 m .50145 .50658 L .50176 .50686 L p .31 .196 .559 r
F P
0 g
s
.28131 .8789 m .2822 .87911 L .28254 .87935 L p .639 .078 0 r
F P
0 g
s
.2822 .87911 m .28131 .8789 L .28128 .87889 L p .64 .079 0 r
F P
0 g
s
.93748 .49994 m .93722 .49907 L .93725 .49865 L p 0 0 .329 r
F P
0 g
s
.93722 .49907 m .93748 .49994 L .93748 .49997 L p 0 0 .329 r
F P
0 g
s
.28058 .87818 m .28121 .87884 L .28118 .87883 L p .642 .082 0 r
F P
0 g
s
.28118 .87883 m .28021 .878 L .28058 .87818 L p .642 .082 0 r
F P
0 g
s
.93722 .50093 m .93748 .50006 L .93749 .50008 L p 0 0 .325 r
F P
0 g
s
.93749 .50008 m .93725 .50135 L .93722 .50093 L p 0 0 .325 r
F P
0 g
s
.28121 .12116 m .28058 .12182 L .28021 .122 L p .642 .967 .869 r
F P
0 g
s
.28058 .12182 m .28121 .12116 L .28123 .12114 L p .642 .967 .87 r
F P
0 g
s
.2822 .12089 m .28131 .1211 L .28133 .12108 L p .639 .966 .871 r
F P
0 g
s
.28133 .12108 m .28254 .12065 L .2822 .12089 L p .639 .966 .871 r
F P
0 g
s
.48017 .49671 m .47607 .49748 L .47609 .49748 L p .135 .678 .701 r
F P
0 g
s
.47609 .49748 m .48019 .49671 L .48017 .49671 L p .135 .678 .701 r
F P
0 g
s
.50706 .4812 m .50977 .47804 L .50978 .47801 L p .543 .819 .466 r
F P
0 g
s
.5136 .47384 m .50978 .47801 L .50977 .47804 L p .528 .821 .484 r
F P
0 g
s
.51275 .51551 m .51413 .51944 L .51415 .51947 L p 0 0 .241 r
F P
0 g
s
.51585 .52486 m .51415 .51947 L .51413 .51944 L p 0 0 .219 r
F P
0 g
s
.51276 .48447 m .51415 .48053 L .51413 .48056 L p 0 0 0 r
F P
0 g
s
.51413 .48056 m .51275 .48449 L .51276 .48447 L p 0 0 0 r
F P
0 g
s
.48019 .50329 m .47609 .50252 L .47607 .50252 L p .135 0 0 r
F P
0 g
s
.47055 .5013 m .47607 .50252 L .47609 .50252 L p .159 0 0 r
F P
0 g
s
.50707 .51882 m .50978 .52199 L .50977 .52196 L p .543 .067 0 r
F P
0 g
s
.50977 .52196 m .50706 .5188 L .50707 .51882 L p .543 .067 0 r
F P
0 g
s
.50174 .49395 m .50145 .49342 L .50176 .49314 L p .357 .386 .754 r
F P
0 g
s
.50157 .49253 m .50176 .49314 L .50145 .49342 L p .31 .309 .697 r
F P
0 g
s
.4935 .49857 m .49318 .49809 L .49358 .49797 L p .879 .566 .452 r
F P
0 g
s
.49358 .49797 m .49389 .49848 L .4935 .49857 L p .879 .566 .452 r
F P
0 g
s
.50449 .49509 m .50506 .49505 L .50497 .49545 L p .679 .8 .94 r
F P
0 g
s
.50497 .49545 m .50437 .49547 L .50449 .49509 L p .679 .8 .94 r
F P
0 g
s
.49389 .50152 m .49358 .50203 L .49318 .50191 L p .879 .87 .824 r
F P
0 g
s
.49275 .50237 m .49318 .50191 L .49358 .50203 L p .847 .888 .869 r
F P
0 g
s
.50437 .50453 m .50497 .50455 L .50506 .50495 L p .679 .308 .337 r
F P
0 g
s
.50568 .5051 m .50506 .50495 L .50497 .50455 L p .727 .34 .318 r
F P
0 g
s
.50201 .50634 m .50176 .50686 L .50145 .50658 L p .357 .197 .523 r
F P
0 g
s
.50145 .50658 m .50174 .50605 L .50201 .50634 L p .357 .197 .523 r
F P
0 g
s
.50149 .49098 m .50164 .49001 L .50188 .48984 L p 0 0 .278 r
F P
0 g
s
.50225 .48869 m .50188 .48984 L .50164 .49001 L p 0 0 .162 r
F P
0 g
s
.49121 .49689 m .49026 .49655 L .49052 .49642 L p .581 .02 0 r
F P
0 g
s
.49052 .49642 m .49144 .49678 L .49121 .49689 L p .581 .02 0 r
F P
0 g
s
.50709 .49394 m .50785 .49329 L .50783 .49358 L p .781 .998 .835 r
F P
0 g
s
.50783 .49358 m .50707 .4942 L .50709 .49394 L p .781 .998 .835 r
F P
0 g
s
.50707 .5058 m .50783 .50642 L .50785 .50671 L p .781 .277 0 r
F P
0 g
s
.50867 .50761 m .50785 .50671 L .50783 .50642 L p .812 .331 0 r
F P
0 g
s
.49144 .50322 m .49052 .50358 L .49026 .50345 L p .582 .929 .95 r
F P
0 g
s
.48908 .50371 m .49026 .50345 L .49052 .50358 L p .478 .879 .954 r
F P
0 g
s
.5017 .50917 m .50188 .51016 L .50164 .50999 L p 0 0 .508 r
F P
0 g
s
.50164 .50999 m .50149 .50902 L .5017 .50917 L p 0 0 .508 r
F P
0 g
s
.28133 .87892 m .28254 .87935 L .28283 .87956 L p .637 .075 0 r
F P
0 g
s
.28254 .87935 m .28133 .87892 L .28131 .8789 L p .639 .078 0 r
F P
0 g
s
.93749 .49992 m .93725 .49865 L .93729 .4983 L p 0 0 .328 r
F P
0 g
s
.93725 .49865 m .93749 .49992 L .93748 .49994 L p 0 0 .329 r
F P
0 g
s
.28021 .878 m .28118 .87883 L .28116 .87882 L p .642 .081 0 r
F P
0 g
s
.28116 .87882 m .27988 .87786 L .28021 .878 L p .642 .081 0 r
F P
0 g
s
.28118 .12117 m .28021 .122 L .27988 .12214 L p .642 .967 .868 r
F P
0 g
s
.28021 .122 m .28118 .12117 L .28121 .12116 L p .642 .967 .869 r
F P
0 g
s
.93725 .50135 m .93749 .50008 L .93749 .50011 L p 0 0 .323 r
F P
0 g
s
.93749 .50011 m .93729 .5017 L .93725 .50135 L p 0 0 .323 r
F P
0 g
s
.28254 .12065 m .28133 .12108 L .28135 .12107 L p .637 .965 .871 r
F P
0 g
s
.28135 .12107 m .28283 .12044 L .28254 .12065 L p .637 .965 .871 r
F P
0 g
s
.50208 .49439 m .50174 .49395 L .50201 .49366 L p .403 .457 .802 r
F P
0 g
s
.50176 .49314 m .50201 .49366 L .50174 .49395 L p .357 .386 .754 r
F P
0 g
s
.49372 .49905 m .4935 .49857 L .49389 .49848 L p .902 .63 .514 r
F P
0 g
s
.49389 .49848 m .4941 .49899 L .49372 .49905 L p .902 .63 .514 r
F P
0 g
s
.50396 .49503 m .50449 .49509 L .50437 .49547 L p .631 .75 .934 r
F P
0 g
s
.50437 .49547 m .50382 .4954 L .50396 .49503 L p .631 .75 .934 r
F P
0 g
s
.4941 .50101 m .49389 .50152 L .4935 .50143 L p .902 .844 .777 r
F P
0 g
s
.49318 .50191 m .4935 .50143 L .49389 .50152 L p .879 .87 .824 r
F P
0 g
s
.50382 .5046 m .50437 .50453 L .50449 .50491 L p .631 .28 .358 r
F P
0 g
s
.50506 .50495 m .50449 .50491 L .50437 .50453 L p .679 .308 .337 r
F P
0 g
s
.50232 .50592 m .50201 .50634 L .50174 .50605 L p .403 .201 .489 r
F P
0 g
s
.50174 .50605 m .50208 .50561 L .50232 .50592 L p .403 .201 .489 r
F P
0 g
s
.50246 .49475 m .50208 .49439 L .50232 .49408 L p .449 .524 .843 r
F P
0 g
s
.50201 .49366 m .50232 .49408 L .50208 .49439 L p .403 .457 .802 r
F P
0 g
s
.49384 .49953 m .49372 .49905 L .4941 .49899 L p .917 .685 .572 r
F P
0 g
s
.4941 .49899 m .49422 .4995 L .49384 .49953 L p .917 .685 .572 r
F P
0 g
s
.50349 .4949 m .50396 .49503 L .50382 .4954 L p .584 .697 .92 r
F P
0 g
s
.50382 .4954 m .50332 .49525 L .50349 .4949 L p .584 .697 .92 r
F P
0 g
s
.49422 .5005 m .4941 .50101 L .49372 .50095 L p .917 .812 .728 r
F P
0 g
s
.4935 .50143 m .49372 .50095 L .4941 .50101 L p .902 .844 .777 r
F P
0 g
s
.50332 .50475 m .50382 .5046 L .50396 .50497 L p .584 .256 .38 r
F P
0 g
s
.50449 .50491 m .50396 .50497 L .50382 .5046 L p .631 .28 .358 r
F P
0 g
s
.50267 .50557 m .50232 .50592 L .50208 .50561 L p .449 .209 .458 r
F P
0 g
s
.50208 .50561 m .50246 .50525 L .50267 .50557 L p .449 .209 .458 r
F P
0 g
s
.50287 .49503 m .50246 .49475 L .50267 .49443 L p .494 .585 .875 r
F P
0 g
s
.50232 .49408 m .50267 .49443 L .50246 .49475 L p .449 .524 .843 r
F P
0 g
s
.49388 .5 m .49384 .49953 L .49422 .4995 L p .924 .734 .626 r
F P
0 g
s
.49422 .4995 m .49426 .5 L .49388 .5 L p .924 .734 .626 r
F P
0 g
s
.50306 .4947 m .50349 .4949 L .50332 .49525 L p .538 .642 .901 r
F P
0 g
s
.50332 .49525 m .50287 .49503 L .50306 .4947 L p .538 .642 .901 r
F P
0 g
s
.49426 .5 m .49422 .5005 L .49384 .50047 L p .924 .776 .678 r
F P
0 g
s
.49372 .50095 m .49384 .50047 L .49422 .5005 L p .917 .812 .728 r
F P
0 g
s
.50287 .50497 m .50332 .50475 L .50349 .5051 L p .538 .237 .404 r
F P
0 g
s
.50396 .50497 m .50349 .5051 L .50332 .50475 L p .584 .256 .38 r
F P
0 g
s
.50306 .5053 m .50267 .50557 L .50246 .50525 L p .494 .221 .429 r
F P
0 g
s
.50246 .50525 m .50287 .50497 L .50306 .5053 L p .494 .221 .429 r
F P
0 g
s
.50267 .49443 m .50306 .4947 L .50287 .49503 L p .494 .585 .875 r
F P
0 g
s
.49384 .50047 m .49388 .5 L .49426 .5 L p .924 .776 .678 r
F P
0 g
s
.50349 .5051 m .50306 .5053 L .50287 .50497 L p .538 .237 .404 r
F P
0 g
s
.50148 .49181 m .50149 .49098 L .5017 .49083 L p 0 0 .394 r
F P
0 g
s
.50188 .48984 m .5017 .49083 L .50149 .49098 L p 0 0 .278 r
F P
0 g
s
.49195 .49728 m .49121 .49689 L .49144 .49678 L p .68 .144 0 r
F P
0 g
s
.49144 .49678 m .49217 .49718 L .49195 .49728 L p .68 .144 0 r
F P
0 g
s
.50638 .49439 m .50709 .49394 L .50707 .4942 L p .737 .986 .898 r
F P
0 g
s
.50707 .4942 m .50635 .49463 L .50638 .49439 L p .737 .986 .898 r
F P
0 g
s
.49217 .50282 m .49144 .50322 L .49121 .50311 L p .68 .966 .931 r
F P
0 g
s
.49026 .50345 m .49121 .50311 L .49144 .50322 L p .582 .929 .95 r
F P
0 g
s
.50635 .50537 m .50707 .5058 L .50709 .50606 L p .737 .218 0 r
F P
0 g
s
.50785 .50671 m .50709 .50606 L .50707 .5058 L p .781 .277 0 r
F P
0 g
s
.50167 .50833 m .5017 .50917 L .50149 .50902 L p 0 0 .46 r
F P
0 g
s
.50149 .50902 m .50148 .50819 L .50167 .50833 L p 0 0 .46 r
F P
0 g
s
.50514 .48368 m .50706 .4812 L .50707 .48118 L p .564 .814 .438 r
F P
0 g
s
.50978 .47801 m .50707 .48118 L .50706 .4812 L p .543 .819 .466 r
F P
0 g
s
.48329 .49629 m .48017 .49671 L .48019 .49671 L p .1 .654 .705 r
F P
0 g
s
.48019 .49671 m .4833 .49629 L .48329 .49629 L p .1 .654 .705 r
F P
0 g
s
.51157 .48738 m .51276 .48447 L .51275 .48449 L p 0 0 0 r
F P
0 g
s
.51275 .48449 m .51156 .48739 L .51157 .48738 L p 0 0 0 r
F P
0 g
s
.51156 .51261 m .51275 .51551 L .51276 .51553 L p 0 0 .272 r
F P
0 g
s
.51415 .51947 m .51276 .51553 L .51275 .51551 L p 0 0 .241 r
F P
0 g
s
.4833 .50371 m .48019 .50329 L .48017 .50329 L p .1 0 0 r
F P
0 g
s
.47607 .50252 m .48017 .50329 L .48019 .50329 L p .135 0 0 r
F P
0 g
s
.50514 .51633 m .50707 .51882 L .50706 .5188 L p .564 .107 0 r
F P
0 g
s
.50706 .5188 m .50514 .51632 L .50514 .51633 L p .564 .107 0 r
F P
0 g
s
.27988 .87786 m .28116 .87882 L .28115 .87882 L p .641 .08 0 r
F P
0 g
s
.28115 .87882 m .27961 .87776 L .27988 .87786 L p .641 .08 0 r
F P
0 g
s
.93729 .5017 m .93749 .50011 L .93749 .50012 L p 0 0 .32 r
F P
0 g
s
.93749 .50012 m .93734 .50199 L .93729 .5017 L p 0 0 .32 r
F P
0 g
s
.93749 .49989 m .93729 .4983 L .93734 .49801 L p 0 0 .327 r
F P
0 g
s
.93729 .4983 m .93749 .49989 L .93749 .49992 L p 0 0 .328 r
F P
0 g
s
.28283 .12044 m .28135 .12107 L .28136 .12106 L p .635 .965 .87 r
F P
0 g
s
.28136 .12106 m .28305 .12026 L .28283 .12044 L p .635 .965 .87 r
F P
0 g
s
.28135 .87893 m .28283 .87956 L .28305 .87974 L p .635 .073 0 r
F P
0 g
s
.28283 .87956 m .28135 .87893 L .28133 .87892 L p .637 .075 0 r
F P
0 g
s
.28116 .12118 m .27988 .12214 L .27961 .12224 L p .641 .966 .867 r
F P
0 g
s
.27988 .12214 m .28116 .12118 L .28118 .12117 L p .642 .967 .868 r
F P
0 g
s
.49254 .4977 m .49195 .49728 L .49217 .49718 L p .769 .269 .017 r
F P
0 g
s
.49217 .49718 m .49275 .49763 L .49254 .4977 L p .769 .269 .017 r
F P
0 g
s
.50157 .49253 m .50148 .49181 L .50167 .49167 L p 0 0 .507 r
F P
0 g
s
.5017 .49083 m .50167 .49167 L .50148 .49181 L p 0 0 .394 r
F P
0 g
s
.50572 .49469 m .50638 .49439 L .50635 .49463 L p .683 .957 .947 r
F P
0 g
s
.50635 .49463 m .50568 .4949 L .50572 .49469 L p .683 .957 .947 r
F P
0 g
s
.49275 .50237 m .49217 .50282 L .49195 .50272 L p .769 .987 .897 r
F P
0 g
s
.49121 .50311 m .49195 .50272 L .49217 .50282 L p .68 .966 .931 r
F P
0 g
s
.50568 .5051 m .50635 .50537 L .50638 .50561 L p .683 .157 0 r
F P
0 g
s
.50709 .50606 m .50638 .50561 L .50635 .50537 L p .737 .218 0 r
F P
0 g
s
.50174 .50761 m .50167 .50833 L .50148 .50819 L p 0 0 .408 r
F P
0 g
s
.50148 .50819 m .50157 .50747 L .50174 .50761 L p 0 0 .408 r
F P
0 g
s
.50176 .49314 m .50157 .49253 L .50174 .49239 L p 0 .092 .613 r
F P
0 g
s
.50167 .49167 m .50174 .49239 L .50157 .49253 L p 0 0 .507 r
F P
0 g
s
.49298 .49815 m .49254 .4977 L .49275 .49763 L p .845 .39 .114 r
F P
0 g
s
.49275 .49763 m .49318 .49809 L .49298 .49815 L p .845 .39 .114 r
F P
0 g
s
.50511 .49484 m .50572 .49469 L .50568 .4949 L p .62 .913 .981 r
F P
0 g
s
.50568 .4949 m .50506 .49505 L .50511 .49484 L p .62 .913 .981 r
F P
0 g
s
.49318 .50191 m .49275 .50237 L .49254 .5023 L p .845 .991 .85 r
F P
0 g
s
.49195 .50272 m .49254 .5023 L .49275 .50237 L p .769 .987 .897 r
F P
0 g
s
.50506 .50495 m .50568 .5051 L .50572 .50531 L p .62 .099 0 r
F P
0 g
s
.50638 .50561 m .50572 .50531 L .50568 .5051 L p .683 .157 0 r
F P
0 g
s
.50191 .507 m .50174 .50761 L .50157 .50747 L p 0 0 .352 r
F P
0 g
s
.50157 .50747 m .50176 .50686 L .50191 .507 L p 0 0 .352 r
F P
0 g
s
.48569 .49612 m .48329 .49629 L .4833 .49629 L p .054 .62 .709 r
F P
0 g
s
.4833 .49629 m .4857 .49612 L .48569 .49612 L p .054 .62 .709 r
F P
0 g
s
.50379 .48568 m .50514 .48368 L .50514 .48367 L p .59 .805 .4 r
F P
0 g
s
.50707 .48118 m .50514 .48367 L .50514 .48368 L p .564 .814 .438 r
F P
0 g
s
.51052 .48955 m .51157 .48738 L .51156 .48739 L p 0 0 0 r
F P
0 g
s
.51156 .48739 m .51051 .48956 L .51052 .48955 L p 0 0 0 r
F P
0 g
s
.51051 .51044 m .51156 .51261 L .51157 .51262 L p 0 0 .313 r
F P
0 g
s
.51276 .51553 m .51157 .51262 L .51156 .51261 L p 0 0 .272 r
F P
0 g
s
.4857 .50388 m .4833 .50371 L .48329 .50371 L p .054 0 0 r
F P
0 g
s
.48017 .50329 m .48329 .50371 L .4833 .50371 L p .1 0 0 r
F P
0 g
s
.50379 .51433 m .50514 .51633 L .50514 .51632 L p .59 .158 0 r
F P
0 g
s
.50514 .51632 m .50379 .51432 L .50379 .51433 L p .59 .158 0 r
F P
0 g
s
.27152 .8727 m .2793 .87771 L .27927 .87776 L p .652 .094 0 r
F P
0 g
s
.27927 .87776 m .27137 .87296 L .27152 .8727 L p .652 .094 0 r
F P
0 g
s
.93701 .51151 m .93746 .50228 L .93752 .50228 L p 0 0 .294 r
F P
0 g
s
.93752 .50228 m .93731 .51152 L .93701 .51151 L p 0 0 .294 r
F P
0 g
s
.31397 .89449 m .29132 .88448 L .29147 .88422 L p .563 0 0 r
F P
0 g
s
.28325 .87999 m .29147 .88422 L .29132 .88448 L p .613 .044 0 r
F P
0 g
s
.29147 .88422 m .28325 .87999 L .28319 .87989 L p .624 .059 0 r
F P
0 g
s
.29147 .11578 m .28325 .12001 L .28322 .11996 L p .613 .956 .875 r
F P
0 g
s
.28322 .11996 m .29132 .11552 L .29147 .11578 L p .613 .956 .875 r
F P
0 g
s
.93465 .46387 m .93731 .48848 L .93701 .48849 L p 0 0 .391 r
F P
0 g
s
.93746 .49772 m .93701 .48849 L .93731 .48848 L p 0 0 .338 r
F P
0 g
s
.93701 .48849 m .93746 .49772 L .9374 .49782 L p 0 0 .352 r
F P
0 g
s
.25138 .14165 m .27137 .12704 L .27152 .1273 L p .695 .981 .821 r
F P
0 g
s
.2793 .12229 m .27152 .1273 L .27137 .12704 L p .652 .97 .852 r
F P
0 g
s
.27152 .1273 m .2793 .12229 L .27941 .12229 L p .662 .973 .861 r
F P
0 g
s
.50201 .49366 m .50176 .49314 L .50191 .493 L p .047 .207 .707 r
F P
0 g
s
.50174 .49239 m .50191 .493 L .50176 .49314 L p 0 .092 .613 r
F P
0 g
s
.4933 .49861 m .49298 .49815 L .49318 .49809 L p .907 .503 .211 r
F P
0 g
s
.49318 .49809 m .4935 .49857 L .4933 .49861 L p .907 .503 .211 r
F P
0 g
s
.50455 .49489 m .50511 .49484 L .50506 .49505 L p .55 .854 .998 r
F P
0 g
s
.50506 .49505 m .50449 .49509 L .50455 .49489 L p .55 .854 .998 r
F P
0 g
s
.4935 .50143 m .49318 .50191 L .49298 .50185 L p .907 .977 .792 r
F P
0 g
s
.49254 .5023 m .49298 .50185 L .49318 .50191 L p .845 .991 .85 r
F P
0 g
s
.50449 .50491 m .50506 .50495 L .50511 .50516 L p .55 .044 .005 r
F P
0 g
s
.50572 .50531 m .50511 .50516 L .50506 .50495 L p .62 .099 0 r
F P
0 g
s
.50215 .50649 m .50191 .507 L .50176 .50686 L p .047 0 .296 r
F P
0 g
s
.50176 .50686 m .50201 .50634 L .50215 .50649 L p .047 0 .296 r
F P
0 g
s
.27961 .87776 m .28115 .87882 L .28113 .87881 L p .639 .078 0 r
F P
0 g
s
.28113 .87881 m .27941 .87771 L .27961 .87776 L p .639 .078 0 r
F P
0 g
s
.93734 .50199 m .93749 .50012 L .93749 .50014 L p 0 0 .318 r
F P
0 g
s
.93749 .50014 m .9374 .50218 L .93734 .50199 L p 0 0 .318 r
F P
0 g
s
.28136 .87894 m .28305 .87974 L .28319 .87989 L p .633 .07 0 r
F P
0 g
s
.28305 .87974 m .28136 .87894 L .28135 .87893 L p .635 .073 0 r
F P
0 g
s
.93749 .49988 m .93734 .49801 L .9374 .49782 L p 0 0 .325 r
F P
0 g
s
.93734 .49801 m .93749 .49988 L .93749 .49989 L p 0 0 .327 r
F P
0 g
s
.28305 .12026 m .28136 .12106 L .28137 .12105 L p .633 .964 .869 r
F P
0 g
s
.28137 .12105 m .28319 .12011 L .28305 .12026 L p .633 .964 .869 r
F P
0 g
s
.28115 .12118 m .27961 .12224 L .27941 .12229 L p .639 .966 .865 r
F P
0 g
s
.27961 .12224 m .28115 .12118 L .28116 .12118 L p .641 .966 .867 r
F P
0 g
s
.50232 .49408 m .50201 .49366 L .50215 .49351 L p .116 .319 .79 r
F P
0 g
s
.50191 .493 m .50215 .49351 L .50201 .49366 L p .047 .207 .707 r
F P
0 g
s
.49352 .49908 m .4933 .49861 L .4935 .49857 L p .952 .607 .307 r
F P
0 g
s
.4935 .49857 m .49372 .49905 L .49352 .49908 L p .952 .607 .307 r
F P
0 g
s
.50403 .49485 m .50455 .49489 L .50449 .49509 L p .477 .784 .998 r
F P
0 g
s
.50449 .49509 m .50396 .49503 L .50403 .49485 L p .477 .784 .998 r
F P
0 g
s
.49372 .50095 m .4935 .50143 L .4933 .50139 L p .952 .948 .724 r
F P
0 g
s
.49298 .50185 m .4933 .50139 L .4935 .50143 L p .907 .977 .792 r
F P
0 g
s
.50396 .50497 m .50449 .50491 L .50455 .50511 L p .477 0 .033 r
F P
0 g
s
.50511 .50516 m .50455 .50511 L .50449 .50491 L p .55 .044 .005 r
F P
0 g
s
.50244 .50607 m .50215 .50649 L .50201 .50634 L p .116 0 .241 r
F P
0 g
s
.50201 .50634 m .50232 .50592 L .50244 .50607 L p .116 0 .241 r
F P
0 g
s
.50267 .49443 m .50232 .49408 L .50244 .49393 L p .187 .426 .858 r
F P
0 g
s
.50215 .49351 m .50244 .49393 L .50232 .49408 L p .116 .319 .79 r
F P
0 g
s
.49365 .49955 m .49352 .49908 L .49372 .49905 L p .982 .7 .399 r
F P
0 g
s
.49372 .49905 m .49384 .49953 L .49365 .49955 L p .982 .7 .399 r
F P
0 g
s
.50357 .49472 m .50403 .49485 L .50396 .49503 L p .403 .704 .983 r
F P
0 g
s
.50396 .49503 m .50349 .4949 L .50357 .49472 L p .403 .704 .983 r
F P
0 g
s
.49384 .50047 m .49372 .50095 L .49352 .50092 L p .982 .904 .649 r
F P
0 g
s
.4933 .50139 m .49352 .50092 L .49372 .50095 L p .952 .948 .724 r
F P
0 g
s
.50349 .5051 m .50396 .50497 L .50403 .50515 L p .403 0 .065 r
F P
0 g
s
.50455 .50511 m .50403 .50515 L .50396 .50497 L p .477 0 .033 r
F P
0 g
s
.50278 .50573 m .50244 .50607 L .50232 .50592 L p .187 0 .19 r
F P
0 g
s
.50232 .50592 m .50267 .50557 L .50278 .50573 L p .187 0 .19 r
F P
0 g
s
.50286 .48732 m .50379 .48568 L .50379 .48567 L p .619 .789 .351 r
F P
0 g
s
.50514 .48367 m .50379 .48567 L .50379 .48568 L p .59 .805 .4 r
F P
0 g
s
.48758 .49614 m .48569 .49612 L .4857 .49612 L p 0 .574 .71 r
F P
0 g
s
.4857 .49612 m .48759 .49614 L .48758 .49614 L p 0 .574 .71 r
F P
0 g
s
.50956 .49118 m .51052 .48955 L .51051 .48956 L p 0 0 0 r
F P
0 g
s
.51051 .48956 m .50955 .49118 L .50956 .49118 L p 0 0 0 r
F P
0 g
s
.50955 .50882 m .51051 .51044 L .51052 .51045 L p 0 0 .362 r
F P
0 g
s
.51157 .51262 m .51052 .51045 L .51051 .51044 L p 0 0 .313 r
F P
0 g
s
.48759 .50386 m .4857 .50388 L .48569 .50388 L p 0 0 0 r
F P
0 g
s
.48329 .50371 m .48569 .50388 L .4857 .50388 L p .054 0 0 r
F P
0 g
s
.50286 .51269 m .50379 .51433 L .50379 .51432 L p .619 .221 0 r
F P
0 g
s
.50379 .51432 m .50286 .51268 L .50286 .51269 L p .619 .221 0 r
F P
0 g
s
.50306 .4947 m .50267 .49443 L .50278 .49427 L p .258 .525 .913 r
F P
0 g
s
.50244 .49393 m .50278 .49427 L .50267 .49443 L p .187 .426 .858 r
F P
0 g
s
.49368 .5 m .49365 .49955 L .49384 .49953 L p .996 .78 .487 r
F P
0 g
s
.49384 .49953 m .49388 .5 L .49368 .5 L p .996 .78 .487 r
F P
0 g
s
.50316 .49453 m .50357 .49472 L .50349 .4949 L p .33 .617 .954 r
F P
0 g
s
.50349 .4949 m .50306 .4947 L .50316 .49453 L p .33 .617 .954 r
F P
0 g
s
.49388 .5 m .49384 .50047 L .49365 .50045 L p .996 .847 .57 r
F P
0 g
s
.49352 .50092 m .49365 .50045 L .49384 .50047 L p .982 .904 .649 r
F P
0 g
s
.50306 .5053 m .50349 .5051 L .50357 .50528 L p .33 0 .102 r
F P
0 g
s
.50403 .50515 m .50357 .50528 L .50349 .5051 L p .403 0 .065 r
F P
0 g
s
.50316 .50547 m .50278 .50573 L .50267 .50557 L p .258 0 .144 r
F P
0 g
s
.50267 .50557 m .50306 .5053 L .50316 .50547 L p .258 0 .144 r
F P
0 g
s
.50278 .49427 m .50316 .49453 L .50306 .4947 L p .258 .525 .913 r
F P
0 g
s
.49365 .50045 m .49368 .5 L .49388 .5 L p .996 .847 .57 r
F P
0 g
s
.50357 .50528 m .50316 .50547 L .50306 .5053 L p .33 0 .102 r
F P
0 g
s
.48907 .49629 m .48758 .49614 L .48759 .49614 L p 0 .515 .705 r
F P
0 g
s
.48759 .49614 m .48908 .49629 L .48907 .49629 L p 0 .515 .705 r
F P
0 g
s
.50225 .48869 m .50286 .48732 L .50286 .48731 L p .648 .764 .289 r
F P
0 g
s
.50379 .48567 m .50286 .48731 L .50286 .48732 L p .619 .789 .351 r
F P
0 g
s
.50867 .49239 m .50956 .49118 L .50955 .49118 L p 0 0 0 r
F P
0 g
s
.50955 .49118 m .50867 .49239 L .50867 .49239 L p 0 0 0 r
F P
0 g
s
.50867 .50761 m .50955 .50882 L .50956 .50882 L p 0 0 .418 r
F P
0 g
s
.51052 .51045 m .50956 .50882 L .50955 .50882 L p 0 0 .362 r
F P
0 g
s
.48908 .50371 m .48759 .50386 L .48758 .50386 L p 0 0 0 r
F P
0 g
s
.48569 .50388 m .48758 .50386 L .48759 .50386 L p 0 0 0 r
F P
0 g
s
.50225 .51132 m .50286 .51269 L .50286 .51268 L p .648 .295 0 r
F P
0 g
s
.50286 .51268 m .50225 .51131 L .50225 .51132 L p .648 .295 0 r
F P
0 g
s
.49026 .49655 m .48907 .49629 L .48908 .49629 L p 0 .441 .692 r
F P
0 g
s
.48908 .49629 m .49026 .49655 L .49026 .49655 L p 0 .441 .692 r
F P
0 g
s
.50188 .48984 m .50225 .48869 L .50225 .48868 L p .675 .726 .215 r
F P
0 g
s
.50286 .48731 m .50225 .48868 L .50225 .48869 L p .648 .764 .289 r
F P
0 g
s
.50786 .49329 m .50867 .49239 L .50867 .49239 L p 0 0 0 r
F P
0 g
s
.50867 .49239 m .50785 .49329 L .50786 .49329 L p 0 0 0 r
F P
0 g
s
.50785 .50671 m .50867 .50761 L .50867 .50761 L p 0 0 .477 r
F P
0 g
s
.50956 .50882 m .50867 .50761 L .50867 .50761 L p 0 0 .418 r
F P
0 g
s
.49026 .50345 m .48908 .50371 L .48907 .50371 L p 0 0 0 r
F P
0 g
s
.48758 .50386 m .48907 .50371 L .48908 .50371 L p 0 0 0 r
F P
0 g
s
.50189 .51016 m .50225 .51132 L .50225 .51131 L p .675 .376 0 r
F P
0 g
s
.50225 .51131 m .50188 .51016 L .50189 .51016 L p .675 .376 0 r
F P
0 g
s
.93749 .49986 m .9374 .49782 L .93746 .49772 L p 0 0 .323 r
F P
0 g
s
.9374 .49782 m .93749 .49986 L .93749 .49988 L p 0 0 .325 r
F P
0 g
s
.9374 .50218 m .93749 .50014 L .9375 .50014 L p 0 0 .315 r
F P
0 g
s
.9375 .50014 m .93746 .50228 L .9374 .50218 L p 0 0 .315 r
F P
0 g
s
.28137 .87895 m .28319 .87989 L .28325 .87999 L p .631 .067 0 r
F P
0 g
s
.28319 .87989 m .28137 .87895 L .28136 .87894 L p .633 .07 0 r
F P
0 g
s
.28113 .12119 m .27941 .12229 L .2793 .12229 L p .638 .965 .863 r
F P
0 g
s
.27941 .12229 m .28113 .12119 L .28115 .12118 L p .639 .966 .865 r
F P
0 g
s
.27941 .87771 m .28113 .87881 L .28113 .87881 L p .638 .076 0 r
F P
0 g
s
.28113 .87881 m .2793 .87771 L .27941 .87771 L p .638 .076 0 r
F P
0 g
s
.28319 .12011 m .28137 .12105 L .28138 .12104 L p .631 .963 .867 r
F P
0 g
s
.28138 .12104 m .28325 .12001 L .28319 .12011 L p .631 .963 .867 r
F P
0 g
s
.4912 .49689 m .49026 .49655 L .49026 .49655 L p .236 0 0 r
F P
0 g
s
.49026 .49655 m .49121 .49689 L .4912 .49689 L p .236 0 0 r
F P
0 g
s
.5017 .49083 m .50188 .48984 L .50189 .48984 L p 0 0 0 r
F P
0 g
s
.50225 .48868 m .50189 .48984 L .50188 .48984 L p .675 .726 .215 r
F P
0 g
s
.50709 .49394 m .50786 .49329 L .50785 .49329 L p .459 .814 .538 r
F P
0 g
s
.50785 .49329 m .50709 .49394 L .50709 .49394 L p .459 .814 .538 r
F P
0 g
s
.50709 .50606 m .50785 .50671 L .50786 .50671 L p .459 0 0 r
F P
0 g
s
.50867 .50761 m .50786 .50671 L .50785 .50671 L p 0 0 .477 r
F P
0 g
s
.49121 .50311 m .49026 .50345 L .49026 .50345 L p .236 .737 .667 r
F P
0 g
s
.48907 .50371 m .49026 .50345 L .49026 .50345 L p 0 0 0 r
F P
0 g
s
.5017 .50917 m .50189 .51016 L .50188 .51016 L p 0 0 .129 r
F P
0 g
s
.50188 .51016 m .5017 .50917 L .5017 .50917 L p 0 0 .129 r
F P
0 g
s
.49195 .49728 m .4912 .49689 L .49121 .49689 L p .327 0 0 r
F P
0 g
s
.49121 .49689 m .49195 .49728 L .49195 .49728 L p .327 0 0 r
F P
0 g
s
.50167 .49167 m .5017 .49083 L .5017 .49083 L p 0 0 0 r
F P
0 g
s
.50189 .48984 m .5017 .49083 L .5017 .49083 L p 0 0 0 r
F P
0 g
s
.50638 .49439 m .50709 .49394 L .50709 .49394 L p .381 .798 .597 r
F P
0 g
s
.50709 .49394 m .50638 .49439 L .50638 .49439 L p .381 .798 .597 r
F P
0 g
s
.49195 .50272 m .49121 .50311 L .4912 .50311 L p .327 .779 .628 r
F P
0 g
s
.49026 .50345 m .4912 .50311 L .49121 .50311 L p .236 .737 .667 r
F P
0 g
s
.50638 .50561 m .50709 .50606 L .50709 .50606 L p .381 0 0 r
F P
0 g
s
.50786 .50671 m .50709 .50606 L .50709 .50606 L p .459 0 0 r
F P
0 g
s
.50167 .50833 m .5017 .50917 L .5017 .50917 L p 0 0 .032 r
F P
0 g
s
.5017 .50917 m .50167 .50833 L .50167 .50833 L p 0 0 .032 r
F P
0 g
s
.49253 .4977 m .49195 .49728 L .49195 .49728 L p .419 0 0 r
F P
0 g
s
.49195 .49728 m .49254 .4977 L .49253 .4977 L p .419 0 0 r
F P
0 g
s
.50174 .49239 m .50167 .49167 L .50167 .49167 L p 0 0 .077 r
F P
0 g
s
.5017 .49083 m .50167 .49167 L .50167 .49167 L p 0 0 0 r
F P
0 g
s
.50572 .49468 m .50638 .49439 L .50638 .49439 L p .288 .763 .649 r
F P
0 g
s
.50638 .49439 m .50572 .49469 L .50572 .49468 L p .288 .763 .649 r
F P
0 g
s
.49254 .5023 m .49195 .50272 L .49195 .50272 L p .419 .808 .573 r
F P
0 g
s
.4912 .50311 m .49195 .50272 L .49195 .50272 L p .327 .779 .628 r
F P
0 g
s
.50572 .50531 m .50638 .50561 L .50638 .50561 L p .288 0 0 r
F P
0 g
s
.50709 .50606 m .50638 .50561 L .50638 .50561 L p .381 0 0 r
F P
0 g
s
.50174 .50761 m .50167 .50833 L .50167 .50833 L p 0 0 0 r
F P
0 g
s
.50167 .50833 m .50174 .50761 L .50174 .50761 L p 0 0 0 r
F P
0 g
s
.50191 .493 m .50174 .49239 L .50174 .49239 L p 0 0 .19 r
F P
0 g
s
.50167 .49167 m .50174 .49239 L .50174 .49239 L p 0 0 .077 r
F P
0 g
s
.49298 .49815 m .49253 .4977 L .49254 .4977 L p .506 .007 0 r
F P
0 g
s
.49254 .4977 m .49298 .49815 L .49298 .49815 L p .506 .007 0 r
F P
0 g
s
.50511 .49484 m .50572 .49468 L .50572 .49469 L p .182 .707 .687 r
F P
0 g
s
.50572 .49469 m .50511 .49484 L .50511 .49484 L p .182 .707 .687 r
F P
0 g
s
.49298 .50185 m .49254 .5023 L .49253 .5023 L p .506 .819 .5 r
F P
0 g
s
.49195 .50272 m .49253 .5023 L .49254 .5023 L p .419 .808 .573 r
F P
0 g
s
.50511 .50516 m .50572 .50531 L .50572 .50532 L p .182 0 0 r
F P
0 g
s
.50638 .50561 m .50572 .50532 L .50572 .50531 L p .288 0 0 r
F P
0 g
s
.50191 .507 m .50174 .50761 L .50174 .50761 L p 0 0 0 r
F P
0 g
s
.50174 .50761 m .50191 .507 L .50191 .507 L p 0 0 0 r
F P
0 g
s
.50215 .49351 m .50191 .493 L .50191 .493 L p 0 0 .303 r
F P
0 g
s
.50174 .49239 m .50191 .493 L .50191 .493 L p 0 0 .19 r
F P
0 g
s
.4933 .49861 m .49298 .49815 L .49298 .49815 L p .583 .145 0 r
F P
0 g
s
.49298 .49815 m .4933 .49861 L .4933 .49861 L p .583 .145 0 r
F P
0 g
s
.50455 .49489 m .50511 .49484 L .50511 .49484 L p .065 .628 .708 r
F P
0 g
s
.50511 .49484 m .50455 .49489 L .50455 .49489 L p .065 .628 .708 r
F P
0 g
s
.4933 .50139 m .49298 .50185 L .49298 .50185 L p .583 .807 .409 r
F P
0 g
s
.49253 .5023 m .49298 .50185 L .49298 .50185 L p .506 .819 .5 r
F P
0 g
s
.50455 .50511 m .50511 .50516 L .50511 .50516 L p .065 0 0 r
F P
0 g
s
.50572 .50532 m .50511 .50516 L .50511 .50516 L p .182 0 0 r
F P
0 g
s
.50215 .50649 m .50191 .507 L .50191 .507 L p 0 0 0 r
F P
0 g
s
.50191 .507 m .50215 .50649 L .50215 .50649 L p 0 0 0 r
F P
0 g
s
.50244 .49393 m .50215 .49351 L .50215 .49351 L p 0 0 .41 r
F P
0 g
s
.50191 .493 m .50215 .49351 L .50215 .49351 L p 0 0 .303 r
F P
0 g
s
.49352 .49908 m .4933 .49861 L .4933 .49861 L p .645 .283 0 r
F P
0 g
s
.4933 .49861 m .49352 .49908 L .49352 .49908 L p .645 .283 0 r
F P
0 g
s
.50404 .49485 m .50455 .49489 L .50455 .49489 L p 0 .528 .709 r
F P
0 g
s
.50455 .49489 m .50403 .49485 L .50404 .49485 L p 0 .528 .709 r
F P
0 g
s
.49352 .50092 m .4933 .50139 L .4933 .50139 L p .645 .771 .303 r
F P
0 g
s
.49298 .50185 m .4933 .50139 L .4933 .50139 L p .583 .807 .409 r
F P
0 g
s
.50403 .50515 m .50455 .50511 L .50455 .50511 L p 0 0 0 r
F P
0 g
s
.50511 .50516 m .50455 .50511 L .50455 .50511 L p .065 0 0 r
F P
0 g
s
.50244 .50607 m .50215 .50649 L .50215 .50649 L p 0 0 0 r
F P
0 g
s
.50215 .50649 m .50244 .50607 L .50244 .50607 L p 0 0 0 r
F P
0 g
s
.50278 .49427 m .50244 .49393 L .50244 .49393 L p 0 .005 .505 r
F P
0 g
s
.50215 .49351 m .50244 .49393 L .50244 .49393 L p 0 0 .41 r
F P
0 g
s
.49364 .49955 m .49352 .49908 L .49352 .49908 L p .688 .413 0 r
F P
0 g
s
.49352 .49908 m .49365 .49955 L .49364 .49955 L p .688 .413 0 r
F P
0 g
s
.50357 .49472 m .50404 .49485 L .50403 .49485 L p 0 .411 .688 r
F P
0 g
s
.50403 .49485 m .50357 .49472 L .50357 .49472 L p 0 .411 .688 r
F P
0 g
s
.49365 .50045 m .49352 .50092 L .49352 .50092 L p .688 .711 .187 r
F P
0 g
s
.4933 .50139 m .49352 .50092 L .49352 .50092 L p .645 .771 .303 r
F P
0 g
s
.50357 .50528 m .50403 .50515 L .50404 .50515 L p 0 0 0 r
F P
0 g
s
.50455 .50511 m .50404 .50515 L .50403 .50515 L p 0 0 0 r
F P
0 g
s
.50278 .50573 m .50244 .50607 L .50244 .50607 L p 0 0 0 r
F P
0 g
s
.50244 .50607 m .50278 .50573 L .50278 .50573 L p 0 0 0 r
F P
0 g
s
.50316 .49453 m .50278 .49427 L .50278 .49427 L p 0 .147 .585 r
F P
0 g
s
.50244 .49393 m .50278 .49427 L .50278 .49427 L p 0 .005 .505 r
F P
0 g
s
.49368 .5 m .49364 .49955 L .49365 .49955 L p .71 .53 0 r
F P
0 g
s
.49365 .49955 m .49368 .5 L .49368 .5 L p .71 .53 0 r
F P
0 g
s
.50316 .49453 m .50357 .49472 L .50357 .49472 L p 0 .283 .646 r
F P
0 g
s
.50357 .49472 m .50316 .49453 L .50316 .49453 L p 0 .283 .646 r
F P
0 g
s
.49368 .5 m .49365 .50045 L .49364 .50045 L p .71 .629 .066 r
F P
0 g
s
.49352 .50092 m .49364 .50045 L .49365 .50045 L p .688 .711 .187 r
F P
0 g
s
.50316 .50547 m .50357 .50528 L .50357 .50528 L p 0 0 0 r
F P
0 g
s
.50404 .50515 m .50357 .50528 L .50357 .50528 L p 0 0 0 r
F P
0 g
s
.50316 .50547 m .50278 .50573 L .50278 .50573 L p 0 0 0 r
F P
0 g
s
.50278 .50573 m .50316 .50547 L .50316 .50547 L p 0 0 0 r
F P
0 g
s
.50278 .49427 m .50316 .49453 L .50316 .49453 L p 0 .147 .585 r
F P
0 g
s
.49364 .50045 m .49368 .5 L .49368 .5 L p .71 .629 .066 r
F P
0 g
s
.50357 .50528 m .50316 .50547 L .50316 .50547 L p 0 0 0 r
F P
0 g
s
.93746 .50228 m .9375 .50014 L .9375 .50014 L p 0 0 .312 r
F P
0 g
s
.9375 .50014 m .93752 .50228 L .93746 .50228 L p 0 0 .312 r
F P
0 g
s
.28325 .12001 m .28138 .12104 L .28137 .12104 L p .629 .962 .866 r
F P
0 g
s
.28137 .12104 m .28322 .11996 L .28325 .12001 L p .629 .962 .866 r
F P
0 g
s
.2793 .87771 m .28113 .87881 L .28112 .87882 L p .636 .074 0 r
F P
0 g
s
.28112 .87882 m .27927 .87776 L .2793 .87771 L p .636 .074 0 r
F P
0 g
s
.93731 .48848 m .93752 .49772 L .93746 .49772 L p 0 0 .338 r
F P
0 g
s
.9375 .49986 m .93746 .49772 L .93752 .49772 L p 0 0 .32 r
F P
0 g
s
.93746 .49772 m .9375 .49986 L .93749 .49986 L p 0 0 .323 r
F P
0 g
s
.29132 .88448 m .28322 .88004 L .28325 .87999 L p .613 .044 0 r
F P
0 g
s
.28138 .87896 m .28325 .87999 L .28322 .88004 L p .629 .065 0 r
F P
0 g
s
.28325 .87999 m .28138 .87896 L .28137 .87895 L p .631 .067 0 r
F P
0 g
s
.27137 .12704 m .27927 .12224 L .2793 .12229 L p .652 .97 .852 r
F P
0 g
s
.28113 .12119 m .2793 .12229 L .27927 .12224 L p .636 .965 .862 r
F P
0 g
s
.2793 .12229 m .28113 .12119 L .28113 .12119 L p .638 .965 .863 r
F P
0 g
s
.28125 .12111 m .28126 .12113 L .28123 .12114 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .12111 m .28128 .12111 L .28126 .12113 L closepath p .633 .964 .864 r
F P
0 g
s
.9375 .5 m .93748 .5 L .93748 .49997 L closepath p 0 0 .317 r
F P
0 g
s
.9375 .5 m .93748 .50003 L .93748 .5 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .87889 m .28126 .87887 L .28128 .87889 L closepath p .633 .07 0 r
F P
0 g
s
.28125 .87889 m .28123 .87886 L .28126 .87887 L closepath p .633 .07 0 r
F P
0 g
s
.9375 .5 m .93748 .50006 L .93748 .50003 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .12111 m .28131 .1211 L .28128 .12111 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28121 .87884 L .28123 .87886 L closepath p .633 .07 0 r
F P
0 g
s
.28125 .12111 m .28123 .12114 L .28121 .12116 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28128 .87889 L .28131 .8789 L closepath p .633 .07 0 r
F P
0 g
s
.9375 .5 m .93748 .49997 L .93748 .49994 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .87889 m .28131 .8789 L .28133 .87892 L closepath p .633 .07 0 r
F P
0 g
s
.9375 .5 m .93749 .50008 L .93748 .50006 L closepath p 0 0 .317 r
F P
0 g
s
.9375 .5 m .93748 .49994 L .93749 .49992 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .12111 m .28121 .12116 L .28118 .12117 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28118 .87883 L .28121 .87884 L closepath p .633 .07 0 r
F P
0 g
s
.28125 .12111 m .28133 .12108 L .28131 .1211 L closepath p .633 .964 .864 r
F P
0 g
s
.9375 .5 m .93749 .49992 L .93749 .49989 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .87889 m .28116 .87882 L .28118 .87883 L closepath p .633 .07 0 r
F P
0 g
s
.28125 .12111 m .28135 .12107 L .28133 .12108 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28133 .87892 L .28135 .87893 L closepath p .633 .07 0 r
F P
0 g
s
.9375 .5 m .93749 .50011 L .93749 .50008 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .12111 m .28118 .12117 L .28116 .12118 L closepath p .633 .964 .864 r
F P
0 g
s
.9375 .5 m .93749 .50012 L .93749 .50011 L closepath p 0 0 .316 r
F P
0 g
s
.28125 .12111 m .28136 .12106 L .28135 .12107 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28115 .87882 L .28116 .87882 L closepath p .633 .07 0 r
F P
0 g
s
.28125 .87889 m .28135 .87893 L .28136 .87894 L closepath p .633 .069 0 r
F P
0 g
s
.28125 .12111 m .28116 .12118 L .28115 .12118 L closepath p .633 .964 .864 r
F P
0 g
s
.9375 .5 m .93749 .49989 L .93749 .49988 L closepath p 0 0 .317 r
F P
0 g
s
.9375 .5 m .93749 .49988 L .93749 .49986 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .12111 m .28115 .12118 L .28113 .12119 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28136 .87894 L .28137 .87895 L closepath p .633 .069 0 r
F P
0 g
s
.28125 .12111 m .28137 .12105 L .28136 .12106 L closepath p .633 .964 .864 r
F P
0 g
s
.9375 .5 m .93749 .50014 L .93749 .50012 L closepath p 0 0 .316 r
F P
0 g
s
.28125 .87889 m .28113 .87881 L .28115 .87882 L closepath p .633 .07 0 r
F P
0 g
s
.9375 .5 m .9375 .50014 L .93749 .50014 L closepath p 0 0 .316 r
F P
0 g
s
.28125 .12111 m .28138 .12104 L .28137 .12105 L closepath p .632 .964 .864 r
F P
0 g
s
.28125 .87889 m .28113 .87881 L .28113 .87881 L closepath p .633 .07 0 r
F P
0 g
s
.9375 .5 m .93749 .49986 L .9375 .49986 L closepath p 0 0 .317 r
F P
0 g
s
.28125 .12111 m .28113 .12119 L .28113 .12119 L closepath p .633 .964 .864 r
F P
0 g
s
.28125 .87889 m .28137 .87895 L .28138 .87896 L closepath p .632 .069 0 r
F P
0 g
s
.28322 .88004 m .28137 .87896 L .28138 .87896 L p .629 .065 0 r
F P
0 g
s
.28125 .87889 m .28138 .87896 L .28137 .87896 L closepath p .632 .069 0 r
F P
0 g
s
.27927 .12224 m .28112 .12118 L .28113 .12119 L p .636 .965 .862 r
F P
0 g
s
.28125 .12111 m .28113 .12119 L .28112 .12118 L closepath p .633 .964 .864 r
F P
0 g
s
.93752 .49772 m .9375 .49986 L .9375 .49986 L p 0 0 .32 r
F P
0 g
s
.9375 .5 m .9375 .49986 L .9375 .49986 L closepath p 0 0 .316 r
F P
0 g
s
.9375 .5 m .9375 .50014 L .9375 .50014 L closepath p 0 0 .316 r
F P
0 g
s
.28125 .87889 m .28112 .87882 L .28113 .87881 L closepath p .633 .069 0 r
F P
0 g
s
.28125 .12111 m .28137 .12104 L .28138 .12104 L closepath p .632 .964 .864 r
F P
0 g
s
.54573 .9351 m
.5 .9375 L
s
.59096 .92794 m
.54573 .9351 L
s
.63519 .91609 m
.59096 .92794 L
s
.67795 .89968 m
.63519 .91609 L
s
.71875 .87889 m
.67795 .89968 L
s
.75716 .85394 m
.71875 .87889 L
s
.79274 .82513 m
.75716 .85394 L
s
.82513 .79274 m
.79274 .82513 L
s
.85394 .75716 m
.82513 .79274 L
s
.87889 .71875 m
.85394 .75716 L
s
.89968 .67795 m
.87889 .71875 L
s
.89968 .67795 m
.91609 .63519 L
s
.91609 .63519 m
.92794 .59096 L
s
.92794 .59096 m
.9351 .54573 L
s
.9367 .51535 m
.9375 .5 L
s
.9351 .54573 m
.93651 .51898 L
s
.9367 .48465 m
.9375 .5 L
s
.9351 .45427 m
.93651 .48102 L
s
.92794 .40904 m
.9351 .45427 L
s
.91609 .36481 m
.92794 .40904 L
s
.89968 .32205 m
.91609 .36481 L
s
.87889 .28125 m
.89968 .32205 L
s
.85394 .24284 m
.87889 .28125 L
s
.82513 .20726 m
.85394 .24284 L
s
.79274 .17487 m
.82513 .20726 L
s
.75716 .14606 m
.79274 .17487 L
s
.71875 .12111 m
.75716 .14606 L
s
.67795 .10032 m
.71875 .12111 L
s
.63519 .08391 m
.67795 .10032 L
s
.59096 .07206 m
.63519 .08391 L
s
.54573 .0649 m
.59096 .07206 L
s
.5 .0625 m
.54573 .0649 L
s
.45427 .9351 m
.5 .9375 L
s
.40904 .92794 m
.45427 .9351 L
s
.36481 .91609 m
.40904 .92794 L
s
.32205 .89968 m
.34247 .90752 L
s
.34247 .90752 m
.36481 .91609 L
s
.28125 .87889 m
.29495 .88586 L
s
.29819 .88752 m
.30868 .89286 L
s
.30868 .89286 m
.32205 .89968 L
s
.26836 .87051 m
.28125 .87889 L
s
.25543 .86212 m
.26531 .86853 L
s
.24284 .85394 m
.25543 .86212 L
s
.20726 .82513 m
.24284 .85394 L
s
.17487 .79274 m
.20726 .82513 L
s
.14606 .75716 m
.17487 .79274 L
s
.12111 .71875 m
.14606 .75716 L
s
.10032 .67795 m
.12111 .71875 L
s
.08391 .63519 m
.10032 .67795 L
s
.07206 .59096 m
.08391 .63519 L
s
.0649 .54573 m
.07206 .59096 L
s
.0625 .5 m
.0649 .54573 L
s
.0649 .45427 m
.0625 .5 L
s
.07206 .40904 m
.0649 .45427 L
s
.08391 .36481 m
.07206 .40904 L
s
.10032 .32205 m
.08391 .36481 L
s
.12111 .28125 m
.10032 .32205 L
s
.14606 .24284 m
.12111 .28125 L
s
.17487 .20726 m
.14606 .24284 L
s
.17487 .20726 m
.20726 .17487 L
s
.20726 .17487 m
.24284 .14606 L
s
.26836 .12949 m
.28125 .12111 L
s
.25543 .13788 m
.26531 .13147 L
s
.24284 .14606 m
.25543 .13788 L
s
.28125 .12111 m
.29495 .11414 L
s
.29819 .11248 m
.30868 .10714 L
s
.30868 .10714 m
.32205 .10032 L
s
.32205 .10032 m
.34247 .09248 L
s
.34247 .09248 m
.36481 .08391 L
s
.40904 .07206 m
.36481 .08391 L
s
.45427 .0649 m
.40904 .07206 L
s
.5 .0625 m
.45427 .0649 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
        ImageSize->{288, 288},
        ImageMargins->{{0, 0}, {0, 0}},
        ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ROooo`d0002:
oooo001ooooo2P0000goool:0000P?ooo`00NOooo`H0000Qoooo1P0007[oool007Coool50000;Ooo
o`D0001eoooo001aoooo0`0003Ooool30000L_ooo`00KOooo`@0000moooo100006koool006[oool3
0000AOooo`<0001[oooo001Woooo0`0004_oool30000J?ooo`00I?ooo`<0001Aoooo0`0006Goool0
067oool300000oooo`H0001>oooo0`0006;oool005koool300000_ooo`@000000g7NkP000000000;
0000BOooo`<0001Ooooo001Koooo0`0000;oool3000000Aag^h00000002;iOT400000Vk4o`L00000
0cFak@00000000060000A?ooo`<0001Loooo001Ioooo0P000003oooo0000000000H00003WNKl00@0
002=a_^=a_^=a_/6000016k4o`D00003=K7]100004?oool20000F_ooo`00F?ooo`D00009WNKl0`00
00R=a_/500001fk4o`H00013oooo0P0005Soool005Koool:00001:[UnP800003WlGc100000Z=a_/4
00001Fk4o`@00014oooo0P0005Koool005?ooolB000029o5l`D0000;SLKk0`0000=3RN/30000A?oo
o`80001Doooo001Aoooo2`0000FdhoL200000Z_3j`@00009WlGc100000R=a_/0100007BHi`000000
0093RN/30000AOooo`80001Boooo001@oooo10000004]_Ka0000000000001;_Rl`H00007Zl?[0`00
00ZOaO<3000018g6n`030000M9SWM9SW009dV>L0100004>9jd>9jd>9j`800016oooo00<0003ooooo
ool0Coooo`00Coooo`8000000kggk`0000000004`^;_0`0000>kh_<200000[C2i0800008Zl?[0`00
00^OaO<300001WBHi`040000@hW[@hW[@hW[0`0004Goool20000Coooo`00COooo`D00002an;/0P00
00K2h^l200001[C2i0800009Zl?[100000NOaO<2000000>>W]h0001dV>L01GBHi`800002@hW[0`00
04Koool00`000?ooooooo`1<oooo001<oooo100000;<i>T01@000<ORk<ORk<ORk0000004`^;_0P00
0003_<;O0000]<;T00Jd`^@200002j_3j`800003WlGc0P0000B>W]h200001WBHi`040000@hW[@hW[
@hW[0`0004Goool20000C?ooo`00B_ooo`H00002c>CY00<00037h^c7h^`00/ORk08000000l;Rk`00
0;c2g`03_<;O0P0000Nd`^@300002j_3j`800008SYkN00<0001dV>MdV>L017BHi`800002@hW[0`00
04Koool20000B_ooo`00B?ooo`D000000mK[i00000000003c>CY00<00037h^c7h^`00/ORk0800007
_<;O00<0002d`^Bd`^@01kC2i0800009Zl?[00<0002NXML0000028jNgP030000M9SWM9SW00EdV>L0
100004>9jd>9jd>9j`<00016oooo00<0003oooooool0Aoooo`00A_ooo`D000000mW`h@000=K[i002
00000lcTj@030000an;/an;/00800002`lCJ00<0002l`]nl`]l01Kc2g`030000]<;T]<;T00Rd`^@2
00001J_3j`800003WZ7G00<0002>W]j>W]h01XjNgP030000M9SWM9SW00EdV>L0100004>9jd>9jd>9
j`<00016oooo0P0004Ooool004Goool02@000?ooo`000=clf=cfgMW`h@000=K[i0000002dNOV00@0
003<i>W<i>W<i>T200001L?4fP030000_<;O_<;O00Fl`]l200002[C2i0800002Zl?[00<0002NXMNN
XML019jQe`800007SYkN0P0000IdV>L200000d>9j`<00016oooo00<0003oooooool0A?ooo`00A?oo
o`040000oooo0000g?cH0P000004fO3Q0000e^_T00000]7WiP060000c>CY00000000b/KF00001/?4
fP030000_<;O_<;O00Jl`]l00`000;C2i;C2i009]<;T0P0000VNXML00`0008jNgXjNgP06SYkN00<0
001dV>MdV>L01GBHi`070000@hW[@hW[@hW[000005C8000004Koool00`000?ooooooo`13oooo0013
oooo00<0003oool000000`000005fO3Q0000e^_Te^_T000000;AinH200000l[6eP030000`lCJ`lCJ
00G3a=X00`000;c2gkc2g`06_<;O00<0002d`^Bd`^@01kC2i08000000jVSd@0009jQe`08WZ7G00<0
002>W]j>W]h01XjNgP030000M9SWM9SW00EdV>L00`0004>9jd>9j`02@hW[0P0004Koool00`000?oo
ooooo`12oooo0012oooo00<0003oool000000P000004g?KM0000fO3Q00000]K[i0040000dNOV0000
00001L[6eP030000`lCJ`lCJ00G3a=X00`000;c2gkc2g`06_<;O00<0002d`^Bd`^@01KC2i0030000
ZJ?AZJ?A00:YXm400`0009jQeijQe`07WZ7G00<0002>W]j>W]h01XjNgP800006M9SW0P0000=3RN/3
0000AOooo`030000oooooooo047oool0043oool2000000Coool00000003Lo=P2000000CIl>40003F
jnCFjn@3000000?@bM<0003:a]H01<[6eP030000`lCJ`lCJ00G3a=X00`000;c2gkc2g`07_<;O0P00
00Bd`^@00`000:VSdJVSd@04ZJ?A00<0002NXMNNXML01ijQe`030000SYkNSYkN00N>W]h00`0007BH
igBHi`05M9SW00L00013RN]3RN]3RN/00000E<P00000AOooo`800011oooo000ooooo00H0003ooooo
ooooool0003Lo=P200000]W`h@040000e^_T000000001=39d`030000b/KFb/KF00?:a]H00`000<?4
f/?4fP05`lCJ00<0002l`]nl`]l02;c2g`040000]<;T000000002:VSd@030000WZ7GWZ7G00NNXML0
0`0008jNgXjNgP07SYkN00<0001dV>MdV>L01GBHi`800003@hW[0`0004Goool00`000?ooooooo`0n
oooo000noooo00D0003oooooooooool000000]clf08000001]W`h@00000000000=S>d00000C@bM<0
0`000<[6e/[6eP03b/KF00<00033a=[3a=X01/?4fP030000_<;O_<;O00Rl`]l00`000:VSdJVSd@09
ZJ?A00<0002NXMNNXML01ijQe`030000SYkNSYkN00N>W]h00`0007BHigBHi`06M9SW00L00013RN]3
RN]3RN/00000E<P00000AOooo`030000oooooooo03goool003goool01@000?ooooooooooo`000002
g?cH0P000003fO3Q0000000000?Hc]000`000=39dm39d`02d<WC00<0003:a]K:a]H01<[6eP030000
`lCJ`lCJ00K3a=X00`000;c2gkc2g`05_<;O0P000003/ZG<0000ZJ?A00ZYXm400`0009jQeijQe`07
WZ7G0P0000R>W]h200001gBHi`030000@hW[@hW[0093RN/00`000?ooooooo`14oooo00<0003ooooo
ool0??ooo`00??ooo`040000oooooooooooo0P000003g?cH0000g?KM008000000n3Ec@000=S>d002
f<k@00<0003@bM?@bM<00m39d`030000b/KFb/KF00C:a]H00`000<?4f/?4fP06`lCJ00<0002l`]nl
`]l00[c2g`800004/ZG<00<0002YXm6YXm402JVSd@030000WZ7GWZ7G00RNXML00`0008jNgXjNgP07
SYkN00<0001dV>MdV>L01GBHi`060000@hW[@hW[00004cbi0000A_ooo`030000oooooooo03_oool0
03_oool010000?ooooooooooo`800002g?cH0P0000?PeLd01@000=S>d=S>d=S>d0000005d<WC00<0
003:a]K:a]H01<[6eP030000`lCJ`lCJ00O3a=X010000;c2g`00000000NbYL`00`000:VSdJVSd@09
ZJ?A00<0002NXMNNXML029jQe`030000SYkNSYkN00N>W]h00`0007BHigBHi`06M9SW00@0000C?;TC
?;T00017oooo00<0003oooooool0>_ooo`00>_ooo`040000oooooooooooo1@000003jMk80000h=G=
00;PeLd01@000=S>d=S>d=S>d0000005d<WC00<0003:a]K:a]H01L[6eP030000`lCJ`lCJ00K3a=X2
00002[:Uc0030000ZJ?AZJ?A00VYXm400`0009jQeijQe`08WZ7G00<0002>W]j>W]h01hjNgP030000
M9SWM9SW00AdV>L200000a<l^@030000oooooooo04Goool00`000?ooooooo`0ioooo000ioooo00<0
003oooooool00_ooo`800002lNW100<0003Yg/P000000n3Ec@050000f<k@f<k@f<k@000000G@bM<0
0`000<[6e/[6eP05b/KF00<00033a=[3a=X01<?4fP800002^ZO700<0002bYLbbYL`02;:Uc0030000
ZJ?AZJ?A00VYXm400`0009jQeijQe`08WZ7G00<0002>W]j>W]h01hjNgP800003M9SW00@0001IILAI
IL@000024cbi00<0003oooooool0A_ooo`030000oooooooo03Soool003Soool00`000?ooooooo`02
oooo00L0003dl[7ajL7ajL40003Yg/P000000n3Ec@030000f<k@f<k@00;Hc]000`000=39dm39d`04
d<WC00<0003:a]K:a]H01L[6eP040000`lCJ`lCJ`lCJ0P0000BjYlL00`000;:Uc;:Uc008/ZG<00<0
002YXm6YXm402JVSd@030000WZ7GWZ7G00VNXML00`0008jNgXjNgP08SYkN00<0001dV>L000000eUU
a00500004cbi4cbi4cbi000004Soool00`000?ooooooo`0goooo000goooo00<0003oooooool00ooo
o`800002lNW100<0003Yg/P000000n3Ec@030000f<k@f<k@00;Hc]000`000=39dm39d`04d<WC00<0
003:a]K:a]H01L[6eP040000`lCJ000000001kZWa`030000/ZG</ZG<00RbYL`00`000:VSdJVSd@09
ZJ?A00<0002NXMNNXML02IjQe`030000SYkNSYkN00R>W]h00`0005UUa5UUa003FFG400@0000C?;TC
?;T00019oooo00<0003oooooool0=_ooo`00=_ooo`030000oooooooo00?oool00`000?Cb/@000002
lNW100<0003Yg/P000000n3Ec@030000f<k@f<k@00;Hc]000`000=39dm39d`04d<WC00<0003:a]K:
a]H01/[6eP030000^ZO7^ZO700RjYlL00`000;:Uc;:Uc008/ZG<00<0002YXm6YXm402JVSd@030000
WZ7GWZ7G00VNXML200001XjNgP<00005FFG400D0000C?;TC?;TC?;T00000BOooo`030000oooooooo
03Goool003Goool00`000?ooooooo`04oooo0P0000;ajL4010000>WNb>WNb00000?PeLd00`000=S>
d=S>d003f<k@00<0003@bM?@bM<01=39d`030000b/KFb/KF00?:a]H2000000?1Z/<0002jYlL02;ZW
a`030000/ZG</ZG<00VbYL`00`000:VSdJVSd@09ZJ?A00<0002NXMNNXML02YjQe`030000SYkNSYkN
00:>W]h01@0007Yg`gYg`gYg``000005FFG400@0000C?;TC?;T0001:oooo00<0003oooooool0=?oo
o`00=?ooo`030000oooooooo00Coool300000_7Y`@040000jMk8jMk800000n3Ec@030000f<k@f<k@
00?Hc]000`000=39dm39d`04d<WC00<0003:a]K:a]H00/[6eP050000`J[3`J[3`J[3000000ZjYlL0
0`000;:Uc;:Uc009/ZG<00<0002YXm6YXm402JVSd@030000WZ7GWZ7G00ZNXML0100008jNgP000000
00AjMl<00`0005UUa5UUa003FFG400D0000C?;TC?;TC?;T00000B_ooo`030000oooooooo03?oool0
03?oool00`000?ooooooo`05oooo0P0000?ajL400`000>WNb0000004h=G=00<0003Hc]3Hc]000mS>
d0030000d<WCd<WC00C@bM<01@000<[6e/[6e/[6eP000005`J[300<0002jYlNjYlL02;ZWa`030000
/ZG</ZG<00VbYL`00`000:VSdJVSd@09ZJ?A00<0002NXMNNXML02YjQe`030000NWO3NWO300EjMl<0
0`0005UUa5UUa003FFG400@0000C?;TC?;T0001;oooo00<0003oooooool0<_ooo`00<_ooo`030000
oooooooo00Goool300000_7Y`@040000jMk8jMk800001>3Ec@030000f<k@f<k@00?Hc]000`000=39
dm39d`05d<WC0`0000K1Z/<00`000;ZWakZWa`09^ZO700<0002bYLbbYL`02K:Uc0030000ZJ?AZJ?A
00VYXm400`0009jQeijQe`07WZ7G0`0000MjMl<00`0005UUa5UUa003FFG400D0000C?;TC?;TC?;T0
0000Boooo`030000oooooooo037oool0037oool00`000?ooooooo`06oooo00<0003dl[4000000_7Y
`@040000jMk8jMk800001>3Ec@030000f<k@f<k@00?Hc]000`000=39dm39d`04d<WC0P0000W1Z/<0
0`000;ZWakZWa`08^ZO700<0002bYLbbYL`02[:Uc0030000ZJ?AZJ?A00VYXm400`0009jQeijQe`04
WZ7G0P0000>>PL000`0007Yg`gYg``05NWO300<0001IILAIIL@00eUUa00400004cbi4cbi0000C?oo
o`030000oooooooo033oool0033oool00`000?ooooooo`06oooo0`0000?ajL4010000>WNb>WNb000
00CPeLd00`000=S>d=S>d003f<k@00<0003@bM?@bM<00]39d`800002bJfn2/6Z``030000^ZO7^ZO7
00RjYlL00`000;:Uc;:Uc00:/ZG<00<0002YXm6YXm402JVSd@030000WZ7GWZ7G00:NXML00`0008j1
`8j1`003SX7000<0001jMl=jMl<01GYg``030000FFG4FFG400=IIL@01@0001<l^A<l^A<l^@00001<
oooo00<0003oooooool0;oooo`00;oooo`030000oooooooo00Ooool300000_7Y`@050000jMk8jMk8
jMk8000000CPeLd00`000=S>d=S>d003f<k@00<0003@bM?@bM<00P0000C9[Kh00`000<6Z`l6Z``07
`J[300<0002jYlNjYlL02KZWa`030000/ZG</ZG<00ZbYL`00`000:VSdJVSd@09ZJ?A00@0002NXML0
00000007SX7000<0001jMl=jMl<01GYg``030000FFG4FFG400=IIL@0100001<l^A<l^@0004goool0
0`000?ooooooo`0^oooo000^oooo00<0003oooooool02?ooo`030000m?:a000000;ajL4010000>WN
b>WNb00000CPeLd00`000=S>d=S>d004f<k@0`0000K9[Kh00`000<6Z`l6Z``08`J[300<0002jYlNj
YlL02;ZWa`030000/ZG</ZG<00ZbYL`00`000:VSdJVSd@0:ZJ?A00<0002>PL2>PL001hj1`0030000
NWO3NWO300EjMl<00`0005UUa5UUa003FFG400D0000C?;TC?;TC?;T00000COooo`030000oooooooo
02goool002koool00`000?ooooooo`07oooo0`0000?ajL4010000>WNb>WNb00000CPeLd00`000=S>
d=S>d003f<k@0P0000W9[Kh00`000<6Z`l6Z``07`J[300<0002jYlNjYlL02KZWa`030000/ZG</ZG<
00ZbYL`00`000:VSdJVSd@07ZJ?A0P000003W8Nl0000SX7000R>PL000`0007Yg`gYg``05NWO300<0
001IILAIIL@00eUUa00400004cbi4cbi0000COooo`030000oooooooo02goool002goool00`000?oo
ooooo`08oooo0`0000;ajL401@000>WNb>WNb>WNb0000004h=G=00@0003Hc]3Hc]3Hc]0200000]6a
^PW9[Kh00`000<6Z`l6Z``08`J[300<0002jYlNjYlL02KZWa`030000/ZG</ZG<00ZbYL`00`000:VS
dJVSd@04ZJ?A0P0000>LQk`00`0008j1`8j1`007SX7000<0001jMl=jMl<01GYg``030000FFG4FFG4
00=IIL@01@0001<l^A<l^A<l^@00001=oooo00<0003oooooool0;?ooo`00;?ooo`030000oooooooo
00Soool2000000Gdl[40003ajL7ajL4000000nWNb0030000h=G=h=G=00;PeLd010000=S>d0000000
00CA/KX00`000<V]_/V]_P07bJfn00<00031Z/?1Z/<02<6Z``030000^ZO7^ZO700RjYlL00`000;:U
c;:Uc00;/ZG<00<0002YXm6YXm400ZVSd@030000W8NlW8Nl00BLQk`00`0008j1`8j1`007SX7000<0
001jMl=jMl<01GYg``030000FFG4FFG400=IIL@0100001<l^A<l^@0004koool00`000?ooooooo`0[
oooo000[oooo00<0003oooooool02Oooo`<00003lNW100D0003Yg/SYg/SYg/P000000n3Ec@<00006
dK6j00<00039[Kk9[Kh01lV]_P030000`J[3`J[300S1Z/<00`000;ZWakZWa`09^ZO700<0002bYLbb
YL`02k:Uc0040000ZJ?A000000001ib7_0030000SX70SX7000N>PL000`0007Yg`gYg``05NWO300<0
001IILAIIL@00eUUa00500004cbi4cbi4cbi000004koool00`000?ooooooo`0Zoooo000Zoooo00<0
003oooooool02Oooo`8000001OCb/@000?7Y`O7Y`@000003jMk800<0003PeLgPeLd00P000003f[Jd
0000dK6j00KA/KX00`000<V]_/V]_P08bJfn00<00031Z/?1Z/<02<6Z``030000^ZO7^ZO700VjYlL0
0`000;:Uc;:Uc00;/ZG<00<0002LQkbLQk`029b7_0030000SX70SX7000N>PL000`0007Yg`gYg``05
NWO300<0001IILAIIL@00eUUa00400004cbi4cbi0000Coooo`030000oooooooo02Woool002Woool0
0`000?ooooooo`0:oooo0`0000?ajL4010000>WNb>WNb>WNb0<00004f[Jd00<0003A/K[A/KX01M6a
^P030000bJfnbJfn00O9[Kh00`000<6Z`l6Z``08`J[300<0002jYlNjYlL02[ZWa`030000/ZG</ZG<
00RbYL`2000000>VRkP0002LQk`029b7_0030000SX70SX7000N>PL000`0007Yg`gYg``05NWO300<0
001IILAIIL@00eUUa00500004cbi4cbi4cbi000004ooool00`000?ooooooo`0Xoooo000Xoooo00<0
003oooooool02_ooo`040000hNf9000000000o7Y`@030000jMk8jMk800800006f[Jd00<0003A/K[A
/KX01M6a^P030000bJfnbJfn00S9[Kh00`000<6Z`l6Z``08`J[300<0002jYlNjYlL02KZWa`030000
/ZG</ZG<00JbYL`200000jJ;^0030000W8NlW8Nl00RLQk`00`0008j1`8j1`007SX7000<0001jMl=j
Ml<01GYg``030000FFG4FFG400=IIL@0100001<l^A<l^@00053oool00`000?ooooooo`0Woooo000X
oooo00<0003oooooool02_ooo`8000001_Cb/@000?7Y`O7Y`@000>WNb08000000nJl[0000=Zf]005
f[Jd00<0003A/K[A/KX01]6a^P030000bJfnbJfn00O9[Kh00`000<6Z`l6Z``09`J[300<0002jYlNj
YlL02KZWa`030000/ZG</ZG<00BbYL`00`000:J;^:J;^004YX^h00<0002LQkbLQk`01ib7_0030000
SX70SX7000N>PL000`0007Yg`gYg``05NWO300<0001IILAIIL@00eUUa00500004cbi4cbi4cbi0000
04ooool00`000?ooooooo`0Woooo000Woooo00<0003oooooool02_ooo`050000hNf900000000lNW1
00@00003i[b/00<0003J][CJ][@01=Zf]0030000dK6jdK6j00KA/KX00`000<V]_/V]_P08bJfn00<0
0031Z/?1Z/<02<6Z``030000^ZO7^ZO700ZjYlL010000;:Uc;:Uc;:Uc0800007YX^h00<0002LQkbL
Qk`029b7_0030000SX70SX7000N>PL000`0007Yg`gYg``05NWO300<0001IILAIIL@00eUUa0040000
4cbi4cbi0000D?ooo`030000oooooooo02Koool002Koool00`000?ooooooo`0;oooo1@0000;ca9d0
0`000>Jl[>Jl[003i[b/00<0003J][CJ][@01=Zf]0030000dK6jdK6j00GA/KX00`000<V]_/V]_P08
bJfn00<00031Z/?1Z/<02L6Z``030000^ZO7^ZO700VjYlL010000;:Uc000000000ZVRkP00`0009b7
_9b7_007W8Nl00<0002>PL2>PL001hj1`0030000NWO3NWO300EjMl<00`0005UUa5UUa003FFG400D0
000C?;TC?;TC?;T00000D?ooo`030000oooooooo02Goool002Koool00`000?ooooooo`0;oooo0P00
0003olYn0000llBM00;ca9d00`000>Jl[>Jl[003i[b/00<0003J][CJ][@01=Zf]0030000dK6jdK6j
00KA/KX00`000<V]_/V]_P08bJfn00<00031Z/?1Z/<02<6Z``030000^ZO7^ZO700ZjYlL00`000:J;
^:J;^00:YX^h00<0002LQkbLQk`029b7_0030000SX70SX7000N>PL000`0007Yg`gYg``05NWO300<0
001IILAIIL@00eUUa0<C?;T00`000?ooooooo`1>oooo00<0003oooooool09Oooo`009Oooo`030000
oooooooo00coool010000>Fa;_o:OP0000?ca9d00`000>Jl[>Jl[003i[b/00<0003J][CJ][@01=Zf
]0030000dK6jdK6j00KA/KX00`000<V]_/V]_P08bJfn00<00031Z/?1Z/<02L6Z``030000^ZO7^ZO7
00NjYlL2000000>_S[@0002VRkP02jJ;^0030000W8NlW8Nl00NLQk`00`0008j1`8j1`007SX7000<0
001jMl=jMl<01GYg``030000FFG4FFG400=IIL@01@0001<l^A<l^A<l^@00001@oooo00<0003ooooo
ool09?ooo`009Oooo`030000oooooooo00coool010000>Fa;_o:OP0000Cca9d00`000>Jl[>Jl[002
i[b/00<0003J][CJ][@01MZf]0030000dK6jdK6j00GA/KX00`000<V]_/V]_P09bJfn00<00031Z/?1
Z/<02L6Z``030000^ZO7^ZO700FjYlL01@000:n>]:n>]:n>]000000<YX^h00<0002LQkbLQk`029b7
_0030000SX70SX7000N>PL000`0007Yg`gYg``05NWO300<0001IILAIIL@00eUUa0044cbi00000000
0000D?ooo`030000oooooooo02Coool002Coool00`000?ooooooo`0=oooo00@0003U/BkobWh00004
llBM00<0003V_:cV_:`00^Jl[0030000f[Jdf[Jd00GJ][@00`000=6a^]6a^P06dK6j00<00039[Kk9
[Kh02<V]_P030000`J[3`J[300W1Z/<00`000;ZWakZWa`03^ZO70P0000F_S[@00`000:J;^:J;^00:
YX^h00<0002LQkbLQk`029b7_0030000SX70SX7000J>PL000`0007Yg`gYg``05NWO300<0001IILAI
IL@00eUUa0040000001c001c0000DOooo`030000oooooooo02?oool002?oool00`000?ooooooo`0>
oooo00@0003U/BkobWh00004llBM00<0003V_:cV_:`00nJl[0030000f[Jdf[Jd00CJ][@00`000=6a
^]6a^P06dK6j00<00039[Kk9[Kh02LV]_P030000`J[3`J[300W1Z/<01@000;ZWakZWakZWa`000007
[hjd00<0002VRkRVRkP02ZJ;^0030000W8NlW8Nl00RLQk`00`0008j1`8j1`007SX7000<0001jMl=j
Ml<01GYg``030000FFG4FFG400<00002001c00<0003oooooool0D?ooo`030000oooooooo02;oool0
02?oool00`000?ooooooo`0>oooo00D0003U/BkobWkobWh000000o?4W@030000i[b/i[b/00?V_:`0
0`000=Zf]=Zf]004f[Jd00<0003A/K[A/KX01m6a^P030000bJfnbJfn00S9[Kh00`000<6Z`l6Z``09
`J[300@0002jYlL000000009[hjd00<0002VRkRVRkP02ZJ;^0030000W8NlW8Nl00RLQk`00`0008j1
`8j1`006SX7000<0001jMl=jMl<01GYg``030000FFG40000008j;IH010000000L`00L`0005;oool0
0`000?ooooooo`0Roooo000Roooo00<0003oooooool03oooo`050000iK4^olYnolYn000000?ca9d0
0`000>Jl[>Jl[003i[b/00<0003J][CJ][@01MZf]0030000dK6jdK6j00KA/KX00`000<V]_/V]_P09
bJfn00<00031Z/?1Z/<02<6Z``80000;[hjd00<0002VRkRVRkP02ZJ;^0030000W8NlW8Nl00RLQk`0
0`0008j1`8j1`007SX7000<0001jMl=jMl<01GYg``050000>RfF>RfF>RfF0000008007<00`000?oo
ooooo`1Aoooo00<0003oooooool08Oooo`008_ooo`030000oooooooo00ooool01@000>Fa;_o:O_o:
OP000003llBM00<0003V_:cV_:`00nJl[0030000f[Jdf[Jd00GJ][@00`000=6a^]6a^P06dK6j00<0
0039[Kk9[Kh02LV]_P030000`J[3`J[300K1Z/<200000[NA/0030000[hjd[hjd00V_S[@00`000:J;
^:J;^00:YX^h00<0002LQkbLQk`029b7_0030000SX70SX7000J>PL000`0007Yg`gYg``03NWO30`00
00<j;IH010000000L`00L`0005?oool00`000?ooooooo`0Qoooo000Qoooo00<0003oooooool04Ooo
o`8000000oo:OP000??4W@02llBM00<0003V_:cV_:`00nJl[0030000f[Jdf[Jd00GJ][@00`000=6a
^]6a^P07dK6j00<00039[Kk9[Kh02LV]_P030000`J[3`J[300?1Z/<200001;NA/0030000[hjd[hjd
00V_S[@00`000:J;^:J;^00;YX^h00<0002LQkbLQk`01ib7_0030000SX70SX7000N>PL001@0007Yg
`gYg`gYg``000002I4fQ00D0000j;IHj;IHj;IH000000P00L`030000oooooooo05;oool00`000?oo
ooooo`0Poooo000Qoooo00<0003oooooool04Oooo`8000000oo:OP000??4W@02llBM00<0003V_:cV
_:`01>Jl[0030000f[Jdf[Jd00GJ][@00`000=6a^]6a^P06dK6j00<00039[Kk9[Kh02LV]_P040000
`J[3`J[3`J[30P0000NgTK000`000:n>]:n>]009[hjd00<0002VRkRVRkP02ZJ;^0030000W8NlW8Nl
00RLQk`00`0008j1`8j1`006SX7000@0001jMl<000000003I4fQ00D0000j;IHj;IHj;IH000000P00
L`030000oooooooo05;oool00`000?ooooooo`0Poooo000Poooo00<0003oooooool04_ooo`800000
0oo:OP000??4W@03llBM00<0003V_:cV_:`00nJl[0030000f[Jdf[Jd00GJ][@00`000=6a^]6a^P06
dK6j00<00039[Kk9[Kh02/V]_P<00009]i6`00<0002_S[B_S[@02Zn>]0030000YX^hYX^h00ZVRkP0
0`0009b7_9b7_007W8Nl00<0002>PL2>PL001hj1`0030000I4fQI4fQ00=TCJ401@0003X]USX]USX]
UP000002001c00<0003oooooool0Doooo`030000oooooooo01ooool0023oool00`000?ooooooo`0B
oooo0P000003olYn0000llBM00?ca9d00`000>Jl[>Jl[003i[b/00<0003J][CJ][@01MZf]0030000
dK6jdK6j00OA/KX00`000<V]_/V]_P09bJfn00<0002gTK2gTK002[NA/0030000[hjd[hjd00V_S[@0
0`000:J;^:J;^00:YX^h00<0002LQkbLQk`029b7_0030000SX70SX7000B>PL0300001FA=X@050000
>RfF>RfF>RfF0000008007<00`000?ooooooo`0[oooo2@0001ooool00`000?ooooooo`0Ooooo000O
oooo00<0003oooooool04oooo`8000000oo:OP000??4W@03llBM00<0003V_:cV_:`00nJl[0030000
f[Jdf[Jd00GJ][@00`000=6a^]6a^P07dK6j00<00039[Kk9[Kh01lV]_P8000000kjCZP000;NA/00:
]i6`00<0002_S[B_S[@02Zn>]0030000YX^hYX^h00ZVRkP00`0009b7_9b7_007W8Nl00<0002>PL2>
PL000hj1`0040000OEjUOEjU00001FA=X@050000>RfF>RfF>RfF0000008007<00`000?ooooooo`0K
oooo60000003073D0000000001koool00`000?ooooooo`0Noooo000Ooooo00<0003oooooool04ooo
o`8000000oo:OP000??4W@03llBM00<0003V_:cV_:`01>Jl[0030000f[Jdf[Jd00GJ][@00`000=6a
^]6a^P07dK6j00<00039[Kk9[Kh01<V]_P800003_Y>Z00<0002gTK2gTK002[NA/0030000[hjd[hjd
00V_S[@00`000:J;^:J;^00:YX^h00<0002LQkbLQk`029b7_0050000SX70SX70SX70000000=mGZD0
0`0006A=XFA=X@03I4fQ00D0000j;IHj;IHj;IH000000P00L`030000oooooooo01?oool00`00036h
eC6he@04<KSE400000N<f?l01@00052JlP000000001`e00200007?ooo`030000oooooooo01koool0
01koool00`000?ooooooo`0Doooo0P000003olYn0000llBM00?ca9d00`000>Jl[>Jl[004i[b/00<0
003J][CJ][@01MZf]0030000dK6jdK6j00OA/KX00`000<V]_/V]_P03bJfn00<0002nTjZnTjX01;jC
ZP030000]i6`]i6`00VgTK000`000:n>]:n>]00:[hjd00<0002VRkRVRkP02ZJ;^0030000W8NlW8Nl
00NLQk`0100008j1`000000000EmGZD00`0006A=XFA=X@02I4fQ00D0000j;IHj;IHj;IH000000P00
L`030000oooooooo017oool900005XcHo`030000D9[bD9[b009@V_82000000<0L=@0000000006ooo
o`030000oooooooo01goool001koool00`000?ooooooo`0Doooo0P0000;obWh01@000??4WO?4WO?4
W@000006i[b/00<0003J][CJ][@01MZf]0030000dK6jdK6j00OA/KX010000<V]_/V]_/V]_P800007
_Y>Z00<0002gTK2gTK002[NA/0030000[hjd[hjd00V_S[@00`000:J;^:J;^00:YX^h00<0002LQkbL
Qk`029b7_0030000OEjUOEjU00EmGZD00`0006A=XFA=X@02I4fQ00<0000j;IHj;IH00SX]UP030000
001c0000017oool400005XcHo`T00005D9[b0P000003073D0000000001Woool00`000?ooooooo`0M
oooo000Moooo00<0003oooooool05Oooo`800002olYn00D0003ca9gca9gca9d000001^Jl[0030000
f[Jdf[Jd00KJ][@00`000=6a^]6a^P07dK6j0`0000ZnTjX00`000;NA/;NA/00:]i6`00<0002_S[B_
S[@02Jn>]0030000YX^hYX^h00ZVRkP00`0009b7_9b7_005W8Nl0`0000MmGZD00`0006A=XFA=X@02
I4fQ00<0000j;IHj;IH00SX]UP030000001c000000ooool300000[[ik0030000S=SoS=So00F<f?l?
00001jS;lP040000NIoZ000000001E2JlP8000000`1`e0000000000Hoooo00<0003oooooool07?oo
o`007Oooo`030000oooooooo01Goool200000_o:OP030000llBMllBM00;ca9d00`000>Jl[>Jl[003
i[b/00<0003J][CJ][@01]Zf]0030000dK6jdK6j00KA/KX200003;jCZP030000]i6`]i6`00ZgTK00
0`000:n>]:n>]00:[hjd00<0002VRkRVRkP02JJ;^0030000W8NlW8Nl00>LQk`200000XeYY0030000
OEjUOEjU00EmGZD00`0006A=XFA=X@02I4fQ00<0000j;IHj;IH00SX]UP030000001c000000koool2
00001;[ik0P0000FZ<_b00@0001iWnYiWnYiWnX200001E2JlP8000000`1`e0000000000Foooo00<0
003oooooool07?ooo`007?ooo`030000oooooooo01Koool200000_o:OP030000llBMllBM00;ca9d0
0`000>Jl[>Jl[004i[b/00<0003J][CJ][@01MZf]0030000dK6jdK6j00CA/KX200000/JEY0030000
_Y>Z_Y>Z00ZnTjX00`000;NA/;NA/00:]i6`00<0002_S[B_S[@02Jn>]0030000YX^hYX^h00ZVRkP0
1@0009b7_9b7_9b7_0000005SFVT00<0001mGZEmGZD017eNY@030000I4fQI4fQ00=TCJ401`0003X]
USX]USX]UP000000L`00000<oooo0P0000BjnN`300007:S;lP030000NIoZNIoZ00AiWnX200001E2J
lPD0000Eoooo00<0003oooooool06oooo`007?ooo`030000oooooooo01Koool200000_o:OP030000
llBMllBM00;ca9d00`000>Jl[>Jl[004i[b/00<0003J][CJ][@01MZf]0030000dK6jdK6j00;A/KX2
00001<JEY0030000_Y>Z_Y>Z00ZnTjX00`000;NA/;NA/00:]i6`00<0002_S[B_S[@02Zn>]0030000
YX^hYX^h00VVRkP0100009b7_000000000J=JJ@00`0007eNYGeNY@04OEjU00<0001TCJ5TCJ400fA=
X@070000>RfF>RfF>RfF0000001c000000[oool200001;[ik0800002c>SZ00<0002Xbo:Xbo806ZS;
lP030000NIoZNIoZ00IiWnX200001U2JlP@0000Coooo00<0003oooooool06oooo`006oooo`030000
oooooooo01Ooool200000_o:OP030000llBMllBM00;ca9d00`000>Jl[>Jl[004i[b/00<0003J][CJ
][@01]Zf]0040000dK6j000000001lJEY0030000_Y>Z_Y>Z00ZnTjX00`000;NA/;NA/00:]i6`00<0
002_S[B_S[@02Jn>]0030000YX^hYX^h00VVRkP2000028eYY0030000OEjUOEjU00AmGZD00`0006A=
XFA=X@03I4fQ00L0000j;IHj;IHj;IH0000007<000002?ooo`800004^_W/0P0000?<j>X00`000:S;
lZS;lP0DZ<_b2@0000UiWnX200001U2JlP@0000Boooo00<0003oooooool06_ooo`006oooo`030000
oooooooo01Ooool200000_o:OP030000llBMllBM00;ca9d00`000>Jl[>Jl[004i[b/00<0003J][CJ
][@01MZf]0<00009aYFT00<0002nTjZnTjX02kjCZP030000]i6`]i6`00VgTK000`000:n>]:n>]00:
[hjd00<0002VRkRVRkP01ZJ;^08000000iU`X`0008eYY007SFVT00<0001mGZEmGZD01GeNY@030000
I4fQI4fQ009TCJ401`0003X]USX]USX]UP000000L`000007oooo0P0000>jnN`200001LcXjP030000
Z<_bZ<_b00FXbo8?00001k6mh`040000S9cM000000002GVOjP<00005D9[b1000013oool00`000?oo
ooooo`0Joooo000Koooo00<0003oooooool05oooo`800002olYn00<0003ca9gca9d00_?4W@030000
i[b/i[b/00CV_:`00`000=Zf]=Zf]003f[Jd0P0000;?Ui/00`000<JEY<JEY008aYFT00<0002nTjZn
TjX02[jCZP030000]i6`]i6`00ZgTK000`000:n>]:n>]009[hjd00<0002VRkRVRkP01:J;^0800004
VG2S00<0002=JJB=JJ@01HeYY0030000OEjUOEjU00EmGZD00`0006A=XFA=X@02I4fQ00L0000j;IHj
;IHj;IH0000007<000001Oooo`800003^_W/0P0000O<j>X800005[6mh`040000S9cMS9cMS9cM0P00
00YiWnX200001E2JlP@0000>oooo00<0003oooooool06_ooo`006_ooo`030000oooooooo01Soool2
00000_o:OP030000llBMllBM00;ca9d00`000>Jl[>Jl[005i[b/00<0003J][CJ][@00P0000C?Ui/0
0`000<JEY<JEY009aYFT00<0002nTjZnTjX02[jCZP030000]i6`]i6`00ZgTK000`000:n>]:n>]009
[hjd00@0002VRkRVRkRVRkP200001YU`X`030000SFVTSFVT00J=JJ@00`0007eNYGeNY@04OEjU00<0
001TCJ5TCJ400VA=X@070000>RfF>RfF>RfF0000001c000000?oool200001;[ik0030000c>SZc>SZ
00G<j>X300007K6mh`030000S9cMS9cM00><W=d300002GVOjP800005D9[b100000goool00`000?oo
ooooo`0Ioooo000Joooo00<0003oooooool06Oooo`8000000oo:OP000??4W@03llBM00<0003V_:cV
_:`01NJl[0<00007ciNK00<00036UJC6UJ@02<JEY0030000_Y>Z_Y>Z00ZnTjX00`000;NA/;NA/00:
]i6`00<0002_S[B_S[@02Jn>]0040000YX^h0000000029U`X`030000SFVTSFVT00J=JJ@00`0007eN
YGeNY@04OEjU00<0001TCJ5TCJ400VA=X@080000>RfF>RfF>RfF0000001c0000oooo0P0000BjnN`2
00001/cXjP800002c]KN00<0002a_N>a_N<06k6mh`030000S9cMS9cM00J<W=d200002GVOjP800005
D9[b100000_oool00`000?ooooooo`0Ioooo000Joooo00<0003oooooool06Oooo`800002olYn00<0
003ca9gca9d00_?4W@030000i[b/i[b/00?V_:`200002/nGV`030000aYFTaYFT00S6UJ@00`000;jC
Z[jCZP0:_Y>Z00<0002gTK2gTK002[NA/0030000[hjd[hjd00V_S[@00`0009U`XiU`X`08VG2S00<0
002=JJB=JJ@01XeYY0030000OEjUOEjU00AmGZD00`0006A=XFA=X@02I4fQ00@0000j;IHj;IHj;IH4
00001;[ik0800006c>SZ0P0000C>e]h00`000;6mhk6mh`0J/KgS00<0002<W=f<W=d02HbLg@800009
NIoZ0P0000E@V_8300002_ooo`030000oooooooo01Woool001Woool00`000?ooooooo`0Joooo0P00
00;obWh00`000??4WO?4W@02llBM00@0003V_:cV_:cV_:`200000]VGS@030000ciNKciNK00O?Ui/0
0`000<JEY<JEY009aYFT00<0002nTjZnTjX02KjCZP030000]i6`]i6`00ZgTK000`000:n>]:n>]007
[hjd0`0000^IL:<00`0008eYY8eYY005SFVT00<0001mGZEmGZD017eNY@030000I4fQI4fQ009TCJ40
0`0003X]USX]UP02000000<002/0000000000[[ik0800006c>SZ0P0000K>e]h00`000;6mhk6mh`0J
/KgS00<0002<W=f<W=d02hbLg@<00008NIoZ0P0000A@V_8300002_ooo`030000oooooooo01Soool0
01Woool00`000?ooooooo`0Joooo0P0000;obWh00`000??4WO?4W@02llBM00@0003V_:`000000004
fIN=00<0003?Ui_?Ui/02<nGV`030000aYFTaYFT00S6UJ@00`000;jCZ[jCZP0:_Y>Z00<0002gTK2g
TK002[NA/0030000[hjd[hjd00F_S[@01@000:9dWj9dWj9dW`00000:VG2S00<0002=JJB=JJ@01HeY
Y0030000OEjUOEjU00AmGZD00`0006A=XFA=X@02I4fQ0`0000036`1P0000000000@00006c>SZ0P00
00S>e]h00`000;6mhk6mh`0J/KgS00<0002<W=f<W=d03XbLg@800008NIoZ0P000003D9[b00004Tk:
0080000:oooo00<0003oooooool06?ooo`006Oooo`030000oooooooo01[oool200000_o:OP040000
llBMllBMllBM0`0000OIUhd00`000<nGVlnGV`07ciNK00<00036UJC6UJ@02LJEY0030000_Y>Z_Y>Z
00ZnTjX00`000;NA/;NA/009]i6`00<0002_S[B_S[@00jn>]0800004XWBO00<0002IL:>IL:<029U`
X`030000SFVTSFVT00J=JJ@00`0007eNYGeNY@04OEjU00D0001TCJ5TCJ5TCJ4000000Q/0H0050000
000[0000dOk3000000K<j>X200002/kFgP030000/KgS/KgS00ba_N<@00004HbLg@800008NIoZ0P00
008BC/X200002Oooo`030000oooooooo01Soool001Soool00`000?ooooooo`0Koooo0P0000;obWh0
10000??4W@00000000;TUG@00`000=VGSMVGS@06fIN=00<0003?Ui_?Ui/01lnGV`030000aYFTaYFT
00S6UJ@00`000;jCZ[jCZP0:_Y>Z00<0002gTK2gTK002[NA/0050000[hjd[hjd[hjd000000NRM9l0
0`0009U`XiU`X`07VG2S00<0002=JJB=JJ@01XeYY0030000OEjUOEjU00AmGZD00`0006A=X@000002
00000Q/0H0D00004c>SZ0P0000_>e]h@00003[BbeP030000UYOB00000080000@S9cM0`0000IiWnX2
00000Q9>bP800009oooo00<0003oooooool05oooo`006?ooo`030000oooooooo01_oool2000000Co
bWh0000000000004i9Ed00<0003IUhgIUhd01]VGS@030000ciNKciNK00S?Ui/00`000<JEY<JEY008
aYFT00<0002nTjZnTjX02[jCZP030000]i6`]i6`00VgTK0010000:n>]000000000RRM9l00`0009U`
XiU`X`08VG2S00<0002=JJB=JJ@01HeYY0030000OEjUOEjU00AmGZD200000T/ON00400006`1P6`1P
dOk30P000004i?OD0000c>SZc>SZ0P0000_>e]h2000000?>am<0002d/]H06kBbeP030000UYOBUYOB
00:FUm8400003hbLg@800004NIoZ00<00011I<l000000Q9>bP030000oooooooo00Ooool00`000?oo
ooooo`0Goooo000Hoooo00<0003oooooool06oooo`<00002jXHm00<0003TUGCTUG@00nBEM0030000
fIN=fIN=00KIUhd00`000<nGVlnGV`07ciNK00<00036UJC6UJ@02LJEY0030000_Y>Z_Y>Z00VnTjX0
0`000;NA/;NA/009]i6`0P0000^RM9l00`0009U`XiU`X`07VG2S00<0002=JJB=JJ@01HeYY0030000
OEjUOEjU00AmGZD0100004/ON4/ON000008K0602dOk300<0003TmmCTmm@00`0000[>e]h300000lk7
d`030000];;F];;F01Zd/]H00`0009JGdYJGdP06UYOB0`0000j<W=d2000000EiWnX00011I<m1I<l0
00000Q9>bP800008oooo00<0003oooooool05oooo`005oooo`030000oooooooo01goool200000^Z6
?@030000i9Edi9Ed00CTUG@00`000=VGSMVGS@05fIN=00<0003?Ui_?Ui/02<nGV`030000aYFTaYFT
00S6UJ@00`000;jCZ[jCZP0:_Y>Z00<0002gTK2gTK001[NA/0800002ZWNK00<0002RM9nRM9l02:9d
W`030000VG2SVG2S00NIL:<00`0008eYY8eYY005SFVT00<0001mGZEmGZD00WeNY@<00002Bamh00H0
000K063Ao/?Ao/<002/00002i?OD00<0003>e]k>e]h02<kFgP800006c/OC00<0002d/]Jd/]H06[Bb
eP030000UYOBUYOB00VFUm8300003HbLg@800003@FC?00<0000BC/XBC/X00P0000Soool00`000?oo
ooooo`0Foooo000Goooo00<0003oooooool07Oooo`800003jXHm00<0003TUGCTUG@00nBEM0030000
fIN=fIN=00KIUhd00`000<nGVlnGV`08ciNK00<00036UJC6UJ@02<JEY0030000_Y>Z_Y>Z00VnTjX0
0`000;NA/;NA/004]i6`0P0000BZMi/00`000:9dWj9dW`09XWBO00<0002IL:>IL:<01YU`X`030000
SFVTSFVT00J=JJ@0100007eNYGeNY@00009W>8<0100004/ON4/ON00000;Ao/<200000^Cge0800007
c]KN0`0000S>am<00`000;Bbe[BbeP0J];;F00<0002FUm:FUm8039JGdP<0000;S9cM0P0000=1I<l0
0`00019>bQ9>bP0200001oooo`030000oooooooo01Koool001Ooool00`000?ooooooo`0Noooo0P00
00?ZQSd00`000>BEM>BEM003i9Ed00<0003IUhgIUhd01]VGS@030000ciNKciNK00O?Ui/00`000<JE
Y<JEY009aYFT00<0002nTjZnTjX02KjCZP040000]i6`]i6`]i6`0P0000NZMi/00`000:9dWj9dW`08
XWBO00<0002IL:>IL:<01iU`X`030000SFVTSFVT00F=JJ@300000fLhP`030000BamhBamh00;Ao/<5
000000?Ui]40003>e]h01<kFgP80000;c/OC00<0002d/]Jd/]H06[BbeP030000UYOBUYOB00nFUm83
000028bLg@030000Ffg<000000=1I<l01000019>bQ9>bP0000Ooool00`000?ooooooo`0Foooo000F
oooo00<0003oooooool08?ooo`800002jXHm00<0003TUGCTUG@01>BEM0030000fIN=fIN=00GIUhd0
0`000<nGVlnGV`08ciNK00<00036UJC6UJ@02<JEY0030000_Y>Z_Y>Z00VnTjX010000;NA/0000000
00VZMi/00`000:9dWj9dW`08XWBO00<0002IL:>IL:<01iU`X`030000SFVTSFVT00F=JJ@00`0006Lh
PfLhP`02IcR300<0001;7gQ;7gP00]7n``8000001@00:`000>GVdNGVd@000003c]KN0`0000g>am<0
0`000;Bbe[BbeP0J];;F00<0002FUm:FUm804YJGdP@00004S9cM00@0001KKLaKKL`00003@FC?00@0
000BC/X000000007oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo023oool200000nZ6
?@030000i9Edi9Ed00?TUG@00`000=VGSMVGS@06fIN=00<0003?Ui_?Ui/02<nGV`030000aYFTaYFT
00S6UJ@00`000;jCZ[jCZP09_Y>Z00<0002ZMi^ZMi/02ZYgV`030000XWBOXWBO00RRM9l00`0009U`
XiU`X`06VG2S00<0002=JJB=JJ@00heYY0<00004IcR300H0001;7gSAo/?Ao/<0000K060200000nGV
d@040000c]KN000000004<k7d`030000];;F];;F01>d/]H900005iJGdP<000000hbLg@0005]]c002
Ffg<00H00011I<m1I<m1I<l0000BC/X200001_ooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Qoooo0P0000?ZQSd00`000>BEM>BEM003i9Ed00<0003IUhgIUhd01]VGS@030000ciNKciNK
00O?Ui/00`000<JEY<JEY008aYFT00<0002nTjZnTjX01kjCZP8000000k5iU0000:YgV`0:ZWNK00<0
002RM9nRM9l02:9dW`030000VG2SVG2S00JIL:<0100008eYY8eYY8eYY0800002NTR800<0001W>8=W
>8<00VLhP`@000001>Cge1/0H000000000?Ui]4200004/k7d`030000];;F];;F00Fd/]H>00001kJY
b`030000Vi79000000<0000FUYOB0P0000AKKL`01000045Tcd5Tc`00008BC/X00`000?ooooooo`04
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02;oool200000^Z6?@030000i9Edi9Ed
00CTUG@00`000=VGSMVGS@05fIN=00<0003?Ui_?Ui/02<nGV`030000aYFTaYFT00S6UJ@00`000;jC
Z[jCZP04_Y>Z0P0000>aNI@00`000:YgVjYgV`0:ZWNK00<0002RM9nRM9l02:9dW`030000VG2SVG2S
00JIL:<3000017Y8R0030000IcR3IcR3009W>8<3000000GTmm@K0600000002/000000^GVd@80000B
c/OC2@0001FfZL/00`0009^AbI^Ab@03Vi790`0001BFUm82000015]]c0040000@FC?@FC?00000Q9>
bP030000oooooooo00?oool00`000?ooooooo`0Eoooo000Eoooo00<0003oooooool08oooo`800003
jXHm00<0003TUGCTUG@00nBEM0030000fIN=fIN=00KIUhd00`000<nGVlnGV`08ciNK00<00036UJC6
UJ@02<JEY0040000_Y>Z_Y>Z_Y>Z0P0000JaNI@00`000:YgVjYgV`09ZWNK00<0002RM9nRM9l02:9d
W`030000VG2SVG2S00JIL:<00`0007Y8R7Y8R004NTR800<0001W>8=W>8<00VLhP`800002i?OD00<K
0600000000000^GVd@030000hmO;000000k>am<4000000?=^lT0002fZL/06kJYb`030000Vi79Vi79
00JKTLT4000049JGdP030000Jg36000000AKKL`01@00045Tcd5Tc`00019>bP0200001Oooo`030000
oooooooo01Coool001Goool00`000?ooooooo`0Toooo0P0000?ZQSd00`000>BEM>BEM003i9Ed00<0
003IUhgIUhd01]VGS@030000ciNKciNK00O?Ui/00`000<JEY<JEY008aYFT00@0002nTjX000000009
/GVD00<0002ZMi^ZMi/02JYgV`030000XWBOXWBO00RRM9l00`0009U`XiU`X`03VG2S0`0000IjB8P0
100006LhPfLhPfLhP`@000001Q/0H000000000000>GVd@0000;Sel/00`000<k7dlk7d`09c/OC0`00
00G=^lT00`000;JYbkJYb`0J]ZW;00<0002KTLVKTLT02Y^Ab@<0000=UYOB00@0001[L<I[L<H00004
Ffg<00H00011I<m1I<l0000BC/X00005oooo00<0003oooooool05?ooo`005Oooo`030000oooooooo
02Goool200000^Z6?@030000i9Edi9Ed00CTUG@00`000=VGSMVGS@05fIN=00<0003?Ui_?Ui/02<nG
V`030000aYFTaYFT00S6UJ@00`000;5iU;5iU00:/GVD00<0002ZMi^ZMi/02JYgV`030000XWBOXWBO
00NRM9l0100009U`XiU`XiU`X`800002R56900<0001jB8QjB8P017Y8R0040000IcR3IcR3IcR32@00
00?Sel/00`000<k7dlk7d`06c/OC0`0000S=^lT00`000;JYbkJYb`0J]ZW;00<0002KTLVKTLT03I^A
b@@00008UYOB00<0001[L<I[L<H00V]`aP030000Ffg<Ffg<009KKL`01P00045Tcd5Tc`00019>bP00
00Coool00`000?ooooooo`0Doooo000Doooo00<0003oooooool09_ooo`800003jXHm00<0003TUGCT
UG@01>BEM0030000fIN=fIN=00GIUhd00`000<nGVlnGV`07ciNK00<00036UJC6UJ@01/JEY0800000
0kQhS0000;5iU00:/GVD00<0002ZMi^ZMi/02JYgV`030000XWBOXWBO00RRM9l3000018QAR@030000
NTR8NTR800=jB8P0100006LhPfLhPfLhP`8000001>kh]@0000000000:`800005hmO;00<0003>am?>
am<00/k7d`@0000;cK_900<0002fZL^fZL/06KJYb`030000Vi79Vi7901:KTLT300001IJGdP030000
Jg36Jg3600=[L<H00`0005]]c5]]c002Ffg<00H00011I<m1I<l0000BC/X00004oooo00<0003ooooo
ool04oooo`005?ooo`030000oooooooo02Ooool200000nZ6?@030000i9Edi9Ed00?TUG@00`000=VG
SMVGS@06fIN=00<0003?Ui_?Ui/01lnGV`030000aYFTaYFT00?6UJ@200001;QhS0030000/GVD/GVD
00VaNI@00`000:YgVjYgV`09ZWNK00<0002RM9nRM9l01Z9dW`800006R56900<0001jB8QjB8P00gY8
R0040000IcR3IcR3IcR31`0000KSel/00`000<k7d`00000200003/fkb@030000]ZW;]ZW;01ZfZL/0
0`0009^AbI^Ab@0EVi7910000003UYOB0000Jg3600E[L<H00`0005]]c5]]c002Ffg<00@00011I<l0
000BC/X200000oooo`030000oooooooo01?oool001Coool00`000?ooooooo`0Xoooo0P0000?ZQSd0
0`000>BEM>BEM003i9Ed00<0003IUhgIUhd01MVGS@030000ciNKciNK00S?Ui/01@000<JEY<JEY<JE
Y0000007^7R<00<0002aNIBaNI@02K5iU0030000ZWNKZWNK00RZMi/00`000:9dWj9dW`04XWBO0P00
0003TUN70000R56900F8DHT00`0007Y8R7Y8R003NTR800<0001W>8=W>8<00P000004k_Re00000000
000[0P0000KSel/200004Lfkb@030000]ZW;]ZW;01ZfZL/00`0009^AbI^Ab@0IVi790P0000M[L<H2
00000e]]c0050000@FC?00004Tk:000000?oool00`000?ooooooo`0Coooo000Doooo00<0003ooooo
ool0:Oooo`05]d@00000jXHmjXHm000000KTUG@00`000=VGSMVGS@05fIN=00<0003?Ui_?Ui/01lnG
V`040000aYFT000000002KQhS0030000/GVD/GVD00VaNI@00`000:YgVjYgV`08ZWNK00@0002RM9nR
M9nRM9l20000199GQ`030000R569R56900B8DHT00`0007Y8R7Y8R002NTR800L0001W>8=W>8<0003^
n;D0000`04`00`0000GSel/300004/fkb@030000]ZW;]ZW;01ZfZL/00`0009^AbI^Ab@0JVi790`00
00M[L<H02@0005]]c5]]c5]]c000045Tc`00019>bP000002oooo00<0003oooooool04oooo`005?oo
o`030000oooooooo02Woool200000nZ6?@030000i9Edi9Ed00?TUG@00`000=VGSMVGS@05fIN=00<0
003?Ui_?Ui/01lnGV`80000<^7R<00<0002aNIBaNI@02;5iU0030000ZWNKZWNK00RZMi/010000:9d
W`00000000JBEhL00`0008QARHQAR@04R56900<0001jB8QjB8P00WY8R0D000000o?^_@000000:`02
00001>?Gb`040000hL_3hL_300004/fkb@030000]ZW;]ZW;01ZfZL/00`0009^AbI^Ab@0JVi7900@0
001dL;mdL;l00007Jg3600H0001KKLaKKLaKKL`00011I<l200000_ooo`030000oooooooo01?oool0
01?oool00`000?ooooooo`0[oooo0P0000?ZQSd00`000>BEM>BEM003i9Ed00<0003IUhgIUhd01MVG
S@030000ciNKciNK00C?Ui/200000[ieO`030000^7R<^7R<00ZhN8`00`000;5iU;5iU008/GVD00<0
002ZMi^ZMi/02:YgV`030000TUN7TUN700JBEhL00`0008QARHQAR@04R56900<0001jB8QjB8P00WY8
R0070000Ca1N00000000lnjm<01<000[00800003hmO;0P0000?Qbl<00`000<fkbLfkb@0?cK_98@00
01ZKTLT0100007A`_gA`_gA`_`800006Jg3600@0001KKLaKKLaKKL`2000000D02IL0003oooooool0
00005?ooo`004oooo`030000oooooooo02coool01KM400000>Z6?NZ6?@000006i9Ed00<0003IUhgI
Uhd01MVGS@040000ciNKciNKciNK0P0000FnMGl00`000;QhS;QhS00:^7R<00<0002aNIBaNI@02;5i
U0030000ZWNKZWNK00FZMi/2000000>JFX80002BEhL01Y9GQ`030000R569R56900B8DHT00`0007Y8
R7Y8R006000000<`04`0000002/00P0000;Sel/00`000>7;`n7;``03hL_300<0003=^lW=^lT02lfk
b@@000000lbb`0000;NQ`P0K]j7200<0002NS<2NS<001P0001BKTLT00`0007A`_gA`_`03M72o00<0
001[L<I[L<H016]`aP040000Ffg<Ffg<Ffg<0`0000;oool00`000?ooooooo`0Boooo000Coooo00<0
003oooooool0;?ooo`800003jXHm00<0003TUGCTUG@00nBEM0030000fIN=fIN=00GIUhd010000<nG
V`00000000RnMGl00`000;QhS;QhS009^7R<00<0002aNIBaNI@02K5iU0030000ZWNKZWNK00>ZMi/0
1@0009YJPYYJPYYJPP000008TUN700<00028DHV8DHT00hQAR@<000000fDSI`0004l@GP02000000?c
k[d`04`000000P0000;Sel/00`000>7;`n7;``04hL_300<0003=^lW=^lT01lfkb@@00005c;;000<0
002gXL:gXL806[NQ`P030000WXc0WXc000JNS<0600003I^Ab@030000M72oM72o00EdL;l200001F]`
aP030000Ffg<Ffg<00<00002oooo00<0003oooooool04_ooo`004oooo`030000oooooooo02goool2
00000nZ6?@030000i9Edi9Ed00?TUG@00`000=VGSMVGS@04fIN=0P0000^nMGl00`000;QhS;QhS009
^7R<00<0002aNIBaNI@02;5iU0030000ZWNKZWNK00:ZMi/00`0009YJPYYJPP03VUZ200<0002BEhNB
EhL01I9GQ`030000R569R56900>8DHT01P0006DSIfDSIfDSI`0004l@GPT00007hL_300<0003=^lW=
^lT00lfkb@@00009c;;000<0002gXL:gXL806[NQ`P030000WXc0WXc000bNS<05000029^Ab@030000
M72oM72o00MdL;l00`0006]`aV]`aP03Jg360P00000672jX000000000000oooo00005?ooo`004ooo
o`030000oooooooo02koool01KM400000>Z6?NZ6?@000006i9Ed00@0003IUhgIUhgIUhd200000/A^
JP030000_WEo_WEo00VnMGl00`000;QhS;QhS009^7R<00<0002aNIBaNI@02;5iU0040000ZWNK0000
00001YYJPP030000TUN7TUN700FBEhL0100008QARHQARHQAR@<00003IB=W1@00000400020000l^:l
00002N7;``030000cK_9000000<0000=c;;000<0002gXL:gXL806[NQ`P030000WXc0WXc0016NS<06
00000Y^Ab@030000M72oM72o00QdL;l00`0006]`aV]`aP03Jg3600<0000L;ZP000000P000003oooo
0000oooo01?oool001?oool00`000?ooooooo`0^oooo0P0000?ZQSd00`000>BEM>BEM003i9Ed00@0
003IUhd000000005a6iZ0P0000ZnMGl00`000;QhS;QhS009^7R<00<0002aNIBaNI@02;5iU0030000
VUZ2VUZ200NJFX800`00099GQi9GQ`05TUN70`00009d;f/0100006DSIfDSIfDSI`<000000aP09@00
0000000300002>7;``<0000Ac;;000<0002gXL:gXL806[NQ`P030000WXc0WXc001NNS<0400002WA`
_`800003Jg360P00000572jX00000000oooo000001Coool001;oool00`000?ooooooo`0`oooo0P00
00?ZQSd00`000>BEM>BEM002i9Ed0P0000W4KVX00`000;ieOkieO`08_WEo0P0000ZhN8`00`000;5i
U;5iU005/GVD0P000003X5Yk0000VUZ200NJFX800`00099GQi9GQ`04TUN70P0000Ad;f/00`0006DS
IfDSI`08000000?`ekP0003Qbl<01N7;``8000000mo1^`000<bb`00Ac;;000<0002gXL:gXL806[NQ
`P030000WXc0WXc001VNS<00100007Y]^@00000000YdL;l00`0006]`aV]`aP02000000HL;ZP00000
0000003oool0000Coooo000Boooo00<0003oooooool0<Oooo`05]d@00000jXHmjXHm000000;TUG@2
00000/IMA@800008a6iZ00<0002nMGnnMGl02KieO`030000^7R<^7R<00RhN8`00`000;5iU;5iU002
/GVD0P0000BPFW/00`0009YJPYYJPP06VUZ200@0002BEhNBEhNBEhL2000000=n=VX0001d;f/00g@_
J`030000IB=WIB=W00<0000011P09@000P00000000;`ekP010000>7;`n7;`n7;``<00003gl6k00<0
003<//3<//004<bb`0030000]j72]j7201ZgXL800`0009j<`9j<`00IWXc000@0001jKKUjKKUjKKT3
000027A`_`<000000bhgZ@0000000002000000?oool0003oool04_ooo`004_ooo`030000oooooooo
037oool200000^Z6?@<00006aUe500<00034KV[4KVX01/A^JP80000:_WEo00<0002hN8bhN8`02;Qh
S0040000/GVD000000001j1JN`030000VUZ2VUZ200FJFX801000099GQ`00000000=n=VX00`0007@_
Jg@_J`02M2m[2@0000?`ekP010000>7;``00000000KO`K/00`000<bb`<bb`00@c;;000<0002gXL:g
XL806[NQ`P030000WXc0WXc001VNS<000`0007Y]^GY]^@04NVfi0P0000QdL;l01P0002hgZ@0001`^
Z0000000P080000Coooo000Boooo00<0003oooooool0<_ooo`<00002^3@00P0000K6GDD200002<A^
JP030000_WEo_WEo00RnMGl00`000;QhS;QhS008^7R<00<0002PFW^PFW/02:1JN`030000VUZ2VUZ2
00FJFX800`0007hfJWhfJP04OSIZ00<0001d;f]d;f/00P00009?0TL500001?3G^0800008gl6k00<0
003<//3<//004<bb`0030000]j72]j7201ZgXL800`0009j<`9j<`00IWXc000<0001jKKUjKKT01WY]
^@800006M72o0P000003;SNY0000000000<0000Coooo000Boooo00<0003oooooool0<oooo`<00003
^3@000<00036GDG6GDD01LIMA@030000a6iZa6iZ00K4KVX00`000;ieOkieO`08_WEo00<0002hN8bh
N8`01KQhS08000000jEFL00000000009X5Yk00<0002JFX:JFX800YYJPP8000000hHiIP0007hfJP04
OSIZ0`000003G`m=0000C`9700H00003l=Nh0P0000WO`K/00`000<bb`<bb`00@c;;000<0002gXL:g
XL806[NQ`P030000WXc0WXc001VNS<000`0007Y]^GY]^@08NVfi0`0000=dL;l200000RhgZ@@0000C
oooo000Boooo00<0003oooooool0=Oooo`<00002^3@00P0000K6GDD200001lA^JP800009_WEo00<0
002hN8bhN8`00[QhS0800005YEI`00<0002PFW^PFW/01j1JN`040000VUZ2000000000hHiIP030000
OSIZOSIZ009n=VX200000Ul?C@030000C`97000000H000001O3G^00000000>k=/@000009gl6k00<0
003<//3<//003<bb`2T0000DWXc000<0001jKKUjKKT02gY]^@8000001GA`_`0003XlZ00002hgZ@02
000000<00800003oool04_ooo`004_ooo`030000oooooooo03Ooool200000kPd00800006aUe500<0
0034KV[4KVX01/A^JP030000_WEo_WEo00NnMGl010000;QhS000000000RUEW000`000:1JNj1JN`06
X5Yk0P0000J6>FH01P0007hfJP00000006TGC@00009O3dd7000000?igJX0000000000nk=/@030000
gl6kgl6k00OO`K/00`000<bb`<bb`002c;;02P0000C<Z[L00`000;RI^KRI^@0J^9Vi00<0002OQKRO
QKP01In5^0h00006WXc000<0001jKKUjKKT03GY]^@800002>SbX00<0000^=jT000000P0001?oool0
01;oool00`000?ooooooo`0ioooo0P0000>h=0000`000<IMALIMA@04aUe50P0000O4KVX00`000;ie
OkieO`06_WEo0`0000ZUEW0200001:1JN`800002RcMM00<00026>FJ6>FH018HiIP040000JAM=JAM=
JAM=0P000003CP0e0000000000D000000oWMZP000>k=/@03k/fa00<0003O`K_O`K/01]o1^`H0000>
c:Zg00<0002hVKVhVKT06[RI^@030000WhFhWhFh01>OQKP900003WY]^@800002>SbX100001?oool0
01;oool00`000?ooooooo`0joooo0`0000:h=00200001/IMA@030000a6iZa6iZ00G4KVX200001;ie
O`800003YdiO0P0000ZUEW0010000:1JN`00000000F;=ed0100008HiIXHiIXHiIP<00003JAM=0`00
0003<`0P0000000000H00004k/fa00<0003O`K_O`K/00]o1^`@000000mji/P000<bZ]`0Ac:Zg00<0
002hVKVhVKT06[RI^@030000WhFhWhFh01VOQKP00`0007aY/GaY/@0400002WY]^@060000@CbU0000
>SbX0000;SNY0P0001?oool001;oool00`000?ooooooo`0loooo0P0000>h=0000`000<IMALIMA@04
aUe50P0000O4KVX010000;ieO`00000000NWCUl200002JEFL0800007RcMM00<00026>FH000000g4I
B@@000000d<09`0000000004000000Cmgid0003heJH00004k/fa00<0003O`K/000000P0000GN^K80
0`000<bZ]lbZ]`0@c:Zg00<0002hVKVhVKT06[RI^@030000WhFhWhFh01VOQKP00`0007aY/GaY/@04
O6Va100000EjKKT01000044lYD4lY@00008j?:P300004oooo`004Oooo`030000oooooooo03ooool2
00000[Pd00800006aUe500<00034KV[4KVX01<A^JP<0000:YdiO0P0000FUEW0200000XdaD0800005
RcMM0`00009a6DT2000000=H03H0000000002@000004n=FV0000k/fak/fa100000SN^K800`000<bZ
]lbZ]`0@c:Zg00<0002hVKVhVKT06[RI^@030000WhFhWhFh01VOQKP00`0007aY/GaY/@08O6Va1000
0003NVfi0000@CbU0091?:D00`0003XlZ3XlZ00300004_ooo`004Oooo`030000oooooooo047oool2
00000[Pd00800005aUe50P0000;4KVX200000jHo@`80000:YdiO0P0000:UEW000`0008daD8daD004
SC5@0P000003RcMM0000000000=d5d42000000=O0380000000001@000007oooo000000000000oMRJ
0000n=FV00<00002kLFZ00<0003N^K;N^K801mji/P030000c:Zgc:Zg013<Z[L00`000;RI^KRI^@0J
^9Vi00<0002OQKROQKP06In5^0030000O6VaO6Va00alJK4300000d4lY@030000>SbX00000080000B
oooo000Aoooo00<0003oooooool0@_ooo`800003^3@000<00036GDG6GDD00lIMA@<00007YSm30`00
00VWCUl300001hdaD0<00002M1M10P000004HP0Y00000000E00U1@000003oooo0000000000H00004
kLFZ00<0003N^K;N^K801mji/P030000c:Zgc:Zg013<Z[L00`000;RI^KRI^@0J^9Vi00<0002OQKRO
QKP06In5^0030000O6VaO6Va00elJK40100004DjX00000000091?:D400004_ooo`004Oooo`030000
oooooooo04Coool200000[Pd008000000lIMA@0000000003W24E0`0000:V?d<D00000XdaD0800003
M0lb3@000003oooo0000000000<00002mlfO00<0003]aJ[]aJX00^g5ZP030000g[Vbg[Vb00ON^K80
0`000<bZ]lbZ]`0@c:Zg00<0002hVKVhVKT06[RI^@030000WhFhWhFh01VOQKP00`0007aY/GaY/@0=
O6Va00@00015>Z15>Z15>Z0600004_ooo`004Oooo`030000oooooooo04Koool2000000>h=0000000
00000P0000BL8AD500000W_QmB/00002mlfO00<0003]aJ[]aJX00^g5ZP030000g[Vbg[Vb00ON^K80
0`000<bZ]lbZ]`0@c:Zg00<0002hVKVhVKT06[RI^@030000WhFhWhFh01VOQKP00`0007aY/GaY/@0=
O6Va00<00015>Z15>Z000dDjX0@0000Boooo000Aoooo00<0003oooooool0B?ooo`<000000g/00?oo
o`00000400000W_Qm@@00002W=km0P0000E`c?hR00000_O=W`030000kLFZkLFZ00;]aJX00`000=ji
/]ji/P07g[Vb00<0003<Z[O<Z[L04<bZ]`030000^9Vi^9Vi01ZhVKT00`0009n5^9n5^00IWhFh00<0
001lJK5lJK403GaY/@030000ACZPACZP00=5>Z0010000000P000000001;oool0017oool00`000?oo
ooooo`1:oooo0`0000Ak00000g_Qm@0000000003W=km0i`Q5@L00005PlOm0P0000AS^_d900001?oo
oh40000Boooo000Aoooo00<0003oooooool0B?ooo`800002Nn7e1@0000=k000400000Y`Q5@800005
L0008P0000;gaiL00`000>fnXNfnX@02kKjQ00<0003N/JWN/JT01mjaZ@030000c:>^c:>^013<Xjh0
0`000;RB/;RB/00J^9:`00<0002OOZnOOZl06Imn[`030000O6:ZO6:Z00elHZX00`0004DfVTDfVP03
ACJJ100001;oool0017oool00`000?ooooooo`16oooo0P0000:hnN`200001YcNo@<00003N`00:`00
00;gaiL00`000>fnXNfnX@02kKjQ00<0003N/JWN/JT01mjaZ@030000c:>^c:>^013<Xjh00`000;RB
/;RB/00J^9:`00<0002OOZnOOZl06Imn[`030000O6:ZO6:Z00elHZX00`0004DfVTDfVP02ACJJ1@00
01;oool0017oool00`000?ooooooo`14oooo0P0000:hnN`200000/KVkP800002W=km0`0000>Vd?HC
00000hfdl@800002M:of1P000003E9kd0000000000@000000oooo`000000000300000_O7U`030000
kKjQkKjQ00;]_Z400`000=jaZMjaZ@07g[6Y00<0003<Xjk<Xjh04<bS[P030000^9:`^9:`01ZhT[00
0`0009mn[imn[`0IWgj_00<0001lHZYlHZX03GaRZP030000ACJJACJJ008000000d4^T`000000LP02
00004_ooo`004Oooo`030000oooooooo04;oool200000kSik0030000a^K^a^K^00C6i^h200001jK@
mP80000;Yl?]0P0000R=]?4200000WBWlP80000016:Rm000000005BHl@h00004kKjQ00<0003N/JWN
/JT01mjaZ@030000c:>^c:>^013<Xjh00`000;RB/;RB/00J^9:`00<0002OOZnOOZl06Imn[`030000
O6:ZO6:Z00elHZX300000d4^T`040000001b000000004_ooo`004Oooo`030000oooooooo047oool2
00000[Sik0800005a^K^0P0000;4d^D200000jK@mP80000:Yl?]0P0000:U]^D2000018fdl@800003
Rj_[0P000003M:Ob0000000000=OVo000`0004j@k@000003000000?oool0000000000P0000;h`8d3
00000^fnX@030000g[6Yg[6Y00ON/JT00`000<bS[/bS[P0@c:>^00<0002hT[2hT[006[RB/0030000
Wgj_Wgj_01VOOZl00`0007aRZWaRZP0;O6:Z0`0000A1;Y<500004_ooo`004Oooo`030000oooooooo
03ooool200000[Sik0800006a^K^00<00034d^G4d^D01<CBi@<0000:Yl?]0P0000JU]^D0100008fd
l@00000000N;Zn/01000076OkG6OkG6Ok@80000015RBk000000004>6j@P000001?S0S@000>jhUnjh
U`@00008g[6Y00<0003<Xjk<Xjh04<bS[P030000^9:`^9:`01ZhT[000`0009mn[imn[`0IWgj_00<0
001lHZYlHZX01gaRZP@00002NUZQ00D00011;Y=1;Y=1;Y<000000SXSRP<0000Boooo000Boooo00<0
003oooooool0??ooo`800003^?W/00<00036i^k6i^h01<KVkP800007a=;U00<0002n`Mbn`M`00P00
00JW`nd200002JFfi@800007Rj_[00@00026X^H000000002LIo]2`000004oKie0000n<2=00001>jh
U`030000gj^O000000<00004g[6Y00<0003<Xjk<Xjh04<bS[P030000^9:`^9:`01ZhT[000`0009mn
[imn[`0IWgj_00<0001lHZYlHZX00gaRZP@00006NUZQ00H00011;Y=1;Y=1;Y<0000j8hX300004ooo
o`004_ooo`030000oooooooo03[oool300000[Sik0800006a^K^00<00034d^G4d^D01LCBi@800005
_/7L0P0000:W`nd200002JFfi@800002X:cO0P0000B;Zn/00`0008JRiXJRiP02QZ;V0P0000=YU^T0
0`0004j8j000000900001>jhU`030000gj^Ogj^O00?OZil3000000?N/JT0003<Xjh04LbS[P030000
^9:`^9:`01ZhT[000`0009mn[imn[`0IWgj_00<0001lHZX000000`0000]jFZ400`00044^T`000002
>R>:0`0001?oool001;oool00`000?ooooooo`0ioooo0P0000>hnN`00`000<KVk/KVkP04a^K^0P00
00O4d^D00`000;k1g;k1g007_/7L0P0000ZU]^D00`000:2/gj2/g`04X:cO0P000003Rj_[0000QZ;V
00F6X^H200000VVFj@<000000celi00000000004000000?i^Wl0003^^9L00njhU`030000gj^Ogj^O
00KOZil600003/bS[P030000^9:`^9:`01ZhT[000`0009mn[imn[`0BWgj_2@0000mjFZ4200000SXS
RP@0000Coooo000Boooo00<0003oooooool0=oooo`800003^?W/0P0000K6i^h00`000<CBiLCBi@06
a=;U00<0002n`Mbn`M`01kk1g0040000^;CF000000002:Ffi@030000X:cOX:cO00NP[=l00`0008JR
iXJRiP04QZ;V00<0001nV>9nV>800`00009ORnD7000000?i^Wl0000000000njhU`030000gj^Ogj^O
00OOZil00`000<bKY<bKY002c9^T2P0000C<Xjh00`000;RB/;RB/00J^9:`00<0002OOZnOOZl019mn
[`h00007WWJV00<0001jFZ5jFZ403GYJX@800002>R>:00<0000^57h000000P0001?oool001;oool0
0`000?ooooooo`0eoooo0`0000:hnN`200001/KVkP800007a=;U0P0000Vn`M`00`000;Rde[RdeP02
^;CF0P0000BU]^D200002J2/g`040000VZ7J0000000018JRiP030000OYSROYSR009nV>82000000=O
RnD0001?On401`000005l;6900000000k[RG000000WOZil00`000<bKY<bKY00<c9^T:00001FNMZH0
0`0007YJXGYJX@0;NUZQ0P000005M4jG0000>R>:0000;QAn00@0000Coooo000Boooo00<0003ooooo
ool0<oooo`<00003^?W/00<00036i^k6i^h01LKVkP030000a=;Ua=;U00K4d^D00`000;k1g;k1g008
_/7L00<0002h]=Jh]=H01KRdeP8000000jFfi@000:2/g`09X:cO00<0002JXMZJXMX00YZQfP800000
0hJRiP0007jHhP04OYSR00<0001dSMh000000P000003CgoQ0000000000@00003l;690P0000WOZil0
0`000<bKY<bKY00@c9^T00<0002gRZJgRZH06[N:YP030000WWJVWWJV01VNMZH00`0007YJXGYJX@08
NUZQ0`0000=dCYL01@0003XSRRhDORhDOQ`0K`0300004oooo`004_ooo`030000oooooooo03;oool3
00000[Sik0800006a^K^0P0000S4d^D00`000;k1g;k1g008_/7L00<0002h]=Jh]=H02;RdeP030000
X:cOX:cO00RP[=l00`0009ZQfYZQfP05VZ7J0P0000EnV>801P0007B=gWB=gWB=gP0004moh@H00004
l;690P0000SOZil00`000<bKY<bKY00@c9^T00<0002gRZJgRZH06[N:YP030000WWJVWWJV01VNMZH0
0`0007YJXGYJX@06NUZQ0P0000IdCYL00`0002hDORhDOP0500004oooo`004_ooo`030000oooooooo
037oool010000;OVQn[hbN[hb@<00006a^K^00<00034d^G4d^D01/CBi@80000:_/7L00<0002h]=Jh
]=H02;RdeP040000/JW@000000001j2/g`030000VZ7JVZ7J00FJXMX00`0009:GeI:Ge@0200000WjH
hP030000M8gNM8gN009dSMh900000o2aR@040000hJ>B000000001]n[W`030000c9^Tc9^T013<Vj@0
0`000;N:Y[N:YP0J]hZV00<0002NMZJNMZH06IifYP030000NUZQNUZQ00AjFZ42000027A>U`040000
;QAn0000701_100001?oool001;oool00`000?ooooooo`0aoooo0P0000?Zn<T2i=o?0P0000;6i^h2
00002<CBi@030000_/7L_/7L00Vn`M`00`000;Rde[RdeP08^;CF00<0002aZM2aZM000[6Yd0800004
X:cO00<0002JXMZJXMX01YZQfP030000TYOETYOE00:BUmD3000017B=gP030000IH7JIH7J00<00000
11QJdP000000000000;`/HT010000>6ST^6ST^6STP<00003gj^O00<0003<VjC<Vj@04<bKY0030000
]hZV]hZV01ZgRZH00`0009ifYYifYP0IWWJV00@0001jFZ5jFZ5jFZ43000027A>U`<000000bhDOQ`0
Ka`0K`02000000?oool0003oool04_ooo`004_ooo`030000oooooooo033oool200000n[hb@030000
i=o?i=o?00;Tgll300002<CBi@030000_/7L_/7L00Rn`M`200002[RdeP030000/JW@/JW@00FaZM02
000000>P[=l0002JXMX01iZQfP030000TYOETYOE00FBUmD00`0007B=gWB=gP02M8gN00D0001UPMYU
PMX0001?LMD01P000003l;690000hJ>B00GQXi82000000?OZil0003<Vj@04LbKY0030000]hZV]hZV
01ZgRZH00`0009ifYYifYP0IWWJV00@0001jFZ400000000:M4jG00<0001[?XU[?XT00P000006701_
000000000000oooo00004oooo`004oooo`030000oooooooo02koool00`000;OVQn[hb@02j_S900<0
003TgloTgll01>COc`;Ibl`200001<CBi@80000:_/7L00<0002h]=Jh]=H02KRdeP030000/JW@/JW@
00RaZM000`0009ZQfYZQfP07VZ7J00<0002BUmFBUmD01I:Ge@<00002M8gN00@0001UPMYUPMYUPMX9
00002>6STP<0000Ac9^T00<0002gRZJgRZH06[N:YP030000WWJVWWJV01NNMZH300002gA>U`800003
Jcj900<0000L06lL06l0100001Coool001?oool00`000?ooooooo`0^oooo0P0000;Zn<T00`000>CO
cnCOc`04i=o?00<0003IblcIbl`00]W;c08000000lCBi@000;k1g00:_/7L00<0002h]=Jh]=H02KRd
eP030000/JW@/JW@00RaZM0010000:ZNb`00000000JJXMX00`0009:GeI:Ge@05TYOE00@00028SM68
SM68SM4300000fF1fPD00000100l`@000?:YM`0000WQXi800`000<fCV000000300003LbKY0030000
]hZV]hZV01ZgRZH00`0009ifYYifYP0AWWJV1P0000:KK9X00`0007A>UgA>U`08M4jG00<0001[?XU[
?XT00f/nR@070000701_000000100000oooo000001Coool001?oool00`000?ooooooo`0]oooo0P00
00?Zn<T00`000>COcnCOc`03i=o?00<0003IblcIbl`01MW;c080000:_/7L00<0002h]=Jh]=H02KRd
eP030000/JW@/JW@00VaZM001@000:ZNbjZNbjZNb`000005VZ7J00<0002BUmFBUmD01I:Ge@030000
R8gAR8gA00>8SM401P0006F1fVF1fVF1fP0004mae@8000000c1Lc@000000000400001n6STP030000
cI>HcI>H00?=TiP400002LbKY0030000]hZV]hZV01ZgRZH00`0009ifYYifYP0;WWJV1P0000RKK9X0
0`0007A>UgA>U`06M4jG0P0000E[?XT2000000HL06l305/00000003oool0000Doooo000Coooo00<0
003oooooool0;?ooo`800003j_S900<0003TgloTgll00nCOc`030000fL_<fL_<00GIbl`00`000<nk
alnka`0200001kk1g0030000^;CF^;CF00Vh]=H00`000;6Yd;6Yd009/JW@00<0002ZW/^ZW//00jZN
b`050000VZ7JVZ7JVZ7J000000RBUmD00`0008R=dHR=d@03R8gA0`000003IH7J0000Cg7E00800000
0o>OG@00000k_P0200000^>KP@030000hJ>BhJ>B00CQXi800`000<fCV<fCV007cI>H100000G<Vj@0
0`000;N:Y[N:YP0J]hZV00<0002NMZJNMZH01YifYPD0000>VfbJ00<0001dCYMdCYL01GA>U`030000
Jcj9Jcj900A[?XT00`0005/XMe/XM`0300000_ooo`030000oooooooo01;oool001?oool00`000?oo
ooooo`0/oooo0P0000;Zn<T00`000>COcnCOc`04i=o?00<0003IblcIbl`01MW;c0030000ck_7ck_7
00;?^lL200001;k1g0030000^;CF^;CF00Zh]=H00`000;6Yd;6Yd008/JW@00<0002ZW/^ZW//01JZN
b`8000000iZQfP0009:Ge@07TYOE00<00028SM68SM400hR=d@030000NX3=NX3=00H000001C1Lc@00
00000009V`000002hi^10P0000CQXi800`000<fCV<fCV00;cI>H10000003c9^T0000]hZV01^gRZH0
0`0009ifYYifYP0600004i]/VP030000M4jGM4jG00AdCYL00`0006/nRF/nR@04Jcj900L0001K:7MK
:7MK:7L00000040000000_ooo`030000oooooooo01;oool001?oool00`000?ooooooo`0[oooo0P00
00?Zn<T00`000>COcnCOc`03i=o?00<0003IblcIbl`01MW;c0030000ck_7ck_700G?^lL2000000>n
`M`0002h]=H02kRdeP030000/JW@/JW@00RaZM000`000:ZNbjZNb`08ZYk;0P0000NBUmD00`0008R=
dHR=d@04R8gA00<0001jP<ejP<d00WZ0c@070000Cg7E00000000limM000003^n00800004hi^100D0
003QXi;QXi;QXi8000004LfCV240000JVfbJ00@0001dCYMdCYMdCYL200001V/nR@040000FbQgFbQg
FbQg0P00000500100000oooooooo000001Coool001Coool00`000?ooooooo`0Yoooo0P0000?Zn<T0
0`000>COcnCOc`03i=o?00<0003IblcIbl`01MW;c0030000ck_7ck_700S?^lL00`000;Rde[RdeP0:
^;CF00<0002aZM2aZM002K6Yd0030000ZYk;ZYk;00NZW//00`000::DaZ:DaP0200001I:Ge@030000
R8gAR8gA00B8SM400`0007Z0cGZ0c@02NX3=1@000005limM0000000000VK000000CSVh4010000>6S
T^6STP0001;=TiP00`000;J1V[J1VP0J]X6J00<0002KK9ZKK9X06Y]/VP040000M4jGM4jG00001f/n
R@060000FbQgFbQgFbQg0000@@EK0P0000;oool00`000?ooooooo`0Coooo000Doooo00<0003ooooo
ool0:Oooo`800002j_S900<0003TgloTgll01>COc`030000fL_<fL_<00GIbl`00`000<nkalnka`07
ck_700@00036[/8000000009^;CF00<0002aZM2aZM002K6Yd0030000ZYk;ZYk;00RZW//00`000::D
aZ:DaP02XYC60P0000>BUmD00`0008R=dHR=d@04R8gA00<0001jP<ejP<d00WZ0c@050000Ig78Ig78
0000kXhc008000000`0k_P0000000005hi^10`0001;=TiP00`000;J1V[J1VP0J]X6J00<0002KK9ZK
K9X06Y]/VP<00007Jcj900T0001K:7MK:7MK:7L000111E/0000B02h000000_ooo`030000oooooooo
01?oool001Coool00`000?ooooooo`0Xoooo0P0000?Zn<T00`000>COcnCOc`03i=o?00<0003IblcI
bl`01MW;c0030000ck_7ck_700S?^lL010000<J^`/J^`/J^`P800006^;CF00<0002aZM2aZM002K6Y
d0030000ZYk;ZYk;00RZW//00`000::DaZ:DaP05XYC60`0000J8SM400`0007Z0cGZ0c@03NX3=00<0
001WLLQWLLP00P000006kXhc00000000000000VK00001^>KP@80000AcI>H00<0002fPIZfPIX06[J1
VP030000VfbJVfbJ01VKK9X200001f/nR@800003FbQg00D000111E/0000B02h000000oooo`030000
oooooooo01?oool001Coool00`000?ooooooo`0Woooo0P0000?Zn<T00`000>COcnCOc`03i=o?00<0
003IblcIbl`01]W;c0030000ck_7ck_700O?^lL00`000<J^`/J^`P04aZk200<0002h]=Jh]=H00[Rd
eP030000/JW@/JW@00VaZM000`000:ZNbjZNb`09ZYk;00<0002RU<JRU<H01j:DaP030000R8gAR8gA
00B8SM400`0007Z0cGZ0c@03NX3=00H0001WLLQWLLQWLLP0003^SS<2000000<0>kh0000000001^>K
P@030000cXV8000000<0000=cI>H00<0002fPIZfPIX06[J1VP030000VfbJVfbJ01FKK9X4000000>F
GH`0001[?XT01F/nR@030000FbQgFbQg009K:7L01P000445Fd45F`000180;P0000?oool00`000?oo
ooooo`0Coooo000Doooo00<0003oooooool09_ooo`800003j_S900<0003TgloTgll01>COc`030000
fL_<fL_<00GIbl`00`000<nkalnka`07ck_700<00036[/;6[/801/J^`P8000000kRdeP000;6Yd00;
/JW@00<0002ZW/^ZW//02:ZNb`030000XYC6XYC600RRU<H3000018R=d@030000NX3=NX3=00=jP<d0
100006Mab6Mab6Mab08000001Nj><`00000000000009V`0200001>>KP@030000cXV8cXV800?>RHP3
00002lfCV0030000]X6J]X6J01VfPIX00`0009]/VY]/VP0BVfbJ0`0000FFGH`00`0006/nRF/nR@03
Jcj900<0001K:7MK:7L00U/XM`060000@@EK@@EK00004P0^00001?ooo`030000oooooooo01?oool0
01Goool00`000?ooooooo`0Uoooo0P0000;Zn<T00`000>COcnCOc`04i=o?00<0003IblcIbl`01MW;
c0030000ck_7ck_700S?^lL00`000<J^`/J^`P08aZk200<0002aZM2aZM002[6Yd0030000ZYk;ZYk;
00VZW//00`000::DaZ:DaP07XYC600@0002IRL:IRL:IRL8200000XR=d@030000NX3=NX3=00=jP<d0
0`0006Mab6Mab002Ig78100000056cRb00000000iI1X000000?SVh400`000<j9R<j9R006cXV80`00
00S=TiP00`000;J1V[J1VP0J]X6J00<0002KK9ZKK9X03I]/VP@00008UUf<00<0001[?XU[?XT00V/n
R@030000FbQgFbQg009K:7L01P000445Fd45F`000180;P0000Coool00`000?ooooooo`0Doooo000E
oooo00<0003oooooool09?ooo`800003j_S900<0003TgloTgll00nCOc`030000fL_<fL_<00KIbl`0
0`000<nkalnka`07ck_700<00036[/;6[/802<J^`P040000_Z>n000000002K6Yd0030000ZYk;ZYk;
00VZW//00`000::DaZ:DaP08XYC600<0002IRL:IRL800iV9`P<00006NX3=00@0001WLLQWLLQWLLP3
000000OTOChK>;80000008h0003UT6P000000^>KP@030000cXV8cXV800W>RHP400001<fCV0030000
]X6J]X6J01ZfPIX00`0009]/VY]/VP0:VfbJ0`0000fFGH`0100006/nRF/nR@0000AK:7L01@000445
Fd45F`000180;P0200001?ooo`030000oooooooo01Coool001Goool00`000?ooooooo`0Soooo0P00
00?Zn<T00`000>COcnCOc`03i=o?00<0003IblcIbl`01]W;c0030000ck_7ck_700S?^lL00`000<J^
`/J^`P08aZk200@0002nXkjnXkjnXkh200001[6Yd0030000ZYk;ZYk;00ZZW//00`000::DaZ:DaP07
XYC600<0002IRL:IRL801YV9`P030000NX3=NX3=00AjP<d00`0006Mab6Mab002Ig780P000005i7dn
6cRb6cRb0000002>00;UT6P00`000>>KP@00000?cXV80`000003cI>H0000]X6J01^fPIX00`0009]/
VY]/VP06VfbJ1000012FGH`00`0006/nR@000004FbQg00@000111E]11E/000024P0^00<0003ooooo
ool00oooo`030000oooooooo01Coool001Koool00`000?ooooooo`0Roooo0P0000;Zn<T00`000>CO
cnCOc`04i=o?00<0003IblcIbl`01MW;c0030000ck_7ck_700S?^lL00`000<J^`/J^`P08aZk200<0
002nXkjnXkh01;jS_P800004/JW@00<0002ZW/^ZW//02JZNb`030000XYC6XYC600RRU<H00`0009V9
`YV9`P06VHW20`0000AjP<d00`0006Mab6Mab002Ig780`000005i7dn6cRb0000002>000000;UT6P2
00004/j9R0T0000E]X6J00<0002KK9ZKK9X00i]/VP<0000DUUf<0P0000AK:7L010000445Fd45F`00
008B02h00`000?ooooooo`03oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo027oool2
00000n[hb@030000i=o?i=o?00?Tgll00`000=W;c=W;c006fL_<00<0003?^lO?^lL01lnka`030000
aZk2aZk200W6[/800`000;jS_[jS_P06_Z>n0P000003/JW@0000ZYk;00ZZW//00`000::DaZ:DaP08
XYC600<0002IRL:IRL801YV9`P040000SGfmSGfmSGfm0P00009jP<d00`0006Mab6Mab002Ig781000
0004i7dn0000002>00000nF@J080000BcXV800<0002dMH^dMH/01KAeR`h00007]X6J00<0002KK9X0
00000`0001JFGH`2000015/XM`070000@@EK@@EK@@EK00004P0^000000Koool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool08?ooo`800003j_S900<0003TgloTgll00nCOc`030000fL_<fL_<
00KIbl`00`000<nkalnka`08ck_700<00036[/;6[/802<J^`P030000_Z>n_Z>n00VnXkh200002jZN
b`030000XYC6XYC600RRU<H00`0009V9`YV9`P06VHW200<0002=OKf=OKd00hem_@<00004Ig7800<0
001;Fl4000000P0000046cRb0000002>00000^F@J0040000cW]`000000004<j9R0030000]7F;]7F;
01>dMH/8000069IMS0<000000ha9N00005/XM`02FbQg00H000111E]11E]11E/0000B02h200001_oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0Poooo0P0000;Zn<T00`000>COcnCOc`04
i=o?00<0003IblcIbl`01MW;c0030000ck_7ck_700S?^lL00`000<J^`/J^`P08aZk200<0002nXkjn
Xkh02KjS_P030000]iVi]iVi00800008ZYk;00<0002RU<JRU<H02::DaP030000VHW2VHW200NIRL80
0`0008em_Hem_@05SGfm00<0001WLLQWLLP00VMab0030000Be_1Be_100@000001@00SP0000000>F@
J0000003cW]`0`0000g>RHP00`000;AeRkAeR`0J]7F;00<0002FGHbFGH`04YIMS0@00004S4Uh00@0
001K:7MK:7L00003@@EK00@0000B02hB02h00007oooo00<0003oooooool05Oooo`005oooo`030000
oooooooo01koool200000n[hb@030000i=o?i=o?00?Tgll00`000=W;c=W;c006fL_<00<0003?^lO?
^lL01lnka`030000aZk2aZk200W6[/800`000;jS_[jS_P09_Z>n00<0002gVKVgVKT00[NI^@800006
ZYk;00<0002RU<JRU<H02::DaP030000VHW2VHW200NIRL800`0008em_Hem_@05SGfm0`0000=WLLP3
Be_100<0003AE`0000000P000004i7dn0000iI1X00001LikL080000;cXV800<0002dMH^dMH/06[Ae
R`030000UUf<UUf<00nFGH`3000028a9N0030000FbQg000000=11E/010000180;Q80;P0000Ooool0
0`000?ooooooo`0Foooo000Goooo00<0003oooooool07Oooo`800003j_S900<0003TgloTgll00nCO
c`030000fL_<fL_<00KIbl`00`000<nkalnka`08ck_700<00036[/;6[/802<J^`P030000_Z>n_Z>n
00VnXkh00`000;NI^KNI^@05]iVi0P0000>ZW//00`000::DaZ:DaP09XYC600<0002IRL:IRL801YV9
`P030000SGfmSGfm00J=OKd0100007e]]ge]]`00009WLLP3Be_10P000003dEL00000000000;TOCh2
00001likL0<00008cXV800<0002dMH^dMH/06[AeR`030000UUf<UUf<00bFGH`300002ha9N0800003
@@EK00<0000B02hB02h00P0000Ooool00`000?ooooooo`0Foooo000Goooo00<0003oooooool07Ooo
o`800002j_S900<0003TgloTgll01>COc`030000fL_<fL_<00GIbl`00`000<nkalnka`08ck_700<0
0036[/;6[/802<J^`P030000_Z>n_Z>n00ZnXkh00`000;NI^KNI^@07]iVi0P000003ZYk;0000XYC6
00VRU<H00`0009V9`YV9`P07VHW200<0002=OKf=OKd01Hem_@030000OFfgOFfg009mKKL200000d]K
`@0300006cRb0000008008h010000>Am?^Am?P0000[>Ng0200001/j9R0030000]7F;]7F;01ZdMH/0
0`0009IMS9IMS009UUf<0`0000f<BGP200000d45F`0300004P0^4P0^00800008oooo00<0003ooooo
ool05_ooo`006?ooo`030000oooooooo01_oool300000^[hb@030000i=o?i=o?00?Tgll00`000=W;
c=W;c006fL_<00<0003?^lO?^lL01lnka`030000aZk2aZk200W6[/800`000;jS_[jS_P09_Z>n00<0
002gVKVgVKT02[NI^@030000XYC6XYC600VRU<H00`0009V9`YV9`P07VHW200<0002=OKf=OKd01Hem
_@030000OFfgOFfg00AmKKL0100004]K`D]K`@00008K>;8300000^Am?P030000c6E9000000[>Ng03
00000lj9R0030000]7F;]7F;01ZdMH/00`0009IMS9IMS006UUf<0`0000j<BGP2000000=i9eL00011
1E/00T45F`<B02h00`000?ooooooo`06oooo00<0003oooooool05oooo`006?ooo`030000oooooooo
01_oool2000000CoeXh0000000000004i=o?00<0003IblcIbl`01]W;c0030000ck_7ck_700S?^lL0
0`000<J^`/J^`P08aZk200<0002nXkjnXkh02[jS_P030000]iVi]iVi00VgVKT010000:n?]@000000
00RRU<H00`0009V9`YV9`P08VHW200<0002=OKf=OKd01Hem_@030000OFfgOFfg00AmKKL3000000A;
Fl40000K>;8K>;83000000CTOCh0003<IDW<IDT200002likL08000000lj9R0000;AeR`0K]7F;00<0
002FGHbFGH`00YIMS0@0000?S4Uh0P0000=i9eL00`000445Fd45F`034P0^0P0000Soool00`000?oo
ooooo`0Goooo000Hoooo00<0003oooooool06oooo`800002omJ>00@0003cbJ<000000002i=o?00<0
003IblcIbl`01]W;c0030000ck_7ck_700O?^lL00`000<J^`/J^`P09aZk200<0002nXkjnXkh02KjS
_P030000]iVi]iVi00ZgVKT01@000:n?]Jn?]Jn?]@000007XYC600<0002IRL:IRL801iV9`P030000
SGfmSGfm00J=OKd00`0007e]]ge]]`04OFfg00<0001TEjiTEjh00P00008K>;800`000000SP000002
00001<aUB@80000;cW]`400000jdMH/00`0009IMS0000002000048a9N0<00006NBMG00@0000B02hB
02hB02h200002Oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Joooo0P0000;oeXh0
10000??9Xo?9Xo?9X`<00007fL_<00<0003?^lO?^lL01lnka`030000aZk2aZk200W6[/800`000;jS
_[jS_P0:_Z>n00<0002gVKVgVKT02KNI^@030000[hne[hne00>_SkD200001::DaP030000VHW2VHW2
00RIRL800`0008em_Hem_@06SGfm00<0001mKKMmKKL017e]]`040000I5N^I5N^I5N^0P0000066cRb
0000002>0000dEL000001/aUB@80000:cW]`00<0002aI7JaI7H03;5TMPl0000BS4Uh0P0000Qi9eL2
00000Q80;P800009oooo00<0003oooooool06?ooo`006Oooo`030000oooooooo01[oool200000_oF
SP030000llVSllVS00;cbJ<010000>JkZ@00000000CIbl`00`000<nkalnka`08ck_700<00036[/;6
[/802<J^`P030000_Z>n_Z>n00ZnXkh00`000;NI^KNI^@0:]iVi00<0002_SkF_SkD01Jn?]@050000
XYC6XYC6XYC6000000ZIRL800`0008em_Hem_@05SGfm00<0001mKKMmKKL017e]]`030000I5N^I5N^
009TEjh00`0003XbW@000005000000>j=P00003<IDT01LaUB@800008cW]`00<0002aI7JaI7H06[5T
MP030000S4UhS4Uh00j<BGP2000027TWE`8000001E006@000180;Q80;P00000:oooo00<0003ooooo
ool06?ooo`006Oooo`030000oooooooo01[oool200000_oFSP030000llVSllVS00;cbJ<010000>Jk
ZNJkZNJkZ@800002fL_<00<0003?^lO?^lL01lnka`030000aZk2aZk200W6[/800`000;jS_[jS_P09
_Z>n00<0002gVKVgVKT02[NI^@030000[hne[hne00N_SkD300002iV9`P030000SGfmSGfm00F=OKd0
0`0007e]]ge]]`04OFfg00<0001TEjiTEjh00VAG[P040000>S:M>S:M>S:M100000:j=P0200001/aU
B@800006cW]`00<0002aI7JaI7H06[5TMP030000S4UhS4Uh00^<BGP3000027TWE`800004D00I0`00
00[oool00`000?ooooooo`0Hoooo000Joooo00<0003oooooool06Oooo`800002omJ>00<0003cbJ?c
bJ<00_?9X`030000i[^Yi[^Y00?V^jT300002Lnka`030000aZk2aZk200S6[/800`000;jS_[jS_P0:
_Z>n00<0002gVKVgVKT02[NI^@030000[hne[hne00V_SkD200002IV9`P030000SGfmSGfm00J=OKd0
0`0007e]]ge]]`04OFfg00<0001TEjiTEjh00VAG[P060000>S:M>S:M>S:M0000001d0P0000Bj=P02
00001/aUB@800004cW]`00<0002aI7JaI7H06[5TMP030000S4UhS4Uh00V<BGP200002GTWE`800005
D00I0`0000[oool00`000?ooooooo`0Ioooo000Joooo00<0003oooooool06Oooo`8000000ooFSP00
0??9X`03llVS00<0003V^jWV^jT01NJkZ@040000fZn[000000001/nka`030000aZk2aZk200S6[/80
0`000;jS_[jS_P0:_Z>n00<0002gVKVgVKT02[NI^@030000[hne[hne00V_SkD00`000:J4/:J4/002
00001iV9`P030000SGfmSGfm00J=OKd00`0007e]]ge]]`04OFfg00<0001TEjiTEjh00VAG[P080000
>S:M>S:M>S:M0000001d0000oooo0P0000Bj=P0200001/aUB@800002cW]`00<0002aI7JaI7H06[5T
MP030000S4UhS4Uh00N<BGP200002GTWE`800005D00I0`0000coool00`000?ooooooo`0Ioooo000J
oooo00<0003oooooool06Oooo`040000omJ>omJ>00001??9X`030000i[^Yi[^Y00GV^jT010000=Z_
ZmZ_ZmZ_Z`800003ck_700<00036[/;6[/802LJ^`P030000_Z>n_Z>n00ZnXkh00`000;NI^KNI^@0:
]iVi00<0002_SkF_SkD02Jn?]@030000YXB`YXB`00:VQ;0200001IV9`P030000SGfmSGfm00J=OKd0
0`0007e]]ge]]`04OFfg00<0001TEjiTEjh00VAG[P070000>S:M>S:M>S:M0000001d000000?oool2
00001;Xf00800006c6E90`0001faI7H00`0008a9N8a9N003S4Uh0`0000Ui9eL200001E006@<0000>
oooo00<0003oooooool06Oooo`006oooo`030000oooooooo01Ooool01@000>G5A_oFS_oFSP000004
llVS00<0003V^jWV^jT01>JkZ@030000fZn[fZn[00CJ[j/2000000??^lL00036[/802LJ^`P030000
_Z>n_Z>n00ZnXkh00`000;NI^KNI^@0:]iVi00<0002_SkF_SkD02Jn?]@030000YXB`YXB`00FVQ;02
00000iV9`P030000SGfmSGfm00F=OKd00`0007e]]ge]]`05OFfg00<0001TEjiTEjh00VAG[P070000
>S:M>S:M>S:M0000001d000000Goool200001;Xf00030000c6E9c6E900G<IDT800005[5TMP040000
S4UhS4UhS4Uh0P0000Ui9eL300001E006@<0000?oooo00<0003oooooool06_ooo`006oooo`030000
oooooooo01Ooool01@000>G5A_oFS_oFSP000004llVS00<0003V^jWV^jT01>JkZ@030000fZn[fZn[
00KJ[j/200002/J^`P030000_Z>n_Z>n00ZnXkh00`000;NI^KNI^@09]iVi00<0002_SkF_SkD02Zn?
]@030000YXB`YXB`00NVQ;03000028em_@030000OFfgOFfg00EmKKL00`0006AG[VAG[P02I5N^00L0
000j<Ydj<Ydj<Yd0000007@000001oooo`800003^SH00P0000G<IDT00`000:Q7DJQ7D@05Z4MA3`00
00NaI7H0100008a9N000000000Ui9eL200001U006@<0000Aoooo00<0003oooooool06_ooo`006ooo
o`030000oooooooo01Ooool200000_oFSP030000llVSllVS00;cbJ<00`000>JkZNJkZ@04i[^Y00<0
003J[j_J[j/01]Z_Z`040000dJBZ000000001lJ^`P030000_Z>n_Z>n00ZnXkh00`000;NI^KNI^@0:
]iVi00<0002_SkF_SkD02Jn?]@030000YXB`YXB`00ZVQ;000`0008em_Hem_@06SGfm00<0001mKKMm
KKL017e]]`030000I5N^I5N^00=TEjh01`0003XbWCXbWCXbW@000000M0000008oooo0`0000>j=P02
00000laUB@030000Z4MAZ4MA01BXAe4800002WTWE`800006D00I0`0001?oool00`000?ooooooo`0J
oooo000Loooo00<0003oooooool05_ooo`800002omJ>00<0003cbJ?cbJ<00_?9X`030000i[^Yi[^Y
00CV^jT00`000=Z_ZmZ_Z`05fZn[00<0003AY:[AY:X00]6TZP800004aZk200<0002nXkjnXkh02[jS
_P030000]iVi]iVi00ZgVKT00`000:n?]Jn?]@0:[hne00<0002VQ;2VQ;002JJ4/0040000W7RZ0000
00001Xem_@030000OFfgOFfg00AmKKL00`0006AG[VAG[P03I5N^00L0000j<Ydj<Ydj<Yd0000007@0
00002_ooo`800004^SH00P0000;<IDT00`000:Q7DJQ7D@0JZ4MA00<0001i9eMi9eL01WTWE`800005
D00I100001Coool00`000?ooooooo`0Koooo000Loooo00<0003oooooool05_ooo`800002omJ>00<0
003cbJ?cbJ<00_?9X`030000i[^Yi[^Y00CV^jT00`000=Z_ZmZ_Z`05fZn[00<0003AY:[AY:X01=6T
ZP800002aZk200<0002nXkjnXkh02[jS_P030000]iVi]iVi00ZgVKT00`000:n?]Jn?]@09[hne00<0
002VQ;2VQ;002ZJ4/0040000W7RZW7RZW7RZ0P0000B=OKd00`0007e]]ge]]`04OFfg00<0001TEjiT
Ejh00fAG[P070000>S:M>S:M>S:M0000001d000000coool200001;Xf00<0000LZ4MA00<0001i9eMi
9eL017TWE`800005D00I100001Koool00`000?ooooooo`0Koooo000Loooo00<0003oooooool05_oo
o`800002omJ>00<0003cbJ?cbJ<00_?9X`030000i[^Yi[^Y00?V^jT00`000=Z_ZmZ_Z`06fZn[00<0
003AY:[AY:X01]6TZP80000<_Z>n00<0002gVKVgVKT02[NI^@030000[hne[hne00Z_SkD00`000:J4
/:J4/009YXB`00<0002LN:ZLN:X019ahZP040000SGfmSGfm00001ge]]`030000I5N^I5N^00=TEjh0
1`0003XbWCXbWCXbW@000000M000000>oooo0P0000Bj=P0800005ZQ7D@040000NBMGNBMGNBMG0P00
00E@01T400006?ooo`030000oooooooo01_oool001goool00`000?ooooooo`0Eoooo0P0000;oeXh0
1@000??9Xo?9Xo?9X`000006i[^Y00<0003J[j_J[j/01]Z_Z`030000dJBZdJBZ00OAY:X300002[jS
_P030000]iVi]iVi00ZgVKT00`000:n?]Jn?]@09[hne00<0002VQ;2VQ;002ZJ4/0030000W7RZW7RZ
00FLN:X300001ge]]`030000I5N^I5N^009TEjh00`0003XbWCXbW@02>S:M00<0000007@000003ooo
o`<00002^SH000<0002<3@N<3@L01H`=1`l00007Z4MA00<0001i9eL000001U006@@0000Ioooo00<0
003oooooool07?ooo`007Oooo`030000oooooooo01Goool200000_oFSP050000llVSllVSllVS0000
00KV^jT00`000=Z_ZmZ_Z`05fZn[00<0003AY:[AY:X01m6TZP040000bIZWbIZWbIZW0P0000NnXkh0
0`000;NI^KNI^@0:]iVi00<0002_SkF_SkD02Jn?]@030000YXB`YXB`00ZVQ;000`0009ahZYahZP08
W7RZ00<0001mKKMmKKL01Ge]]`030000I5N^I5N^009TEjh00`0003XbWCXbW@02>S:M00<0000007@0
00004Oooo`@0000FS0d7200000I@01T400006oooo`030000oooooooo01coool001koool00`000?oo
ooooo`0Doooo0P000003omJ>0000llVS00?cbJ<00`000>JkZNJkZ@04i[^Y00<0003J[j_J[j/01MZ_
Z`030000dJBZdJBZ00OAY:X00`000<VJYlVJY`03bIZW00<0002nXkjnXkh01;jS_P030000]iVi]iVi
00VgVKT00`000:n?]Jn?]@0:[hne00<0002VQ;2VQ;002ZJ4/0030000W7RZW7RZ00NLN:X0100008iX
X@00000000EmKKL00`0006AG[VAG[P02I5N^00D0000j<Ydj<Ydj<Yd000000P00M0030000oooooooo
017oool900005X`=1`030000D00ID00I009@01T400007?ooo`030000oooooooo01goool001koool0
0`000?ooooooo`0Doooo0P000003omJ>0000llVS00?cbJ<00`000>JkZNJkZ@04i[^Y00<0003J[j_J
[j/01MZ_Z`030000dJBZdJBZ00OAY:X00`000<VJYlVJY`04bIZW0P0000>nXkh00`000;NI^KNI^@0:
]iVi00<0002_SkF_SkD02Jn?]@030000YXB`YXB`00ZVQ;000`0009ahZYahZP08W7RZ00D0002>J:6>
J:6>J:4000000ge]]`030000I5N^I5N^00=TEjh01@0003XbWCXbWCXbW@000002001d00<0003ooooo
ool04oooo`P00002<@003@0000N<3@L00`0005006@00000300007_ooo`030000oooooooo01goool0
01ooool00`000?ooooooo`0Coooo0P000003omJ>0000llVS00?cbJ<00`000>JkZNJkZ@03i[^Y00<0
003J[j_J[j/01MZ_Z`030000dJBZdJBZ00OAY:X00`000<VJYlVJY`07bIZW0P000003_Z>n0000]iVi
00ZgVKT00`000:n?]Jn?]@0:[hne00<0002VQ;2VQ;002ZJ4/0030000W7RZW7RZ00NLN:X00`0008iX
XHiXX@03SVRQ00@0001mKKMmKKL00005I5N^00D0000j<Ydj<Ydj<Yd000000P00M0030000oooooooo
01_ooolJ00007oooo`030000oooooooo01koool001ooool00`000?ooooooo`0Coooo0P000003omJ>
0000llVS00?cbJ<00`000>JkZNJkZ@03i[^Y00<0003J[j_J[j/01MZ_Z`030000dJBZdJBZ00OAY:X0
0`000<VJYlVJY`09bIZW0P0000^gVKT00`000:n?]Jn?]@09[hne00<0002VQ;2VQ;002ZJ4/0030000
W7RZW7RZ00RLN:X00`0008iXXHiXX@04SVRQ0`0000ETEjh01@0003XbWCXbWCXbW@000002001d00<0
003oooooool0:oooo`P0000Qoooo00<0003oooooool07_ooo`008?ooo`030000oooooooo01;oool2
000000?oeXh0003cbJ<00o?9X`030000i[^Yi[^Y00?V^jT00`000=Z_ZmZ_Z`05fZn[00<0003AY:[A
Y:X01]6TZP030000bIZWbIZW00[9VZL010000<6AY000000000RgVKT00`000:n?]Jn?]@0:[hne00<0
002VQ;2VQ;002ZJ4/0030000W7RZW7RZ00NLN:X00`0008iXXHiXX@07SVRQ00<0001TEjiTEjh00fAG
[P050000>S:M>S:M>S:M0000008007@00`000?ooooooo`1Coooo00<0003oooooool07oooo`008?oo
o`030000oooooooo01;oool2000000?oeXh0003cbJ<00_?9X`030000i[^Yi[^Y00CV^jT00`000=Z_
ZmZ_Z`05fZn[00<0003AY:[AY:X01]6TZP030000bIZWbIZW00W9VZL00`000<6AY<6AY002`I6T0P00
00JgVKT00`000:n?]Jn?]@09[hne00<0002VQ;2VQ;002ZJ4/0030000W7RZW7RZ00RLN:X00`0008iX
XHiXX@07SVRQ0`0000=TEjh01@0003XbWCXbWCXbW@000002001d00<0003oooooool0Doooo`030000
oooooooo01ooool0027oool00`000?ooooooo`0Aoooo0P000003omJ>0000llVS00;cbJ<00`000>Jk
ZNJkZ@03i[^Y00<0003J[j_J[j/01MZ_Z`030000dJBZdJBZ00OAY:X00`000<VJYlVJY`09bIZW00<0
0031TJC1TJ@01<6AY0800003]iVi00<0002_SkF_SkD02Jn?]@030000YXB`YXB`00^VQ;000`0009ah
ZYahZP07W7RZ00<0002>J:6>J:401hiXX@050000NU6ENU6ENU6E0000009TEjh01@0003XbWCXbWCXb
W@000002001d00<0003oooooool0D_ooo`030000oooooooo023oool0027oool00`000?ooooooo`0A
oooo00@0003oeXkoeXh00003llVS00<0003V^jWV^jT00nJkZ@030000fZn[fZn[00GJ[j/00`000=6T
Z]6TZP06dJBZ00<00039VZO9VZL02LVJY`030000`I6T`I6T00O1TJ@2000000>gVKT0002_SkD02Zn?
]@030000YXB`YXB`00ZVQ;000`0009ahZYahZP08W7RZ00<0002>J:6>J:401hiXX@030000NU6ENU6E
009jDID300000cXbW@040000001d001d0000E?ooo`030000oooooooo023oool002;oool00`000?oo
ooooo`0?oooo0P0000;oeXh01@000??9Xo?9Xo?9X`000005i[^Y00<0003J[j_J[j/01MZ_Z`030000
dJBZdJBZ00KAY:X00`000<VJYlVJY`09bIZW00<00031TJC1TJ@02L6AY0030000[hne[hne00V_SkD0
0`000:J4/:J4/00:YXB`00<0002LN:ZLN:X029ahZP030000SVRQSVRQ00N>J:400`0007YAUGYAU@05
NU6E00D0000j<Ydj<Ydj<Yd000000P00M0030000oooooooo057oool00`000?ooooooo`0Qoooo000S
oooo00<0003oooooool03_ooo`800002omJ>00D0003cbJ?cbJ?cbJ<000001NJkZ@030000fZn[fZn[
00CJ[j/00`000=6TZ]6TZP07dJBZ00<00039VZO9VZL02<VJY`030000`I6T`I6T00W1TJ@010000;Z7
X000000000V_SkD00`000:J4/:J4/00:YXB`00<0002LN:ZLN:X029ahZP030000SVRQSVRQ00N>J:40
0`0007YAUGYAU@05NU6E0`000005>S:M0000001d001d000005;oool00`000?ooooooo`0Roooo000S
oooo00<0003oooooool03_ooo`8000000ooFSP000??9X`03llVS00<0003V^jWV^jT00nJkZ@030000
fZn[fZn[00CJ[j/00`000=6TZ]6TZP06dJBZ00<00039VZO9VZL02LVJY`030000`I6T`I6T00W1TJ@0
1@000;Z7X;Z7X;Z7X0000007[hne00<0002VQ;2VQ;002ZJ4/0030000W7RZW7RZ00RLN:X00`0008iX
XHiXX@07SVRQ00<0001jDIEjDID01GYAU@040000FBanFBanFBan0P00008007@00`000?ooooooo`1@
oooo00<0003oooooool08_ooo`009?ooo`030000oooooooo00goool2000000?oeXh0003cbJ<00o?9
X`030000i[^Yi[^Y00;V^jT00`000=Z_ZmZ_Z`05fZn[00<0003AY:[AY:X01]6TZP030000bIZWbIZW
00S9VZL00`000<6AY<6AY009`I6T00<0002jQj2jQj000kZ7X0800005[hne00<0002VQ;2VQ;002ZJ4
/0030000W7RZW7RZ00RLN:X00`0008iXXHiXX@07SVRQ00<0001jDIEjDID01GYAU@030000FBanFBan
009I;7h010000000M000M000057oool00`000?ooooooo`0Soooo000Uoooo00<0003oooooool03?oo
o`8000000ooFSP000??9X`03llVS00<0003V^jWV^jT00^JkZ@030000fZn[fZn[00GJ[j/00`000=6T
Z]6TZP05dJBZ00<00039VZO9VZL02LVJY`030000`I6T`I6T00W1TJ@00`000;Z7X;Z7X005^XNP00D0
002_SkF_SkF_SkD000003:J4/0030000W7RZW7RZ00RLN:X00`0008iXXHiXX@07SVRQ00<0001jDIEj
DID01GYAU@030000FBanFBan00=I;7h40000D?ooo`030000oooooooo02Coool002Goool00`000?oo
ooooo`0<oooo0P000003omJ>0000llVS00;cbJ<00`000>JkZNJkZ@03i[^Y00<0003J[j_J[j/01=Z_
Z`030000dJBZdJBZ00KAY:X00`000<VJYlVJY`08bIZW00<00031TJC1TJ@02L6AY0030000^XNP^XNP
00NjQj02000000>_SkD0002VQ;002jJ4/0030000W7RZW7RZ00NLN:X00`0008iXXHiXX@08SVRQ00<0
001jDIEjDID01GYAU@030000FBanFBan009I;7h01@0001<0CA<0CA<0C@00001@oooo00<0003ooooo
ool09?ooo`009_ooo`030000oooooooo00_oool400000o?9X`030000i[^Yi[^Y00?V^jT00`000=Z_
ZmZ_Z`04fZn[00<0003AY:[AY:X01]6TZP030000bIZWbIZW00S9VZL00`000<6AY<6AY008`I6T00<0
002jQj2jQj002[Z7X0030000YXB`YXB`00ZVQ;000`0009ahZYahZP08W7RZ00<0002>J:6>J:401hiX
X@030000NU6ENU6E00EjDID00`0005T/OUT/OP03FBan00<0000C04dC04d00P0004ooool00`000?oo
ooooo`0Uoooo000Voooo00<0003oooooool02oooo`030000hH87m9a700<000000o?9X`000>JkZ@04
i[^Y00<0003J[j_J[j/01=Z_Z`030000dJBZdJBZ00GAY:X00`000<VJYlVJY`08bIZW00<00031TJC1
TJ@02L6AY0030000^XNP^XNP00VjQj0010000;9mVP00000000ZVQ;000`0009ahZYahZP07W7RZ00<0
002>J:6>J:4028iXX@030000NU6ENU6E00EjDID00`0005T/OUT/OP02FBan00D0000C04dC04dC04d0
0000D?ooo`030000oooooooo02Goool002Ooool00`000?ooooooo`0:oooo00@0003QPPL0003dW4L2
lJ5Y0`0000?V^jT00`000=Z_ZmZ_Z`04fZn[00<0003AY:[AY:X01]6TZP030000bIZWbIZW00S9VZL0
0`000<6AY<6AY008`I6T00<0002jQj2jQj002[Z7X0040000/WfJ/WfJ/WfJ0P0000NVQ;000`0009ah
ZYahZP08W7RZ00<0002>J:6>J:401hiXX@030000NU6ENU6E00EjDID00`0005T/OUT/OP03FBan00<0
000C04dC04d00P0004ooool00`000?ooooooo`0Voooo000Xoooo00<0003oooooool02_ooo`040000
hH87m9a700000o6QJ@05jIij00000000i[^Y000000KJ[j/00`000=6TZ]6TZP06dJBZ00<00039VZO9
VZL01lVJY`030000`I6T`I6T00W1TJ@00`000;Z7X;Z7X009^XNP00<0002bOIZbOIX01;9mVP030000
YXB`YXB`00BVQ;000`0009ahZYahZP07W7RZ00<0002>J:6>J:4028iXX@030000NU6ENU6E00EjDID0
0`0005T/OUT/OP02FBan00D0000C04dC04dC04d00000Coooo`030000oooooooo02Ooool002Soool0
0`000?ooooooo`0:oooo00@0003QPPL000000003lJ5Y00<0003YWW[YWWX00`0000GJ[j/00`000=6T
Z]6TZP05dJBZ00<00039VZO9VZL02<VJY`030000`I6T`I6T00S1TJ@00`000;Z7X;Z7X009^XNP00<0
002bOIZbOIX01[9mVP800003YXB`00<0002LN:ZLN:X029ahZP030000SVRQSVRQ00N>J:400`0007YA
UGYAU@05NU6E00<0001I;7iI;7h00eT/OP0300004`1=4`1=0080001?oooo00<0003oooooool09ooo
o`00:Oooo`030000oooooooo00[oool2000000GdW4OaXFWaXFWaXFT000001>VNNP03h9R200000000
00?J[j/00`000=6TZ]6TZP05dJBZ00<00039VZO9VZL01lVJY`030000`I6T`I6T00S1TJ@00`000;Z7
X;Z7X00:^XNP00<0002bOIZbOIX02;9mVP8000000jJ4/00009ahZP08W7RZ00<0002>J:6>J:4028iX
X@030000NU6ENU6E00EjDID00`0005T/OUT/OP02FBan00D0000C04dC04dC04d00000Coooo`030000
oooooooo02Soool002[oool00`000?ooooooo`09oooo00@0003QPPOdW4L00002lJ5Y00<0003YWW[Y
WWX00^VNNP?PV88300001m6TZP030000bIZWbIZW00S9VZL00`000<6AY<6AY008`I6T00<0002jQj2j
Qj002KZ7X0030000/WfJ/WfJ00^bOIX00`0009ahZYahZP08W7RZ00<0002>J:6>J:401hiXX@030000
NU6ENU6E00EjDID00`0005T/OUT/OP03FBan00<0000C04dC04d00P0004koool00`000?ooooooo`0Y
oooo000[oooo00<0003oooooool02Oooo`<00003lJ5Y00D0003YWW[YWW[YWWX000001>2HPP800006
dJBZ00<00039VZO9VZL01lVJY`030000`I6T`I6T00S1TJ@00`000;Z7X;Z7X009^XNP00<0002bOIZb
OIX02k9mVP040000ZG2B000000001iahZP030000SVRQSVRQ00R>J:400`0007YAUGYAU@05NU6E00<0
001I;7iI;7h00UT/OP0500004`1=4`1=4`1=000004koool00`000?ooooooo`0Zoooo000/oooo00<0
003oooooool02?ooo`040000hH87m9a700000_6QJ@050000jIijjIijjIij000000CPV88010000=RB
QP00000000CAY:X00`000<VJYlVJY`07bIZW00<00031TJC1TJ@02<6AY0030000^XNP^XNP00RjQj00
0`000;9mV[9mVP0;/WfJ00<0002YL9:YL9800ZU`TP800005W7RZ00<0002>J:6>J:401hiXX@030000
NU6ENU6E00EjDID00`0005T/OUT/OP03FBan00<0000C04dC04d00P0004goool00`000?ooooooo`0[
oooo000]oooo00<0003oooooool02?ooo`<00002lJ5Y00D0003YWW[YWW[YWWX000001>2HPP040000
f9:6f9:6f9:60P000003dJBZ0000bIZW00S9VZL00`000<6AY<6AY008`I6T00<0002jQj2jQj002KZ7
X0030000/WfJ/WfJ00ZbOIX00`000:U`TZU`TP05ZG2B00D0002LN:ZLN:ZLN:X000002XiXX@030000
NU6ENU6E00EjDID00`0005T/OUT/OP02FBan00D0000C04dC04dC04d00000COooo`030000oooooooo
02coool002goool00`000?ooooooo`08oooo0`0000?aXFT010000>VNN^VNNP0000CPV8800`000=RB
Q]RBQP03f9:60`0000S9VZL00`000<6AY<6AY007`I6T00<0002jQj2jQj002KZ7X0030000/WfJ/WfJ
00ZbOIX00`000:U`TZU`TP07ZG2B0P000003W7RZ0000SVRQ00R>J:400`0007YAUGYAU@05NU6E00<0
001I;7iI;7h00eT/OP0300004`1=4`1=0080001=oooo00<0003oooooool0;?ooo`00;_ooo`030000
oooooooo00Soool00`000?BLA`000002lJ5Y00@0003YWW[YWWX00004h9R200<0003HTXKHTXH01=RB
QP040000d8^7000000001LVJY`030000`I6T`I6T00S1TJ@00`000;Z7X;Z7X008^XNP00<0002bOIZb
OIX02[9mVP030000ZG2BZG2B00ZYL9800`0008iXXHiXX@08SVRQ00<0001jDIEjDID01GYAU@030000
FBanFBan009I;7h01@0001<0CA<0CA<0C@00001=oooo00<0003oooooool0;Oooo`00;oooo`030000
oooooooo00Ooool300000_6QJ@050000jIijjIijjIij000000CPV8800`000=RBQ]RBQP03f9:600@0
003@RhO@RhO@RhL200000lVJY`030000`I6T`I6T00O1TJ@00`000;Z7X;Z7X009^XNP00<0002bOIZb
OIX02[9mVP030000ZG2BZG2B00VYL980100009iPR000000000N>J:400`0007YAUGYAU@05NU6E00<0
001I;7iI;7h00eT/OP0300004`1=4`1=0080001<oooo00<0003oooooool0;_ooo`00<?ooo`030000
oooooooo00Koool00`000>621`000003lJ5Y00@0003YWW[YWWX00004h9R200<0003HTXKHTXH00mRB
QP030000d8^7d8^700?@RhL300002/6AY0030000^XNP^XNP00RjQj000`000;9mV[9mVP0:/WfJ00<0
002YL9:YL9802JU`TP030000WV28WV2800:NH8P200001HiXX@030000NU6ENU6E00EjDID00`0005T/
OUT/OP02FBan00D0000C04dC04dC04d00000C?ooo`030000oooooooo02ooool0037oool00`000?oo
ooooo`06oooo00<0003dW4L000000_6QJ@040000jIijjIij00001>2HPP030000f9:6f9:600?HTXH0
0`000=2;Qm2;Q`05d8^700<00031TJC1TJ@01l6AY0030000^XNP^XNP00RjQj000`000;9mV[9mVP0:
/WfJ00<0002YL9:YL9802JU`TP030000WV28WV2800FNH8P01@0008iXXHiXXHiXX@000007NU6E00<0
001I;7iI;7h00eT/OP0300004`1=4`1=0080001;oooo00<0003oooooool0<?ooo`00<_ooo`030000
oooooooo00Goool300000_6QJ@040000jIijjIij00001>2HPP030000f9:6f9:600?HTXH00`000=2;
Qm2;Q`05d8^70`0000K1TJ@00`000;Z7X;Z7X009^XNP00<0002bOIZbOIX02K9mVP030000ZG2BZG2B
00VYL9800`0009iPR9iPR007WV280P000003SVRQ0000NU6E00IjDID00`0005T/OUT/OP02FBan00D0
000C04dC04dC04d00000Boooo`030000oooooooo037oool003?oool00`000?ooooooo`05oooo0P00
00?aXFT00`000>VNNP000004h9R200<0003HTXKHTXH00mRBQP030000d8^7d8^700C@RhL01@000<Z3
QLZ3QLZ3Q@000005`I6T00<0002jQj2jQj002;Z7X0030000/WfJ/WfJ00VbOIX00`000:U`TZU`TP09
ZG2B00<0002NH8RNH8P02YiPR0030000NU6ENU6E00EjDID00`0005T/OUT/OP03FBan00<0000C04dC
04d00P0004[oool00`000?ooooooo`0boooo000doooo00<0003oooooool01?ooo`<00002lJ5Y00@0
003YWW[YWWX00003h9R200<0003HTXKHTXH00mRBQP030000d8^7d8^700C@RhL00`000<Z3QLZ3Q@02
bX>500D00031TJC1TJC1TJ@000002[Z7X0030000/WfJ/WfJ00VbOIX00`000:U`TZU`TP09ZG2B00<0
002NH8RNH8P02YiPR0040000STUg000000001GYAU@030000FBanFBan009I;7h01@0001<0CA<0CA<0
C@00001:oooo00<0003oooooool0<oooo`00=Oooo`030000oooooooo00Coool200000_6QJ@040000
jIijjIij00000n2HPP030000f9:6f9:600?HTXH00`000=2;Qm2;Q`04d8^700<0003:PhG:PhD00lZ3
Q@8000000l6AY0000;Z7X008^XNP00<0002bOIZbOIX02K9mVP030000ZG2BZG2B00VYL9800`0009iP
R9iPR00:WV2800<0002>BGN>BGL00Xi9M`050000NU6ENU6ENU6E000000EI;7h00`0001<0CA<0C@02
0000BOooo`030000oooooooo03Coool003Koool00`000?ooooooo`03oooo00<0003dW4L000000_6Q
J@030000jIij000000?PV8800`000=RBQ]RBQP03f9:600<0003@RhO@RhL00m2;Q`030000bX>5bX>5
00K:PhD200002KZ7X0030000/WfJ/WfJ00RbOIX00`000:U`TZU`TP09ZG2B00<0002NH8RNH8P02IiP
R0800006STUg0P000003NU6E0000FBan00=I;7h01@0001<0CA<0CA<0C@000019oooo00<0003ooooo
ool0=Oooo`00=oooo`030000oooooooo00?oool200000_6QJ@030000jIij000000?PV8800`000=RB
Q]RBQP02f9:600<0003@RhO@RhL01=2;Q`030000bX>5bX>500G:PhD00`000<=kPL=kP@0200001[Z7
X0030000/WfJ/WfJ00RbOIX00`000:U`TZU`TP09ZG2B00<0002NH8RNH8P02IiPR0030000STUgSTUg
00R>BGL00`0005T/OUT/OP03FBan00<0000C04dC04d00P0004Soool00`000?ooooooo`0foooo000h
oooo00<0003oooooool00_ooo`800002lJ5Y00<0003YWWX000000n2HPP030000f9:6f9:600;HTXH0
0`000=2;Qm2;Q`04d8^700<0003:PhG:PhD01LZ3Q@030000`g^1`g^100;3Nh4200000kZ7X0030000
/WfJ/WfJ00RbOIX00`000:U`TZU`TP09ZG2B00<0002NH8RNH8P02IiPR0030000STUgSTUg00R>BGL0
0`0007@UFP000003FBan00D0000C04dC04dC04d00000B?ooo`030000oooooooo03Ooool003Woool0
0`000?ooooooo`02oooo0P0000;aXFT00`000>VNNP000003h9R200D0003HTXKHTXKHTXH000001]2;
Q`030000bX>5bX>500C:PhD00`000<=kPL=kP@05`g^10P000003^XNP0000/WfJ00VbOIX00`000:U`
TZU`TP09ZG2B00<0002NH8RNH8P029iPR0030000STUgSTUg00N>BGL200000g@UFP040000FBanFBan
00000Q<0C@800017oooo00<0003oooooool0>?ooo`00>_ooo`040000oooooooooooo1`0000?PV880
1@000=RBQ]RBQ]RBQP000005d8^700<0003:PhG:PhD01LZ3Q@030000`g^1`g^100O3Nh400`000;9m
V[9mVP08/WfJ00<0002YL9:YL9802JU`TP030000WV28WV2800RNH8P00`0008i9Mhi9M`07STUg00<0
001d9EYd9EX017@UFP8000034`1=00<0003oooooool0AOooo`030000oooooooo03Woool003_oool0
10000?ooooooooooo`800002g6/V0`0000;PV8801@000=RBQ]RBQ]RBQP000005d8^700<0003:PhG:
PhD01<Z3Q@030000`g^1`g^100O3Nh4010000;aaN`00000000NbOIX00`000:U`TZU`TP09ZG2B00<0
002NH8RNH8P029iPR0030000STUgSTUg00N>BGL00`0007@UFW@UFP06M2EJ00<0000C04dC04d00P00
04Koool00`000?ooooooo`0joooo000loooo00@0003oooooooooool200000]a[9P03g74j00000000
00800003f9:600<0003@RhO@RhL00m2;Q`030000bX>5bX>500C:PhD00`000<=kPL=kP@06`g^100<0
002lLG^lLG/00[aaN`800004/WfJ00<0002YL9:YL9802JU`TP030000WV28WV2800RNH8P00`0008i9
Mhi9M`07STUg00<0001d9EYd9EX01G@UFP80000014<08@0001<0C@0004Koool00`000?ooooooo`0k
oooo000moooo00D0003oooooooooool000000]a[9P800002fG960P0000;HTXH00`000=2;Qm2;Q`02
d8^700<0003:PhG:PhD01<Z3Q@030000`g^1`g^100K3Nh400`000;aaNkaaN`05_75k0P000003/WfJ
0000ZG2B00ZYL9800`0009iPR9iPR007WV280P0000R>BGL200001g@UFP030000@`0Q@`0Q00930242
0000AOooo`030000oooooooo03coool003koool01@000?ooooooooooo`000002g6/V0P0000;ILTH0
1=IaCP000000000000C@RhL00`000<Z3QLZ3Q@03bX>500<00033Nh73Nh401/=kP@030000_75k_75k
00RlLG/00`000:U`TZU`TP09ZG2B00<0002NH8RNH8P01iiPR0030000STUgSTUg00N>BGL00`0007@U
FW@UFP06M2EJ00@000130253025302430000AOooo`030000oooooooo03goool003ooool200000_oo
o`040000g6/V000000000]UbAP030000eW5>eW5>00800003d8^700<0003:PhG:PhD00lZ3Q@030000
`g^1`g^100G3Nh400`000;aaNkaaN`08_75k00@0002dI78000000008ZG2B00<0002NH8RNH8P01iiP
R0030000STUgSTUg00N>BGL00`0007@UFW@UFP05M2EJ0P0000=302430000A?ooo`800010oooo0011
oooo00D0003oool00000003LJbH00P000006fG960000eW5>eW5>0000dFiB0`0000G:PhD00`000<=k
PL=kP@06`g^100<0002lLG^lLG/01[aaN`800004]6Ab00<0002YL9:YL9801:U`TP030000WV28WV28
00NNH8P00`0008i9Mhi9M`06STUg0P0000Md9EX0100004<08D<08D<08@<00015oooo00<0003ooooo
ool0@?ooo`00@_ooo`030000oooo0000008000001]aa>P000=UbAP000=IaCP0000?AKU800`000<Z3
QLZ3Q@03bX>500<00033Nh73Nh401L=kP@030000_75k_75k00JlLG/00`000;ATL[ATLP05]6Ab00<0
002YL9:YL9800ZU`TP030000WV28WV2800NNH8P00`0008i9Mhi9M`06STUg00<0001d9EYd9EX01G@U
FP800003@`0Q0`0004Goool00`000?ooooooo`11oooo0013oooo00<0003oool000000`000005fG96
0000eW5>eW5>000000;AKU8300000/Z3Q@030000`g^1`g^100G3Nh400`000;aaNkaaN`06_75k00<0
002dI7:dI7801kATLP8000000jU`TP0009iPR008WV2800<0002>BGN>BGL01Xi9M`030000M2EJM2EJ
00Ed9EX00`0004<08D<08@02@`0Q0P0004Koool00`000?ooooooo`12oooo0014oooo00@0003oool0
003LJbH2000000CILTH0003FLDh00002dFiB00H0003<JE;<JE80003:PhD00006`g^100<0002lLG^l
LG/01KaaN`80000;]6Ab0P0000VNH8P00`0008i9Mhi9M`06STUg00<0001d9EYd9EX01G@UFP040000
@`0Q@`0Q@`0Q0`0004Koool00`000?ooooooo`13oooo0015oooo1@000004fG960000eW5>00000]5^
DP040000c6UBc6UBc6UB0P0000G3Nh400`000;aaNkaaN`05_75k00<0002dI7:dI7802KATLP800002
ZeET00<0002NH8RNH8P019iPR0800007STUg0P0000Id9EX200000d<08@<00016oooo00<0003ooooo
ool0A?ooo`00Aoooo`L000000m5^DP000<aYDP02c6UB00<00037Hdo7Hdl00P0000;3Nh400`000;aa
NkaaN`05_75k00<0002dI7:dI7802;ATLP800005ZeET0P0000>NH8P00`0008i9Mhi9M`06STUg00<0
001d9EYd9EX01G@UFP040000@`0Q@`0Q@`0Q0`0004Koool20000Aoooo`00BOooo`L00003c6UB00<0
0037Hdo7Hdl00/MSC`800007_75k00<0002dI7:dI7801kATLP800009ZeET00<0002NH8P0000028i9
M`030000M2EJM2EJ00Ed9EX0100004<08D<08D<08@<00016oooo00<0003oooooool0Aoooo`00B_oo
o`H00002c6UB00<00037Hdo7Hdl00/MSC`8000000l9JB@0000000003_75k0P0000NdI78300002j]E
I0800008STUg00<0001d9EYd9EX017@UFP800002@`0Q0`0004Koool20000B_ooo`00C?ooo`D00000
0laYDP000<MSC`02af=?00<00032FTW2FTT00l9JB@030000_75k000000NdI78200002Z]EI0@00002
Wcm?0P0000B>BGL200001W@UFP040000@`0Q@`0Q@`0Q0`0004Goool20000C?ooo`00COooo`<00000
1<123`0000000<MSC`800005`UY90`0000JdI78200002J]EI0<00008Wcm?0P000003STUg0000M2EJ
00Ed9EX200000T<08@<00016oooo00<0003oooooool0C?ooo`00Coooo`8000001;do3P0000000000
00;2FTT400000k]??`800002]6Ab0P0000R[EF@300002iloC`<00006M2EJ00@00013025302530243
0000AOooo`80001?oooo001@oooo1`0000BkCcl600001j]EI0@0000:Wcm?100000>=82l00`0007@U
FW@UFP02M2EJ00@000130253025302420000AOooo`80001Aoooo001Boooo2@0000Jd@S4200000Z]E
I0<00009Wcm?1@0000R=82l00`0007@UFP000003@`0Q0`0004Coool20000Doooo`00E?oooa000009
Wcm?100000^=82l400000d<08@<00013oooo0P0005Goool005Koool:00001:Xa7@800003Wcm?1000
00V=82l600000fh000030000@`0Q000000800013oooo0P0005Ooool005Soool500000idJ0PL00009
SB0_1P0000I^00070000@_ooo`80001Ioooo001Joooo2P0000:M6P80100008dP;hdP;hdP;`H00004
KP003@0004;oool20000Foooo`00G?ooo`800002oooo200000A^000@0000AOooo`80001Moooo001N
oooo0`0000;oool600000cD000P0001:oooo0`0005ooool0067oool300000oooo`D0001?oooo0`00
06;oool006Coool30000DOooo`<0001Uoooo001Woooo0`0004_oool30000J?ooo`00J_ooo`<00015
oooo0`0006_oool006goool40000?Oooo`@0001^oooo001aoooo0`0003Ooool30000L_ooo`00M?oo
o`D0000]oooo1@0007Goool007Woool600008Oooo`H0001joooo001ooooo2P0000goool:0000P?oo
o`00ROooo`d0002:oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
        ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}], 
      "\[IndentingNewLine]"}]}], "Input",
  Editable->False,
  CellDingbat->None],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.4;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\n", 
    StyleBox[\(\(\[CapitalDelta]1 = 0.4;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\n", 
    StyleBox[\(\(\[CapitalDelta]8 = 0.4;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\n", 
    StyleBox[\(\(kembed = \(-1\);\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\n", 
    RowBox[{Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.4474 .55325 m .3772 .55672 L .37746 .5 L p .662 .526 .688 r
F P
0 g
s
.37746 .5 m .44757 .5 L .4474 .55325 L p .662 .526 .688 r
F P
0 g
s
.44757 .5 m .37746 .5 L .3772 .44328 L p .662 .555 .723 r
F P
0 g
s
.29717 .5 m .37746 .5 L .3772 .55672 L p .717 .572 .69 r
F P
0 g
s
.37746 .5 m .29717 .5 L .2968 .44438 L p .717 .6 .724 r
F P
0 g
s
.2968 .44438 m .3772 .44328 L .37746 .5 L p .717 .6 .724 r
F P
0 g
s
.57242 .51893 m .61052 .57799 L .56127 .60612 L p .712 .62 .752 r
F P
0 g
s
.56127 .60612 m .52622 .54541 L .57242 .51893 L p .712 .62 .752 r
F P
0 g
s
.52622 .54541 m .56127 .60612 L .51228 .63471 L p .742 .63 .735 r
F P
0 g
s
.60142 .67566 m .56127 .60612 L .61052 .57799 L p .687 .56 .706 r
F P
0 g
s
.56127 .60612 m .60142 .67566 L .55343 .70379 L p .717 .571 .689 r
F P
0 g
s
.55343 .70379 m .51228 .63471 L .56127 .60612 L p .717 .571 .689 r
F P
0 g
s
.48018 .42782 m .51228 .36529 L .56127 .39388 L p .742 .582 .676 r
F P
0 g
s
.56127 .39388 m .52622 .45459 L .48018 .42782 L p .742 .582 .676 r
F P
0 g
s
.52622 .45459 m .56127 .39388 L .61052 .42201 L p .712 .544 .659 r
F P
0 g
s
.60142 .32434 m .56127 .39388 L .51228 .36529 L p .717 .599 .724 r
F P
0 g
s
.56127 .39388 m .60142 .32434 L .64977 .35183 L p .687 .561 .707 r
F P
0 g
s
.64977 .35183 m .61052 .42201 L .56127 .39388 L p .687 .561 .707 r
F P
0 g
s
.51228 .36529 m .55343 .29621 L .60142 .32434 L p .717 .599 .724 r
F P
0 g
s
.63995 .2576 m .60142 .32434 L .55343 .29621 L p .686 .613 .769 r
F P
0 g
s
.60142 .32434 m .63995 .2576 L .68309 .28201 L p .657 .576 .752 r
F P
0 g
s
.68309 .28201 m .64977 .35183 L .60142 .32434 L p .657 .576 .752 r
F P
0 g
s
.61052 .57799 m .64977 .64817 L .60142 .67566 L p .687 .56 .706 r
F P
0 g
s
.63995 .7424 m .60142 .67566 L .64977 .64817 L p .657 .497 .656 r
F P
0 g
s
.60142 .67566 m .63995 .7424 L .59724 .76756 L p .686 .507 .639 r
F P
0 g
s
.59724 .76756 m .55343 .70379 L .60142 .67566 L p .686 .507 .639 r
F P
0 g
s
.3772 .55672 m .2968 .55562 L .29717 .5 L p .717 .572 .69 r
F P
0 g
s
.2201 .5 m .29717 .5 L .2968 .55562 L p .769 .614 .687 r
F P
0 g
s
.29717 .5 m .2201 .5 L .21967 .45043 L p .769 .642 .721 r
F P
0 g
s
.21967 .45043 m .2968 .44438 L .29717 .5 L p .769 .642 .721 r
F P
0 g
s
.3772 .55672 m .4474 .55325 L .44703 .59174 L p .658 .494 .65 r
F P
0 g
s
.46527 .66275 m .44066 .60862 L p .48018 .57218 L .773 .641 .716 r
F P
0 g
s
.44066 .60862 m .44066 .60861 L .48018 .57218 L .773 .641 .716 r
F
.44066 .60862 m .44309 .60219 L .48018 .57218 L F
.44703 .59174 m .48018 .57218 L p .43917 .60535 L F P
0 g
s
.51228 .63471 m .48018 .57218 L .52622 .54541 L p .742 .63 .735 r
F P
0 g
s
.48018 .57218 m .51228 .63471 L .46527 .66275 L p .773 .641 .716 r
F P
0 g
s
.52622 .54541 m .48018 .57218 L p .49454 .51981 L .766 .691 .78 r
F P
0 g
s
.49454 .51981 m .49995 .50009 L .50421 .50729 L .766 .691 .78 r
F
.5 .5 m .50421 .50729 L p .49995 .50009 L F P
0 g
s
.50421 .50729 m .52622 .54541 L p .49454 .51981 L .766 .691 .78 r
F P
0 g
s
.57242 .51893 m .52622 .54541 L p .53515 .50312 L .736 .68 .797 r
F P
0 g
s
.53515 .50312 m .53581 .5 L .54046 .5024 L .736 .68 .797 r
F
.53515 .50312 m .54046 .5024 L .57242 .51893 L F
.57242 .48107 m .55829 .5 L p .55828 .5 L .736 .521 .602 r
F P
0 g
s
.57242 .48107 m .55828 .5 L .51989 .49482 L .736 .521 .602 r
F
.57242 .48107 m .59675 .49481 L p .55829 .5 L .704 .478 .578 r
F P
0 g
s
.55829 .5 m .55829 .5 L p .55829 .5 L .704 .478 .578 r
F P
0 g
s
.55829 .5 m .57242 .48107 L p .55829 .5 L .704 .478 .578 r
F P
0 g
s
.61052 .42201 m .57242 .48107 L .52622 .45459 L p .712 .544 .659 r
F P
0 g
s
.57242 .48107 m .61052 .42201 L .65832 .4487 L p .68 .501 .638 r
F P
0 g
s
.61052 .57799 m .57242 .51893 L .60594 .5 L p .68 .609 .77 r
F P
0 g
s
.65832 .4487 m .62165 .5 L p .57242 .48107 L .68 .501 .638 r
F P
0 g
s
.60593 .5 m .57242 .48107 L p .62165 .5 L .68 .501 .638 r
F P
0 g
s
.60594 .5 m .61713 .49368 L p .61664 .5 L .68 .609 .77 r
F P
0 g
s
.61052 .57799 m .60594 .5 L .6165 .50173 L .68 .609 .77 r
F
.65832 .5513 m .61052 .57799 L p .61655 .50109 L F P
0 g
s
.61655 .50109 m .61664 .5 L .61738 .50091 L .68 .609 .77 r
F
.61655 .50109 m .61738 .50091 L .65832 .5513 L F
.74086 .40111 m .70295 .47302 L .65832 .4487 L p .615 .473 .665 r
F P
0 g
s
.70295 .47302 m .74086 .40111 L .78027 .4211 L p .565 .413 .635 r
F P
0 g
s
.78027 .4211 m .74274 .49408 L .70295 .47302 L p .565 .413 .635 r
F P
0 g
s
.74983 .50231 m .74274 .50592 L p .74155 .50073 L .527 .562 .834 r
F P
0 g
s
.74274 .50592 m .7348 .51012 L p .72815 .5 L .595 .583 .81 r
F P
0 g
s
.72815 .5 m .73772 .5 L .73121 .50124 L .595 .583 .81 r
F
.7348 .51012 m .70295 .52698 L p .70071 .50361 L F P
0 g
s
.70295 .47302 m .74274 .49408 L p .7315 .49881 L .595 .388 .571 r
F P
0 g
s
.7315 .49881 m .72868 .5 L .72667 .49789 L .595 .388 .571 r
F
.7315 .49881 m .72667 .49789 L .70295 .47302 L F
.68181 .5 m .70295 .47302 L p .72868 .5 L F P
0 g
s
.72868 .5 m .70036 .5 L .72868 .5 L .595 .388 .571 r
F
.70036 .5 m .68181 .5 L .72868 .5 L F
.65832 .4487 m .70295 .47302 L p .6494 .4938 L .643 .452 .61 r
F P
0 g
s
.62165 .5 m .65832 .5513 L p .61664 .5 L .68 .609 .77 r
F P
0 g
s
.70295 .52698 m .65832 .5513 L p .65857 .5 L .643 .598 .788 r
F P
0 g
s
.70295 .47302 m .68181 .5 L p .63343 .5 L .643 .452 .61 r
F P
0 g
s
.6494 .4938 m .6479 .49439 L .64809 .49355 L .643 .452 .61 r
F
.6494 .4938 m .64809 .49355 L .65832 .4487 L F
.6479 .49439 m .63343 .5 L .62165 .5 L F
.62165 .5 m .65832 .4487 L p .6479 .49439 L F P
0 g
s
.65832 .5513 m .62165 .5 L p .65857 .5 L .643 .598 .788 r
F P
0 g
s
.61713 .50632 m .62165 .5 L p .63343 .5 L .643 .452 .61 r
F P
0 g
s
.61713 .49368 m .65872 .47055 L p .65857 .5 L .643 .598 .788 r
F P
0 g
s
.65857 .5 m .65857 .5 L .65857 .5 L .643 .598 .788 r
F
.65857 .5 m .61713 .49368 L .65857 .5 L F
.63343 .5 m .63343 .5 L .63343 .5 L .643 .452 .61 r
F
.68181 .5 m .70295 .52698 L p .66413 .50338 L .643 .598 .788 r
F P
0 g
s
.65857 .5 m .68181 .5 L .66413 .50338 L .643 .598 .788 r
F
.70295 .52698 m .68181 .5 L p .70036 .5 L .595 .583 .81 r
F P
0 g
s
.70071 .50361 m .70036 .5 L .7348 .51012 L .595 .583 .81 r
F
.70036 .5 m .6956 .45038 L .72815 .5 L F
.70036 .5 m .72815 .5 L .7348 .51012 L F
.65872 .52945 m .68181 .5 L p .72868 .5 L .595 .388 .571 r
F P
0 g
s
.68181 .5 m .68181 .5 L p .68181 .5 L .595 .388 .571 r
F P
0 g
s
.72868 .5 m .68181 .5 L .68181 .5 L .595 .388 .571 r
F
.68181 .5 m .65872 .52945 L p .63343 .5 L .643 .452 .61 r
F P
0 g
s
.62165 .5 m .61713 .49368 L p .65857 .5 L .643 .598 .788 r
F P
0 g
s
.65872 .52945 m .61713 .50632 L p .63343 .5 L .643 .452 .61 r
F P
0 g
s
.63343 .5 m .65872 .52945 L .63343 .5 L .643 .452 .61 r
F
.65872 .47055 m .68181 .5 L p .65857 .5 L .643 .598 .788 r
F P
0 g
s
.65872 .47055 m .6956 .45038 L p .70036 .5 L .595 .583 .81 r
F P
0 g
s
.68181 .5 m .65872 .47055 L p .70036 .5 L .595 .583 .81 r
F P
0 g
s
.69681 .62227 m .65832 .5513 L .70295 .52698 L p .615 .532 .737 r
F P
0 g
s
.70295 .52698 m .74086 .59889 L .69681 .62227 L p .615 .532 .737 r
F P
0 g
s
.74086 .59889 m .70295 .52698 L .74274 .50592 L p .565 .509 .751 r
F P
0 g
s
.6956 .54962 m .65872 .52945 L p .72868 .5 L .595 .388 .571 r
F P
0 g
s
.74274 .49408 m .73772 .5 L p .7315 .49881 L .595 .388 .571 r
F P
0 g
s
.73772 .5 m .74274 .49408 L .75438 .5 L p .527 .299 .512 r
F P
0 g
s
.75438 .5 m .75438 .5 L p .74138 .5 L .527 .299 .512 r
F P
0 g
s
.74138 .5 m .73772 .5 L .75438 .5 L .527 .299 .512 r
F
.6956 .45038 m .72624 .43395 L p .74138 .5 L .527 .562 .834 r
F P
0 g
s
.74155 .50073 m .74088 .5 L .74138 .5 L .527 .562 .834 r
F
.74088 .5 m .6956 .45038 L .74138 .5 L F
.74274 .50592 m .73772 .5 L p .74155 .50073 L F P
0 g
s
.73772 .5 m .74088 .5 L .74155 .50073 L .527 .562 .834 r
F
.75438 .5 m .74983 .50231 L p .74903 .5 L F P
0 g
s
.74274 .49408 m .78027 .4211 L .81346 .43688 L p .492 .33 .589 r
F P
0 g
s
.81346 .43688 m .7839 .49552 L p .77039 .49505 L .492 .33 .589 r
F P
0 g
s
.75171 .48683 m .77039 .49505 L .74274 .49408 L .492 .33 .589 r
F
.81346 .43688 m .77039 .49505 L .75171 .48683 L F
.81346 .56312 m .78164 .5 L p .80617 .5108 L .372 .41 .771 r
F P
0 g
s
.78164 .5 m .81346 .43688 L p .78703 .5 L .372 .197 .511 r
F P
0 g
s
.81346 .56312 m .78027 .5789 L p .77659 .5 L .492 .473 .765 r
F P
0 g
s
.7839 .49552 m .78164 .5 L p .77659 .5 L .492 .33 .589 r
F P
0 g
s
.7839 .49552 m .77659 .5 L .75439 .5 L .492 .33 .589 r
F
.78164 .5 m .81346 .56312 L p .77659 .5 L .492 .473 .765 r
F P
0 g
s
.78027 .5789 m .75438 .5 L .77659 .5 L .492 .473 .765 r
F
.78164 .5 m .77608 .51104 L .75438 .5 L p .492 .33 .589 r
F P
0 g
s
.75438 .5 m .74274 .49408 L p .7839 .49552 L .492 .33 .589 r
F P
0 g
s
.77608 .48896 m .78164 .5 L p .77659 .5 L .492 .473 .765 r
F P
0 g
s
.75439 .5 m .77659 .5 L .75438 .5 L .492 .33 .589 r
F
.78027 .5789 m .74274 .50592 L .75438 .5 L p .492 .473 .765 r
F P
0 g
s
.75438 .5 m .77608 .48896 L p .77659 .5 L .492 .473 .765 r
F P
0 g
s
.78164 .5 m .78164 .5 L p .80617 .5108 L .372 .41 .771 r
F P
0 g
s
.78703 .5 m .78703 .5 L .78703 .5 L .372 .197 .511 r
F
.81294 .5 m .81294 .5 L .81294 .5 L F
.83891 .44771 m .81294 .5 L p .81294 .5 L F P
0 g
s
.85527 .54705 m .83891 .55229 L p .82745 .50842 L .135 .273 .742 r
F P
0 g
s
.83891 .44771 m .81294 .5 L .79649 .49046 L .372 .197 .511 r
F
.83891 .44771 m .85527 .45295 L p .82519 .49218 L .135 0 .343 r
F P
0 g
s
.82519 .49218 m .82305 .48977 L .83891 .44771 L .135 0 .343 r
F
.81294 .5 m .83891 .44771 L p .81919 .5 L F P
0 g
s
.82519 .49218 m .82359 .5 L .81919 .5 L .135 0 .343 r
F
.82745 .50842 m .82051 .5 L .82525 .5 L .135 .273 .742 r
F
.82745 .50842 m .82682 .50598 L .83978 .51557 L F
.82682 .50598 m .82525 .5 L .82877 .50377 L F
.82682 .50598 m .82877 .50377 L .83978 .51557 L F
.85527 .45295 m .86143 .45214 L p .83821 .49314 L 0 0 0 r
F P
0 g
s
.83884 .50757 m .83212 .5 L .83884 .50757 L 0 0 .525 r
F
.83821 .49314 m .83432 .5 L .83212 .5 L 0 0 0 r
F
.85527 .54705 m .83212 .5 L p .83884 .50757 L 0 0 .525 r
F P
0 g
s
.83212 .5 m .83212 .5 L p .83884 .50757 L 0 0 .525 r
F P
0 g
s
.86143 .45214 m .83794 .5 L p .83432 .5 L 0 0 0 r
F P
0 g
s
.83212 .5 m .85527 .45295 L p .83821 .49314 L 0 0 0 r
F P
0 g
s
.85527 .45295 m .83212 .5 L p .82519 .49218 L .135 0 .343 r
F P
0 g
s
.83212 .5 m .8175 .47029 L p .83884 .50757 L 0 0 .525 r
F P
0 g
s
.83212 .5 m .83978 .51557 L p .82525 .5 L .135 .273 .742 r
F P
0 g
s
.83978 .51557 m .85527 .54705 L p .82745 .50842 L .135 .273 .742 r
F P
0 g
s
.83891 .55229 m .81294 .5 L p .82745 .50842 L .135 .273 .742 r
F P
0 g
s
.83891 .55229 m .81346 .56312 L p .80529 .50444 L .372 .41 .771 r
F P
0 g
s
.80529 .50444 m .80467 .5 L .80695 .50348 L .372 .41 .771 r
F
.80529 .50444 m .80695 .50348 L .83891 .55229 L F
.81919 .5 m .81919 .5 L .81294 .5 L .135 0 .343 r
F
.82519 .49218 m .81919 .5 L .82305 .48977 L F
.81294 .5 m .80467 .5 L .78703 .5 L .372 .197 .511 r
F
.81346 .43688 m .83891 .44771 L p .79649 .49046 L F P
0 g
s
.79649 .49046 m .78703 .5 L .79209 .48791 L .372 .197 .511 r
F
.79649 .49046 m .79209 .48791 L .81346 .43688 L F
.81294 .5 m .80145 .47687 L .82051 .5 L .135 .273 .742 r
F
.81294 .5 m .81294 .5 L p .81294 .5 L F P
0 g
s
.81294 .5 m .80145 .47687 L p .81294 .5 L .135 .273 .742 r
F P
0 g
s
.81294 .5 m .82051 .5 L .82745 .50842 L .135 .273 .742 r
F
.79649 .49046 m .81294 .5 L .78703 .5 L .372 .197 .511 r
F
.81294 .5 m .81294 .5 L p .80467 .5 L F P
0 g
s
.81294 .5 m .83891 .55229 L p .80467 .5 L .372 .41 .771 r
F P
0 g
s
.80145 .52313 m .81294 .5 L p .81919 .5 L .135 0 .343 r
F P
0 g
s
.8231 .53023 m .8175 .52971 L p .83432 .5 L 0 0 0 r
F P
0 g
s
.8175 .47029 m .8231 .46977 L p .83884 .50757 L 0 0 .525 r
F P
0 g
s
.8231 .46977 m .86143 .54786 L .85527 .54705 L p 0 0 .525 r
F P
0 g
s
.83794 .5 m .8231 .53023 L p .83432 .5 L 0 0 0 r
F P
0 g
s
.8175 .52971 m .83212 .5 L p .83432 .5 L 0 0 0 r
F P
0 g
s
.83212 .5 m .8175 .52971 L p .82359 .5 L .135 0 .343 r
F P
0 g
s
.83212 .5 m .82359 .5 L .82519 .49218 L .135 0 .343 r
F
.80145 .47687 m .8175 .47029 L p .82525 .5 L .135 .273 .742 r
F P
0 g
s
.82051 .5 m .80145 .47687 L .82525 .5 L .135 .273 .742 r
F
.8175 .52971 m .80145 .52313 L p .81919 .5 L .135 0 .343 r
F P
0 g
s
.82359 .5 m .8175 .52971 L .81919 .5 L .135 0 .343 r
F
.8175 .47029 m .83212 .5 L p .82525 .5 L .135 .273 .742 r
F P
0 g
s
.80467 .5 m .79129 .5 L .80467 .5 L .372 .41 .771 r
F
.80617 .5108 m .79129 .5 L .80467 .5 L F
.78164 .5 m .79129 .5 L .80617 .5108 L F
.81294 .5 m .80145 .52313 L p .78703 .5 L .372 .197 .511 r
F P
0 g
s
.79129 .5 m .79129 .5 L .80467 .5 L .372 .41 .771 r
F
.78703 .5 m .78703 .5 L .78703 .5 L .372 .197 .511 r
F
.78703 .5 m .78703 .5 L .81346 .43688 L F
.78164 .5 m .77608 .48896 L p .79129 .5 L .372 .41 .771 r
F P
0 g
s
.80145 .52313 m .77608 .51104 L p .78703 .5 L .372 .197 .511 r
F P
0 g
s
.78703 .5 m .80145 .52313 L .78703 .5 L .372 .197 .511 r
F
.80145 .47687 m .81294 .5 L p .80467 .5 L .372 .41 .771 r
F P
0 g
s
.77608 .51104 m .78164 .5 L p .78703 .5 L .372 .197 .511 r
F P
0 g
s
.77608 .48896 m .80145 .47687 L p .80467 .5 L .372 .41 .771 r
F P
0 g
s
.79129 .5 m .77608 .48896 L .80467 .5 L .372 .41 .771 r
F
.74155 .50073 m .72624 .43395 L .7493 .50077 L .527 .562 .834 r
F
.7451 .50141 m .7493 .50077 L .74983 .50231 L F
.74155 .50073 m .7493 .50077 L .7451 .50141 L F
.75438 .5 m .77608 .51104 L p .73772 .5 L .527 .299 .512 r
F P
0 g
s
.73772 .5 m .73772 .5 L .74138 .5 L .527 .299 .512 r
F
.73772 .5 m .74138 .5 L .75438 .5 L F
.73772 .5 m .6956 .45038 L p .74088 .5 L .527 .562 .834 r
F P
0 g
s
.7315 .49881 m .73772 .5 L .72868 .5 L .595 .388 .571 r
F
.72815 .5 m .72868 .5 L .73772 .5 L .595 .583 .81 r
F
.73772 .5 m .74274 .50592 L p .73121 .50124 L F P
0 g
s
.73772 .5 m .6956 .54962 L p .72868 .5 L .595 .388 .571 r
F P
0 g
s
.73771 .5 m .73772 .5 L p .72868 .5 L .595 .583 .81 r
F P
0 g
s
.74274 .50592 m .78027 .5789 L .74086 .59889 L p .565 .509 .751 r
F P
0 g
s
.6956 .54962 m .73772 .5 L p .77608 .51104 L .527 .299 .512 r
F P
0 g
s
.72624 .43395 m .77608 .48896 L .75438 .5 L p .527 .562 .834 r
F P
0 g
s
.74903 .5 m .72624 .43395 L .75438 .5 L .527 .562 .834 r
F
.6956 .45038 m .73771 .5 L p .72815 .5 L .595 .583 .81 r
F P
0 g
s
.60594 .5 m .57242 .51893 L p .57468 .5 L .704 .672 .816 r
F P
0 g
s
.59613 .5 m .55829 .5 L .58442 .49647 L .704 .478 .578 r
F
.52622 .45459 m .57242 .48107 L p .51989 .49482 L .736 .521 .602 r
F P
0 g
s
.51989 .49482 m .50011 .5 L .5043 .49272 L .736 .521 .602 r
F
.51989 .49482 m .5043 .49272 L .52622 .45459 L F
.55829 .5 m .55829 .5 L p .57442 .50218 L .704 .672 .816 r
F P
0 g
s
.55829 .5 m .55829 .5 L p .53581 .5 L .736 .521 .602 r
F P
0 g
s
.55829 .5 m .53581 .5 L .50011 .5 L .736 .521 .602 r
F
.55829 .5 m .54077 .47654 L p .57442 .50218 L .704 .672 .816 r
F P
0 g
s
.55829 .5 m .57442 .50218 L .57442 .50218 L .704 .672 .816 r
F
.54077 .47654 m .58016 .45416 L p .57468 .5 L F P
0 g
s
.57442 .50218 m .57156 .5 L .57468 .5 L .704 .672 .816 r
F
.57156 .5 m .54077 .47654 L .57468 .5 L F
.61713 .50632 m .55829 .5 L .59613 .5 L .704 .478 .578 r
F
.59675 .49481 m .60594 .5 L p .58442 .49647 L F P
0 g
s
.60594 .5 m .61713 .50632 L p .58442 .49647 L .704 .478 .578 r
F P
0 g
s
.6165 .50173 m .60594 .5 L .61664 .5 L .68 .609 .77 r
F
.62165 .5 m .61713 .50632 L .60593 .5 L p .68 .501 .638 r
F P
0 g
s
.61713 .49368 m .62165 .5 L p .61664 .5 L .68 .609 .77 r
F P
0 g
s
.58016 .45416 m .61713 .49368 L .60594 .5 L p .704 .672 .816 r
F P
0 g
s
.57468 .5 m .58016 .45416 L .60594 .5 L .704 .672 .816 r
F
.57242 .51893 m .55829 .5 L p .57442 .50218 L F P
0 g
s
.51989 .49482 m .55828 .5 L .50011 .5 L .736 .521 .602 r
F
.52622 .54541 m .5 .5 L p .50011 .5 L .736 .68 .797 r
F P
0 g
s
.52622 .54541 m .50011 .5 L .53581 .5 L .736 .68 .797 r
F
.44757 .5 m .4474 .44675 L p .48557 .48536 L .597 .502 .717 r
F P
0 g
s
.3772 .44328 m .4474 .44675 L .44757 .5 L p .662 .555 .723 r
F P
0 g
s
.4474 .44675 m .3772 .44328 L .37642 .38854 L p .658 .581 .757 r
F P
0 g
s
.51228 .36529 m .48018 .42782 L .44703 .40826 L p .773 .62 .691 r
F P
0 g
s
.37642 .38854 m .43561 .3943 L p .4474 .44675 L .658 .581 .757 r
F P
0 g
s
.43561 .3943 m .43917 .39465 L p .43996 .39962 L .658 .581 .757 r
F P
0 g
s
.43561 .3943 m .43996 .39962 L .4474 .44675 L .658 .581 .757 r
F
.44325 .39824 m .44703 .40826 L .44168 .39899 L .773 .62 .691 r
F
.51228 .36529 m .44703 .40826 L .44325 .39824 L F
.44703 .40826 m .48018 .42782 L p .4675 .43325 L .797 .597 .632 r
F P
0 g
s
.4675 .43325 m .46266 .43533 L .44703 .40826 L .797 .597 .632 r
F
.47086 .44952 m .46224 .4485 L p .45421 .42069 L .591 .526 .75 r
F P
0 g
s
.45421 .42068 m .46266 .43533 L .45421 .42069 L .591 .526 .75 r
F
.46266 .43533 m .47086 .44952 L .45421 .42069 L F
.46224 .4485 m .4474 .44675 L .44703 .40826 L p F P
0 g
s
.46527 .33725 m .51228 .36529 L p .44267 .39852 L .773 .62 .691 r
F P
0 g
s
.44267 .39852 m .44168 .39899 L .4421 .39789 L .773 .62 .691 r
F
.44267 .39852 m .4421 .39789 L .46527 .33725 L F
.29393 .34086 m .37516 .33773 L .37642 .38854 L p .713 .657 .793 r
F P
0 g
s
.37516 .33773 m .29393 .34086 L .29153 .29673 L p .706 .691 .833 r
F P
0 g
s
.29153 .29673 m .3735 .29274 L .37516 .33773 L p .706 .691 .833 r
F P
0 g
s
.37709 .28248 m .38376 .28682 L p .37986 .29045 L .885 .76 .719 r
F P
0 g
s
.38376 .28682 m .39137 .2916 L p .38592 .30241 L .841 .706 .713 r
F P
0 g
s
.38592 .30241 m .38114 .29413 L .38547 .29914 L .841 .706 .713 r
F
.39137 .2916 m .42189 .31075 L p .40277 .32438 L F P
0 g
s
.37516 .33773 m .3735 .29274 L p .38322 .30011 L .635 .635 .833 r
F P
0 g
s
.38322 .30011 m .38566 .30196 L .38484 .30475 L .635 .635 .833 r
F
.38322 .30011 m .38484 .30475 L .37516 .33773 L F
.4091 .34255 m .37516 .33773 L p .38566 .30196 L F P
0 g
s
.38566 .30196 m .39982 .32648 L .38566 .30196 L .635 .635 .833 r
F
.39982 .32648 m .4091 .34255 L .38566 .30196 L F
.37642 .38854 m .37516 .33773 L p .41994 .37372 L .65 .607 .793 r
F P
0 g
s
.43917 .39465 m .46527 .33725 L p .44168 .39899 L .773 .62 .691 r
F P
0 g
s
.42189 .31075 m .46527 .33725 L p .42071 .36267 L .805 .661 .703 r
F P
0 g
s
.37516 .33773 m .4091 .34255 L p .43328 .38444 L .65 .607 .793 r
F P
0 g
s
.41994 .37372 m .42119 .37473 L .42037 .37498 L .65 .607 .793 r
F
.41994 .37372 m .42037 .37498 L .37642 .38854 L F
.42119 .37473 m .43329 .38445 L .43917 .39465 L F
.43917 .39465 m .37642 .38854 L p .42119 .37473 L F P
0 g
s
.46527 .33725 m .43917 .39465 L p .42071 .36267 L .805 .661 .703 r
F P
0 g
s
.44691 .3954 m .43917 .39465 L p .43329 .38445 L .65 .607 .793 r
F P
0 g
s
.43596 .40172 m .39513 .37727 L p .42071 .36267 L .805 .661 .703 r
F P
0 g
s
.42071 .36267 m .42071 .36268 L .42071 .36267 L .805 .661 .703 r
F
.42071 .36268 m .43596 .40172 L .42071 .36267 L F
.43328 .38444 m .43328 .38444 L .43329 .38445 L .65 .607 .793 r
F
.4091 .34255 m .42189 .31075 L p .42086 .35617 L .805 .661 .703 r
F P
0 g
s
.42071 .36267 m .4091 .34255 L .42086 .35617 L .805 .661 .703 r
F
.42189 .31075 m .4091 .34255 L p .39982 .32648 L .841 .706 .713 r
F P
0 g
s
.40277 .32438 m .39982 .32648 L .39137 .2916 L .841 .706 .713 r
F
.39982 .32648 m .35923 .35542 L .38592 .30241 L F
.39982 .32648 m .38592 .30241 L .39137 .2916 L F
.44614 .34782 m .4091 .34255 L p .38566 .30196 L .635 .635 .833 r
F P
0 g
s
.4091 .34255 m .4091 .34255 L p .40909 .34255 L .635 .635 .833 r
F P
0 g
s
.38566 .30196 m .4091 .34255 L .40909 .34255 L .635 .635 .833 r
F
.4091 .34255 m .44614 .34782 L p .43328 .38444 L .65 .607 .793 r
F P
0 g
s
.43917 .39465 m .43596 .40172 L p .42071 .36267 L .805 .661 .703 r
F P
0 g
s
.44614 .34782 m .44691 .3954 L p .43329 .38445 L .65 .607 .793 r
F P
0 g
s
.43328 .38444 m .44614 .34782 L .43329 .38445 L .65 .607 .793 r
F
.39513 .37727 m .4091 .34255 L p .42071 .36267 L .805 .661 .703 r
F P
0 g
s
.39513 .37727 m .35923 .35542 L p .39982 .32648 L .841 .706 .713 r
F P
0 g
s
.4091 .34255 m .39513 .37727 L p .39982 .32648 L .841 .706 .713 r
F P
0 g
s
.50749 .26842 m .46527 .33725 L .42189 .31075 L p .775 .679 .757 r
F P
0 g
s
.42189 .31075 m .46522 .24197 L .50749 .26842 L p .775 .679 .757 r
F P
0 g
s
.46522 .24197 m .42189 .31075 L .38376 .28682 L p .808 .726 .775 r
F P
0 g
s
.44517 .3058 m .44614 .34782 L p .38566 .30196 L .635 .635 .833 r
F P
0 g
s
.3735 .29274 m .38114 .29413 L p .38322 .30011 L .635 .635 .833 r
F P
0 g
s
.38114 .29413 m .3735 .29274 L .37281 .2797 L p .606 .664 .88 r
F P
0 g
s
.37281 .2797 m .37281 .2797 L p .37931 .29096 L .606 .664 .88 r
F P
0 g
s
.37931 .29096 m .38114 .29413 L .37281 .2797 L .606 .664 .88 r
F
.35923 .35542 m .32968 .3371 L p .37931 .29096 L .885 .76 .719 r
F P
0 g
s
.37986 .29045 m .37956 .29139 L .37931 .29096 L .885 .76 .719 r
F
.37956 .29139 m .35923 .35542 L .37931 .29096 L F
.38376 .28682 m .38114 .29413 L p .37986 .29045 L F P
0 g
s
.38114 .29413 m .37956 .29139 L .37986 .29045 L .885 .76 .719 r
F
.37281 .2797 m .37709 .28248 L p .37548 .28433 L F P
0 g
s
.3735 .29274 m .29153 .29673 L .2886 .2601 L p .693 .733 .881 r
F P
0 g
s
.2886 .2601 m .35417 .25638 L p .36052 .26831 L .693 .733 .881 r
F P
0 g
s
.36274 .2886 m .36052 .26831 L .3735 .29274 L .693 .733 .881 r
F
.2886 .2601 m .36052 .26831 L .36274 .2886 L F
.39794 .19698 m .35918 .25609 L p .35626 .22945 L .888 .862 .809 r
F P
0 g
s
.35918 .25609 m .2886 .2601 L p .35649 .25143 L .663 .784 .939 r
F P
0 g
s
.39794 .19698 m .4282 .21782 L p .3617 .26046 L .845 .785 .793 r
F P
0 g
s
.35417 .25638 m .35918 .25609 L p .3617 .26046 L .693 .733 .881 r
F P
0 g
s
.35417 .25638 m .3617 .26046 L .3728 .27969 L .693 .733 .881 r
F
.35918 .25609 m .39794 .19698 L p .3617 .26046 L .845 .785 .793 r
F P
0 g
s
.4282 .21782 m .37281 .2797 L .3617 .26046 L .845 .785 .793 r
F
.35918 .25609 m .37152 .25539 L .37281 .2797 L p .693 .733 .881 r
F P
0 g
s
.37281 .2797 m .3735 .29274 L p .35417 .25638 L .693 .733 .881 r
F P
0 g
s
.3524 .26643 m .35918 .25609 L p .3617 .26046 L .845 .785 .793 r
F P
0 g
s
.3728 .27969 m .3617 .26046 L .37281 .2797 L .693 .733 .881 r
F
.4282 .21782 m .38376 .28682 L .37281 .2797 L p .845 .785 .793 r
F P
0 g
s
.37281 .2797 m .3524 .26643 L p .3617 .26046 L .845 .785 .793 r
F P
0 g
s
.35918 .25609 m .35918 .25609 L p .35626 .22945 L .888 .862 .809 r
F P
0 g
s
.35648 .25143 m .35648 .25142 L .35649 .25143 L .663 .784 .939 r
F
.34353 .22899 m .34353 .22899 L .34353 .22899 L F
.28526 .23264 m .34353 .22899 L p .34353 .22899 L F P
0 g
s
.36311 .1688 m .37583 .18035 L p .34357 .21221 L .919 .957 .795 r
F P
0 g
s
.28526 .23264 m .34353 .22899 L .34349 .248 L .663 .784 .939 r
F
.28526 .23264 m .28162 .21585 L p .33064 .22229 L .573 .838 .995 r
F P
0 g
s
.33064 .22229 m .32962 .22534 L .28526 .23264 L .573 .838 .995 r
F
.34353 .22899 m .28526 .23264 L p .3404 .22357 L F P
0 g
s
.33064 .22229 m .33821 .21977 L .3404 .22357 L .573 .838 .995 r
F
.34357 .21221 m .33974 .22243 L .33737 .21832 L .919 .957 .795 r
F
.34357 .21221 m .34177 .21398 L .3436 .19795 L F
.34177 .21398 m .33737 .21832 L .33888 .21339 L F
.34177 .21398 m .33888 .21339 L .3436 .19795 L F
.28162 .21585 m .27784 .21093 L p .32495 .21053 L .274 .769 .897 r
F P
0 g
s
.33714 .20277 m .33394 .21238 L .33714 .20277 L .785 .945 .602 r
F
.32495 .21053 m .33284 .21047 L .33394 .21238 L .274 .769 .897 r
F
.36311 .1688 m .33394 .21238 L p .33714 .20277 L .785 .945 .602 r
F P
0 g
s
.33394 .21238 m .33394 .21238 L p .33714 .20277 L .785 .945 .602 r
F P
0 g
s
.27784 .21093 m .33103 .20734 L p .33284 .21047 L .274 .769 .897 r
F P
0 g
s
.33394 .21238 m .28162 .21585 L p .32495 .21053 L .274 .769 .897 r
F P
0 g
s
.28162 .21585 m .33394 .21238 L p .33064 .22229 L .573 .838 .995 r
F P
0 g
s
.33394 .21238 m .31552 .23989 L p .33714 .20277 L .785 .945 .602 r
F P
0 g
s
.33394 .21238 m .3436 .19795 L p .33737 .21832 L .919 .957 .795 r
F P
0 g
s
.3436 .19795 m .36311 .1688 L p .34357 .21221 L .919 .957 .795 r
F P
0 g
s
.37583 .18035 m .34353 .22899 L p .34357 .21221 L .919 .957 .795 r
F P
0 g
s
.37583 .18035 m .39794 .19698 L p .3512 .23339 L .888 .862 .809 r
F P
0 g
s
.3512 .23339 m .34766 .23615 L .34954 .23244 L .888 .862 .809 r
F
.3512 .23339 m .34954 .23244 L .37583 .18035 L F
.3404 .22357 m .3404 .22357 L .34353 .22899 L .573 .838 .995 r
F
.33064 .22229 m .3404 .22357 L .32962 .22534 L F
.34353 .22899 m .34766 .23615 L .35648 .25143 L .663 .784 .939 r
F
.2886 .2601 m .28526 .23264 L p .34349 .248 L F P
0 g
s
.34349 .248 m .35648 .25143 L .34348 .25309 L .663 .784 .939 r
F
.34349 .248 m .34348 .25309 L .2886 .2601 L F
.34353 .22899 m .32924 .2505 L .33974 .22243 L .919 .957 .795 r
F
.34353 .22899 m .34353 .22899 L p .34353 .22899 L F P
0 g
s
.34353 .22899 m .32924 .2505 L p .34353 .22899 L .919 .957 .795 r
F P
0 g
s
.34353 .22899 m .33974 .22243 L .34357 .21221 L .919 .957 .795 r
F
.34349 .248 m .34353 .22899 L .35648 .25143 L .663 .784 .939 r
F
.34353 .22899 m .34353 .22899 L p .34766 .23615 L .888 .862 .809 r
F P
0 g
s
.34353 .22899 m .37583 .18035 L p .34954 .23244 L .888 .862 .809 r
F P
0 g
s
.34353 .22899 m .34353 .22899 L p .34766 .23615 L .663 .784 .939 r
F P
0 g
s
.34766 .23615 m .34353 .22899 L .34954 .23244 L .888 .862 .809 r
F
.36931 .22737 m .34353 .22899 L p .3404 .22357 L .573 .838 .995 r
F P
0 g
s
.36464 .20507 m .36698 .21018 L p .33284 .21047 L .274 .769 .897 r
F P
0 g
s
.31552 .23989 m .31227 .23531 L p .33714 .20277 L .785 .945 .602 r
F P
0 g
s
.31227 .23531 m .36074 .16307 L .36311 .1688 L p .785 .945 .602 r
F P
0 g
s
.33103 .20734 m .36464 .20507 L p .33284 .21047 L .274 .769 .897 r
F P
0 g
s
.36698 .21018 m .33394 .21238 L p .33284 .21047 L .274 .769 .897 r
F P
0 g
s
.33394 .21238 m .36698 .21018 L p .33821 .21977 L .573 .838 .995 r
F P
0 g
s
.33394 .21238 m .33821 .21977 L .33064 .22229 L .573 .838 .995 r
F
.32924 .2505 m .31552 .23989 L p .33737 .21832 L .919 .957 .795 r
F P
0 g
s
.33974 .22243 m .32924 .2505 L .33737 .21832 L .919 .957 .795 r
F
.36698 .21018 m .36931 .22737 L p .3404 .22357 L .573 .838 .995 r
F P
0 g
s
.33821 .21977 m .36698 .21018 L .3404 .22357 L .573 .838 .995 r
F
.31552 .23989 m .33394 .21238 L p .33737 .21832 L .919 .957 .795 r
F P
0 g
s
.34766 .23615 m .35435 .24774 L .34766 .23615 L .888 .862 .809 r
F
.35626 .22945 m .35435 .24774 L .34766 .23615 L F
.35918 .25609 m .35435 .24774 L .35626 .22945 L F
.34353 .22899 m .36931 .22737 L p .35648 .25143 L .663 .784 .939 r
F P
0 g
s
.35435 .24774 m .35435 .24774 L .34766 .23615 L .888 .862 .809 r
F
.35648 .25143 m .35649 .25143 L .35648 .25143 L .663 .784 .939 r
F
.35648 .25143 m .35648 .25143 L .2886 .2601 L F
.35918 .25609 m .3524 .26643 L p .35435 .24774 L .888 .862 .809 r
F P
0 g
s
.36931 .22737 m .37152 .25539 L p .35649 .25143 L .663 .784 .939 r
F P
0 g
s
.35648 .25142 m .36931 .22737 L .35649 .25143 L .663 .784 .939 r
F
.32924 .2505 m .34353 .22899 L p .34766 .23615 L .888 .862 .809 r
F P
0 g
s
.37152 .25539 m .35918 .25609 L p .35649 .25143 L .663 .784 .939 r
F P
0 g
s
.3524 .26643 m .32924 .2505 L p .34766 .23615 L .888 .862 .809 r
F P
0 g
s
.35435 .24774 m .3524 .26643 L .34766 .23615 L .888 .862 .809 r
F
.37986 .29045 m .32968 .3371 L .37602 .28372 L .885 .76 .719 r
F
.37867 .28704 m .37602 .28372 L .37709 .28248 L F
.37986 .29045 m .37602 .28372 L .37867 .28704 L F
.37281 .2797 m .37152 .25539 L p .38114 .29413 L .606 .664 .88 r
F P
0 g
s
.38114 .29413 m .38114 .29413 L .37931 .29096 L .606 .664 .88 r
F
.38114 .29413 m .37931 .29096 L .37281 .2797 L F
.38114 .29413 m .35923 .35542 L p .37956 .29139 L .885 .76 .719 r
F P
0 g
s
.38322 .30011 m .38114 .29413 L .38566 .30196 L .635 .635 .833 r
F
.38592 .30241 m .38566 .30196 L .38114 .29413 L .841 .706 .713 r
F
.38114 .29413 m .38376 .28682 L p .38547 .29914 L F P
0 g
s
.38114 .29413 m .44517 .3058 L p .38566 .30196 L .635 .635 .833 r
F P
0 g
s
.38114 .29413 m .38114 .29413 L p .38566 .30196 L .841 .706 .713 r
F P
0 g
s
.38376 .28682 m .4282 .21782 L .46522 .24197 L p .808 .726 .775 r
F P
0 g
s
.44517 .3058 m .38114 .29413 L p .37152 .25539 L .606 .664 .88 r
F P
0 g
s
.32968 .3371 m .3524 .26643 L .37281 .2797 L p .885 .76 .719 r
F P
0 g
s
.37548 .28433 m .32968 .3371 L .37281 .2797 L .885 .76 .719 r
F
.35923 .35542 m .38114 .29413 L p .38592 .30241 L .841 .706 .713 r
F P
0 g
s
.44703 .40826 m .44691 .3954 L p .46224 .4485 L .591 .526 .75 r
F P
0 g
s
.44703 .40826 m .4474 .44675 L p .43917 .39465 L .658 .581 .757 r
F P
0 g
s
.48018 .42782 m .52622 .45459 L p .48512 .46799 L .766 .56 .619 r
F P
0 g
s
.48512 .46799 m .48185 .46376 L .48018 .42782 L .766 .56 .619 r
F
.4474 .44675 m .47086 .44952 L p .48557 .48536 L .597 .502 .717 r
F P
0 g
s
.47086 .44952 m .47086 .44952 L p .47086 .44953 L .597 .502 .717 r
F P
0 g
s
.47086 .44952 m .47086 .44953 L .48557 .48536 L .597 .502 .717 r
F
.47086 .44952 m .48817 .4795 L .48557 .48536 L F
.52622 .45459 m .5 .5 L p .48209 .46898 L .766 .56 .619 r
F P
0 g
s
.49995 .49991 m .49995 .49991 L .49998 .49997 L .597 .502 .717 r
F
.49995 .49991 m .50001 .49997 L .49998 .49997 L F
.49995 .49991 m .49998 .49997 L .49998 .49997 L F
.5 .5 m .52622 .45459 L p .50011 .5 L .736 .521 .602 r
F P
0 g
s
.49993 .45296 m .50004 .49994 L p .48557 .48536 L .597 .502 .717 r
F P
0 g
s
.50011 .5 m .50011 .5 L .52622 .45459 L .736 .521 .602 r
F
.50004 .49994 m .54077 .47654 L p .50002 .49999 L .736 .68 .797 r
F P
0 g
s
.5 .5 m .50004 .49994 L .50002 .49999 L .736 .68 .797 r
F
.50011 .5 m .50011 .5 L .50011 .5 L .736 .521 .602 r
F
.55829 .5 m .55829 .5 L p .53581 .5 L .736 .68 .797 r
F P
0 g
s
.55829 .5 m .57242 .51893 L p .53581 .5 L .736 .68 .797 r
F P
0 g
s
.53581 .5 m .55829 .5 L .53581 .5 L .736 .68 .797 r
F
.55829 .5 m .54077 .52346 L p .50011 .5 L .736 .521 .602 r
F P
0 g
s
.53581 .5 m .50011 .5 L .53581 .5 L .736 .68 .797 r
F
.50011 .5 m .50011 .5 L .50011 .5 L .736 .521 .602 r
F
.53581 .5 m .50011 .5 L .54077 .47654 L .736 .68 .797 r
F
.53462 .5 m .50004 .5 L .50004 .49994 L p .512 .432 .703 r
F P
0 g
s
.50004 .49994 m .49993 .45296 L p .51168 .4689 L .512 .432 .703 r
F P
0 g
s
.51168 .4689 m .5152 .47367 L .50004 .49994 L .512 .432 .703 r
F
.48557 .48536 m .50004 .49994 L .50001 .49998 L .597 .502 .717 r
F
.54077 .47654 m .50004 .49994 L p .5152 .47367 L .757 .748 .844 r
F P
0 g
s
.52429 .45792 m .54077 .47654 L p .5152 .47367 L .757 .748 .844 r
F P
0 g
s
.54077 .47654 m .53056 .46501 L p .55079 .43106 L .726 .741 .864 r
F P
0 g
s
.53056 .46501 m .52666 .4606 L p .53374 .45194 L .726 .741 .864 r
F P
0 g
s
.53056 .46501 m .53374 .45194 L .55079 .43106 L .726 .741 .864 r
F
.53431 .42155 m .53399 .3861 L p .544 .40965 L .341 .35 .724 r
F P
0 g
s
.52666 .4606 m .52985 .45229 L .55079 .43106 L .726 .741 .864 r
F
.52985 .45229 m .53145 .44812 L .55079 .43106 L F
.53442 .44038 m .55079 .43106 L p .5284 .45081 L F P
0 g
s
.55079 .43106 m .58016 .45416 L .54077 .47654 L p .726 .741 .864 r
F P
0 g
s
.53829 .4303 m .53998 .43075 L .53915 .43219 L .372 .345 .7 r
F
.53431 .42155 m .54019 .42534 L p .53829 .4303 L F P
0 g
s
.49962 .40766 m .53431 .42155 L .5344 .43755 L p .502 .453 .735 r
F P
0 g
s
.5344 .43755 m .53442 .44038 L p .53292 .43897 L .502 .453 .735 r
F P
0 g
s
.49962 .40766 m .5344 .43755 L .53292 .43897 L .502 .453 .735 r
F
.544 .40965 m .54747 .41778 L .54019 .42534 L .341 .35 .724 r
F
.55492 .40552 m .58164 .41362 L .55079 .43106 L p .708 .823 .936 r
F P
0 g
s
.58164 .41362 m .55655 .40601 L p .57729 .39293 L .664 .827 .962 r
F P
0 g
s
.55655 .40601 m .55492 .40552 L .55687 .40443 L p .664 .827 .962 r
F P
0 g
s
.55687 .40443 m .57729 .39293 L p .55655 .40601 L .664 .827 .962 r
F P
0 g
s
.55408 .37952 m .55391 .35869 L p .56071 .38572 L 0 .073 .606 r
F P
0 g
s
.56422 .3833 m .56424 .37105 L p .56558 .3825 L 0 0 .296 r
F P
0 g
s
.57729 .39293 m .56359 .39381 L p .56895 .38603 L .59 .908 .981 r
F P
0 g
s
.56359 .39381 m .5638 .39261 L .56895 .38603 L .59 .908 .981 r
F
.56282 .39386 m .56343 .3917 L .56895 .38603 L F
.56122 .39396 m .56123 .39395 L .56342 .3917 L F
.56342 .3917 m .56342 .3917 L .56895 .38603 L F
.56122 .39396 m .56342 .3917 L .56342 .3917 L F
.56071 .38572 m .56203 .39097 L .55966 .39081 L 0 .073 .606 r
F
.56203 .39097 m .56231 .39208 L .56138 .39164 L F
.56203 .39097 m .56138 .39164 L .55966 .39081 L F
.56122 .39396 m .55966 .39081 L p .56231 .39208 L F P
0 g
s
.56558 .3825 m .56591 .38533 L .56485 .38661 L 0 0 .296 r
F
.56577 .38714 m .56895 .38603 L .56452 .38854 L p .508 .912 .863 r
F P
0 g
s
.5646 .38834 m .56577 .38714 L .56452 .38854 L .508 .912 .863 r
F
.56422 .3833 m .56468 .38723 L .5644 .38822 L 0 0 .34 r
F
.56428 .38867 m .56427 .3884 L p .5644 .38822 L F P
0 g
s
.56427 .3884 m .56422 .3833 L p .5644 .38822 L 0 0 .34 r
F P
0 g
s
.58604 .37529 m .58537 .37626 L p .56822 .38238 L .322 .799 .725 r
F P
0 g
s
.56424 .37105 m .56448 .36419 L p .56685 .38374 L 0 0 .241 r
F P
0 g
s
.56685 .38374 m .56684 .38375 L .56424 .37105 L 0 0 .241 r
F
.56687 .38389 m .56656 .38471 L .56424 .37105 L F
.56656 .38471 m .56656 .38471 L p .56656 .38471 L F P
0 g
s
.56656 .38471 m .56424 .37105 L p .56656 .38471 L 0 0 .241 r
F P
0 g
s
.57956 .37989 m .56895 .38603 L p .56588 .38652 L .45 .882 .829 r
F P
0 g
s
.56588 .38652 m .56591 .38642 L .57956 .37989 L .45 .882 .829 r
F
.56563 .38656 m .56548 .38658 L .56716 .38449 L F
.56591 .38533 m .56596 .38576 L .56501 .38741 L 0 0 .296 r
F
.56596 .38576 m .56596 .38576 L .56548 .38658 L F
.56596 .38576 m .56548 .38658 L .56501 .38741 L F
.565 .38741 m .56485 .38661 L p .56591 .38533 L F P
0 g
s
.56485 .38661 m .565 .38741 L p .56468 .38723 L 0 0 .34 r
F P
0 g
s
.56422 .3833 m .56485 .38661 L p .56468 .38723 L 0 0 .34 r
F P
0 g
s
.55966 .39081 m .55408 .37952 L p .56071 .38572 L 0 .073 .606 r
F P
0 g
s
.55408 .37952 m .56122 .39396 L p .55858 .39741 L .043 .126 .626 r
F P
0 g
s
.55408 .37952 m .55753 .39323 L .55528 .40173 L .043 .126 .626 r
F
.55433 .40296 m .55408 .37952 L p .55528 .40173 L F P
0 g
s
.53365 .35507 m .55408 .37952 L .55436 .40519 L p .285 .34 .743 r
F P
0 g
s
.55391 .35869 m .56422 .3833 L .56428 .38867 L p 0 .073 .606 r
F P
0 g
s
.56123 .39395 m .56231 .39208 L .56602 .38768 L .59 .908 .981 r
F
.56428 .38867 m .56602 .38768 L p .56231 .39208 L F P
0 g
s
.56359 .39381 m .56282 .39386 L p .5638 .39261 L .59 .908 .981 r
F P
0 g
s
.56282 .39386 m .56122 .39396 L p .56343 .3917 L .59 .908 .981 r
F P
0 g
s
.56602 .38768 m .56895 .38603 L p .56122 .39396 L .59 .908 .981 r
F P
0 g
s
.55753 .39323 m .55878 .39819 L .55451 .40544 L .043 .126 .626 r
F
.55878 .39819 m .55875 .39824 L .55451 .40544 L F
.55455 .40551 m .55451 .40544 L p .55878 .39819 L F P
0 g
s
.55436 .40519 m .55433 .40296 L p .55528 .40173 L .043 .126 .626 r
F P
0 g
s
.55451 .40544 m .55436 .40519 L p .55753 .39323 L .043 .126 .626 r
F P
0 g
s
.55254 .42025 m .55085 .42023 L .55492 .40552 L .708 .823 .936 r
F
.55085 .42023 m .54915 .42021 L .55375 .40852 L F
.55085 .42023 m .55375 .40852 L .55492 .40552 L F
.54915 .42021 m .54608 .42018 L .5538 .40738 L F
.54915 .42021 m .5538 .40738 L .55492 .40552 L F
.53399 .3861 m .55436 .40519 L .55436 .40584 L p .341 .35 .724 r
F P
0 g
s
.54641 .4153 m .55436 .40584 L .54747 .41778 L .341 .35 .724 r
F
.53399 .3861 m .55436 .40584 L .54641 .4153 L F
.55464 .40551 m .55492 .40552 L .55436 .40584 L p .701 .914 .968 r
F P
0 g
s
.55436 .40584 m .55492 .40552 L p .5538 .40738 L .708 .823 .936 r
F P
0 g
s
.58016 .45416 m .55079 .43106 L .58164 .41362 L p .691 .738 .887 r
F P
0 g
s
.56465 .42152 m .56492 .44584 L p .55447 .40565 L .111 .154 .627 r
F P
0 g
s
.55446 .40558 m .55449 .40563 L .55447 .40565 L .111 .154 .627 r
F
.55449 .40563 m .56465 .42152 L .55447 .40565 L F
.55436 .40584 m .55436 .40519 L p .55446 .40558 L F P
0 g
s
.54019 .42534 m .53431 .42155 L p .544 .40965 L .341 .35 .724 r
F P
0 g
s
.53431 .42155 m .49962 .40766 L .49916 .36579 L p .48 .467 .766 r
F P
0 g
s
.49916 .36579 m .53399 .3861 L .53431 .42155 L p .48 .467 .766 r
F P
0 g
s
.53564 .40477 m .55455 .40551 L p .52929 .42 L .701 .914 .968 r
F P
0 g
s
.55455 .40551 m .55464 .40551 L p .55451 .40559 L .701 .914 .968 r
F P
0 g
s
.55451 .40544 m .55455 .40551 L p .55446 .40558 L .111 .154 .627 r
F P
0 g
s
.55451 .40559 m .55464 .40551 L .55436 .40584 L .701 .914 .968 r
F
.55455 .40551 m .56465 .42152 L p .55449 .40563 L .111 .154 .627 r
F P
0 g
s
.55455 .40551 m .55449 .40563 L .55446 .40558 L .111 .154 .627 r
F
.55446 .40558 m .55447 .40565 L .55436 .40584 L F
.55436 .40584 m .55436 .40584 L p .55464 .40551 L .701 .914 .968 r
F P
0 g
s
.55447 .40565 m .56492 .44584 L .55436 .40584 L .111 .154 .627 r
F
.55436 .40584 m .52929 .42 L p .55451 .40559 L .701 .914 .968 r
F P
0 g
s
.52929 .42 m .55455 .40551 L .55451 .40559 L .701 .914 .968 r
F
.55436 .40584 m .55436 .40584 L p .54608 .42018 L .708 .823 .936 r
F P
0 g
s
.54608 .42018 m .55436 .40584 L .5538 .40738 L .708 .823 .936 r
F
.55436 .40519 m .55451 .40544 L p .55446 .40558 L .111 .154 .627 r
F P
0 g
s
.55079 .43106 m .54456 .42786 L p .55254 .42025 L .708 .823 .936 r
F P
0 g
s
.54232 .4267 m .54019 .42534 L p .54747 .41778 L .341 .35 .724 r
F P
0 g
s
.54019 .42534 m .54232 .4267 L p .53829 .4303 L .372 .345 .7 r
F P
0 g
s
.52731 .44917 m .53442 .44038 L .5284 .45081 L .502 .453 .735 r
F
.49962 .40766 m .53442 .44038 L .52731 .44917 L F
.53442 .44038 m .53431 .42155 L p .53829 .4303 L .372 .345 .7 r
F P
0 g
s
.53829 .4303 m .53915 .43219 L .53442 .44038 L .372 .345 .7 r
F
.54232 .4267 m .54456 .42786 L p .53442 .44038 L .743 .823 .914 r
F P
0 g
s
.53915 .43219 m .54232 .4267 L .53442 .44038 L .743 .823 .914 r
F
.54456 .42786 m .55079 .43106 L .53442 .44038 L p F P
0 g
s
.53442 .44038 m .53442 .44038 L p .54456 .42786 L .743 .823 .914 r
F P
0 g
s
.53915 .43219 m .55485 .46666 L .53442 .44038 L .372 .345 .7 r
F
.53442 .44038 m .53915 .43219 L .53442 .44038 L .743 .823 .914 r
F
.54232 .4267 m .55464 .43463 L p .53998 .43075 L .372 .345 .7 r
F P
0 g
s
.54232 .4267 m .53998 .43075 L .53947 .43061 L .372 .345 .7 r
F
.54232 .4267 m .53947 .43061 L .53829 .4303 L F
.54456 .42786 m .54232 .4267 L p .55254 .42025 L .708 .823 .936 r
F P
0 g
s
.54232 .4267 m .52929 .42 L p .54707 .42019 L .708 .823 .936 r
F P
0 g
s
.54232 .4267 m .54707 .42019 L .55254 .42025 L .708 .823 .936 r
F
.55436 .40584 m .55464 .43463 L p .54747 .41778 L .341 .35 .724 r
F P
0 g
s
.52929 .42 m .55436 .40584 L p .54747 .41778 L .708 .823 .936 r
F P
0 g
s
.54608 .42018 m .54608 .42018 L .54747 .41778 L .708 .823 .936 r
F
.54608 .42018 m .52929 .42 L .54747 .41778 L F
.55436 .40519 m .53399 .3861 L .53365 .35507 L p .285 .34 .743 r
F P
0 g
s
.53564 .40477 m .55408 .39442 L p .55488 .40494 L .654 .913 .979 r
F P
0 g
s
.55492 .40552 m .55455 .40551 L p .55488 .40494 L .654 .913 .979 r
F P
0 g
s
.55455 .40551 m .53564 .40477 L p .55488 .40494 L .654 .913 .979 r
F P
0 g
s
.55878 .39819 m .55878 .39819 L .55875 .39824 L .043 .126 .626 r
F
.57729 .39293 m .55492 .40552 L p .55488 .40494 L .654 .913 .979 r
F P
0 g
s
.55488 .40494 m .55489 .40494 L .57729 .39293 L .654 .913 .979 r
F
.56122 .39396 m .57729 .39293 L p .55488 .40494 L F P
0 g
s
.56465 .42152 m .55455 .40551 L p .55878 .39819 L .043 .126 .626 r
F P
0 g
s
.55488 .40494 m .55488 .40494 L .55489 .40494 L .654 .913 .979 r
F
.55858 .39741 m .55908 .39766 L .55878 .39819 L .043 .126 .626 r
F
.56122 .39396 m .56439 .40037 L p .55858 .39741 L F P
0 g
s
.55408 .39442 m .56122 .39396 L p .55488 .40494 L .654 .913 .979 r
F P
0 g
s
.56439 .40037 m .56465 .42152 L p .55878 .39819 L .043 .126 .626 r
F P
0 g
s
.55908 .39766 m .56439 .40037 L .55878 .39819 L .043 .126 .626 r
F
.56428 .38867 m .56439 .40037 L p .56231 .39208 L 0 .073 .606 r
F P
0 g
s
.55391 .35869 m .56428 .38867 L .56231 .39208 L 0 .073 .606 r
F
.56427 .38867 m .56428 .38867 L p .56231 .39208 L .59 .908 .981 r
F P
0 g
s
.54987 .39269 m .55856 .38768 L p .56548 .38658 L .45 .882 .829 r
F P
0 g
s
.56895 .38603 m .565 .38741 L p .56548 .38658 L .45 .882 .829 r
F P
0 g
s
.56468 .38723 m .56475 .38785 L .56428 .38867 L 0 0 .34 r
F
.565 .38741 m .56479 .38777 L .56468 .38723 L F
.56468 .38723 m .56479 .38777 L .56475 .38785 L F
.565 .38741 m .54987 .39269 L p .56548 .38658 L .45 .882 .829 r
F P
0 g
s
.56485 .38661 m .56422 .3833 L p .56558 .3825 L 0 0 .296 r
F P
0 g
s
.56656 .38471 m .56716 .38449 L p .56548 .38658 L .45 .882 .829 r
F P
0 g
s
.56716 .38449 m .57956 .37989 L p .56563 .38656 L .45 .882 .829 r
F P
0 g
s
.56799 .39313 m .568 .40316 L p .56596 .38576 L 0 0 .296 r
F P
0 g
s
.56424 .37105 m .56656 .38471 L p .56593 .38549 L 0 0 .296 r
F P
0 g
s
.56448 .36419 m .56748 .38312 L p .56748 .38312 L 0 0 .241 r
F P
0 g
s
.56448 .36419 m .56748 .38312 L .56685 .38374 L 0 0 .241 r
F
.56448 .36419 m .56498 .36313 L p .56758 .38294 L 0 0 .177 r
F P
0 g
s
.58537 .37626 m .56748 .38312 L p .56822 .38238 L .322 .799 .725 r
F P
0 g
s
.57956 .37989 m .56656 .38471 L p .56759 .38345 L .388 .844 .782 r
F P
0 g
s
.56685 .38374 m .56748 .38312 L .5669 .38412 L 0 0 .241 r
F
.56748 .38312 m .56723 .38356 L .5669 .38412 L F
.56687 .38389 m .5669 .38412 L .56656 .38471 L F
.56656 .38471 m .56656 .38471 L .56759 .38345 L .388 .844 .782 r
F
.56656 .38471 m .56718 .38364 L .56759 .38345 L F
.56799 .39313 m .56656 .38471 L p .5669 .38412 L 0 0 .241 r
F P
0 g
s
.56656 .38471 m .56656 .38471 L p .56656 .38471 L .388 .844 .782 r
F P
0 g
s
.56685 .38374 m .56687 .38389 L .56684 .38375 L 0 0 .241 r
F
.56656 .38471 m .55856 .38768 L p .56718 .38364 L .388 .844 .782 r
F P
0 g
s
.5682 .38761 m .56799 .39313 L p .5669 .38412 L 0 0 .241 r
F P
0 g
s
.58537 .37626 m .57956 .37989 L p .56723 .38356 L .388 .844 .782 r
F P
0 g
s
.56748 .38312 m .56748 .38312 L p .56723 .38356 L 0 0 .241 r
F P
0 g
s
.56748 .38312 m .58537 .37626 L p .56723 .38356 L .388 .844 .782 r
F P
0 g
s
.5682 .38761 m .56748 .38312 L p .56758 .38294 L 0 0 .177 r
F P
0 g
s
.56748 .38312 m .56448 .36419 L p .56758 .38294 L 0 0 .177 r
F P
0 g
s
.56822 .38238 m .56779 .38259 L .56783 .38252 L .322 .799 .725 r
F
.56862 .3869 m .5682 .38761 L p .56758 .38294 L 0 0 .177 r
F P
0 g
s
.56498 .36313 m .56793 .38235 L p .56758 .38294 L 0 0 .177 r
F P
0 g
s
.56748 .38312 m .56779 .38259 L .56822 .38238 L .322 .799 .725 r
F
.56363 .38402 m .56847 .38214 L p .56822 .38238 L F P
0 g
s
.56793 .38235 m .56862 .3869 L p .56758 .38294 L 0 0 .177 r
F P
0 g
s
.56748 .38312 m .56324 .38474 L p .56779 .38259 L .322 .799 .725 r
F P
0 g
s
.56324 .38474 m .56363 .38402 L p .56783 .38252 L .322 .799 .725 r
F P
0 g
s
.56779 .38259 m .56324 .38474 L .56783 .38252 L .322 .799 .725 r
F
.55856 .38768 m .56324 .38474 L p .56723 .38356 L .388 .844 .782 r
F P
0 g
s
.56759 .38345 m .56718 .38364 L .56723 .38356 L .388 .844 .782 r
F
.56718 .38364 m .55856 .38768 L .56723 .38356 L F
.56593 .38549 m .56656 .38471 L .56596 .38576 L 0 0 .296 r
F
.56656 .38471 m .56799 .39313 L p .56596 .38576 L F P
0 g
s
.55856 .38768 m .56656 .38471 L p .56596 .38576 L .45 .882 .829 r
F P
0 g
s
.56548 .38658 m .56548 .38658 L .56596 .38576 L .45 .882 .829 r
F
.56548 .38658 m .55856 .38768 L .56596 .38576 L F
.56428 .38867 m .56577 .38714 L .56428 .38867 L .508 .912 .863 r
F
.565 .38741 m .56577 .38714 L p .56482 .38774 L F P
0 g
s
.56427 .38867 m .55408 .39442 L p .56577 .38714 L .508 .912 .863 r
F P
0 g
s
.568 .40316 m .565 .38741 L p .56501 .38741 L 0 0 .296 r
F P
0 g
s
.56588 .38652 m .56563 .38656 L .56591 .38642 L .45 .882 .829 r
F
.56596 .38576 m .568 .40316 L .56501 .38741 L 0 0 .296 r
F
.56748 .38312 m .5682 .38761 L p .5669 .38412 L 0 0 .241 r
F P
0 g
s
.56324 .38474 m .56748 .38312 L p .56723 .38356 L .388 .844 .782 r
F P
0 g
s
.56847 .38214 m .58604 .37529 L p .56822 .38238 L .322 .799 .725 r
F P
0 g
s
.56428 .38867 m .56428 .38867 L .56428 .38867 L .508 .912 .863 r
F
.56428 .38867 m .56428 .38867 L .56428 .38867 L F
.56452 .38854 m .56428 .38867 L p .5646 .38834 L F P
0 g
s
.56475 .38785 m .56816 .41724 L .56428 .38867 L 0 0 .34 r
F
.56428 .38867 m .56427 .38867 L p .56428 .38867 L .508 .912 .863 r
F P
0 g
s
.565 .38741 m .568 .40316 L p .56479 .38777 L 0 0 .34 r
F P
0 g
s
.568 .40316 m .56816 .41724 L p .56475 .38785 L 0 0 .34 r
F P
0 g
s
.56479 .38777 m .568 .40316 L .56475 .38785 L 0 0 .34 r
F
.54987 .39269 m .565 .38741 L p .55408 .39442 L .508 .912 .863 r
F P
0 g
s
.55408 .39442 m .565 .38741 L .56482 .38774 L .508 .912 .863 r
F
.56122 .39396 m .55408 .39442 L .56427 .38867 L p .59 .908 .981 r
F P
0 g
s
.56122 .39396 m .56427 .38867 L .56123 .39395 L .59 .908 .981 r
F
.56439 .40037 m .56122 .39396 L p .56231 .39208 L 0 .073 .606 r
F P
0 g
s
.56816 .41724 m .56439 .40037 L .56428 .38867 L p 0 0 .34 r
F P
0 g
s
.56122 .39396 m .56122 .39396 L p .56123 .39395 L .59 .908 .981 r
F P
0 g
s
.56492 .44584 m .55464 .43463 L .55436 .40584 L p .111 .154 .627 r
F P
0 g
s
.55464 .43463 m .54232 .4267 L p .54747 .41778 L .341 .35 .724 r
F P
0 g
s
.49993 .45296 m .49962 .40766 L p .5284 .45081 L .502 .453 .735 r
F P
0 g
s
.52929 .42 m .54232 .4267 L p .51736 .4501 L .743 .823 .914 r
F P
0 g
s
.53442 .44038 m .51736 .4501 L p .54232 .4267 L .743 .823 .914 r
F P
0 g
s
.55464 .43463 m .55485 .46666 L p .53915 .43219 L .372 .345 .7 r
F P
0 g
s
.53998 .43075 m .55464 .43463 L .53915 .43219 L .372 .345 .7 r
F
.52429 .45792 m .5284 .45081 L .53145 .44812 L .726 .741 .864 r
F
.52429 .45792 m .53145 .44812 L .52985 .45229 L F
.53442 .44038 m .53442 .44038 L p .5284 .45081 L F P
0 g
s
.52666 .4606 m .52429 .45792 L p .52985 .45229 L .726 .741 .864 r
F P
0 g
s
.53442 .44038 m .53454 .46001 L p .5284 .45081 L .502 .453 .735 r
F P
0 g
s
.55485 .46666 m .53454 .46001 L .53442 .44038 L p .372 .345 .7 r
F P
0 g
s
.52429 .45792 m .49993 .45296 L p .5284 .45081 L .502 .453 .735 r
F P
0 g
s
.52429 .45792 m .51736 .4501 L .53442 .44038 L p .726 .741 .864 r
F P
0 g
s
.53454 .46001 m .52429 .45792 L p .5284 .45081 L .502 .453 .735 r
F P
0 g
s
.53454 .46001 m .53462 .5 L p .5152 .47367 L .512 .432 .703 r
F P
0 g
s
.49993 .45296 m .52429 .45792 L p .5152 .47367 L .512 .432 .703 r
F P
0 g
s
.52429 .45792 m .53454 .46001 L p .5152 .47367 L .512 .432 .703 r
F P
0 g
s
.52429 .45792 m .52429 .45792 L p .5152 .47367 L .757 .748 .844 r
F P
0 g
s
.51736 .4501 m .52429 .45792 L p .49998 .49997 L .757 .748 .844 r
F P
0 g
s
.50004 .49994 m .49998 .49997 L p .52429 .45792 L .757 .748 .844 r
F P
0 g
s
.5152 .47367 m .53462 .5 L .50004 .49994 L .512 .432 .703 r
F
.50004 .49994 m .50004 .5 L p .50001 .49998 L .597 .502 .717 r
F P
0 g
s
.50001 .49997 m .50001 .49998 L .50001 .49998 L .597 .502 .717 r
F
.50001 .49998 m .49998 .49997 L .50004 .49994 L p .736 .68 .797 r
F P
0 g
s
.48557 .48536 m .49995 .49991 L .49155 .49992 L .597 .502 .717 r
F
.48557 .48536 m .49155 .49992 L .44757 .5 L F
.49995 .49991 m .49998 .49997 L .44757 .5 L F
.44757 .5 m .5 .5 L p .49995 .50009 L .597 .473 .682 r
F P
0 g
s
.44757 .5 m .49995 .50009 L .48209 .53102 L .597 .473 .682 r
F
.46223 .5515 m .47086 .55048 L p .45845 .56152 L .591 .439 .644 r
F P
0 g
s
.47644 .56347 m .47086 .55048 L p .47086 .55047 L .766 .691 .78 r
F P
0 g
s
.47644 .56347 m .47086 .55047 L .49089 .52454 L .766 .691 .78 r
F
.4474 .55325 m .44757 .5 L p .47972 .52888 L .597 .473 .682 r
F P
0 g
s
.47972 .52888 m .48209 .53102 L .47769 .53384 L .597 .473 .682 r
F
.47972 .52888 m .47769 .53384 L .4474 .55325 L F
.47086 .55048 m .4474 .55325 L p .48209 .53102 L F P
0 g
s
.48018 .57218 m .45612 .58638 L p .47086 .55048 L .797 .704 .762 r
F P
0 g
s
.47086 .55048 m .47086 .55048 L p .47086 .55048 L .797 .704 .762 r
F P
0 g
s
.47086 .55048 m .48018 .57218 L p .47086 .55048 L .797 .704 .762 r
F P
0 g
s
.45845 .56152 m .46266 .56467 L .44703 .59174 L .591 .439 .644 r
F
.45612 .58638 m .44703 .59174 L p .47086 .55048 L .797 .704 .762 r
F P
0 g
s
.47086 .55048 m .47086 .55048 L p .48209 .53102 L .766 .691 .78 r
F P
0 g
s
.47086 .55048 m .49981 .50034 L .49989 .50029 L .766 .691 .78 r
F
.48018 .57218 m .47644 .56347 L p .49989 .50029 L F P
0 g
s
.47086 .55048 m .49993 .54704 L p .466 .55888 L .591 .439 .644 r
F P
0 g
s
.47086 .55048 m .466 .55888 L .46376 .55967 L .591 .439 .644 r
F
.49993 .54704 m .49962 .59234 L p .46091 .56336 L F P
0 g
s
.46376 .55967 m .49993 .54704 L .46091 .56336 L .591 .439 .644 r
F
.44703 .59174 m .4474 .55325 L p .45845 .56152 L F P
0 g
s
.44025 .60003 m .44703 .59174 L .44168 .60101 L .658 .494 .65 r
F
.3772 .55672 m .44703 .59174 L .44025 .60003 L F
.37642 .61146 m .3772 .55672 L p .44078 .60039 L F P
0 g
s
.44078 .60039 m .44168 .60101 L .44052 .6012 L .658 .494 .65 r
F
.44078 .60039 m .44052 .6012 L .37642 .61146 L F
.46522 .75803 m .42189 .68925 L .46527 .66275 L p .775 .587 .645 r
F P
0 g
s
.42189 .68925 m .46522 .75803 L .4282 .78218 L p .808 .593 .611 r
F P
0 g
s
.4282 .78218 m .38376 .71318 L .42189 .68925 L p .808 .593 .611 r
F P
0 g
s
.37308 .7152 m .3735 .70726 L p .37859 .70882 L .606 .326 .466 r
F P
0 g
s
.3735 .70726 m .37383 .69828 L p .38592 .69759 L .635 .402 .548 r
F P
0 g
s
.38592 .69759 m .38114 .70587 L .38332 .69962 L .635 .402 .548 r
F
.37383 .69828 m .37516 .66227 L p .39652 .67201 L F P
0 g
s
.42189 .68925 m .38376 .71318 L p .38528 .70108 L .841 .668 .667 r
F P
0 g
s
.38528 .70108 m .38566 .69804 L .38849 .69736 L .841 .668 .667 r
F
.38528 .70108 m .38849 .69736 L .42189 .68925 L F
.4091 .65745 m .42189 .68925 L p .38566 .69804 L F P
0 g
s
.38566 .69804 m .39982 .67352 L .38566 .69804 L .841 .668 .667 r
F
.39982 .67352 m .4091 .65745 L .38566 .69804 L F
.46527 .66275 m .42189 .68925 L p .43067 .63248 L .805 .654 .695 r
F P
0 g
s
.43917 .60535 m .37642 .61146 L p .44168 .60101 L .658 .494 .65 r
F P
0 g
s
.37516 .66227 m .37642 .61146 L p .42071 .63733 L .65 .454 .606 r
F P
0 g
s
.42189 .68925 m .4091 .65745 L p .43329 .61556 L .805 .654 .695 r
F P
0 g
s
.43067 .63248 m .43091 .63089 L .43154 .63147 L .805 .654 .695 r
F
.43067 .63248 m .43154 .63147 L .46527 .66275 L F
.43091 .63089 m .43329 .61555 L .43917 .60535 L F
.43917 .60535 m .46527 .66275 L p .43091 .63089 L F P
0 g
s
.37642 .61146 m .43917 .60535 L p .42071 .63733 L .65 .454 .606 r
F P
0 g
s
.43596 .59828 m .43917 .60535 L p .43329 .61555 L .805 .654 .695 r
F P
0 g
s
.44691 .6046 m .44614 .65218 L p .42071 .63733 L .65 .454 .606 r
F P
0 g
s
.42071 .63733 m .42072 .63733 L .42071 .63733 L .65 .454 .606 r
F
.42072 .63733 m .44691 .6046 L .42071 .63733 L F
.43329 .61556 m .43328 .61556 L .43329 .61555 L .805 .654 .695 r
F
.4091 .65745 m .37516 .66227 L p .41501 .64045 L .65 .454 .606 r
F P
0 g
s
.42071 .63733 m .4091 .65745 L .41501 .64045 L .65 .454 .606 r
F
.37516 .66227 m .4091 .65745 L p .39982 .67352 L .635 .402 .548 r
F P
0 g
s
.39652 .67201 m .39982 .67352 L .37383 .69828 L .635 .402 .548 r
F
.39982 .67352 m .44517 .6942 L .38592 .69759 L F
.39982 .67352 m .38592 .69759 L .37383 .69828 L F
.39513 .62273 m .4091 .65745 L p .38566 .69804 L .841 .668 .667 r
F P
0 g
s
.4091 .65745 m .4091 .65745 L p .40909 .65745 L .841 .668 .667 r
F P
0 g
s
.38566 .69804 m .4091 .65745 L .40909 .65745 L .841 .668 .667 r
F
.4091 .65745 m .39513 .62273 L p .43329 .61556 L .805 .654 .695 r
F P
0 g
s
.44066 .60862 m .44066 .60862 L p .44066 .60861 L .773 .641 .716 r
F P
0 g
s
.44066 .60862 m .43917 .60535 L p .44309 .60219 L .773 .641 .716 r
F P
0 g
s
.43917 .60535 m .44691 .6046 L p .42071 .63733 L .65 .454 .606 r
F P
0 g
s
.39513 .62273 m .43596 .59828 L p .43329 .61555 L .805 .654 .695 r
F P
0 g
s
.43328 .61556 m .39513 .62273 L .43329 .61555 L .805 .654 .695 r
F
.44614 .65218 m .4091 .65745 L p .42071 .63733 L .65 .454 .606 r
F P
0 g
s
.44614 .65218 m .44517 .6942 L p .39982 .67352 L .635 .402 .548 r
F P
0 g
s
.4091 .65745 m .44614 .65218 L p .39982 .67352 L .635 .402 .548 r
F P
0 g
s
.29571 .6093 m .37642 .61146 L .37516 .66227 L p .713 .507 .609 r
F P
0 g
s
.37516 .66227 m .29393 .65914 L .29571 .6093 L p .713 .507 .609 r
F P
0 g
s
.29393 .65914 m .37516 .66227 L .3735 .70726 L p .706 .462 .553 r
F P
0 g
s
.35923 .64458 m .39513 .62273 L p .38566 .69804 L .841 .668 .667 r
F P
0 g
s
.38376 .71318 m .38114 .70587 L p .38528 .70108 L .841 .668 .667 r
F P
0 g
s
.38114 .70587 m .38376 .71318 L .37281 .7203 L p .885 .685 .627 r
F P
0 g
s
.37281 .7203 m .37281 .7203 L p .37931 .70904 L .885 .685 .627 r
F P
0 g
s
.37931 .70904 m .38114 .70587 L .37281 .7203 L .885 .685 .627 r
F
.44517 .6942 m .44408 .72895 L p .37931 .70904 L .606 .326 .466 r
F P
0 g
s
.37859 .70882 m .37956 .70861 L .37931 .70904 L .606 .326 .466 r
F
.37956 .70861 m .44517 .6942 L .37931 .70904 L F
.3735 .70726 m .38114 .70587 L p .37859 .70882 L F P
0 g
s
.38114 .70587 m .37956 .70861 L .37859 .70882 L .606 .326 .466 r
F
.37281 .7203 m .37308 .7152 L p .37548 .71567 L F P
0 g
s
.38376 .71318 m .4282 .78218 L .39794 .80302 L p .845 .595 .561 r
F P
0 g
s
.39794 .80302 m .36193 .7481 L p .3691 .73664 L .845 .595 .561 r
F P
0 g
s
.38556 .72457 m .3691 .73664 L .38376 .71318 L .845 .595 .561 r
F
.39794 .80302 m .3691 .73664 L .38556 .72457 L F
.2886 .7399 m .35918 .74391 L p .33756 .75975 L .663 .298 .343 r
F P
0 g
s
.35918 .74391 m .39794 .80302 L p .35649 .74857 L .888 .588 .473 r
F P
0 g
s
.2886 .7399 m .29153 .70327 L p .3617 .73954 L .693 .4 .473 r
F P
0 g
s
.36193 .7481 m .35918 .74391 L p .3617 .73954 L .845 .595 .561 r
F P
0 g
s
.36193 .7481 m .3617 .73954 L .37281 .72031 L .845 .595 .561 r
F
.35918 .74391 m .2886 .7399 L p .3617 .73954 L .693 .4 .473 r
F P
0 g
s
.29153 .70327 m .37281 .7203 L .3617 .73954 L .693 .4 .473 r
F
.35918 .74391 m .3524 .73357 L .37281 .7203 L p .845 .595 .561 r
F P
0 g
s
.37281 .7203 m .38376 .71318 L p .36193 .7481 L .845 .595 .561 r
F P
0 g
s
.37152 .74461 m .35918 .74391 L p .3617 .73954 L .693 .4 .473 r
F P
0 g
s
.37281 .72031 m .3617 .73954 L .37281 .7203 L .845 .595 .561 r
F
.29153 .70327 m .3735 .70726 L .37281 .7203 L p .693 .4 .473 r
F P
0 g
s
.37281 .7203 m .37152 .74461 L p .3617 .73954 L .693 .4 .473 r
F P
0 g
s
.35918 .74391 m .35918 .74391 L p .33756 .75975 L .663 .298 .343 r
F P
0 g
s
.35649 .74858 m .35649 .74858 L .35649 .74857 L .888 .588 .473 r
F
.34353 .77101 m .34353 .77101 L .34353 .77101 L F
.37583 .81965 m .34353 .77101 L p .34353 .77101 L F P
0 g
s
.28162 .78415 m .28526 .76736 L p .32898 .77937 L .573 .099 .09 r
F P
0 g
s
.37583 .81965 m .34353 .77101 L .36002 .76154 L .888 .588 .473 r
F
.37583 .81965 m .36311 .8312 L p .34417 .78553 L .919 .544 .29 r
F P
0 g
s
.34417 .78553 m .34733 .78488 L .37583 .81965 L .919 .544 .29 r
F
.34353 .77101 m .37583 .81965 L p .3404 .77643 L F P
0 g
s
.34417 .78553 m .33821 .78023 L .3404 .77643 L .919 .544 .29 r
F
.32898 .77937 m .33974 .77757 L .33737 .78168 L .573 .099 .09 r
F
.32898 .77937 m .33141 .78004 L .31662 .78648 L F
.33141 .78004 m .33737 .78168 L .33235 .78284 L F
.33141 .78004 m .33235 .78284 L .31662 .78648 L F
.36311 .8312 m .36074 .83693 L p .33684 .79633 L .785 .337 0 r
F P
0 g
s
.32402 .78966 m .33394 .78762 L .32403 .78966 L .274 0 0 r
F
.33684 .79633 m .33284 .78953 L .33394 .78762 L .785 .337 0 r
F
.28162 .78415 m .33394 .78762 L p .32402 .78966 L .274 0 0 r
F P
0 g
s
.33394 .78762 m .33394 .78762 L p .32402 .78966 L .274 0 0 r
F P
0 g
s
.36074 .83693 m .33103 .79266 L p .33284 .78953 L .785 .337 0 r
F P
0 g
s
.33394 .78762 m .36311 .8312 L p .33684 .79633 L .785 .337 0 r
F P
0 g
s
.36311 .8312 m .33394 .78762 L p .34417 .78553 L .919 .544 .29 r
F P
0 g
s
.33394 .78762 m .36698 .78982 L p .32403 .78966 L .274 0 0 r
F P
0 g
s
.33394 .78762 m .31662 .78648 L p .33737 .78168 L .573 .099 .09 r
F P
0 g
s
.31662 .78648 m .28162 .78415 L p .32898 .77937 L .573 .099 .09 r
F P
0 g
s
.28526 .76736 m .34353 .77101 L p .32898 .77937 L .573 .099 .09 r
F P
0 g
s
.28526 .76736 m .2886 .7399 L p .34351 .76217 L .663 .298 .343 r
F P
0 g
s
.34351 .76217 m .34767 .76385 L .34352 .76409 L .663 .298 .343 r
F
.34351 .76217 m .34352 .76409 L .28526 .76736 L F
.3404 .77643 m .3404 .77643 L .34353 .77101 L .919 .544 .29 r
F
.34417 .78553 m .3404 .77643 L .34733 .78488 L F
.34353 .77101 m .34767 .76385 L .35649 .74858 L .888 .588 .473 r
F
.39794 .80302 m .37583 .81965 L p .36002 .76154 L F P
0 g
s
.36002 .76154 m .35649 .74858 L .36443 .75901 L .888 .588 .473 r
F
.36002 .76154 m .36443 .75901 L .39794 .80302 L F
.34353 .77101 m .36931 .77263 L .33974 .77757 L .573 .099 .09 r
F
.34353 .77101 m .34353 .77101 L p .34353 .77101 L F P
0 g
s
.34353 .77101 m .36931 .77263 L p .34353 .77101 L .573 .099 .09 r
F P
0 g
s
.34353 .77101 m .33974 .77757 L .32898 .77937 L .573 .099 .09 r
F
.36002 .76154 m .34353 .77101 L .35649 .74858 L .888 .588 .473 r
F
.34353 .77101 m .34353 .77101 L p .34767 .76385 L F P
0 g
s
.34353 .77101 m .28526 .76736 L p .34767 .76385 L .663 .298 .343 r
F P
0 g
s
.32924 .7495 m .34353 .77101 L p .3404 .77643 L .919 .544 .29 r
F P
0 g
s
.31227 .76469 m .31552 .76011 L p .33284 .78953 L .785 .337 0 r
F P
0 g
s
.36698 .78982 m .36464 .79493 L p .32403 .78966 L .274 0 0 r
F P
0 g
s
.36464 .79493 m .27784 .78907 L .28162 .78415 L p .274 0 0 r
F P
0 g
s
.33103 .79266 m .31227 .76469 L p .33284 .78953 L .785 .337 0 r
F P
0 g
s
.31552 .76011 m .33394 .78762 L p .33284 .78953 L .785 .337 0 r
F P
0 g
s
.33394 .78762 m .31552 .76011 L p .33821 .78023 L .919 .544 .29 r
F P
0 g
s
.33394 .78762 m .33821 .78023 L .34417 .78553 L .919 .544 .29 r
F
.36931 .77263 m .36698 .78982 L p .33737 .78168 L .573 .099 .09 r
F P
0 g
s
.33974 .77757 m .36931 .77263 L .33737 .78168 L .573 .099 .09 r
F
.31552 .76011 m .32924 .7495 L p .3404 .77643 L .919 .544 .29 r
F P
0 g
s
.33821 .78023 m .31552 .76011 L .3404 .77643 L .919 .544 .29 r
F
.36698 .78982 m .33394 .78762 L p .33737 .78168 L .573 .099 .09 r
F P
0 g
s
.34767 .76385 m .35436 .75226 L .34767 .76385 L .663 .298 .343 r
F
.33756 .75975 m .35436 .75226 L .34767 .76385 L F
.35918 .74391 m .35436 .75226 L .33756 .75975 L F
.34353 .77101 m .32924 .7495 L p .35649 .74858 L .888 .588 .473 r
F P
0 g
s
.35436 .75226 m .35436 .75226 L .34767 .76385 L .663 .298 .343 r
F
.35649 .74858 m .35649 .74857 L .35649 .74858 L .888 .588 .473 r
F
.35649 .74858 m .35649 .74858 L .39794 .80302 L F
.35918 .74391 m .37152 .74461 L p .35436 .75226 L .663 .298 .343 r
F P
0 g
s
.32924 .7495 m .3524 .73357 L p .35649 .74857 L .888 .588 .473 r
F P
0 g
s
.35649 .74858 m .32924 .7495 L .35649 .74857 L .888 .588 .473 r
F
.36931 .77263 m .34353 .77101 L p .34767 .76385 L .663 .298 .343 r
F P
0 g
s
.3524 .73357 m .35918 .74391 L p .35649 .74857 L .888 .588 .473 r
F P
0 g
s
.37152 .74461 m .36931 .77263 L p .34767 .76385 L .663 .298 .343 r
F P
0 g
s
.35436 .75226 m .37152 .74461 L .34767 .76385 L .663 .298 .343 r
F
.37859 .70882 m .44408 .72895 L .37468 .71551 L .606 .326 .466 r
F
.37623 .71156 m .37468 .71551 L .37308 .7152 L F
.37859 .70882 m .37468 .71551 L .37623 .71156 L F
.37281 .7203 m .3524 .73357 L p .38114 .70587 L .885 .685 .627 r
F P
0 g
s
.38114 .70587 m .38114 .70587 L .37931 .70904 L .885 .685 .627 r
F
.38114 .70587 m .37931 .70904 L .37281 .7203 L F
.38114 .70587 m .44517 .6942 L p .37956 .70861 L .606 .326 .466 r
F P
0 g
s
.38528 .70108 m .38114 .70587 L .38566 .69804 L .841 .668 .667 r
F
.38592 .69759 m .38566 .69804 L .38114 .70587 L .635 .402 .548 r
F
.38114 .70587 m .3735 .70726 L p .38332 .69962 L F P
0 g
s
.38114 .70587 m .35923 .64458 L p .38566 .69804 L .841 .668 .667 r
F P
0 g
s
.38114 .70587 m .38114 .70587 L p .38566 .69804 L .635 .402 .548 r
F P
0 g
s
.3735 .70726 m .29153 .70327 L .29393 .65914 L p .706 .462 .553 r
F P
0 g
s
.35923 .64458 m .38114 .70587 L p .3524 .73357 L .885 .685 .627 r
F P
0 g
s
.44408 .72895 m .37152 .74461 L .37281 .7203 L p .606 .326 .466 r
F P
0 g
s
.37548 .71567 m .44408 .72895 L .37281 .7203 L .606 .326 .466 r
F
.44517 .6942 m .38114 .70587 L p .38592 .69759 L .635 .402 .548 r
F P
0 g
s
.43596 .59828 m .47086 .55048 L .44704 .59174 L .797 .704 .762 r
F
.44703 .59174 m .44703 .59174 L p .44704 .59174 L F P
0 g
s
.44703 .59174 m .43596 .59828 L p .44704 .59174 L .797 .704 .762 r
F P
0 g
s
.43917 .60535 m .43596 .59828 L .44703 .59174 L p .773 .641 .716 r
F P
0 g
s
.46266 .56467 m .49962 .59234 L .44703 .59174 L .591 .439 .644 r
F
.47086 .55048 m .46376 .55967 L .45845 .56152 L F
.45845 .56152 m .46376 .55967 L .46091 .56336 L F
.4474 .55325 m .46223 .5515 L p .45845 .56152 L F P
0 g
s
.4593 .52358 m .47086 .55048 L p .43596 .59828 L .797 .704 .762 r
F P
0 g
s
.48209 .53102 m .4593 .52358 L .49981 .50034 L .766 .691 .78 r
F
.47086 .55048 m .4593 .52358 L p .48209 .53102 L F P
0 g
s
.49089 .52454 m .47086 .55047 L .49989 .50029 L .766 .691 .78 r
F
.49993 .54704 m .47086 .55048 L p .48209 .53102 L .597 .473 .682 r
F P
0 g
s
.49989 .50029 m .49981 .50034 L .49991 .50016 L .766 .691 .78 r
F
.50011 .5 m .50001 .50002 L .5 .5 L .736 .521 .602 r
F
.49998 .50003 m .5 .5 L p .50001 .50002 L F P
0 g
s
.49995 .50009 m .50001 .50002 L p .48209 .53102 L .597 .473 .682 r
F P
0 g
s
.50001 .50002 m .50004 .5 L p .50002 .50003 L .597 .473 .682 r
F P
0 g
s
.50001 .50002 m .50002 .50003 L .48209 .53102 L .597 .473 .682 r
F
.48209 .53102 m .49995 .50009 L .48209 .53102 L F
.4593 .52358 m .49993 .5 L p .49991 .50016 L .766 .691 .78 r
F P
0 g
s
.49981 .50034 m .4593 .52358 L .49991 .50016 L .766 .691 .78 r
F
.48512 .46799 m .48209 .46898 L .48185 .46376 L .766 .56 .619 r
F
.47086 .44952 m .48018 .42782 L p .48209 .46898 L F P
0 g
s
.47086 .44952 m .49993 .45296 L p .48817 .4795 L .597 .502 .717 r
F P
0 g
s
.49998 .49997 m .49999 .49998 L .44757 .5 L .597 .502 .717 r
F
.5 .5 m .44757 .5 L p .49999 .49998 L F P
0 g
s
.50001 .49998 m .5 .5 L .49999 .49998 L .597 .502 .717 r
F
.48209 .46898 m .49996 .49999 L .4593 .47642 L .766 .56 .619 r
F
.49996 .49999 m .49995 .5 L .4593 .47642 L F
.4822 .46917 m .49996 .5 L .48209 .46898 L F
.49995 .50009 m .49997 .5 L .5 .5 L .766 .691 .78 r
F
.5 .5 m .49998 .50003 L p .49996 .5 L .766 .56 .619 r
F P
0 g
s
.5 .5 m .49996 .5 L .4822 .46917 L .766 .56 .619 r
F
.49998 .49997 m .5 .5 L p .49997 .5 L .766 .691 .78 r
F P
0 g
s
.49995 .49991 m .4822 .46917 L .48209 .46898 L .766 .56 .619 r
F
.5 .5 m .4822 .46917 L .49995 .49991 L F
.49993 .5 m .4593 .47642 L p .49996 .5 L F P
0 g
s
.49996 .5 m .49993 .5 L .49996 .5 L .766 .56 .619 r
F
.49993 .5 m .49993 .5 L .49996 .5 L F
.46723 .50543 m .46046 .5 L .4696 .5 L .787 .758 .827 r
F
.4593 .52358 m .45397 .50763 L p .46723 .50543 L F P
0 g
s
.49993 .5 m .4593 .52358 L p .46723 .50543 L .787 .758 .827 r
F P
0 g
s
.45141 .5 m .4593 .47642 L .49993 .5 L p .787 .527 .544 r
F P
0 g
s
.46723 .50543 m .4696 .5 L .49993 .5 L .787 .758 .827 r
F
.49993 .5 m .49993 .5 L p .4696 .5 L .787 .527 .544 r
F P
0 g
s
.4696 .5 m .45141 .5 L .49993 .5 L .787 .527 .544 r
F
.4696 .5 m .48269 .47002 L .49993 .5 L .787 .758 .827 r
F
.45397 .50763 m .45141 .5 L p .46723 .50543 L F P
0 g
s
.41491 .50951 m .38437 .52752 L p .39975 .50707 L .86 .876 .848 r
F P
0 g
s
.4593 .47642 m .45441 .49103 L p .41491 .49049 L .817 .562 .553 r
F P
0 g
s
.45441 .49103 m .44151 .49481 L .41491 .49049 L .817 .562 .553 r
F
.45255 .49661 m .44376 .498 L .41491 .49049 L F
.42549 .49668 m .41491 .49049 L p .44376 .49801 L F P
0 g
s
.45141 .5 m .44022 .49857 L .44376 .49801 L .817 .562 .553 r
F
.44022 .49857 m .42549 .49668 L .44376 .49801 L F
.41491 .49049 m .42022 .4535 L .4593 .47642 L p F P
0 g
s
.42049 .50169 m .42003 .5 L .4217 .5 L .831 .853 .863 r
F
.41491 .50951 m .41524 .50252 L p .42049 .50169 L F P
0 g
s
.41537 .5 m .41491 .49049 L .42872 .49857 L p .831 .504 .435 r
F P
0 g
s
.41491 .50951 m .42049 .50169 L .42479 .50101 L .831 .853 .863 r
F
.43116 .5 m .42872 .50143 L p .42479 .50101 L F P
0 g
s
.42872 .50143 m .41491 .50951 L p .42479 .50101 L .831 .853 .863 r
F P
0 g
s
.39975 .50707 m .40416 .5012 L .41524 .50252 L .86 .876 .848 r
F
.41524 .50252 m .41491 .50951 L p .39975 .50707 L F P
0 g
s
.42022 .5465 m .41491 .50951 L .43116 .5 L p .817 .773 .811 r
F P
0 g
s
.45441 .49103 m .45255 .49661 L p .44151 .49481 L .817 .562 .553 r
F P
0 g
s
.45255 .49661 m .45141 .5 L p .44376 .498 L .817 .562 .553 r
F P
0 g
s
.4593 .52358 m .42022 .5465 L p .4432 .5 L .817 .773 .811 r
F P
0 g
s
.45141 .5 m .45141 .5 L .42549 .49668 L .817 .562 .553 r
F
.43116 .5 m .42549 .49668 L p .45141 .5 L F P
0 g
s
.4481 .49009 m .45141 .5 L p .4432 .5 L .817 .773 .811 r
F P
0 g
s
.45141 .5 m .4593 .52358 L p .4432 .5 L .817 .773 .811 r
F P
0 g
s
.45141 .5 m .45141 .5 L p .45141 .5 L .817 .562 .553 r
F P
0 g
s
.44233 .50177 m .43116 .5 L .4432 .5 L .817 .773 .811 r
F
.42022 .5465 m .43116 .5 L .44233 .50177 L F
.45141 .5 m .4481 .50991 L .43116 .5 L p .817 .562 .553 r
F P
0 g
s
.43116 .5 m .4481 .49009 L p .4432 .5 L .817 .773 .811 r
F P
0 g
s
.42049 .50169 m .4217 .5 L .43116 .5 L .831 .853 .863 r
F
.43116 .5 m .41537 .5 L .42479 .49899 L .831 .504 .435 r
F
.4217 .5 m .41537 .5 L .43116 .5 L F
.42872 .49857 m .43116 .5 L p .42479 .49899 L F P
0 g
s
.43116 .5 m .43116 .5 L p .42479 .49899 L .831 .504 .435 r
F P
0 g
s
.4217 .5 m .4437 .46917 L .43116 .5 L .831 .853 .863 r
F
.43116 .5 m .4217 .5 L .43116 .5 L .831 .504 .435 r
F
.41491 .50951 m .42022 .5465 L .38419 .56783 L p .85 .793 .795 r
F P
0 g
s
.38419 .56783 m .38437 .52752 L .41491 .50951 L p .85 .793 .795 r
F P
0 g
s
.38437 .52752 m .39072 .50033 L .39122 .50003 L p .86 .876 .848 r
F P
0 g
s
.38437 .52752 m .39122 .50003 L .39126 .50004 L .86 .876 .848 r
F
.40344 .50216 m .39127 .5 L .40506 .5 L F
.38437 .52752 m .39127 .5 L .40344 .50216 L F
.39072 .49967 m .38437 .47248 L .41491 .49049 L p .86 .529 .424 r
F P
0 g
s
.38437 .47248 m .39033 .49802 L p .36862 .4866 L .89 .548 .394 r
F P
0 g
s
.39033 .49802 m .39072 .49967 L .38879 .49853 L p .89 .548 .394 r
F P
0 g
s
.38879 .49853 m .36862 .4866 L p .39033 .49802 L .89 .548 .394 r
F P
0 g
s
.36862 .5134 m .35067 .52397 L p .37068 .50457 L .845 .996 .833 r
F P
0 g
s
.36683 .50273 m .35621 .50885 L p .36545 .50196 L .619 .94 .732 r
F P
0 g
s
.36862 .4866 m .37624 .49803 L p .36683 .49727 L .845 .384 .085 r
F P
0 g
s
.37624 .49803 m .3751 .49844 L .36683 .49727 L .845 .384 .085 r
F
.37667 .49866 m .37449 .49922 L .36683 .49727 L F
.37756 .5 m .37755 .5 L .3745 .49922 L F
.3745 .49922 m .3745 .49922 L .36683 .49727 L F
.37756 .5 m .3745 .49922 L .3745 .49922 L F
.37068 .50457 m .37457 .5008 L .37561 .50293 L .845 .996 .833 r
F
.37457 .5008 m .37539 .5 L .37547 .50103 L F
.37457 .5008 m .37547 .50103 L .37561 .50293 L F
.37756 .5 m .37561 .50293 L p .37539 .5 L F P
0 g
s
.36545 .50196 m .36774 .50026 L .36938 .50053 L .619 .94 .732 r
F
.36938 .49947 m .36683 .49727 L .37121 .49986 L p .655 .107 0 r
F P
0 g
s
.371 .49989 m .36938 .49947 L .37121 .49986 L .655 .107 0 r
F
.36683 .50273 m .37 .50037 L .371 .50012 L .655 .963 .779 r
F
.37145 .5 m .37121 .50014 L p .371 .50012 L F P
0 g
s
.37121 .50014 m .36683 .50273 L p .371 .50012 L .655 .963 .779 r
F P
0 g
s
.34898 .48784 m .35015 .48794 L p .36403 .49973 L .51 0 0 r
F P
0 g
s
.35621 .50885 m .35015 .51206 L p .36589 .50023 L .57 .907 .677 r
F P
0 g
s
.36589 .50023 m .3659 .50024 L .35621 .50885 L .57 .907 .677 r
F
.36601 .50014 m .36688 .5 L .35621 .50885 L F
.36688 .5 m .36688 .5 L p .36688 .5 L F P
0 g
s
.36688 .5 m .35621 .50885 L p .36688 .5 L .57 .907 .677 r
F P
0 g
s
.35621 .49115 m .36683 .49727 L p .36879 .49969 L .618 .07 0 r
F P
0 g
s
.36879 .49969 m .36869 .49971 L .35621 .49115 L .618 .07 0 r
F
.36894 .49988 m .36904 .5 L .36638 .49959 L F
.36774 .50026 m .36808 .5 L .36999 .5 L .619 .94 .732 r
F
.36808 .5 m .36808 .5 L .36904 .5 L F
.36808 .5 m .36904 .5 L .36999 .5 L F
.36999 .5 m .36938 .50053 L p .36774 .50026 L F P
0 g
s
.36938 .50053 m .36999 .5 L p .37 .50037 L .655 .963 .779 r
F P
0 g
s
.36683 .50273 m .36938 .50053 L p .37 .50037 L .655 .963 .779 r
F P
0 g
s
.37561 .50293 m .36862 .5134 L p .37068 .50457 L .845 .996 .833 r
F P
0 g
s
.36862 .5134 m .37756 .5 L p .38186 .50056 L .847 .98 .868 r
F P
0 g
s
.36862 .5134 m .37877 .50356 L .38726 .50126 L .847 .98 .868 r
F
.3888 .50146 m .36862 .5134 L p .38726 .50126 L F P
0 g
s
.35766 .54332 m .36862 .5134 L .39072 .50033 L p .89 .905 .831 r
F P
0 g
s
.35067 .52397 m .36683 .50273 L .37145 .5 L p .845 .996 .833 r
F P
0 g
s
.37755 .5 m .37539 .5 L .36972 .49898 L .845 .384 .085 r
F
.37145 .5 m .36972 .49898 L p .37539 .5 L F P
0 g
s
.37624 .49803 m .37667 .49866 L p .3751 .49844 L .845 .384 .085 r
F P
0 g
s
.37667 .49866 m .37756 .5 L p .37449 .49922 L .845 .384 .085 r
F P
0 g
s
.36972 .49898 m .36683 .49727 L p .37756 .5 L .845 .384 .085 r
F P
0 g
s
.37877 .50356 m .38244 .5 L .39085 .50007 L .847 .98 .868 r
F
.38244 .5 m .3825 .5 L .39085 .50007 L F
.39089 .5 m .39085 .50007 L p .3825 .5 L F P
0 g
s
.38244 .5 m .39024 .5 L .3825 .5 L .847 .98 .868 r
F
.39024 .5 m .39089 .5 L .3825 .5 L F
.39085 .49993 m .39089 .5 L p .3905 .49982 L .847 .404 .162 r
F P
0 g
s
.39085 .50007 m .39072 .50033 L p .37877 .50356 L .847 .98 .868 r
F P
0 g
s
.39072 .50033 m .39085 .50007 L p .391 .50005 L .836 .961 .89 r
F P
0 g
s
.39127 .5 m .39072 .50033 L p .39105 .5 L .836 .961 .89 r
F P
0 g
s
.39089 .5 m .3997 .51675 L p .39059 .5 L .847 .404 .162 r
F P
0 g
s
.39089 .5 m .39059 .5 L .3905 .49982 L .847 .404 .162 r
F
.39072 .50033 m .3888 .50146 L p .38726 .50126 L .847 .98 .868 r
F P
0 g
s
.39072 .50033 m .38437 .52752 L .35766 .54332 L p .89 .905 .831 r
F P
0 g
s
.3997 .51675 m .38153 .50595 L p .39024 .5 L .847 .404 .162 r
F P
0 g
s
.3905 .49982 m .39059 .5 L .39024 .5 L .847 .404 .162 r
F
.39059 .5 m .3997 .51675 L .39024 .5 L F
.38244 .5 m .38244 .5 L .3825 .5 L .847 .98 .868 r
F
.36862 .4866 m .39072 .49967 L p .39024 .5 L .847 .404 .162 r
F P
0 g
s
.39024 .5 m .39023 .5 L .36862 .4866 L .847 .404 .162 r
F
.37756 .5 m .36862 .4866 L p .39023 .5 L F P
0 g
s
.39546 .49787 m .39626 .49851 L .39072 .49967 L .86 .529 .424 r
F
.39626 .49851 m .39316 .49941 L .39072 .49967 L F
.39687 .49901 m .39264 .49976 L .39072 .49967 L F
.39085 .49993 m .39072 .49967 L .39127 .5 L p .836 .404 .209 r
F P
0 g
s
.39127 .5 m .39127 .5 L p .39085 .49993 L .836 .404 .209 r
F P
0 g
s
.391 .50005 m .39103 .5 L .39105 .5 L .836 .961 .89 r
F
.39098 .5 m .39085 .49993 L .39127 .5 L .836 .404 .209 r
F
.39085 .50007 m .39089 .5 L p .391 .50005 L .836 .961 .89 r
F P
0 g
s
.39089 .5 m .39085 .49993 L p .39098 .5 L .836 .404 .209 r
F P
0 g
s
.39127 .5 m .39072 .49967 L p .39808 .5 L .86 .529 .424 r
F P
0 g
s
.39089 .5 m .3997 .48325 L p .39103 .5 L .836 .961 .89 r
F P
0 g
s
.39089 .5 m .39103 .5 L .391 .50005 L .836 .961 .89 r
F
.39089 .5 m .39089 .5 L p .39098 .5 L .836 .404 .209 r
F P
0 g
s
.39098 .5 m .39089 .5 L .39098 .5 L .836 .404 .209 r
F
.39122 .50003 m .39127 .5 L p .39126 .50004 L .86 .876 .848 r
F P
0 g
s
.39127 .5 m .41607 .51464 L p .39098 .5 L .836 .404 .209 r
F P
0 g
s
.42022 .4535 m .41491 .49049 L .38437 .47248 L p .85 .595 .552 r
F P
0 g
s
.3997 .48325 m .42064 .47085 L p .39105 .5 L .836 .961 .89 r
F P
0 g
s
.39103 .5 m .3997 .48325 L .39105 .5 L .836 .961 .89 r
F
.39072 .49967 m .39085 .49993 L p .3905 .49982 L .847 .404 .162 r
F P
0 g
s
.3997 .48325 m .39089 .5 L p .38244 .5 L .847 .98 .868 r
F P
0 g
s
.39024 .5 m .39023 .5 L .39023 .5 L .847 .404 .162 r
F
.38186 .50056 m .38183 .5 L .38244 .5 L .847 .98 .868 r
F
.37756 .5 m .38153 .49405 L p .38186 .50056 L F P
0 g
s
.38153 .50595 m .37756 .5 L p .39023 .5 L .847 .404 .162 r
F P
0 g
s
.38153 .49405 m .3997 .48325 L p .38244 .5 L .847 .98 .868 r
F P
0 g
s
.38183 .5 m .38153 .49405 L .38244 .5 L .847 .98 .868 r
F
.37145 .5 m .38153 .49405 L p .37539 .5 L .845 .996 .833 r
F P
0 g
s
.35067 .52397 m .37145 .5 L .37539 .5 L .845 .996 .833 r
F
.37145 .5 m .37145 .5 L p .37539 .5 L .845 .384 .085 r
F P
0 g
s
.38214 .51047 m .37345 .50545 L p .36904 .5 L .618 .07 0 r
F P
0 g
s
.36683 .49727 m .36999 .5 L p .36904 .5 L .618 .07 0 r
F P
0 g
s
.37 .50037 m .3705 .5 L .37145 .5 L .655 .963 .779 r
F
.36999 .5 m .37041 .5 L .37 .50037 L F
.37 .50037 m .37041 .5 L .3705 .5 L F
.36999 .5 m .38214 .51047 L p .36904 .5 L .618 .07 0 r
F P
0 g
s
.36938 .50053 m .36683 .50273 L p .36545 .50196 L .619 .94 .732 r
F P
0 g
s
.36688 .5 m .36638 .49959 L p .36904 .5 L .618 .07 0 r
F P
0 g
s
.36638 .49959 m .35621 .49115 L p .36894 .49988 L .618 .07 0 r
F P
0 g
s
.37345 .49455 m .38214 .48953 L p .36808 .5 L .619 .94 .732 r
F P
0 g
s
.35621 .50885 m .36688 .5 L p .36787 .50016 L .619 .94 .732 r
F P
0 g
s
.35015 .51206 m .36503 .5 L p .36503 .5 L .57 .907 .677 r
F P
0 g
s
.35015 .51206 m .36503 .5 L .36589 .50023 L .57 .907 .677 r
F
.35015 .51206 m .34898 .51216 L p .36483 .5 L .51 .864 .616 r
F P
0 g
s
.35015 .48794 m .36503 .5 L p .36403 .49973 L .51 0 0 r
F P
0 g
s
.35621 .49115 m .36688 .5 L p .36527 .49974 L .57 .023 0 r
F P
0 g
s
.36589 .50023 m .36503 .5 L .3662 .5 L .57 .907 .677 r
F
.36503 .5 m .36555 .5 L .3662 .5 L F
.36601 .50014 m .3662 .5 L .36688 .5 L F
.36688 .5 m .36688 .5 L .36527 .49974 L .57 .023 0 r
F
.36688 .5 m .36564 .5 L .36527 .49974 L F
.37345 .49455 m .36688 .5 L p .3662 .5 L .57 .907 .677 r
F P
0 g
s
.36688 .5 m .36688 .5 L p .36688 .5 L .57 .023 0 r
F P
0 g
s
.36589 .50023 m .36601 .50014 L .3659 .50024 L .57 .907 .677 r
F
.36688 .5 m .37345 .50545 L p .36564 .5 L .57 .023 0 r
F P
0 g
s
.36857 .49714 m .37345 .49455 L p .3662 .5 L .57 .907 .677 r
F P
0 g
s
.35015 .48794 m .35621 .49115 L p .36555 .5 L .57 .023 0 r
F P
0 g
s
.36503 .5 m .36503 .5 L p .36555 .5 L .57 .907 .677 r
F P
0 g
s
.36503 .5 m .35015 .48794 L p .36555 .5 L .57 .023 0 r
F P
0 g
s
.36857 .49714 m .36503 .5 L p .36483 .5 L .51 .864 .616 r
F P
0 g
s
.36503 .5 m .35015 .51206 L p .36483 .5 L .51 .864 .616 r
F P
0 g
s
.36403 .49973 m .36442 .5 L .36435 .5 L .51 0 0 r
F
.36774 .49712 m .36857 .49714 L p .36483 .5 L .51 .864 .616 r
F P
0 g
s
.34898 .51216 m .36415 .5 L p .36483 .5 L .51 .864 .616 r
F P
0 g
s
.36503 .5 m .36442 .5 L .36403 .49973 L .51 0 0 r
F
.36774 .50288 m .36369 .49964 L p .36403 .49973 L F P
0 g
s
.36415 .5 m .36774 .49712 L p .36483 .5 L .51 .864 .616 r
F P
0 g
s
.36503 .5 m .36857 .50286 L p .36442 .5 L .51 0 0 r
F P
0 g
s
.36857 .50286 m .36774 .50288 L p .36435 .5 L .51 0 0 r
F P
0 g
s
.36442 .5 m .36857 .50286 L .36435 .5 L .51 0 0 r
F
.37345 .50545 m .36857 .50286 L p .36555 .5 L .57 .023 0 r
F P
0 g
s
.36527 .49974 m .36564 .5 L .36555 .5 L .57 .023 0 r
F
.36564 .5 m .37345 .50545 L .36555 .5 L F
.36787 .50016 m .36688 .5 L .36808 .5 L .619 .94 .732 r
F
.36688 .5 m .37345 .49455 L p .36808 .5 L F P
0 g
s
.37345 .50545 m .36688 .5 L p .36808 .5 L .618 .07 0 r
F P
0 g
s
.36904 .5 m .36904 .5 L .36808 .5 L .618 .07 0 r
F
.36904 .5 m .37345 .50545 L .36808 .5 L F
.37144 .5 m .36938 .49947 L .37145 .5 L .655 .107 0 r
F
.36999 .5 m .36938 .49947 L p .37037 .5 L F P
0 g
s
.37145 .5 m .38153 .50595 L p .36938 .49947 L .655 .107 0 r
F P
0 g
s
.38214 .48953 m .36999 .5 L p .36999 .5 L .619 .94 .732 r
F P
0 g
s
.36879 .49969 m .36894 .49988 L .36869 .49971 L .618 .07 0 r
F
.36808 .5 m .38214 .48953 L .36999 .5 L .619 .94 .732 r
F
.36503 .5 m .36857 .49714 L p .3662 .5 L .57 .907 .677 r
F P
0 g
s
.36857 .50286 m .36503 .5 L p .36555 .5 L .57 .023 0 r
F P
0 g
s
.36369 .49964 m .34898 .48784 L p .36403 .49973 L .51 0 0 r
F P
0 g
s
.37145 .5 m .37144 .5 L .37145 .5 L .655 .107 0 r
F
.37144 .5 m .37145 .5 L .37145 .5 L F
.37121 .49986 m .37145 .5 L p .371 .49989 L F P
0 g
s
.3705 .5 m .39425 .48236 L .37145 .5 L .655 .963 .779 r
F
.37145 .5 m .37145 .5 L p .37145 .5 L .655 .107 0 r
F P
0 g
s
.36999 .5 m .38214 .48953 L p .37041 .5 L .655 .963 .779 r
F P
0 g
s
.38214 .48953 m .39425 .48236 L p .3705 .5 L .655 .963 .779 r
F P
0 g
s
.37041 .5 m .38214 .48953 L .3705 .5 L .655 .963 .779 r
F
.38214 .51047 m .36999 .5 L p .38153 .50595 L .655 .107 0 r
F P
0 g
s
.38153 .50595 m .36999 .5 L .37037 .5 L .655 .107 0 r
F
.37756 .5 m .38153 .50595 L .37145 .5 L p .845 .384 .085 r
F P
0 g
s
.37756 .5 m .37145 .5 L .37755 .5 L .845 .384 .085 r
F
.38153 .49405 m .37756 .5 L p .37539 .5 L .845 .996 .833 r
F P
0 g
s
.39425 .48236 m .38153 .49405 L .37145 .5 L p .655 .963 .779 r
F P
0 g
s
.37756 .5 m .37756 .5 L p .37755 .5 L .845 .384 .085 r
F P
0 g
s
.39626 .49851 m .39687 .49901 L .39316 .49941 L .86 .529 .424 r
F
.39687 .49901 m .39808 .5 L .39264 .49976 L F
.42064 .47085 m .41607 .48536 L .39127 .5 L p .836 .961 .89 r
F P
0 g
s
.39105 .5 m .42064 .47085 L .39127 .5 L .836 .961 .89 r
F
.3997 .51675 m .39089 .5 L p .41607 .51464 L .836 .404 .209 r
F P
0 g
s
.41607 .51464 m .39089 .5 L .39098 .5 L .836 .404 .209 r
F
.41491 .49049 m .41537 .5 L p .39546 .49787 L .86 .529 .424 r
F P
0 g
s
.41537 .5 m .41524 .50252 L p .40416 .5012 L .86 .876 .848 r
F P
0 g
s
.41537 .5 m .41537 .5 L p .41536 .5 L .86 .529 .424 r
F P
0 g
s
.41537 .5 m .41536 .5 L .39546 .49787 L .86 .529 .424 r
F
.40416 .5012 m .40506 .5 L .41537 .5 L .86 .876 .848 r
F
.41524 .50252 m .41537 .5 L p .42049 .50169 L .831 .853 .863 r
F P
0 g
s
.41537 .5 m .41607 .48536 L p .42017 .50052 L .831 .853 .863 r
F P
0 g
s
.41537 .5 m .42017 .50052 L .42049 .50169 L .831 .853 .863 r
F
.41537 .5 m .41607 .51464 L p .39546 .49787 L .86 .529 .424 r
F P
0 g
s
.41607 .48536 m .41537 .5 L p .40506 .5 L .86 .876 .848 r
F P
0 g
s
.39127 .5 m .41607 .48536 L p .40506 .5 L .86 .876 .848 r
F P
0 g
s
.41607 .51464 m .39127 .5 L p .39808 .5 L .86 .529 .424 r
F P
0 g
s
.41607 .51464 m .41537 .5 L p .4481 .50991 L .831 .504 .435 r
F P
0 g
s
.43116 .5 m .4481 .50991 L p .41537 .5 L .831 .504 .435 r
F P
0 g
s
.41607 .48536 m .4437 .46917 L p .4217 .5 L .831 .853 .863 r
F P
0 g
s
.42003 .5 m .41607 .48536 L .4217 .5 L .831 .853 .863 r
F
.4437 .46917 m .4481 .49009 L .43116 .5 L p F P
0 g
s
.45141 .5 m .4481 .49009 L p .46217 .50138 L .787 .758 .827 r
F P
0 g
s
.45141 .5 m .46217 .50138 L .46723 .50543 L .787 .758 .827 r
F
.4481 .50991 m .45141 .5 L p .49998 .50003 L .787 .527 .544 r
F P
0 g
s
.49993 .5 m .49998 .50003 L p .45141 .5 L .787 .527 .544 r
F P
0 g
s
.4481 .49009 m .48269 .47002 L p .4696 .5 L .787 .758 .827 r
F P
0 g
s
.46046 .5 m .4481 .49009 L .4696 .5 L .787 .758 .827 r
F
.48269 .47002 m .49998 .49997 L .49993 .5 L p F P
0 g
s
.49996 .49999 m .49996 .5 L .49995 .5 L .766 .56 .619 r
F
.48209 .46898 m .4822 .46917 L .48209 .46898 L F
.50001 .49997 m .50001 .49998 L .49999 .49998 L .597 .502 .717 r
F
.50001 .49997 m .49999 .49998 L .49998 .49997 L F
.49993 .5 m .49998 .49997 L p .49997 .5 L .766 .691 .78 r
F P
0 g
s
.49989 .50029 m .49993 .5 L .49997 .5 L .766 .691 .78 r
F
.49998 .50003 m .49993 .5 L p .49996 .5 L .766 .56 .619 r
F P
0 g
s
.46467 .43446 m .47086 .44952 L .46467 .43446 L .797 .597 .632 r
F
.48018 .42782 m .47086 .44952 L p .46467 .43446 L F P
0 g
s
.47086 .44952 m .47086 .44952 L p .46467 .43446 L .797 .597 .632 r
F P
0 g
s
.46467 .43446 m .46422 .43802 L .46266 .43533 L .797 .597 .632 r
F
.47086 .44952 m .47086 .44952 L p .47086 .44952 L .591 .526 .75 r
F P
0 g
s
.47086 .44952 m .46422 .43802 L .46467 .43446 L .797 .597 .632 r
F
.44691 .3954 m .47086 .44952 L .45421 .42068 L .591 .526 .75 r
F
.47086 .44952 m .4593 .47642 L p .46422 .43802 L .797 .597 .632 r
F P
0 g
s
.47086 .44952 m .46422 .43802 L .47086 .44952 L .797 .597 .632 r
F
.47085 .44952 m .47086 .44952 L .47086 .44952 L .591 .526 .75 r
F
.44691 .3954 m .47086 .44952 L .47085 .44952 L F
.49993 .45296 m .47086 .44952 L p .44691 .3954 L F P
0 g
s
.4593 .47642 m .42022 .4535 L p .46266 .43533 L .797 .597 .632 r
F P
0 g
s
.46422 .43802 m .4593 .47642 L .46266 .43533 L .797 .597 .632 r
F
.43917 .39465 m .44691 .3954 L .44703 .40826 L p .658 .581 .757 r
F P
0 g
s
.44703 .40826 m .44703 .40826 L p .44703 .40825 L .658 .581 .757 r
F P
0 g
s
.43917 .39465 m .44703 .40826 L .44703 .40825 L .658 .581 .757 r
F
.46266 .43533 m .42022 .4535 L .44703 .40826 L .797 .597 .632 r
F
.42022 .4535 m .43596 .40172 L .44703 .40826 L p F P
0 g
s
.44703 .40826 m .43596 .40172 L p .44168 .39899 L .773 .62 .691 r
F P
0 g
s
.43596 .40172 m .43917 .39465 L p .44168 .39899 L .773 .62 .691 r
F P
0 g
s
.4593 .47642 m .47086 .44952 L p .48209 .46898 L .766 .56 .619 r
F P
0 g
s
.48209 .53102 m .50002 .50004 L .49993 .54704 L .597 .473 .682 r
F
.50002 .50004 m .50002 .50004 L .49993 .54704 L F
.50004 .50006 m .49993 .54704 L p .50002 .50004 L F P
0 g
s
.50002 .50003 m .50003 .50006 L .50002 .50004 L .597 .473 .682 r
F
.50003 .50006 m .50004 .50006 L .50002 .50004 L F
.52109 .52567 m .51977 .53425 L .5152 .52633 L .757 .489 .527 r
F
.54077 .52346 m .52963 .53605 L p .52109 .52567 L F P
0 g
s
.50004 .50006 m .54077 .52346 L p .52109 .52567 L .757 .489 .527 r
F P
0 g
s
.52429 .54208 m .49993 .54704 L .50004 .50006 L p .512 .404 .668 r
F P
0 g
s
.52109 .52567 m .5152 .52633 L .50004 .50006 L .757 .489 .527 r
F
.54077 .52346 m .50004 .50006 L p .50011 .5 L .736 .521 .602 r
F P
0 g
s
.50004 .50006 m .50004 .50006 L p .5152 .52633 L .512 .404 .668 r
F P
0 g
s
.5152 .52633 m .52429 .54208 L .50004 .50006 L .512 .404 .668 r
F
.5152 .52633 m .48269 .52998 L .50004 .50006 L .757 .489 .527 r
F
.52963 .53605 m .52429 .54208 L p .52109 .52567 L F P
0 g
s
.55079 .56894 m .58164 .58638 L p .55625 .58329 L .708 .333 .336 r
F P
0 g
s
.49993 .54704 m .51502 .54397 L p .53431 .57845 L .502 .367 .629 r
F P
0 g
s
.51502 .54397 m .52476 .55325 L .53431 .57845 L .502 .367 .629 r
F
.52079 .54279 m .52639 .54971 L .53431 .57845 L F
.53438 .56618 m .53431 .57845 L p .52639 .5497 L F P
0 g
s
.52429 .54208 m .52865 .55249 L .52639 .5497 L .502 .367 .629 r
F
.52865 .55249 m .53438 .56618 L .52639 .5497 L F
.53431 .57845 m .49962 .59234 L .49993 .54704 L p F P
0 g
s
.54122 .56801 m .53998 .56925 L .53915 .56781 L .743 .39 .384 r
F
.55079 .56894 m .54456 .57214 L p .54122 .56801 L F P
0 g
s
.54232 .5733 m .53431 .57845 L .5344 .56245 L p .372 .262 .598 r
F P
0 g
s
.55079 .56894 m .54122 .56801 L .53848 .56463 L .743 .39 .384 r
F
.53442 .55962 m .53688 .56102 L p .53848 .56463 L F P
0 g
s
.53688 .56102 m .55079 .56894 L p .53848 .56463 L .743 .39 .384 r
F P
0 g
s
.55625 .58329 m .54896 .5824 L .54456 .57214 L .708 .333 .336 r
F
.54456 .57214 m .55079 .56894 L p .55625 .58329 L F P
0 g
s
.58016 .54584 m .55079 .56894 L .53442 .55962 L p .726 .444 .5 r
F P
0 g
s
.51502 .54397 m .52079 .54279 L p .52476 .55325 L .502 .367 .629 r
F P
0 g
s
.52079 .54279 m .52429 .54208 L p .52639 .54971 L .502 .367 .629 r
F P
0 g
s
.54077 .52346 m .58016 .54584 L p .5284 .54919 L .726 .444 .5 r
F P
0 g
s
.52429 .54208 m .5243 .54208 L .53438 .56618 L .502 .367 .629 r
F
.53442 .55962 m .53438 .56618 L p .52429 .54208 L F P
0 g
s
.51736 .5499 m .52429 .54208 L p .5284 .54919 L .726 .444 .5 r
F P
0 g
s
.52429 .54208 m .54077 .52346 L p .5284 .54919 L .726 .444 .5 r
F P
0 g
s
.52429 .54208 m .52429 .54208 L p .5243 .54208 L .502 .367 .629 r
F P
0 g
s
.53037 .54906 m .53442 .55962 L .5284 .54919 L .726 .444 .5 r
F
.58016 .54584 m .53442 .55962 L .53037 .54906 L F
.52429 .54208 m .53454 .53999 L .53442 .55962 L p .502 .367 .629 r
F P
0 g
s
.53442 .55962 m .51736 .5499 L p .5284 .54919 L .726 .444 .5 r
F P
0 g
s
.54122 .56801 m .53915 .56781 L .53442 .55962 L .743 .39 .384 r
F
.53442 .55962 m .54232 .5733 L .53673 .56564 L .372 .262 .598 r
F
.53915 .56781 m .54232 .5733 L .53442 .55962 L F
.5344 .56245 m .53442 .55962 L p .53673 .56564 L F P
0 g
s
.53442 .55962 m .53442 .55961 L p .53673 .56564 L .372 .262 .598 r
F P
0 g
s
.53915 .56781 m .50145 .56417 L .53442 .55962 L .743 .39 .384 r
F
.53442 .55961 m .53915 .56781 L .53442 .55962 L .372 .262 .598 r
F
.55079 .56894 m .58016 .54584 L .61665 .56638 L p .691 .39 .46 r
F P
0 g
s
.61665 .56638 m .58164 .58638 L .55079 .56894 L p .691 .39 .46 r
F P
0 g
s
.58164 .58638 m .55492 .59448 L .55442 .59419 L p .708 .333 .336 r
F P
0 g
s
.58164 .58638 m .55442 .59419 L .55441 .59415 L .708 .333 .336 r
F
.55015 .58254 m .55436 .59416 L .54747 .58222 L F
.58164 .58638 m .55436 .59416 L .55015 .58254 L F
.55436 .59481 m .53399 .6139 L .53431 .57845 L p .341 .206 .548 r
F P
0 g
s
.53399 .6139 m .55312 .59596 L p .55408 .62048 L .285 .127 .483 r
F P
0 g
s
.55312 .59596 m .55436 .59481 L .55433 .59704 L p .285 .127 .483 r
F P
0 g
s
.55433 .59704 m .55408 .62048 L p .55312 .59596 L .285 .127 .483 r
F P
0 g
s
.57729 .60707 m .59542 .61734 L p .56862 .60971 L .59 .056 0 r
F P
0 g
s
.56895 .61397 m .57956 .62011 L p .56897 .61554 L .45 0 0 r
F P
0 g
s
.55408 .62048 m .56017 .60816 L p .56422 .6167 L 0 0 .312 r
F P
0 g
s
.56017 .60816 m .5611 .60894 L .56422 .6167 L 0 0 .312 r
F
.56051 .60748 m .56208 .60908 L .56422 .6167 L F
.56122 .60604 m .56122 .60605 L .56208 .60908 L F
.56208 .60908 m .56208 .60908 L .56422 .6167 L F
.56122 .60604 m .56208 .60908 L .56208 .60908 L F
.56862 .60971 m .56341 .60823 L .56473 .60626 L .59 .056 0 r
F
.56341 .60823 m .56231 .60792 L .56316 .60734 L F
.56341 .60823 m .56316 .60734 L .56473 .60626 L F
.56122 .60604 m .56473 .60626 L p .56231 .60792 L F P
0 g
s
.56897 .61554 m .56635 .61441 L .56577 .61286 L .45 0 0 r
F
.56485 .61338 m .56422 .6167 L .56427 .6116 L p 0 0 .169 r
F P
0 g
s
.5644 .61178 m .56485 .61338 L .56427 .6116 L 0 0 .169 r
F
.56895 .61397 m .56532 .6124 L .5646 .61166 L .508 0 0 r
F
.56428 .61133 m .56452 .61146 L p .5646 .61166 L F P
0 g
s
.56452 .61146 m .56895 .61397 L p .5646 .61166 L .508 0 0 r
F P
0 g
s
.56498 .63687 m .56448 .63581 L p .56775 .61789 L 0 0 0 r
F P
0 g
s
.57956 .62011 m .58537 .62374 L p .56726 .61603 L .388 0 0 r
F P
0 g
s
.56726 .61603 m .56725 .61601 L .57956 .62011 L .388 0 0 r
F
.56712 .61597 m .56656 .61529 L .57956 .62011 L F
.56656 .61529 m .56656 .61529 L p .56656 .61529 L F P
0 g
s
.56656 .61529 m .57956 .62011 L p .56656 .61529 L .388 0 0 r
F P
0 g
s
.56424 .62895 m .56422 .6167 L p .56534 .61379 L 0 0 .101 r
F P
0 g
s
.56534 .61379 m .5654 .61387 L .56424 .62895 L 0 0 .101 r
F
.56543 .61356 m .56548 .61342 L .56645 .61592 L F
.56635 .61441 m .56596 .61424 L .56501 .61259 L .45 0 0 r
F
.56596 .61424 m .56596 .61424 L .56548 .61342 L F
.56596 .61424 m .56548 .61342 L .56501 .61259 L F
.565 .61259 m .56577 .61286 L p .56635 .61441 L F P
0 g
s
.56577 .61286 m .565 .61259 L p .56532 .6124 L .508 0 0 r
F P
0 g
s
.56895 .61397 m .56577 .61286 L p .56532 .6124 L .508 0 0 r
F P
0 g
s
.56473 .60626 m .57729 .60707 L p .56862 .60971 L .59 .056 0 r
F P
0 g
s
.57729 .60707 m .56122 .60604 L p .55956 .60203 L .654 .155 .051 r
F P
0 g
s
.57729 .60707 m .5637 .60321 L .55747 .59701 L .654 .155 .051 r
F
.55687 .59557 m .57729 .60707 L p .55747 .59701 L F P
0 g
s
.60869 .60161 m .57729 .60707 L .55492 .59448 L p .664 .257 .264 r
F P
0 g
s
.59542 .61734 m .56895 .61397 L .56428 .61133 L p .59 .056 0 r
F P
0 g
s
.56123 .60605 m .56231 .60792 L .56426 .61333 L 0 0 .312 r
F
.56428 .61133 m .56426 .61333 L p .56231 .60792 L F P
0 g
s
.56017 .60816 m .56051 .60748 L p .5611 .60894 L 0 0 .312 r
F P
0 g
s
.56051 .60748 m .56122 .60604 L p .56208 .60908 L 0 0 .312 r
F P
0 g
s
.56426 .61333 m .56422 .6167 L p .56122 .60604 L 0 0 .312 r
F P
0 g
s
.5637 .60321 m .55878 .60181 L .55464 .59449 L .654 .155 .051 r
F
.55878 .60181 m .55875 .60176 L .55464 .59449 L F
.55455 .59449 m .55464 .59449 L p .55875 .60176 L F P
0 g
s
.55878 .60181 m .55488 .59506 L .55875 .60176 L .654 .155 .051 r
F
.55488 .59506 m .55455 .59449 L .55875 .60176 L F
.55451 .59456 m .55455 .59449 L p .5546 .59492 L .043 0 .403 r
F P
0 g
s
.55464 .59449 m .55492 .59448 L p .5637 .60321 L .654 .155 .051 r
F P
0 g
s
.55492 .59448 m .55464 .59449 L p .55454 .59437 L .701 .231 .131 r
F P
0 g
s
.55436 .59416 m .55492 .59448 L p .55447 .59435 L .701 .231 .131 r
F P
0 g
s
.55455 .59449 m .56465 .57848 L p .5547 .59475 L .043 0 .403 r
F P
0 g
s
.55455 .59449 m .5547 .59475 L .5546 .59492 L .043 0 .403 r
F
.55492 .59448 m .55687 .59557 L p .55747 .59701 L .654 .155 .051 r
F P
0 g
s
.55492 .59448 m .58164 .58638 L .60869 .60161 L p .664 .257 .264 r
F P
0 g
s
.56465 .57848 m .56439 .59963 L p .55488 .59506 L .043 0 .403 r
F P
0 g
s
.5546 .59492 m .5547 .59475 L .55488 .59506 L .043 0 .403 r
F
.5547 .59475 m .56465 .57848 L .55488 .59506 L F
.55878 .60181 m .55878 .60181 L .55875 .60176 L .654 .155 .051 r
F
.55408 .62048 m .55436 .59481 L p .55488 .59506 L .043 0 .403 r
F P
0 g
s
.55488 .59506 m .55489 .59506 L .55408 .62048 L .043 0 .403 r
F
.56122 .60604 m .55408 .62048 L p .55489 .59506 L F P
0 g
s
.55042 .5916 m .55058 .59059 L .55436 .59481 L .341 .206 .548 r
F
.55058 .59059 m .55291 .59282 L .55436 .59481 L F
.55071 .58981 m .55347 .5931 L .55436 .59481 L F
.55451 .59456 m .55436 .59481 L .55436 .59416 L p .111 .027 .472 r
F P
0 g
s
.55436 .59416 m .55436 .59416 L p .55451 .59456 L .111 .027 .472 r
F P
0 g
s
.55454 .59437 m .55449 .59437 L .55447 .59435 L .701 .231 .131 r
F
.55451 .59441 m .55451 .59456 L .55436 .59416 L .111 .027 .472 r
F
.55464 .59449 m .55455 .59449 L p .55454 .59437 L .701 .231 .131 r
F P
0 g
s
.55455 .59449 m .55451 .59456 L p .55451 .59441 L .111 .027 .472 r
F P
0 g
s
.55436 .59416 m .55436 .59481 L p .55096 .58826 L .341 .206 .548 r
F P
0 g
s
.55455 .59449 m .53564 .59523 L p .55449 .59437 L .701 .231 .131 r
F P
0 g
s
.55455 .59449 m .55449 .59437 L .55454 .59437 L .701 .231 .131 r
F
.55455 .59449 m .55455 .59449 L p .55451 .59441 L .111 .027 .472 r
F P
0 g
s
.55451 .59441 m .55455 .59449 L .55451 .59441 L .111 .027 .472 r
F
.55442 .59419 m .55436 .59416 L p .55441 .59415 L .708 .333 .336 r
F P
0 g
s
.55436 .59416 m .55464 .56537 L p .55451 .59441 L .111 .027 .472 r
F P
0 g
s
.49962 .59234 m .53431 .57845 L .53399 .6139 L p .48 .317 .582 r
F P
0 g
s
.53564 .59523 m .51444 .5833 L p .55447 .59435 L .701 .231 .131 r
F P
0 g
s
.55449 .59437 m .53564 .59523 L .55447 .59435 L .701 .231 .131 r
F
.55436 .59481 m .55451 .59456 L p .5546 .59492 L .043 0 .403 r
F P
0 g
s
.53564 .59523 m .55455 .59449 L p .55878 .60181 L .654 .155 .051 r
F P
0 g
s
.55488 .59506 m .55489 .59506 L .55489 .59506 L .043 0 .403 r
F
.55956 .60203 m .55909 .60234 L .55878 .60181 L .654 .155 .051 r
F
.56122 .60604 m .55408 .60558 L p .55956 .60203 L F P
0 g
s
.56439 .59963 m .56122 .60604 L p .55489 .59506 L .043 0 .403 r
F P
0 g
s
.55408 .60558 m .53564 .59523 L p .55878 .60181 L .654 .155 .051 r
F P
0 g
s
.55909 .60234 m .55408 .60558 L .55878 .60181 L .654 .155 .051 r
F
.56428 .61133 m .55408 .60558 L p .56231 .60792 L .59 .056 0 r
F P
0 g
s
.59542 .61734 m .56428 .61133 L .56231 .60792 L .59 .056 0 r
F
.56428 .61133 m .56428 .61133 L p .56231 .60792 L 0 0 .312 r
F P
0 g
s
.568 .59684 m .56799 .60687 L p .56548 .61342 L 0 0 .101 r
F P
0 g
s
.56422 .6167 m .565 .61259 L p .56548 .61342 L 0 0 .101 r
F P
0 g
s
.56532 .6124 m .56475 .61215 L .56428 .61133 L .508 0 0 r
F
.565 .61259 m .56479 .61222 L .56532 .6124 L F
.56532 .6124 m .56479 .61222 L .56475 .61215 L F
.565 .61259 m .568 .59684 L p .56548 .61342 L 0 0 .101 r
F P
0 g
s
.56577 .61286 m .56895 .61397 L p .56897 .61554 L .45 0 0 r
F P
0 g
s
.56656 .61529 m .56645 .61592 L p .56548 .61342 L 0 0 .101 r
F P
0 g
s
.56645 .61592 m .56424 .62895 L p .56543 .61356 L 0 0 .101 r
F P
0 g
s
.55856 .61232 m .54987 .60731 L p .56596 .61424 L .45 0 0 r
F P
0 g
s
.57956 .62011 m .56656 .61529 L p .56621 .61435 L .45 0 0 r
F P
0 g
s
.58537 .62374 m .56748 .61688 L p .56748 .61688 L .388 0 0 r
F P
0 g
s
.58537 .62374 m .56748 .61688 L .56726 .61603 L .388 0 0 r
F
.58537 .62374 m .58604 .62471 L p .56758 .61706 L .322 0 0 r
F P
0 g
s
.56448 .63581 m .56748 .61688 L p .56775 .61789 L 0 0 0 r
F P
0 g
s
.56424 .62895 m .56656 .61529 L p .56714 .61681 L 0 0 .031 r
F P
0 g
s
.56726 .61603 m .56748 .61688 L .5669 .61587 L .388 0 0 r
F
.56748 .61688 m .56723 .61644 L .5669 .61587 L F
.56712 .61597 m .5669 .61587 L .56656 .61529 L F
.56656 .61529 m .56656 .61529 L .56714 .61681 L 0 0 .031 r
F
.56656 .61529 m .56718 .61636 L .56714 .61681 L F
.55856 .61232 m .56656 .61529 L p .5669 .61587 L .388 0 0 r
F P
0 g
s
.56656 .61529 m .56656 .61529 L p .56656 .61529 L 0 0 .031 r
F P
0 g
s
.56726 .61603 m .56712 .61597 L .56725 .61601 L .388 0 0 r
F
.56656 .61529 m .56799 .60687 L p .56718 .61636 L 0 0 .031 r
F P
0 g
s
.56324 .61526 m .55856 .61232 L p .5669 .61587 L .388 0 0 r
F P
0 g
s
.56448 .63581 m .56424 .62895 L p .56723 .61644 L 0 0 .031 r
F P
0 g
s
.56748 .61688 m .56748 .61688 L p .56723 .61644 L .388 0 0 r
F P
0 g
s
.56748 .61688 m .56448 .63581 L p .56723 .61644 L 0 0 .031 r
F P
0 g
s
.56324 .61526 m .56748 .61688 L p .56758 .61706 L .322 0 0 r
F P
0 g
s
.56748 .61688 m .58537 .62374 L p .56758 .61706 L .322 0 0 r
F P
0 g
s
.56775 .61789 m .56779 .61741 L .56783 .61748 L 0 0 0 r
F
.56363 .61598 m .56324 .61526 L p .56758 .61706 L .322 0 0 r
F P
0 g
s
.58604 .62471 m .56793 .61765 L p .56758 .61706 L .322 0 0 r
F P
0 g
s
.56748 .61688 m .56779 .61741 L .56775 .61789 L 0 0 0 r
F
.56862 .6131 m .56784 .61823 L p .56775 .61789 L F P
0 g
s
.56793 .61765 m .56363 .61598 L p .56758 .61706 L .322 0 0 r
F P
0 g
s
.56748 .61688 m .5682 .61239 L p .56779 .61741 L 0 0 0 r
F P
0 g
s
.5682 .61239 m .56862 .6131 L p .56783 .61748 L 0 0 0 r
F P
0 g
s
.56779 .61741 m .5682 .61239 L .56783 .61748 L 0 0 0 r
F
.56799 .60687 m .5682 .61239 L p .56723 .61644 L 0 0 .031 r
F P
0 g
s
.56714 .61681 m .56718 .61636 L .56723 .61644 L 0 0 .031 r
F
.56718 .61636 m .56799 .60687 L .56723 .61644 L F
.56621 .61435 m .56656 .61529 L .56596 .61424 L .45 0 0 r
F
.56656 .61529 m .55856 .61232 L p .56596 .61424 L F P
0 g
s
.56799 .60687 m .56656 .61529 L p .56596 .61424 L 0 0 .101 r
F P
0 g
s
.56548 .61342 m .56548 .61342 L .56596 .61424 L 0 0 .101 r
F
.56548 .61342 m .56799 .60687 L .56596 .61424 L F
.56428 .61133 m .56485 .61338 L .56428 .61133 L 0 0 .169 r
F
.565 .61259 m .56485 .61338 L p .56482 .61226 L F P
0 g
s
.56428 .61133 m .56439 .59963 L p .56485 .61338 L 0 0 .169 r
F P
0 g
s
.54987 .60731 m .565 .61259 L p .56501 .61259 L .45 0 0 r
F P
0 g
s
.56534 .61379 m .56543 .61356 L .5654 .61387 L 0 0 .101 r
F
.56596 .61424 m .54987 .60731 L .56501 .61259 L .45 0 0 r
F
.56748 .61688 m .56324 .61526 L p .5669 .61587 L .388 0 0 r
F P
0 g
s
.5682 .61239 m .56748 .61688 L p .56723 .61644 L 0 0 .031 r
F P
0 g
s
.56784 .61823 m .56498 .63687 L p .56775 .61789 L 0 0 0 r
F P
0 g
s
.56428 .61133 m .56428 .61133 L .56428 .61133 L 0 0 .169 r
F
.56428 .61133 m .56428 .61133 L .56428 .61133 L F
.56427 .6116 m .56428 .61133 L p .5644 .61178 L F P
0 g
s
.56475 .61215 m .5376 .60041 L .56428 .61133 L .508 0 0 r
F
.56428 .61133 m .56428 .61133 L p .56428 .61133 L 0 0 .169 r
F P
0 g
s
.565 .61259 m .54987 .60731 L p .56479 .61222 L .508 0 0 r
F P
0 g
s
.54987 .60731 m .5376 .60041 L p .56475 .61215 L .508 0 0 r
F P
0 g
s
.56479 .61222 m .54987 .60731 L .56475 .61215 L .508 0 0 r
F
.568 .59684 m .565 .61259 L p .56439 .59963 L 0 0 .169 r
F P
0 g
s
.56439 .59963 m .565 .61259 L .56482 .61226 L 0 0 .169 r
F
.56122 .60604 m .56439 .59963 L .56428 .61133 L p 0 0 .312 r
F P
0 g
s
.56122 .60604 m .56428 .61133 L .56123 .60605 L 0 0 .312 r
F
.55408 .60558 m .56122 .60604 L p .56231 .60792 L .59 .056 0 r
F P
0 g
s
.5376 .60041 m .55408 .60558 L .56428 .61133 L p .508 0 0 r
F P
0 g
s
.56122 .60604 m .56122 .60604 L p .56122 .60605 L 0 0 .312 r
F P
0 g
s
.55058 .59059 m .55071 .58981 L .55291 .59282 L .341 .206 .548 r
F
.55071 .58981 m .55096 .58826 L .55347 .5931 L F
.51444 .5833 m .52929 .58 L .55436 .59416 L p .701 .231 .131 r
F P
0 g
s
.55447 .59435 m .51444 .5833 L .55436 .59416 L .701 .231 .131 r
F
.56465 .57848 m .55455 .59449 L p .55464 .56537 L .111 .027 .472 r
F P
0 g
s
.55464 .56537 m .55455 .59449 L .55451 .59441 L .111 .027 .472 r
F
.53431 .57845 m .54232 .5733 L p .55042 .5916 L .341 .206 .548 r
F P
0 g
s
.54232 .5733 m .54456 .57214 L p .54896 .5824 L .708 .333 .336 r
F P
0 g
s
.54232 .5733 m .54232 .5733 L p .54232 .5733 L .341 .206 .548 r
F P
0 g
s
.54232 .5733 m .54232 .5733 L .55042 .5916 L .341 .206 .548 r
F
.54896 .5824 m .54747 .58222 L .54232 .5733 L .708 .333 .336 r
F
.54456 .57214 m .54232 .5733 L p .54122 .56801 L .743 .39 .384 r
F P
0 g
s
.54232 .5733 m .52929 .58 L p .54036 .56887 L .743 .39 .384 r
F P
0 g
s
.54232 .5733 m .54036 .56887 L .54122 .56801 L .743 .39 .384 r
F
.54232 .5733 m .55464 .56537 L p .55042 .5916 L .341 .206 .548 r
F P
0 g
s
.52929 .58 m .54232 .5733 L p .54747 .58222 L .708 .333 .336 r
F P
0 g
s
.55436 .59416 m .52929 .58 L p .54747 .58222 L .708 .333 .336 r
F P
0 g
s
.55464 .56537 m .55436 .59416 L p .55096 .58826 L .341 .206 .548 r
F P
0 g
s
.55464 .56537 m .54232 .5733 L p .53454 .53999 L .372 .262 .598 r
F P
0 g
s
.53442 .55961 m .53454 .53999 L p .54232 .5733 L .372 .262 .598 r
F P
0 g
s
.52929 .58 m .50145 .56417 L p .53915 .56781 L .743 .39 .384 r
F P
0 g
s
.53998 .56925 m .52929 .58 L .53915 .56781 L .743 .39 .384 r
F
.50145 .56417 m .51736 .5499 L .53442 .55962 L p F P
0 g
s
.52429 .54208 m .51736 .5499 L p .52011 .53207 L .757 .489 .527 r
F P
0 g
s
.52429 .54208 m .52011 .53207 L .52109 .52567 L .757 .489 .527 r
F
.53454 .53999 m .52429 .54208 L p .50004 .5 L .512 .404 .668 r
F P
0 g
s
.50011 .5 m .50004 .50006 L .50001 .50002 L .736 .521 .602 r
F
.50004 .50006 m .50004 .5 L p .52429 .54208 L .512 .404 .668 r
F P
0 g
s
.51736 .5499 m .48269 .52998 L p .5152 .52633 L .757 .489 .527 r
F P
0 g
s
.51977 .53425 m .51736 .5499 L .5152 .52633 L .757 .489 .527 r
F
.48269 .52998 m .49998 .50003 L .50004 .50006 L p F P
0 g
s
.50002 .50004 m .50002 .50003 L .50002 .50004 L .597 .473 .682 r
F
.50004 .5 m .50004 .50006 L p .50002 .50003 L F P
0 g
s
.50004 .50006 m .49998 .50003 L p .50001 .50002 L .736 .521 .602 r
F P
0 g
s
.50011 .5 m .54077 .52346 L .50011 .5 L .736 .521 .602 r
F
.54077 .52346 m .55829 .5 L p .61713 .50632 L .704 .478 .578 r
F P
0 g
s
.54077 .47654 m .55829 .5 L p .53581 .5 L .736 .68 .797 r
F P
0 g
s
.50004 .5 m .5 .5 L p .50001 .49998 L .597 .502 .717 r
F P
0 g
s
.49962 .59234 m .44691 .6046 L .44703 .59174 L p .591 .439 .644 r
F P
0 g
s
.44703 .59174 m .44691 .6046 L p .44168 .60101 L .658 .494 .65 r
F P
0 g
s
.44691 .6046 m .43917 .60535 L p .44168 .60101 L .658 .494 .65 r
F P
0 g
s
.2968 .55562 m .3772 .55672 L .37642 .61146 L p .716 .541 .652 r
F P
0 g
s
.51228 .63471 m .55343 .70379 L .50749 .73158 L p .745 .579 .669 r
F P
0 g
s
.50749 .73158 m .46527 .66275 L .51228 .63471 L p .745 .579 .669 r
F P
0 g
s
.3772 .44328 m .2968 .44438 L .29571 .3907 L p .716 .628 .758 r
F P
0 g
s
.29571 .3907 m .37642 .38854 L .3772 .44328 L p .716 .628 .758 r
F P
0 g
s
.64977 .64817 m .61052 .57799 L .65832 .5513 L p .654 .548 .722 r
F P
0 g
s
.55343 .29621 m .51228 .36529 L .46527 .33725 L p .745 .638 .741 r
F P
0 g
s
.61052 .42201 m .64977 .35183 L .69681 .37773 L p .654 .52 .688 r
F P
0 g
s
.69681 .37773 m .65832 .4487 L .61052 .42201 L p .654 .52 .688 r
F P
0 g
s
.46527 .33725 m .50749 .26842 L .55343 .29621 L p .745 .638 .741 r
F P
0 g
s
.59724 .23244 m .55343 .29621 L .50749 .26842 L p .712 .651 .786 r
F P
0 g
s
.55343 .29621 m .59724 .23244 L .63995 .2576 L p .686 .613 .769 r
F P
0 g
s
.64977 .35183 m .68309 .28201 L .72513 .30481 L p .624 .536 .735 r
F P
0 g
s
.72513 .30481 m .69681 .37773 L .64977 .35183 L p .624 .536 .735 r
F P
0 g
s
.55343 .70379 m .59724 .76756 L .55648 .79256 L p .712 .513 .617 r
F P
0 g
s
.55648 .79256 m .50749 .73158 L .55343 .70379 L p .712 .513 .617 r
F P
0 g
s
.65832 .5513 m .69681 .62227 L .64977 .64817 L p .654 .548 .722 r
F P
0 g
s
.68309 .71799 m .64977 .64817 L .69681 .62227 L p .624 .482 .669 r
F P
0 g
s
.64977 .64817 m .68309 .71799 L .63995 .7424 L p .657 .497 .656 r
F P
0 g
s
.37642 .61146 m .29571 .6093 L .2968 .55562 L p .716 .541 .652 r
F P
0 g
s
.21967 .54957 m .2968 .55562 L .29571 .6093 L p .77 .587 .651 r
F P
0 g
s
.2968 .55562 m .21967 .54957 L .2201 .5 L p .769 .614 .687 r
F P
0 g
s
.2968 .44438 m .21967 .45043 L .2184 .40263 L p .77 .671 .753 r
F P
0 g
s
.2184 .40263 m .29571 .3907 L .2968 .44438 L p .77 .671 .753 r
F P
0 g
s
.46527 .66275 m .50749 .73158 L .46522 .75803 L p .775 .587 .645 r
F P
0 g
s
.37642 .38854 m .29571 .3907 L .29393 .34086 L p .713 .657 .793 r
F P
0 g
s
.65832 .4487 m .69681 .37773 L .74086 .40111 L p .615 .473 .665 r
F P
0 g
s
.55648 .20744 m .50749 .26842 L .46522 .24197 L p .738 .692 .806 r
F P
0 g
s
.50749 .26842 m .55648 .20744 L .59724 .23244 L p .712 .651 .786 r
F P
0 g
s
.69681 .37773 m .72513 .30481 L .76454 .32516 L p .583 .491 .716 r
F P
0 g
s
.76454 .32516 m .74086 .40111 L .69681 .37773 L p .583 .491 .716 r
F P
0 g
s
.50749 .73158 m .55648 .79256 L .51915 .81652 L p .738 .514 .589 r
F P
0 g
s
.51915 .81652 m .46522 .75803 L .50749 .73158 L p .738 .514 .589 r
F P
0 g
s
.72513 .69519 m .69681 .62227 L .74086 .59889 L p .583 .461 .679 r
F P
0 g
s
.69681 .62227 m .72513 .69519 L .68309 .71799 L p .624 .482 .669 r
F P
0 g
s
.29571 .3907 m .2184 .40263 L .21631 .35833 L p .771 .703 .787 r
F P
0 g
s
.21631 .35833 m .29393 .34086 L .29571 .3907 L p .771 .703 .787 r
F P
0 g
s
.2184 .59737 m .29571 .6093 L .29393 .65914 L p .771 .556 .608 r
F P
0 g
s
.29571 .6093 m .2184 .59737 L .21967 .54957 L p .77 .587 .651 r
F P
0 g
s
.67086 .20407 m .63995 .2576 L .59724 .23244 L p .646 .624 .813 r
F P
0 g
s
.63995 .2576 m .67086 .20407 L .70583 .22378 L p .618 .588 .797 r
F P
0 g
s
.70583 .22378 m .68309 .28201 L .63995 .2576 L p .618 .588 .797 r
F P
0 g
s
.67086 .79593 m .63995 .7424 L .68309 .71799 L p .618 .422 .594 r
F P
0 g
s
.63995 .7424 m .67086 .79593 L .6363 .81636 L p .646 .431 .578 r
F P
0 g
s
.6363 .81636 m .59724 .76756 L .63995 .7424 L p .646 .431 .578 r
F P
0 g
s
.15829 .5 m .2201 .5 L .21967 .54957 L p .822 .658 .68 r
F P
0 g
s
.2201 .5 m .15829 .5 L .15787 .45986 L p .822 .684 .711 r
F P
0 g
s
.15787 .45986 m .21967 .45043 L .2201 .5 L p .822 .684 .711 r
F P
0 g
s
.44691 .3954 m .49962 .40766 L .49993 .45296 L p .591 .526 .75 r
F P
0 g
s
.49962 .40766 m .44691 .3954 L .44614 .34782 L p .576 .547 .785 r
F P
0 g
s
.49916 .63421 m .44614 .65218 L .44691 .6046 L p .576 .394 .598 r
F P
0 g
s
.44691 .6046 m .49962 .59234 L .49916 .63421 L p .576 .394 .598 r
F P
0 g
s
.43596 .59828 m .42022 .5465 L .4593 .52358 L p .797 .704 .762 r
F P
0 g
s
.42022 .5465 m .43596 .59828 L .39513 .62273 L p .83 .721 .744 r
F P
0 g
s
.61665 .43362 m .65872 .47055 L .61713 .49368 L p .668 .665 .838 r
F P
0 g
s
.61713 .49368 m .58016 .45416 L .61665 .43362 L p .668 .665 .838 r
F P
0 g
s
.38419 .43217 m .39513 .37727 L .43596 .40172 L p .83 .635 .639 r
F P
0 g
s
.43596 .40172 m .42022 .4535 L .38419 .43217 L p .83 .635 .639 r
F P
0 g
s
.61713 .50632 m .58016 .54584 L .54077 .52346 L p .704 .478 .578 r
F P
0 g
s
.58016 .54584 m .61713 .50632 L .65872 .52945 L p .668 .426 .545 r
F P
0 g
s
.68309 .28201 m .70583 .22378 L .73992 .24204 L p .585 .551 .782 r
F P
0 g
s
.73992 .24204 m .72513 .30481 L .68309 .28201 L p .585 .551 .782 r
F P
0 g
s
.6363 .18364 m .59724 .23244 L .55648 .20744 L p .67 .66 .831 r
F P
0 g
s
.59724 .23244 m .6363 .18364 L .67086 .20407 L p .646 .624 .813 r
F P
0 g
s
.59724 .76756 m .6363 .81636 L .60344 .83676 L p .67 .434 .555 r
F P
0 g
s
.60344 .83676 m .55648 .79256 L .59724 .76756 L p .67 .434 .555 r
F P
0 g
s
.70583 .77622 m .68309 .71799 L .72513 .69519 L p .585 .405 .604 r
F P
0 g
s
.68309 .71799 m .70583 .77622 L .67086 .79593 L p .618 .422 .594 r
F P
0 g
s
.21967 .45043 m .15787 .45986 L .15664 .4212 L p .824 .713 .742 r
F P
0 g
s
.15664 .4212 m .2184 .40263 L .21967 .45043 L p .824 .713 .742 r
F P
0 g
s
.15787 .54014 m .21967 .54957 L .2184 .59737 L p .824 .633 .644 r
F P
0 g
s
.21967 .54957 m .15787 .54014 L .15829 .5 L p .822 .658 .68 r
F P
0 g
s
.50004 .5 m .53462 .5 L .53454 .53999 L p .512 .404 .668 r
F P
0 g
s
.49998 .49997 m .48269 .47002 L .51736 .4501 L p .757 .748 .844 r
F P
0 g
s
.49998 .50003 m .48269 .52998 L .4481 .50991 L p .787 .527 .544 r
F P
0 g
s
.51915 .18348 m .46522 .24197 L .4282 .21782 L p .765 .739 .829 r
F P
0 g
s
.46522 .24197 m .51915 .18348 L .55648 .20744 L p .738 .692 .806 r
F P
0 g
s
.74086 .40111 m .76454 .32516 L .79982 .34227 L p .53 .436 .693 r
F P
0 g
s
.79982 .34227 m .78027 .4211 L .74086 .40111 L p .53 .436 .693 r
F P
0 g
s
.46522 .75803 m .51915 .81652 L .48669 .83851 L p .765 .51 .549 r
F P
0 g
s
.48669 .83851 m .4282 .78218 L .46522 .75803 L p .765 .51 .549 r
F P
0 g
s
.76454 .67484 m .74086 .59889 L .78027 .5789 L p .53 .429 .685 r
F P
0 g
s
.74086 .59889 m .76454 .67484 L .72513 .69519 L p .583 .461 .679 r
F P
0 g
s
.21631 .64167 m .29393 .65914 L .29153 .70327 L p .772 .52 .553 r
F P
0 g
s
.29393 .65914 m .21631 .64167 L .2184 .59737 L p .771 .556 .608 r
F P
0 g
s
.29393 .34086 m .21631 .35833 L .2135 .31922 L p .772 .741 .825 r
F P
0 g
s
.2135 .31922 m .29153 .29673 L .29393 .34086 L p .772 .741 .825 r
F P
0 g
s
.72513 .30481 m .73992 .24204 L .77186 .25815 L p .543 .509 .767 r
F P
0 g
s
.77186 .25815 m .76454 .32516 L .72513 .30481 L p .543 .509 .767 r
F P
0 g
s
.60344 .16324 m .55648 .20744 L .51915 .18348 L p .691 .699 .853 r
F P
0 g
s
.55648 .20744 m .60344 .16324 L .6363 .18364 L p .67 .66 .831 r
F P
0 g
s
.55648 .79256 m .60344 .83676 L .57352 .85636 L p .691 .429 .523 r
F P
0 g
s
.57352 .85636 m .51915 .81652 L .55648 .79256 L p .691 .429 .523 r
F P
0 g
s
.73992 .75796 m .72513 .69519 L .76454 .67484 L p .543 .378 .608 r
F P
0 g
s
.72513 .69519 m .73992 .75796 L .70583 .77622 L p .585 .405 .604 r
F P
0 g
s
.15664 .5788 m .2184 .59737 L .21631 .64167 L p .829 .607 .602 r
F P
0 g
s
.2184 .59737 m .15664 .5788 L .15787 .54014 L p .824 .633 .644 r
F P
0 g
s
.2184 .40263 m .15664 .4212 L .15462 .38549 L p .829 .746 .773 r
F P
0 g
s
.15462 .38549 m .21631 .35833 L .2184 .40263 L p .829 .746 .773 r
F P
0 g
s
.49863 .67102 m .44517 .6942 L .44614 .65218 L p .55 .333 .538 r
F P
0 g
s
.44614 .65218 m .49916 .63421 L .49863 .67102 L p .55 .333 .538 r
F P
0 g
s
.44614 .34782 m .49916 .36579 L .49962 .40766 L p .576 .547 .785 r
F P
0 g
s
.49916 .36579 m .44614 .34782 L .44517 .3058 L p .55 .565 .822 r
F P
0 g
s
.39513 .62273 m .38419 .56783 L .42022 .5465 L p .83 .721 .744 r
F P
0 g
s
.38419 .56783 m .39513 .62273 L .35923 .64458 L p .868 .743 .722 r
F P
0 g
s
.6488 .41568 m .6956 .45038 L .65872 .47055 L p .623 .658 .864 r
F P
0 g
s
.65872 .47055 m .61665 .43362 L .6488 .41568 L p .623 .658 .864 r
F P
0 g
s
.35257 .4133 m .35923 .35542 L .39513 .37727 L p .868 .675 .639 r
F P
0 g
s
.39513 .37727 m .38419 .43217 L .35257 .4133 L p .868 .675 .639 r
F P
0 g
s
.65872 .52945 m .61665 .56638 L .58016 .54584 L p .668 .426 .545 r
F P
0 g
s
.61665 .56638 m .65872 .52945 L .6956 .54962 L p .622 .358 .497 r
F P
0 g
s
.53399 .6139 m .49916 .63421 L .49962 .59234 L p .48 .317 .582 r
F P
0 g
s
.58164 .41362 m .61665 .43362 L .58016 .45416 L p .691 .738 .887 r
F P
0 g
s
.38437 .47248 m .38419 .43217 L .42022 .4535 L p .85 .595 .552 r
F P
0 g
s
.4282 .21782 m .48669 .16149 L .51915 .18348 L p .765 .739 .829 r
F P
0 g
s
.57352 .14364 m .51915 .18348 L .48669 .16149 L p .709 .743 .878 r
F P
0 g
s
.51915 .18348 m .57352 .14364 L .60344 .16324 L p .691 .699 .853 r
F P
0 g
s
.76454 .32516 m .77186 .25815 L .80039 .27147 L p .487 .458 .75 r
F P
0 g
s
.80039 .27147 m .79982 .34227 L .76454 .32516 L p .487 .458 .75 r
F P
0 g
s
.78027 .5789 m .79982 .65773 L .76454 .67484 L p .53 .429 .685 r
F P
0 g
s
.77186 .74185 m .76454 .67484 L .79982 .65773 L p .487 .338 .604 r
F P
0 g
s
.76454 .67484 m .77186 .74185 L .73992 .75796 L p .543 .378 .608 r
F P
0 g
s
.51915 .81652 m .57352 .85636 L .54772 .87441 L p .709 .414 .476 r
F P
0 g
s
.54772 .87441 m .48669 .83851 L .51915 .81652 L p .709 .414 .476 r
F P
0 g
s
.21631 .35833 m .15462 .38549 L .15189 .35412 L p .836 .787 .805 r
F P
0 g
s
.15189 .35412 m .2135 .31922 L .21631 .35833 L p .836 .787 .805 r
F P
0 g
s
.29153 .70327 m .2135 .68078 L .21631 .64167 L p .772 .52 .553 r
F P
0 g
s
.15462 .61451 m .21631 .64167 L .2135 .68078 L p .836 .578 .549 r
F P
0 g
s
.21631 .64167 m .15462 .61451 L .15664 .5788 L p .829 .607 .602 r
F P
0 g
s
.69198 .16747 m .67086 .20407 L .6363 .18364 L p .592 .63 .858 r
F P
0 g
s
.67086 .20407 m .69198 .16747 L .71798 .18208 L p .566 .597 .843 r
F P
0 g
s
.71798 .18208 m .70583 .22378 L .67086 .20407 L p .566 .597 .843 r
F P
0 g
s
.69198 .83253 m .67086 .79593 L .70583 .77622 L p .566 .328 .514 r
F P
0 g
s
.67086 .79593 m .69198 .83253 L .66634 .84773 L p .592 .337 .499 r
F P
0 g
s
.66634 .84773 m .6363 .81636 L .67086 .79593 L p .592 .337 .499 r
F P
0 g
s
.11603 .5 m .15829 .5 L .15787 .54014 L p .877 .704 .664 r
F P
0 g
s
.15829 .5 m .11603 .5 L .11569 .47019 L p .877 .728 .693 r
F P
0 g
s
.11569 .47019 m .15787 .45986 L .15829 .5 L p .877 .728 .693 r
F P
0 g
s
.66634 .15227 m .6363 .18364 L .60344 .16324 L p .612 .663 .875 r
F P
0 g
s
.6363 .18364 m .66634 .15227 L .69198 .16747 L p .592 .63 .858 r
F P
0 g
s
.70583 .22378 m .71798 .18208 L .74331 .19553 L p .533 .562 .83 r
F P
0 g
s
.74331 .19553 m .73992 .24204 L .70583 .22378 L p .533 .562 .83 r
F P
0 g
s
.71798 .81792 m .70583 .77622 L .73992 .75796 L p .533 .309 .52 r
F P
0 g
s
.70583 .77622 m .71798 .81792 L .69198 .83253 L p .566 .328 .514 r
F P
0 g
s
.6363 .81636 m .66634 .84773 L .64203 .86295 L p .612 .336 .475 r
F P
0 g
s
.64203 .86295 m .60344 .83676 L .6363 .81636 L p .612 .336 .475 r
F P
0 g
s
.11569 .52981 m .15787 .54014 L .15664 .5788 L p .88 .682 .63 r
F P
0 g
s
.15787 .54014 m .11569 .52981 L .11603 .5 L p .877 .704 .664 r
F P
0 g
s
.15787 .45986 m .11569 .47019 L .11466 .44153 L p .88 .756 .72 r
F P
0 g
s
.11466 .44153 m .15664 .4212 L .15787 .45986 L p .88 .756 .72 r
F P
0 g
s
.55485 .53334 m .53454 .53999 L .53462 .5 L p .387 .302 .638 r
F P
0 g
s
.53462 .5 m .55492 .5 L .55485 .53334 L p .387 .302 .638 r
F P
0 g
s
.55492 .5 m .53462 .5 L .53454 .46001 L p .387 .329 .671 r
F P
0 g
s
.50145 .43583 m .51736 .4501 L .48269 .47002 L p .774 .828 .894 r
F P
0 g
s
.48269 .47002 m .47254 .45244 L .50145 .43583 L p .774 .828 .894 r
F P
0 g
s
.47254 .45244 m .48269 .47002 L .4481 .49009 L p .803 .838 .878 r
F P
0 g
s
.4437 .53083 m .4481 .50991 L .48269 .52998 L p .803 .473 .431 r
F P
0 g
s
.48269 .52998 m .47254 .54756 L .4437 .53083 L p .803 .473 .431 r
F P
0 g
s
.47254 .54756 m .48269 .52998 L .51736 .5499 L p .774 .436 .414 r
F P
0 g
s
.53454 .46001 m .55485 .46666 L .55492 .5 L p .387 .329 .671 r
F P
0 g
s
.53454 .53999 m .55485 .53334 L .55464 .56537 L p .372 .262 .598 r
F P
0 g
s
.4481 .49009 m .4437 .46917 L .47254 .45244 L p .803 .838 .878 r
F P
0 g
s
.51736 .4501 m .50145 .43583 L .52929 .42 L p .743 .823 .914 r
F P
0 g
s
.4481 .50991 m .4437 .53083 L .41607 .51464 L p .831 .504 .435 r
F P
0 g
s
.51736 .5499 m .50145 .56417 L .47254 .54756 L p .774 .436 .414 r
F P
0 g
s
.48669 .16149 m .4282 .21782 L .39794 .19698 L p .792 .797 .856 r
F P
0 g
s
.4282 .78218 m .48669 .83851 L .46044 .85767 L p .792 .496 .488 r
F P
0 g
s
.46044 .85767 m .39794 .80302 L .4282 .78218 L p .792 .496 .488 r
F P
0 g
s
.78027 .4211 m .79982 .34227 L .82953 .35543 L p .453 .36 .66 r
F P
0 g
s
.82953 .35543 m .81346 .43688 L .78027 .4211 L p .453 .36 .66 r
F P
0 g
s
.79982 .65773 m .78027 .5789 L .81346 .56312 L p .453 .379 .684 r
F P
0 g
s
.2135 .68078 m .29153 .70327 L .2886 .7399 L p .772 .47 .476 r
F P
0 g
s
.29153 .29673 m .2135 .31922 L .21003 .2869 L p .772 .79 .868 r
F P
0 g
s
.21003 .2869 m .2886 .2601 L .29153 .29673 L p .772 .79 .868 r
F P
0 g
s
.53399 .3861 m .49916 .36579 L .49863 .32898 L p .441 .473 .797 r
F P
0 g
s
.44517 .3058 m .49863 .32898 L .49916 .36579 L p .55 .565 .822 r
F P
0 g
s
.53365 .64493 m .49863 .67102 L .49916 .63421 L p .441 .247 .52 r
F P
0 g
s
.49916 .63421 m .53399 .6139 L .53365 .64493 L p .441 .247 .52 r
F P
0 g
s
.38437 .52752 m .38419 .56783 L .35257 .5867 L p .887 .821 .777 r
F P
0 g
s
.35923 .64458 m .35257 .5867 L .38419 .56783 L p .868 .743 .722 r
F P
0 g
s
.60869 .39839 m .6488 .41568 L .61665 .43362 L p .647 .739 .916 r
F P
0 g
s
.61665 .43362 m .58164 .41362 L .60869 .39839 L p .647 .739 .916 r
F P
0 g
s
.35766 .45668 m .35257 .4133 L .38419 .43217 L p .887 .627 .54 r
F P
0 g
s
.38419 .43217 m .38437 .47248 L .35766 .45668 L p .887 .627 .54 r
F P
0 g
s
.58164 .58638 m .61665 .56638 L .6488 .58432 L p .647 .318 .401 r
F P
0 g
s
.6956 .54962 m .6488 .58432 L .61665 .56638 L p .622 .358 .497 r
F P
0 g
s
.73992 .24204 m .74331 .19553 L .76699 .20727 L p .491 .524 .818 r
F P
0 g
s
.76699 .20727 m .77186 .25815 L .73992 .24204 L p .491 .524 .818 r
F P
0 g
s
.64203 .13705 m .60344 .16324 L .57352 .14364 L p .626 .698 .897 r
F P
0 g
s
.60344 .16324 m .64203 .13705 L .66634 .15227 L p .612 .663 .875 r
F P
0 g
s
.60344 .83676 m .64203 .86295 L .62001 .87758 L p .626 .324 .439 r
F P
0 g
s
.62001 .87758 m .57352 .85636 L .60344 .83676 L p .626 .324 .439 r
F P
0 g
s
.74331 .80447 m .73992 .75796 L .77186 .74185 L p .491 .278 .517 r
F P
0 g
s
.73992 .75796 m .74331 .80447 L .71798 .81792 L p .533 .309 .52 r
F P
0 g
s
.15664 .4212 m .11466 .44153 L .113 .41514 L p .887 .788 .746 r
F P
0 g
s
.113 .41514 m .15462 .38549 L .15664 .4212 L p .887 .788 .746 r
F P
0 g
s
.11466 .55847 m .15664 .5788 L .15462 .61451 L p .887 .66 .59 r
F P
0 g
s
.15664 .5788 m .11466 .55847 L .11569 .52981 L p .88 .682 .63 r
F P
0 g
s
.49811 .70129 m .44408 .72895 L .44517 .6942 L p .503 .243 .453 r
F P
0 g
s
.44517 .6942 m .49863 .67102 L .49811 .70129 L p .503 .243 .453 r
F P
0 g
s
.49863 .32898 m .44517 .3058 L .44408 .27105 L p .503 .579 .864 r
F P
0 g
s
.37152 .25539 m .44408 .27105 L .44517 .3058 L p .606 .664 .88 r
F P
0 g
s
.35257 .5867 m .35923 .64458 L .32968 .6629 L p .914 .772 .69 r
F P
0 g
s
.3524 .73357 m .32968 .6629 L .35923 .64458 L p .885 .685 .627 r
F P
0 g
s
.67527 .40099 m .72624 .43395 L .6956 .45038 L p .558 .65 .896 r
F P
0 g
s
.6956 .45038 m .6488 .41568 L .67527 .40099 L p .558 .65 .896 r
F P
0 g
s
.32662 .39772 m .32968 .3371 L .35923 .35542 L p .914 .72 .627 r
F P
0 g
s
.35923 .35542 m .35257 .4133 L .32662 .39772 L p .914 .72 .627 r
F P
0 g
s
.6488 .58432 m .6956 .54962 L .72624 .56605 L p .558 .262 .421 r
F P
0 g
s
.77608 .51104 m .72624 .56605 L .6956 .54962 L p .527 .299 .512 r
F P
0 g
s
.79982 .34227 m .80039 .27147 L .82433 .28142 L p .407 .39 .728 r
F P
0 g
s
.82433 .28142 m .82953 .35543 L .79982 .34227 L p .407 .39 .728 r
F P
0 g
s
.39794 .19698 m .46044 .14233 L .48669 .16149 L p .792 .797 .856 r
F P
0 g
s
.54772 .12559 m .48669 .16149 L .46044 .14233 L p .722 .795 .91 r
F P
0 g
s
.48669 .16149 m .54772 .12559 L .57352 .14364 L p .709 .743 .878 r
F P
0 g
s
.48669 .83851 m .54772 .87441 L .52713 .89017 L p .722 .383 .405 r
F P
0 g
s
.52713 .89017 m .46044 .85767 L .48669 .83851 L p .722 .383 .405 r
F P
0 g
s
.81346 .56312 m .82953 .64457 L .79982 .65773 L p .453 .379 .684 r
F P
0 g
s
.80039 .72853 m .79982 .65773 L .82953 .64457 L p .407 .274 .587 r
F P
0 g
s
.79982 .65773 m .80039 .72853 L .77186 .74185 L p .487 .338 .604 r
F P
0 g
s
.2135 .31922 m .15189 .35412 L .14854 .32841 L p .844 .838 .839 r
F P
0 g
s
.14854 .32841 m .21003 .2869 L .2135 .31922 L p .844 .838 .839 r
F P
0 g
s
.2886 .7399 m .21003 .7131 L .2135 .68078 L p .772 .47 .476 r
F P
0 g
s
.15189 .64588 m .2135 .68078 L .21003 .7131 L p .844 .541 .475 r
F P
0 g
s
.2135 .68078 m .15189 .64588 L .15462 .61451 L p .836 .578 .549 r
F P
0 g
s
.62001 .12242 m .57352 .14364 L .54772 .12559 L p .633 .736 .922 r
F P
0 g
s
.57352 .14364 m .62001 .12242 L .64203 .13705 L p .626 .698 .897 r
F P
0 g
s
.77186 .25815 m .76699 .20727 L .78807 .21684 L p .433 .477 .806 r
F P
0 g
s
.78807 .21684 m .80039 .27147 L .77186 .25815 L p .433 .477 .806 r
F P
0 g
s
.57352 .85636 m .62001 .87758 L .60119 .89105 L p .633 .298 .386 r
F P
0 g
s
.60119 .89105 m .54772 .87441 L .57352 .85636 L p .633 .298 .386 r
F P
0 g
s
.76699 .79273 m .77186 .74185 L .80039 .72853 L p .433 .229 .502 r
F P
0 g
s
.77186 .74185 m .76699 .79273 L .74331 .80447 L p .491 .278 .517 r
F P
0 g
s
.113 .58486 m .15462 .61451 L .15189 .64588 L p .897 .638 .538 r
F P
0 g
s
.15462 .61451 m .113 .58486 L .11466 .55847 L p .887 .66 .59 r
F P
0 g
s
.15462 .38549 m .113 .41514 L .11075 .3921 L p .897 .827 .77 r
F P
0 g
s
.11075 .3921 m .15189 .35412 L .15462 .38549 L p .897 .827 .77 r
F P
0 g
s
.56513 .52764 m .55485 .53334 L .55492 .5 L p .173 .129 .564 r
F P
0 g
s
.55492 .5 m .5652 .5 L .56513 .52764 L p .173 .129 .564 r
F P
0 g
s
.5652 .5 m .55492 .5 L .55485 .46666 L p .173 .154 .594 r
F P
0 g
s
.49137 .42978 m .50145 .43583 L .47254 .45244 L p .769 .921 .938 r
F P
0 g
s
.47254 .45244 m .4674 .44354 L .49137 .42978 L p .769 .921 .938 r
F P
0 g
s
.4674 .44354 m .47254 .45244 L .4437 .46917 L p .795 .93 .923 r
F P
0 g
s
.4435 .54258 m .4437 .53083 L .47254 .54756 L p .795 .368 .235 r
F P
0 g
s
.47254 .54756 m .4674 .55646 L .4435 .54258 L p .795 .368 .235 r
F P
0 g
s
.4674 .55646 m .47254 .54756 L .50145 .56417 L p .769 .335 .22 r
F P
0 g
s
.55408 .62048 m .53365 .64493 L .53399 .6139 L p .285 .127 .483 r
F P
0 g
s
.49863 .32898 m .53365 .35507 L .53399 .3861 L p .441 .473 .797 r
F P
0 g
s
.35257 .5867 m .35766 .54332 L .38437 .52752 L p .887 .821 .777 r
F P
0 g
s
.57729 .39293 m .60869 .39839 L .58164 .41362 L p .664 .827 .962 r
F P
0 g
s
.6488 .58432 m .60869 .60161 L .58164 .58638 L p .647 .318 .401 r
F P
0 g
s
.36862 .4866 m .35766 .45668 L .38437 .47248 L p .89 .548 .394 r
F P
0 g
s
.53339 .67027 m .49811 .70129 L .49863 .67102 L p .372 .142 .431 r
F P
0 g
s
.49863 .67102 m .53365 .64493 L .53339 .67027 L p .372 .142 .431 r
F P
0 g
s
.53365 .35507 m .49863 .32898 L .49811 .29871 L p .372 .466 .827 r
F P
0 g
s
.44408 .27105 m .49811 .29871 L .49863 .32898 L p .503 .579 .864 r
F P
0 g
s
.35766 .54332 m .35257 .5867 L .32662 .60228 L p .928 .858 .752 r
F P
0 g
s
.32968 .6629 m .32662 .60228 L .35257 .5867 L p .914 .772 .69 r
F P
0 g
s
.63076 .38595 m .67527 .40099 L .6488 .41568 L p .585 .74 .95 r
F P
0 g
s
.6488 .41568 m .60869 .39839 L .63076 .38595 L p .585 .74 .95 r
F P
0 g
s
.33585 .44378 m .32662 .39772 L .35257 .4133 L p .928 .657 .506 r
F P
0 g
s
.35257 .4133 m .35766 .45668 L .33585 .44378 L p .928 .657 .506 r
F P
0 g
s
.60869 .60161 m .6488 .58432 L .67527 .59901 L p .585 .216 .308 r
F P
0 g
s
.72624 .56605 m .67527 .59901 L .6488 .58432 L p .558 .262 .421 r
F P
0 g
s
.56492 .55416 m .55464 .56537 L .55485 .53334 L p .153 .088 .524 r
F P
0 g
s
.55485 .53334 m .56513 .52764 L .56492 .55416 L p .153 .088 .524 r
F P
0 g
s
.55485 .46666 m .56513 .47236 L .5652 .5 L p .173 .154 .594 r
F P
0 g
s
.56513 .47236 m .55485 .46666 L .55464 .43463 L p .153 .162 .615 r
F P
0 g
s
.4437 .46917 m .4435 .45742 L .4674 .44354 L p .795 .93 .923 r
F P
0 g
s
.4435 .45742 m .4437 .46917 L .41607 .48536 L p .817 .943 .907 r
F P
0 g
s
.51444 .4167 m .52929 .42 L .50145 .43583 L p .738 .916 .953 r
F P
0 g
s
.50145 .43583 m .49137 .42978 L .51444 .4167 L p .738 .916 .953 r
F P
0 g
s
.42064 .52915 m .41607 .51464 L .4437 .53083 L p .817 .392 .232 r
F P
0 g
s
.4437 .53083 m .4435 .54258 L .42064 .52915 L p .817 .392 .232 r
F P
0 g
s
.50145 .56417 m .49137 .57022 L .4674 .55646 L p .769 .335 .22 r
F P
0 g
s
.49137 .57022 m .50145 .56417 L .52929 .58 L p .738 .29 .186 r
F P
0 g
s
.70472 .14542 m .69198 .16747 L .66634 .15227 L p .517 .628 .9 r
F P
0 g
s
.69198 .16747 m .70472 .14542 L .72261 .15546 L p .494 .599 .887 r
F P
0 g
s
.72261 .15546 m .71798 .18208 L .69198 .16747 L p .494 .599 .887 r
F P
0 g
s
.70472 .85458 m .69198 .83253 L .71798 .81792 L p .494 .208 .408 r
F P
0 g
s
.69198 .83253 m .70472 .85458 L .68708 .86506 L p .517 .216 .395 r
F P
0 g
s
.68708 .86506 m .66634 .84773 L .69198 .83253 L p .517 .216 .395 r
F P
0 g
s
.09057 .5 m .11603 .5 L .11569 .52981 L p .931 .75 .635 r
F P
0 g
s
.11603 .5 m .09057 .5 L .09031 .47948 L p .931 .771 .661 r
F P
0 g
s
.09031 .47948 m .11569 .47019 L .11603 .5 L p .931 .771 .661 r
F P
0 g
s
.55464 .43463 m .56492 .44584 L .56513 .47236 L p .153 .162 .615 r
F P
0 g
s
.55464 .56537 m .56492 .55416 L .56465 .57848 L p .111 .027 .472 r
F P
0 g
s
.41607 .48536 m .42064 .47085 L .4435 .45742 L p .817 .943 .907 r
F P
0 g
s
.52929 .42 m .51444 .4167 L .53564 .40477 L p .701 .914 .968 r
F P
0 g
s
.52929 .58 m .51444 .5833 L .49137 .57022 L p .738 .29 .186 r
F P
0 g
s
.41607 .51464 m .42064 .52915 L .3997 .51675 L p .836 .404 .209 r
F P
0 g
s
.44296 .75488 m .36931 .77263 L .37152 .74461 L p .547 .2 .33 r
F P
0 g
s
.37152 .74461 m .44408 .72895 L .44296 .75488 L p .547 .2 .33 r
F P
0 g
s
.30779 .32316 m .32924 .2505 L .3524 .26643 L p .938 .829 .71 r
F P
0 g
s
.3524 .26643 m .32968 .3371 L .30779 .32316 L p .938 .829 .71 r
F P
0 g
s
.32968 .6629 m .3524 .73357 L .32924 .7495 L p .938 .703 .556 r
F P
0 g
s
.74925 .42196 m .80145 .47687 L .77608 .48896 L p .414 .522 .859 r
F P
0 g
s
.77608 .48896 m .72624 .43395 L .74925 .42196 L p .414 .522 .859 r
F P
0 g
s
.72624 .56605 m .77608 .51104 L .80145 .52313 L p .414 .154 .407 r
F P
0 g
s
.44408 .27105 m .37152 .25539 L .36931 .22737 L p .547 .694 .936 r
F P
0 g
s
.68708 .13494 m .66634 .15227 L .64203 .13705 L p .532 .656 .915 r
F P
0 g
s
.66634 .15227 m .68708 .13494 L .70472 .14542 L p .517 .628 .9 r
F P
0 g
s
.71798 .18208 m .72261 .15546 L .74004 .16466 L p .463 .568 .876 r
F P
0 g
s
.74004 .16466 m .74331 .19553 L .71798 .18208 L p .463 .568 .876 r
F P
0 g
s
.72261 .84454 m .71798 .81792 L .74331 .80447 L p .463 .188 .41 r
F P
0 g
s
.71798 .81792 m .72261 .84454 L .70472 .85458 L p .494 .208 .408 r
F P
0 g
s
.66634 .84773 m .68708 .86506 L .6704 .87555 L p .532 .212 .371 r
F P
0 g
s
.6704 .87555 m .64203 .86295 L .66634 .84773 L p .532 .212 .371 r
F P
0 g
s
.09031 .52052 m .11569 .52981 L .11466 .55847 L p .934 .731 .603 r
F P
0 g
s
.11569 .52981 m .09031 .52052 L .09057 .5 L p .931 .75 .635 r
F P
0 g
s
.11569 .47019 m .09031 .47948 L .08957 .45979 L p .934 .795 .683 r
F P
0 g
s
.08957 .45979 m .11466 .44153 L .11569 .47019 L p .934 .795 .683 r
F P
0 g
s
.46044 .14233 m .39794 .19698 L .37583 .18035 L p .817 .872 .887 r
F P
0 g
s
.81346 .43688 m .82953 .35543 L .85233 .36399 L p .327 .242 .605 r
F P
0 g
s
.85233 .36399 m .83891 .44771 L .81346 .43688 L p .327 .242 .605 r
F P
0 g
s
.39794 .80302 m .46044 .85767 L .44162 .87313 L p .817 .461 .384 r
F P
0 g
s
.44162 .87313 m .37583 .81965 L .39794 .80302 L p .817 .461 .384 r
F P
0 g
s
.82953 .64457 m .81346 .56312 L .83891 .55229 L p .327 .293 .667 r
F P
0 g
s
.21003 .7131 m .2886 .7399 L .28526 .76736 L p .763 .392 .353 r
F P
0 g
s
.2886 .2601 m .21003 .2869 L .20605 .26288 L p .763 .854 .918 r
F P
0 g
s
.20605 .26288 m .28526 .23264 L .2886 .2601 L p .763 .854 .918 r
F P
0 g
s
.6704 .12445 m .64203 .13705 L .62001 .12242 L p .538 .684 .933 r
F P
0 g
s
.64203 .13705 m .6704 .12445 L .68708 .13494 L p .532 .656 .915 r
F P
0 g
s
.74331 .19553 m .74004 .16466 L .75629 .17264 L p .42 .533 .866 r
F P
0 g
s
.75629 .17264 m .76699 .20727 L .74331 .19553 L p .42 .533 .866 r
F P
0 g
s
.74004 .83534 m .74331 .80447 L .76699 .79273 L p .42 .153 .4 r
F P
0 g
s
.74331 .80447 m .74004 .83534 L .72261 .84454 L p .463 .188 .41 r
F P
0 g
s
.64203 .86295 m .6704 .87555 L .65536 .88564 L p .538 .194 .333 r
F P
0 g
s
.65536 .88564 m .62001 .87758 L .64203 .86295 L p .538 .194 .333 r
F P
0 g
s
.08957 .54021 m .11466 .55847 L .113 .58486 L p .941 .713 .565 r
F P
0 g
s
.11466 .55847 m .08957 .54021 L .09031 .52052 L p .934 .731 .603 r
F P
0 g
s
.11466 .44153 m .08957 .45979 L .08835 .44173 L p .941 .823 .701 r
F P
0 g
s
.08835 .44173 m .113 .41514 L .11466 .44153 L p .941 .823 .701 r
F P
0 g
s
.46044 .14233 m .52713 .10983 L .54772 .12559 L p .722 .795 .91 r
F P
0 g
s
.60119 .10895 m .54772 .12559 L .52713 .10983 L p .629 .777 .952 r
F P
0 g
s
.54772 .12559 m .60119 .10895 L .62001 .12242 L p .633 .736 .922 r
F P
0 g
s
.80039 .27147 m .78807 .21684 L .80565 .22382 L p .35 .418 .791 r
F P
0 g
s
.80565 .22382 m .82433 .28142 L .80039 .27147 L p .35 .418 .791 r
F P
0 g
s
.54772 .87441 m .60119 .89105 L .58636 .90279 L p .629 .251 .307 r
F P
0 g
s
.58636 .90279 m .52713 .89017 L .54772 .87441 L p .629 .251 .307 r
F P
0 g
s
.82953 .64457 m .82433 .71858 L .80039 .72853 L p .407 .274 .587 r
F P
0 g
s
.78807 .78316 m .80039 .72853 L .82433 .71858 L p .35 .154 .468 r
F P
0 g
s
.80039 .72853 m .78807 .78316 L .76699 .79273 L p .433 .229 .502 r
F P
0 g
s
.15189 .35412 m .11075 .3921 L .10799 .37339 L p .909 .873 .79 r
F P
0 g
s
.10799 .37339 m .14854 .32841 L .15189 .35412 L p .909 .873 .79 r
F P
0 g
s
.21003 .7131 m .14854 .67159 L .15189 .64588 L p .844 .541 .475 r
F P
0 g
s
.11075 .6079 m .15189 .64588 L .14854 .67159 L p .909 .61 .468 r
F P
0 g
s
.15189 .64588 m .11075 .6079 L .113 .58486 L p .897 .638 .538 r
F P
0 g
s
.49768 .72366 m .44296 .75488 L .44408 .72895 L p .412 .094 .314 r
F P
0 g
s
.44408 .72895 m .49811 .70129 L .49768 .72366 L p .412 .094 .314 r
F P
0 g
s
.32662 .60228 m .32968 .6629 L .30779 .67684 L p .967 .808 .634 r
F P
0 g
s
.32924 .7495 m .30779 .67684 L .32968 .6629 L p .938 .703 .556 r
F P
0 g
s
.49811 .29871 m .44408 .27105 L .44296 .24512 L p .412 .579 .907 r
F P
0 g
s
.36931 .22737 m .44296 .24512 L .44408 .27105 L p .547 .694 .936 r
F P
0 g
s
.69485 .39018 m .74925 .42196 L .72624 .43395 L p .453 .631 .931 r
F P
0 g
s
.72624 .43395 m .67527 .40099 L .69485 .39018 L p .453 .631 .931 r
F P
0 g
s
.30746 .38616 m .30779 .32316 L .32968 .3371 L p .967 .77 .587 r
F P
0 g
s
.32968 .3371 m .32662 .39772 L .30746 .38616 L p .967 .77 .587 r
F P
0 g
s
.67527 .59901 m .72624 .56605 L .74925 .57804 L p .453 .108 .29 r
F P
0 g
s
.80145 .52313 m .74925 .57804 L .72624 .56605 L p .414 .154 .407 r
F P
0 g
s
.55391 .64131 m .53339 .67027 L .53365 .64493 L p .194 .011 .39 r
F P
0 g
s
.53365 .64493 m .55408 .62048 L .55391 .64131 L p .194 .011 .39 r
F P
0 g
s
.55408 .37952 m .53365 .35507 L .53339 .32973 L p .195 .307 .752 r
F P
0 g
s
.49811 .29871 m .53339 .32973 L .53365 .35507 L p .372 .466 .827 r
F P
0 g
s
.59542 .38266 m .63076 .38595 L .60869 .39839 L p .602 .832 .987 r
F P
0 g
s
.60869 .39839 m .57729 .39293 L .59542 .38266 L p .602 .832 .987 r
F P
0 g
s
.36862 .5134 m .35766 .54332 L .33585 .55622 L p .916 .94 .806 r
F P
0 g
s
.32662 .60228 m .33585 .55622 L .35766 .54332 L p .928 .858 .752 r
F P
0 g
s
.35067 .47603 m .33585 .44378 L .35766 .45668 L p .916 .555 .335 r
F P
0 g
s
.35766 .45668 m .36862 .4866 L .35067 .47603 L p .916 .555 .335 r
F P
0 g
s
.57729 .60707 m .60869 .60161 L .63076 .61405 L p .602 .152 .154 r
F P
0 g
s
.67527 .59901 m .63076 .61405 L .60869 .60161 L p .585 .216 .308 r
F P
0 g
s
.56884 .523 m .56513 .52764 L .5652 .5 L p 0 0 .363 r
F P
0 g
s
.5652 .5 m .56891 .5 L .56884 .523 L p 0 0 .363 r
F P
0 g
s
.56891 .5 m .5652 .5 L .56513 .47236 L p 0 0 .384 r
F P
0 g
s
.4855 .42888 m .49137 .42978 L .4674 .44354 L p .665 .971 .899 r
F P
0 g
s
.4674 .44354 m .46554 .44032 L .4855 .42888 L p .665 .971 .899 r
F P
0 g
s
.46554 .44032 m .4674 .44354 L .4435 .45742 L p .683 .978 .888 r
F P
0 g
s
.44566 .54812 m .4435 .54258 L .4674 .55646 L p .683 .138 0 r
F P
0 g
s
.4674 .55646 m .46554 .55968 L .44566 .54812 L p .683 .138 0 r
F P
0 g
s
.46554 .55968 m .4674 .55646 L .49137 .57022 L p .665 .114 0 r
F P
0 g
s
.56866 .54506 m .56492 .55416 L .56513 .52764 L p 0 0 .33 r
F P
0 g
s
.56513 .52764 m .56884 .523 L .56866 .54506 L p 0 0 .33 r
F P
0 g
s
.56513 .47236 m .56884 .477 L .56891 .5 L p 0 0 .384 r
F P
0 g
s
.56884 .477 m .56513 .47236 L .56492 .44584 L p 0 0 .393 r
F P
0 g
s
.4435 .45742 m .44566 .45188 L .46554 .44032 L p .683 .978 .888 r
F P
0 g
s
.44566 .45188 m .4435 .45742 L .42064 .47085 L p .692 .982 .871 r
F P
0 g
s
.5047 .41801 m .51444 .4167 L .49137 .42978 L p .638 .963 .903 r
F P
0 g
s
.49137 .42978 m .4855 .42888 L .5047 .41801 L p .638 .963 .903 r
F P
0 g
s
.49137 .57022 m .4855 .57112 L .46554 .55968 L p .665 .114 0 r
F P
0 g
s
.4855 .57112 m .49137 .57022 L .51444 .5833 L p .638 .079 0 r
F P
0 g
s
.42665 .53693 m .42064 .52915 L .4435 .54258 L p .692 .149 0 r
F P
0 g
s
.4435 .54258 m .44566 .54812 L .42665 .53693 L p .692 .149 0 r
F P
0 g
s
.37583 .18035 m .44162 .12687 L .46044 .14233 L p .817 .872 .887 r
F P
0 g
s
.52713 .10983 m .46044 .14233 L .44162 .12687 L p .722 .859 .946 r
F P
0 g
s
.82953 .35543 m .82433 .28142 L .8426 .28752 L p .279 .287 .69 r
F P
0 g
s
.8426 .28752 m .85233 .36399 L .82953 .35543 L p .279 .287 .69 r
F P
0 g
s
.83891 .55229 m .85233 .63601 L .82953 .64457 L p .327 .293 .667 r
F P
0 g
s
.82433 .71858 m .82953 .64457 L .85233 .63601 L p .279 .168 .543 r
F P
0 g
s
.46044 .85767 m .52713 .89017 L .51271 .90294 L p .722 .321 .287 r
F P
0 g
s
.51271 .90294 m .44162 .87313 L .46044 .85767 L p .722 .321 .287 r
F P
0 g
s
.28526 .76736 m .20605 .73712 L .21003 .7131 L p .763 .392 .353 r
F P
0 g
s
.14854 .67159 m .21003 .7131 L .20605 .73712 L p .849 .484 .361 r
F P
0 g
s
.21003 .2869 m .14854 .32841 L .14469 .30954 L p .849 .903 .873 r
F P
0 g
s
.14469 .30954 m .20605 .26288 L .21003 .2869 L p .849 .903 .873 r
F P
0 g
s
.65536 .11436 m .62001 .12242 L .60119 .10895 L p .533 .712 .954 r
F P
0 g
s
.62001 .12242 m .65536 .11436 L .6704 .12445 L p .538 .684 .933 r
F P
0 g
s
.76699 .20727 m .75629 .17264 L .7707 .17906 L p .363 .492 .856 r
F P
0 g
s
.7707 .17906 m .78807 .21684 L .76699 .20727 L p .363 .492 .856 r
F P
0 g
s
.75629 .82736 m .76699 .79273 L .78807 .78316 L p .363 .1 .375 r
F P
0 g
s
.76699 .79273 m .75629 .82736 L .74004 .83534 L p .42 .153 .4 r
F P
0 g
s
.62001 .87758 m .65536 .88564 L .64259 .8949 L p .533 .159 .276 r
F P
0 g
s
.64259 .8949 m .60119 .89105 L .62001 .87758 L p .533 .159 .276 r
F P
0 g
s
.08835 .55827 m .113 .58486 L .11075 .6079 L p .95 .695 .517 r
F P
0 g
s
.113 .58486 m .08835 .55827 L .08957 .54021 L p .941 .713 .565 r
F P
0 g
s
.113 .41514 m .08835 .44173 L .08671 .42603 L p .95 .856 .714 r
F P
0 g
s
.08671 .42603 m .11075 .3921 L .113 .41514 L p .95 .856 .714 r
F P
0 g
s
.5684 .56526 m .56465 .57848 L .56492 .55416 L p 0 0 .286 r
F P
0 g
s
.56492 .55416 m .56866 .54506 L .5684 .56526 L p 0 0 .286 r
F P
0 g
s
.56492 .44584 m .56866 .45494 L .56884 .477 L p 0 0 .393 r
F P
0 g
s
.56866 .45494 m .56492 .44584 L .56465 .42152 L p 0 0 .389 r
F P
0 g
s
.42064 .47085 m .42665 .46307 L .44566 .45188 L p .692 .982 .871 r
F P
0 g
s
.42665 .46307 m .42064 .47085 L .3997 .48325 L p .692 .982 .848 r
F P
0 g
s
.52231 .40813 m .53564 .40477 L .51444 .4167 L p .602 .951 .899 r
F P
0 g
s
.51444 .4167 m .5047 .41801 L .52231 .40813 L p .602 .951 .899 r
F P
0 g
s
.51444 .5833 m .5047 .58199 L .4855 .57112 L p .638 .079 0 r
F P
0 g
s
.5047 .58199 m .51444 .5833 L .53564 .59523 L p .602 .033 0 r
F P
0 g
s
.40928 .52661 m .3997 .51675 L .42064 .52915 L p .691 .148 0 r
F P
0 g
s
.42064 .52915 m .42665 .53693 L .40928 .52661 L p .691 .148 0 r
F P
0 g
s
.5333 .6888 m .49768 .72366 L .49811 .70129 L p .248 0 .289 r
F P
0 g
s
.49811 .70129 m .53339 .67027 L .5333 .6888 L p .248 0 .289 r
F P
0 g
s
.53339 .32973 m .49811 .29871 L .49768 .27634 L p .248 .43 .845 r
F P
0 g
s
.44296 .24512 m .49768 .27634 L .49811 .29871 L p .412 .579 .907 r
F P
0 g
s
.33585 .55622 m .32662 .60228 L .30746 .61384 L p .967 .901 .704 r
F P
0 g
s
.30779 .67684 m .30746 .61384 L .32662 .60228 L p .967 .808 .634 r
F P
0 g
s
.64686 .37676 m .69485 .39018 L .67527 .40099 L p .485 .735 .982 r
F P
0 g
s
.67527 .40099 m .63076 .38595 L .64686 .37676 L p .485 .735 .982 r
F P
0 g
s
.31985 .43444 m .30746 .38616 L .32662 .39772 L p .967 .678 .43 r
F P
0 g
s
.32662 .39772 m .33585 .44378 L .31985 .43444 L p .967 .678 .43 r
F P
0 g
s
.63076 .61405 m .67527 .59901 L .69485 .60982 L p .485 .057 .152 r
F P
0 g
s
.74925 .57804 m .69485 .60982 L .67527 .59901 L p .453 .108 .29 r
F P
0 g
s
.53339 .32973 m .55391 .35869 L .55408 .37952 L p .195 .307 .752 r
F P
0 g
s
.56422 .6167 m .55391 .64131 L .55408 .62048 L p 0 0 .312 r
F P
0 g
s
.33585 .55622 m .35067 .52397 L .36862 .5134 L p .916 .94 .806 r
F P
0 g
s
.56895 .38603 m .59542 .38266 L .57729 .39293 L p .59 .908 .981 r
F P
0 g
s
.36683 .49727 m .35067 .47603 L .36862 .4866 L p .845 .384 .085 r
F P
0 g
s
.63076 .61405 m .59542 .61734 L .57729 .60707 L p .602 .152 .154 r
F P
0 g
s
.56465 .42152 m .5684 .43474 L .56866 .45494 L p 0 0 .389 r
F P
0 g
s
.5684 .43474 m .56465 .42152 L .56439 .40037 L p 0 0 .371 r
F P
0 g
s
.56816 .58276 m .56439 .59963 L .56465 .57848 L p 0 0 .232 r
F P
0 g
s
.56465 .57848 m .5684 .56526 L .56816 .58276 L p 0 0 .232 r
F P
0 g
s
.3997 .48325 m .40928 .47339 L .42665 .46307 L p .692 .982 .848 r
F P
0 g
s
.40928 .47339 m .3997 .48325 L .38153 .49405 L p .68 .976 .817 r
F P
0 g
s
.5376 .39959 m .55408 .39442 L .53564 .40477 L p .559 .934 .887 r
F P
0 g
s
.53564 .40477 m .52231 .40813 L .5376 .39959 L p .559 .934 .887 r
F P
0 g
s
.39425 .51764 m .38153 .50595 L .3997 .51675 L p .679 .133 0 r
F P
0 g
s
.3997 .51675 m .40928 .52661 L .39425 .51764 L p .679 .133 0 r
F P
0 g
s
.53564 .59523 m .52231 .59187 L .5047 .58199 L p .602 .033 0 r
F P
0 g
s
.52231 .59187 m .53564 .59523 L .55408 .60558 L p .559 0 0 r
F P
0 g
s
.56842 .51937 m .56884 .523 L .56891 .5 L p .768 .628 .065 r
F P
0 g
s
.56891 .5 m .56847 .5 L .56842 .51937 L p .768 .628 .065 r
F P
0 g
s
.56847 .5 m .56891 .5 L .56884 .477 L p .768 .627 .063 r
F P
0 g
s
.48257 .43106 m .4855 .42888 L .46554 .44032 L p 0 0 0 r
F P
0 g
s
.46554 .44032 m .46576 .4407 L .48257 .43106 L p 0 0 0 r
F P
0 g
s
.46576 .4407 m .46554 .44032 L .44566 .45188 L p 0 0 0 r
F P
0 g
s
.44901 .54957 m .44566 .54812 L .46554 .55968 L p 0 .262 .674 r
F P
0 g
s
.46554 .55968 m .46576 .5593 L .44901 .54957 L p 0 .262 .674 r
F P
0 g
s
.46576 .5593 m .46554 .55968 L .4855 .57112 L p 0 .263 .674 r
F P
0 g
s
.56827 .53793 m .56866 .54506 L .56884 .523 L p .769 .629 .066 r
F P
0 g
s
.56884 .523 m .56842 .51937 L .56827 .53793 L p .769 .629 .066 r
F P
0 g
s
.56884 .477 m .56842 .48063 L .56847 .5 L p .768 .627 .063 r
F P
0 g
s
.56842 .48063 m .56884 .477 L .56866 .45494 L p .768 .626 .063 r
F P
0 g
s
.44566 .45188 m .44901 .45043 L .46576 .4407 L p 0 0 0 r
F P
0 g
s
.44901 .45043 m .44566 .45188 L .42665 .46307 L p 0 0 0 r
F P
0 g
s
.49872 .42191 m .5047 .41801 L .4855 .42888 L p 0 0 0 r
F P
0 g
s
.4855 .42888 m .48257 .43106 L .49872 .42191 L p 0 0 0 r
F P
0 g
s
.43302 .54016 m .42665 .53693 L .44566 .54812 L p 0 .262 .674 r
F P
0 g
s
.44566 .54812 m .44901 .54957 L .43302 .54016 L p 0 .262 .674 r
F P
0 g
s
.4855 .57112 m .48257 .56894 L .46576 .5593 L p 0 .263 .674 r
F P
0 g
s
.48257 .56894 m .4855 .57112 L .5047 .58199 L p 0 .264 .675 r
F P
0 g
s
.82433 .28142 m .80565 .22382 L .81895 .22785 L p .226 .333 .764 r
F P
0 g
s
.81895 .22785 m .8426 .28752 L .82433 .28142 L p .226 .333 .764 r
F P
0 g
s
.44162 .12687 m .51271 .09706 L .52713 .10983 L p .722 .859 .946 r
F P
0 g
s
.58636 .09721 m .52713 .10983 L .51271 .09706 L p .604 .82 .983 r
F P
0 g
s
.52713 .10983 m .58636 .09721 L .60119 .10895 L p .629 .777 .952 r
F P
0 g
s
.52713 .89017 m .58636 .90279 L .57621 .9123 L p .604 .167 .183 r
F P
0 g
s
.57621 .9123 m .51271 .90294 L .52713 .89017 L p .604 .167 .183 r
F P
0 g
s
.85233 .63601 m .8426 .71248 L .82433 .71858 L p .279 .168 .543 r
F P
0 g
s
.80565 .77618 m .82433 .71858 L .8426 .71248 L p .226 .037 .402 r
F P
0 g
s
.82433 .71858 m .80565 .77618 L .78807 .78316 L p .35 .154 .468 r
F P
0 g
s
.20605 .73712 m .14469 .69046 L .14854 .67159 L p .849 .484 .361 r
F P
0 g
s
.10799 .62661 m .14854 .67159 L .14469 .69046 L p .918 .571 .364 r
F P
0 g
s
.14854 .67159 m .10799 .62661 L .11075 .6079 L p .909 .61 .468 r
F P
0 g
s
.14854 .32841 m .10799 .37339 L .10484 .35985 L p .918 .928 .801 r
F P
0 g
s
.10484 .35985 m .14469 .30954 L .14854 .32841 L p .918 .928 .801 r
F P
0 g
s
.71172 .13328 m .70472 .14542 L .68708 .13494 L p .418 .613 .93 r
F P
0 g
s
.70472 .14542 m .71172 .13328 L .72319 .13971 L p .4 .589 .919 r
F P
0 g
s
.72319 .13971 m .72261 .15546 L .70472 .14542 L p .4 .589 .919 r
F P
0 g
s
.71172 .86672 m .70472 .85458 L .72261 .84454 L p .4 .064 .276 r
F P
0 g
s
.70472 .85458 m .71172 .86672 L .70042 .87343 L p .418 .07 .265 r
F P
0 g
s
.70042 .87343 m .68708 .86506 L .70472 .85458 L p .418 .07 .265 r
F P
0 g
s
.07655 .5 m .09057 .5 L .09031 .52052 L p .975 .788 .587 r
F P
0 g
s
.09057 .5 m .07655 .5 L .07639 .48686 L p .975 .805 .608 r
F P
0 g
s
.07639 .48686 m .09031 .47948 L .09057 .5 L p .975 .805 .608 r
F P
0 g
s
.78807 .21684 m .7707 .17906 L .78265 .18366 L p .283 .441 .842 r
F P
0 g
s
.78265 .18366 m .80565 .22382 L .78807 .21684 L p .283 .441 .842 r
F P
0 g
s
.64259 .1051 m .60119 .10895 L .58636 .09721 L p .514 .738 .976 r
F P
0 g
s
.60119 .10895 m .64259 .1051 L .65536 .11436 L p .533 .712 .954 r
F P
0 g
s
.60119 .89105 m .64259 .8949 L .63264 .90295 L p .514 .101 .195 r
F P
0 g
s
.63264 .90295 m .58636 .90279 L .60119 .89105 L p .514 .101 .195 r
F P
0 g
s
.7707 .82094 m .78807 .78316 L .80565 .77618 L p .283 .021 .328 r
F P
0 g
s
.78807 .78316 m .7707 .82094 L .75629 .82736 L p .363 .1 .375 r
F P
0 g
s
.11075 .3921 m .08671 .42603 L .08471 .41339 L p .959 .892 .718 r
F P
0 g
s
.08471 .41339 m .10799 .37339 L .11075 .3921 L p .959 .892 .718 r
F P
0 g
s
.08671 .57397 m .11075 .6079 L .10799 .62661 L p .959 .674 .452 r
F P
0 g
s
.11075 .6079 m .08671 .57397 L .08835 .55827 L p .95 .695 .517 r
F P
0 g
s
.72261 .15546 m .72319 .13971 L .73435 .14558 L p .372 .563 .91 r
F P
0 g
s
.73435 .14558 m .74004 .16466 L .72261 .15546 L p .372 .563 .91 r
F P
0 g
s
.70042 .12657 m .68708 .13494 L .6704 .12445 L p .427 .634 .942 r
F P
0 g
s
.68708 .13494 m .70042 .12657 L .71172 .13328 L p .418 .613 .93 r
F P
0 g
s
.68708 .86506 m .70042 .87343 L .68976 .88016 L p .427 .063 .242 r
F P
0 g
s
.68976 .88016 m .6704 .87555 L .68708 .86506 L p .427 .063 .242 r
F P
0 g
s
.09031 .47948 m .07639 .48686 L .07589 .47426 L p .977 .824 .624 r
F P
0 g
s
.07589 .47426 m .08957 .45979 L .09031 .47948 L p .977 .824 .624 r
F P
0 g
s
.72319 .86029 m .72261 .84454 L .74004 .83534 L p .372 .044 .274 r
F P
0 g
s
.72261 .84454 m .72319 .86029 L .71172 .86672 L p .4 .064 .276 r
F P
0 g
s
.07639 .51314 m .09031 .52052 L .08957 .54021 L p .977 .772 .56 r
F P
0 g
s
.09031 .52052 m .07639 .51314 L .07655 .5 L p .975 .788 .587 r
F P
0 g
s
.55391 .35869 m .53339 .32973 L .5333 .3112 L p .046 .236 .735 r
F P
0 g
s
.49768 .27634 m .5333 .3112 L .53339 .32973 L p .248 .43 .845 r
F P
0 g
s
.55391 .6564 m .5333 .6888 L .53339 .67027 L p .046 0 .25 r
F P
0 g
s
.53339 .67027 m .55391 .64131 L .55391 .6564 L p .046 0 .25 r
F P
0 g
s
.35067 .52397 m .33585 .55622 L .31985 .56556 L p .925 .972 .757 r
F P
0 g
s
.30746 .61384 m .31985 .56556 L .33585 .55622 L p .967 .901 .704 r
F P
0 g
s
.60849 .37511 m .64686 .37676 L .63076 .38595 L p .505 .827 1 r
F P
0 g
s
.63076 .38595 m .59542 .38266 L .60849 .37511 L p .505 .827 1 r
F P
0 g
s
.3376 .46849 m .31985 .43444 L .33585 .44378 L p .925 .539 .227 r
F P
0 g
s
.33585 .44378 m .35067 .47603 L .3376 .46849 L p .925 .539 .227 r
F P
0 g
s
.59542 .61734 m .63076 .61405 L .64686 .62324 L p .505 0 0 r
F P
0 g
s
.69485 .60982 m .64686 .62324 L .63076 .61405 L p .485 .057 .152 r
F P
0 g
s
.56866 .45494 m .56827 .46207 L .56842 .48063 L p .768 .626 .063 r
F P
0 g
s
.56827 .46207 m .56866 .45494 L .5684 .43474 L p .767 .626 .062 r
F P
0 g
s
.56806 .5549 m .5684 .56526 L .56866 .54506 L p .767 .627 .064 r
F P
0 g
s
.56866 .54506 m .56827 .53793 L .56806 .5549 L p .767 .627 .064 r
F P
0 g
s
.42665 .46307 m .43302 .45984 L .44901 .45043 L p 0 0 0 r
F P
0 g
s
.43302 .45984 m .42665 .46307 L .40928 .47339 L p 0 0 0 r
F P
0 g
s
.51351 .4136 m .52231 .40813 L .5047 .41801 L p 0 0 0 r
F P
0 g
s
.5047 .41801 m .49872 .42191 L .51351 .4136 L p 0 0 0 r
F P
0 g
s
.41842 .53149 m .40928 .52661 L .42665 .53693 L p 0 .261 .673 r
F P
0 g
s
.42665 .53693 m .43302 .54016 L .41842 .53149 L p 0 .261 .673 r
F P
0 g
s
.5047 .58199 m .49872 .57809 L .48257 .56894 L p 0 .264 .675 r
F P
0 g
s
.49872 .57809 m .5047 .58199 L .52231 .59187 L p 0 .262 .673 r
F P
0 g
s
.68976 .11984 m .6704 .12445 L .65536 .11436 L p .426 .653 .954 r
F P
0 g
s
.6704 .12445 m .68976 .11984 L .70042 .12657 L p .427 .634 .942 r
F P
0 g
s
.74004 .16466 m .73435 .14558 L .74474 .15065 L p .332 .533 .9 r
F P
0 g
s
.74474 .15065 m .75629 .17264 L .74004 .16466 L p .332 .533 .9 r
F P
0 g
s
.73435 .85442 m .74004 .83534 L .75629 .82736 L p .332 .01 .259 r
F P
0 g
s
.74004 .83534 m .73435 .85442 L .72319 .86029 L p .372 .044 .274 r
F P
0 g
s
.07589 .52574 m .08957 .54021 L .08835 .55827 L p .981 .757 .526 r
F P
0 g
s
.08957 .54021 m .07589 .52574 L .07639 .51314 L p .977 .772 .56 r
F P
0 g
s
.6704 .87555 m .68976 .88016 L .68018 .88662 L p .426 .042 .205 r
F P
0 g
s
.68018 .88662 m .65536 .88564 L .6704 .87555 L p .426 .042 .205 r
F P
0 g
s
.08957 .45979 m .07589 .47426 L .07509 .46273 L p .981 .845 .634 r
F P
0 g
s
.07509 .46273 m .08835 .44173 L .08957 .45979 L p .981 .845 .634 r
F P
0 g
s
.30779 .67684 m .32924 .7495 L .31552 .76011 L p .982 .701 .401 r
F P
0 g
s
.74925 .57804 m .80145 .52313 L .8175 .52971 L p .189 0 .191 r
F P
0 g
s
.76341 .41503 m .8175 .47029 L .80145 .47687 L p .189 .427 .859 r
F P
0 g
s
.80145 .47687 m .74925 .42196 L .76341 .41503 L p .189 .427 .859 r
F P
0 g
s
.2947 .31436 m .31552 .23989 L .32924 .2505 L p .982 .903 .649 r
F P
0 g
s
.32924 .2505 m .30779 .32316 L .2947 .31436 L p .982 .903 .649 r
F P
0 g
s
.44188 .77061 m .36698 .78982 L .36931 .77263 L p .404 0 .067 r
F P
0 g
s
.36931 .77263 m .44296 .75488 L .44188 .77061 L p .404 0 .067 r
F P
0 g
s
.44296 .24512 m .36931 .22737 L .36698 .21018 L p .404 .704 .983 r
F P
0 g
s
.44162 .12687 m .37583 .18035 L .36311 .1688 L p .816 .963 .904 r
F P
0 g
s
.83891 .44771 m .85233 .36399 L .86703 .36744 L p .089 .027 .484 r
F P
0 g
s
.86703 .36744 m .85527 .45295 L .83891 .44771 L p .089 .027 .484 r
F P
0 g
s
.20605 .73712 m .28526 .76736 L .28162 .78415 L p .718 .243 .121 r
F P
0 g
s
.85233 .63601 m .83891 .55229 L .85527 .54705 L p .089 .119 .598 r
F P
0 g
s
.37583 .81965 m .44162 .87313 L .43129 .88414 L p .816 .37 .178 r
F P
0 g
s
.43129 .88414 m .36311 .8312 L .37583 .81965 L p .816 .37 .178 r
F P
0 g
s
.28526 .23264 m .20605 .26288 L .20168 .24842 L p .718 .929 .961 r
F P
0 g
s
.20168 .24842 m .28162 .21585 L .28526 .23264 L p .718 .929 .961 r
F P
0 g
s
.56439 .59963 m .56816 .58276 L .568 .59684 L p 0 0 .169 r
F P
0 g
s
.56439 .40037 m .56816 .41724 L .5684 .43474 L p 0 0 .371 r
F P
0 g
s
.38153 .49405 m .39425 .48236 L .40928 .47339 L p .68 .976 .817 r
F P
0 g
s
.55408 .39442 m .5376 .39959 L .54987 .39269 L p .508 .912 .863 r
F P
0 g
s
.38153 .50595 m .39425 .51764 L .38214 .51047 L p .655 .107 0 r
F P
0 g
s
.55408 .60558 m .5376 .60041 L .52231 .59187 L p .559 0 0 r
F P
0 g
s
.56787 .56957 m .56816 .58276 L .5684 .56526 L p .762 .621 .055 r
F P
0 g
s
.5684 .56526 m .56806 .5549 L .56787 .56957 L p .762 .621 .055 r
F P
0 g
s
.5684 .43474 m .56806 .4451 L .56827 .46207 L p .767 .626 .062 r
F P
0 g
s
.56806 .4451 m .5684 .43474 L .56816 .41724 L p .761 .623 .058 r
F P
0 g
s
.40928 .47339 m .41842 .46851 L .43302 .45984 L p 0 0 0 r
F P
0 g
s
.41842 .46851 m .40928 .47339 L .39425 .48236 L p 0 0 0 r
F P
0 g
s
.52632 .40644 m .5376 .39959 L .52231 .40813 L p 0 0 0 r
F P
0 g
s
.52231 .40813 m .51351 .4136 L .52632 .40644 L p 0 0 0 r
F P
0 g
s
.40582 .52399 m .39425 .51764 L .40928 .52661 L p 0 .259 .668 r
F P
0 g
s
.40928 .52661 m .41842 .53149 L .40582 .52399 L p 0 .259 .668 r
F P
0 g
s
.52231 .59187 m .51351 .5864 L .49872 .57809 L p 0 .262 .673 r
F P
0 g
s
.51351 .5864 m .52231 .59187 L .5376 .60041 L p 0 .255 .666 r
F P
0 g
s
.56541 .51661 m .56842 .51937 L .56847 .5 L p .993 .804 .43 r
F P
0 g
s
.56847 .5 m .56545 .5 L .56541 .51661 L p .993 .804 .43 r
F P
0 g
s
.56545 .5 m .56847 .5 L .56842 .48063 L p .993 .818 .447 r
F P
0 g
s
.48167 .43505 m .48257 .43106 L .46576 .4407 L p .154 0 0 r
F P
0 g
s
.46576 .4407 m .46728 .44332 L .48167 .43505 L p .154 0 0 r
F P
0 g
s
.46728 .44332 m .46576 .4407 L .44901 .45043 L p .168 0 0 r
F P
0 g
s
.45291 .54835 m .44901 .54957 L .46576 .5593 L p .168 .533 .923 r
F P
0 g
s
.46576 .5593 m .46728 .55668 L .45291 .54835 L p .168 .533 .923 r
F P
0 g
s
.46728 .55668 m .46576 .5593 L .48257 .56894 L p .153 .514 .915 r
F P
0 g
s
.30746 .61384 m .30779 .67684 L .2947 .68564 L p .999 .83 .504 r
F P
0 g
s
.31552 .76011 m .2947 .68564 L .30779 .67684 L p .982 .701 .401 r
F P
0 g
s
.49743 .73698 m .44188 .77061 L .44296 .75488 L p .215 0 .051 r
F P
0 g
s
.44296 .75488 m .49768 .72366 L .49743 .73698 L p .215 0 .051 r
F P
0 g
s
.29606 .37929 m .2947 .31436 L .30779 .32316 L p .999 .802 .469 r
F P
0 g
s
.30779 .32316 m .30746 .38616 L .29606 .37929 L p .999 .802 .469 r
F P
0 g
s
.69485 .60982 m .74925 .57804 L .76341 .58497 L p .245 0 .034 r
F P
0 g
s
.8175 .52971 m .76341 .58497 L .74925 .57804 L p .189 0 .191 r
F P
0 g
s
.49768 .27634 m .44296 .24512 L .44188 .22939 L p .215 .531 .922 r
F P
0 g
s
.36698 .21018 m .44188 .22939 L .44296 .24512 L p .404 .704 .983 r
F P
0 g
s
.70651 .38374 m .76341 .41503 L .74925 .42196 L p .245 .57 .939 r
F P
0 g
s
.74925 .42196 m .69485 .39018 L .70651 .38374 L p .245 .57 .939 r
F P
0 g
s
.56533 .5325 m .56827 .53793 L .56842 .51937 L p .991 .788 .404 r
F P
0 g
s
.56842 .51937 m .56541 .51661 L .56533 .5325 L p .991 .788 .404 r
F P
0 g
s
.56842 .48063 m .56541 .48339 L .56545 .5 L p .993 .818 .447 r
F P
0 g
s
.56541 .48339 m .56842 .48063 L .56827 .46207 L p .991 .83 .456 r
F P
0 g
s
.49548 .42717 m .49872 .42191 L .48257 .43106 L p .127 0 0 r
F P
0 g
s
.48257 .43106 m .48167 .43505 L .49548 .42717 L p .127 0 0 r
F P
0 g
s
.44901 .45043 m .45291 .45165 L .46728 .44332 L p .168 0 0 r
F P
0 g
s
.45291 .45165 m .44901 .45043 L .43302 .45984 L p .172 0 0 r
F P
0 g
s
.43919 .54033 m .43302 .54016 L .44901 .54957 L p .172 .547 .929 r
F P
0 g
s
.44901 .54957 m .45291 .54835 L .43919 .54033 L p .172 .547 .929 r
F P
0 g
s
.48257 .56894 m .48167 .56495 L .46728 .55668 L p .153 .514 .915 r
F P
0 g
s
.48167 .56495 m .48257 .56894 L .49872 .57809 L p .127 .49 .903 r
F P
0 g
s
.68018 .11338 m .65536 .11436 L .64259 .1051 L p .413 .669 .966 r
F P
0 g
s
.65536 .11436 m .68018 .11338 L .68976 .11984 L p .426 .653 .954 r
F P
0 g
s
.75629 .17264 m .74474 .15065 L .75391 .1547 L p .28 .498 .89 r
F P
0 g
s
.75391 .1547 m .7707 .17906 L .75629 .17264 L p .28 .498 .89 r
F P
0 g
s
.74474 .84935 m .75629 .82736 L .7707 .82094 L p .28 0 .228 r
F P
0 g
s
.75629 .82736 m .74474 .84935 L .73435 .85442 L p .332 .01 .259 r
F P
0 g
s
.07509 .53727 m .08835 .55827 L .08671 .57397 L p .985 .742 .482 r
F P
0 g
s
.08835 .55827 m .07509 .53727 L .07589 .52574 L p .981 .757 .526 r
F P
0 g
s
.65536 .88564 m .68018 .88662 L .67208 .89254 L p .413 .004 .152 r
F P
0 g
s
.67208 .89254 m .64259 .8949 L .65536 .88564 L p .413 .004 .152 r
F P
0 g
s
.08835 .44173 m .07509 .46273 L .07401 .45276 L p .985 .867 .636 r
F P
0 g
s
.07401 .45276 m .08671 .42603 L .08835 .44173 L p .985 .867 .636 r
F P
0 g
s
.56422 .3833 m .55391 .35869 L .55391 .3436 L p 0 0 .556 r
F P
0 g
s
.5333 .3112 m .55391 .3436 L .55391 .35869 L p .046 .236 .735 r
F P
0 g
s
.56424 .62895 m .55391 .6564 L .55391 .64131 L p 0 0 .19 r
F P
0 g
s
.55391 .64131 m .56422 .6167 L .56424 .62895 L p 0 0 .19 r
F P
0 g
s
.36683 .50273 m .35067 .52397 L .3376 .53151 L p .818 .997 .777 r
F P
0 g
s
.31985 .56556 m .3376 .53151 L .35067 .52397 L p .925 .972 .757 r
F P
0 g
s
.57956 .37989 m .60849 .37511 L .59542 .38266 L p .5 .888 .96 r
F P
0 g
s
.59542 .38266 m .56895 .38603 L .57956 .37989 L p .5 .888 .96 r
F P
0 g
s
.56895 .61397 m .59542 .61734 L .60849 .62489 L p .5 0 0 r
F P
0 g
s
.64686 .62324 m .60849 .62489 L .59542 .61734 L p .505 0 0 r
F P
0 g
s
.35621 .49115 m .3376 .46849 L .35067 .47603 L p .818 .338 0 r
F P
0 g
s
.35067 .47603 m .36683 .49727 L .35621 .49115 L p .818 .338 0 r
F P
0 g
s
.85233 .36399 m .8426 .28752 L .85427 .28939 L p .053 .113 .608 r
F P
0 g
s
.85427 .28939 m .86703 .36744 L .85233 .36399 L p .053 .113 .608 r
F P
0 g
s
.44162 .87313 m .51271 .90294 L .50526 .91211 L p .683 .191 .073 r
F P
0 g
s
.50526 .91211 m .43129 .88414 L .44162 .87313 L p .683 .191 .073 r
F P
0 g
s
.36311 .1688 m .43129 .11586 L .44162 .12687 L p .816 .963 .904 r
F P
0 g
s
.51271 .09706 m .44162 .12687 L .43129 .11586 L p .683 .924 .971 r
F P
0 g
s
.20605 .26288 m .14469 .30954 L .14048 .2985 L p .831 .975 .886 r
F P
0 g
s
.14048 .2985 m .20168 .24842 L .20605 .26288 L p .831 .975 .886 r
F P
0 g
s
.85527 .54705 m .86703 .63256 L .85233 .63601 L p .089 .119 .598 r
F P
0 g
s
.8426 .71248 m .85233 .63601 L .86703 .63256 L p .053 0 .437 r
F P
0 g
s
.28162 .78415 m .20168 .75158 L .20605 .73712 L p .718 .243 .121 r
F P
0 g
s
.14469 .69046 m .20605 .73712 L .20168 .75158 L p .831 .382 .159 r
F P
0 g
s
.56522 .547 m .56806 .5549 L .56827 .53793 L p .985 .768 .366 r
F P
0 g
s
.56827 .53793 m .56533 .5325 L .56522 .547 L p .985 .768 .366 r
F P
0 g
s
.56827 .46207 m .56533 .4675 L .56541 .48339 L p .991 .83 .456 r
F P
0 g
s
.56533 .4675 m .56827 .46207 L .56806 .4451 L p .985 .84 .456 r
F P
0 g
s
.43302 .45984 m .43919 .45967 L .45291 .45165 L p .172 0 0 r
F P
0 g
s
.43919 .45967 m .43302 .45984 L .41842 .46851 L p .163 0 0 r
F P
0 g
s
.50809 .42001 m .51351 .4136 L .49872 .42191 L p .086 0 0 r
F P
0 g
s
.49872 .42191 m .49548 .42717 L .50809 .42001 L p .086 0 0 r
F P
0 g
s
.42668 .53298 m .41842 .53149 L .43302 .54016 L p .163 .557 .93 r
F P
0 g
s
.43302 .54016 m .43919 .54033 L .42668 .53298 L p .163 .557 .93 r
F P
0 g
s
.49872 .57809 m .49548 .57283 L .48167 .56495 L p .127 .49 .903 r
F P
0 g
s
.49548 .57283 m .49872 .57809 L .51351 .5864 L p .085 .457 .885 r
F P
0 g
s
.51271 .09706 m .57621 .0877 L .58636 .09721 L p .604 .82 .983 r
F P
0 g
s
.63264 .09705 m .58636 .09721 L .57621 .0877 L p .47 .757 .993 r
F P
0 g
s
.58636 .09721 m .63264 .09705 L .64259 .1051 L p .514 .738 .976 r
F P
0 g
s
.8426 .71248 m .81895 .77215 L .80565 .77618 L p .226 .037 .402 r
F P
0 g
s
.78265 .81634 m .80565 .77618 L .81895 .77215 L p .171 0 .25 r
F P
0 g
s
.80565 .77618 m .78265 .81634 L .7707 .82094 L p .283 .021 .328 r
F P
0 g
s
.80565 .22382 m .78265 .18366 L .7916 .18619 L p .171 .373 .82 r
F P
0 g
s
.7916 .18619 m .81895 .22785 L .80565 .22382 L p .171 .373 .82 r
F P
0 g
s
.58636 .90279 m .63264 .90295 L .62596 .90944 L p .47 .01 .078 r
F P
0 g
s
.62596 .90944 m .57621 .9123 L .58636 .90279 L p .47 .01 .078 r
F P
0 g
s
.14469 .69046 m .10484 .64015 L .10799 .62661 L p .918 .571 .364 r
F P
0 g
s
.08471 .58661 m .10799 .62661 L .10484 .64015 L p .964 .646 .363 r
F P
0 g
s
.10799 .62661 m .08471 .58661 L .08671 .57397 L p .959 .674 .452 r
F P
0 g
s
.10799 .37339 m .08471 .41339 L .08243 .40437 L p .964 .928 .708 r
F P
0 g
s
.08243 .40437 m .10484 .35985 L .10799 .37339 L p .964 .928 .708 r
F P
0 g
s
.53343 .6996 m .49743 .73698 L .49768 .72366 L p .015 0 .042 r
F P
0 g
s
.49768 .72366 m .5333 .6888 L .53343 .6996 L p .015 0 .042 r
F P
0 g
s
.5333 .3112 m .49768 .27634 L .49743 .26302 L p .015 .327 .812 r
F P
0 g
s
.44188 .22939 m .49743 .26302 L .49768 .27634 L p .215 .531 .922 r
F P
0 g
s
.31985 .56556 m .30746 .61384 L .29606 .62071 L p .966 .923 .591 r
F P
0 g
s
.2947 .68564 m .29606 .62071 L .30746 .61384 L p .999 .83 .504 r
F P
0 g
s
.65614 .37125 m .70651 .38374 L .69485 .39018 L p .299 .693 .976 r
F P
0 g
s
.69485 .39018 m .64686 .37676 L .65614 .37125 L p .299 .693 .976 r
F P
0 g
s
.31043 .42915 m .29606 .37929 L .30746 .38616 L p .966 .655 .263 r
F P
0 g
s
.30746 .38616 m .31985 .43444 L .31043 .42915 L p .966 .655 .263 r
F P
0 g
s
.64686 .62324 m .69485 .60982 L .70651 .61626 L p .299 0 0 r
F P
0 g
s
.76341 .58497 m .70651 .61626 L .69485 .60982 L p .245 0 .034 r
F P
0 g
s
.56774 .58132 m .568 .59684 L .56816 .58276 L p .748 .607 .037 r
F P
0 g
s
.56816 .58276 m .56787 .56957 L .56774 .58132 L p .748 .607 .037 r
F P
0 g
s
.56816 .41724 m .56787 .43043 L .56806 .4451 L p .761 .623 .058 r
F P
0 g
s
.56787 .43043 m .56816 .41724 L .568 .40316 L p .748 .615 .047 r
F P
0 g
s
.53656 .40067 m .54987 .39269 L .5376 .39959 L p 0 0 0 r
F P
0 g
s
.5376 .39959 m .52632 .40644 L .53656 .40067 L p 0 0 0 r
F P
0 g
s
.39425 .48236 m .40582 .47601 L .41842 .46851 L p 0 0 0 r
F P
0 g
s
.40582 .47601 m .39425 .48236 L .38214 .48953 L p 0 0 0 r
F P
0 g
s
.3957 .518 m .38214 .51047 L .39425 .51764 L p 0 .251 .656 r
F P
0 g
s
.39425 .51764 m .40582 .52399 L .3957 .518 L p 0 .251 .656 r
F P
0 g
s
.5376 .60041 m .52632 .59356 L .51351 .5864 L p 0 .255 .666 r
F P
0 g
s
.52632 .59356 m .5376 .60041 L .54987 .60731 L p 0 .24 .651 r
F P
0 g
s
.5608 .51457 m .56541 .51661 L .56545 .5 L p .978 .789 .58 r
F P
0 g
s
.56545 .5 m .56079 .5 L .5608 .51457 L p .978 .789 .58 r
F P
0 g
s
.56079 .5 m .56545 .5 L .56541 .48339 L p .978 .809 .604 r
F P
0 g
s
.48222 .44006 m .48167 .43505 L .46728 .44332 L p .389 .049 .264 r
F P
0 g
s
.46728 .44332 m .4696 .44735 L .48222 .44006 L p .389 .049 .264 r
F P
0 g
s
.4696 .44735 m .46728 .44332 L .45291 .45165 L p .41 .056 .252 r
F P
0 g
s
.45698 .54537 m .45291 .54835 L .46728 .55668 L p .41 .612 .933 r
F P
0 g
s
.46728 .55668 m .4696 .55265 L .45698 .54537 L p .41 .612 .933 r
F P
0 g
s
.4696 .55265 m .46728 .55668 L .48167 .56495 L p .389 .586 .921 r
F P
0 g
s
.56806 .4451 m .56522 .453 L .56533 .4675 L p .985 .84 .456 r
F P
0 g
s
.56522 .453 m .56806 .4451 L .56787 .43043 L p .971 .847 .442 r
F P
0 g
s
.56513 .55951 m .56787 .56957 L .56806 .5549 L p .972 .74 .311 r
F P
0 g
s
.56806 .5549 m .56522 .547 L .56513 .55951 L p .972 .74 .311 r
F P
0 g
s
.51897 .41384 m .52632 .40644 L .51351 .4136 L p .023 0 0 r
F P
0 g
s
.51351 .4136 m .50809 .42001 L .51897 .41384 L p .023 0 0 r
F P
0 g
s
.41842 .46851 m .42668 .46702 L .43919 .45967 L p .163 0 0 r
F P
0 g
s
.42668 .46702 m .41842 .46851 L .40582 .47601 L p .136 0 0 r
F P
0 g
s
.4159 .52665 m .40582 .52399 L .41842 .53149 L p .136 .559 .925 r
F P
0 g
s
.41842 .53149 m .42668 .53298 L .4159 .52665 L p .136 .559 .925 r
F P
0 g
s
.51351 .5864 m .50809 .57999 L .49548 .57283 L p .085 .457 .885 r
F P
0 g
s
.50809 .57999 m .51351 .5864 L .52632 .59356 L p .022 .412 .859 r
F P
0 g
s
.7707 .17906 m .75391 .1547 L .76148 .15756 L p .21 .456 .876 r
F P
0 g
s
.76148 .15756 m .78265 .18366 L .7707 .17906 L p .21 .456 .876 r
F P
0 g
s
.67208 .10746 m .64259 .1051 L .63264 .09705 L p .384 .68 .976 r
F P
0 g
s
.64259 .1051 m .67208 .10746 L .68018 .11338 L p .413 .669 .966 r
F P
0 g
s
.64259 .8949 m .67208 .89254 L .66583 .89767 L p .384 0 .078 r
F P
0 g
s
.66583 .89767 m .63264 .90295 L .64259 .8949 L p .384 0 .078 r
F P
0 g
s
.75391 .8453 m .7707 .82094 L .78265 .81634 L p .21 0 .179 r
F P
0 g
s
.7707 .82094 m .75391 .8453 L .74474 .84935 L p .28 0 .228 r
F P
0 g
s
.07401 .54724 m .08671 .57397 L .08471 .58661 L p .988 .725 .427 r
F P
0 g
s
.08671 .57397 m .07401 .54724 L .07509 .53727 L p .985 .742 .482 r
F P
0 g
s
.08671 .42603 m .07401 .45276 L .0727 .44478 L p .988 .888 .627 r
F P
0 g
s
.0727 .44478 m .08471 .41339 L .08671 .42603 L p .988 .888 .627 r
F P
0 g
s
.56541 .48339 m .5608 .48543 L .56079 .5 L p .978 .809 .604 r
F P
0 g
s
.5608 .48543 m .56541 .48339 L .56533 .4675 L p .98 .83 .623 r
F P
0 g
s
.56083 .52849 m .56533 .5325 L .56541 .51661 L p .98 .77 .549 r
F P
0 g
s
.56541 .51661 m .5608 .51457 L .56083 .52849 L p .98 .77 .549 r
F P
0 g
s
.45291 .45165 m .45698 .45463 L .4696 .44735 L p .41 .056 .252 r
F P
0 g
s
.45698 .45463 m .45291 .45165 L .43919 .45967 L p .422 .051 .227 r
F P
0 g
s
.49426 .43307 m .49548 .42717 L .48167 .43505 L p .357 .029 .264 r
F P
0 g
s
.48167 .43505 m .48222 .44006 L .49426 .43307 L p .357 .029 .264 r
F P
0 g
s
.44491 .53844 m .43919 .54033 L .45291 .54835 L p .422 .638 .946 r
F P
0 g
s
.45291 .54835 m .45698 .54537 L .44491 .53844 L p .422 .638 .946 r
F P
0 g
s
.48167 .56495 m .48222 .55994 L .4696 .55265 L p .389 .586 .921 r
F P
0 g
s
.48222 .55994 m .48167 .56495 L .49548 .57283 L p .357 .555 .909 r
F P
0 g
s
.55391 .3436 m .56424 .37105 L .56422 .3833 L p 0 0 .556 r
F P
0 g
s
.3376 .53151 m .35621 .50885 L .36683 .50273 L p .818 .997 .777 r
F P
0 g
s
.60849 .62489 m .57956 .62011 L .56895 .61397 L p .5 0 0 r
F P
0 g
s
.71536 .12699 m .71172 .13328 L .70042 .12657 L p .303 .581 .939 r
F P
0 g
s
.71172 .13328 m .71536 .12699 L .72217 .13081 L p .29 .564 .931 r
F P
0 g
s
.72217 .13081 m .72319 .13971 L .71172 .13328 L p .29 .564 .931 r
F P
0 g
s
.71536 .87301 m .71172 .86672 L .72319 .86029 L p .29 0 .129 r
F P
0 g
s
.71172 .86672 m .71536 .87301 L .70864 .877 L p .303 0 .121 r
F P
0 g
s
.70864 .877 m .70042 .87343 L .71172 .86672 L p .303 0 .121 r
F P
0 g
s
.06929 .5 m .07655 .5 L .07639 .51314 L p .998 .809 .523 r
F P
0 g
s
.07655 .5 m .06929 .5 L .06919 .49219 L p .998 .821 .538 r
F P
0 g
s
.06919 .49219 m .07639 .48686 L .07655 .5 L p .998 .821 .538 r
F P
0 g
s
.43129 .11586 m .50526 .08789 L .51271 .09706 L p .683 .924 .971 r
F P
0 g
s
.57621 .0877 m .51271 .09706 L .50526 .08789 L p .533 .85 .998 r
F P
0 g
s
.8426 .28752 m .81895 .22785 L .82731 .22871 L p .028 .2 .706 r
F P
0 g
s
.82731 .22871 m .85427 .28939 L .8426 .28752 L p .028 .2 .706 r
F P
0 g
s
.51271 .90294 m .57621 .9123 L .57128 .9191 L p .533 .021 0 r
F P
0 g
s
.57128 .9191 m .50526 .91211 L .51271 .90294 L p .533 .021 0 r
F P
0 g
s
.14469 .30954 m .10484 .35985 L .1014 .35218 L p .908 .98 .781 r
F P
0 g
s
.1014 .35218 m .14048 .2985 L .14469 .30954 L p .908 .98 .781 r
F P
0 g
s
.20168 .75158 m .14048 .7015 L .14469 .69046 L p .831 .382 .159 r
F P
0 g
s
.10484 .64015 m .14469 .69046 L .14048 .7015 L p .908 .503 .198 r
F P
0 g
s
.86703 .63256 m .85427 .71061 L .8426 .71248 L p .053 0 .437 r
F P
0 g
s
.81895 .77215 m .8426 .71248 L .85427 .71061 L p .028 0 .273 r
F P
0 g
s
.72319 .13971 m .72217 .13081 L .7288 .13429 L p .267 .544 .923 r
F P
0 g
s
.7288 .13429 m .73435 .14558 L .72319 .13971 L p .267 .544 .923 r
F P
0 g
s
.70864 .123 m .70042 .12657 L .68976 .11984 L p .307 .596 .946 r
F P
0 g
s
.70042 .12657 m .70864 .123 L .71536 .12699 L p .303 .581 .939 r
F P
0 g
s
.70042 .87343 m .70864 .877 L .70231 .881 L p .307 0 .102 r
F P
0 g
s
.70231 .881 m .68976 .88016 L .70042 .87343 L p .307 0 .102 r
F P
0 g
s
.72217 .86919 m .72319 .86029 L .73435 .85442 L p .267 0 .125 r
F P
0 g
s
.72319 .86029 m .72217 .86919 L .71536 .87301 L p .29 0 .129 r
F P
0 g
s
.07639 .48686 m .06919 .49219 L .06889 .48471 L p .998 .834 .547 r
F P
0 g
s
.06889 .48471 m .07589 .47426 L .07639 .48686 L p .998 .834 .547 r
F P
0 g
s
.06919 .50781 m .07639 .51314 L .07589 .52574 L p .998 .796 .501 r
F P
0 g
s
.07639 .51314 m .06919 .50781 L .06929 .5 L p .998 .809 .523 r
F P
0 g
s
.56088 .54116 m .56522 .547 L .56533 .5325 L p .982 .749 .507 r
F P
0 g
s
.56533 .5325 m .56083 .52849 L .56088 .54116 L p .982 .749 .507 r
F P
0 g
s
.56533 .4675 m .56083 .47151 L .5608 .48543 L p .98 .83 .623 r
F P
0 g
s
.56083 .47151 m .56533 .4675 L .56522 .453 L p .982 .855 .638 r
F P
0 g
s
.5052 .4267 m .50809 .42001 L .49548 .42717 L p .311 0 .25 r
F P
0 g
s
.49548 .42717 m .49426 .43307 L .5052 .4267 L p .311 0 .25 r
F P
0 g
s
.43919 .45967 m .44491 .46156 L .45698 .45463 L p .422 .051 .227 r
F P
0 g
s
.44491 .46156 m .43919 .45967 L .42668 .46702 L p .424 .029 .185 r
F P
0 g
s
.43392 .53215 m .42668 .53298 L .43919 .54033 L p .424 .663 .96 r
F P
0 g
s
.43919 .54033 m .44491 .53844 L .43392 .53215 L p .424 .663 .96 r
F P
0 g
s
.49548 .57283 m .49426 .56693 L .48222 .55994 L p .357 .555 .909 r
F P
0 g
s
.49426 .56693 m .49548 .57283 L .50809 .57999 L p .311 .517 .895 r
F P
0 g
s
.55416 .665 m .53343 .6996 L .5333 .6888 L p 0 0 .036 r
F P
0 g
s
.5333 .6888 m .55391 .6564 L .55416 .665 L p 0 0 .036 r
F P
0 g
s
.55391 .3436 m .5333 .3112 L .53343 .3004 L p 0 .101 .656 r
F P
0 g
s
.49743 .26302 m .53343 .3004 L .5333 .3112 L p .015 .327 .812 r
F P
0 g
s
.3376 .53151 m .31985 .56556 L .31043 .57085 L p .881 .97 .653 r
F P
0 g
s
.29606 .62071 m .31043 .57085 L .31985 .56556 L p .966 .923 .591 r
F P
0 g
s
.61581 .37059 m .65614 .37125 L .64686 .37676 L p .344 .785 .963 r
F P
0 g
s
.64686 .37676 m .60849 .37511 L .61581 .37059 L p .344 .785 .963 r
F P
0 g
s
.60849 .62489 m .64686 .62324 L .65614 .62875 L p .344 0 0 r
F P
0 g
s
.70651 .61626 m .65614 .62875 L .64686 .62324 L p .299 0 0 r
F P
0 g
s
.33003 .46441 m .31043 .42915 L .31985 .43444 L p .881 .469 .04 r
F P
0 g
s
.31985 .43444 m .3376 .46849 L .33003 .46441 L p .881 .469 .04 r
F P
0 g
s
.73435 .14558 m .7288 .13429 L .73496 .13729 L p .235 .52 .914 r
F P
0 g
s
.73496 .13729 m .74474 .15065 L .73435 .14558 L p .235 .52 .914 r
F P
0 g
s
.70231 .119 m .68976 .11984 L .68018 .11338 L p .302 .606 .952 r
F P
0 g
s
.68976 .11984 m .70231 .119 L .70864 .123 L p .307 .596 .946 r
F P
0 g
s
.68976 .88016 m .70231 .881 L .69664 .88484 L p .302 0 .071 r
F P
0 g
s
.69664 .88484 m .68018 .88662 L .68976 .88016 L p .302 0 .071 r
F P
0 g
s
.7288 .86571 m .73435 .85442 L .74474 .84935 L p .235 0 .11 r
F P
0 g
s
.73435 .85442 m .7288 .86571 L .72217 .86919 L p .267 0 .125 r
F P
0 g
s
.06889 .51529 m .07589 .52574 L .07509 .53727 L p .998 .784 .473 r
F P
0 g
s
.07589 .52574 m .06889 .51529 L .06919 .50781 L p .998 .796 .501 r
F P
0 g
s
.07589 .47426 m .06889 .48471 L .0684 .47788 L p .998 .846 .55 r
F P
0 g
s
.0684 .47788 m .07509 .46273 L .07589 .47426 L p .998 .846 .55 r
F P
0 g
s
.56508 .56949 m .56774 .58132 L .56787 .56957 L p .944 .699 .231 r
F P
0 g
s
.56787 .56957 m .56513 .55951 L .56508 .56949 L p .944 .699 .231 r
F P
0 g
s
.56787 .43043 m .56513 .44049 L .56522 .453 L p .971 .847 .442 r
F P
0 g
s
.56513 .44049 m .56787 .43043 L .56774 .41868 L p .944 .843 .408 r
F P
0 g
s
.568 .40316 m .56774 .41868 L .56787 .43043 L p .748 .615 .047 r
F P
0 g
s
.40582 .47601 m .4159 .47335 L .42668 .46702 L p .136 0 0 r
F P
0 g
s
.4159 .47335 m .40582 .47601 L .3957 .482 L p .083 0 0 r
F P
0 g
s
.38214 .48953 m .3957 .482 L .40582 .47601 L p 0 0 0 r
F P
0 g
s
.52764 .40889 m .53656 .40067 L .52632 .40644 L p 0 0 0 r
F P
0 g
s
.52632 .40644 m .51897 .41384 L .52764 .40889 L p 0 0 0 r
F P
0 g
s
.40728 .52162 m .3957 .518 L .40582 .52399 L p .084 .546 .905 r
F P
0 g
s
.40582 .52399 m .4159 .52665 L .40728 .52162 L p .084 .546 .905 r
F P
0 g
s
.52632 .59356 m .51897 .58616 L .50809 .57999 L p .022 .412 .859 r
F P
0 g
s
.51897 .58616 m .52632 .59356 L .53656 .59933 L p 0 .349 .816 r
F P
0 g
s
.54987 .60731 m .53656 .59933 L .52632 .59356 L p 0 .24 .651 r
F P
0 g
s
.55518 .51316 m .5608 .51457 L .56079 .5 L p .925 .745 .639 r
F P
0 g
s
.56079 .5 m .5551 .5 L .55518 .51316 L p .925 .745 .639 r
F P
0 g
s
.5551 .5 m .56079 .5 L .5608 .48543 L p .925 .766 .665 r
F P
0 g
s
.48381 .44564 m .48222 .44006 L .4696 .44735 L p .504 .224 .422 r
F P
0 g
s
.4696 .44735 m .47245 .45228 L .48381 .44564 L p .504 .224 .422 r
F P
0 g
s
.47245 .45228 m .4696 .44735 L .45698 .45463 L p .527 .232 .409 r
F P
0 g
s
.46102 .5412 m .45698 .54537 L .4696 .55265 L p .527 .629 .895 r
F P
0 g
s
.4696 .55265 m .47245 .54772 L .46102 .5412 L p .527 .629 .895 r
F P
0 g
s
.47245 .54772 m .4696 .55265 L .48222 .55994 L p .504 .599 .882 r
F P
0 g
s
.56522 .453 m .56088 .45884 L .56083 .47151 L p .982 .855 .638 r
F P
0 g
s
.56088 .45884 m .56522 .453 L .56513 .44049 L p .985 .884 .643 r
F P
0 g
s
.56095 .55204 m .56513 .55951 L .56522 .547 L p .985 .724 .447 r
F P
0 g
s
.56522 .547 m .56088 .54116 L .56095 .55204 L p .985 .724 .447 r
F P
0 g
s
.51459 .4212 m .51897 .41384 L .50809 .42001 L p .24 0 .214 r
F P
0 g
s
.50809 .42001 m .5052 .4267 L .51459 .4212 L p .24 0 .214 r
F P
0 g
s
.42668 .46702 m .43392 .46785 L .44491 .46156 L p .424 .029 .185 r
F P
0 g
s
.43392 .46785 m .42668 .46702 L .4159 .47335 L p .41 0 .115 r
F P
0 g
s
.42446 .52677 m .4159 .52665 L .42668 .53298 L p .411 .686 .975 r
F P
0 g
s
.42668 .53298 m .43392 .53215 L .42446 .52677 L p .411 .686 .975 r
F P
0 g
s
.50809 .57999 m .5052 .5733 L .49426 .56693 L p .311 .517 .895 r
F P
0 g
s
.5052 .5733 m .50809 .57999 L .51897 .58616 L p .24 .467 .877 r
F P
0 g
s
.5608 .48543 m .55518 .48684 L .5551 .5 L p .925 .766 .665 r
F P
0 g
s
.55518 .48684 m .5608 .48543 L .56083 .47151 L p .927 .79 .689 r
F P
0 g
s
.55538 .52568 m .56083 .52849 L .5608 .51457 L p .927 .724 .608 r
F P
0 g
s
.5608 .51457 m .55518 .51316 L .55538 .52568 L p .927 .724 .608 r
F P
0 g
s
.45698 .45463 m .46102 .4588 L .47245 .45228 L p .527 .232 .409 r
F P
0 g
s
.46102 .4588 m .45698 .45463 L .44491 .46156 L p .545 .231 .387 r
F P
0 g
s
.49455 .4392 m .49426 .43307 L .48222 .44006 L p .474 .207 .428 r
F P
0 g
s
.48222 .44006 m .48381 .44564 L .49455 .4392 L p .474 .207 .428 r
F P
0 g
s
.45007 .53512 m .44491 .53844 L .45698 .54537 L p .545 .658 .91 r
F P
0 g
s
.45698 .54537 m .46102 .5412 L .45007 .53512 L p .545 .658 .91 r
F P
0 g
s
.48222 .55994 m .48381 .55436 L .47245 .54772 L p .504 .599 .882 r
F P
0 g
s
.48381 .55436 m .48222 .55994 L .49426 .56693 L p .474 .567 .869 r
F P
0 g
s
.56774 .58965 m .56799 .60687 L .568 .59684 L p .725 .585 .009 r
F P
0 g
s
.568 .59684 m .56774 .58132 L .56774 .58965 L p .725 .585 .009 r
F P
0 g
s
.56774 .41868 m .568 .40316 L .56799 .39313 L p .725 .599 .027 r
F P
0 g
s
.3957 .482 m .38214 .48953 L .37345 .49455 L p 0 0 0 r
F P
0 g
s
.54377 .39651 m .55856 .38768 L .54987 .39269 L p 0 0 0 r
F P
0 g
s
.54987 .39269 m .53656 .40067 L .54377 .39651 L p 0 0 0 r
F P
0 g
s
.53656 .59933 m .54987 .60731 L .55856 .61232 L p 0 .216 .626 r
F P
0 g
s
.38849 .51384 m .37345 .50545 L .38214 .51047 L p 0 .236 .635 r
F P
0 g
s
.38214 .51047 m .3957 .518 L .38849 .51384 L p 0 .236 .635 r
F P
0 g
s
.74474 .15065 m .73496 .13729 L .74038 .13967 L p .193 .493 .903 r
F P
0 g
s
.74038 .13967 m .75391 .1547 L .74474 .15065 L p .193 .493 .903 r
F P
0 g
s
.69664 .11516 m .68018 .11338 L .67208 .10746 L p .286 .612 .956 r
F P
0 g
s
.68018 .11338 m .69664 .11516 L .70231 .119 L p .302 .606 .952 r
F P
0 g
s
.68018 .88662 m .69664 .88484 L .69186 .88834 L p .286 0 .028 r
F P
0 g
s
.69186 .88834 m .67208 .89254 L .68018 .88662 L p .286 0 .028 r
F P
0 g
s
.07509 .46273 m .0684 .47788 L .06775 .47199 L p .997 .858 .546 r
F P
0 g
s
.06775 .47199 m .07401 .45276 L .07509 .46273 L p .997 .858 .546 r
F P
0 g
s
.73496 .86271 m .74474 .84935 L .75391 .8453 L p .193 0 .082 r
F P
0 g
s
.74474 .84935 m .73496 .86271 L .7288 .86571 L p .235 0 .11 r
F P
0 g
s
.0684 .52212 m .07509 .53727 L .07401 .54724 L p .997 .77 .439 r
F P
0 g
s
.07509 .53727 m .0684 .52212 L .06889 .51529 L p .998 .784 .473 r
F P
0 g
s
.56083 .47151 m .55538 .47432 L .55518 .48684 L p .927 .79 .689 r
F P
0 g
s
.55538 .47432 m .56083 .47151 L .56088 .45884 L p .932 .82 .713 r
F P
0 g
s
.55566 .53702 m .56088 .54116 L .56083 .52849 L p .932 .702 .568 r
F P
0 g
s
.56083 .52849 m .55538 .52568 L .55566 .53702 L p .932 .702 .568 r
F P
0 g
s
.44491 .46156 m .45007 .46488 L .46102 .4588 L p .545 .231 .387 r
F P
0 g
s
.45007 .46488 m .44491 .46156 L .43392 .46785 L p .557 .219 .352 r
F P
0 g
s
.50423 .43329 m .5052 .4267 L .49426 .43307 L p .432 .176 .424 r
F P
0 g
s
.49426 .43307 m .49455 .4392 L .50423 .43329 L p .432 .176 .424 r
F P
0 g
s
.49426 .56693 m .49455 .5608 L .48381 .55436 L p .474 .567 .869 r
F P
0 g
s
.49455 .5608 m .49426 .56693 L .5052 .5733 L p .432 .529 .856 r
F P
0 g
s
.44011 .5297 m .43392 .53215 L .44491 .53844 L p .557 .69 .929 r
F P
0 g
s
.44491 .53844 m .45007 .53512 L .44011 .5297 L p .557 .69 .929 r
F P
0 g
s
.78265 .18366 m .76148 .15756 L .7671 .15908 L p .12 .404 .855 r
F P
0 g
s
.7671 .15908 m .7916 .18619 L .78265 .18366 L p .12 .404 .855 r
F P
0 g
s
.57621 .0877 m .62596 .09056 L .63264 .09705 L p .47 .757 .993 r
F P
0 g
s
.66583 .10233 m .63264 .09705 L .62596 .09056 L p .335 .681 .979 r
F P
0 g
s
.63264 .09705 m .66583 .10233 L .67208 .10746 L p .384 .68 .976 r
F P
0 g
s
.63264 .90295 m .66583 .89767 L .66169 .90178 L p .335 0 0 r
F P
0 g
s
.66169 .90178 m .62596 .90944 L .63264 .90295 L p .335 0 0 r
F P
0 g
s
.81895 .77215 m .7916 .81381 L .78265 .81634 L p .171 0 .25 r
F P
0 g
s
.76148 .84244 m .78265 .81634 L .7916 .81381 L p .12 0 .105 r
F P
0 g
s
.78265 .81634 m .76148 .84244 L .75391 .8453 L p .21 0 .179 r
F P
0 g
s
.10484 .64015 m .08243 .59563 L .08471 .58661 L p .964 .646 .363 r
F P
0 g
s
.0727 .55522 m .08471 .58661 L .08243 .59563 L p .984 .702 .355 r
F P
0 g
s
.08471 .58661 m .0727 .55522 L .07401 .54724 L p .988 .725 .427 r
F P
0 g
s
.08471 .41339 m .0727 .44478 L .0712 .43914 L p .984 .905 .604 r
F P
0 g
s
.0712 .43914 m .08243 .40437 L .08471 .41339 L p .984 .905 .604 r
F P
0 g
s
.56424 .37105 m .55391 .3436 L .55416 .335 L p 0 0 .462 r
F P
0 g
s
.53343 .3004 m .55416 .335 L .55391 .3436 L p 0 .101 .656 r
F P
0 g
s
.56448 .63581 m .55416 .665 L .55391 .6564 L p 0 0 .033 r
F P
0 g
s
.55391 .6564 m .56424 .62895 L .56448 .63581 L p 0 0 .033 r
F P
0 g
s
.35621 .50885 m .3376 .53151 L .33003 .53559 L p .747 .965 .683 r
F P
0 g
s
.31043 .57085 m .33003 .53559 L .3376 .53151 L p .881 .97 .653 r
F P
0 g
s
.58537 .37626 m .61581 .37059 L .60849 .37511 L p .375 .837 .898 r
F P
0 g
s
.60849 .37511 m .57956 .37989 L .58537 .37626 L p .375 .837 .898 r
F P
0 g
s
.57956 .62011 m .60849 .62489 L .61581 .62941 L p .375 0 0 r
F P
0 g
s
.65614 .62875 m .61581 .62941 L .60849 .62489 L p .344 0 0 r
F P
0 g
s
.35015 .48794 m .33003 .46441 L .3376 .46849 L p .747 .254 0 r
F P
0 g
s
.3376 .46849 m .35621 .49115 L .35015 .48794 L p .747 .254 0 r
F P
0 g
s
.54886 .51229 m .55518 .51316 L .5551 .5 L p .876 .704 .666 r
F P
0 g
s
.5551 .5 m .54868 .5 L .54886 .51229 L p .876 .704 .666 r
F P
0 g
s
.54868 .5 m .5551 .5 L .55518 .48684 L p .876 .726 .692 r
F P
0 g
s
.48621 .45154 m .48381 .44564 L .47245 .45228 L p .569 .331 .515 r
F P
0 g
s
.47245 .45228 m .47566 .45784 L .48621 .45154 L p .569 .331 .515 r
F P
0 g
s
.47566 .45784 m .47245 .45228 L .46102 .4588 L p .592 .339 .502 r
F P
0 g
s
.46492 .53617 m .46102 .5412 L .47245 .54772 L p .592 .628 .856 r
F P
0 g
s
.47245 .54772 m .47566 .54216 L .46492 .53617 L p .592 .628 .856 r
F P
0 g
s
.47566 .54216 m .47245 .54772 L .48381 .55436 L p .569 .599 .843 r
F P
0 g
s
.56513 .44049 m .56095 .44796 L .56088 .45884 L p .985 .884 .643 r
F P
0 g
s
.56095 .44796 m .56513 .44049 L .56508 .43051 L p .981 .914 .632 r
F P
0 g
s
.56774 .41868 m .56508 .43051 L .56513 .44049 L p .944 .843 .408 r
F P
0 g
s
.56104 .56069 m .56508 .56949 L .56513 .55951 L p .981 .687 .355 r
F P
0 g
s
.56513 .55951 m .56095 .55204 L .56104 .56069 L p .981 .687 .355 r
F P
0 g
s
.52204 .41679 m .52764 .40889 L .51897 .41384 L p .13 0 .142 r
F P
0 g
s
.51897 .41384 m .51459 .4212 L .52204 .41679 L p .13 0 .142 r
F P
0 g
s
.4159 .47335 m .42446 .47323 L .43392 .46785 L p .41 0 .115 r
F P
0 g
s
.42446 .47323 m .4159 .47335 L .40728 .47838 L p .37 0 .003 r
F P
0 g
s
.3957 .482 m .40728 .47838 L .4159 .47335 L p .083 0 0 r
F P
0 g
s
.51897 .58616 m .51459 .5788 L .5052 .5733 L p .24 .467 .877 r
F P
0 g
s
.51459 .5788 m .51897 .58616 L .52764 .59111 L p .13 .394 .846 r
F P
0 g
s
.53656 .59933 m .52764 .59111 L .51897 .58616 L p 0 .349 .816 r
F P
0 g
s
.41692 .52252 m .40728 .52162 L .4159 .52665 L p .37 .703 .985 r
F P
0 g
s
.4159 .52665 m .42446 .52677 L .41692 .52252 L p .37 .703 .985 r
F P
0 g
s
.50526 .08789 m .57128 .0809 L .57621 .0877 L p .533 .85 .998 r
F P
0 g
s
.62596 .09056 m .57621 .0877 L .57128 .0809 L p .386 .758 .992 r
F P
0 g
s
.81895 .22785 m .7916 .18619 L .79713 .18653 L p .013 .277 .776 r
F P
0 g
s
.79713 .18653 m .82731 .22871 L .81895 .22785 L p .013 .277 .776 r
F P
0 g
s
.85427 .71061 m .82731 .77129 L .81895 .77215 L p .028 0 .273 r
F P
0 g
s
.7916 .81381 m .81895 .77215 L .82731 .77129 L p .013 0 .124 r
F P
0 g
s
.57621 .9123 m .62596 .90944 L .6229 .91405 L p .386 0 0 r
F P
0 g
s
.6229 .91405 m .57128 .9191 L .57621 .9123 L p .386 0 0 r
F P
0 g
s
.10484 .35985 m .08243 .40437 L .07997 .39941 L p .951 .953 .666 r
F P
0 g
s
.07997 .39941 m .1014 .35218 L .10484 .35985 L p .951 .953 .666 r
F P
0 g
s
.14048 .7015 m .1014 .64782 L .10484 .64015 L p .908 .503 .198 r
F P
0 g
s
.08243 .59563 m .10484 .64015 L .1014 .64782 L p .951 .6 .234 r
F P
0 g
s
.56088 .45884 m .55566 .46298 L .55538 .47432 L p .932 .82 .713 r
F P
0 g
s
.55566 .46298 m .56088 .45884 L .56095 .44796 L p .939 .857 .734 r
F P
0 g
s
.55597 .5467 m .56095 .55204 L .56088 .54116 L p .939 .676 .512 r
F P
0 g
s
.56088 .54116 m .55566 .53702 L .55597 .5467 L p .939 .676 .512 r
F P
0 g
s
.51246 .42818 m .51459 .4212 L .5052 .4267 L p .369 .123 .405 r
F P
0 g
s
.5052 .4267 m .50423 .43329 L .51246 .42818 L p .369 .123 .405 r
F P
0 g
s
.43392 .46785 m .44011 .4703 L .45007 .46488 L p .557 .219 .352 r
F P
0 g
s
.44011 .4703 m .43392 .46785 L .42446 .47323 L p .561 .189 .294 r
F P
0 g
s
.5052 .5733 m .50423 .56671 L .49455 .5608 L p .432 .529 .856 r
F P
0 g
s
.50423 .56671 m .5052 .5733 L .51459 .5788 L p .369 .479 .841 r
F P
0 g
s
.43157 .52512 m .42446 .52677 L .43392 .53215 L p .561 .727 .952 r
F P
0 g
s
.43392 .53215 m .44011 .5297 L .43157 .52512 L p .561 .727 .952 r
F P
0 g
s
.54933 .52391 m .55538 .52568 L .55518 .51316 L p .877 .683 .636 r
F P
0 g
s
.55518 .51316 m .54886 .51229 L .54933 .52391 L p .877 .683 .636 r
F P
0 g
s
.55518 .48684 m .54886 .48771 L .54868 .5 L p .876 .726 .692 r
F P
0 g
s
.54886 .48771 m .55518 .48684 L .55538 .47432 L p .877 .75 .718 r
F P
0 g
s
.49604 .44532 m .49455 .4392 L .48381 .44564 L p .541 .317 .524 r
F P
0 g
s
.48381 .44564 m .48621 .45154 L .49604 .44532 L p .541 .317 .524 r
F P
0 g
s
.46102 .4588 m .46492 .46383 L .47566 .45784 L p .592 .339 .502 r
F P
0 g
s
.46492 .46383 m .46102 .4588 L .45007 .46488 L p .613 .342 .483 r
F P
0 g
s
.48381 .55436 m .48621 .54846 L .47566 .54216 L p .569 .599 .843 r
F P
0 g
s
.48621 .54846 m .48381 .55436 L .49455 .5608 L p .541 .567 .83 r
F P
0 g
s
.45463 .53077 m .45007 .53512 L .46102 .5412 L p .613 .658 .871 r
F P
0 g
s
.46102 .5412 m .46492 .53617 L .45463 .53077 L p .613 .658 .871 r
F P
0 g
s
.75391 .1547 m .74038 .13967 L .74484 .14133 L p .141 .461 .888 r
F P
0 g
s
.74484 .14133 m .76148 .15756 L .75391 .1547 L p .141 .461 .888 r
F P
0 g
s
.69186 .11166 m .67208 .10746 L .66583 .10233 L p .258 .613 .956 r
F P
0 g
s
.67208 .10746 m .69186 .11166 L .69664 .11516 L p .286 .612 .956 r
F P
0 g
s
.07401 .45276 m .06775 .47199 L .06696 .46729 L p .993 .866 .532 r
F P
0 g
s
.06696 .46729 m .0727 .44478 L .07401 .45276 L p .993 .866 .532 r
F P
0 g
s
.67208 .89254 m .69186 .88834 L .68819 .89137 L p .258 0 0 r
F P
0 g
s
.68819 .89137 m .66583 .89767 L .67208 .89254 L p .258 0 0 r
F P
0 g
s
.74038 .86033 m .75391 .8453 L .76148 .84244 L p .141 0 .039 r
F P
0 g
s
.75391 .8453 m .74038 .86033 L .73496 .86271 L p .193 0 .082 r
F P
0 g
s
.06775 .52801 m .07401 .54724 L .0727 .55522 L p .993 .756 .396 r
F P
0 g
s
.07401 .54724 m .06775 .52801 L .0684 .52212 L p .997 .77 .439 r
F P
0 g
s
.55538 .47432 m .54933 .47609 L .54886 .48771 L p .877 .75 .718 r
F P
0 g
s
.54933 .47609 m .55538 .47432 L .55566 .46298 L p .88 .778 .745 r
F P
0 g
s
.54995 .53432 m .55566 .53702 L .55538 .52568 L p .88 .658 .598 r
F P
0 g
s
.55538 .52568 m .54933 .52391 L .54995 .53432 L p .88 .658 .598 r
F P
0 g
s
.50474 .43958 m .50423 .43329 L .49455 .4392 L p .504 .295 .528 r
F P
0 g
s
.49455 .4392 m .49604 .44532 L .50474 .43958 L p .504 .295 .528 r
F P
0 g
s
.45007 .46488 m .45463 .46923 L .46492 .46383 L p .613 .342 .483 r
F P
0 g
s
.45463 .46923 m .45007 .46488 L .44011 .4703 L p .631 .338 .455 r
F P
0 g
s
.4453 .5261 m .44011 .5297 L .45007 .53512 L p .631 .693 .889 r
F P
0 g
s
.45007 .53512 m .45463 .53077 L .4453 .5261 L p .631 .693 .889 r
F P
0 g
s
.49455 .5608 m .49604 .55468 L .48621 .54846 L p .541 .567 .83 r
F P
0 g
s
.49604 .55468 m .49455 .5608 L .50423 .56671 L p .504 .529 .815 r
F P
0 g
s
.56508 .43051 m .56774 .41868 L .56774 .41035 L p .89 .817 .341 r
F P
0 g
s
.56799 .39313 m .56774 .41035 L p .5678 .41294 L .725 .599 .027 r
F P
0 g
s
.56799 .39313 m .5682 .38761 L p .56774 .41034 L 0 0 .004 r
F P
0 g
s
.56774 .41035 m .56774 .41034 L p .56774 .41034 L 0 0 .004 r
F P
0 g
s
.56774 .41034 m .56799 .39313 L p .56774 .41034 L 0 0 .004 r
F P
0 g
s
.56791 .40582 m .56774 .41035 L p .56785 .40512 L 0 0 .004 r
F P
0 g
s
.5682 .38761 m .56791 .40582 L p .56785 .40512 L 0 0 .004 r
F P
0 g
s
.56791 .40582 m .56825 .40535 L p .56798 .40666 L 0 0 0 r
F P
0 g
s
.56528 .41969 m .56513 .42347 L p .5661 .41729 L .794 .753 .234 r
F P
0 g
s
.56791 .40583 m .56528 .41969 L .5661 .41729 L .794 .753 .234 r
F
.56117 .43324 m .56513 .42347 L .56528 .41969 L p .853 .886 .457 r
F P
0 g
s
.56134 .43001 m .56117 .43324 L p .56297 .42731 L .853 .886 .457 r
F P
0 g
s
.56528 .41969 m .56134 .43001 L p .56297 .42731 L .853 .886 .457 r
F P
0 g
s
.55653 .4403 m .56117 .43324 L .56134 .43001 L p .866 .969 .648 r
F P
0 g
s
.56134 .43001 m .55675 .43748 L .55653 .4403 L p .866 .969 .648 r
F P
0 g
s
.56134 .43001 m .56155 .42977 L p .55961 .43288 L 0 0 0 r
F P
0 g
s
.55675 .43748 m .56134 .43001 L p .55961 .43288 L 0 0 0 r
F P
0 g
s
.56528 .41969 m .56555 .41936 L p .56437 .42235 L 0 0 0 r
F P
0 g
s
.56134 .43001 m .56528 .41969 L p .56437 .42235 L 0 0 0 r
F P
0 g
s
.56791 .40582 m .56791 .40583 L p .56791 .40583 L .794 .753 .234 r
F P
0 g
s
.56791 .40583 m .56528 .41969 L p .56791 .40583 L .794 .753 .234 r
F P
0 g
s
.56774 .41035 m .56791 .40582 L p .56768 .40729 L .794 .753 .234 r
F P
0 g
s
.56513 .42347 m .56774 .41035 L p .56768 .40729 L .794 .753 .234 r
F P
0 g
s
.56528 .41969 m .56791 .40582 L p .56798 .40666 L 0 0 0 r
F P
0 g
s
.56774 .41035 m .56774 .41868 L p .5678 .41294 L .725 .599 .027 r
F P
0 g
s
.56513 .57653 m .56774 .58965 L .56774 .58132 L p .89 .637 .121 r
F P
0 g
s
.56774 .58132 m .56508 .56949 L .56513 .57653 L p .89 .637 .121 r
F P
0 g
s
.53371 .40533 m .54377 .39651 L .53656 .40067 L p 0 0 0 r
F P
0 g
s
.53656 .40067 m .52764 .40889 L .53371 .40533 L p 0 0 0 r
F P
0 g
s
.40728 .47838 m .3957 .482 L .38849 .48616 L p 0 0 0 r
F P
0 g
s
.37345 .49455 m .38849 .48616 L p .3907 .48482 L 0 0 0 r
F P
0 g
s
.37345 .49455 m .36857 .49714 L p .38848 .48616 L .359 .797 .633 r
F P
0 g
s
.38849 .48616 m .38848 .48616 L p .38848 .48616 L .359 .797 .633 r
F P
0 g
s
.38848 .48616 m .37345 .49455 L p .38848 .48616 L .359 .797 .633 r
F P
0 g
s
.38449 .48828 m .38849 .48616 L p .38391 .48868 L .359 .797 .633 r
F P
0 g
s
.36857 .49714 m .38449 .48828 L p .38391 .48868 L .359 .797 .633 r
F P
0 g
s
.38449 .48828 m .3839 .48822 L p .38517 .4878 L .271 .766 .706 r
F P
0 g
s
.39781 .48362 m .40116 .48186 L p .39532 .48411 L 0 0 0 r
F P
0 g
s
.38449 .48827 m .39781 .48362 L .39532 .48411 L 0 0 0 r
F
.4116 .4804 m .40116 .48186 L .39781 .48362 L p .111 0 0 r
F P
0 g
s
.40871 .48187 m .4116 .4804 L p .40556 .48181 L .111 0 0 r
F P
0 g
s
.39781 .48362 m .40871 .48187 L p .40556 .48181 L .111 0 0 r
F P
0 g
s
.42003 .48089 m .4116 .4804 L .40871 .48187 L p .335 0 0 r
F P
0 g
s
.40871 .48187 m .41748 .48211 L .42003 .48089 L p .335 0 0 r
F P
0 g
s
.40871 .48187 m .4084 .48181 L p .41207 .48193 L 0 .571 .719 r
F P
0 g
s
.41748 .48211 m .40871 .48187 L p .41207 .48193 L 0 .571 .719 r
F P
0 g
s
.39781 .48362 m .39738 .48355 L p .40057 .48308 L .138 .682 .724 r
F P
0 g
s
.40871 .48187 m .39781 .48362 L p .40057 .48308 L .138 .682 .724 r
F P
0 g
s
.38449 .48828 m .38449 .48828 L p .38449 .48827 L 0 0 0 r
F P
0 g
s
.38449 .48828 m .39781 .48362 L p .38449 .48827 L 0 0 0 r
F P
0 g
s
.38849 .48616 m .38449 .48828 L p .38587 .48774 L 0 0 0 r
F P
0 g
s
.40116 .48186 m .38849 .48616 L p .38587 .48774 L 0 0 0 r
F P
0 g
s
.39781 .48362 m .38449 .48828 L p .38517 .4878 L .271 .766 .706 r
F P
0 g
s
.38849 .48616 m .3957 .482 L p .3907 .48482 L 0 0 0 r
F P
0 g
s
.40116 .51814 m .38849 .51384 L .3957 .518 L p 0 .509 .857 r
F P
0 g
s
.3957 .518 m .40728 .52162 L .40116 .51814 L p 0 .509 .857 r
F P
0 g
s
.52764 .59111 m .53656 .59933 L .54377 .60349 L p 0 .262 .747 r
F P
0 g
s
.55856 .61232 m .54377 .60349 L p .5415 .60225 L 0 .216 .626 r
F P
0 g
s
.55856 .61232 m .56324 .61526 L p .54378 .6035 L .379 0 0 r
F P
0 g
s
.54377 .60349 m .54377 .6035 L p .54378 .6035 L .379 0 0 r
F P
0 g
s
.54377 .6035 m .55856 .61232 L p .54378 .6035 L .379 0 0 r
F P
0 g
s
.5476 .6059 m .54377 .60349 L p .54824 .6062 L .379 0 0 r
F P
0 g
s
.56324 .61526 m .5476 .6059 L p .54824 .6062 L .379 0 0 r
F P
0 g
s
.5476 .6059 m .54785 .60644 L p .54685 .60555 L .501 0 0 r
F P
0 g
s
.53691 .59669 m .53371 .59467 L p .53858 .5986 L 0 .151 .639 r
F P
0 g
s
.5476 .60589 m .53691 .59669 L .53858 .5986 L 0 .151 .639 r
F
.52723 .58636 m .53371 .59467 L .53691 .59669 L p 0 .111 .652 r
F P
0 g
s
.52994 .58812 m .52723 .58636 L p .53147 .59088 L 0 .111 .652 r
F P
0 g
s
.53691 .59669 m .52994 .58812 L p .53147 .59088 L 0 .111 .652 r
F P
0 g
s
.52343 .57881 m .52723 .58636 L .52994 .58812 L p 0 .071 .633 r
F P
0 g
s
.52994 .58812 m .52577 .58041 L .52343 .57881 L p 0 .071 .633 r
F P
0 g
s
.52994 .58812 m .53004 .58842 L p .52832 .58519 L .635 .244 0 r
F P
0 g
s
.52577 .58041 m .52994 .58812 L p .52832 .58519 L .635 .244 0 r
F P
0 g
s
.53691 .59669 m .53707 .59709 L p .53506 .59457 L .575 .106 0 r
F P
0 g
s
.52994 .58812 m .53691 .59669 L p .53506 .59457 L .575 .106 0 r
F P
0 g
s
.5476 .6059 m .5476 .60589 L p .5476 .60589 L 0 .151 .639 r
F P
0 g
s
.5476 .60589 m .53691 .59669 L p .5476 .60589 L 0 .151 .639 r
F P
0 g
s
.54377 .60349 m .5476 .6059 L p .54645 .60496 L 0 .151 .639 r
F P
0 g
s
.53371 .59467 m .54377 .60349 L p .54645 .60496 L 0 .151 .639 r
F P
0 g
s
.53691 .59669 m .5476 .6059 L p .54685 .60555 L .501 0 0 r
F P
0 g
s
.54377 .60349 m .53656 .59933 L p .5415 .60225 L 0 .216 .626 r
F P
0 g
s
.55416 .335 m .56448 .36419 L .56424 .37105 L p 0 0 .462 r
F P
0 g
s
.33003 .53559 m .35015 .51206 L .35621 .50885 L p .747 .965 .683 r
F P
0 g
s
.61581 .62941 m .58537 .62374 L .57956 .62011 L p .375 0 0 r
F P
0 g
s
.54204 .51194 m .54886 .51229 L .54868 .5 L p .834 .671 .68 r
F P
0 g
s
.54868 .5 m .54169 .5 L .54204 .51194 L p .834 .671 .68 r
F P
0 g
s
.54169 .5 m .54868 .5 L .54886 .48771 L p .834 .692 .705 r
F P
0 g
s
.48932 .45762 m .48621 .45154 L .47566 .45784 L p .611 .404 .576 r
F P
0 g
s
.47566 .45784 m .47915 .46389 L .48932 .45762 L p .611 .404 .576 r
F P
0 g
s
.47915 .46389 m .47566 .45784 L .46492 .46383 L p .633 .411 .564 r
F P
0 g
s
.46864 .53044 m .46492 .53617 L .47566 .54216 L p .633 .622 .822 r
F P
0 g
s
.47566 .54216 m .47915 .53611 L .46864 .53044 L p .633 .622 .822 r
F P
0 g
s
.47915 .53611 m .47566 .54216 L .48621 .54846 L p .611 .594 .809 r
F P
0 g
s
.54292 .52307 m .54933 .52391 L .54886 .51229 L p .834 .649 .652 r
F P
0 g
s
.54886 .51229 m .54204 .51194 L .54292 .52307 L p .834 .649 .652 r
F P
0 g
s
.54886 .48771 m .54204 .48806 L .54169 .5 L p .834 .692 .705 r
F P
0 g
s
.54204 .48806 m .54886 .48771 L .54933 .47609 L p .834 .713 .731 r
F P
0 g
s
.46492 .46383 m .46864 .46956 L .47915 .46389 L p .633 .411 .564 r
F P
0 g
s
.46864 .46956 m .46492 .46383 L .45463 .46923 L p .654 .417 .548 r
F P
0 g
s
.49852 .45129 m .49604 .44532 L .48621 .45154 L p .586 .393 .587 r
F P
0 g
s
.48621 .45154 m .48932 .45762 L .49852 .45129 L p .586 .393 .587 r
F P
0 g
s
.48621 .54846 m .48932 .54238 L .47915 .53611 L p .611 .594 .809 r
F P
0 g
s
.48932 .54238 m .48621 .54846 L .49604 .55468 L p .586 .563 .795 r
F P
0 g
s
.45856 .52563 m .45463 .53077 L .46492 .53617 L p .654 .651 .835 r
F P
0 g
s
.46492 .53617 m .46864 .53044 L .45856 .52563 L p .654 .651 .835 r
F P
0 g
s
.71717 .12384 m .71536 .12699 L .70864 .123 L p .192 .54 .927 r
F P
0 g
s
.71536 .12699 m .71717 .12384 L .72088 .12592 L p .184 .529 .922 r
F P
0 g
s
.72088 .12592 m .72217 .13081 L .71536 .12699 L p .184 .529 .922 r
F P
0 g
s
.71717 .87616 m .71536 .87301 L .72217 .86919 L p .184 0 0 r
F P
0 g
s
.71536 .87301 m .71717 .87616 L .71352 .87833 L p .192 0 0 r
F P
0 g
s
.71352 .87833 m .70864 .877 L .71536 .87301 L p .192 0 0 r
F P
0 g
s
.06565 .5 m .06929 .5 L .06919 .50781 L p .997 .81 .453 r
F P
0 g
s
.06929 .5 m .06565 .5 L .0656 .49575 L p .997 .818 .462 r
F P
0 g
s
.0656 .49575 m .06919 .49219 L .06929 .5 L p .997 .818 .462 r
F P
0 g
s
.56095 .44796 m .55597 .4533 L .55566 .46298 L p .939 .857 .734 r
F P
0 g
s
.55597 .4533 m .56095 .44796 L .56104 .43931 L p .946 .905 .749 r
F P
0 g
s
.56508 .43051 m .56104 .43931 L .56095 .44796 L p .981 .914 .632 r
F P
0 g
s
.55627 .55436 m .56104 .56069 L .56095 .55204 L p .946 .64 .425 r
F P
0 g
s
.56095 .55204 m .55597 .5467 L .55627 .55436 L p .946 .64 .425 r
F P
0 g
s
.51894 .42409 m .52204 .41679 L .51459 .4212 L p .267 .03 .357 r
F P
0 g
s
.51459 .4212 m .51246 .42818 L .51894 .42409 L p .267 .03 .357 r
F P
0 g
s
.42446 .47323 m .43157 .47488 L .44011 .4703 L p .561 .189 .294 r
F P
0 g
s
.43157 .47488 m .42446 .47323 L .41692 .47748 L p .548 .127 .194 r
F P
0 g
s
.40728 .47838 m .41692 .47748 L .42446 .47323 L p .37 0 .003 r
F P
0 g
s
.51459 .5788 m .51246 .57182 L .50423 .56671 L p .369 .479 .841 r
F P
0 g
s
.51246 .57182 m .51459 .5788 L .52204 .58321 L p .266 .406 .817 r
F P
0 g
s
.52764 .59111 m .52204 .58321 L .51459 .5788 L p .13 .394 .846 r
F P
0 g
s
.42479 .52155 m .41692 .52252 L .42446 .52677 L p .548 .768 .979 r
F P
0 g
s
.42446 .52677 m .43157 .52512 L .42479 .52155 L p .548 .768 .979 r
F P
0 g
s
.5506 .54313 m .55597 .5467 L .55566 .53702 L p .885 .629 .546 r
F P
0 g
s
.55566 .53702 m .54995 .53432 L .5506 .54313 L p .885 .629 .546 r
F P
0 g
s
.55566 .46298 m .54995 .46568 L .54933 .47609 L p .88 .778 .745 r
F P
0 g
s
.54995 .46568 m .55566 .46298 L .55597 .4533 L p .885 .816 .775 r
F P
0 g
s
.44011 .4703 m .4453 .4739 L .45463 .46923 L p .631 .338 .455 r
F P
0 g
s
.4453 .4739 m .44011 .4703 L .43157 .47488 L p .647 .323 .409 r
F P
0 g
s
.51205 .43462 m .51246 .42818 L .50423 .43329 L p .449 .255 .523 r
F P
0 g
s
.50423 .43329 m .50474 .43958 L .51205 .43462 L p .449 .255 .523 r
F P
0 g
s
.50423 .56671 m .50474 .56042 L .49604 .55468 L p .504 .529 .815 r
F P
0 g
s
.50474 .56042 m .50423 .56671 L .51246 .57182 L p .449 .479 .798 r
F P
0 g
s
.43735 .52225 m .43157 .52512 L .44011 .5297 L p .647 .734 .912 r
F P
0 g
s
.44011 .5297 m .4453 .5261 L .43735 .52225 L p .647 .734 .912 r
F P
0 g
s
.71352 .12167 m .70864 .123 L .70231 .119 L p .194 .548 .93 r
F P
0 g
s
.70864 .123 m .71352 .12167 L .71717 .12384 L p .192 .54 .927 r
F P
0 g
s
.72217 .13081 m .72088 .12592 L .72448 .12781 L p .168 .516 .916 r
F P
0 g
s
.72448 .12781 m .7288 .13429 L .72217 .13081 L p .168 .516 .916 r
F P
0 g
s
.70864 .877 m .71352 .87833 L .71008 .8805 L p .194 0 0 r
F P
0 g
s
.71008 .8805 m .70231 .881 L .70864 .877 L p .194 0 0 r
F P
0 g
s
.72088 .87408 m .72217 .86919 L .7288 .86571 L p .168 0 0 r
F P
0 g
s
.72217 .86919 m .72088 .87408 L .71717 .87616 L p .184 0 0 r
F P
0 g
s
.0656 .50425 m .06919 .50781 L .06889 .51529 L p .996 .801 .438 r
F P
0 g
s
.06919 .50781 m .0656 .50425 L .06565 .5 L p .997 .81 .453 r
F P
0 g
s
.06919 .49219 m .0656 .49575 L .06543 .49169 L p .996 .825 .467 r
F P
0 g
s
.06543 .49169 m .06889 .48471 L .06919 .49219 L p .996 .825 .467 r
F P
0 g
s
.54933 .47609 m .54292 .47693 L .54204 .48806 L p .834 .713 .731 r
F P
0 g
s
.54292 .47693 m .54933 .47609 L .54995 .46568 L p .835 .74 .759 r
F P
0 g
s
.54402 .53287 m .54995 .53432 L .54933 .52391 L p .835 .623 .617 r
F P
0 g
s
.54933 .52391 m .54292 .52307 L .54402 .53287 L p .835 .623 .617 r
F P
0 g
s
.50646 .44544 m .50474 .43958 L .49604 .44532 L p .553 .377 .597 r
F P
0 g
s
.49604 .44532 m .49852 .45129 L .50646 .44544 L p .553 .377 .597 r
F P
0 g
s
.45463 .46923 m .45856 .47437 L .46864 .46956 L p .654 .417 .548 r
F P
0 g
s
.45856 .47437 m .45463 .46923 L .4453 .4739 L p .677 .42 .526 r
F P
0 g
s
.49604 .55468 m .49852 .54871 L .48932 .54238 L p .586 .563 .795 r
F P
0 g
s
.49852 .54871 m .49604 .55468 L .50474 .56042 L p .553 .526 .779 r
F P
0 g
s
.44952 .52169 m .4453 .5261 L .45463 .53077 L p .677 .685 .851 r
F P
0 g
s
.45463 .53077 m .45856 .52563 L .44952 .52169 L p .677 .685 .851 r
F P
0 g
s
.7288 .13429 m .72448 .12781 L .72783 .12943 L p .147 .499 .908 r
F P
0 g
s
.72783 .12943 m .73496 .13729 L .7288 .13429 L p .147 .499 .908 r
F P
0 g
s
.06889 .48471 m .06543 .49169 L .06517 .48798 L p .994 .831 .467 r
F P
0 g
s
.06517 .48798 m .0684 .47788 L .06889 .48471 L p .994 .831 .467 r
F P
0 g
s
.71008 .1195 m .70231 .119 L .69664 .11516 L p .188 .553 .932 r
F P
0 g
s
.70231 .119 m .71008 .1195 L .71352 .12167 L p .194 .548 .93 r
F P
0 g
s
.70231 .881 m .71008 .8805 L .70701 .88259 L p .188 0 0 r
F P
0 g
s
.70701 .88259 m .69664 .88484 L .70231 .881 L p .188 0 0 r
F P
0 g
s
.72448 .87219 m .7288 .86571 L .73496 .86271 L p .147 0 0 r
F P
0 g
s
.7288 .86571 m .72448 .87219 L .72088 .87408 L p .168 0 0 r
F P
0 g
s
.06543 .50831 m .06889 .51529 L .0684 .52212 L p .994 .792 .419 r
F P
0 g
s
.06889 .51529 m .06543 .50831 L .0656 .50425 L p .996 .801 .438 r
F P
0 g
s
.56117 .56676 m .56513 .57653 L .56508 .56949 L p .952 .625 .211 r
F P
0 g
s
.56508 .56949 m .56104 .56069 L .56117 .56676 L p .952 .625 .211 r
F P
0 g
s
.56104 .43931 m .56508 .43051 L .56513 .42347 L p .952 .929 .583 r
F P
0 g
s
.56774 .41035 m .56513 .42347 L .56508 .43051 L p .89 .817 .341 r
F P
0 g
s
.41692 .47748 m .40728 .47838 L .40116 .48186 L p .281 0 0 r
F P
0 g
s
.38849 .48616 m .40116 .48186 L .40728 .47838 L p 0 0 0 r
F P
0 g
s
.52723 .41364 m .53371 .40533 L .52764 .40889 L p 0 0 .01 r
F P
0 g
s
.52764 .40889 m .52204 .41679 L .52723 .41364 L p 0 0 .01 r
F P
0 g
s
.52204 .58321 m .52764 .59111 L .53371 .59467 L p 0 .282 .784 r
F P
0 g
s
.54377 .60349 m .53371 .59467 L .52764 .59111 L p 0 .262 .747 r
F P
0 g
s
.4116 .5196 m .40116 .51814 L .40728 .52162 L p .281 .698 .971 r
F P
0 g
s
.40728 .52162 m .41692 .52252 L .4116 .5196 L p .281 .698 .971 r
F P
0 g
s
.53477 .51214 m .54204 .51194 L .54169 .5 L p .8 .643 .688 r
F P
0 g
s
.54169 .5 m .53412 .5 L .53477 .51214 L p .8 .643 .688 r
F P
0 g
s
.53412 .5 m .54169 .5 L .54204 .48806 L p .8 .662 .711 r
F P
0 g
s
.49313 .46382 m .48932 .45762 L .47915 .46389 L p .64 .457 .619 r
F P
0 g
s
.47915 .46389 m .48294 .47045 L .49313 .46382 L p .64 .457 .619 r
F P
0 g
s
.48294 .47045 m .47915 .46389 L .46864 .46956 L p .66 .464 .608 r
F P
0 g
s
.4721 .52404 m .46864 .53044 L .47915 .53611 L p .66 .614 .792 r
F P
0 g
s
.47915 .53611 m .48294 .52955 L .4721 .52404 L p .66 .614 .792 r
F P
0 g
s
.48294 .52955 m .47915 .53611 L .48932 .54238 L p .64 .588 .78 r
F P
0 g
s
.56791 .59418 m .5682 .61239 L .56799 .60687 L p 0 0 .027 r
F P
0 g
s
.56782 .59516 m .56774 .58965 L .56791 .59418 L p 0 0 .027 r
F P
0 g
s
.56528 .58031 m .56791 .59418 L .56774 .58965 L p .795 .545 0 r
F P
0 g
s
.56774 .58965 m .56672 .58451 L p .56528 .58031 L .795 .545 0 r
F P
0 g
s
.56672 .58451 m .56513 .57653 L .56528 .58031 L p .795 .545 0 r
F P
0 g
s
.56134 .56999 m .56528 .58031 L .56513 .57653 L p .853 .506 0 r
F P
0 g
s
.56513 .57653 m .56481 .57574 L p .56134 .56999 L .853 .506 0 r
F P
0 g
s
.56481 .57574 m .56117 .56676 L .56134 .56999 L p .853 .506 0 r
F P
0 g
s
.55675 .56252 m .56134 .56999 L .56117 .56676 L p .866 .445 .007 r
F P
0 g
s
.55691 .5627 m .55874 .56566 L p .56134 .56999 L 0 0 .383 r
F P
0 g
s
.55874 .56566 m .56155 .57023 L .56134 .56999 L p 0 0 .383 r
F P
0 g
s
.56155 .57023 m .56409 .57684 L p .56528 .58031 L 0 0 .279 r
F P
0 g
s
.56409 .57684 m .56555 .58064 L .56528 .58031 L p 0 0 .279 r
F P
0 g
s
.56555 .58064 m .56799 .59328 L p .56791 .59418 L 0 0 .172 r
F P
0 g
s
.56799 .59328 m .56825 .59465 L .56791 .59418 L p 0 0 .172 r
F P
0 g
s
.56799 .60687 m .56782 .59516 L p .56791 .59418 L 0 0 .027 r
F P
0 g
s
.5476 .3941 m .56324 .38474 L .55856 .38768 L p .379 .804 .621 r
F P
0 g
s
.5485 .39369 m .54377 .39651 L .5476 .3941 L p .379 .804 .621 r
F P
0 g
s
.53691 .40331 m .5476 .3941 L .54377 .39651 L p 0 0 0 r
F P
0 g
s
.54377 .39651 m .53983 .39996 L p .53691 .40331 L 0 0 0 r
F P
0 g
s
.53983 .39996 m .53371 .40533 L .53691 .40331 L p 0 0 0 r
F P
0 g
s
.52994 .41188 m .53691 .40331 L .53371 .40533 L p 0 0 0 r
F P
0 g
s
.53371 .40533 m .53319 .406 L p .52994 .41188 L 0 0 0 r
F P
0 g
s
.53319 .406 m .52723 .41364 L .52994 .41188 L p 0 0 0 r
F P
0 g
s
.52577 .41959 m .52994 .41188 L .52723 .41364 L p 0 0 .021 r
F P
0 g
s
.52584 .41936 m .52749 .41631 L p .52994 .41188 L .635 .793 .349 r
F P
0 g
s
.52749 .41631 m .53004 .41158 L .52994 .41188 L p .635 .793 .349 r
F P
0 g
s
.53004 .41158 m .5345 .40607 L p .53691 .40331 L .575 .833 .472 r
F P
0 g
s
.5345 .40607 m .53707 .40291 L .53691 .40331 L p .575 .833 .472 r
F P
0 g
s
.53707 .40291 m .54678 .39448 L p .5476 .3941 L .501 .845 .574 r
F P
0 g
s
.54678 .39448 m .54785 .39356 L .5476 .3941 L p .501 .845 .574 r
F P
0 g
s
.55856 .38768 m .5485 .39369 L p .5476 .3941 L .379 .804 .621 r
F P
0 g
s
.38449 .51172 m .36857 .50286 L .37345 .50545 L p .358 0 0 r
F P
0 g
s
.38368 .51116 m .38849 .51384 L .38449 .51172 L p .358 0 0 r
F P
0 g
s
.39781 .51638 m .38449 .51172 L .38849 .51384 L p 0 .435 .766 r
F P
0 g
s
.38849 .51384 m .39345 .51552 L p .39781 .51638 L 0 .435 .766 r
F P
0 g
s
.39345 .51552 m .40116 .51814 L .39781 .51638 L p 0 .435 .766 r
F P
0 g
s
.40871 .51813 m .39781 .51638 L .40116 .51814 L p .111 .63 .885 r
F P
0 g
s
.40116 .51814 m .402 .51825 L p .40871 .51813 L .111 .63 .885 r
F P
0 g
s
.402 .51825 m .4116 .5196 L .40871 .51813 L p .111 .63 .885 r
F P
0 g
s
.41748 .51789 m .40871 .51813 L .4116 .5196 L p .335 .786 .954 r
F P
0 g
s
.41725 .51794 m .41377 .51804 L p .40871 .51813 L 0 0 0 r
F P
0 g
s
.41377 .51804 m .4084 .51819 L .40871 .51813 L p 0 0 0 r
F P
0 g
s
.4084 .51819 m .40141 .51708 L p .39781 .51638 L .138 0 0 r
F P
0 g
s
.40141 .51708 m .39738 .51645 L .39781 .51638 L p .138 0 0 r
F P
0 g
s
.39738 .51645 m .38523 .51224 L p .38449 .51172 L .271 0 0 r
F P
0 g
s
.38523 .51224 m .3839 .51178 L .38449 .51172 L p .271 0 0 r
F P
0 g
s
.37345 .50545 m .38368 .51116 L p .38449 .51172 L .358 0 0 r
F P
0 g
s
.53629 .52314 m .54292 .52307 L .54204 .51194 L p .798 .622 .663 r
F P
0 g
s
.54204 .51194 m .53477 .51214 L .53629 .52314 L p .798 .622 .663 r
F P
0 g
s
.54204 .48806 m .53477 .48786 L .53412 .5 L p .8 .662 .711 r
F P
0 g
s
.53477 .48786 m .54204 .48806 L .54292 .47693 L p .798 .681 .736 r
F P
0 g
s
.50189 .45701 m .49852 .45129 L .48932 .45762 L p .618 .45 .632 r
F P
0 g
s
.48932 .45762 m .49313 .46382 L .50189 .45701 L p .618 .45 .632 r
F P
0 g
s
.46864 .46956 m .4721 .47596 L .48294 .47045 L p .66 .464 .608 r
F P
0 g
s
.4721 .47596 m .46864 .46956 L .45856 .47437 L p .681 .472 .596 r
F P
0 g
s
.46182 .51986 m .45856 .52563 L .46864 .53044 L p .681 .641 .803 r
F P
0 g
s
.46864 .53044 m .4721 .52404 L .46182 .51986 L p .681 .641 .803 r
F P
0 g
s
.48932 .54238 m .49313 .53618 L .48294 .52955 L p .64 .588 .78 r
F P
0 g
s
.49313 .53618 m .48932 .54238 L .49852 .54871 L p .618 .56 .767 r
F P
0 g
s
.76148 .15756 m .74484 .14133 L .74813 .1422 L p .076 .424 .869 r
F P
0 g
s
.74813 .1422 m .7671 .15908 L .76148 .15756 L p .076 .424 .869 r
F P
0 g
s
.66583 .89767 m .68819 .89137 L .68579 .89379 L p .216 0 0 r
F P
0 g
s
.68579 .89379 m .66169 .90178 L .66583 .89767 L p .216 0 0 r
F P
0 g
s
.0727 .44478 m .06696 .46729 L .06607 .46401 L p .984 .87 .506 r
F P
0 g
s
.06607 .46401 m .0712 .43914 L .0727 .44478 L p .984 .87 .506 r
F P
0 g
s
.62596 .09056 m .66169 .09822 L .66583 .10233 L p .335 .681 .979 r
F P
0 g
s
.68819 .10863 m .66583 .10233 L .66169 .09822 L p .216 .605 .95 r
F P
0 g
s
.66583 .10233 m .68819 .10863 L .69186 .11166 L p .258 .613 .956 r
F P
0 g
s
.7916 .81381 m .7671 .84092 L .76148 .84244 L p .12 0 .105 r
F P
0 g
s
.74484 .85867 m .76148 .84244 L .7671 .84092 L p .076 0 0 r
F P
0 g
s
.76148 .84244 m .74484 .85867 L .74038 .86033 L p .141 0 .039 r
F P
0 g
s
.08243 .59563 m .0712 .56086 L .0727 .55522 L p .984 .702 .355 r
F P
0 g
s
.06696 .53271 m .0727 .55522 L .0712 .56086 L p .984 .738 .345 r
F P
0 g
s
.0727 .55522 m .06696 .53271 L .06775 .52801 L p .993 .756 .396 r
F P
0 g
s
.5451 .54104 m .5506 .54313 L .54995 .53432 L p .836 .591 .568 r
F P
0 g
s
.54995 .53432 m .54402 .53287 L .5451 .54104 L p .836 .591 .568 r
F P
0 g
s
.54995 .46568 m .54402 .46713 L .54292 .47693 L p .835 .74 .759 r
F P
0 g
s
.54402 .46713 m .54995 .46568 L .5506 .45687 L p .836 .774 .793 r
F P
0 g
s
.55597 .4533 m .5506 .45687 L .54995 .46568 L p .885 .816 .775 r
F P
0 g
s
.513 .44042 m .51205 .43462 L .50474 .43958 L p .506 .349 .603 r
F P
0 g
s
.50474 .43958 m .50646 .44544 L .513 .44042 L p .506 .349 .603 r
F P
0 g
s
.4453 .4739 m .44952 .47831 L .45856 .47437 L p .677 .42 .526 r
F P
0 g
s
.44952 .47831 m .4453 .4739 L .43735 .47775 L p .7 .416 .49 r
F P
0 g
s
.43157 .47488 m .43735 .47775 L .4453 .4739 L p .647 .323 .409 r
F P
0 g
s
.50474 .56042 m .50646 .55456 L .49852 .54871 L p .553 .526 .779 r
F P
0 g
s
.50646 .55456 m .50474 .56042 L .51205 .56538 L p .506 .477 .759 r
F P
0 g
s
.51246 .57182 m .51205 .56538 L .50474 .56042 L p .449 .479 .798 r
F P
0 g
s
.44191 .51853 m .43735 .52225 L .4453 .5261 L p .7 .727 .871 r
F P
0 g
s
.4453 .5261 m .44952 .52169 L .44191 .51853 L p .7 .727 .871 r
F P
0 g
s
.5506 .45687 m .55597 .4533 L .55627 .44564 L p .893 .869 .807 r
F P
0 g
s
.56104 .43931 m .55627 .44564 L .55597 .4533 L p .946 .905 .749 r
F P
0 g
s
.55117 .55004 m .55627 .55436 L .55597 .5467 L p .893 .59 .465 r
F P
0 g
s
.55597 .5467 m .5506 .54313 L .55117 .55004 L p .893 .59 .465 r
F P
0 g
s
.51775 .43067 m .51894 .42409 L .51246 .42818 L p .36 .182 .5 r
F P
0 g
s
.51246 .42818 m .51205 .43462 L .51775 .43067 L p .36 .182 .5 r
F P
0 g
s
.43735 .47775 m .43157 .47488 L .42479 .47845 L p .656 .284 .329 r
F P
0 g
s
.41692 .47748 m .42479 .47845 L .43157 .47488 L p .548 .127 .194 r
F P
0 g
s
.51205 .56538 m .51246 .57182 L .51894 .57591 L p .36 .406 .773 r
F P
0 g
s
.52204 .58321 m .51894 .57591 L .51246 .57182 L p .266 .406 .817 r
F P
0 g
s
.43108 .51929 m .42479 .52155 L .43157 .52512 L p .656 .787 .944 r
F P
0 g
s
.43157 .52512 m .43735 .52225 L .43108 .51929 L p .656 .787 .944 r
F P
0 g
s
.57128 .0809 m .6229 .08595 L .62596 .09056 L p .386 .758 .992 r
F P
0 g
s
.66169 .09822 m .62596 .09056 L .6229 .08595 L p .259 .665 .966 r
F P
0 g
s
.7916 .18619 m .7671 .15908 L .77052 .1592 L p .005 .338 .819 r
F P
0 g
s
.77052 .1592 m .79713 .18653 L .7916 .18619 L p .005 .338 .819 r
F P
0 g
s
.62596 .90944 m .66169 .90178 L .65988 .90468 L p .259 0 0 r
F P
0 g
s
.65988 .90468 m .6229 .91405 L .62596 .90944 L p .259 0 0 r
F P
0 g
s
.82731 .77129 m .79713 .81347 L .7916 .81381 L p .013 0 .124 r
F P
0 g
s
.7671 .84092 m .7916 .81381 L .79713 .81347 L p .005 0 .001 r
F P
0 g
s
.08243 .40437 m .0712 .43914 L .06959 .43612 L p .967 .909 .557 r
F P
0 g
s
.06959 .43612 m .07997 .39941 L .08243 .40437 L p .967 .909 .557 r
F P
0 g
s
.1014 .64782 m .07997 .60059 L .08243 .59563 L p .951 .6 .234 r
F P
0 g
s
.0712 .56086 m .08243 .59563 L .07997 .60059 L p .967 .67 .264 r
F P
0 g
s
.73496 .13729 m .72783 .12943 L .73077 .13072 L p .118 .481 .898 r
F P
0 g
s
.73077 .13072 m .74038 .13967 L .73496 .13729 L p .118 .481 .898 r
F P
0 g
s
.70701 .11741 m .69664 .11516 L .69186 .11166 L p .175 .554 .931 r
F P
0 g
s
.69664 .11516 m .70701 .11741 L .71008 .1195 L p .188 .553 .932 r
F P
0 g
s
.72783 .87057 m .73496 .86271 L .74038 .86033 L p .118 0 0 r
F P
0 g
s
.73496 .86271 m .72783 .87057 L .72448 .87219 L p .147 0 0 r
F P
0 g
s
.69664 .88484 m .70701 .88259 L .70442 .88449 L p .175 0 0 r
F P
0 g
s
.70442 .88449 m .69186 .88834 L .69664 .88484 L p .175 0 0 r
F P
0 g
s
.0684 .47788 m .06517 .48798 L .06481 .48479 L p .99 .835 .461 r
F P
0 g
s
.06481 .48479 m .06775 .47199 L .0684 .47788 L p .99 .835 .461 r
F P
0 g
s
.06517 .51202 m .0684 .52212 L .06775 .52801 L p .99 .781 .395 r
F P
0 g
s
.0684 .52212 m .06517 .51202 L .06543 .50831 L p .994 .792 .419 r
F P
0 g
s
.2947 .68564 m .31552 .76011 L .31227 .76469 L p .849 .545 .012 r
F P
0 g
s
.29134 .31132 m .31227 .23531 L .31552 .23989 L p .849 .842 .376 r
F P
0 g
s
.31552 .23989 m .2947 .31436 L .29134 .31132 L p .849 .842 .376 r
F P
0 g
s
.76773 .41363 m .8231 .46977 L .8175 .47029 L p 0 .151 .67 r
F P
0 g
s
.8175 .47029 m .76341 .41503 L .76773 .41363 L p 0 .151 .67 r
F P
0 g
s
.44188 .22939 m .36698 .21018 L .36464 .20507 L p .024 .557 .852 r
F P
0 g
s
.76341 .58497 m .8175 .52971 L .8231 .53023 L p 0 0 0 r
F P
0 g
s
.44093 .77504 m .36464 .79493 L .36698 .78982 L p .024 0 0 r
F P
0 g
s
.36698 .78982 m .44188 .77061 L .44093 .77504 L p .024 0 0 r
F P
0 g
s
.53804 .53253 m .54402 .53287 L .54292 .52307 L p .795 .595 .631 r
F P
0 g
s
.54292 .52307 m .53629 .52314 L .53804 .53253 L p .795 .595 .631 r
F P
0 g
s
.54292 .47693 m .53629 .47686 L .53477 .48786 L p .798 .681 .736 r
F P
0 g
s
.53629 .47686 m .54292 .47693 L .54402 .46713 L p .795 .704 .764 r
F P
0 g
s
.45856 .47437 m .46182 .48014 L .4721 .47596 L p .681 .472 .596 r
F P
0 g
s
.46182 .48014 m .45856 .47437 L .44952 .47831 L p .706 .48 .579 r
F P
0 g
s
.50916 .45079 m .50646 .44544 L .49852 .45129 L p .59 .44 .645 r
F P
0 g
s
.49852 .45129 m .50189 .45701 L .50916 .45079 L p .59 .44 .645 r
F P
0 g
s
.45281 .51668 m .44952 .52169 L .45856 .52563 L p .706 .673 .815 r
F P
0 g
s
.45856 .52563 m .46182 .51986 L .45281 .51668 L p .706 .673 .815 r
F P
0 g
s
.49852 .54871 m .50189 .54299 L .49313 .53618 L p .618 .56 .767 r
F P
0 g
s
.50189 .54299 m .49852 .54871 L .50646 .55456 L p .59 .524 .749 r
F P
0 g
s
.43129 .11586 m .36311 .1688 L .36074 .16307 L p .663 .966 .782 r
F P
0 g
s
.85527 .45295 m .86703 .36744 L .87265 .36541 L p 0 0 .175 r
F P
0 g
s
.87265 .36541 m .86143 .45214 L .85527 .45295 L p 0 0 .175 r
F P
0 g
s
.86703 .63256 m .85527 .54705 L .86143 .54786 L p 0 0 .349 r
F P
0 g
s
.20168 .75158 m .28162 .78415 L .27784 .78907 L p .512 0 0 r
F P
0 g
s
.36311 .8312 m .43129 .88414 L .43023 .89002 L p .663 .116 0 r
F P
0 g
s
.43023 .89002 m .36074 .83693 L .36311 .8312 L p .663 .116 0 r
F P
0 g
s
.28162 .21585 m .20168 .24842 L .19711 .24457 L p .512 .914 .869 r
F P
0 g
s
.19711 .24457 m .27784 .21093 L .28162 .21585 L p .512 .914 .869 r
F P
0 g
s
.52704 .51303 m .53477 .51214 L .53412 .5 L p .77 .62 .694 r
F P
0 g
s
.53412 .5 m .52579 .5 L .52704 .51303 L p .77 .62 .694 r
F P
0 g
s
.52579 .5 m .53412 .5 L .53477 .48786 L p .77 .636 .714 r
F P
0 g
s
.49777 .47007 m .49313 .46382 L .48294 .47045 L p .663 .499 .652 r
F P
0 g
s
.48294 .47045 m .4871 .47766 L .49777 .47007 L p .663 .499 .652 r
F P
0 g
s
.4871 .47766 m .48294 .47045 L .4721 .47596 L p .68 .505 .642 r
F P
0 g
s
.47519 .5169 m .4721 .52404 L .48294 .52955 L p .68 .605 .766 r
F P
0 g
s
.48294 .52955 m .4871 .52234 L .47519 .5169 L p .68 .605 .766 r
F P
0 g
s
.4871 .52234 m .48294 .52955 L .49313 .53618 L p .663 .584 .756 r
F P
0 g
s
.29315 .37757 m .29134 .31132 L .2947 .31436 L p .848 .679 .143 r
F P
0 g
s
.2947 .31436 m .29606 .37929 L .29315 .37757 L p .848 .679 .143 r
F P
0 g
s
.49739 .74035 m .44093 .77504 L .44188 .77061 L p 0 0 0 r
F P
0 g
s
.44188 .77061 m .49743 .73698 L .49739 .74035 L p 0 0 0 r
F P
0 g
s
.70945 .38208 m .76773 .41363 L .76341 .41503 L p 0 .354 .764 r
F P
0 g
s
.76341 .41503 m .70651 .38374 L .70945 .38208 L p 0 .354 .764 r
F P
0 g
s
.49743 .26302 m .44188 .22939 L .44093 .22496 L p 0 .317 .748 r
F P
0 g
s
.36464 .20507 m .44093 .22496 L .44188 .22939 L p .024 .557 .852 r
F P
0 g
s
.29606 .62071 m .2947 .68564 L .29134 .68868 L p .848 .706 .176 r
F P
0 g
s
.31227 .76469 m .29134 .68868 L .2947 .68564 L p .849 .545 .012 r
F P
0 g
s
.70651 .61626 m .76341 .58497 L .76773 .58637 L p 0 0 0 r
F P
0 g
s
.8231 .53023 m .76773 .58637 L .76341 .58497 L p 0 0 0 r
F P
0 g
s
.55653 .5597 m .56117 .56676 L .56104 .56069 L p .941 .579 .275 r
F P
0 g
s
.56104 .56069 m .55627 .55436 L .55653 .5597 L p .941 .579 .275 r
F P
0 g
s
.55627 .44564 m .56104 .43931 L .56117 .43324 L p .941 .959 .741 r
F P
0 g
s
.56513 .42347 m .56117 .43324 L .56104 .43931 L p .952 .929 .583 r
F P
0 g
s
.42479 .47845 m .41692 .47748 L .4116 .4804 L p .493 .001 .016 r
F P
0 g
s
.40116 .48186 m .4116 .4804 L .41692 .47748 L p .281 0 0 r
F P
0 g
s
.52343 .42119 m .52723 .41364 L .52204 .41679 L p .09 0 .249 r
F P
0 g
s
.52204 .41679 m .51894 .42409 L .52343 .42119 L p .09 0 .249 r
F P
0 g
s
.42003 .51911 m .4116 .5196 L .41692 .52252 L p .493 .804 1 r
F P
0 g
s
.41692 .52252 m .42479 .52155 L .42003 .51911 L p .493 .804 1 r
F P
0 g
s
.51894 .57591 m .52204 .58321 L .52723 .58636 L p .09 .285 .767 r
F P
0 g
s
.53371 .59467 m .52723 .58636 L .52204 .58321 L p 0 .282 .784 r
F P
0 g
s
.53477 .48786 m .52704 .48697 L .52579 .5 L p .77 .636 .714 r
F P
0 g
s
.52704 .48697 m .53477 .48786 L .53629 .47686 L p .767 .652 .735 r
F P
0 g
s
.52957 .52412 m .53629 .52314 L .53477 .51214 L p .767 .6 .672 r
F P
0 g
s
.53477 .51214 m .52704 .51303 L .52957 .52412 L p .767 .6 .672 r
F P
0 g
s
.50611 .46233 m .50189 .45701 L .49313 .46382 L p .645 .495 .665 r
F P
0 g
s
.49313 .46382 m .49777 .47007 L .50611 .46233 L p .645 .495 .665 r
F P
0 g
s
.4721 .47596 m .47519 .4831 L .4871 .47766 L p .68 .505 .642 r
F P
0 g
s
.47519 .4831 m .4721 .47596 L .46182 .48014 L p .699 .514 .633 r
F P
0 g
s
.46432 .51355 m .46182 .51986 L .4721 .52404 L p .699 .628 .774 r
F P
0 g
s
.4721 .52404 m .47519 .5169 L .46432 .51355 L p .699 .628 .774 r
F P
0 g
s
.49313 .53618 m .49777 .52993 L .4871 .52234 L p .663 .584 .756 r
F P
0 g
s
.49777 .52993 m .49313 .53618 L .50189 .54299 L p .645 .558 .742 r
F P
0 g
s
.53967 .54023 m .5451 .54104 L .54402 .53287 L p .792 .559 .585 r
F P
0 g
s
.54402 .53287 m .53804 .53253 L .53967 .54023 L p .792 .559 .585 r
F P
0 g
s
.54402 .46713 m .53804 .46747 L .53629 .47686 L p .795 .704 .764 r
F P
0 g
s
.53804 .46747 m .54402 .46713 L .5451 .45896 L p .792 .733 .798 r
F P
0 g
s
.5506 .45687 m .5451 .45896 L .54402 .46713 L p .836 .774 .793 r
F P
0 g
s
.515 .44553 m .513 .44042 L .50646 .44544 L p .55 .422 .659 r
F P
0 g
s
.50646 .44544 m .50916 .45079 L .515 .44553 L p .55 .422 .659 r
F P
0 g
s
.44952 .47831 m .45281 .48332 L .46182 .48014 L p .706 .48 .579 r
F P
0 g
s
.45281 .48332 m .44952 .47831 L .44191 .48147 L p .734 .486 .552 r
F P
0 g
s
.43735 .47775 m .44191 .48147 L .44952 .47831 L p .7 .416 .49 r
F P
0 g
s
.50646 .55456 m .50916 .54921 L .50189 .54299 L p .59 .524 .749 r
F P
0 g
s
.50916 .54921 m .50646 .55456 L .513 .55958 L p .55 .476 .725 r
F P
0 g
s
.51205 .56538 m .513 .55958 L .50646 .55456 L p .506 .477 .759 r
F P
0 g
s
.44533 .51424 m .44191 .51853 L .44952 .52169 L p .734 .714 .832 r
F P
0 g
s
.44952 .52169 m .45281 .51668 L .44533 .51424 L p .734 .714 .832 r
F P
0 g
s
.53629 .47686 m .52957 .47588 L .52704 .48697 L p .767 .652 .735 r
F P
0 g
s
.52957 .47588 m .53629 .47686 L .53804 .46747 L p .761 .67 .762 r
F P
0 g
s
.53219 .53321 m .53804 .53253 L .53629 .52314 L p .761 .573 .643 r
F P
0 g
s
.53629 .52314 m .52957 .52412 L .53219 .53321 L p .761 .573 .643 r
F P
0 g
s
.51267 .45552 m .50916 .45079 L .50189 .45701 L p .621 .49 .681 r
F P
0 g
s
.50189 .45701 m .50611 .46233 L .51267 .45552 L p .621 .49 .681 r
F P
0 g
s
.46182 .48014 m .46432 .48645 L .47519 .4831 L p .699 .514 .633 r
F P
0 g
s
.46432 .48645 m .46182 .48014 L .45281 .48332 L p .724 .526 .622 r
F P
0 g
s
.50189 .54299 m .50611 .53767 L .49777 .52993 L p .645 .558 .742 r
F P
0 g
s
.50611 .53767 m .50189 .54299 L .50916 .54921 L p .621 .524 .723 r
F P
0 g
s
.45514 .51127 m .45281 .51668 L .46182 .51986 L p .724 .657 .783 r
F P
0 g
s
.46182 .51986 m .46432 .51355 L .45514 .51127 L p .724 .657 .783 r
F P
0 g
s
.43129 .88414 m .50526 .91211 L .50532 .91715 L p .51 0 0 r
F P
0 g
s
.50532 .91715 m .43023 .89002 L .43129 .88414 L p .51 0 0 r
F P
0 g
s
.86703 .36744 m .85427 .28939 L .8586 .28681 L p 0 0 .395 r
F P
0 g
s
.8586 .28681 m .87265 .36541 L .86703 .36744 L p 0 0 .395 r
F P
0 g
s
.36074 .16307 m .43023 .10998 L .43129 .11586 L p .663 .966 .782 r
F P
0 g
s
.50526 .08789 m .43129 .11586 L .43023 .10998 L p .51 .912 .893 r
F P
0 g
s
.20168 .24842 m .14048 .2985 L .13607 .29603 L p .699 .977 .784 r
F P
0 g
s
.13607 .29603 m .19711 .24457 L .20168 .24842 L p .699 .977 .784 r
F P
0 g
s
.86143 .54786 m .87265 .63459 L .86703 .63256 L p 0 0 .349 r
F P
0 g
s
.85427 .71061 m .86703 .63256 L .87265 .63459 L p 0 0 .177 r
F P
0 g
s
.27784 .78907 m .19711 .75543 L .20168 .75158 L p .512 0 0 r
F P
0 g
s
.14048 .7015 m .20168 .75158 L .19711 .75543 L p .699 .165 0 r
F P
0 g
s
.54601 .5474 m .55117 .55004 L .5506 .54313 L p .838 .545 .493 r
F P
0 g
s
.5506 .54313 m .5451 .54104 L .54601 .5474 L p .838 .545 .493 r
F P
0 g
s
.5451 .45896 m .5506 .45687 L .55117 .44996 L p .838 .823 .834 r
F P
0 g
s
.55627 .44564 m .55117 .44996 L .5506 .45687 L p .893 .869 .807 r
F P
0 g
s
.44191 .48147 m .43735 .47775 L .43108 .48071 L p .724 .399 .428 r
F P
0 g
s
.42479 .47845 m .43108 .48071 L .43735 .47775 L p .656 .284 .329 r
F P
0 g
s
.51804 .43645 m .51775 .43067 L .51205 .43462 L p .429 .297 .598 r
F P
0 g
s
.51205 .43462 m .513 .44042 L .51804 .43645 L p .429 .297 .598 r
F P
0 g
s
.513 .55958 m .51205 .56538 L .51775 .56933 L p .429 .404 .729 r
F P
0 g
s
.51894 .57591 m .51775 .56933 L .51205 .56538 L p .36 .406 .773 r
F P
0 g
s
.43595 .51615 m .43108 .51929 L .43735 .52225 L p .724 .784 .9 r
F P
0 g
s
.43735 .52225 m .44191 .51853 L .43595 .51615 L p .724 .784 .9 r
F P
0 g
s
.51886 .51497 m .52704 .51303 L .52579 .5 L p .743 .601 .699 r
F P
0 g
s
.52579 .5 m .51609 .5 L .51886 .51497 L p .743 .601 .699 r
F P
0 g
s
.51609 .5 m .52579 .5 L .52704 .48697 L p .743 .612 .713 r
F P
0 g
s
.50353 .47618 m .49777 .47007 L .4871 .47766 L p .682 .533 .678 r
F P
0 g
s
.4871 .47766 m .49196 .48607 L .50353 .47618 L p .682 .533 .678 r
F P
0 g
s
.49196 .48607 m .4871 .47766 L .47519 .4831 L p .694 .537 .671 r
F P
0 g
s
.47761 .50885 m .47519 .5169 L .4871 .52234 L p .694 .595 .742 r
F P
0 g
s
.4871 .52234 m .49196 .51393 L .47761 .50885 L p .694 .595 .742 r
F P
0 g
s
.49196 .51393 m .4871 .52234 L .49777 .52993 L p .682 .58 .735 r
F P
0 g
s
.74038 .13967 m .73077 .13072 L .73318 .13161 L p .084 .46 .886 r
F P
0 g
s
.73318 .13161 m .74484 .14133 L .74038 .13967 L p .084 .46 .886 r
F P
0 g
s
.06775 .47199 m .06481 .48479 L .06438 .48226 L p .984 .837 .448 r
F P
0 g
s
.06438 .48226 m .06696 .46729 L .06775 .47199 L p .984 .837 .448 r
F P
0 g
s
.69186 .88834 m .70442 .88449 L .70244 .88613 L p .154 0 0 r
F P
0 g
s
.70244 .88613 m .68819 .89137 L .69186 .88834 L p .154 0 0 r
F P
0 g
s
.70442 .11551 m .69186 .11166 L .68819 .10863 L p .154 .55 .927 r
F P
0 g
s
.69186 .11166 m .70442 .11551 L .70701 .11741 L p .175 .554 .931 r
F P
0 g
s
.73077 .86928 m .74038 .86033 L .74484 .85867 L p .084 0 0 r
F P
0 g
s
.74038 .86033 m .73077 .86928 L .72783 .87057 L p .118 0 0 r
F P
0 g
s
.06481 .51521 m .06775 .52801 L .06696 .53271 L p .984 .77 .367 r
F P
0 g
s
.06775 .52801 m .06481 .51521 L .06517 .51202 L p .99 .781 .395 r
F P
0 g
s
.52704 .48697 m .51886 .48503 L .51609 .5 L p .743 .612 .713 r
F P
0 g
s
.51886 .48503 m .52704 .48697 L .52957 .47588 L p .739 .623 .731 r
F P
0 g
s
.52297 .52609 m .52957 .52412 L .52704 .51303 L p .739 .583 .681 r
F P
0 g
s
.52704 .51303 m .51886 .51497 L .52297 .52609 L p .739 .583 .681 r
F P
0 g
s
.51111 .46706 m .50611 .46233 L .49777 .47007 L p .668 .533 .69 r
F P
0 g
s
.49777 .47007 m .50353 .47618 L .51111 .46706 L p .668 .533 .69 r
F P
0 g
s
.47519 .4831 m .47761 .49115 L .49196 .48607 L p .694 .537 .671 r
F P
0 g
s
.47761 .49115 m .47519 .4831 L .46432 .48645 L p .711 .547 .665 r
F P
0 g
s
.46592 .50684 m .46432 .51355 L .47519 .5169 L p .711 .614 .747 r
F P
0 g
s
.47519 .5169 m .47761 .50885 L .46592 .50684 L p .711 .614 .747 r
F P
0 g
s
.49777 .52993 m .50353 .52382 L .49196 .51393 L p .682 .58 .735 r
F P
0 g
s
.50353 .52382 m .49777 .52993 L .50611 .53767 L p .668 .559 .722 r
F P
0 g
s
.31043 .57085 m .29606 .62071 L .29315 .62243 L p .797 .81 .324 r
F P
0 g
s
.29134 .68868 m .29315 .62243 L .29606 .62071 L p .848 .706 .176 r
F P
0 g
s
.53343 .3004 m .49743 .26302 L .49739 .25965 L p 0 .088 .61 r
F P
0 g
s
.44093 .22496 m .49739 .25965 L .49743 .26302 L p 0 .317 .748 r
F P
0 g
s
.53383 .70197 m .49739 .74035 L .49743 .73698 L p 0 0 0 r
F P
0 g
s
.49743 .73698 m .53343 .6996 L .53383 .70197 L p 0 0 0 r
F P
0 g
s
.65614 .62875 m .70651 .61626 L .70945 .61792 L p 0 0 0 r
F P
0 g
s
.76773 .58637 m .70945 .61792 L .70651 .61626 L p 0 0 0 r
F P
0 g
s
.65799 .36972 m .70945 .38208 L .70651 .38374 L p 0 .523 .805 r
F P
0 g
s
.70651 .38374 m .65614 .37125 L .65799 .36972 L p 0 .523 .805 r
F P
0 g
s
.30818 .42831 m .29315 .37757 L .29606 .37929 L p .797 .491 0 r
F P
0 g
s
.29606 .37929 m .31043 .42915 L .30818 .42831 L p .797 .491 0 r
F P
0 g
s
.52957 .47588 m .52297 .47391 L .51886 .48503 L p .739 .623 .731 r
F P
0 g
s
.52297 .47391 m .52957 .47588 L .53219 .46679 L p .73 .637 .755 r
F P
0 g
s
.53804 .46747 m .53219 .46679 L .52957 .47588 L p .761 .67 .762 r
F P
0 g
s
.51685 .45954 m .51267 .45552 L .50611 .46233 L p .649 .533 .708 r
F P
0 g
s
.50611 .46233 m .51111 .46706 L .51685 .45954 L p .649 .533 .708 r
F P
0 g
s
.52662 .53482 m .53219 .53321 L .52957 .52412 L p .73 .555 .655 r
F P
0 g
s
.52957 .52412 m .52297 .52609 L .52662 .53482 L p .73 .555 .655 r
F P
0 g
s
.46432 .48645 m .46592 .49316 L .47761 .49115 L p .711 .547 .665 r
F P
0 g
s
.46592 .49316 m .46432 .48645 L .45514 .48873 L p .736 .563 .658 r
F P
0 g
s
.45281 .48332 m .45514 .48873 L .46432 .48645 L p .724 .526 .622 r
F P
0 g
s
.50611 .53767 m .51111 .53294 L .50353 .52382 L p .668 .559 .722 r
F P
0 g
s
.51111 .53294 m .50611 .53767 L .51267 .54448 L p .649 .527 .702 r
F P
0 g
s
.50916 .54921 m .51267 .54448 L .50611 .53767 L p .621 .524 .723 r
F P
0 g
s
.45653 .50564 m .45514 .51127 L .46432 .51355 L p .736 .639 .752 r
F P
0 g
s
.46432 .51355 m .46592 .50684 L .45653 .50564 L p .736 .639 .752 r
F P
0 g
s
.53219 .46679 m .53804 .46747 L .53967 .45977 L p .752 .694 .796 r
F P
0 g
s
.5451 .45896 m .53967 .45977 L .53804 .46747 L p .792 .733 .798 r
F P
0 g
s
.53447 .5405 m .53967 .54023 L .53804 .53253 L p .752 .534 .601 r
F P
0 g
s
.53804 .53253 m .53219 .53321 L .53447 .5405 L p .752 .534 .601 r
F P
0 g
s
.51784 .4499 m .515 .44553 L .50916 .45079 L p .587 .481 .7 r
F P
0 g
s
.50916 .45079 m .51267 .45552 L .51784 .4499 L p .587 .481 .7 r
F P
0 g
s
.45514 .48873 m .45281 .48332 L .44533 .48576 L p .756 .539 .603 r
F P
0 g
s
.44191 .48147 m .44533 .48576 L .45281 .48332 L p .734 .486 .552 r
F P
0 g
s
.51267 .54448 m .50916 .54921 L .515 .55447 L p .587 .477 .696 r
F P
0 g
s
.513 .55958 m .515 .55447 L .50916 .54921 L p .55 .476 .725 r
F P
0 g
s
.44769 .5096 m .44533 .51424 L .45281 .51668 L p .756 .695 .794 r
F P
0 g
s
.45281 .51668 m .45514 .51127 L .44769 .5096 L p .756 .695 .794 r
F P
0 g
s
.55162 .55484 m .55653 .5597 L .55627 .55436 L p .895 .522 .322 r
F P
0 g
s
.55627 .55436 m .55117 .55004 L .55162 .55484 L p .895 .522 .322 r
F P
0 g
s
.55117 .44996 m .55627 .44564 L .55653 .4403 L p .895 .94 .833 r
F P
0 g
s
.56117 .43324 m .55653 .4403 L .55627 .44564 L p .941 .959 .741 r
F P
0 g
s
.43108 .48071 m .42479 .47845 L .42003 .48089 L p .64 .193 .174 r
F P
0 g
s
.4116 .4804 m .42003 .48089 L .42479 .47845 L p .493 .001 .016 r
F P
0 g
s
.52168 .42788 m .52343 .42119 L .51894 .42409 L p .197 .04 .43 r
F P
0 g
s
.51894 .42409 m .51775 .43067 L .52168 .42788 L p .197 .04 .43 r
F P
0 g
s
.51775 .56933 m .51894 .57591 L .52343 .57881 L p .197 .281 .725 r
F P
0 g
s
.52723 .58636 m .52343 .57881 L .51894 .57591 L p .09 .285 .767 r
F P
0 g
s
.4267 .51728 m .42003 .51911 L .42479 .52155 L p .64 .852 .981 r
F P
0 g
s
.42479 .52155 m .43108 .51929 L .4267 .51728 L p .64 .852 .981 r
F P
0 g
s
.5107 .51853 m .51886 .51497 L .51609 .5 L p .718 .584 .704 r
F P
0 g
s
.51609 .5 m .50007 .5 L .5107 .51853 L p .718 .584 .704 r
F P
0 g
s
.50007 .5 m .51609 .5 L .51886 .48503 L p .719 .59 .711 r
F P
0 g
s
.5107 .48146 m .50353 .47618 L .49196 .48607 L p .699 .565 .699 r
F P
0 g
s
.49196 .48607 m .49996 .49994 L .5107 .48146 L p .699 .565 .699 r
F P
0 g
s
.49996 .49994 m .49196 .48607 L .47761 .49115 L p .704 .565 .695 r
F P
0 g
s
.4786 .5 m .47761 .50885 L .49196 .51393 L p .704 .584 .718 r
F P
0 g
s
.49196 .51393 m .49996 .50006 L .4786 .5 L p .704 .584 .718 r
F P
0 g
s
.49996 .50006 m .49196 .51393 L .50353 .52382 L p .698 .577 .715 r
F P
0 g
s
.51886 .48503 m .5107 .48147 L .50007 .5 L p .719 .59 .711 r
F P
0 g
s
.5107 .48147 m .51886 .48503 L .52297 .47391 L p .714 .595 .722 r
F P
0 g
s
.51677 .47095 m .51111 .46706 L .50353 .47618 L p .691 .565 .709 r
F P
0 g
s
.50353 .47618 m .5107 .48146 L .51677 .47095 L p .691 .565 .709 r
F P
0 g
s
.51677 .52904 m .52297 .52609 L .51886 .51497 L p .714 .57 .692 r
F P
0 g
s
.51886 .51497 m .5107 .51853 L .51677 .52904 L p .714 .57 .692 r
F P
0 g
s
.47761 .49115 m .4786 .5 L .49996 .49994 L p .704 .565 .695 r
F P
0 g
s
.4786 .5 m .47761 .49115 L .46592 .49316 L p .717 .574 .694 r
F P
0 g
s
.50353 .52382 m .5107 .51854 L .49996 .50006 L p .698 .577 .715 r
F P
0 g
s
.5107 .51854 m .50353 .52382 L .51111 .53294 L p .691 .562 .705 r
F P
0 g
s
.46646 .5 m .46592 .50684 L .47761 .50885 L p .717 .596 .72 r
F P
0 g
s
.47761 .50885 m .4786 .5 L .46646 .5 L p .717 .596 .72 r
F P
0 g
s
.53967 .45977 m .5451 .45896 L .54601 .4526 L p .786 .776 .844 r
F P
0 g
s
.55117 .44996 m .54601 .4526 L .5451 .45896 L p .838 .823 .834 r
F P
0 g
s
.541 .54614 m .54601 .5474 L .5451 .54104 L p .786 .508 .515 r
F P
0 g
s
.5451 .54104 m .53967 .54023 L .541 .54614 L p .786 .508 .515 r
F P
0 g
s
.51946 .44142 m .51804 .43645 L .513 .44042 L p .484 .387 .669 r
F P
0 g
s
.513 .44042 m .515 .44553 L .51946 .44142 L p .484 .387 .669 r
F P
0 g
s
.44533 .48576 m .44191 .48147 L .43595 .48385 L p .768 .485 .505 r
F P
0 g
s
.43108 .48071 m .43595 .48385 L .44191 .48147 L p .724 .399 .428 r
F P
0 g
s
.515 .55447 m .513 .55958 L .51804 .56355 L p .484 .404 .69 r
F P
0 g
s
.51775 .56933 m .51804 .56355 L .513 .55958 L p .429 .404 .729 r
F P
0 g
s
.43954 .51244 m .43595 .51615 L .44191 .51853 L p .768 .77 .854 r
F P
0 g
s
.44191 .51853 m .44533 .51424 L .43954 .51244 L p .768 .77 .854 r
F P
0 g
s
.52297 .47391 m .51677 .47096 L .5107 .48147 L p .714 .595 .722 r
F P
0 g
s
.51111 .53294 m .51677 .52905 L .5107 .51854 L p .691 .562 .705 r
F P
0 g
s
.46592 .49316 m .46646 .5 L .4786 .5 L p .717 .574 .694 r
F P
0 g
s
.51677 .47096 m .52297 .47391 L .52662 .46518 L p .702 .604 .744 r
F P
0 g
s
.53219 .46679 m .52662 .46518 L .52297 .47391 L p .73 .637 .755 r
F P
0 g
s
.52151 .46275 m .51685 .45954 L .51111 .46706 L p .675 .57 .729 r
F P
0 g
s
.51111 .46706 m .51677 .47095 L .52151 .46275 L p .675 .57 .729 r
F P
0 g
s
.52151 .53725 m .52662 .53482 L .52297 .52609 L p .702 .542 .668 r
F P
0 g
s
.52297 .52609 m .51677 .52904 L .52151 .53725 L p .702 .542 .668 r
F P
0 g
s
.51677 .52905 m .51111 .53294 L .51685 .54046 L p .675 .533 .684 r
F P
0 g
s
.51267 .54448 m .51685 .54046 L .51111 .53294 L p .649 .527 .702 r
F P
0 g
s
.46646 .5 m .46592 .49316 L .45653 .49436 L p .741 .592 .691 r
F P
0 g
s
.45514 .48873 m .45653 .49436 L .46592 .49316 L p .736 .563 .658 r
F P
0 g
s
.45699 .5 m .45653 .50564 L .46592 .50684 L p .741 .617 .721 r
F P
0 g
s
.46592 .50684 m .46646 .5 L .45699 .5 L p .741 .617 .721 r
F P
0 g
s
.52662 .46518 m .52151 .46275 L .51677 .47096 L p .702 .604 .744 r
F P
0 g
s
.45653 .49436 m .45699 .5 L .46646 .5 L p .741 .592 .691 r
F P
0 g
s
.51685 .54046 m .52151 .53725 L .51677 .52905 L p .675 .533 .684 r
F P
0 g
s
.52662 .46518 m .53219 .46679 L .53447 .4595 L p .716 .655 .787 r
F P
0 g
s
.53967 .45977 m .53447 .4595 L .53219 .46679 L p .752 .694 .796 r
F P
0 g
s
.52963 .54172 m .53447 .5405 L .53219 .53321 L p .716 .515 .616 r
F P
0 g
s
.53219 .53321 m .52662 .53482 L .52963 .54172 L p .716 .515 .616 r
F P
0 g
s
.52132 .45348 m .51784 .4499 L .51267 .45552 L p .62 .531 .732 r
F P
0 g
s
.51267 .45552 m .51685 .45954 L .52132 .45348 L p .62 .531 .732 r
F P
0 g
s
.45653 .49436 m .45514 .48873 L .44769 .4904 L p .769 .582 .646 r
F P
0 g
s
.44533 .48576 m .44769 .4904 L .45514 .48873 L p .756 .539 .603 r
F P
0 g
s
.51685 .54046 m .51267 .54448 L .51784 .5501 L p .62 .482 .672 r
F P
0 g
s
.515 .55447 m .51784 .5501 L .51267 .54448 L p .587 .477 .696 r
F P
0 g
s
.44905 .5048 m .44769 .5096 L .45514 .51127 L p .769 .673 .757 r
F P
0 g
s
.45514 .51127 m .45653 .50564 L .44905 .5048 L p .769 .673 .757 r
F P
0 g
s
.85427 .28939 m .82731 .22871 L .83024 .22628 L p 0 0 .567 r
F P
0 g
s
.83024 .22628 m .8586 .28681 L .85427 .28939 L p 0 0 .567 r
F P
0 g
s
.14048 .2985 m .1014 .35218 L .09783 .35086 L p .822 .975 .673 r
F P
0 g
s
.09783 .35086 m .13607 .29603 L .14048 .2985 L p .822 .975 .673 r
F P
0 g
s
.50526 .91211 m .57128 .9191 L .57192 .92286 L p .362 0 0 r
F P
0 g
s
.57192 .92286 m .50532 .91715 L .50526 .91211 L p .362 0 0 r
F P
0 g
s
.43023 .10998 m .50532 .08285 L .50526 .08789 L p .51 .912 .893 r
F P
0 g
s
.57128 .0809 m .50526 .08789 L .50532 .08285 L p .362 .816 .938 r
F P
0 g
s
.87265 .63459 m .8586 .71319 L .85427 .71061 L p 0 0 .177 r
F P
0 g
s
.82731 .77129 m .85427 .71061 L .8586 .71319 L p 0 0 .036 r
F P
0 g
s
.19711 .75543 m .13607 .70397 L .14048 .7015 L p .699 .165 0 r
F P
0 g
s
.1014 .64782 m .14048 .7015 L .13607 .70397 L p .822 .368 0 r
F P
0 g
s
.55469 .66659 m .53383 .70197 L .53343 .6996 L p 0 0 0 r
F P
0 g
s
.53343 .6996 m .55416 .665 L .55469 .66659 L p 0 0 0 r
F P
0 g
s
.55416 .335 m .53343 .3004 L .53383 .29803 L p 0 0 .462 r
F P
0 g
s
.49739 .25965 m .53383 .29803 L .53343 .3004 L p 0 .088 .61 r
F P
0 g
s
.61693 .36934 m .65799 .36972 L .65614 .37125 L p .096 .649 .804 r
F P
0 g
s
.65614 .37125 m .61581 .37059 L .61693 .36934 L p .096 .649 .804 r
F P
0 g
s
.33003 .53559 m .31043 .57085 L .30818 .57169 L p .715 .863 .447 r
F P
0 g
s
.29315 .62243 m .30818 .57169 L .31043 .57085 L p .797 .81 .324 r
F P
0 g
s
.32838 .46407 m .30818 .42831 L .31043 .42915 L p .715 .305 0 r
F P
0 g
s
.31043 .42915 m .33003 .46441 L .32838 .46407 L p .715 .305 0 r
F P
0 g
s
.61581 .62941 m .65614 .62875 L .65799 .63028 L p .096 0 0 r
F P
0 g
s
.70945 .61792 m .65799 .63028 L .65614 .62875 L p 0 0 0 r
F P
0 g
s
.52525 .54374 m .52963 .54172 L .52662 .53482 L p .683 .5 .632 r
F P
0 g
s
.52662 .53482 m .52151 .53725 L .52525 .54374 L p .683 .5 .632 r
F P
0 g
s
.52525 .45626 m .52132 .45348 L .51685 .45954 L p .652 .575 .756 r
F P
0 g
s
.51685 .45954 m .52151 .46275 L .52525 .45626 L p .652 .575 .756 r
F P
0 g
s
.52151 .46275 m .52662 .46518 L .52963 .45828 L p .683 .616 .774 r
F P
0 g
s
.53447 .4595 m .52963 .45828 L .52662 .46518 L p .716 .655 .787 r
F P
0 g
s
.52151 .53725 m .51685 .54046 L .52132 .54652 L p .652 .489 .651 r
F P
0 g
s
.51784 .5501 m .52132 .54652 L .51685 .54046 L p .62 .482 .672 r
F P
0 g
s
.45699 .5 m .45653 .49436 L .44905 .4952 L p .775 .618 .685 r
F P
0 g
s
.44769 .4904 m .44905 .4952 L .45653 .49436 L p .769 .582 .646 r
F P
0 g
s
.44949 .5 m .44905 .5048 L .45653 .50564 L p .775 .647 .721 r
F P
0 g
s
.45653 .50564 m .45699 .5 L .44949 .5 L p .775 .647 .721 r
F P
0 g
s
.71806 .1223 m .71717 .12384 L .71352 .12167 L p .105 .501 .905 r
F P
0 g
s
.71717 .12384 m .71806 .1223 L .71986 .12331 L p .101 .495 .902 r
F P
0 g
s
.71986 .12331 m .72088 .12592 L .71717 .12384 L p .101 .495 .902 r
F P
0 g
s
.71806 .8777 m .71717 .87616 L .72088 .87408 L p .101 0 0 r
F P
0 g
s
.71717 .87616 m .71806 .8777 L .7163 .87875 L p .105 0 0 r
F P
0 g
s
.7163 .87875 m .71352 .87833 L .71717 .87616 L p .105 0 0 r
F P
0 g
s
.06387 .5 m .06565 .5 L .0656 .50425 L p .982 .799 .393 r
F P
0 g
s
.06565 .5 m .06387 .5 L .06385 .49794 L p .982 .804 .399 r
F P
0 g
s
.06385 .49794 m .0656 .49575 L .06565 .5 L p .982 .804 .399 r
F P
0 g
s
.53447 .4595 m .53967 .45977 L .541 .45386 L p .739 .728 .842 r
F P
0 g
s
.54601 .4526 m .541 .45386 L .53967 .45977 L p .786 .776 .844 r
F P
0 g
s
.53627 .54605 m .541 .54614 L .53967 .54023 L p .739 .478 .535 r
F P
0 g
s
.53967 .54023 m .53447 .5405 L .53627 .54605 L p .739 .478 .535 r
F P
0 g
s
.52174 .44556 m .51946 .44142 L .515 .44553 L p .531 .461 .722 r
F P
0 g
s
.515 .44553 m .51784 .4499 L .52174 .44556 L p .531 .461 .722 r
F P
0 g
s
.44769 .4904 m .44533 .48576 L .43954 .48756 L p .796 .552 .569 r
F P
0 g
s
.43595 .48385 m .43954 .48756 L .44533 .48576 L p .768 .485 .505 r
F P
0 g
s
.51784 .5501 m .515 .55447 L .51946 .55858 L p .531 .406 .655 r
F P
0 g
s
.51804 .56355 m .51946 .55858 L .515 .55447 L p .484 .404 .69 r
F P
0 g
s
.44199 .50839 m .43954 .51244 L .44533 .51424 L p .796 .748 .808 r
F P
0 g
s
.44533 .51424 m .44769 .5096 L .44199 .50839 L p .796 .748 .808 r
F P
0 g
s
.52963 .45828 m .52525 .45626 L .52151 .46275 L p .683 .616 .774 r
F P
0 g
s
.52132 .54652 m .52525 .54374 L .52151 .53725 L p .652 .489 .651 r
F P
0 g
s
.44905 .4952 m .44949 .5 L .45699 .5 L p .775 .618 .685 r
F P
0 g
s
.72088 .12592 m .71986 .12331 L .7216 .12422 L p .092 .487 .898 r
F P
0 g
s
.7216 .12422 m .72448 .12781 L .72088 .12592 L p .092 .487 .898 r
F P
0 g
s
.7163 .12125 m .71352 .12167 L .71008 .1195 L p .106 .505 .906 r
F P
0 g
s
.71352 .12167 m .7163 .12125 L .71806 .1223 L p .105 .501 .905 r
F P
0 g
s
.0656 .49575 m .06385 .49794 L .06377 .49598 L p .981 .807 .401 r
F P
0 g
s
.06377 .49598 m .06543 .49169 L .0656 .49575 L p .981 .807 .401 r
F P
0 g
s
.71352 .87833 m .7163 .87875 L .71463 .8798 L p .106 0 0 r
F P
0 g
s
.71463 .8798 m .71008 .8805 L .71352 .87833 L p .106 0 0 r
F P
0 g
s
.71986 .87669 m .72088 .87408 L .72448 .87219 L p .092 0 0 r
F P
0 g
s
.72088 .87408 m .71986 .87669 L .71806 .8777 L p .101 0 0 r
F P
0 g
s
.06385 .50206 m .0656 .50425 L .06543 .50831 L p .981 .794 .385 r
F P
0 g
s
.0656 .50425 m .06385 .50206 L .06387 .5 L p .982 .799 .393 r
F P
0 g
s
.54601 .4526 m .55117 .44996 L .55162 .44516 L p .836 .897 .883 r
F P
0 g
s
.55653 .4403 m .55162 .44516 L .55117 .44996 L p .895 .94 .833 r
F P
0 g
s
.54669 .55177 m .55162 .55484 L .55117 .55004 L p .836 .468 .357 r
F P
0 g
s
.55117 .55004 m .54601 .5474 L .54669 .55177 L p .836 .468 .357 r
F P
0 g
s
.52149 .43367 m .52168 .42788 L .51775 .43067 L p .285 .187 .564 r
F P
0 g
s
.51775 .43067 m .51804 .43645 L .52149 .43367 L p .285 .187 .564 r
F P
0 g
s
.43595 .48385 m .43108 .48071 L .4267 .48272 L p .74 .344 .302 r
F P
0 g
s
.42003 .48089 m .4267 .48272 L .43108 .48071 L p .64 .193 .174 r
F P
0 g
s
.51804 .56355 m .51775 .56933 L .52168 .57212 L p .285 .278 .676 r
F P
0 g
s
.52343 .57881 m .52168 .57212 L .51775 .56933 L p .197 .281 .725 r
F P
0 g
s
.43182 .51455 m .4267 .51728 L .43108 .51929 L p .74 .864 .938 r
F P
0 g
s
.43108 .51929 m .43595 .51615 L .43182 .51455 L p .74 .864 .938 r
F P
0 g
s
.79713 .81347 m .77052 .8408 L .7671 .84092 L p .005 0 .001 r
F P
0 g
s
.74813 .8578 m .7671 .84092 L .77052 .8408 L p .001 0 0 r
F P
0 g
s
.7671 .84092 m .74813 .8578 L .74484 .85867 L p .076 0 0 r
F P
0 g
s
.6229 .08595 m .65988 .09532 L .66169 .09822 L p .259 .665 .966 r
F P
0 g
s
.68579 .10621 m .66169 .09822 L .65988 .09532 L p .16 .586 .934 r
F P
0 g
s
.66169 .09822 m .68579 .10621 L .68819 .10863 L p .216 .605 .95 r
F P
0 g
s
.07997 .60059 m .06959 .56388 L .0712 .56086 L p .967 .67 .264 r
F P
0 g
s
.06607 .53599 m .0712 .56086 L .06959 .56388 L p .968 .716 .285 r
F P
0 g
s
.0712 .56086 m .06607 .53599 L .06696 .53271 L p .984 .738 .345 r
F P
0 g
s
.7671 .15908 m .74813 .1422 L .75011 .14223 L p .001 .382 .843 r
F P
0 g
s
.75011 .14223 m .77052 .1592 L .7671 .15908 L p .001 .382 .843 r
F P
0 g
s
.66169 .90178 m .68579 .89379 L .68478 .89549 L p .16 0 0 r
F P
0 g
s
.68478 .89549 m .65988 .90468 L .66169 .90178 L p .16 0 0 r
F P
0 g
s
.0712 .43914 m .06607 .46401 L .06511 .46228 L p .968 .865 .468 r
F P
0 g
s
.06511 .46228 m .06959 .43612 L .0712 .43914 L p .968 .865 .468 r
F P
0 g
s
.74484 .14133 m .73318 .13161 L .73495 .13207 L p .044 .436 .872 r
F P
0 g
s
.73495 .13207 m .74813 .1422 L .74484 .14133 L p .044 .436 .872 r
F P
0 g
s
.70244 .11387 m .68819 .10863 L .68579 .10621 L p .126 .542 .919 r
F P
0 g
s
.68819 .10863 m .70244 .11387 L .70442 .11551 L p .154 .55 .927 r
F P
0 g
s
.73318 .86839 m .74484 .85867 L .74813 .8578 L p .044 0 0 r
F P
0 g
s
.74484 .85867 m .73318 .86839 L .73077 .86928 L p .084 0 0 r
F P
0 g
s
.06438 .51774 m .06696 .53271 L .06607 .53599 L p .975 .757 .334 r
F P
0 g
s
.06696 .53271 m .06438 .51774 L .06481 .51521 L p .984 .77 .367 r
F P
0 g
s
.68819 .89137 m .70244 .88613 L .70116 .88743 L p .126 0 0 r
F P
0 g
s
.70116 .88743 m .68579 .89379 L .68819 .89137 L p .126 0 0 r
F P
0 g
s
.06696 .46729 m .06438 .48226 L .06389 .48049 L p .975 .835 .429 r
F P
0 g
s
.06389 .48049 m .06607 .46401 L .06696 .46729 L p .975 .835 .429 r
F P
0 g
s
.71463 .1202 m .71008 .1195 L .70701 .11741 L p .102 .507 .906 r
F P
0 g
s
.71008 .1195 m .71463 .1202 L .7163 .12125 L p .106 .505 .906 r
F P
0 g
s
.72448 .12781 m .7216 .12422 L .72322 .12501 L p .079 .478 .893 r
F P
0 g
s
.72322 .12501 m .72783 .12943 L .72448 .12781 L p .079 .478 .893 r
F P
0 g
s
.71008 .8805 m .71463 .8798 L .71314 .88081 L p .102 0 0 r
F P
0 g
s
.71314 .88081 m .70701 .88259 L .71008 .8805 L p .102 0 0 r
F P
0 g
s
.7216 .87578 m .72448 .87219 L .72783 .87057 L p .079 0 0 r
F P
0 g
s
.72448 .87219 m .7216 .87578 L .71986 .87669 L p .092 0 0 r
F P
0 g
s
.06377 .50402 m .06543 .50831 L .06517 .51202 L p .979 .788 .374 r
F P
0 g
s
.06543 .50831 m .06377 .50402 L .06385 .50206 L p .981 .794 .385 r
F P
0 g
s
.06543 .49169 m .06377 .49598 L .06364 .49418 L p .979 .81 .4 r
F P
0 g
s
.06364 .49418 m .06517 .48798 L .06543 .49169 L p .979 .81 .4 r
F P
0 g
s
.52963 .45828 m .53447 .4595 L .53627 .45395 L p .694 .68 .832 r
F P
0 g
s
.541 .45386 m .53627 .45395 L .53447 .4595 L p .739 .728 .842 r
F P
0 g
s
.52468 .44887 m .52174 .44556 L .51784 .4499 L p .573 .524 .762 r
F P
0 g
s
.51784 .4499 m .52132 .45348 L .52468 .44887 L p .573 .524 .762 r
F P
0 g
s
.53194 .54694 m .53627 .54605 L .53447 .5405 L p .694 .454 .555 r
F P
0 g
s
.53447 .5405 m .52963 .54172 L .53194 .54694 L p .694 .454 .555 r
F P
0 g
s
.44905 .4952 m .44769 .4904 L .44199 .49161 L p .813 .607 .624 r
F P
0 g
s
.43954 .48756 m .44199 .49161 L .44769 .4904 L p .796 .552 .569 r
F P
0 g
s
.52132 .54652 m .51784 .5501 L .52174 .55444 L p .573 .412 .625 r
F P
0 g
s
.51946 .55858 m .52174 .55444 L .51784 .5501 L p .531 .406 .655 r
F P
0 g
s
.44338 .50419 m .44199 .50839 L .44769 .5096 L p .813 .721 .763 r
F P
0 g
s
.44769 .5096 m .44905 .5048 L .44338 .50419 L p .813 .721 .763 r
F P
0 g
s
.56117 .56676 m .55653 .5597 L .55675 .56252 L p .866 .445 .007 r
F P
0 g
s
.52723 .41364 m .52343 .42119 L .52577 .41959 L p 0 0 .021 r
F P
0 g
s
.4116 .5196 m .42003 .51911 L .41748 .51789 L p .335 .786 .954 r
F P
0 g
s
.52525 .45626 m .52963 .45828 L .53194 .45306 L p .653 .631 .815 r
F P
0 g
s
.53627 .45395 m .53194 .45306 L .52963 .45828 L p .694 .68 .832 r
F P
0 g
s
.52808 .45135 m .52468 .44887 L .52132 .45348 L p .614 .58 .792 r
F P
0 g
s
.52132 .45348 m .52525 .45626 L .52808 .45135 L p .614 .58 .792 r
F P
0 g
s
.52809 .54864 m .53194 .54694 L .52963 .54172 L p .653 .436 .576 r
F P
0 g
s
.52963 .54172 m .52525 .54374 L .52809 .54864 L p .653 .436 .576 r
F P
0 g
s
.44949 .5 m .44905 .4952 L .44338 .49581 L p .82 .651 .673 r
F P
0 g
s
.44199 .49161 m .44338 .49581 L .44905 .4952 L p .813 .607 .624 r
F P
0 g
s
.52525 .54374 m .52132 .54652 L .52468 .55113 L p .614 .422 .599 r
F P
0 g
s
.52174 .55444 m .52468 .55113 L .52132 .54652 L p .573 .412 .625 r
F P
0 g
s
.44383 .5 m .44338 .50419 L .44905 .5048 L p .82 .688 .719 r
F P
0 g
s
.44905 .5048 m .44949 .5 L .44383 .5 L p .82 .688 .719 r
F P
0 g
s
.541 .45386 m .54601 .4526 L .54669 .44823 L p .773 .842 .904 r
F P
0 g
s
.55162 .44516 m .54669 .44823 L .54601 .4526 L p .836 .897 .883 r
F P
0 g
s
.54196 .55019 m .54669 .55177 L .54601 .5474 L p .773 .42 .387 r
F P
0 g
s
.54601 .5474 m .541 .54614 L .54196 .55019 L p .773 .42 .387 r
F P
0 g
s
.52248 .43857 m .52149 .43367 L .51804 .43645 L p .358 .308 .665 r
F P
0 g
s
.51804 .43645 m .51946 .44142 L .52248 .43857 L p .358 .308 .665 r
F P
0 g
s
.43954 .48756 m .43595 .48385 L .43182 .48545 L p .806 .463 .407 r
F P
0 g
s
.4267 .48272 m .43182 .48545 L .43595 .48385 L p .74 .344 .302 r
F P
0 g
s
.51946 .55858 m .51804 .56355 L .52149 .56633 L p .358 .277 .627 r
F P
0 g
s
.52168 .57212 m .52149 .56633 L .51804 .56355 L p .285 .278 .676 r
F P
0 g
s
.43556 .51124 m .43182 .51455 L .43595 .51615 L p .806 .854 .885 r
F P
0 g
s
.43595 .51615 m .43954 .51244 L .43556 .51124 L p .806 .854 .885 r
F P
0 g
s
.53194 .45306 m .52809 .45136 L .52525 .45626 L p .653 .631 .815 r
F P
0 g
s
.52468 .55113 m .52808 .54865 L .52525 .54374 L p .614 .422 .599 r
F P
0 g
s
.44338 .49581 m .44383 .5 L .44949 .5 L p .82 .651 .673 r
F P
0 g
s
.56448 .36419 m .55416 .335 L .55469 .33341 L p 0 0 .317 r
F P
0 g
s
.53383 .29803 m .55469 .33341 L .55416 .335 L p 0 0 .462 r
F P
0 g
s
.58604 .37529 m .61693 .36934 L .61581 .37059 L p .216 .739 .775 r
F P
0 g
s
.61581 .37059 m .58537 .37626 L .58604 .37529 L p .216 .739 .775 r
F P
0 g
s
.35015 .51206 m .33003 .53559 L .32838 .53593 L p .617 .878 .543 r
F P
0 g
s
.30818 .57169 m .32838 .53593 L .33003 .53559 L p .715 .863 .447 r
F P
0 g
s
.56498 .63687 m .55469 .66659 L .55416 .665 L p 0 0 0 r
F P
0 g
s
.55416 .665 m .56448 .63581 L .56498 .63687 L p 0 0 0 r
F P
0 g
s
.34898 .48784 m .32838 .46407 L .33003 .46441 L p .617 .13 0 r
F P
0 g
s
.33003 .46441 m .35015 .48794 L .34898 .48784 L p .617 .13 0 r
F P
0 g
s
.58537 .62374 m .61581 .62941 L .61693 .63066 L p .216 0 0 r
F P
0 g
s
.65799 .63028 m .61693 .63066 L .61581 .62941 L p .096 0 0 r
F P
0 g
s
.71314 .11919 m .70701 .11741 L .70442 .11551 L p .094 .506 .904 r
F P
0 g
s
.70701 .11741 m .71314 .11919 L .71463 .1202 L p .102 .507 .906 r
F P
0 g
s
.72322 .87499 m .72783 .87057 L .73077 .86928 L p .063 0 0 r
F P
0 g
s
.72783 .87057 m .72322 .87499 L .7216 .87578 L p .079 0 0 r
F P
0 g
s
.06517 .48798 m .06364 .49418 L .06346 .49264 L p .975 .811 .395 r
F P
0 g
s
.06346 .49264 m .06481 .48479 L .06517 .48798 L p .975 .811 .395 r
F P
0 g
s
.70701 .88259 m .71314 .88081 L .7119 .88173 L p .094 0 0 r
F P
0 g
s
.7119 .88173 m .70442 .88449 L .70701 .88259 L p .094 0 0 r
F P
0 g
s
.72783 .12943 m .72322 .12501 L .72464 .12563 L p .063 .467 .886 r
F P
0 g
s
.72464 .12563 m .73077 .13072 L .72783 .12943 L p .063 .467 .886 r
F P
0 g
s
.06364 .50582 m .06517 .51202 L .06481 .51521 L p .975 .782 .36 r
F P
0 g
s
.06517 .51202 m .06364 .50582 L .06377 .50402 L p .979 .788 .374 r
F P
0 g
s
.57128 .9191 m .6229 .91405 L .62365 .91657 L p .24 0 0 r
F P
0 g
s
.62365 .91657 m .57192 .92286 L .57128 .9191 L p .24 0 0 r
F P
0 g
s
.82731 .22871 m .79713 .18653 L .79894 .18463 L p 0 .141 .686 r
F P
0 g
s
.79894 .18463 m .83024 .22628 L .82731 .22871 L p 0 .141 .686 r
F P
0 g
s
.13607 .70397 m .09783 .64914 L .1014 .64782 L p .822 .368 0 r
F P
0 g
s
.07997 .60059 m .1014 .64782 L .09783 .64914 L p .892 .519 .054 r
F P
0 g
s
.50532 .08285 m .57192 .07714 L .57128 .0809 L p .362 .816 .938 r
F P
0 g
s
.6229 .08595 m .57128 .0809 L .57192 .07714 L p .24 .712 .942 r
F P
0 g
s
.1014 .35218 m .07997 .39941 L .07741 .3988 L p .892 .937 .566 r
F P
0 g
s
.07741 .3988 m .09783 .35086 L .1014 .35218 L p .892 .937 .566 r
F P
0 g
s
.8586 .71319 m .83024 .77372 L .82731 .77129 L p 0 0 .036 r
F P
0 g
s
.79713 .81347 m .82731 .77129 L .83024 .77372 L p 0 0 0 r
F P
0 g
s
.53753 .54982 m .54196 .55019 L .541 .54614 L p .711 .38 .416 r
F P
0 g
s
.541 .54614 m .53627 .54605 L .53753 .54982 L p .711 .38 .416 r
F P
0 g
s
.53627 .45395 m .541 .45386 L .54196 .44981 L p .711 .781 .907 r
F P
0 g
s
.54669 .44823 m .54196 .44981 L .541 .45386 L p .773 .842 .904 r
F P
0 g
s
.52438 .44259 m .52248 .43857 L .51946 .44142 L p .424 .411 .741 r
F P
0 g
s
.51946 .44142 m .52174 .44556 L .52438 .44259 L p .424 .411 .741 r
F P
0 g
s
.44199 .49161 m .43954 .48756 L .43556 .48876 L p .849 .558 .495 r
F P
0 g
s
.43182 .48545 m .43556 .48876 L .43954 .48756 L p .806 .463 .407 r
F P
0 g
s
.52174 .55444 m .51946 .55858 L .52248 .56143 L p .424 .281 .582 r
F P
0 g
s
.52149 .56633 m .52248 .56143 L .51946 .55858 L p .358 .277 .627 r
F P
0 g
s
.43809 .50759 m .43556 .51124 L .43954 .51244 L p .849 .829 .827 r
F P
0 g
s
.43954 .51244 m .44199 .50839 L .43809 .50759 L p .849 .829 .827 r
F P
0 g
s
.55191 .55735 m .55675 .56252 L .55653 .5597 L p .839 .371 .028 r
F P
0 g
s
.55653 .5597 m .55162 .55484 L .55191 .55735 L p .839 .371 .028 r
F P
0 g
s
.55162 .44516 m .55653 .4403 L .55675 .43748 L p .839 .999 .797 r
F P
0 g
s
.52371 .42637 m .52577 .41959 L .52343 .42119 L p 0 0 .235 r
F P
0 g
s
.52343 .42119 m .52168 .42788 L .52371 .42637 L p 0 0 .235 r
F P
0 g
s
.4267 .48272 m .42003 .48089 L .41748 .48211 L p .532 0 0 r
F P
0 g
s
.52168 .57212 m .52343 .57881 L .52577 .58041 L p 0 .035 .59 r
F P
0 g
s
.42437 .51628 m .41748 .51789 L .42003 .51911 L p .532 .893 .974 r
F P
0 g
s
.42003 .51911 m .4267 .51728 L .42437 .51628 L p .532 .893 .974 r
F P
0 g
s
.53194 .45306 m .53627 .45395 L .53753 .45018 L p .652 .716 .896 r
F P
0 g
s
.54196 .44981 m .53753 .45018 L .53627 .45395 L p .711 .781 .907 r
F P
0 g
s
.52695 .44573 m .52438 .44259 L .52174 .44556 L p .483 .5 .798 r
F P
0 g
s
.52174 .44556 m .52468 .44887 L .52695 .44573 L p .483 .5 .798 r
F P
0 g
s
.53352 .55047 m .53753 .54982 L .53627 .54605 L p .652 .348 .444 r
F P
0 g
s
.53627 .54605 m .53194 .54694 L .53352 .55047 L p .652 .348 .444 r
F P
0 g
s
.44338 .49581 m .44199 .49161 L .43809 .49241 L p .874 .635 .573 r
F P
0 g
s
.43556 .48876 m .43809 .49241 L .44199 .49161 L p .849 .558 .495 r
F P
0 g
s
.52468 .55113 m .52174 .55444 L .52438 .55741 L p .483 .29 .541 r
F P
0 g
s
.52248 .56143 m .52438 .55741 L .52174 .55444 L p .424 .281 .582 r
F P
0 g
s
.43953 .5038 m .43809 .50759 L .44199 .50839 L p .874 .793 .767 r
F P
0 g
s
.44199 .50839 m .44338 .50419 L .43953 .5038 L p .874 .793 .767 r
F P
0 g
s
.72464 .87437 m .73077 .86928 L .73318 .86839 L p .044 0 0 r
F P
0 g
s
.73077 .86928 m .72464 .87437 L .72322 .87499 L p .063 0 0 r
F P
0 g
s
.7119 .11827 m .70442 .11551 L .70244 .11387 L p .082 .503 .9 r
F P
0 g
s
.70442 .11551 m .7119 .11827 L .71314 .11919 L p .094 .506 .904 r
F P
0 g
s
.06346 .50736 m .06481 .51521 L .06438 .51774 L p .97 .775 .344 r
F P
0 g
s
.06481 .51521 m .06346 .50736 L .06364 .50582 L p .975 .782 .36 r
F P
0 g
s
.73077 .13072 m .72464 .12563 L .7258 .12606 L p .044 .455 .879 r
F P
0 g
s
.7258 .12606 m .73318 .13161 L .73077 .13072 L p .044 .455 .879 r
F P
0 g
s
.70442 .88449 m .7119 .88173 L .71094 .88252 L p .082 0 0 r
F P
0 g
s
.71094 .88252 m .70244 .88613 L .70442 .88449 L p .082 0 0 r
F P
0 g
s
.06481 .48479 m .06346 .49264 L .06326 .49142 L p .97 .81 .387 r
F P
0 g
s
.06326 .49142 m .06438 .48226 L .06481 .48479 L p .97 .81 .387 r
F P
0 g
s
.55469 .33341 m .56498 .36313 L .56448 .36419 L p 0 0 .317 r
F P
0 g
s
.32838 .53593 m .34898 .51216 L .35015 .51206 L p .617 .878 .543 r
F P
0 g
s
.61693 .63066 m .58604 .62471 L .58537 .62374 L p .216 0 0 r
F P
0 g
s
.52809 .45136 m .53194 .45306 L .53352 .44953 L p .595 .649 .874 r
F P
0 g
s
.53753 .45018 m .53352 .44953 L .53194 .45306 L p .652 .716 .896 r
F P
0 g
s
.53001 .44802 m .52695 .44573 L .52468 .44887 L p .54 .578 .842 r
F P
0 g
s
.52468 .44887 m .52808 .45135 L .53001 .44802 L p .54 .578 .842 r
F P
0 g
s
.53001 .55197 m .53352 .55047 L .53194 .54694 L p .595 .323 .474 r
F P
0 g
s
.53194 .54694 m .52809 .54864 L .53001 .55197 L p .595 .323 .474 r
F P
0 g
s
.44383 .5 m .44338 .49581 L .43953 .4962 L p .886 .697 .642 r
F P
0 g
s
.43809 .49241 m .43953 .4962 L .44338 .49581 L p .874 .635 .573 r
F P
0 g
s
.52808 .54865 m .52468 .55113 L .52695 .55427 L p .54 .304 .506 r
F P
0 g
s
.52438 .55741 m .52695 .55427 L .52468 .55113 L p .483 .29 .541 r
F P
0 g
s
.43998 .5 m .43953 .5038 L .44338 .50419 L p .886 .75 .706 r
F P
0 g
s
.44338 .50419 m .44383 .5 L .43998 .5 L p .886 .75 .706 r
F P
0 g
s
.53352 .44953 m .53001 .44803 L .52809 .45136 L p .595 .649 .874 r
F P
0 g
s
.52695 .55427 m .53001 .55198 L .52808 .54865 L p .54 .304 .506 r
F P
0 g
s
.43953 .4962 m .43998 .5 L .44383 .5 L p .886 .697 .642 r
F P
0 g
s
.54669 .44823 m .55162 .44516 L .55191 .44265 L p .782 .984 .901 r
F P
0 g
s
.55675 .43748 m .55191 .44265 L .55162 .44516 L p .839 .999 .797 r
F P
0 g
s
.5471 .55406 m .55191 .55735 L .55162 .55484 L p .782 .293 .055 r
F P
0 g
s
.55162 .55484 m .54669 .55177 L .5471 .55406 L p .782 .293 .055 r
F P
0 g
s
.52327 .43219 m .52371 .42637 L .52168 .42788 L p 0 0 .427 r
F P
0 g
s
.52168 .42788 m .52149 .43367 L .52327 .43219 L p 0 0 .427 r
F P
0 g
s
.43182 .48545 m .4267 .48272 L .42437 .48372 L p .693 .178 .003 r
F P
0 g
s
.41748 .48211 m .42437 .48372 L .4267 .48272 L p .532 0 0 r
F P
0 g
s
.42964 .51376 m .42437 .51628 L .4267 .51728 L p .693 .953 .953 r
F P
0 g
s
.4267 .51728 m .43182 .51455 L .42964 .51376 L p .693 .953 .953 r
F P
0 g
s
.52149 .56633 m .52168 .57212 L .52371 .57363 L p 0 .009 .53 r
F P
0 g
s
.52577 .58041 m .52371 .57363 L .52168 .57212 L p 0 .035 .59 r
F P
0 g
s
.06959 .56388 m .06511 .53772 L .06607 .53599 L p .968 .716 .285 r
F P
0 g
s
.06389 .51951 m .06607 .53599 L .06511 .53772 L p .963 .743 .299 r
F P
0 g
s
.06607 .53599 m .06389 .51951 L .06438 .51774 L p .975 .757 .334 r
F P
0 g
s
.65988 .09532 m .68478 .10451 L .68579 .10621 L p .16 .586 .934 r
F P
0 g
s
.70116 .11257 m .68579 .10621 L .68478 .10451 L p .09 .528 .907 r
F P
0 g
s
.68579 .10621 m .70116 .11257 L .70244 .11387 L p .126 .542 .919 r
F P
0 g
s
.06607 .46401 m .06389 .48049 L .06337 .47958 L p .963 .829 .403 r
F P
0 g
s
.06337 .47958 m .06511 .46228 L .06607 .46401 L p .963 .829 .403 r
F P
0 g
s
.74813 .1422 m .73495 .13207 L .736 .13208 L p 0 .411 .855 r
F P
0 g
s
.736 .13208 m .75011 .14223 L .74813 .1422 L p 0 .411 .855 r
F P
0 g
s
.77052 .8408 m .75011 .85777 L .74813 .8578 L p .001 0 0 r
F P
0 g
s
.73495 .86793 m .74813 .8578 L .75011 .85777 L p 0 0 0 r
F P
0 g
s
.74813 .8578 m .73495 .86793 L .73318 .86839 L p .044 0 0 r
F P
0 g
s
.68579 .89379 m .70116 .88743 L .70063 .88834 L p .09 0 0 r
F P
0 g
s
.70063 .88834 m .68478 .89549 L .68579 .89379 L p .09 0 0 r
F P
0 g
s
.56825 .59465 m .56862 .6131 L .5682 .61239 L p 0 0 .066 r
F P
0 g
s
.5682 .61239 m .56791 .59418 L .56825 .59465 L p 0 0 .066 r
F P
0 g
s
.56791 .40582 m .5682 .38761 L .56862 .3869 L p 0 0 .041 r
F P
0 g
s
.54785 .39356 m .56363 .38402 L .56324 .38474 L p .417 .834 .658 r
F P
0 g
s
.56324 .38474 m .5476 .3941 L .54785 .39356 L p .417 .834 .658 r
F P
0 g
s
.38449 .48828 m .36857 .49714 L .36774 .49712 L p .395 .826 .67 r
F P
0 g
s
.5476 .6059 m .56324 .61526 L .56363 .61598 L p .417 0 0 r
F P
0 g
s
.3839 .51178 m .36774 .50288 L .36857 .50286 L p .395 0 0 r
F P
0 g
s
.36857 .50286 m .38449 .51172 L .3839 .51178 L p .395 0 0 r
F P
0 g
s
.54248 .55228 m .5471 .55406 L .54669 .55177 L p .705 .218 .087 r
F P
0 g
s
.54669 .55177 m .54196 .55019 L .54248 .55228 L p .705 .218 .087 r
F P
0 g
s
.54196 .44981 m .54669 .44823 L .5471 .44594 L p .705 .933 .963 r
F P
0 g
s
.55191 .44265 m .5471 .44594 L .54669 .44823 L p .782 .984 .901 r
F P
0 g
s
.52404 .43707 m .52327 .43219 L .52149 .43367 L p .056 .098 .589 r
F P
0 g
s
.52149 .43367 m .52248 .43857 L .52404 .43707 L p .056 .098 .589 r
F P
0 g
s
.43556 .48876 m .43182 .48545 L .42964 .48624 L p .815 .359 .151 r
F P
0 g
s
.42437 .48372 m .42964 .48624 L .43182 .48545 L p .693 .178 .003 r
F P
0 g
s
.52248 .56143 m .52149 .56633 L .52327 .56781 L p .056 0 .462 r
F P
0 g
s
.52371 .57363 m .52327 .56781 L .52149 .56633 L p 0 .009 .53 r
F P
0 g
s
.43348 .51065 m .42964 .51376 L .43182 .51455 L p .815 .971 .9 r
F P
0 g
s
.43182 .51455 m .43556 .51124 L .43348 .51065 L p .815 .971 .9 r
F P
0 g
s
.07997 .39941 m .06959 .43612 L .06794 .43588 L p .926 .89 .478 r
F P
0 g
s
.06794 .43588 m .07741 .3988 L .07997 .39941 L p .926 .89 .478 r
F P
0 g
s
.6229 .91405 m .65988 .90468 L .6605 .90624 L p .15 0 0 r
F P
0 g
s
.6605 .90624 m .62365 .91657 L .6229 .91405 L p .15 0 0 r
F P
0 g
s
.79713 .18653 m .77052 .1592 L .77156 .15788 L p 0 .255 .761 r
F P
0 g
s
.77156 .15788 m .79894 .18463 L .79713 .18653 L p 0 .255 .761 r
F P
0 g
s
.09783 .64914 m .07741 .6012 L .07997 .60059 L p .892 .519 .054 r
F P
0 g
s
.06959 .56388 m .07997 .60059 L .07741 .6012 L p .926 .621 .149 r
F P
0 g
s
.57192 .07714 m .62365 .08343 L .6229 .08595 L p .24 .712 .942 r
F P
0 g
s
.65988 .09532 m .6229 .08595 L .62365 .08343 L p .15 .623 .926 r
F P
0 g
s
.83024 .77372 m .79894 .81537 L .79713 .81347 L p 0 0 0 r
F P
0 g
s
.77052 .8408 m .79713 .81347 L .79894 .81537 L p 0 0 0 r
F P
0 g
s
.71094 .11748 m .70244 .11387 L .70116 .11257 L p .066 .497 .894 r
F P
0 g
s
.70244 .11387 m .71094 .11748 L .7119 .11827 L p .082 .503 .9 r
F P
0 g
s
.06326 .50858 m .06438 .51774 L .06389 .51951 L p .964 .767 .326 r
F P
0 g
s
.06438 .51774 m .06326 .50858 L .06346 .50736 L p .97 .775 .344 r
F P
0 g
s
.73318 .13161 m .7258 .12606 L .72665 .12628 L p .023 .442 .87 r
F P
0 g
s
.72665 .12628 m .73495 .13207 L .73318 .13161 L p .023 .442 .87 r
F P
0 g
s
.7258 .87394 m .73318 .86839 L .73495 .86793 L p .023 0 0 r
F P
0 g
s
.73318 .86839 m .7258 .87394 L .72464 .87437 L p .044 0 0 r
F P
0 g
s
.06438 .48226 m .06326 .49142 L .06302 .49057 L p .964 .808 .376 r
F P
0 g
s
.06302 .49057 m .06389 .48049 L .06438 .48226 L p .964 .808 .376 r
F P
0 g
s
.70244 .88613 m .71094 .88252 L .71033 .88315 L p .066 0 0 r
F P
0 g
s
.71033 .88315 m .70116 .88743 L .70244 .88613 L p .066 0 0 r
F P
0 g
s
.71849 .12157 m .71806 .1223 L .7163 .12125 L p .049 .473 .885 r
F P
0 g
s
.71806 .1223 m .71849 .12157 L .71922 .12199 L p .047 .471 .883 r
F P
0 g
s
.71922 .12199 m .71986 .12331 L .71806 .1223 L p .047 .471 .883 r
F P
0 g
s
.71849 .87843 m .71806 .8777 L .71986 .87669 L p .047 0 0 r
F P
0 g
s
.71806 .8777 m .71849 .87843 L .71776 .87886 L p .049 0 0 r
F P
0 g
s
.71776 .87886 m .7163 .87875 L .71806 .8777 L p .049 0 0 r
F P
0 g
s
.06303 .5 m .06387 .5 L .06385 .50206 L p .966 .788 .353 r
F P
0 g
s
.06387 .5 m .06303 .5 L .06302 .49916 L p .966 .79 .355 r
F P
0 g
s
.06302 .49916 m .06385 .49794 L .06387 .5 L p .966 .79 .355 r
F P
0 g
s
.06385 .49794 m .06302 .49916 L .06299 .49835 L p .965 .791 .356 r
F P
0 g
s
.06299 .49835 m .06377 .49598 L .06385 .49794 L p .965 .791 .356 r
F P
0 g
s
.71986 .12331 m .71922 .12199 L .71994 .12236 L p .043 .467 .881 r
F P
0 g
s
.71994 .12236 m .7216 .12422 L .71986 .12331 L p .043 .467 .881 r
F P
0 g
s
.06302 .50084 m .06385 .50206 L .06377 .50402 L p .965 .785 .349 r
F P
0 g
s
.06385 .50206 m .06302 .50084 L .06303 .5 L p .966 .788 .353 r
F P
0 g
s
.71922 .87801 m .71986 .87669 L .7216 .87578 L p .043 0 0 r
F P
0 g
s
.71986 .87669 m .71922 .87801 L .71849 .87843 L p .047 0 0 r
F P
0 g
s
.71776 .12114 m .7163 .12125 L .71463 .1202 L p .049 .475 .885 r
F P
0 g
s
.7163 .12125 m .71776 .12114 L .71849 .12157 L p .049 .473 .885 r
F P
0 g
s
.7163 .87875 m .71776 .87886 L .71708 .87929 L p .049 0 0 r
F P
0 g
s
.71708 .87929 m .71463 .8798 L .7163 .87875 L p .049 0 0 r
F P
0 g
s
.53821 .55177 m .54248 .55228 L .54196 .55019 L p .618 .152 .126 r
F P
0 g
s
.54196 .55019 m .53753 .54982 L .53821 .55177 L p .618 .152 .126 r
F P
0 g
s
.53753 .45018 m .54196 .44981 L .54248 .44772 L p .617 .856 .988 r
F P
0 g
s
.5471 .44594 m .54248 .44772 L .54196 .44981 L p .705 .933 .963 r
F P
0 g
s
.52573 .44103 m .52404 .43707 L .52248 .43857 L p .153 .258 .72 r
F P
0 g
s
.52248 .43857 m .52438 .44259 L .52573 .44103 L p .153 .258 .72 r
F P
0 g
s
.43809 .49241 m .43556 .48876 L .43348 .48935 L p .9 .516 .289 r
F P
0 g
s
.42964 .48624 m .43348 .48935 L .43556 .48876 L p .815 .359 .151 r
F P
0 g
s
.52438 .55741 m .52248 .56143 L .52404 .56293 L p .153 0 .394 r
F P
0 g
s
.52327 .56781 m .52404 .56293 L .52248 .56143 L p .056 0 .462 r
F P
0 g
s
.43606 .5072 m .43348 .51065 L .43556 .51124 L p .9 .954 .825 r
F P
0 g
s
.43556 .51124 m .43809 .50759 L .43606 .5072 L p .9 .954 .825 r
F P
0 g
s
.06299 .50165 m .06377 .50402 L .06364 .50582 L p .964 .782 .343 r
F P
0 g
s
.06377 .50402 m .06299 .50165 L .06302 .50084 L p .965 .785 .349 r
F P
0 g
s
.71708 .12071 m .71463 .1202 L .71314 .11919 L p .047 .476 .885 r
F P
0 g
s
.71463 .1202 m .71708 .12071 L .71776 .12114 L p .049 .475 .885 r
F P
0 g
s
.06377 .49598 m .06299 .49835 L .06293 .49761 L p .964 .792 .355 r
F P
0 g
s
.06293 .49761 m .06364 .49418 L .06377 .49598 L p .964 .792 .355 r
F P
0 g
s
.7216 .12422 m .71994 .12236 L .7206 .12268 L p .037 .462 .879 r
F P
0 g
s
.7206 .12268 m .72322 .12501 L .7216 .12422 L p .037 .462 .879 r
F P
0 g
s
.71994 .87764 m .7216 .87578 L .72322 .87499 L p .037 0 0 r
F P
0 g
s
.7216 .87578 m .71994 .87764 L .71922 .87801 L p .043 0 0 r
F P
0 g
s
.71463 .8798 m .71708 .87929 L .71647 .8797 L p .047 0 0 r
F P
0 g
s
.71647 .8797 m .71314 .88081 L .71463 .8798 L p .047 0 0 r
F P
0 g
s
.56791 .59418 m .56528 .58031 L .56555 .58064 L p 0 0 .172 r
F P
0 g
s
.56862 .3869 m .56825 .40535 L .56791 .40582 L p 0 0 .041 r
F P
0 g
s
.36774 .49712 m .3839 .48822 L .38449 .48828 L p .395 .826 .67 r
F P
0 g
s
.5476 .3941 m .53691 .40331 L .53707 .40291 L p .501 .845 .574 r
F P
0 g
s
.56363 .61598 m .54785 .60644 L .5476 .6059 L p .417 0 0 r
F P
0 g
s
.38449 .51172 m .39781 .51638 L .39738 .51645 L p .271 0 0 r
F P
0 g
s
.53352 .44953 m .53753 .45018 L .53821 .44823 L p .526 .762 .983 r
F P
0 g
s
.54248 .44772 m .53821 .44823 L .53753 .45018 L p .617 .856 .988 r
F P
0 g
s
.52812 .4441 m .52573 .44103 L .52438 .44259 L p .249 .405 .823 r
F P
0 g
s
.52438 .44259 m .52695 .44573 L .52812 .4441 L p .249 .405 .823 r
F P
0 g
s
.53436 .5523 m .53821 .55177 L .53753 .54982 L p .526 .097 .169 r
F P
0 g
s
.53753 .54982 m .53352 .55047 L .53436 .5523 L p .526 .097 .169 r
F P
0 g
s
.43953 .4962 m .43809 .49241 L .43606 .4928 L p .954 .648 .416 r
F P
0 g
s
.43348 .48935 m .43606 .4928 L .43809 .49241 L p .9 .516 .289 r
F P
0 g
s
.52695 .55427 m .52438 .55741 L .52573 .55897 L p .249 .001 .329 r
F P
0 g
s
.52404 .56293 m .52573 .55897 L .52438 .55741 L p .153 0 .394 r
F P
0 g
s
.43753 .5036 m .43606 .5072 L .43809 .50759 L p .954 .909 .736 r
F P
0 g
s
.43809 .50759 m .43953 .5038 L .43753 .5036 L p .954 .909 .736 r
F P
0 g
s
.531 .4463 m .52812 .4441 L .52695 .44573 L p .342 .536 .899 r
F P
0 g
s
.52695 .44573 m .53001 .44802 L .531 .4463 L p .342 .536 .899 r
F P
0 g
s
.53001 .44803 m .53352 .44953 L .53436 .4477 L p .434 .654 .952 r
F P
0 g
s
.53821 .44823 m .53436 .4477 L .53352 .44953 L p .526 .762 .983 r
F P
0 g
s
.531 .5537 m .53436 .5523 L .53352 .55047 L p .434 .054 .217 r
F P
0 g
s
.53352 .55047 m .53001 .55197 L .531 .5537 L p .434 .054 .217 r
F P
0 g
s
.53001 .55198 m .52695 .55427 L .52812 .5559 L p .342 .022 .27 r
F P
0 g
s
.52573 .55897 m .52812 .5559 L .52695 .55427 L p .249 .001 .329 r
F P
0 g
s
.43998 .5 m .43953 .4962 L .43753 .4964 L p .979 .756 .532 r
F P
0 g
s
.43606 .4928 m .43753 .4964 L .43953 .4962 L p .954 .648 .416 r
F P
0 g
s
.438 .5 m .43753 .5036 L .43953 .5038 L p .979 .842 .638 r
F P
0 g
s
.43953 .5038 m .43998 .5 L .438 .5 L p .979 .842 .638 r
F P
0 g
s
.53436 .4477 m .531 .4463 L .53001 .44803 L p .434 .654 .952 r
F P
0 g
s
.52812 .5559 m .531 .5537 L .53001 .55198 L p .342 .022 .27 r
F P
0 g
s
.43753 .4964 m .438 .5 L .43998 .5 L p .979 .756 .532 r
F P
0 g
s
.06364 .49418 m .06293 .49761 L .06286 .49698 L p .962 .792 .353 r
F P
0 g
s
.06286 .49698 m .06346 .49264 L .06364 .49418 L p .962 .792 .353 r
F P
0 g
s
.71314 .88081 m .71647 .8797 L .71595 .88008 L p .043 0 0 r
F P
0 g
s
.71595 .88008 m .7119 .88173 L .71314 .88081 L p .043 0 0 r
F P
0 g
s
.72322 .12501 m .7206 .12268 L .72118 .12294 L p .029 .457 .875 r
F P
0 g
s
.72118 .12294 m .72464 .12563 L .72322 .12501 L p .029 .457 .875 r
F P
0 g
s
.7206 .87732 m .72322 .87499 L .72464 .87437 L p .029 0 0 r
F P
0 g
s
.72322 .87499 m .7206 .87732 L .71994 .87764 L p .037 0 0 r
F P
0 g
s
.06293 .50239 m .06364 .50582 L .06346 .50736 L p .962 .779 .337 r
F P
0 g
s
.06364 .50582 m .06293 .50239 L .06299 .50165 L p .964 .782 .343 r
F P
0 g
s
.71647 .1203 m .71314 .11919 L .7119 .11827 L p .043 .475 .883 r
F P
0 g
s
.71314 .11919 m .71647 .1203 L .71708 .12071 L p .047 .476 .885 r
F P
0 g
s
.56528 .58031 m .56134 .56999 L .56155 .57023 L p 0 0 .279 r
F P
0 g
s
.53691 .40331 m .52994 .41188 L .53004 .41158 L p .575 .833 .472 r
F P
0 g
s
.56825 .40535 m .56555 .41936 L .56528 .41969 L p 0 0 0 r
F P
0 g
s
.3839 .48822 m .39738 .48355 L .39781 .48362 L p .271 .766 .706 r
F P
0 g
s
.54785 .60644 m .53707 .59709 L .53691 .59669 L p .501 0 0 r
F P
0 g
s
.39781 .51638 m .40871 .51813 L .4084 .51819 L p .138 0 0 r
F P
0 g
s
.06959 .43612 m .06511 .46228 L .06412 .46219 L p .94 .849 .414 r
F P
0 g
s
.06412 .46219 m .06794 .43588 L .06959 .43612 L p .94 .849 .414 r
F P
0 g
s
.07741 .6012 m .06794 .56412 L .06959 .56388 L p .926 .621 .149 r
F P
0 g
s
.06511 .53772 m .06959 .56388 L .06794 .56412 L p .94 .687 .216 r
F P
0 g
s
.79894 .81537 m .77156 .84212 L .77052 .8408 L p 0 0 0 r
F P
0 g
s
.75011 .85777 m .77052 .8408 L .77156 .84212 L p 0 0 0 r
F P
0 g
s
.62365 .08343 m .6605 .09376 L .65988 .09532 L p .15 .623 .926 r
F P
0 g
s
.68478 .10451 m .65988 .09532 L .6605 .09376 L p .088 .555 .906 r
F P
0 g
s
.77052 .1592 m .75011 .14223 L .75068 .14142 L p 0 .334 .807 r
F P
0 g
s
.75068 .14142 m .77156 .15788 L .77052 .1592 L p 0 .334 .807 r
F P
0 g
s
.65988 .90468 m .68478 .89549 L .6852 .89638 L p .088 0 0 r
F P
0 g
s
.6852 .89638 m .6605 .90624 L .65988 .90468 L p .088 0 0 r
F P
0 g
s
.06346 .49264 m .06286 .49698 L .06278 .49648 L p .959 .791 .349 r
F P
0 g
s
.06278 .49648 m .06326 .49142 L .06346 .49264 L p .959 .791 .349 r
F P
0 g
s
.7119 .88173 m .71595 .88008 L .71556 .88041 L p .037 0 0 r
F P
0 g
s
.71556 .88041 m .71094 .88252 L .7119 .88173 L p .037 0 0 r
F P
0 g
s
.72464 .12563 m .72118 .12294 L .72166 .12311 L p .02 .451 .871 r
F P
0 g
s
.72166 .12311 m .7258 .12606 L .72464 .12563 L p .02 .451 .871 r
F P
0 g
s
.71595 .11992 m .7119 .11827 L .71094 .11748 L p .037 .473 .881 r
F P
0 g
s
.7119 .11827 m .71595 .11992 L .71647 .1203 L p .043 .475 .883 r
F P
0 g
s
.06286 .50302 m .06346 .50736 L .06326 .50858 L p .959 .775 .329 r
F P
0 g
s
.06346 .50736 m .06286 .50302 L .06293 .50239 L p .962 .779 .337 r
F P
0 g
s
.72118 .87706 m .72464 .87437 L .7258 .87394 L p .02 0 0 r
F P
0 g
s
.72464 .87437 m .72118 .87706 L .7206 .87732 L p .029 0 0 r
F P
0 g
s
.06511 .53772 m .06337 .52042 L .06389 .51951 L p .963 .743 .299 r
F P
0 g
s
.06302 .50943 m .06389 .51951 L .06337 .52042 L p .957 .759 .307 r
F P
0 g
s
.06389 .51951 m .06302 .50943 L .06326 .50858 L p .964 .767 .326 r
F P
0 g
s
.68478 .10451 m .70063 .11166 L .70116 .11257 L p .09 .528 .907 r
F P
0 g
s
.71033 .11685 m .70116 .11257 L .70063 .11166 L p .046 .489 .887 r
F P
0 g
s
.70116 .11257 m .71033 .11685 L .71094 .11748 L p .066 .497 .894 r
F P
0 g
s
.75011 .85777 m .736 .86792 L .73495 .86793 L p 0 0 0 r
F P
0 g
s
.72665 .87372 m .73495 .86793 L .736 .86792 L p 0 0 0 r
F P
0 g
s
.73495 .86793 m .72665 .87372 L .7258 .87394 L p .023 0 0 r
F P
0 g
s
.73495 .13207 m .72665 .12628 L .72716 .12628 L p 0 .429 .86 r
F P
0 g
s
.72716 .12628 m .736 .13208 L .73495 .13207 L p 0 .429 .86 r
F P
0 g
s
.70116 .88743 m .71033 .88315 L .71008 .88359 L p .046 0 0 r
F P
0 g
s
.71008 .88359 m .70063 .88834 L .70116 .88743 L p .046 0 0 r
F P
0 g
s
.06389 .48049 m .06302 .49057 L .06277 .49014 L p .957 .803 .361 r
F P
0 g
s
.06277 .49014 m .06337 .47958 L .06389 .48049 L p .957 .803 .361 r
F P
0 g
s
.56134 .56999 m .55675 .56252 L .55691 .5627 L p 0 0 .383 r
F P
0 g
s
.52994 .41188 m .52577 .41959 L .52584 .41936 L p .635 .793 .349 r
F P
0 g
s
.56555 .41936 m .56155 .42977 L .56134 .43001 L p 0 0 0 r
F P
0 g
s
.39738 .48355 m .4084 .48181 L .40871 .48187 L p .138 .682 .724 r
F P
0 g
s
.53707 .59709 m .53004 .58842 L .52994 .58812 L p .575 .106 0 r
F P
0 g
s
.40871 .51813 m .41748 .51789 L .41725 .51794 L p 0 0 0 r
F P
0 g
s
.71556 .11959 m .71094 .11748 L .71033 .11685 L p .03 .47 .878 r
F P
0 g
s
.71094 .11748 m .71556 .11959 L .71595 .11992 L p .037 .473 .881 r
F P
0 g
s
.72166 .87689 m .7258 .87394 L .72665 .87372 L p .01 0 0 r
F P
0 g
s
.7258 .87394 m .72166 .87689 L .72118 .87706 L p .02 0 0 r
F P
0 g
s
.06278 .50352 m .06326 .50858 L .06302 .50943 L p .956 .772 .321 r
F P
0 g
s
.06326 .50858 m .06278 .50352 L .06286 .50302 L p .959 .775 .329 r
F P
0 g
s
.7258 .12606 m .72166 .12311 L .72201 .1232 L p .01 .445 .867 r
F P
0 g
s
.72201 .1232 m .72665 .12628 L .7258 .12606 L p .01 .445 .867 r
F P
0 g
s
.71094 .88252 m .71556 .88041 L .71531 .88066 L p .03 0 0 r
F P
0 g
s
.71531 .88066 m .71033 .88315 L .71094 .88252 L p .03 0 0 r
F P
0 g
s
.06326 .49142 m .06278 .49648 L .06268 .49613 L p .956 .79 .343 r
F P
0 g
s
.06268 .49613 m .06302 .49057 L .06326 .49142 L p .956 .79 .343 r
F P
0 g
s
.55191 .44265 m .55675 .43748 L .55691 .4373 L p .517 .817 .484 r
F P
0 g
s
.56155 .42977 m .55691 .4373 L .55675 .43748 L p 0 0 0 r
F P
0 g
s
.52377 .42619 m .52584 .41936 L .52577 .41959 L p 0 0 0 r
F P
0 g
s
.52577 .41959 m .52371 .42637 L .52377 .42619 L p 0 0 0 r
F P
0 g
s
.55204 .55749 m .55691 .5627 L .55675 .56252 L p .517 .028 0 r
F P
0 g
s
.55675 .56252 m .55191 .55735 L .55204 .55749 L p .517 .028 0 r
F P
0 g
s
.42437 .48372 m .41748 .48211 L .41725 .48206 L p .162 0 0 r
F P
0 g
s
.4084 .48181 m .41725 .48206 L .41748 .48211 L p 0 .571 .719 r
F P
0 g
s
.42419 .51632 m .41725 .51794 L .41748 .51789 L p .162 .694 .69 r
F P
0 g
s
.41748 .51789 m .42437 .51628 L .42419 .51632 L p .162 .694 .69 r
F P
0 g
s
.52371 .57363 m .52577 .58041 L .52584 .58064 L p 0 0 .206 r
F P
0 g
s
.53004 .58842 m .52584 .58064 L .52577 .58041 L p .635 .244 0 r
F P
0 g
s
.54719 .55417 m .55204 .55749 L .55191 .55735 L p .414 0 0 r
F P
0 g
s
.55191 .55735 m .5471 .55406 L .54719 .55417 L p .414 0 0 r
F P
0 g
s
.5471 .44594 m .55191 .44265 L .55204 .44251 L p .414 .814 .598 r
F P
0 g
s
.55691 .4373 m .55204 .44251 L .55191 .44265 L p .517 .817 .484 r
F P
0 g
s
.52331 .43204 m .52377 .42619 L .52371 .42637 L p 0 0 0 r
F P
0 g
s
.52371 .42637 m .52327 .43219 L .52331 .43204 L p 0 0 0 r
F P
0 g
s
.42964 .48624 m .42437 .48372 L .42419 .48368 L p .32 0 0 r
F P
0 g
s
.41725 .48206 m .42419 .48368 L .42437 .48372 L p .162 0 0 r
F P
0 g
s
.52327 .56781 m .52371 .57363 L .52377 .57381 L p 0 0 .069 r
F P
0 g
s
.52584 .58064 m .52377 .57381 L .52371 .57363 L p 0 0 .206 r
F P
0 g
s
.42949 .51379 m .42419 .51632 L .42437 .51628 L p .32 .782 .652 r
F P
0 g
s
.42437 .51628 m .42964 .51376 L .42949 .51379 L p .32 .782 .652 r
F P
0 g
s
.06266 .5 m .06303 .5 L .06302 .50084 L p .956 .78 .33 r
F P
0 g
s
.06303 .5 m .06266 .5 L .06266 .49973 L p .956 .781 .331 r
F P
0 g
s
.06266 .49973 m .06302 .49916 L .06303 .5 L p .956 .781 .331 r
F P
0 g
s
.71867 .12126 m .71849 .12157 L .71776 .12114 L p .019 .457 .872 r
F P
0 g
s
.71849 .12157 m .71867 .12126 L .7189 .12139 L p .018 .456 .872 r
F P
0 g
s
.7189 .12139 m .71922 .12199 L .71849 .12157 L p .018 .456 .872 r
F P
0 g
s
.71867 .87874 m .71849 .87843 L .71922 .87801 L p .018 0 0 r
F P
0 g
s
.71849 .87843 m .71867 .87874 L .71844 .87888 L p .019 0 0 r
F P
0 g
s
.71844 .87888 m .71776 .87886 L .71849 .87843 L p .019 0 0 r
F P
0 g
s
.06302 .49916 m .06266 .49973 L .06265 .49948 L p .955 .781 .331 r
F P
0 g
s
.06265 .49948 m .06299 .49835 L .06302 .49916 L p .955 .781 .331 r
F P
0 g
s
.71922 .12199 m .7189 .12139 L .71913 .1215 L p .016 .455 .871 r
F P
0 g
s
.71913 .1215 m .71994 .12236 L .71922 .12199 L p .016 .455 .871 r
F P
0 g
s
.71844 .12112 m .71776 .12114 L .71708 .12071 L p .019 .458 .872 r
F P
0 g
s
.71776 .12114 m .71844 .12112 L .71867 .12126 L p .019 .457 .872 r
F P
0 g
s
.71776 .87886 m .71844 .87888 L .71822 .87902 L p .019 0 0 r
F P
0 g
s
.71822 .87902 m .71708 .87929 L .71776 .87886 L p .019 0 0 r
F P
0 g
s
.7189 .87861 m .71922 .87801 L .71994 .87764 L p .016 0 0 r
F P
0 g
s
.71922 .87801 m .7189 .87861 L .71867 .87874 L p .018 0 0 r
F P
0 g
s
.06266 .50027 m .06302 .50084 L .06299 .50165 L p .955 .779 .329 r
F P
0 g
s
.06302 .50084 m .06266 .50027 L .06266 .5 L p .956 .78 .33 r
F P
0 g
s
.75011 .14223 m .736 .13208 L .73629 .13163 L p 0 .385 .834 r
F P
0 g
s
.73629 .13163 m .75068 .14142 L .75011 .14223 L p 0 .385 .834 r
F P
0 g
s
.06794 .56412 m .06412 .53781 L .06511 .53772 L p .94 .687 .216 r
F P
0 g
s
.06337 .52042 m .06511 .53772 L .06412 .53781 L p .946 .728 .261 r
F P
0 g
s
.68478 .89549 m .70063 .88834 L .70087 .88882 L p .049 0 0 r
F P
0 g
s
.70087 .88882 m .6852 .89638 L .68478 .89549 L p .049 0 0 r
F P
0 g
s
.6605 .09376 m .6852 .10362 L .68478 .10451 L p .088 .555 .906 r
F P
0 g
s
.70063 .11166 m .68478 .10451 L .6852 .10362 L p .049 .508 .889 r
F P
0 g
s
.06511 .46228 m .06337 .47958 L .06283 .47955 L p .946 .817 .371 r
F P
0 g
s
.06283 .47955 m .06412 .46219 L .06511 .46228 L p .946 .817 .371 r
F P
0 g
s
.77156 .84212 m .75068 .85858 L .75011 .85777 L p 0 0 0 r
F P
0 g
s
.736 .86792 m .75011 .85777 L .75068 .85858 L p 0 0 0 r
F P
0 g
s
.71822 .12098 m .71708 .12071 L .71647 .1203 L p .018 .458 .872 r
F P
0 g
s
.71708 .12071 m .71822 .12098 L .71844 .12112 L p .019 .458 .872 r
F P
0 g
s
.06265 .50052 m .06299 .50165 L .06293 .50239 L p .955 .778 .327 r
F P
0 g
s
.06299 .50165 m .06265 .50052 L .06266 .50027 L p .955 .779 .329 r
F P
0 g
s
.71913 .8785 m .71994 .87764 L .7206 .87732 L p .014 0 0 r
F P
0 g
s
.71994 .87764 m .71913 .8785 L .7189 .87861 L p .016 0 0 r
F P
0 g
s
.71708 .87929 m .71822 .87902 L .71803 .87915 L p .018 0 0 r
F P
0 g
s
.71803 .87915 m .71647 .8797 L .71708 .87929 L p .018 0 0 r
F P
0 g
s
.71994 .12236 m .71913 .1215 L .71934 .12161 L p .014 .453 .87 r
F P
0 g
s
.71934 .12161 m .7206 .12268 L .71994 .12236 L p .014 .453 .87 r
F P
0 g
s
.06299 .49835 m .06265 .49948 L .06263 .49924 L p .955 .781 .331 r
F P
0 g
s
.06263 .49924 m .06293 .49761 L .06299 .49835 L p .955 .781 .331 r
F P
0 g
s
.54256 .55238 m .54719 .55417 L .5471 .55406 L p .281 0 0 r
F P
0 g
s
.5471 .55406 m .54248 .55228 L .54256 .55238 L p .281 0 0 r
F P
0 g
s
.52408 .43695 m .52331 .43204 L .52327 .43219 L p 0 0 .137 r
F P
0 g
s
.52327 .43219 m .52404 .43707 L .52408 .43695 L p 0 0 .137 r
F P
0 g
s
.54248 .44772 m .5471 .44594 L .54719 .44583 L p .281 .768 .686 r
F P
0 g
s
.55204 .44251 m .54719 .44583 L .5471 .44594 L p .414 .814 .598 r
F P
0 g
s
.43348 .48935 m .42964 .48624 L .42949 .48621 L p .471 0 0 r
F P
0 g
s
.42419 .48368 m .42949 .48621 L .42964 .48624 L p .32 0 0 r
F P
0 g
s
.43336 .51067 m .42949 .51379 L .42964 .51376 L p .471 .833 .577 r
F P
0 g
s
.42964 .51376 m .43348 .51065 L .43336 .51067 L p .471 .833 .577 r
F P
0 g
s
.52404 .56293 m .52327 .56781 L .52331 .56796 L p 0 0 0 r
F P
0 g
s
.52377 .57381 m .52331 .56796 L .52327 .56781 L p 0 0 .069 r
F P
0 g
s
.71934 .87839 m .7206 .87732 L .72118 .87706 L p .011 0 0 r
F P
0 g
s
.7206 .87732 m .71934 .87839 L .71913 .8785 L p .014 0 0 r
F P
0 g
s
.71803 .12085 m .71647 .1203 L .71595 .11992 L p .016 .458 .871 r
F P
0 g
s
.71647 .1203 m .71803 .12085 L .71822 .12098 L p .018 .458 .872 r
F P
0 g
s
.71647 .8797 m .71803 .87915 L .71787 .87927 L p .016 0 0 r
F P
0 g
s
.71787 .87927 m .71595 .88008 L .71647 .8797 L p .016 0 0 r
F P
0 g
s
.7206 .12268 m .71934 .12161 L .71952 .12169 L p .011 .451 .868 r
F P
0 g
s
.71952 .12169 m .72118 .12294 L .7206 .12268 L p .011 .451 .868 r
F P
0 g
s
.06293 .49761 m .06263 .49924 L .06261 .49904 L p .954 .781 .33 r
F P
0 g
s
.06261 .49904 m .06286 .49698 L .06293 .49761 L p .954 .781 .33 r
F P
0 g
s
.06263 .50076 m .06293 .50239 L .06286 .50302 L p .954 .776 .324 r
F P
0 g
s
.06293 .50239 m .06263 .50076 L .06265 .50052 L p .955 .778 .327 r
F P
0 g
s
.52578 .44093 m .52408 .43695 L .52404 .43707 L p 0 0 .315 r
F P
0 g
s
.52404 .43707 m .52573 .44103 L .52578 .44093 L p 0 0 .315 r
F P
0 g
s
.53827 .55186 m .54256 .55238 L .54248 .55228 L p .123 0 0 r
F P
0 g
s
.54248 .55228 m .53821 .55177 L .53827 .55186 L p .123 0 0 r
F P
0 g
s
.53821 .44823 m .54248 .44772 L .54256 .44762 L p .123 .672 .739 r
F P
0 g
s
.54719 .44583 m .54256 .44762 L .54248 .44772 L p .281 .768 .686 r
F P
0 g
s
.43606 .4928 m .43348 .48935 L .43336 .48933 L p .603 .146 0 r
F P
0 g
s
.42949 .48621 m .43336 .48933 L .43348 .48935 L p .471 0 0 r
F P
0 g
s
.52573 .55897 m .52404 .56293 L .52408 .56305 L p 0 0 0 r
F P
0 g
s
.52331 .56796 m .52408 .56305 L .52404 .56293 L p 0 0 0 r
F P
0 g
s
.43595 .50721 m .43336 .51067 L .43348 .51065 L p .603 .838 .462 r
F P
0 g
s
.43348 .51065 m .43606 .5072 L .43595 .50721 L p .603 .838 .462 r
F P
0 g
s
.06302 .49057 m .06268 .49613 L .06258 .49596 L p .953 .788 .336 r
F P
0 g
s
.06258 .49596 m .06277 .49014 L .06302 .49057 L p .953 .788 .336 r
F P
0 g
s
.72665 .12628 m .72201 .1232 L .72221 .1232 L p 0 .439 .862 r
F P
0 g
s
.72221 .1232 m .72716 .12628 L .72665 .12628 L p 0 .439 .862 r
F P
0 g
s
.70063 .11166 m .71008 .11641 L .71033 .11685 L p .046 .489 .887 r
F P
0 g
s
.71531 .11934 m .71033 .11685 L .71008 .11641 L p .021 .466 .874 r
F P
0 g
s
.71033 .11685 m .71531 .11934 L .71556 .11959 L p .03 .47 .878 r
F P
0 g
s
.736 .86792 m .72716 .87372 L .72665 .87372 L p 0 0 0 r
F P
0 g
s
.72201 .8768 m .72665 .87372 L .72716 .87372 L p 0 0 0 r
F P
0 g
s
.72665 .87372 m .72201 .8768 L .72166 .87689 L p .01 0 0 r
F P
0 g
s
.71033 .88315 m .71531 .88066 L .71521 .88084 L p .021 0 0 r
F P
0 g
s
.71521 .88084 m .71008 .88359 L .71033 .88315 L p .021 0 0 r
F P
0 g
s
.06337 .52042 m .06277 .50986 L .06302 .50943 L p .957 .759 .307 r
F P
0 g
s
.06268 .50387 m .06302 .50943 L .06277 .50986 L p .953 .768 .312 r
F P
0 g
s
.06302 .50943 m .06268 .50387 L .06278 .50352 L p .956 .772 .321 r
F P
0 g
s
.52816 .44401 m .52578 .44093 L .52573 .44103 L p 0 0 .478 r
F P
0 g
s
.52573 .44103 m .52812 .4441 L .52816 .44401 L p 0 0 .478 r
F P
0 g
s
.53441 .55238 m .53827 .55186 L .53821 .55177 L p 0 0 0 r
F P
0 g
s
.53821 .55177 m .53436 .5523 L .53441 .55238 L p 0 0 0 r
F P
0 g
s
.53436 .4477 m .53821 .44823 L .53827 .44814 L p 0 .53 .745 r
F P
0 g
s
.54256 .44762 m .53827 .44814 L .53821 .44823 L p .123 .672 .739 r
F P
0 g
s
.52812 .5559 m .52573 .55897 L .52578 .55907 L p 0 0 0 r
F P
0 g
s
.52408 .56305 m .52578 .55907 L .52573 .55897 L p 0 0 0 r
F P
0 g
s
.43753 .4964 m .43606 .4928 L .43595 .49279 L p .699 .353 0 r
F P
0 g
s
.43336 .48933 m .43595 .49279 L .43606 .4928 L p .603 .146 0 r
F P
0 g
s
.43743 .50361 m .43595 .50721 L .43606 .5072 L p .699 .788 .312 r
F P
0 g
s
.43606 .5072 m .43753 .5036 L .43743 .50361 L p .699 .788 .312 r
F P
0 g
s
.53105 .44622 m .52816 .44401 L .52812 .4441 L p 0 .148 .61 r
F P
0 g
s
.52812 .4441 m .531 .4463 L .53105 .44622 L p 0 .148 .61 r
F P
0 g
s
.531 .4463 m .53436 .4477 L .53441 .44762 L p 0 .351 .701 r
F P
0 g
s
.53827 .44814 m .53441 .44762 L .53436 .4477 L p 0 .53 .745 r
F P
0 g
s
.438 .5 m .43753 .4964 L .43743 .49639 L p .749 .538 0 r
F P
0 g
s
.43595 .49279 m .43743 .49639 L .43753 .4964 L p .699 .353 0 r
F P
0 g
s
.53105 .55378 m .53441 .55238 L .53436 .5523 L p 0 0 0 r
F P
0 g
s
.53436 .5523 m .531 .5537 L .53105 .55378 L p 0 0 0 r
F P
0 g
s
.531 .5537 m .52812 .5559 L .52816 .55599 L p 0 0 0 r
F P
0 g
s
.52578 .55907 m .52816 .55599 L .52812 .5559 L p 0 0 0 r
F P
0 g
s
.4379 .5 m .43743 .50361 L .43753 .5036 L p .749 .686 .14 r
F P
0 g
s
.43753 .5036 m .438 .5 L .4379 .5 L p .749 .686 .14 r
F P
0 g
s
.53441 .44762 m .53105 .44622 L .531 .4463 L p 0 .351 .701 r
F P
0 g
s
.43743 .49639 m .4379 .5 L .438 .5 L p .749 .538 0 r
F P
0 g
s
.52816 .55599 m .53105 .55378 L .531 .5537 L p 0 0 0 r
F P
0 g
s
.06261 .50096 m .06286 .50302 L .06278 .50352 L p .953 .775 .321 r
F P
0 g
s
.06286 .50302 m .06261 .50096 L .06263 .50076 L p .954 .776 .324 r
F P
0 g
s
.71787 .12073 m .71595 .11992 L .71556 .11959 L p .014 .457 .871 r
F P
0 g
s
.71595 .11992 m .71787 .12073 L .71803 .12085 L p .016 .458 .871 r
F P
0 g
s
.71952 .87831 m .72118 .87706 L .72166 .87689 L p .008 0 0 r
F P
0 g
s
.72118 .87706 m .71952 .87831 L .71934 .87839 L p .011 0 0 r
F P
0 g
s
.72118 .12294 m .71952 .12169 L .71967 .12174 L p .008 .449 .867 r
F P
0 g
s
.71967 .12174 m .72166 .12311 L .72118 .12294 L p .008 .449 .867 r
F P
0 g
s
.71595 .88008 m .71787 .87927 L .71774 .87937 L p .014 0 0 r
F P
0 g
s
.71774 .87937 m .71556 .88041 L .71595 .88008 L p .014 0 0 r
F P
0 g
s
.06286 .49698 m .06261 .49904 L .06258 .49888 L p .953 .781 .328 r
F P
0 g
s
.06258 .49888 m .06278 .49648 L .06286 .49698 L p .953 .781 .328 r
F P
0 g
s
.736 .13208 m .72716 .12628 L .72729 .12605 L p 0 .416 .849 r
F P
0 g
s
.72729 .12605 m .73629 .13163 L .736 .13208 L p 0 .416 .849 r
F P
0 g
s
.06337 .47958 m .06277 .49014 L .06251 .49013 L p .948 .797 .344 r
F P
0 g
s
.06251 .49013 m .06283 .47955 L .06337 .47958 L p .948 .797 .344 r
F P
0 g
s
.70063 .88834 m .71008 .88359 L .7102 .88381 L p .024 0 0 r
F P
0 g
s
.7102 .88381 m .70087 .88882 L .70063 .88834 L p .024 0 0 r
F P
0 g
s
.06412 .53781 m .06283 .52045 L .06337 .52042 L p .946 .728 .261 r
F P
0 g
s
.06277 .50986 m .06337 .52042 L .06283 .52045 L p .948 .751 .288 r
F P
0 g
s
.6852 .10362 m .70087 .11118 L .70063 .11166 L p .049 .508 .889 r
F P
0 g
s
.71008 .11641 m .70063 .11166 L .70087 .11118 L p .024 .478 .877 r
F P
0 g
s
.75068 .85858 m .73629 .86837 L .736 .86792 L p 0 0 0 r
F P
0 g
s
.72716 .87372 m .736 .86792 L .73629 .86837 L p 0 0 0 r
F P
0 g
s
.06258 .50112 m .06278 .50352 L .06268 .50387 L p .952 .774 .318 r
F P
0 g
s
.06278 .50352 m .06258 .50112 L .06261 .50096 L p .953 .775 .321 r
F P
0 g
s
.71967 .87826 m .72166 .87689 L .72201 .8768 L p .004 0 0 r
F P
0 g
s
.72166 .87689 m .71967 .87826 L .71952 .87831 L p .008 0 0 r
F P
0 g
s
.71774 .12063 m .71556 .11959 L .71531 .11934 L p .011 .456 .869 r
F P
0 g
s
.71556 .11959 m .71774 .12063 L .71787 .12073 L p .014 .457 .871 r
F P
0 g
s
.06278 .49648 m .06258 .49888 L .06255 .49878 L p .952 .78 .326 r
F P
0 g
s
.06255 .49878 m .06268 .49613 L .06278 .49648 L p .952 .78 .326 r
F P
0 g
s
.72166 .12311 m .71967 .12174 L .71978 .12177 L p .004 .446 .865 r
F P
0 g
s
.71978 .12177 m .72201 .1232 L .72166 .12311 L p .004 .446 .865 r
F P
0 g
s
.71556 .88041 m .71774 .87937 L .71766 .87945 L p .011 0 0 r
F P
0 g
s
.71766 .87945 m .71531 .88066 L .71556 .88041 L p .011 0 0 r
F P
0 g
s
.71873 .12114 m .71867 .12126 L .71844 .12112 L p .005 .45 .866 r
F P
0 g
s
.71867 .12126 m .71873 .12114 L .71878 .12117 L p .005 .45 .866 r
F P
0 g
s
.71878 .12117 m .7189 .12139 L .71867 .12126 L p .005 .45 .866 r
F P
0 g
s
.71873 .87886 m .71867 .87874 L .7189 .87861 L p .005 0 0 r
F P
0 g
s
.71867 .87874 m .71873 .87886 L .71869 .87889 L p .005 0 0 r
F P
0 g
s
.71869 .87889 m .71844 .87888 L .71867 .87874 L p .005 0 0 r
F P
0 g
s
.06253 .5 m .06266 .5 L .06266 .50027 L p .951 .776 .32 r
F P
0 g
s
.06266 .5 m .06253 .5 L .06253 .49995 L p .951 .776 .32 r
F P
0 g
s
.06253 .49995 m .06266 .49973 L .06266 .5 L p .951 .776 .32 r
F P
0 g
s
.71878 .87883 m .7189 .87861 L .71913 .8785 L p .005 0 0 r
F P
0 g
s
.7189 .87861 m .71878 .87883 L .71873 .87886 L p .005 0 0 r
F P
0 g
s
.71869 .12111 m .71844 .12112 L .71822 .12098 L p .005 .45 .866 r
F P
0 g
s
.71844 .12112 m .71869 .12111 L .71873 .12114 L p .005 .45 .866 r
F P
0 g
s
.7189 .12139 m .71878 .12117 L .71883 .12119 L p .005 .449 .866 r
F P
0 g
s
.71883 .12119 m .71913 .1215 L .7189 .12139 L p .005 .449 .866 r
F P
0 g
s
.71844 .87888 m .71869 .87889 L .71865 .87891 L p .005 0 0 r
F P
0 g
s
.71865 .87891 m .71822 .87902 L .71844 .87888 L p .005 0 0 r
F P
0 g
s
.06253 .50005 m .06266 .50027 L .06265 .50052 L p .951 .776 .32 r
F P
0 g
s
.06266 .50027 m .06253 .50005 L .06253 .5 L p .951 .776 .32 r
F P
0 g
s
.06266 .49973 m .06253 .49995 L .06253 .4999 L p .951 .776 .321 r
F P
0 g
s
.06253 .4999 m .06265 .49948 L .06266 .49973 L p .951 .776 .321 r
F P
0 g
s
.72201 .1232 m .71978 .12177 L .71985 .12177 L p 0 .444 .863 r
F P
0 g
s
.71985 .12177 m .72221 .1232 L .72201 .1232 L p 0 .444 .863 r
F P
0 g
s
.71008 .11641 m .71521 .11916 L .71531 .11934 L p .021 .466 .874 r
F P
0 g
s
.71766 .12055 m .71531 .11934 L .71521 .11916 L p .008 .454 .868 r
F P
0 g
s
.71531 .11934 m .71766 .12055 L .71774 .12063 L p .011 .456 .869 r
F P
0 g
s
.71531 .88066 m .71766 .87945 L .71763 .87951 L p .008 0 0 r
F P
0 g
s
.71763 .87951 m .71521 .88084 L .71531 .88066 L p .008 0 0 r
F P
0 g
s
.06277 .50986 m .06258 .50404 L .06268 .50387 L p .953 .768 .312 r
F P
0 g
s
.06255 .50122 m .06268 .50387 L .06258 .50404 L p .95 .772 .315 r
F P
0 g
s
.06268 .50387 m .06255 .50122 L .06258 .50112 L p .952 .774 .318 r
F P
0 g
s
.06268 .49613 m .06255 .49878 L .06252 .49872 L p .95 .779 .324 r
F P
0 g
s
.06252 .49872 m .06258 .49596 L .06268 .49613 L p .95 .779 .324 r
F P
0 g
s
.72716 .87372 m .72221 .8768 L .72201 .8768 L p 0 0 0 r
F P
0 g
s
.71978 .87823 m .72201 .8768 L .72221 .8768 L p 0 0 0 r
F P
0 g
s
.72201 .8768 m .71978 .87823 L .71967 .87826 L p .004 0 0 r
F P
0 g
s
.06253 .5001 m .06265 .50052 L .06263 .50076 L p .95 .776 .319 r
F P
0 g
s
.06265 .50052 m .06253 .5001 L .06253 .50005 L p .951 .776 .32 r
F P
0 g
s
.71822 .87902 m .71865 .87891 L .71861 .87894 L p .005 0 0 r
F P
0 g
s
.71861 .87894 m .71803 .87915 L .71822 .87902 L p .005 0 0 r
F P
0 g
s
.71865 .12109 m .71822 .12098 L .71803 .12085 L p .005 .45 .866 r
F P
0 g
s
.71822 .12098 m .71865 .12109 L .71869 .12111 L p .005 .45 .866 r
F P
0 g
s
.71913 .1215 m .71883 .12119 L .71887 .12121 L p .004 .449 .866 r
F P
0 g
s
.71887 .12121 m .71934 .12161 L .71913 .1215 L p .004 .449 .866 r
F P
0 g
s
.71883 .87881 m .71913 .8785 L .71934 .87839 L p .004 0 0 r
F P
0 g
s
.71913 .8785 m .71883 .87881 L .71878 .87883 L p .005 0 0 r
F P
0 g
s
.06265 .49948 m .06253 .4999 L .06253 .49985 L p .95 .777 .32 r
F P
0 g
s
.06253 .49985 m .06263 .49924 L .06265 .49948 L p .95 .777 .32 r
F P
0 g
s
.06263 .49924 m .06253 .49985 L .06252 .49981 L p .95 .777 .32 r
F P
0 g
s
.06252 .49981 m .06261 .49904 L .06263 .49924 L p .95 .777 .32 r
F P
0 g
s
.71803 .87915 m .71861 .87894 L .71858 .87896 L p .005 0 0 r
F P
0 g
s
.71858 .87896 m .71787 .87927 L .71803 .87915 L p .005 0 0 r
F P
0 g
s
.71934 .12161 m .71887 .12121 L .7189 .12123 L p .003 .448 .865 r
F P
0 g
s
.7189 .12123 m .71952 .12169 L .71934 .12161 L p .003 .448 .865 r
F P
0 g
s
.06253 .50015 m .06263 .50076 L .06261 .50096 L p .95 .775 .318 r
F P
0 g
s
.06263 .50076 m .06253 .50015 L .06253 .5001 L p .95 .776 .319 r
F P
0 g
s
.71861 .12106 m .71803 .12085 L .71787 .12073 L p .005 .45 .866 r
F P
0 g
s
.71803 .12085 m .71861 .12106 L .71865 .12109 L p .005 .45 .866 r
F P
0 g
s
.71887 .87879 m .71934 .87839 L .71952 .87831 L p .003 0 0 r
F P
0 g
s
.71934 .87839 m .71887 .87879 L .71883 .87881 L p .004 0 0 r
F P
0 g
s
.06283 .52045 m .06251 .50987 L .06277 .50986 L p .948 .751 .288 r
F P
0 g
s
.06258 .50404 m .06277 .50986 L .06251 .50987 L p .949 .764 .304 r
F P
0 g
s
.70087 .11118 m .7102 .11619 L .71008 .11641 L p .024 .478 .877 r
F P
0 g
s
.71521 .11916 m .71008 .11641 L .7102 .11619 L p .011 .461 .87 r
F P
0 g
s
.73629 .86837 m .72729 .87395 L .72716 .87372 L p 0 0 0 r
F P
0 g
s
.72221 .8768 m .72716 .87372 L .72729 .87395 L p 0 0 0 r
F P
0 g
s
.72716 .12628 m .72221 .1232 L .72227 .12311 L p 0 .433 .858 r
F P
0 g
s
.72227 .12311 m .72729 .12605 L .72716 .12628 L p 0 .433 .858 r
F P
0 g
s
.71008 .88359 m .71521 .88084 L .71526 .88094 L p .011 0 0 r
F P
0 g
s
.71526 .88094 m .7102 .88381 L .71008 .88359 L p .011 0 0 r
F P
0 g
s
.06277 .49014 m .06258 .49596 L .06247 .49596 L p .949 .785 .329 r
F P
0 g
s
.06247 .49596 m .06251 .49013 L .06277 .49014 L p .949 .785 .329 r
F P
0 g
s
.06252 .50019 m .06261 .50096 L .06258 .50112 L p .95 .775 .318 r
F P
0 g
s
.06261 .50096 m .06252 .50019 L .06253 .50015 L p .95 .775 .318 r
F P
0 g
s
.71787 .87927 m .71858 .87896 L .71855 .87898 L p .004 0 0 r
F P
0 g
s
.71855 .87898 m .71774 .87937 L .71787 .87927 L p .004 0 0 r
F P
0 g
s
.7189 .87877 m .71952 .87831 L .71967 .87826 L p .002 0 0 r
F P
0 g
s
.71952 .87831 m .7189 .87877 L .71887 .87879 L p .003 0 0 r
F P
0 g
s
.71858 .12104 m .71787 .12073 L .71774 .12063 L p .004 .45 .866 r
F P
0 g
s
.71787 .12073 m .71858 .12104 L .71861 .12106 L p .005 .45 .866 r
F P
0 g
s
.71952 .12169 m .7189 .12123 L .71893 .12124 L p .002 .448 .865 r
F P
0 g
s
.71893 .12124 m .71967 .12174 L .71952 .12169 L p .002 .448 .865 r
F P
0 g
s
.06261 .49904 m .06252 .49981 L .06252 .49978 L p .95 .776 .32 r
F P
0 g
s
.06252 .49978 m .06258 .49888 L .06261 .49904 L p .95 .776 .32 r
F P
0 g
s
.71967 .12174 m .71893 .12124 L .71895 .12124 L p .001 .447 .864 r
F P
0 g
s
.71895 .12124 m .71978 .12177 L .71967 .12174 L p .001 .447 .864 r
F P
0 g
s
.71774 .87937 m .71855 .87898 L .71854 .879 L p .003 0 0 r
F P
0 g
s
.71854 .879 m .71766 .87945 L .71774 .87937 L p .003 0 0 r
F P
0 g
s
.71855 .12102 m .71774 .12063 L .71766 .12055 L p .003 .45 .865 r
F P
0 g
s
.71774 .12063 m .71855 .12102 L .71858 .12104 L p .004 .45 .866 r
F P
0 g
s
.06252 .50022 m .06258 .50112 L .06255 .50122 L p .95 .774 .317 r
F P
0 g
s
.06258 .50112 m .06252 .50022 L .06252 .50019 L p .95 .775 .318 r
F P
0 g
s
.06258 .49888 m .06252 .49978 L .06251 .49976 L p .95 .776 .319 r
F P
0 g
s
.06251 .49976 m .06255 .49878 L .06258 .49888 L p .95 .776 .319 r
F P
0 g
s
.71893 .87876 m .71967 .87826 L .71978 .87823 L p .001 0 0 r
F P
0 g
s
.71967 .87826 m .71893 .87876 L .7189 .87877 L p .002 0 0 r
F P
0 g
s
.72221 .1232 m .71985 .12177 L .71987 .12174 L p 0 .442 .862 r
F P
0 g
s
.71987 .12174 m .72227 .12311 L .72221 .1232 L p 0 .442 .862 r
F P
0 g
s
.7102 .11619 m .71526 .11906 L .71521 .11916 L p .011 .461 .87 r
F P
0 g
s
.71763 .12049 m .71521 .11916 L .71526 .11906 L p .004 .452 .866 r
F P
0 g
s
.71521 .11916 m .71763 .12049 L .71766 .12055 L p .008 .454 .868 r
F P
0 g
s
.71521 .88084 m .71763 .87951 L .71765 .87954 L p .004 0 0 r
F P
0 g
s
.71765 .87954 m .71526 .88094 L .71521 .88084 L p .004 0 0 r
F P
0 g
s
.72729 .87395 m .72227 .87689 L .72221 .8768 L p 0 0 0 r
F P
0 g
s
.71985 .87823 m .72221 .8768 L .72227 .87689 L p 0 0 0 r
F P
0 g
s
.72221 .8768 m .71985 .87823 L .71978 .87823 L p 0 0 0 r
F P
0 g
s
.06258 .49596 m .06252 .49872 L .06249 .49872 L p .949 .778 .321 r
F P
0 g
s
.06249 .49872 m .06247 .49596 L .06258 .49596 L p .949 .778 .321 r
F P
0 g
s
.06251 .50987 m .06247 .50404 L .06258 .50404 L p .949 .764 .304 r
F P
0 g
s
.06252 .50128 m .06258 .50404 L .06247 .50404 L p .949 .771 .312 r
F P
0 g
s
.06258 .50404 m .06252 .50128 L .06255 .50122 L p .95 .772 .315 r
F P
0 g
s
.06255 .49878 m .06251 .49976 L .0625 .49975 L p .949 .776 .318 r
F P
0 g
s
.0625 .49975 m .06252 .49872 L .06255 .49878 L p .949 .776 .318 r
F P
0 g
s
.06251 .50024 m .06255 .50122 L .06252 .50128 L p .949 .774 .316 r
F P
0 g
s
.06255 .50122 m .06251 .50024 L .06252 .50022 L p .95 .774 .317 r
F P
0 g
s
.71978 .12177 m .71895 .12124 L .71897 .12124 L p 0 .446 .864 r
F P
0 g
s
.71897 .12124 m .71985 .12177 L .71978 .12177 L p 0 .446 .864 r
F P
0 g
s
.71854 .121 m .71766 .12055 L .71763 .12049 L p .002 .449 .865 r
F P
0 g
s
.71766 .12055 m .71854 .121 L .71855 .12102 L p .003 .45 .865 r
F P
0 g
s
.71766 .87945 m .71854 .879 L .71853 .87901 L p .002 0 0 r
F P
0 g
s
.71853 .87901 m .71763 .87951 L .71766 .87945 L p .002 0 0 r
F P
0 g
s
.71895 .87876 m .71978 .87823 L .71985 .87823 L p 0 0 0 r
F P
0 g
s
.71978 .87823 m .71895 .87876 L .71893 .87876 L p .001 0 0 r
F P
0 g
s
.0625 .5 m .06253 .5 L .06253 .50005 L p .949 .775 .317 r
F P
0 g
s
.06253 .5 m .0625 .5 L .0625 .5 L p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06253 .49995 L .06253 .5 L p .949 .775 .317 r
F P
0 g
s
.71875 .12112 m .71873 .12114 L .71869 .12111 L p .001 .448 .864 r
F P
0 g
s
.71873 .12114 m .71875 .12112 L .71875 .12112 L p .001 .448 .864 r
F P
0 g
s
.71875 .12112 m .71878 .12117 L .71873 .12114 L p .001 .448 .864 r
F P
0 g
s
.71875 .87888 m .71873 .87886 L .71878 .87883 L p .001 0 0 r
F P
0 g
s
.71873 .87886 m .71875 .87888 L .71875 .87889 L p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71869 .87889 L .71873 .87886 L p .001 0 0 r
F P
0 g
s
.06253 .49995 m .0625 .5 L .0625 .49999 L p .949 .775 .317 r
F P
0 g
s
.0625 .49999 m .06253 .4999 L .06253 .49995 L p .949 .775 .317 r
F P
0 g
s
.71875 .12111 m .71869 .12111 L .71865 .12109 L p .001 .448 .864 r
F P
0 g
s
.71869 .12111 m .71875 .12111 L .71875 .12112 L p .001 .448 .864 r
F P
0 g
s
.71869 .87889 m .71875 .87889 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71865 .87891 L .71869 .87889 L p .001 0 0 r
F P
0 g
s
.71878 .12117 m .71875 .12112 L .71875 .12112 L p .001 .448 .864 r
F P
0 g
s
.71875 .12112 m .71883 .12119 L .71878 .12117 L p .001 .448 .864 r
F P
0 g
s
.0625 .5 m .06253 .50005 L .06253 .5001 L p .949 .775 .317 r
F P
0 g
s
.06253 .50005 m .0625 .5 L .0625 .5 L p .949 .775 .317 r
F P
0 g
s
.71875 .87888 m .71878 .87883 L .71883 .87881 L p .001 0 0 r
F P
0 g
s
.71878 .87883 m .71875 .87888 L .71875 .87888 L p .001 0 0 r
F P
0 g
s
.71874 .12111 m .71865 .12109 L .71861 .12106 L p .001 .448 .864 r
F P
0 g
s
.71865 .12109 m .71874 .12111 L .71875 .12111 L p .001 .448 .864 r
F P
0 g
s
.71883 .12119 m .71875 .12112 L .71876 .12112 L p .001 .447 .864 r
F P
0 g
s
.71876 .12112 m .71887 .12121 L .71883 .12119 L p .001 .447 .864 r
F P
0 g
s
.71875 .87888 m .71883 .87881 L .71887 .87879 L p .001 0 0 r
F P
0 g
s
.71883 .87881 m .71875 .87888 L .71875 .87888 L p .001 0 0 r
F P
0 g
s
.71865 .87891 m .71874 .87889 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71861 .87894 L .71865 .87891 L p .001 0 0 r
F P
0 g
s
.0625 .50001 m .06253 .5001 L .06253 .50015 L p .949 .775 .317 r
F P
0 g
s
.06253 .5001 m .0625 .50001 L .0625 .5 L p .949 .775 .317 r
F P
0 g
s
.06253 .4999 m .0625 .49999 L .0625 .49999 L p .949 .775 .317 r
F P
0 g
s
.0625 .49999 m .06253 .49985 L .06253 .4999 L p .949 .775 .317 r
F P
0 g
s
.71874 .12111 m .71861 .12106 L .71858 .12104 L p .001 .448 .864 r
F P
0 g
s
.71861 .12106 m .71874 .12111 L .71874 .12111 L p .001 .448 .864 r
F P
0 g
s
.0625 .50001 m .06253 .50015 L .06252 .50019 L p .949 .775 .317 r
F P
0 g
s
.06253 .50015 m .0625 .50001 L .0625 .50001 L p .949 .775 .317 r
F P
0 g
s
.71876 .87888 m .71887 .87879 L .7189 .87877 L p .001 0 0 r
F P
0 g
s
.71887 .87879 m .71876 .87888 L .71875 .87888 L p .001 0 0 r
F P
0 g
s
.06253 .49985 m .0625 .49999 L .0625 .49999 L p .949 .775 .317 r
F P
0 g
s
.0625 .49999 m .06252 .49981 L .06253 .49985 L p .949 .775 .317 r
F P
0 g
s
.71861 .87894 m .71874 .87889 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71858 .87896 L .71861 .87894 L p .001 0 0 r
F P
0 g
s
.71887 .12121 m .71876 .12112 L .71876 .12112 L p .001 .447 .864 r
F P
0 g
s
.71876 .12112 m .7189 .12123 L .71887 .12121 L p .001 .447 .864 r
F P
0 g
s
.06252 .49981 m .0625 .49999 L .0625 .49999 L p .949 .775 .317 r
F P
0 g
s
.0625 .49999 m .06252 .49978 L .06252 .49981 L p .949 .775 .317 r
F P
0 g
s
.71858 .87896 m .71874 .87889 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71855 .87898 L .71858 .87896 L p .001 0 0 r
F P
0 g
s
.7189 .12123 m .71876 .12112 L .71876 .12112 L p 0 .447 .864 r
F P
0 g
s
.71876 .12112 m .71893 .12124 L .7189 .12123 L p 0 .447 .864 r
F P
0 g
s
.0625 .50001 m .06252 .50019 L .06252 .50022 L p .949 .775 .316 r
F P
0 g
s
.06252 .50019 m .0625 .50001 L .0625 .50001 L p .949 .775 .317 r
F P
0 g
s
.71874 .12111 m .71858 .12104 L .71855 .12102 L p .001 .448 .864 r
F P
0 g
s
.71858 .12104 m .71874 .12111 L .71874 .12111 L p .001 .448 .864 r
F P
0 g
s
.71876 .87888 m .7189 .87877 L .71893 .87876 L p 0 0 0 r
F P
0 g
s
.7189 .87877 m .71876 .87888 L .71876 .87888 L p .001 0 0 r
F P
0 g
s
.71985 .12177 m .71897 .12124 L .71897 .12124 L p 0 .446 .863 r
F P
0 g
s
.71897 .12124 m .71987 .12174 L .71985 .12177 L p 0 .446 .863 r
F P
0 g
s
.71763 .87951 m .71853 .87901 L .71853 .87902 L p .001 0 0 r
F P
0 g
s
.71853 .87902 m .71765 .87954 L .71763 .87951 L p .001 0 0 r
F P
0 g
s
.06252 .49872 m .0625 .49975 L .0625 .49975 L p .949 .776 .318 r
F P
0 g
s
.0625 .49975 m .06249 .49872 L .06252 .49872 L p .949 .776 .318 r
F P
0 g
s
.71526 .11906 m .71765 .12046 L .71763 .12049 L p .004 .452 .866 r
F P
0 g
s
.71853 .12099 m .71763 .12049 L .71765 .12046 L p .001 .449 .865 r
F P
0 g
s
.71763 .12049 m .71853 .12099 L .71854 .121 L p .002 .449 .865 r
F P
0 g
s
.72227 .87689 m .71987 .87826 L .71985 .87823 L p 0 0 0 r
F P
0 g
s
.71897 .87876 m .71985 .87823 L .71987 .87826 L p 0 0 0 r
F P
0 g
s
.71985 .87823 m .71897 .87876 L .71895 .87876 L p 0 0 0 r
F P
0 g
s
.06247 .50404 m .06249 .50128 L .06252 .50128 L p .949 .771 .312 r
F P
0 g
s
.0625 .50025 m .06252 .50128 L .06249 .50128 L p .949 .774 .315 r
F P
0 g
s
.06252 .50128 m .0625 .50025 L .06251 .50024 L p .949 .774 .316 r
F P
0 g
s
.71893 .12124 m .71876 .12112 L .71876 .12112 L p 0 .447 .864 r
F P
0 g
s
.71876 .12112 m .71895 .12124 L .71893 .12124 L p 0 .447 .864 r
F P
0 g
s
.06252 .49978 m .0625 .49999 L .0625 .49998 L p .949 .775 .317 r
F P
0 g
s
.0625 .49998 m .06251 .49976 L .06252 .49978 L p .949 .775 .317 r
F P
0 g
s
.71874 .12111 m .71855 .12102 L .71854 .121 L p .001 .448 .864 r
F P
0 g
s
.71855 .12102 m .71874 .12111 L .71874 .12111 L p .001 .448 .864 r
F P
0 g
s
.71876 .87888 m .71893 .87876 L .71895 .87876 L p 0 0 0 r
F P
0 g
s
.71893 .87876 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71855 .87898 m .71874 .87889 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71854 .879 L .71855 .87898 L p .001 0 0 r
F P
0 g
s
.0625 .50001 m .06252 .50022 L .06251 .50024 L p .949 .775 .316 r
F P
0 g
s
.06252 .50022 m .0625 .50001 L .0625 .50001 L p .949 .775 .316 r
F P
0 g
s
.06251 .49976 m .0625 .49998 L .0625 .49998 L p .949 .775 .317 r
F P
0 g
s
.0625 .49998 m .0625 .49975 L .06251 .49976 L p .949 .775 .317 r
F P
0 g
s
.71876 .87888 m .71895 .87876 L .71897 .87876 L p 0 0 0 r
F P
0 g
s
.71895 .87876 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71874 .12111 m .71854 .121 L .71853 .12099 L p 0 .448 .864 r
F P
0 g
s
.71854 .121 m .71874 .12111 L .71874 .12111 L p .001 .448 .864 r
F P
0 g
s
.0625 .50002 m .06251 .50024 L .0625 .50025 L p .949 .774 .316 r
F P
0 g
s
.06251 .50024 m .0625 .50002 L .0625 .50001 L p .949 .775 .316 r
F P
0 g
s
.71854 .879 m .71874 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71874 .87889 m .71853 .87901 L .71854 .879 L p 0 0 0 r
F P
0 g
s
.71895 .12124 m .71876 .12112 L .71876 .12112 L p 0 .447 .864 r
F P
0 g
s
.71876 .12112 m .71897 .12124 L .71895 .12124 L p 0 .447 .864 r
F P
0 g
s
.71897 .12124 m .71876 .12112 L .71876 .12112 L p 0 .447 .864 r
F P
0 g
s
.71876 .12112 m .71897 .12124 L .71897 .12124 L p 0 .447 .864 r
F P
0 g
s
.0625 .49975 m .0625 .49998 L .0625 .49998 L p .949 .775 .316 r
F P
0 g
s
.0625 .49998 m .0625 .49975 L .0625 .49975 L p .949 .775 .316 r
F P
0 g
s
.71853 .87901 m .71874 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71874 .87889 m .71853 .87902 L .71853 .87901 L p 0 0 0 r
F P
0 g
s
.71987 .87826 m .71897 .87876 L .71897 .87876 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71897 .87876 L .71897 .87876 L p 0 0 0 r
F P
0 g
s
.71897 .87876 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.06249 .50128 m .0625 .50025 L .0625 .50025 L p .949 .774 .315 r
F P
0 g
s
.0625 .50002 m .0625 .50025 L .0625 .50025 L p .949 .774 .316 r
F P
0 g
s
.0625 .50025 m .0625 .50002 L .0625 .50002 L p .949 .774 .316 r
F P
0 g
s
.71765 .12046 m .71853 .12098 L .71853 .12099 L p .001 .449 .865 r
F P
0 g
s
.71874 .12111 m .71853 .12099 L .71853 .12098 L p 0 .447 .864 r
F P
0 g
s
.71853 .12099 m .71874 .12111 L .71874 .12111 L p 0 .448 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71875 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71875 .87888 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .5 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71875 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71875 .87888 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49999 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71897 .87876 m .71876 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71853 .12098 m .71874 .12111 L .71874 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .50025 m .0625 .50002 L .0625 .50002 L p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71874 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.45427 .9351 m
.5 .9375 L
s
.40904 .92794 m
.45427 .9351 L
s
.36481 .91609 m
.40904 .92794 L
s
.32205 .89968 m
.36481 .91609 L
s
.28125 .87889 m
.32205 .89968 L
s
.24284 .85394 m
.28125 .87889 L
s
.20726 .82513 m
.24284 .85394 L
s
.17487 .79274 m
.20726 .82513 L
s
.14606 .75716 m
.17487 .79274 L
s
.12111 .71875 m
.14606 .75716 L
s
.10032 .67795 m
.12111 .71875 L
s
.08391 .63519 m
.10032 .67795 L
s
.07206 .59096 m
.08391 .63519 L
s
.0649 .54573 m
.06639 .55517 L
s
.06639 .55517 m
.07206 .59096 L
s
.0625 .5 m
.06427 .53384 L
s
.06468 .54169 m
.0649 .54573 L
s
.0625 .5 m
.06427 .46616 L
s
.06468 .45831 m
.0649 .45427 L
s
.0649 .45427 m
.06639 .44483 L
s
.06639 .44483 m
.07206 .40904 L
s
.07206 .40904 m
.08391 .36481 L
s
.08391 .36481 m
.10032 .32205 L
s
.10032 .32205 m
.12111 .28125 L
s
.12111 .28125 m
.14606 .24284 L
s
.17487 .20726 m
.14606 .24284 L
s
.20726 .17487 m
.17487 .20726 L
s
.24284 .14606 m
.20726 .17487 L
s
.28125 .12111 m
.24284 .14606 L
s
.32205 .10032 m
.28125 .12111 L
s
.36481 .08391 m
.32205 .10032 L
s
.40904 .07206 m
.36481 .08391 L
s
.45427 .0649 m
.40904 .07206 L
s
.5 .0625 m
.45427 .0649 L
s
.54573 .9351 m
.5 .9375 L
s
.59096 .92794 m
.54573 .9351 L
s
.59096 .92794 m
.63519 .91609 L
s
.66902 .9031 m
.67795 .89968 L
s
.63519 .91609 m
.66902 .9031 L
s
.68855 .89427 m
.71875 .87889 L
s
.67795 .89968 m
.68155 .89784 L
s
.71875 .87889 m
.74717 .86043 L
s
.75376 .85615 m
.75716 .85394 L
s
.75716 .85394 m
.76458 .84793 L
s
.76458 .84793 m
.79274 .82513 L
s
.79274 .82513 m
.82513 .79274 L
s
.82513 .79274 m
.85394 .75716 L
s
.85394 .75716 m
.87889 .71875 L
s
.89968 .67795 m
.87889 .71875 L
s
.91609 .63519 m
.89968 .67795 L
s
.92794 .59096 m
.91609 .63519 L
s
.9351 .54573 m
.92794 .59096 L
s
.9375 .5 m
.9351 .54573 L
s
.9351 .45427 m
.9375 .5 L
s
.92794 .40904 m
.9351 .45427 L
s
.91609 .36481 m
.92794 .40904 L
s
.89968 .32205 m
.91609 .36481 L
s
.87889 .28125 m
.89968 .32205 L
s
.85394 .24284 m
.87889 .28125 L
s
.82513 .20726 m
.85394 .24284 L
s
.79274 .17487 m
.82513 .20726 L
s
.75716 .14606 m
.76458 .15207 L
s
.76458 .15207 m
.79274 .17487 L
s
.71875 .12111 m
.74717 .13957 L
s
.75376 .14385 m
.75716 .14606 L
s
.68855 .10573 m
.71875 .12111 L
s
.67795 .10032 m
.68155 .10216 L
s
.66902 .0969 m
.67795 .10032 L
s
.63519 .08391 m
.66902 .0969 L
s
.59096 .07206 m
.63519 .08391 L
s
.54573 .0649 m
.59096 .07206 L
s
.5 .0625 m
.54573 .0649 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
        ImageSize->{288, 288},
        ImageMargins->{{0, 0}, {0, 0}},
        ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ROooo`d0002:
oooo001ooooo2P0000goool:0000P?ooo`00NOooo`H0000Qoooo1P0007[oool007Coool50000;Ooo
o`D0001eoooo001aoooo0`0003Ooool30000L_ooo`00KOooo`@0000Zoooo4@0000;oool40000K_oo
o`00J_ooo`<0000Soooo2`0000QLd?08000000<m]_40000000001`0006_oool006Ooool300008ooo
o`<000000h;Yi00005c@l003G=3`2@0000F8fOl00`0006;2oF;2o@04H/;m3@0006Soool006Coool3
00009?ooo`800004P^WT1@0000n8fOlG0000I?ooo`00HOooo`<0000Toooo0`0000>2jN@200000Zk/
n0030000R=WoR=Wo00>8fOl900001I[An`80000<N<7n1`0000049Yo]000000000000HOooo`00G_oo
o`<0000Toooo0`0000>2jN@200001Zk/n0D0000@V]7k40000004EJkj00000000@Z[g1P0005koool0
05_oool300009?ooo`<00003P^WT0`0000F^k?P200000[SKlP030000V]7kV]7k00^JdO/400000j76
l`030000PkciPkci00Z3_?T00`0006:^n@00000:0000GOooo`00FOooo`80000Uoooo0P0000>2jN@3
00001Zk/n0800005^=_b00<0002JdO^JdO/01Y[An`@00008XLKc00<00023_?V3_?T02X>ln@030000
HZkiHZki00=R[_T5000000@XU^l000000000001Joooo001Goooo0P0002Coool300000X;Yi0<00006
[^ch0`0000Rhfo80100009[Ani[Ani[An`@0000=XLKc00<00023_?V3_?T018>lnAH0001Hoooo001E
oooo0P0002Coool200000h;Yi0800007[^ch0P0000bhfo8300004Z76l`H00008R;Kd0P0000EYZoL9
0000E_ooo`00Doooo`80000Toooo0`000004P^WT0000000000001jk/n080000;^=_b0P0000:hbnP0
0`000:76lj76l`0=XLKc0`0000:R_>`00`0008Rfm8Rfm00;R;Kd400005Goool0057oool200009Ooo
o`030000ZOO8ZOO800800007[^ch0`0000^hfo8200001KS;j080000:XLKc0`0000JR_>`200001hRf
m0@00002RJo^0P0000E]Yo@00`0004fKl`0000070000D_ooo`00D?ooo`030000oooooooo02Coool0
1P000:Wgb:Wgb0000=3fi`0000F^k?P200003;SKlP800009^<_X00<0002Qa_>Qa_<01:76l`<0000;
X[c/00<00028]_B8]_@0100000R9[nh0100006fWm6fWm6fWm0`0001Aoooo001>oooo0P0002Goool2
000000>YmlP0000000000m3fi`030000[^ch[^ch0080000<^=_b0P0000bhbnP00`000:76lj76l`03
00003j:lk080000=RJo^0`0000A]X_42000000A>V?800000000aR^d40000Coooo`00COooo`030000
oooooooo02Coool010000:Wgb:Wgb00000K@m^L200003;SKlP80000?^<_X0P0000nR_>`200000Z2b
i@800009RJo^0P0000:8YnX200001FfRl@800003CIC`1@0004koool004_oool200009_ooo`040000
ZOO8ZOO800001]3fi`040000dMoS000000002KSKlP80000?^<_X0P000003]KkP0000000000bR_>`2
00001Z2bi@800005RJo^0P0000J8YnX2000000=]X_40000000000V^LkP8000000dfDl00004Z@kP05
0000C?ooo`00BOooo`80000Voooo0P0000:YmlP00`000=3fim3fi`03d?KW0P0000CAgn<00`000;SK
l[SKlP04^=_b0P0000nhbnP200001KFnh0030000X[c/X[c/00NR_>`200002Z2bi@8000000hV_kP00
0000000:R:OZ00<0001[W>i[W>h016^LkP050000BY3^BY3^0000A8_/00D0001:oooo0018oooo00<0
003oooooool09Oooo`030000ZOO8ZOO800800005d?KW00<0003Agn?Agn<01M7Oh`800002^=_b0P00
00nhbnP200002;Fnh0030000X[c/X[c/00BR_>`200003Z2bi@030000R:OZR:OZ00V8YnX0100008BP
iP00000000=[W>h00`0006JFj`000002000000E4Rn`000000000000;Kml00P0004Woool004Koool2
00009oooo`040000ZOO8ZOO800001]3fi`030000dMoSdMoS00SAgn<200003kS;j080000;]KkP0P00
00:R_>`200003Z2bi@8000000ibYg`0000000007R:OZ0P0000B4X>H2000000=[W>h0001VU^/00VJF
j`8000000dB;k3b5j@0000040000B?ooo`00AOooo`030000oooooooo02Goool200000ZWgb0030000
d?KWd?KW00C@m^L00`000=7Ohm7Oh`08dMoS00<0003:c=/000003[S;j0030000]KkP]KkP00fe_^02
00003j2bi@030000W:WOW:WO00>LZMl2000018RWjP030000Q:3VQ:3V00J4X>H00`0006JFjfJFj`02
IYK[00<0001OT>P000000P000003<GkW0000000000<00016oooo0014oooo00<0003oooooool09Ooo
o`030000ZOO8ZOO800800005d?KW0P0000[Agn<01@000<[<fl[<fl[<f`00000;^<_X0P0000je_^02
000000>`/]X0000000003:2bi@800008W:WO0P000003R:OZ0000Q:3V00N4X>H0100007jIh`000000
009VU^/00`0005n@j5n@j003000000<aO^L0000000000`0004Goool004?oool00`000?ooooooo`0U
oooo00@0002YmlRYmlP00006d?KW00<0003Agn?Agn<02M7Oh`030000b/cKb/cK00?:c=/200001kS;
j080000?]KkP00<0002`/]Z`/]X00k2bfP800008X;;U0P0000bLZMl00`0008BPiXBPiP07Q:3V00@0
001nVN=nVN=nVN<300000en@j0030000E8SV000000<000000a=/gP1Qe`000014oooo0012oooo00<0
003oooooool09?ooo`800002ZOO800<0003@m^O@m^L01=3fi`030000dMoSdMoS00SAgn<200002<[<
f`030000^<_X^<_X00:hbnP200003kFnh0800008/;;J0P0000FP/^D00`0009bYgibYg`0;W:WO00@0
002GXM/000000006Q:3V00<0001nVN=nVN<017jIh`050000Gi3XGi3XGi3X0000009DR>H4000000<C
K=h0HML00000@oooo`00@?ooo`80000Voooo00D0002YmlRYmlRYmlP000001M3fi`80000:dMoS00<0
003:c=_:c=/02L[<f`040000^<_X000000004;Fnh0030000/;;J/;;J00Z`/]X2000000>P/^D00000
00003IbYg`030000Uj7KUj7K00:GXM/00`0008BPiXBPiP03Q:3V00<0001nVN=nVN<017jIh`<00000
1En@j00005B8iUB8iP000002AgoS1@0004;oool003ooool00`000?ooooooo`0Uoooo00<0002YmlRY
mlP00P0000G@m^L00`000=7Ohm7Oh`09dMoS00<0003:c=_:c=/02l[<f`030000]KkP]KkP00je_^02
00003k2bfP030000W:WOW:WO00bLZMl00`0009NQfiNQf`04Uj7K00D00024X>J4X>J4X>H000001gjI
h`030000MY7PMY7P00<00002E8SV00H00017On<0000eM>00000NImX30000@?ooo`00?_ooo`030000
oooooooo02Goool2000000>YmlP0003@m^L01M3fi`030000dMoSdMoS00WAgn<00`000<[<fl[<f`0;
b/cK00@00033_M@00000000=]KkP00<0002`/]Z`/]X03[2bfP040000ZjSD000000002ibYg`030000
Uj7KUj7K00JGXM/2000000>4X>H0001nVN<01WjIh`030000MY7PMY7P009fTN0200000UB8iP060000
AgoS0000=GCP00007VOJ0`0003ooool003goool00`000?ooooooo`0Voooo00<00038lIX000001]3f
i`030000dMoSdMoS00WAgn<00`000<[<fl[<f`0;b/cK00<00033_MC3_M@00/>me0030000]KkP]KkP
00Ve_^000`000;2bf[2bfP0>/;;J00<0002[Z=B[Z=@00Z^Xe0030000W:WOW:WO00NLZMl00`0009NQ
fiNQf`09Uj7K0P0000MnVN<00`0007JAh7JAh002MY7P00<0001[R=d000000P000097On<0100003Ed
h00001iWfP<0000noooo000loooo00<0003oooooool09_ooo`050000b?6Jb?6JjoC;000000?@m^L2
00002m7Oh`030000b/cKb/cK00_:c=/00`000<>me<>me004`kgD0P0000Ne_^0200004;2bfP030000
ZjSDZjSD00B[Z=@200001YbYg`030000Uj7KUj7K00VGXM/00`00092Hei2He`02000017jIh`030000
MY7PMY7P00=fTN00100006^8gF^8gF^8g@<0000014MohcEdh00001iWfP8000000`11`P000?ooo`0l
oooo000koooo00<0003oooooool09_ooo`040000b?6Jb?6J00000^_db`030000d?KW000000cAgn<0
0`000<[<fl[<f`0;b/cK00<00033_MC3_M@01l>me0030000]KkP]KkP00>e_^000`000;2bf[2bfP0?
/;;J00<0002[Z=B[Z=@01j^Xe0030000W:WOW:WO00:LZMl00`0009NQfiNQf`0:Uj7K00<0002@V=N@
V=L00Y2He`800002OYWS00<0001fTN1fTN000gJAh0030000JhSMJhSM009[R=d01`0005amf`000000
03Edh00001iWfP02000000<0@L80003oool0>oooo`00>_ooo`030000oooooooo02Ooool00`000<Sa
VP000004joC;00<0003Agn?Agn<02]7Oh`030000b/cKb/cK00_:c=/00`000<>me<>me009`kgD0P00
0003]KkP00000000016`/]X00`000:^Xe:^Xe009ZjSD0P000003W:WO0000Uj7K00^GXM/00`00092H
ei2He`05T9SG0`0000EfTN000`0006^8gF^8g@03JhSM00<0001LOM]LOM/00`0000057VOJ00000000
0472000003_oool003Woool00`000?ooooooo`0Woooo00<00038lIX000001>_db`040000hmc?0000
00002=7Oh`80000=b/cK00<00033_MC3_M@03<>me0030000/;;J/;;J00n`/]X200003Z^Xe0030000
Uj7KUj7K00^GXM/00`00092Hei2He`07T9SG00<0001fTN1fTN0017JAh0030000JhSMJhSM009[R=d0
1@0005amfeamf`0004Q`e`05000000<0@L80003oool0>Oooo`00>?ooo`030000oooooooo02Ooool0
0`000<SaV/SaVP05joC;00D0003Sg<oSg<oSg<l000001]7Oh`030000b/cKb/cK00c:c=/00`000<>m
e<>me00<`kgD00@0002l/Lh00000000>/;;J00<0002[Z=B[Z=@03J^Xe0040000YIo@000000002YNQ
f`030000T9SGT9SG00R@V=L3000017JAh0030000JhSMJhSM009[R=d01@0005amfeamfeamf`000002
B73G1000000302B_0000oooo03Soool003Ooool00`000?ooooooo`0Xoooo00<00038lIX000001>_d
b`030000hmc?hmc?00?Sg<l00`000=7Ohm7Oh`02dMoS00<0003:c=_:c=/02l[<f`80000>`kgD00<0
002l/Ljl/Lh00[bacP030000/;;J/;;J00Z`/]X00`000:^Xe:^Xe00=ZjSD00<0002UWm2UWm000ZFO
d0800007Uj7K00<0002@V=N@V=L0292He`040000R8oDR8oDR8oD0P00009fTN000`0006^8gF^8g@02
JhSM00D0001LOM]LOM]LOM/000000TQ`e`030000:eoA:eoA00@0000hoooo000foooo00<0003ooooo
ool0:?ooo`030000b?6J000000C[m</00`000>?Lcn?Lc`05hmc?0P000003dMoS0000b/cK00c:c=/0
0`000<>me<>me00=`kgD00<0002l/Ljl/Lh01;bacP800009/;;J00<0002[Z=B[Z=@03Z^Xe0030000
YIo@YIo@00BUWm000`0009NQfiNQf`04Uj7K00<0002@V=N@V=L0292He`030000R8oDR8oD00>8Sm@3
00001F^8g@050000G7gKG7gKG7gK00000098L=L01@0002]Od@000000000T[`020000=oooo`00=Ooo
o`030000oooooooo02Soool00`000<SaVP000005joC;00<0003Sg<oSg<l01n?Lc`030000b/cKb/cK
00_:c=/00`000<>me<>me00=`kgD00<0002l/Ljl/Lh01kbacP800006/;;J00<0002[Z=B[Z=@03Z^X
e0030000YIo@YIo@00JUWm0200000iNQf`030000T9SGT9SG00V@V=L00`0008R?e8R?e005R8oD0P00
00A[R=d01@0005amfeamfeamf`000002B73G00<0000[Gm4[Gm400P00000302B_0000000003Koool0
03Coool00`000?ooooooo`0Yoooo0P0000G[m</00`000>?Lcn?Lc`07hmc?00@0003Hb</00000000:
b/cK00<00033_MC3_M@03/>me0030000_;7>_;7>00Vl/Lh00`000;2bf[2bfP02/;;J00<0002[Z=B[
Z=@03Z^Xe0030000YIo@YIo@00VUWm02000000>GXM/0002@V=L02I2He`030000R8oDR8oD00J8Sm@0
100007f6d@000000009[R=d00`0005amfeamf`02G7gK00@00018L=M8L=L00002:eoA0P00000302B_
0000000003Goool003?oool00`000?ooooooo`0Yoooo00<00038lIX000000^_db`H00007hmc?00D0
003Hb<_Hb<_Hb</000002<[<f`030000`kgD`kgD00k3_M@00`000;bac[bacP0;_;7>0P000003/;;J
0000ZjSD00n[Z=@00`000:FOd:FOd00<YIo@00<0002@V=N@V=L02I2He`030000R8oDR8oD00J8Sm@0
100007f6dGf6dGf6d@8000000f^8g@0005amf`02G7gK00@00018L=M8L=L00002:eoA00H00003A/H0
0000003oool0000doooo000boooo00<0003oooooool08_ooo`d00004A/CU00<00006S]X000000`00
00;Sg<l00`000=S8bmS8b`03f<S;00<0003:c=_:c=/01<[<f`030000`kgD`kgD00k3_M@00`000;ba
c[bacP0>_;7>00<0002[Z=B[Z=@03j^Xe0030000YIo@YIo@00^UWm00100009jFc000000000V@V=L0
0`0008R?e8R?e006R8oD00<0001mQ]5mQ]400gf6d@<00003G7gK00@00018L=M8L=L00002:eoA0P00
000402B_0000oooo0000<oooo`00<Oooo`030000oooooooo01[oool9000000=6a>D0000000004P00
0086S]X400001MS8b`800003b/cK00<00033_MC3_M@03/>me0030000_;7>_;7>00jl/Lh010000;JV
b@00000000j[Z=@00`000:FOd:FOd00<YIo@00@0002NU/bNU/bNU/`200001Y2He`030000R8oDR8oD
00N8Sm@00`0007f6dGf6d@04OHKA00H0001^N/h00000001LOM/00003B73G00<0000[Gm4[Gm400P00
000402B_0000oooo0000<_ooo`00<?ooo`030000oooooooo01Woool200000X?YgPP00005T]Kn0P00
0003joC;T]KnT]Kn00NBe_h00`0006NdnfNdn`0400000PJ>fP<00004f<S;00<0003:c=/000004<>m
e0030000_;7>_;7>00jl/Lh00`000;JVbKJVb@02]ZK90P0000^[Z=@00`000:FOd:FOd00<YIo@00<0
002NU/bNU/`019jFc0030000T9SGT9SG00>@V=L00`0008R?e8R?e007R8oD00<0001mQ]5mQ]4017f6
d@040000KW[>KW[>KW[>0P0000=8L=L02P0002]OdB]Od@0000=6aP00000T[`000?ooo`00037oool0
02ooool00`000?ooooooo`0Hoooo0P0000:3jMh00`000;O]mP00000;T]Kn00@00038lIX0003[m</9
T]Kn00<0001W]?]W]?/016Ndn`@000000`J>fP0000000002000000?Hb</00033_M@03l>me0030000
_;7>_;7>00nl/Lh00`000;JVbKJVb@04]ZK90P0000R[Z=@00`000:FOd:FOd00=YIo@00<0002NU/bN
U/`01IjFc0800003T9SG00<00028SmB8Sm@01hR?e0030000OHKAOHKA00AmQ]400`0006ijcVijcP03
KW[>0P000098L=L01@0002]OdB]Od@0000=6aP0200000_ooo`030000oooooooo02koool002koool0
0`000?ooooooo`0Foooo0`000003PnWN0000000000>gkOH00`0009;FoY;FoP09T]Kn0P0000?[m</8
T]Kn00<0001W]?]W]?/026Ndn`@000000`J>fP000000000200003L>me0030000_;7>_;7>00nl/Lh0
0`000;JVbKJVb@07]ZK900<0002[Z=B[Z=@01:^Xe0030000YIo@YIo@00fUWm000`0009jFc9jFc008
WYK<0`0000V8Sm@00`0007f6dGf6d@05OHKA00<0001^N/i^N/h00fijcP030000FF_:000000800003
:eoA00@3A/H000009:l00002oooo00<0003oooooool0;Oooo`00;_ooo`030000oooooooo01Coool2
000000B3jMh0000000000006]ngf00<0002Be_jBe_h01i;FoP030000b?6J000000?[m</8T]Kn00<0
001W]?]W]?/036Ndn`<000021XkJ0P0000[3_M@00`000;bac[bacP0?_;7>00<0002fY/VfY/T02KJV
b@800004ZjSD00<0002UWm2UWm003:FOd0030000WYK<WYK<00^NU/`2000028R?e0030000OHKAOHKA
00EmQ]400`0006ijcVijcP03KW[>00@0001IJlYIJlYIJlX5000000H3A/H000009:l0003oool0000_
oooo000]oooo00<0003oooooool04oooo`8000000h?YgP0000000009]ngf00<0002Be_jBe_h019;F
oP05ooooT]Kn0000b?6J000000G[m</:000046Ndn`D00008`kgD00<0002l/Ljl/Lh03[bacP030000
]ZK9]ZK900bfY/T2000000>[Z=@0002UWm003ZFOd0030000WYK<WYK<00^NU/`0100009F=b0000000
00J8Sm@00`0007f6dGf6d@05OHKA00<0001^N/i^N/h016ijcP050000FF_:FF_:FF_:0000008iEL<5
00000_ooo`030000oooooooo02coool002coool00`000?ooooooo`0Boooo0P000003PnWN00000000
00^gkOH;00001N_db`030000hmc?ZLS`00FYb?000`0008bakhbak`0400003VNdn`D00005`kgD00<0
002l/Ljl/Lh03kbacP030000]ZK9]ZK900jfY/T00`000:FOd:FOd00=YIo@00<0002NU/bNU/`02ijF
c0030000UHg8UHg800:ESLP2000018R?e0030000OHKAOHKA00EmQ]400`0006ijcVijcP04KW[>00<0
001IJlYIJlX00UU[bP080000>EG3>EG300001c>d0000002A00000_ooo`030000oooooooo02_oool0
02_oool00`000?ooooooo`0@oooo0`000003PnWN0000000000ZgkOH2000000?3f^/0002Yb?001ZW8
l0030000b?6J000000G[m</00`000>?Lcn?Lc`05ZLS`00<0002</Nn</Nl018bak`D00009IkCk00<0
000gQn`gQn`00`0000?3_M@00`000;bac[bacP0?_;7>00<0002fY/VfY/T03[JVb@040000[ic40000
00003JFOd0030000WYK<WYK<00^NU/`00`0009F=b9F=b004UHg80P0000:8Sm@00`0007f6dGf6d@06
OHKA00<0001^N/i^N/h00fijcP030000FF_:FF_:009IJlX01P0003UE`cUE`cUE``0000Lc]0800003
oooo00<0003oooooool0:_ooo`00:_ooo`030000oooooooo00ooool2000000B3jMh0000000000009
]ngf0`0000?3f^/00`000:W8l:W8l005ZLS`0P0000G[m</010000>?Lcn?Lcn?Lc`FYb?000`0008ba
khbak`09S;7_100000IW]?/0100003N7k3N7k3N7k0@0000A_;7>00<0002fY/VfY/T03kJVb@040000
[ic4[ic4[ic40P0000ZUWm000`0009jFc9jFc00<WYK<00<0002ESLRESLP01YF=b0<00008OHKA00<0
001^N/i^N/h00fijcP030000FF_:FF_:009IJlX02@0003UE`cUE`cUE``0000Lc]0000000T@000003
oooo00<0003oooooool0:Oooo`00:Oooo`030000oooooooo00koool2000000>3jMh0000000002[O]
mP800006`m[[00<0002Yb?2Yb?001:W8l0030000fMMP000000800002joC;00<0003Sg<oSg<l00n?L
c`BYb?000`0008bakhbak`0=S;7_1000009W]?/00`0003N7k3N7k002=hO/0`00012l/Lh00`000;JV
bKJVb@0?]ZK900<0002_W<B_W<@01:nLa0800007YIo@00<0002NU/bNU/`039jFc0030000UHg8UHg8
00VESLP00`0007f6dGf6d@06OHKA00<0001^N/i^N/h00fijcP030000FF_:FF_:00=IJlX0100003UE
`cUE``000087<k@200001?ooo`030000oooooooo02Soool002Soool00`000?ooooooo`0=oooo0P00
0003PnWN0000000000VgkOH300002<?Jj`030000ZLS`ZLS`00BYb?0200000o_WYP030000joC;0000
00GSg<l5ZLS`00<0002</Nn</Nl048bak`<00006=hO/0`0000fl/Lh00`000;JVbKJVb@0?]ZK900<0
002_W<B_W<@01jnLa0030000YIo@YIo@00BUWm000`0009jFc9jFc00<WYK<00<0002ESLRESLP02IF=
b0<00006OHKA00<0001^N/i^N/h016ijcP030000FF_:FF_:009IJlX02@0003UE`cUE`cUE``0000Lc
]0000000T@000004oooo00<0003oooooool09oooo`00:?ooo`030000oooooooo00coool010000;;j
b000000000VgkOH200003<?Jj`030000ZLS`ZLS`00>Yb?0200001?_WYP030000hmc?hmc?00GSg<l4
ZLS`00<0002</Nn</Nl04Xbak`<00005=hO/100000^l/Lh00`000;JVbKJVb@0?]ZK900<0002_W<B_
W<@02:nLa0800003YIo@00<0002NU/bNU/`039jFc0030000UHg8UHg800ZESLP00`0008^2a8^2a002
000017f6d@030000KW[>KW[>00A^N/h00`0005U[bUU[bP02FF_:00D0000iEL<iEL<iEL<000000PLc
]0800004oooo00<0003oooooool09oooo`009oooo`030000oooooooo00_oool2000000>bn/P00000
00002;O]mP80000>`m[[00<0002Yb?2Yb?000jW8l0800004nnNV0`0000GSg<l4ZLS`00<0002</Nn<
/Nl04Xbak`030000JICXJICX00800005=hO/00<00000DKl000002KbacP030000]ZK9]ZK900nfY/T0
0`000:nLa:nLa00;[ic40P000003YIo@0000WYK<00fNU/`00`0009F=b9F=b009UHg800<0002;P/B;
P/@00h^2a0800002OHKA00<0001^N/i^N/h016ijcP030000FF_:FF_:009IJlX01@0003UE`cUE`cUE
``0000021c>d00<00000094000001?ooo`030000oooooooo02Koool002Koool00`000?ooooooo`0;
oooo00@0002bn/Rbn/P00002e?WR00<0002gkOJgkOH00[O]mP<0000@`m[[00<0002Yb?2Yb?000ZW8
l0030000fMMP000000?kijH01@000?3D]O3D]O3D]@000005hmc?1P0001:</Nl00`0006VDj6VDj002
JICX00<0000gQn`gQn`013N7k0<00006_;7>00<0002fY/VfY/T03kJVb@030000[ic4[ic400j_W<@0
0`0009jFc9jFc00=WYK<00<0002ESLRESLP02IF=b0030000Rh;4Rh;400F;P/@300001VijcP030000
FF_:FF_:00=IJlX01@0003UE`cUE`cUE``0000021c>d0P0000Goool00`000?ooooooo`0Uoooo000V
oooo00<0003oooooool02_ooo`030000/_[8000000CDnN800`000;O]m[O]mP0200004l?Jj`L00004
nnNV00<0003`e;G`e;D00_3D]@060000hmc?hmc?hmc?0000f<S;0[6kh@030000VjWQVjWQ00D0000=
S;7_00<0001YU>QYU>P00fVDj0800005=hO/00<00000DKl000001;bacP030000]ZK9]ZK9012fY/T0
0`000:nLa:nLa00=[ic400@0002XTl000000000<WYK<00<0002ESLRESLP02YF=b0030000Rh;4Rh;4
00N;P/@200001FijcP030000FF_:FF_:00=IJlX01@0003UE`cUE`cUE``0000021c>d0P0000Goool0
0`000?ooooooo`0Uoooo000Uoooo00<0003oooooool02_ooo`030000/_[8000000KDnN8200004L?J
j`<000000lG:gP000;6kh@03/K_Q0P0000CkijH00`000?3D]O3D]@03l=Be0P000003hmc?0000f<S;
00:a^n400`0009^YhI^Yh@05VjWQ1P0000N</Nl00`0006VDj6VDj005JICX0P0000DgQn`200000kba
cP030000]ZK9]ZK900nfY/T00`000:nLa:nLa00>[ic400@0002XTl2XTl2XTl0200002YjFc0030000
UHg8UHg800ZESLP00`0008^2a8^2a007Rh;400<0001lMKl000000P0000=^N/h00`0005U[bUU[bP02
FF_:00<0000iEL<iEL<00SUE``0500001c>d0000002A000000Goool00`000?ooooooo`0Toooo000U
oooo00<0003oooooool02Oooo`030000/_[8000000KDnN8200004<?Jj`800004aL[N00<0002a^n6a
^n400[6kh@800004nnNV00<0003`e;G`e;D01O3D]@060000f<S;f<S;f<S;/K_Q00003I^Yh@D00002
S;7_00<0001YU>QYU>P01fVDj0030000=hO/=hO/008gQn`3000000>l/Lh0002fY/T04;JVb@030000
[ic4[ic400j_W<@00`000:RC`:RC`004Z9?00P0000RNU/`00`0009F=b9F=b009UHg800<0002;P/B;
P/@028^2a0030000O7FoO7Fo009lMKl2000000=^N/h0001IJlX015U[bP050000>EG3>EG3>EG30000
0087<k@200001Oooo`030000oooooooo02Coool002Coool00`000?ooooooo`08oooo0P000003/_[8
0000e?WR00CDnN8010000=WWgmWWg`0000g3f^/300001/G:gP070000/K_Q/K_Q/K_Q0000fMMP0000
00?kijH00`000?3D]O3D]@06l=Be0P0000;Hb</00k6kh@0009^Yh@0AVjWQ0`0000YYU>P200000SN7
k00400000e??000000004KJVb@030000[ic4[ic400n_W<@00`000:RC`:RC`006Z9?00P0000FNU/`0
0`0009F=b9F=b00:UHg800<0002;P/B;P/@028^2a0030000O7FoO7Fo00AlMKl3000015U[bP050000
>EG3>EG3>EG300000087<k@00`000000T@000005oooo00<0003oooooool08oooo`008oooo`030000
oooooooo00Soool010000;;jb000000000GDnN801@000=WWgmWWgmWWg`00000:`m[[0`0000W5b]h0
10000;6khK6khK6kh@800004nnNV00<0003`e;G`e;D01O3D]@030000h/:hh/:h008000000mS8b`00
09^Yh@0CVjWQ0`0000YYU>P00`0003N7k00000020e??0`0000nfY/T00`000:nLa:nLa00>[ic400<0
002XTl2XTl002JRC`0800003WYK<00<0002ESLRESLP02YF=b0030000Rh;4Rh;400R;P/@00`0007ae
_gae_`05O7Fo00@0001XHkX000000002FF_:00<0000iEL<iEL<00SUE``0300001c>d1c>d00800006
oooo00<0003oooooool08_ooo`008oooo`030000oooooooo00Ooool00`000;;jb0000005e?WR0P00
00GIiml00`000<?Jjl?Jj`04`m[[0`0000c5b]h010000;6khK6khK6kh@800004nnNV00<0003`e;G`
e;D01O3D]@030000h/:hh/:h00;R`[P2000059^Yh@030000P9CMP9CM0080000:JICX00@00003Dll3
Dll3Dll400003;JVb@030000[ic4[ic400n_W<@00`000:RC`:RC`00;Z9?00`0000fESLP00`0008^2
a8^2a007Rh;400<0001lMKmlMKl01Wae_`040000J6>jJ6>jJ6>j0P000003FF_:>EG3>EG3008iEL<0
1P0000Lc]0Lc]0000000T@0000Goool00`000?ooooooo`0Roooo000Roooo00<0003oooooool01ooo
o`030000/_[8000000GDnN800`000=WWgmWWg`05fNOO00<00033f^_3f^/00/?Jj`80000@aL[N00D0
002a^n40003Ief0000000o_WYP030000l=Bel=Be00K`e;D00`000>;2^>;2^003h/:h00<0002KZN6K
ZN404Y^Yh@030000P9CMP9CM00:0U=d2000026VDj08000030e??0P000003_Z>m0000]ZK900VfY/T0
0`000:nLa:nLa00?[ic400<0002XTl2XTl003ZRC`0030000UHg8UHg800^ESLP00`0008^2a8^2a007
Rh;400<0001lMKmlMKl01Wae_`030000J6>jJ6>j00=XHkX300000SUE``0600001c>d1c>d1c>d002A
00001_ooo`030000oooooooo027oool002;oool00`000?ooooooo`06oooo00<0002bn/P000001=Ci
hP800008fNOO00<00033f^/000000P0001;5b]h010000;6kh@00000000CkijH00`000?3D]O3D]@05
l=Be00<0003R`[SR`[P01N;2^1BKZN400`00082DgH2Dg@04P9CM0P0000IYU>P00`0003m^f0000003
0e??0P000003_Z>m0000000000RfY/T00`000:nLa:nLa00?[ic400<0002XTl2XTl003ZRC`0<0000:
UHg800<0002;P/B;P/@028^2a0030000O7FoO7Fo00IlMKl00`0006QS^VQS^P04J6>j00D00017BK00
0000000iEL<00`Lc]0030000002A000000Goool00`000?ooooooo`0Qoooo000Qoooo00<0003ooooo
ool01Oooo`8000000k;jb0000=CihP03e?WR00<0003IimoIiml02=WWg`80000EaL[N00@0002a^n40
00000004nnNV00<0003`e;G`e;D01O3D]@030000h/:hh/:h00KR`[PCVjWQ00<00020U=f0U=d01X2D
g@800004JICX00@0000oK]PoK]P000030e??0P0000:nXkd00`000;JVbKJVb@04]ZK900<0002_W<B_
W<@03jnLa0030000Z9?0Z9?000jXTl00100009n9_9n9_9n9_0800008UHg800<0002;P/B;P/@028^2
a0030000O7FoO7Fo00IlMKl00`0006QS^VQS^P04J6>j00@00017BK17BK17BK04000000<7<k@00940
00001_ooo`030000oooooooo023oool0027oool00`000?ooooooo`04oooo00@0002bn/P000000004
e?WR00<0003IimoIiml01mWWg`<0000FaL[N00@0002a^n7Ief000004nnNV00<0003`e;G`e;D01O3D
]@030000h/:hh/:h00KR`[PCVjWQ00<00020U=f0U=d0282Dg@800002JICX00D0000oK]PoK]PoK]P0
00000`=Cc`800002_Z>m0P0000>fY/T00`000:nLa:nLa00@[ic400<0002XTl2XTl003ZRC`0030000
WhVlWhVl00>ORK`200001YF=b0030000Rh;4Rh;400R;P/@00`0007ae_gae_`06O7Fo00<0001XHkYX
HkX016QS^P030000AdV`AdV`0097BK000`0000dLV`dLV`0300001_ooo`030000oooooooo023oool0
023oool00`000?ooooooo`04oooo00<0002bn/P000001=CihP800009fNOO00@0003He]KHe]H0000F
aL[N0P000003fMMP0000nnNV00;kijH00`000?3D]O3D]@05l=Be00<0003R`[SR`[P02>;2^0@0000>
VjWQ00<00020U=f0U=d02X2Dg@030000JICX000000@oK]P200000P=Cc`800003_Z>m0P000003]ZK9
0000[ic4012_W<@00`000:RC`:RC`00>Z9?000<0002ORKbORK`01Yn9_0030000UHg8UHg800>ESLP0
0`0008^2a8^2a008Rh;400<0001lMKmlMKl01Wae_`030000J6>jJ6>j00AXHkX00`0004M9/4M9/002
AdV`00@0000=79/=79/=79/200001oooo`030000oooooooo01ooool0023oool00`000?ooooooo`03
oooo00<0003BnJ`000001=CihP030000fNOOfNOO00OIiml200000mSFeP030000aL[NaL[N01?5b]h4
00001?_WYP030000l=Bel=Be00G`e;D00`000>;2^>;2^008h/:h00@0002RX]FRX]FRX]D6000029^Y
h@030000P9CMP9CM00b0U=d00`0003m^f3m^f004?fkH00<00003Dll3Dll00P0000BnXkd00`000:nL
a:nLa00?[ic400<0002XTl2XTl003jRC`0030000WhVlWhVl00NORK`200000YF=b0030000Rh;4Rh;4
00V;P/@00`0007ae_gae_`06O7Fo00<0001XHkYXHkX016QS^P030000AdV`AdV`0097BK001`0000dL
V`dLV`dLV`000000I@000006oooo00<0003oooooool07oooo`007oooo`030000oooooooo00Coool0
0`000=;i[0000003e?WR00<0003IimoIiml01mWWg`030000f=KFf=KF00?He]H00`000<G:g/G:gP0?
aL[N10000004aKgC0000fMMP00001?_WYP030000l=Bel=Be00G`e;D00`000>;2^>;2^007h/:h00<0
003G];JRX]D02::Re@H00002VjWQ00<00020U=f0U=d0382Dg@800006?fkH00<00003Dll3Dll00P00
00:nXkd010000;NI^@00000000n_W<@00`000:RC`:RC`00>Z9?000<0002ORKbORK`02Yn9_0<0000;
Rh;400<0001lMKmlMKl01Wae_`030000J6>jJ6>j00EXHkX00`0004M9/4M9/002AdV`00H0000=79/=
79/0000006D00007oooo00<0003oooooool07_ooo`007oooo`030000oooooooo00?oool010000=;i
[0000>Sja`<00008fNOO0P0000OHe]H00`000<G:g/G:gP0:aL[N100000G5_M<00`000=WGH0000003
nnNV00<0003`e;G`e;D01O3D]@030000h/:hh/:h00SR`[P00`000=Nd]]Nd]P0>XZ;E100000f0U=d0
100005mgd`00000000DoK]P0100000=Cc`00000000:nXkd010000;NI^KNI^KNI^@80000<[ic400<0
002XTl2XTl003jRC`0030000WhVlWhVl00bORK`00`0008^2a8^2a009Rh;400<0001lMKmlMKl01Wae
_`030000J6>jJ6>j00EXHkX00`0004M9/4M9/002AdV`00@0000=79/=79/=79/200001oooo`030000
oooooooo01koool001koool00`000?ooooooo`03oooo00<0003BnJ`000000^Sja`030000fNOOfNOO
00OIiml00`000=SFe]SFeP07f=KF00<00035b]k5b]h01lG:gP<00009aKgC00<0003Ief0000000o_W
YP030000l=Bel=Be00G`e;D00`000>;2^>;2^008h/:h00@0003G];KG];KG];H?XZ;E00@0002<T=80
0000000;P9CM00D0001OMm=OMm=OMm<000001Cm^f0D00006]iVi0P0000Z_W<@00`000:RC`:RC`00>
Z9?000<0002ORKbORK`03In9_0<00009Rh;400<0001lMKmlMKl01Wae_`030000J6>jJ6>j00EXHkX0
0`0004M9/4M9/002AdV`00@0000=79/=79/=79/200002?ooo`030000oooooooo01goool001koool0
0`000?ooooooo`03oooo0P0000?Xn/L00`000=WWgmWWg`05fNOO0P0000[He]H00`000<G:g/G:gP03
aL[N100000c5_M<200001?_WYP030000l=Bel=Be00C`e;D00`000>;2^>;2^008h/:h00<0003G];KG
];H00]Nd]PnRX]D0100008b@dXb@dXb@dP800009P9CM00<0001OMm=OMm<00Umgd`030000?fkH?fkH
00<oK]P01000000IY`00000000RgVKT00`000:nLa:nLa006[ic400<0002XTl2XTl003jRC`0030000
WhVlWhVl00bORK`0100009Em]iEm]iEm]`800006Rh;400<0001lMKmlMKl01gae_`030000J6>jJ6>j
00EXHkX00`0004M9/4M9/002AdV`00@0000=79/=79/=79/200002?ooo`030000oooooooo01goool0
01goool00`000?ooooooo`03oooo00<0003BnJ`000000^Sja`800006fNOO00<0003He]KHe]H02]SF
eP030000aL[N000000<0000@aKgC0`0000?kijH00`000?3D]O3D]@04l=Be00<0003R`[SR`[P02>;2
^0030000ekBfekBf00?G];H>XZ;E00<0002<T=:<T=800hb@dP<00007P9CM00<0001OMm=OMm<00Umg
d`030000?fkH?fkH008oK]P400002KNI^@800006[ic400<0002XTl2XTl003ZRC`0030000WhVlWhVl
00fORK`00`0009Em]iEm]`03UGfg0P0000B;P/@00`0007ae_gae_`07O7Fo00<0001XHkYXHkX01FQS
^P030000AdV`AdV`0097BK00100000dLV`dLV`dLV`800009oooo00<0003oooooool07?ooo`007Ooo
o`030000oooooooo00;oool00`000=;i[0000002j?[700<0003[kLd000001=WWg`80000=f=KF0P00
01C5_M<2000000CocGP0000000000007l=Be00<0003R`[SR`[P02>;2^0030000ekBfekBf00?G];H>
XZ;E00<0002<T=:<T=801Xb@dP800005P9CM00<0001OMm=OMm<00emgd`040000?fkH?fkH?fkH0P00
000301VW0000000000ZgVKT200000jnLa0030000Z9?0Z9?000nXTl000`0009n9_9n9_00<WhVl00<0
002EOKNEOKL01YEm]`800002Rh;400<0001lMKmlMKl01gae_`030000J6>jJ6>j00EXHkX00`0004M9
/4M9/002AdV`00L0000=79/=79/=79/0000006D000002?ooo`030000oooooooo01coool001coool0
0`000?ooooooo`03oooo0P0000;Xn/L01@000>_]cN_]cN_]c@000002fNOO00<0003He]KHe]H02mSF
eP<0000EaKgC0P0000?ocGP00`000?3D]O3D]@04l=Be00<0003R`[SR`[P02>;2^0030000ekBfekBf
00GG];H=XZ;E00<0002<T=:<T=8028b@dP800003P9CM00<0001OMm=OMm<015mgd`8000001Sm^f000
00/l_000000IY`0000bgVKT2000000>_W<@0002XTl003jRC`0030000WhVlWhVl00fORK`00`0009Em
]iEm]`08UGfg0`0000UlMKl00`0006QS^VQS^P05J6>j00<00017BK17BK000TM9/00700003AbK3AbK
3AbK0000001U000000Woool00`000?ooooooo`0Koooo000Loooo00<0003oooooool00_ooo`050000
d_V/0000j?[7000000C[kLd300003=SFeP800002e/W>00<00035_M?5_M<04lFmd`800003oleh0`00
00C`e;D00`000>;2^>;2^008h/:h00<0003G];KG];H01]Nd]PbRX]D00`0008b@dXb@dP0:S93B0P00
0003P9CM0000GgOC00MOMm<2000000<;?;`000006JL00P0000fgVKT200004:RC`0030000WhVlWhVl
00bORK`00`0009Em]iEm]`0;UGfg0P0000QlMKl00`0006QS^VQS^P05J6>j00<00017BK17BK000TM9
/00700003AbK3AbK3AbK0000001U000000Woool00`000?ooooooo`0Koooo000Koooo00<0003ooooo
ool00_ooo`030000d_V/000000;Xn/L00`000>_]cN_]c@02jng=00<0003He]KHe]H02]SFeP800004
e/W>00<00035_M?5_M<04lFmd`800003oleh00@0003gaIKgaIH00003l=Be00<0003R`[SR`[P02>;2
^0030000ekBfekBf00KG];H=XZ;E00<0002<T=:<T=802hb@dP800009GgOC00H0000;?;`;?;`00000
6JL0000<]iVi00<0002_SkB_Sk@00P0000fXTl000`0009n9_9n9_00=WhVl00<0002EOKNEOKL02iEm
]`040000Qfna000000001Wae_`030000J6>jJ6>j00EXHkX00`0004M9/4M9/003AdV`00H0000=79/=
79/0000006D0000:oooo00<0003oooooool06_ooo`006oooo`070000oooooooooooo0000d_V/0000
00;Xn/L00`000>_]cN_]c@02jng=0P0000[He]H200001]K9cP030000aKgCaKgC01?5_M<200000oo=
N0040000mlFFmlFFmlFF0`0000[R`[P00`000=Nd]]Nd]P08ekBf3::Re@030000S93BS93B00b<T=83
00001emgd`8000000`/l_000000IY`0200002kNI^@030000[hnd[hnd00:_Sk@200002jRC`0030000
WhVlWhVl00fORK`00`0009Em]iEm]`0:UGfg00<00027Kk67Kk400XM_/@800004O7Fo00<0001XHkYX
HkX01FQS^P030000AdV`AdV`00=7BK00100000dLV`dLV`dLV`80000:oooo00<0003oooooool06_oo
o`006oooo`040000oooooooooooo0P0000;Xn/L00`000>_]cN_]c@02jng=00<0003XglX000002MSF
eP030000e/W>e/W>00KFbLh00`000<FmdlFmd`0CaKgC0P0000?ocGP00`000?O5U_O5UP03mlFF00<0
003R`[SR`[P02>;2^0030000ekBfekBf00SG];H<XZ;E00<0002<T=:<T=8038b@dP040000L7W<L7W<
00001Umgd`8000022cbl00<000006JL000002[NI^@030000[hnd[hnd00F_Sk@200002:RC`0030000
WhVlWhVl00fORK`00`0009Em]iEm]`0;UGfg00<00027Kk67Kk4018M_/@800002O7Fo00<0001XHkYX
HkX01FQS^P030000AdV`AdV`00=7BK001`0000dLV`dLV`dLV`000000I@000009oooo00<0003ooooo
ool06_ooo`006_ooo`090000oooooooooooo0000d_V/0000j?[7000000C[kLd010000>SOb^SObP00
00OHe]H200002]K9cP030000aKgCaKgC0175_M<300000oo=N0030000mlFFmlFF00?gaIH300002>;2
^0030000ekBfekBf00WG];H;XZ;E00<0002<T=:<T=8038b@dP040000L7W<L7W<L7W<0P0000AOMm<0
1P00035>`00000/l_000000IY`800009]iVi00<0002_SkB_Sk@01jn?]0800006Z9?000<0002ORKbO
RK`03In9_0030000UGfgUGfg00^EOKL00`0008M_/HM_/@06Qfna0`0000QXHkX00`0004M9/4M9/002
AdV`00L0000=79/=79/=79/0000006D000002_ooo`030000oooooooo01Woool001[oool01P000?oo
ooooo`000=;i[00000;Xn/L01@000>_]cN_]cN_]c@000004j=o:00<0003He]KHe]H00]SFeP80000<
e/W>00<00035_M?5_M<03LFmd`@000000lFcb@0000000003oleh00<0003gaIKgaIH00oO5UP040000
jKRPjKRP00001^;2^0030000ekBfekBf00[G];H600001J:Re@030000S93BS93B00b<T=800`00071i
c71ic003L7W<00L0001OMm=OMm=OMm<0000aC/0000000P/l_0030000001f000000RgVKT00`000:n?
]:n?]00:[hnd0P0000>XTl000`0009n9_9n9_00=WhVl00<0002EOKNEOKL02iEm]`030000QfnaQfna
00V7Kk4200001fQS^P030000AdV`AdV`0097BK001`0000dLV`dLV`dLV`000000I@00000:oooo00<0
003oooooool06Oooo`006_ooo`030000oooooooo00800002j?[700D0003[kLg[kLg[kLd000001NSO
bP030000f=KFf=KF0080000>e/W>00<00035_M?5_M<02<Fmd`D00006aK?900D0003ocGSocGSocGP0
00001OO5UP040000jKRPjKRPjKRP0P0000CR`[P00`000=Nd]]Nd]P0:ekBf00<0002VVl^VVl/00jJK
b`L0000=S93B00<0001`NLa`NL`0171ic0040000GgOCGgOC00000S5>`00500002cbl0000001f0000
00RgVKT00`000:n?]:n?]00<[hnd0P000003Z9?00000WhVl00jORK`00`0009Em]iEm]`0;UGfg00<0
0027Kk67Kk402HM_/@040000LebX000000001FQS^P030000AdV`AdV`0097BK001`0000dLV`dLV`dL
V`000000I@00000:oooo00<0003oooooool06Oooo`006Oooo`080000oooooooo0000d_V/0000j?[7
00000n_]c@030000j=o:j=o:00CXglX300004=K9cP030000aKgCaKgC00C5_M<400002lFcb@050000
oleholeholeh000000GgaIH00`000>VhX>VhX003jKRP00D0003R`[SR`[SR`[P000002mNd]P030000
cZVccZVc00VVVl/00`0009><b000000200002Xb@dP030000L7W<L7W<00E`NL`300000c5>`0D00006
]iVi00<0002_SkB_Sk@03jn?]0030000WhVlWhVl00fORK`00`0009Em]iEm]`0<UGfg00<00027Kk67
Kk4028M_/@030000LebXLebX009cG:P200000fQS^P030000AdV`AdV`0097BK001`0000dLV`dLV`dL
V`000000I@00000;oooo00<0003oooooool06?ooo`006Oooo`030000oooooooo008000000nSja`00
0>_]c@03jng=00<0003Xgl[XglX01>SObP030000e/W>e/W>013FbLh00`000<FmdlFmd`0400003lFc
b@050000oleholeholeh000000GgaIH00`000>VhX>VhX004jKRP0`0000cG];H00`000<jY/ljY/`09
YY_;00<0002CS<RCS<P00Y><b0<00007S93B00<0001`NLa`NL`01g1ic0040000<Dk0<Dk0<Dk00`00
0003001f0000]iVi00FgVKT00`000:n?]:n?]00>[hnd00@0002WQK000000000=WhVl00<0002EOKNE
OKL02iEm]`030000QfnaQfna00V7Kk400`0007=LZ7=LZ004LebX0P000003J6>j0000AdV`00A7BK00
1P0000dLV`dLV`000000I@0000_oool00`000?ooooooo`0Hoooo000Ioooo00L0003oool0003Tki00
003Xn/L000000n_]c@030000j=o:j=o:00CXglX200004MK9cP@0000CaK?900D0003ocGSocGSocGP0
00001OO5UP030000jKRPjKRP00KY^:000`000=Nd]]Nd]P09ekBf00<0003>ZK?>ZK<00/jY/`RVVl/0
0`0009><b9><b005Thc80`0000B<T=800`00071ic71ic007L7W<0P0000<aC/02000000<007H0002g
VKT01;NI^@030000[hnd[hnd00n_Sk@010000:N5/:N5/:N5/080000;WhVl00<0002EOKNEOKL02iEm
]`030000QfnaQfna00V7Kk400`0007=LZ7=LZ006LebX0`0000A7BK00100000dLV`dLV`dLV`8006D0
0`000?ooooooo`08oooo00<0003oooooool06?ooo`006?ooo`030000oooooooo008000000o?cZP00
0>_]c@02jng=00<0003Xgl[XglX01>SObP030000iM?5000000oFbLh2000000?D_/D00035/lT05<Fc
b@050000oleholeholeh000000GgaIH00`000>VhX>VhX006jKRP0`0000WG];H00`000<jY/ljY/`02
cZVc2:JKb`030000Thc8Thc800RCS<P3000000><T=80001`NL`0271ic0030000B5Nn0000008aC/00
1@000000SP000000MP000004]iVi00<0002_SkB_Sk@03Zn?]0030000YhF`YhF`00BWQK000`0009n9
_9n9_007WhVl00<0002EOKNEOKL039Em]`030000QfnaQfna00V7Kk400`0007=LZ7=LZ007LebX00<0
001C?IX000000P000003AdV`00003AbK008=79/2001U00<0003oooooool02Oooo`030000oooooooo
01Ooool001Soool010000?ooo`000>C_T0;cljX010000>_]cN_]c@0000KXglX010000>GCaNGCa@00
00gFbLh200000mBna@030000aK?9aK?901?5/lT01@000?o=N?o=N?o=N0000005mlFF00<0003Y^:3Y
^:001^VhX0030000gZbSgZbS00800007ekBf00<0003>ZK?>ZK<00ljY/`NVVl/00`0009><b9><b00;
Thc80P0000U`NL`01@0004QG_TQG_P00035>`003000000<007H0002gVKT00[NI^@030000[hnd[hnd
00n_Sk@00`000:N5/:N5/005YhF`0P0000NORK`00`0009Em]iEm]`0<UGfg00<00027Kk67Kk4028M_
/@030000LebXLebX00QcG:P00`0005<mVU<mVP02DcfJ100000043AbK001U000000002oooo`030000
oooooooo01Ooool001Soool01@000?ooo`0000000??cZP02000000?[kLd0003XglX01NSObP050000
iM?5iM?5iM?5000000_FbLh200001MBna@030000aK?9aK?901?5/lT01@000?o=N?o=N?o=N0000005
mlFF00<0003Y^:3Y^:001^VhX0030000gZbSgZbS00;N[:<00`000=Nd]]Nd]P03ekBf00<0003>ZK?>
ZK<01LjY/`JVVl/00`0009><b9><b00<Thc80`0000M`NL`01@0004QG_TQG_P00035>`002000000<0
08h007H000000[NI^@030000[hnd[hnd00N_Sk@900002ZN5/0030000WhVlWhVl00>ORK`00`0009Em
]iEm]`0<UGfg00<00027Kk67Kk402HM_/@030000LebXLebX00McG:P00`0005<mVU<mVP04DcfJ00<0
000F1W/F1W/00P000003000/0000oooo00[oool00`000?ooooooo`0Goooo000Goooo00L0003oool0
003Tki3cljX0003fkKD00P0000GXglX200001NGCa@030000e/W>e/W>00GFbLh300001mBna@030000
aK?9aK?901?5/lT01@000?o=N?o=N?o=N0000004mlFF00<0003Y^:3Y^:001nVhX0030000gZbSgZbS
00?N[:<200000mNd]P030000cZVccZVc00G>ZK<6YY_;00<0002CS<RCS<P039><b0030000NWO4NWO4
00800005L7W<00P00018Eki8Eki8Ekh0000aC/00000008h200000[NI^@030000[hnd[hnd00>_Sk@D
00001:N5/0800003WhVl00<0002EOKNEOKL039Em]`030000QfnaQfna00V7Kk400`0007=LZ7=LZ007
LebX00<0001C?IYC?IX015<mVP0700005PIk5PIk5PIk0000000/000000coool00`000?ooooooo`0F
oooo000Goooo00P0003oool00000003cljX0003fkKD00005j=o:00<0003UdlGUdlD01NGCa@030000
e/W>e/W>00?FbLh200002]Bna@030000aK?9aK?901?5/lT01@000?o=N?o=N?o=N0000004mlFF00<0
003Y^:3Y^:001^VhX0030000gZbSgZbS00KN[:<300002LjY/`FVVl/00`0009><b9><b00<Thc800<0
001jMlAjMl@00WYga0030000L7W<L7W<009`NL`00`0004QG_TQG_P02B5Nn1@000004]iVi0000[hnd
[hnd3@0000IHb?H200000Tban@H000001:N5/0000000000000nEOKL00`0008M_/HM_/@09Qfna00<0
001cG:QcG:P01g=LZ0030000DcfJDcfJ00AC?IX01`0001H6NaH6NaH6N`000000;000000<oooo00<0
003oooooool05_ooo`005oooo`050000oooo0000lo>Z000000;fkKD00`000>SOb^SObP02j=o:00<0
003UdlGUdlD01^GCa@040000e/W>e/W>e/W>0P0000cD_/D00`000<FcbLFcb@0CaK?90P0000;ocGP0
0`000?O5U_O5UP02mlFF00<0003Y^:3Y^:001^VhX0030000gZbSgZbS00SN[:<00`000<jY/ljY/`07
cZVc1JJKb`030000Thc8Thc800bCS<P00`0007Yga7Yga003NWO40P00009`NL`00`0004QG_TQG_P03
B5Nn10000003]iVi0000000000L00007PM?o200000I</OT700003IEm]`030000QfnaQfna00V7Kk40
0`0007=LZ7=LZ008LebX00<0001C?IYC?IX00e<mVP0300005PIk5PIk008F1W/00`000000;000000<
oooo00<0003oooooool05_ooo`005_ooo`070000oooo00000000lo>Z0000m^fe00800003j=o:00<0
003UdlGUdlD01nGCa@040000e/W>000000003]Bna@030000aK?9aK?901?5/lT00`000?NW@`000002
00001?O5UP030000jKRPjKRP00KY^:000`000=j/Xmj/X`08gZbS0`0000S>ZK<4YY_;00<0002CS<RC
S<P039><b0030000NWO4NWO400EjMl@300001DQG_P030000]iVi000000h00006PM?o0P0000Al_?/5
000014ban@L0000:UGfg00<00027Kk67Kk402HM_/@030000LebXLebX00McG:P00`0005<mVU<mVP04
DcfJ00<0000F1W/F1W/00QH6N`80000>oooo00<0003oooooool05Oooo`005_ooo`070000oooo0000
lo>Z0000m^fe000000;ei;L00`000>SObP00000:iM?50P00013D_/D00`000<FcbLFcb@0CaK?90P00
00;gYd<00`000?O5U_O5UP02mlFF00<0003Y^:3Y^:001^VhX0030000gZbSgZbS00SN[:<00`000=BR
XmBRX`0200001/jY/`BVVl/00`0009><b9><b00<Thc800<0001jMlAjMl@01gYga0030000B5NnB5Nn
00=8Ekh8000000>Gj?/0000000001Y[Do0L0000:O;ck100000A</OT200000P1J``030000UGfgUGfg
00JEOKL00`0008M_/HM_/@09Qfna00<0001cG:QcG:P01g=LZ0030000DcfJDcfJ00AC?IX01`0001H6
NaH6NaH6N`000000;000000>oooo00<0003oooooool05Oooo`005_ooo`<000001??cZP000?K]]@00
00;ei;L200002NGCa@<0000Ae;k500<00035/lW5/lT04lFcb@800002mjM30P0000?gaIH00`000>Vh
X>VhX006jKRP00<0003N[:?N[:<01mj/X`030000e::Se::S00?DXZ<200001LjY/`>VVl/00`0009><
b9><b00<Thc800<0001jMlAjMl@01gYga0800003B5Nn1P0000:Gj?/200002i[Do0800002UKgc0P00
00al_?/400000SjAl080000205[300<0002EOKNEOKL00iEm]`030000QfnaQfna00V7Kk400`0007=L
Z7=LZ008LebX00<0001C?IYC?IX015<mVP0700005PIk5PIk5PIk0000000/000000koool00`000?oo
ooooo`0Eoooo000Foooo0P000004lo>Z0000m^fe00000oGT]`030000iM?5iM?500OUdlD010000>?9
_^?9_P00017D_/D00`000<FcbLFcb@0@aK?91@0000;gYd<01P000?N]KP0000000?O5UP0000SY^:00
0`000=j/Xmj/X`07gZbS00<0003DXZ?DXZ<01MBRX`030000cZVccZVc00?>ZK<2YY_;00<0002CS<RC
S<P039><b0030000NWO4NWO400MjMl@00`0005MI^@00000<00002I[Do0800006UKgc0`0000Ul_?/2
000000=cXNh0000000000cjAl08000000`1J``0000000003UGfg00<00027Kk67Kk402HM_/@030000
LebXLebX00QcG:P00`0005<mVU<mVP04DcfJ00L0000F1W/F1W/F1W/0000002`000003_ooo`030000
oooooooo01Goool001Goool3000000CcljX0003fkKD00002mNBg0P0000SUdlD01@000>?9_^?9_^?9
_P00000Ae;k500<00035/lW5/lT02<Fcb@P00003aJ_00`0000;gYd<00`000?N]K_N]KP0200002>Vh
X0030000gZbSgZbS00ON[:<00`000=BRXmBRX`06e::S0P0000?>ZK<5000039><b0030000NWO4NWO4
00MjMl@8000000BGj?/0000000000003ZM?f100000>Je?`200002iFml`800006O;ck00<0001cXNic
XNh00g>QkP800003?Y7`0P00000505[300000000UGfg000000^7Kk400`0007=LZ7=LZ008LebX00<0
001C?IYC?IX015<mVP0700005PIk5PIk5PIk0000000/000000ooool00`000?ooooooo`0Doooo000E
oooo0P000004lo>Z0000m^fe00000oGT]`800006iM?50P0000CSbKh00`000=BnaMBna@0?e;k500@0
0035/lW5/lW5/lT700002lF[`0030000]j32000000;gYd<010000?N]K_N]K_N]KP800007jKRP00<0
003N[:?N[:<01mj/X`030000e::Se::S00SDXZ<2000000C>ZK<0002XU<400002UhJo1@0000NCS<P0
0`0007Yga7Yga007NWO41@0000:WjOX010/PX0000000000000RYdoH400003YFml`800002O;ck0P00
00QcXNh00`0003jAl3jAl002?Y7`0P00000305[30000000000^7Kk400`0007=LZ7=LZ007LebX00<0
001C?IYC?IX015<mVP0300005PIk5PIk008F1W/00`000000;000000?oooo00<0003oooooool05?oo
o`005Oooo`8000001??cZP000?K]]@0000;ei;L00`000??K]P000005iM?500<0003SbKkSbKh01>?9
_P030000e;k5e;k500kD_/D500004/F[`0030000]j32000000;gYd<01P000?N]K_N]K_N]KP000>fX
P@800004jKRP00<0003N[:?N[:<02=j/X`030000e::Se::S00[DXZ<010000<FN/:RD`@0000NGQ[l5
00000Y><b0030000NWO4NWO400IjMl@400001:OYnP042b2P0000000000001jWCmP800003YKgZ0P00
00jE_O<200002g>QkP800004?Y7`0P00000305[30000000000R7Kk400`0007=LZ7=LZ008LebX00<0
001C?IYC?IX015<mVP0300005PIk5PIk008F1W/00`000000;000000?oooo00<0003oooooool05?oo
o`005?ooo`8000001?OXSP000?K]]@0000;ei;L01@000??K]_?K]_?K]P000003iM?500<0003SbKkS
bKh01N?9_P030000e;k5e;k500[D_/D4000000?B][d00035Zl005<F[`0060000]j3200000000mjM3
00000oN]KP040000kJR1kJR1kJR10P0000;Y^:000`000=j/Xmj/X`08gZbS00<0003DXZ?DXZ<02]BR
X`@0000<UhJo100000EjMl@:000000@;8:00000000000005ZM?f0P0000NU_NX300002YFml`800000
0hjVi@000000000;Lj7^00<0000nTO0nTO000cjAl08000000`1J``0000000006Qfna00<0001cG:Qc
G:P027=LZ0030000DcfJDcfJ00AC?IX00`0001H6NaH6N`025PIk00<0000002`000004?ooo`030000
oooooooo01?oool001Coool2000000Cgj8h0003fkKD00002mNBg00H0003cfkKcfkKcfkH0003UdlD2
00002>?9_P030000e;k5e;k500KD_/D400001M:f_@030000aJ_0aJ_001?5Zl001P000;NP`[NP`P00
0?NW@`0000Cg[Fh00`000>fXPNfXP@02kJR10`0000WN[:<00`000=BRXmBRX`0:e::S00D0003<V:7<
V:7<V:4000003YN6_`050000P7>l00000000NWO400H00002/nWg0P000003]M;_0000000000@00002
ZM?f0P0000bU_NX200001YFml`800005SZKU0P0000YcXNh200001CjAl08000000`1J``0000000004
Qfna00<0001cG:QcG:P027=LZ0030000DcfJDcfJ00AC?IX00`0001H6NaH6N`025PIk0P00017oool0
0`000?ooooooo`0Coooo000Doooo0P000003mnR>nnNJ000000;ei;L00`000??K]_?K]P02lm^f0P00
00[SbKh00`000=BnaMBna@03e;k50`0000WB][d00`000<F[`<F[`00CaJ_000@0002gX<:gX<800002
mjM300D0003g[Fkg[Fkg[Fh000001^fXP@030000gZbSgZbS00ON[:<00`000=BRXmBRX`0:e::S00<0
003<V:7<V:400/bHX@jGQ[l00`00081c_81c_007000000>cjOL0000000000[GBk`04EeVi00000000
2b2P0P000003]M;_00000000012U_NX200000YFml`800009SZKU00<0001cXNicXNh02G>QkP800005
?Y7`0P00000305[30000Qfna00:7Kk400`0007=LZ7=LZ008LebX00<0001C?IYC?IX015<mVP070000
5PIk5PIk5PIk0000000/0000017oool00`000?ooooooo`0Coooo000Doooo0`000004nnNJ0000mNBg
00001O?K]P030000hlVnhlVn00WSbKh00`000=Bna@00000300003=:f_@030000aJ_0aJ_001?5Zl00
0`000;NP`[NP`P02000000?gYd<0003g[Fh00_N]KP030000kJR1kJR100C]Z84300001mj/X`030000
e::Se::S00[DXZ<00`000<bHXLbHX@03c9RQ3IN6_`L0000011L0?`000000000000>ed^l2EeVi00<0
000L9j00000010000003/;cS00000000012U_NX2000038jVi@80000;Lj7^00<0000nTO0nTO000cjA
l0800000100VZ`0008M_/@0000YcG:P00`0005<mVU<mVP05DcfJ00L0000F1W/F1W/F1W/0000002`0
00004Oooo`030000oooooooo01?oool001Coool00`000?OXSP00000300001O?K]P80000:hlVn0`00
013B][d00`000<F[`<F[`00DaJ_000H0002gX<800000003gYd<00003mje^00<0003]Z87]Z8401>fX
P@040000hj2:hj2:00001]j/X`030000e::Se::S00WDXZ<00`000<bHXLbHX@04c9RQ3IN6_`<00000
0cd0=P0004@7F`0400001;GBk`9GFKT00`0001`WX1`WX00200001K2lh`80000<YKgZ0P0000:OZ=d0
0`0008jViHjVi@0;SZKU0P0000YcXNh2000000<nTO00000000000S1]f`03000002J[000000800009
LebX00<0001C?IYC?IX015<mVP0300005PIk5PIk008F1W/00`000000;000000Aoooo00<0003ooooo
ool04oooo`005?ooo`030000mnR>000000<00004lm^f00<0003`d[<000002>?9_P8000000n71^000
0=:f_@0@d[Jm00<00035Zl35Zl005<F[`0060000]j32]j320000mjM300001?N]KP030000kJR1kJR1
00?]Z84010000>>PR^>PR^>PRP800004gZbS00<0003DXZ?DXZ<02MBRX`030000c9RQc9RQ00G<V:4:
UhJo20000004<PY^0000_];Y_];Y0P000006]M;_EeViEeViEeVi000072NP0`0000N`_><00`000:Fm
jZFmjP07YKgZ0P0000FOZ=d200003HjVi@030000Lj7^Lj7^00QcXNh200001C1]f`04000002J[0000
OEBF0P0000McG:P00`0005<mVU<mVP04DcfJ00<0000F1W/F1W/00QH6N`030000000/000001;oool0
0`000?ooooooo`0Boooo000Doooo0`000003o>>P0000lm^f00?cfkH010000?3B/o3B/`0000KSbKh2
00000n71^0030000d[Jmd[Jm00oB][d00`000<F[`<F[`00DaJ_000<0002gX<:gX<800P000003mjM3
0000mje^00;g[Fh00`000>fXPNfXP@03kJR100<0003SX8[SX8X00n>PRP040000gZbSgZbS00003=BR
X`030000c9RQc9RQ00G<V:49UhJo0`000004C`0o0000GQmWGQmW100000Bnd^T200000UMI^@030000
72NP000000800008/;cS0P0000FU_NX200002InXg@030000SZKUSZKU00^>Y^D200001W>QkP800002
JHGK00<0000`KM/`KM/00c1]f`03000002J[0000009mE9H200001G=LZ0030000DcfJDcfJ00AC?IX0
0`0001H6NaH6N`025PIk00<0000002`000004_ooo`030000oooooooo01;oool001?oool4000000?l
hj00003cfkH00_?K]P050000l=:cl=:cl=:c000000CSbKh200001N71^0030000d[Jmd[Jm013B][d0
0`000<F[`<F[`00CaJ_000@0002gX<:gX<:gX<8300000oN]KP030000kJR1kJR100?]Z8400`000>>P
R^>PRP04hj2:0`0000_DXZ<00`000<bHXLbHX@07c9RQ1YN6_`<000000e/7@`000000000700001;kB
j@9OF;<3000000@L9j0000000000000:/;cS0P000003YKgZ0000000000bOZ=d00`0008jViHjVi@0<
SZKU0P00009cXNh200001FV5f`030000<6gK<6gK00<`KM/00`00000VZ`000003OEBF0P00009cG:P0
0`0005<mVU<mVP05DcfJ00<0000F1W/F1W/00QH6N`030000000/000001;oool00`000?ooooooo`0B
oooo000Coooo00@0003gj8h0003lhj0200000_?K]P030000l=:cl=:c00;`d[<00`000>?9_^?9_P02
00001n71^0030000d[Jmd[Jm013B][d00`000<F[`<F[`00CaJ_000L0002gX<:gX<:gX<80003QN0X0
00000oN]KP030000kJR1kJR100?]Z8400`000>>PR^>PRP06hj2:00<0003DXZ?DXZ<02MBRX`030000
c9RQc9RQ00O<V:44UhJo0`00009K1d<01`0006h]K6h]K0000791Q@0006e<V@0300000kkBj@EOF;<5
00003;2lh`030000WjSMWjSM00fOZ=d200003XjVi@800008JHGK00<0000`KM/`KM/00c1]f`030000
02J[000000AmE9H300001e<mVP0300005PIk5PIk008F1W/2000/00<0003oooooool04?ooo`030000
oooooooo01;oool001?oool3000000?lhj00003lgJ800P0000G`d[<300002N71^0030000d[Jmd[Jm
013B][d00`000<F[`<F[`00CaJ_000<0002gX<:gX<800[NP`P@00002mje^00<0003]Z87]Z8400nfX
P@030000hj2:hj2:00GSX8X300002MBRX`030000c9RQc9RQ00S<V:400iN6_`000000000;000000A]
C9T0000000000003_];Y1EmH/`D0000:/;cS0P000003Zj[F0000WjSM00nOZ=d00`0008jViHjVi@09
SZKU0P000003QXoE0000JHGK00QYQM/00`00031]fc1]f`03<6gK00<000009Z/000001GeDUP800006
DcfJ00<0000F1W/F1W/00QH6N`03000/0000oooo01;oool00`000?ooooooo`0Boooo000Coooo0P00
0005o>>P0000o=fRo=fR000000K`d[<00`000>71^>71^00:hL6h00<0003B][gB][d03m:f_@030000
aJ_0aJ_001?5Zl000`000;NP`[NP`P02]j3200@0003QN0X0003/RCX300001NfXP@030000hj2:hj2:
00GSX8X00`000=VHSMVHS@0200001]BRX`030000c9RQc9RQ00S<V:42000000<W0000001S34<00P00
0004NCA]00000000PD^70P000003PEVJ0000000000<00002_];Y00<0001OF;=OF;<00UmH/`H00008
/;cS0P0000B[Z]H00`0009nXgInXg@0>WjSM00<0002>Y^F>Y^D01XjVi@800004QXoE00<0001YQM]Y
QM/01fV5f`030000<6gK<6gK00<`KM/00`00000VZ`000004OEBF0UlbPP800003DcfJ00<0000F1W/F
1W/00QH6N`030000000/000001?oool00`000?ooooooo`0Boooo000Coooo0P000003o>>P0000o=fR
00800004l=:c0`0000cQ`KP00`000=:f_M:f_@0?d[Jm00<00035Zl35Zl003/F[`0d00003k8Tj00<0
003]Z87]Z8400nfXP@030000hj2:hj2:00GSX8X00`000=VHSMVHS@02fIR=00<0003DXZ?DXZ<00mBR
X`030000c9RQc9RQ00K<V:47000000>1>F`0000000000XYAQP070000SF2HSF2H0000S6bX0000QgJh
00D00002GeRc10000004l^No0000000000001k2lh`030000Zj[FZj[F00F[Z]H200003inXg@800004
SZKU0P0000N6SmD00`0006V5ffV5f`07JHGK00<0000`KM/`KM/00c1]f`03000002J[0000009mE9H0
0`0005lbPUlbPP02Gc:20P000003DcfJ00005PIk00<F1W/00`000000;000000Doooo00<0003ooooo
ool04Oooo`004oooo`<00002o=fR0P0000?`d[<010000>o;[^o;[P0000cQ`KP00`000=:f_M:f_@0?
d[Jm00<00035Zl35Zl000lF[`0/00005a:Bh00<0002gVKVgVKT00kNI^@030000hGP:000000;/RCX3
00000nfXP@030000hj2:hj2:00GSX8X00`000=VHSMVHS@03fIR=0P0000?DXZ<00`000<bHXLbHX@04
c9RQ1@000003J0i00000PCU/00<000001HYAQP000000000008ePV002000000><K:P00027M[P00P00
0003RY?G0000000000<000001MKUhP00000000000?cRY00300001;2lh`80000:Zj[F00<0002OZ=fO
Z=d03YnXg@040000SZKU000000002HJ?e@030000JHGKJHGK00QYQM/00`00031]fc1]f`03<6gK00@0
00009Z/000000007Gc:21000008F1W/00`000000;000000Doooo00<0003oooooool04Oooo`004_oo
o`@000001?cMXP000?_HXP0000;`d[<01@000>o;[^o;[^o;[P00000<hL6h00<0003B][gB][d02m:f
_@X0000@a:Bh00<0002gVKVgVKT01;NI^@800003k8Tj00<0003ZSUD000000^fXP@030000hj2:hj2:
00GSX8X00`000=VHSMVHS@05fIR=0`0000K<V:44000000EX3T0000000026>fP000000i5DP`050000
UVBFUVBFUVBF000000:GL:D0100009Ik/`0009:6``8000000iRVg`0000000006000000KlhZ@00000
002i_Md0002`_><200003J^ZeP030000WjSMWjSM00jOZ=d00`0008J?eHJ?e@0:QXoE00<0001YQM]Y
QM/026V5f`030000<6gK<6gK00<`KM/00`00000VZ`000008Gc:200<0000R05LR05L01@0001Coool0
0`000?ooooooo`0Aoooo000Boooo1@0000;kf:8300001>o;[P030000hL6hhL6h00[Q`KP00`000=:f
_M:f_@02d[Jm2@0000CB[kH00`000<BT^<BT^00Ca:Bh00<0002gVKVgVKT01;NI^@030000hGP:0000
00;/RCX00`000>Z>ENZ>E@0300001n>PRP030000fIR=fIR=00OIV8d00`000<bHXLbHX@02c9RQ1000
0004K0dj00000000QS]X0`000005TEB3000000000000UVBF00<000001IM`Y@0009im[P0009j7^`02
000000>WXM00000000000`000003e];E0000000000@00002^KgM00<0002[Z]J[Z]H03Z^ZeP030000
WjSMWjSM00^OZ=d2000000>HULl00026SmD02hJ?e@030000JHGKJHGK00QYQM/00`00031]fc1]f`03
<6gK00<000009Z/000001UlbPP0300008P1G8P1G00<R05L300005?ooo`030000oooooooo017oool0
01;oool2000000?ngHP0000000000__HXP030000kl^^kl^^00G_bjh00`000>71^>71^007hL6h1`00
00gB[kH00`000<BT^<BT^00Ca:Bh00<0002gVKVgVKT01KNI^@800003k8Tj00@0003ZSUGZSUGZSUD2
00001^>PRP030000fIR=fIR=00OIV8d7000000=/3CX0000000000X/kH`050000UeJ0UeJ0UeJ00000
00>LIi<0300009icXIicXIicX@0009im[P000:J8]@000:JC`@000:jMaPT000000o_JX`0000000002
000000>d[=00002[Z]H03j^ZeP030000WjSMWjSM00ROZ=d2000019REc`030000QXoEQXoE00Z6SmD0
0`0006V5ffV5f`08JHGK00<0000`KM/`KM/00c1]f`03000002J[000000EO<X800`000280Eb80E`02
8P1G0`0001Goool00`000?ooooooo`0Aoooo000Boooo100000;kf:8200001no;[P030000hL6hhL6h
00?Q`KP400000^2j/@030000dZnfdZnf00oB[kH00`000<BT^<BT^00Ca:Bh00<0002gVKVgVKT01KNI
^@030000hGP:000000;/RCX01P000>Z>ENZ>ENZ>E@000>><I0800004hj2:00<0003IV8gIV8d01mVH
S@030000dHn=000000<0000016`7;`00000008/kH`<000001IMFP0000000000009aWT`03000000RN
Lj400000002UOZX0002VR;D0002/TKX2000000N^WLH000000000003:^l`0003Fa//00`000003nmZS
0000000000Bd[=000`000:^ZeZ^ZeP0>Zj[F0P0000NOZ=d00`0009REciREc`05V9G?00<00026SmF6
SmD02XJ?e@030000JHGKJHGK00QYQM/00`00031]fc1]f`03<6gK00<000009Z/000000elbPP030000
8P1G8P1G00<R05L300005Oooo`030000oooooooo017oool001;oool4000000Ckf:80003jdYl00007
kl^^00<0003Q`KP000000`0000KP^[400`000=:_]]:_]P0?dZnf00<00034Y;S4Y;P04lBT^0030000
]iVi]iVi00JgVKT200000nb9>P050000jXiEjXiEjXiE000000;SS6@200000^>PRP030000fIR=fIR=
00OIV8d2000000<Y0000001/1bl00P000003SSQJ0000000000:LEg/200000Z9YT0800003XgBN00<0
002UOZX000000P000005YXRe0000[96j0000/iZn00@000001<Zkc00000000>77_P8000000o_JX`00
00000005]:c@00<0002[Z]J[Z]H03j^ZeP030000WjSMWjSM00:OZ=d2000029REc`030000QXoEQXoE
00^6SmD00`0006V5ffV5f`08JHGK00<0000`KM/`KM/00c1]f`03000002J[0000009O<X800`000280
Eb80E`028P1G0`0001Koool00`000?ooooooo`0Aoooo000Boooo10000004nmRR0000n]:O00001^o;
[P<0000:h;Za00<0003B[kKB[kH03m:_]P030000a:Bha:Bh01?4Y;P00`000;NI^KNI^@07]iVi0`00
0003k8Tj0000jXiE00;ZSUD00`000>><I>><I002hhaT0`0000OIV8d:00000Z5FM0800002YfZ<0P00
0003Z7JK0000XgBN008000000jUoYP000:^8/002ZhR`0`0000:cV[h2000000?2Zl<0000000000P00
0003hLNn0000000000<00006]:c@00<0002[Z]J[Z]H03j^ZeP040000WjSM000000002iREc`030000
QXoEQXoE00^6SmD00`0006V5ffV5f`08JHGK00<0000`KM/`KM/00S1]f`D000058P1G0`0001Koool0
0`000?ooooooo`0Aoooo000Boooo1@0000;jdYl010000>o;[^o;[^o;[P<000000nk5Z@000>2j/@0:
h;Za00<0003B[kKB[kH03m:_]P030000a:Bha:Bh01?4Y;P00`000;NI^KNI^@08]iVi1@0000;ZSUD0
0`000>><I>><I004hhaT00<0003IV8gIV8d01=VHS@H000001Hl`B`00000000000:5FM003000000BW
JX`0000000000002Z7JK0P0000:YOjH01@000:j8[@000:^8/0000002/92e100000;2Zl<01@000<^d
``0000000>77_P02000000?je9l0000000001kB/d0030000Zj[FZj[F00j[Z]H200003YREc`030000
QXoEQXoE00^6SmD00`0006V5ffV5f`08JHGK00L0000`KM/00000000RAKd0000008H00P0000@R05L3
00005oooo`030000oooooooo017oool001;oool2000000?of8`0003jdYl00_[BW`040000kl^^0000
00001>k5Z@030000h;Zah;Za00WP^[400`000=:_]]:_]P0?dZnf00<00034Y;S4Y;P04lBT^0030000
]iVi]iVi00VgVKT2000000?AEP00003ZSUD00^Z>E@030000hhaThhaT00?SS6@300000]VHS@@00000
0eh0000008`P<@03000000FUDVP000000000002]JhH00P0000:^N9P3000000B^PJ@0002YOjH00003
[XR]00@0002`T;F`T;D00002]YRh2`000003n]BO0000000000Rd[=000`000:^ZeZ^ZeP0;Zj[F0P00
00:TVLT00`0009REciREc`0<V9G?00<00026SmF6SmD02XJ?e@030000JHGKJHGK00QYQM/200001295
_@0300000026000000@R05L300005oooo`030000oooooooo017oool001;oool400000_[BW`<00006
k/FY00<0003P^[7P^[402N2j/@030000dZnfdZnf00oB[kH00`000<BT^<BT^00Ca:Bh00<0002gVKVg
VKT02KNI^@040000_d400000dEH00P000003jXiE0000hhaT00GSS6@00`000=b7K000000<00000[=Z
O@8000001[AjU000000000000;:3XP0000:^PJ@200000jj8[@0@0000/Y2b0000/92e0000]YRh0000
_Ink0000a:Jl0000c:jl0000eKJk0000h;ng0P000003n]BO0000000000Vd[=000`000:^ZeZ^ZeP08
Zj[F0P0000BTVLT00`0009REciREc`0=V9G?00<00026SmF6SmD02XJ?e@030000JHGKJHGK00EYQM/2
000000=OJ<D0000RAKd00b95_@0300000026000000<R05L300006Oooo`030000oooooooo013oool0
01;oool6000000?icY/0003^aJT01^k5Z@030000h;Zah;Za00WP^[400`000=:_]]:_]P0?dZnf00<0
0034Y;S4Y;P04lBT^0030000]iVi]iVi00ZgVKT010000;m100000=5F00@00005hhaT30000003_EQ=
0000000000D000001;V6W`000;:3X[:3XP<00002/HV[00<0002^R:d000000k:@/P8000002kJH^000
0;fO^`000<BV_0000<b^_0000=Ff^`000>2o]`0500002[B/d0030000Zj[FZj[F00F[Z]H200001jBI
b@030000V9G?V9G?00fHULl00`0008J?eHJ?e@0:QXoE00<0001YQM]YQM/00VV5f`800004GfS500<0
000RAKdRAKd00R95_@03000000260000008R05L300006Oooo`030000oooooooo013oool0017oool3
000000?oeH`0003icY/00_W>V`030000k/FYk/FY00G^aJT00`000>2j/N2j/@09h;Za00<0003B[kKB
[kH03m:_]P030000a:Bha:Bh01?4Y;P00`000;NI^KNI^@0;]iVi00@0002o@@0000000002f68E00<0
003SS6CSS6@00^><I003ALBd0000000000800004e_KS00@0003Df]cDf]cDf]`2000000G>MVP00000
0031RIX000000[V6W`<000001;J<ZP000;69Zk69Z`<00003/Y2b00<0002hUkJhUkH01P000003c:jl
0000000000@000000o[?VP000000000;]:c@00<0002[Z]J[Z]H00Z^ZeP80000:Y9W900<0002HULnH
ULl03IREc`030000QXoEQXoE00Z6SmD0100006V5f`00000000IOJ<D00`000295_B95_@028TFm00@0
000008H0000R05L300006_ooo`030000oooooooo013oool0017oool500000oW>V`030000k/FYk/FY
00G^aJT00`000>2j/N2j/@09h;Za00<0003B[kKB[kH03m:_]P030000a:Bha:Bh01?4Y;P00`000;NI
^KNI^@0<]iVi100000;HHQD6000000?Hn]h0003Fm^<00]Kfh`<00004e=[L20000003_92X0000]XbZ
00@00002]92a00D0002bT;:bT;:bT;8000000[RG]P050000_Ybf_Ybf0000aJ:f00<000000mFa]000
0>2i/@02000000?jciX0000000003;B/d0040000Zj[F000000003JBIb@030000V9G?V9G?00bHULl0
0`0008J?eHJ?e@0:QXoE0P0000UOJ<D00`000295_B95_@028TFm00<0000008H000000`0001[oool0
0`000?ooooooo`0@oooo000Aoooo0`000003om:90000nLjK00;icY/00`000>k5ZNk5Z@05k/FY00<0
003P^[7P^[402N2j/@030000dZnfdZnf00oB[kH00`000<BT^<BT^00Ca:Bh00<0002gVKVgVKT03KNI
^@@000000mQR5@000000000200000mSjgP040000e_KS000000000]cPf@030000e=[Le=[L00?Df]`2
000000?@Vil00034U:D01@0000:gT[400`000;B@/KB@/@02]92a00<0002bT;8000000kRG]P0;0000
_Ybf_Ybf0000aJ:f0000c:Vf0000eK6d0000h;Va008000000o[?VP000000000<]:c@0P0000nTVLT0
0`0009REciREc`0=V9G?00<00026SmF6SmD01hJ?e@800002OGW300<0001OJ<EOJ<D01UmXa@030000
8TFm8TFm008RAKd01@000000QP000?ooo`00000Koooo00<0003oooooool04?ooo`004Oooo`<00000
0ooBR@000?W>V`02nLjK00<0003^aJW^aJT01Nk5Z@030000h;Zah;Za00WP^[400`000=:_]]:_]P0?
dZnf00<00034Y;S4Y;P04lBT^0030000]iVi]iVi00ngVKT700000]SjgP<00004g>3I00<0003Df]cD
f]`00]CJg0H000001<JN[`000;fG/00000>gT[400`000;B@/KB@/@02]92a00<0002bT;8000000kRG
]P030000_Ybf000000;5X[H01P000<bY]P000=Fa]0000>2i/@8000000o[?VP000000000:]:c@0P00
0003[Y_50000Y9W900nTVLT00`0009REciREc`0=V9G?00<00026SmF6SmD018J?e@800004OGW300<0
001OJ<EOJ<D01emXa@0300008TFm8TFm008RAKd400006oooo`030000oooooooo013oool0017ooomH
000000BNl;/0003Ho]D00002f?[N00?HIbT0003Lh=T01McPf@060000e=[Le85_e85_0000dLG?9`00
00Vd[=0200000jjKa@030000Y9W9Y9W900jTVLT00`0009REciREc`03V9G?1iQSTP>HULl00`0008I<
PhI<P`02QXoE0P0000AmNL<00geDUWei``000008GfS500<0000RAKdRAKd00R95_@03000000260000
01coool00`000?ooooooo`0@oooo000Aoooo0`000003oln50000nLVF00;ibIH00`000>joX^joXP05
k[nR00<0003P]:WP]:T02N2dZ@030000dZR^dZR^00oBZ:h00`000<BM[lBM[`0Ca9f_00<0002gT[2g
T[003[NB/0L000000mQW:@000=QW:@0300001=b7K0030000e85_e85_00;DPFl6000000C6YKP0002m
WKP00003]iRh00<0002dUKNdUKL00kBE]`800003]iFd00<0002nVK8000000/FN/@060000c:B`0000
eJ^^0000h;BZ0P000003n/VD0000000000^dNY<2000000>^P:<0002TLi`03ZAcW0030000V6>BV6>B
00fHHi800`0008I<PhI<P`05QTb30P0000=mE9H00`0005lbPUlbPP07Gc:200<0000R05LR05L00R80
E`@0000Koooo00<0003oooooool04?ooo`004Oooo`<000000oo?Q@000?W9UP02nLVF00<0003^_j;^
_j801NjoXP030000h;BYh;BY00WP]:T00`000=:X[]:X[P0?dZR^00<00034WJo4WJl04lBM[`030000
]i:`]i:`00fgT[001@00097X[@0000000=Sne@0400000mQW:@040000eVLe000000000]b7K0030000
e85_e85_00?DPFl4000000?4[<400000000010000003]iRh0000]9Fg00>dUKL00`000;:C]`000003
]iFd00<0002nVK8000000/FN/@060000c:B`0000eJ^^0000h;BZ0P000003n/VD0000000000fdNY<2
00003jAcW0030000V6>BV6>B00bHHi800`0008I<PhI<P`08QTb30P000003OEBF0000Gc:200MO<X80
0`000280Eb80E`028P1G0`000003oooo0000oooo01[oool00`000?ooooooo`0@oooo000Aoooo1@00
00?ibIH00`000>joX^joXP05k[nR00<0003P]:WP]:T02N2dZ@030000dZR^dZR^00oBZ:h00`000<BM
[lBM[`0Ca9f_00<0002gT[2gT[003;NB/0@00002f?kE0P000006hnOD000000000000f6LY00000mIW
=@<00004e85_0`000003bko>00000000008000001;bS`0000;JM_kJM_`@00002]9Fg00@0002bTkNb
TkL00002]iFd00<0002nVK:nVK801`000004h;BZ00000000n/VD0P0000bdNY<00`000:]]Rj]]R`02
00003:AcW0030000V6>BV6>B00bHHi800`0008I<PhI<P`0;QTb30P0000QO<X800`000280Eb80E`02
8P1G1000000300260000oooo01Woool00`000?ooooooo`0@oooo000Aoooo0`000003ol^000000000
00;ibIH00`000>joX^joXP05k[nR00<0003P]:WP]:T02N2dZ@030000dZR^dZR^00oBZ:h00`000<BM
[lBM[`0Ca9f_00<0002gT[2gT[002kNB/0070000_oN^0000dOo60000f?kE000000CSim@500001=IW
=@030000e85_e85_00<000001lkJhP00000000000<6ab`000;VXb00300000[JM_`030000/IRm/IRm
00800003/Y>g00<0002gUK@0000010000005a9V/0000c9nY0000eJJV00L0000;]7ZC00<0002[KH^[
KH/00j]]R`800009Y7>L00<0002HHi:HHi803IQSTP030000QTb3QTb300Z6C8<00`0006TWJ6TWJ002
00001ElbPP0300008P1G8P1G008R05L300000R95_@80000Joooo00<0003oooooool04?ooo`004Ooo
o`D000001?[5S`000000000000O^_j800`000>2dZN2dZ@09h;BY00<0003BZ:kBZ:h03m:X[P030000
a9f_a9f_01?4WJl00`000;NB/;NB/00:]i:`00@0002omjh0003AolH400001N?We0030000g>3I0000
00T000000kgMl00000000002000000>k]]@0000000000[VXb0030000/Z36000000800002/IRm00<0
002^U;`000000k:C]`0=0000]Y6a]Y6a0000_IF^0000a9V/0000c9nY0000eJJV0000h:jR00800000
0o[5S0000000000:]7ZC00<0002[KH^[KH/01Z]]R`800006Y7>L00<0002HHi:HHi803IQSTP030000
QTb3QTb300Z6C8<00`0006TWJ6TWJ003JBMX0P0000=O<X800`000280Eb80E`028P1G0`00008RAKd0
0`000000QP00000Ioooo00<0003oooooool04?ooo`004_ooo`@00003n/F?0P0000K^_j800`000>2d
ZN2dZ@09h;BY00<0003BZ:kBZ:h03m:X[P030000a9f_a9f_01?4WJl00`000;NB/;NB/009]i:`00@0
002omjh0003AolH2000000?Zl<h0003Sim@01N?We0030000g>3I000000d000001;>jgP0000000;B/
d0<00002/Z3600@0002^V/@000000003[YBl0100002bTkL0002`Sk@0002fTK40002mUJh00034VJ`0
003<WjT0003EYZH0003P[Z82000000?jaH`0000000002KAjT`030000Zff;Zff;00V[KH/200001:Ac
W0030000V6>BV6>B00bHHi800`0008I<PhI<P`0:QTb300<0001Y9fQY9fP01VTWJ0<000048P1G0`00
00@RAKd00`00QP000?ooo`0Hoooo00<0003oooooool04?ooo`004_ooo`8000000oo8N@000?[5S`02
n/F?00<0003_^iX000000P0000?^_j800`000>2dZN2dZ@09h;BY00<0003BZ:kBZ:h03m:X[P030000
a9f_a9f_01?4WJl00`000;NB/;NB/009]i:`100000?Zl<h00`000>?We>?We003hnOD0`0000?Ibl/3
000000=N/o`0002<a?X00P0000>U^nT01@000:f_fJf_fJf_f@000002[ZC=0`0000:^V/@200000jjD
_0050000/8nd/8nd0000]Y6a00`000000o[5S00000000008]7ZC00<0002[KH^[KH/03:]]R`800000
0jAcW00009QSTP0=V6>B00<00026C8>6C8<02hI<P`030000JBMXJBMX00QY9fP200000b80E`<00004
8TFm00<0000008H000005oooo`030000oooooooo017oool001;oool500000_[5S`030000kk^Jkk^J
00;_^iX2000000?^_j80003P]:T02^2dZ@030000dZR^dZR^00oBZ:h00`000<BM[lBM[`0Ca9f_00<0
002gT[2gT[002;NB/0<000000nch`@000>[`cP02j_3>00<0003SimCSim@00^?We0800006fL_;1P00
0004Sk[c00000000YK_Y0`000007[JoI000000000000[ZC=0000Z9g:00800002ZIG100H0002^U;`0
002[SkP0002`Sk@2000000ZcRZ/000000032TZ@0003;V:40003EWid0003QZ9T500001kAjT`030000
Zff;Zff;00n[KH/00`0009QSTYQSTP0<V6>B00<00026C8>6C8<02hI<P`030000JBMXJBMX00QY9fP0
0`000300<300<002000000@R05L00000000000058TFm00<008H0003oool05_ooo`030000oooooooo
017oool001;oool4000000Ck`HH0003jaHl00006kk^J100000WP]:T00`000=:X[]:X[P0?dZR^00<0
0034WJo4WJl04lBM[`030000]i:`]i:`00NgT[0200000^ch`@050000j_3>j_3>j_3>000000?Sim@2
000000?Sd/H0003Ibl/01]W;b`X00002XK7S0P0000:WY]D200000ZRMbP<000000jVE`@000:^?^002
Zhnh00<0002/R:l000000[>:Z`L000001>6XV@0000000?^oP@800006]7ZC00<0002[KH^[KH/03j]]
R`040000We]o000000002iQSTP030000QTb3QTb300^6C8<00`0006TWJ6TWJ008JBMX00<0000`030`
03000c00<0@000058TFm00<0000008H000005_ooo`030000oooooooo017oool001;oool020000?^l
F00000000?_1QP000?[5S`0000O_^iX00`000>6^XN6^X@0400001N2dZ@030000dZR^dZR^00oBZ:h0
0`000<BM[lBM[`0Ca9f_00<0002gT[2gT[001[NB/0030000hORW000000;/n<401P000>[`c^[`c^[`
cP000>?We0800003hm;600<0003Ibl_Ibl/01mW;b`L000000hj`k@0000000002W:SN0P0000:RWm82
00000j>Fa`050000YHjm00000000Zhnh008000000jb8[`0000000002000000?0R9T0003:SiD01@00
0003nkn10000000000FdNY<00`000:]]Rj]]R`0?Zff;00<0002OFgnOFgl00YmKO`800008V6>B00<0
0026C8>6C8<02hI<P`030000JBMXJBMX00QY9fP00`000300<300<003<00`0`00009OJ<D00`000295
_B95_@028TFm00<0000008H000005_ooo`030000oooooooo017oool001;oool010000?^lF0000000
00;k`HH200001nnkVP030000hJjQhJjQ00CQ[Z44000000?P]:T0003BZ:h04=:X[P030000a9f_a9f_
01?4WJl00`000;NB/;NB/005]i:`0`0000;/n<4010000>[`c^[`c^[`cP<00005hm;600<0003Ibl_I
bl/01mW;b`070000ZHJ`00000000:Hk^0000K:We0080000018^Xj000000009bXgP<000001J:OdP00
000000000:>Fa`03000000NUS[d0002VQ[<0002/R:l0002^Oj400P000003`8RI0000bXnE00800000
1>:QR`0000000?^oP@800004]7ZC00<0002[KH^[KH/03Z]]R`800007We]o00<0002HHi:HHi801IQS
TP030000QTb3QTb300Z6C8<00`0006TWJ6TWJ008JBMX00<0000`030`03000c00<0<00003GfS500<0
000RAKdRAKd00b95_@8008H00`000?ooooooo`0Coooo00<0003oooooool04Oooo`004_ooo`D00002
nl6600<0003_^i[_^iX01NnkVP030000hJjQhJjQ00SQ[Z4600003M:X[P030000a9f_a9f_01?4WJl0
0`000;NB/;NB/005]i:`00<0003Qn:L000000^ch`@050000j_3>j_3>j_3>000000OSd/H00`000=W;
bmW;b`07fL_;1`00009/Xo82000000>;Z>P0002GX=/00YNPf`050000W9S?W9S?W9S?000000>NSl@0
100009j6^@000:J6/`8000000jioX@000000000=000000>dNY<0002[KH/03j]]R`030000We]oWe]o
00ROFgl2000019QSTP030000QTb3QTb300Z6C8<00`0006TWJ6TWJ008JBMX00<0000`030`03000c00
<0<00005GfS500<0000RAKdRAKd00R95_@0300000026000001Goool00`000?ooooooo`0Aoooo000B
oooo1@0000;k`HH300001NnkVP030000hJjQhJjQ00WQ[Z400`000=:RY=:RY002dZ:T2@0000CBZ:h0
0`000<BM[lBM[`0Ca9f_00<0002gT[2gT[001;NB/0<00002k?S100<0003Zl<kZl<h00`0000OSd/H0
0`000=W;bmW;b`07fL_;00<0003<]<?<]<<00/bd``@0000016bSlP00000008JQi@8000001INPf`00
0000000009bHc`03000000JNSl@00000002NQ[T0002NNj`2000000>WKi<0000000000`000005eX]n
000000000000o;Ub00800002^G5o00<0002[KH^[KH/03Z]]R`030000We]oWe]o00^OFgl2000000>H
Hi800026C8<02hI<P`030000JBMXJBMX00QY9fP00`000300<300<003<00`0`0000IOJ<D00`000295
_B95_@028TFm00@0000008H008H0000Doooo00<0003oooooool04Oooo`004_ooo`@000001?bmN`00
0?_1QP0000;`]Y001@000>nkV^nkV^nkVP00000<hJjQ00<0003BXZCBXZ@02m:RY0X0000@a9f_00<0
002gT[2gT[001;NB/0030000hORW000000;/n<400`000>[`cP000002kM_000<0003Sd/KSd/H01N?B
aP030000fL_;fL_;00GIbl/300001/bd``@000001FRLkP00000008JQi@000003TIWG00D0002FT<^F
T<^FT</000000YN6_`070000UWZb00000000WFbI0000V59i00P000001_biLP0000000;UaO`000;1S
M@80000=Zff;00<0002OFgnOFgl03YmKO`030000QTb3QTb300Z6C8<00`0006TWJ6TWJ008JBMX00<0
000`030`03000c00<0<00008GfS500<0000RAKdRAKd01@0001Coool00`000?ooooooo`0Aoooo000C
oooo0`0000;l_G/200000o2fT0040000kk^Jkk^J00003>6^X@030000dZ:TdZ:T00oBXZ@00`000<FF
Y/FFYP03aIJV2`0000G4WJl00`000;NB/;NB/003]i:`0`0000;/n<4300000ngK`0030000hm;6hm;6
00GSd/H00`000=W;bmW;b`03fL_;0P0000?D^;h00`000<bd`lbd``05c;C310000003J9c^00000000
008000001I6Ie`000000000009J@b`02000000NGQ[l0002FN[80002BJIl0002:CH402@000004o;Ub
0000000000001;1SM@80000:Zff;00<0002OFgnOFgl03YmKO`040000ST=[000000002XI<P`030000
JBMXJBMX00MY9fP00`000300<300<003<00`100000MOJ<D400000QHNV@030000001I000001Coool0
0`000?ooooooo`0Aoooo000Coooo0P000003o;U]0000o;ek00800004l;J@0`0000cQ[Z400`000=:R
Y=:RY00?dZ:T00<00035UZK5UZH03/FFYP`000001N7hY`000>ch`Nch`@000005kM_000<0003Sd/KS
d/H01N?BaP030000fL_;fL_;00;Ibl/00`000=Bh_]Bh_P03e;Rn00<0003<]<?<]<<01lbd``070000
:hS/00000000HiK[0000PIWQ00800002RY7D0P000003SHK70000000000L00003Gd>I1`0000N`HgD0
0`000:]]Rj]]R`05Zff;0P0000nOFgl2000018i3J`800007QTb300<0001Y9fQY9fP01fTWJ0030000
<00`<00`00<`030300000Wei``030000GfS5GfS5009OJ<D2000000=CBjX0000F7YT00aHNV@030000
001I000001Coool00`000?ooooooo`0Aoooo000Coooo0P000005o;U]0000o;eko;ek000000K`]Y02
00002n6^X@030000dZ:TdZ:T00oBXZ@00`000<FFY/FFYP0CaIJV00<0002gRZJgRZH00[N:YP<00000
1>ch`@000000000000G]fl000`000>?Ba^?BaP05hm;600<0003Ibl_Ibl/00P0000KD^;h00`000<bd
`lbd``09c;C300<0000WPnX000000V>Fj`040000NI7N000000000X67d0070000PG[2PG[20000NfN`
K4ND000000:nHf800`0005m3VEm3V@02Gd>I0P000004l9A60000000000002;1SM@800004Zff;00<0
002OFgnOFgl03YmKO`030000ST=[ST=[00J>@f/2000018I<P`030000JBMXJBMX00MY9fP00`000300
<300<003<00`0`0000=mNL<00`0005mXaEmXa@0200000e=;ZP0300005QjI5QjI008F7YT00`000000
F@00000Coooo00<0003oooooool04_ooo`004oooo`060000mj]30000o;U]0000o;ek0P0000G`]Y00
10000>>XU`00000000SQ[Z400`000=:RY=:RY00@dZ:T00<00035UZK5UZH04lFFYP030000]hZV]hZV
00:gRZH010000>7hY`00000000;gi[@00`000>gK`>gK`003kM_000<0003Sd/KSd/H01N?BaP<00009
e;Rn00<0003<]<?<]<<02<bd``05Ug2T000000009h?ZHiK[008000000gVAgP0000000003000000>1
N/80000000000P0000>nHf85Gd>I1@0000Z`HgD2000000>[KH/0002OFgl03imKO`030000ST=[ST=[
00V>@f/2000000>6C8<0001Y9fP026TWJ0030000<00`<00`00<`0303000017ei``<00005Dd^Z00<0
000F7YTF7YT00QHNV@030000001I000001?oool00`000?ooooooo`0Boooo000Coooo00T0003gZd<0
003l^Fd0003l_G/0003c/H@000001?2fT0040000hjRGhjRGhjRG0P0000KQ[Z400`000=:RY=:RY00@
dZ:T00<00035UZK5UZH04lFFYP040000]hZV]hZV]hZV0`0000?gi[@00`000>gK`>gK`003kM_000<0
003Sd/KSd/H01^?BaP030000e;Rne;Rn00WD^;h00`000<bd`lbd``09c;C30YM`Y00600009h?Z0000
0000FhkX00000Vj7f`030000LW[<000000@00003_V=R15m3V@H0000</6=e0P0000jOFgl200003Xi3
J`800008JBMX00<0000`030`03000c00<0<00003OGW30P000003Lf6_0000Dd^Z00ICBjX00`0001HN
VAHNV@025QjI00<0000005T000004_ooo`030000oooooooo01;oool001?oool4000000?l^Fd0003c
/H@00_>aQ0050000l;J@l;J@l;J@000000GSZ9L200001>6^X@030000dZ:TdZ:T013BXZ@00`000<FF
Y/FFYP0CaIJV00L0002gRZJgRZJgRZH0003gk9L000000oOV]0030000kM_0kM_000?]fl000`000>?B
a^?BaP04hm;60`0000_D^;h00`000<bd`lbd``07c;C30YM`Y004c;C3Ug2TUg2TUg2T2@000004G6O5
0000000000000kiSHP9O@iT2000000=G=8`0000L1WP00`0000Z`HgD200000ZEAIP80000;We]o00<0
002>@f^>@f/038i3J`800002La]:0P0000EY9fP00`000300<300<003<00`0`00009mNL<200000g=Q
[`030000Dd^ZDd^Z00ECBjX00`0001HNVAHNV@025QjI00<0000005T000004_ooo`030000oooooooo
01;oool001?oool4000000?l^Fd0003c/H@00o>aQ0040000l;J@l;J@00001n>XU`800002hJjQ00<0
003BXZCBXZ@04=:RY0030000aIJVaIJV01?5UZH00`000;N:Y[N:YP02000000?gk9L0003gi[@00_OV
]0030000kM_0kM_000?]fl000`000>?Ba^?BaP03hm;600@0003N_[SN_[P0000<e;Rn00<0003<]<?<
]<<01Lbd``FGL:@01<bd`iM`Y9M`Y9M`Y0<0000014n4i@0005ijeeije`@00002_V=R0`0000=G=8`0
0`0001`6N000000200002;1SM@800006YE5V0P0000ROFgl00`0008i3Jhi3J`0;ST=[0P0000Ic6dX2
00000VTWJ0030000<00`<00`00<`0303000000=mNL<0000000001W=Q[`030000Dd^ZDd^Z00ACBjX0
0`0001HNVAHNV@025QjI00<0000005T000004_ooo`030000oooooooo01;oool001Coool2000000Ck
/eX0000000000004lk6400<0003`]Y0000002N>XU`<0000AdZ:T00<00035UZK5UZH05<FFYP060000
]hZV]hZV0000mnbG00001?OV]0030000kM_0kM_000?]fl0010000>?Ba^?Ba^?BaP800004g[jh00<0
003D^;kD^;h02MBh_P030000c;C3c;C300G<]<<6Ug2T00G5Y;NGL:BGL:BGL:@0@j`02@000003_V=R
0000000000:eEEH3EcB<00<0000L1WP000000P0000N`HgD00`000:EAIZEAIP08YE5V0P0000BOFgl2
00003Hi3J`030000La]:La]:00Qc6dX300001300<0D00008Lf6_00<0001CBjYCBjX015=;ZP030000
5QjI5QjI008F7YT00`000000F@00000Boooo00<0003oooooool04_ooo`005?ooo`030000mj]30000
00<00005lk640P0000_SZ9L200004=:RY0030000aIJVaIJV01C5UZH01P000;N:YP0000000?O/U`00
00?gi[@00`000>gK`>gK`004kM_000@0003Sd/KSd/H00006g[jh00<0003D^;kD^;h02MBh_P030000
c;C3c;C300C<]<<=Ug2T0`000004?GOP000000005dS40`0000BeEEH00eLdS;EEEP00000270Ih0P00
00F`HgD200003JEAIP8000000imKO`0008i3J`0<ST=[0P0000Yc6dX200000Sh0208000000c00<000
0000000200002W=Q[`030000Dd^ZDd^Z00ACBjX00`0001HNVAHNV@025QjI00<0000005T000004Ooo
o`030000oooooooo01?oool001Coool3000000Ck/eX0003e[7<00005lk6400<0003SZ9OSZ9L02N>X
U`030000e9^J000000<0000<dZ:T00<00035UZK5UZH04lFFYP030000]hZV]hZV008000000oO/U`00
0?OV]002mnJd00<0003]fl3]fl001>gK`0<00007g[jh00<0003D^;kD^;h02]Bh_P030000c;C3c;C3
00?<]<<:Ug2T00>mXKbGL:BGL:@01@0000058FCH000000000000/c/Q00800002]EEF00AG=8beEEH0
000L1WP5000000>`HgD0000000004:EAIP80000<ST=[0P0000Yc6dX200001Sh020<000000hM][`00
07=Q[`09Lf6_00<0001CBjYCBjX015=;ZP0300005QjI5QjI008F7YT00`000000F@00000Aoooo00<0
003oooooool04oooo`005?ooo`<000001O^cFP000?F/LoF/L`000004lk640`0000WSZ9L00`000=BK
V]BKVP03e9^J100000SBXZ@00`000<FFY/FFYP0CaIJV00@0002gRZJgRZH00002mnbG00D0003gi[Cg
i[Cgi[@000001NgK`0800009g[jh00<0003D^;kD^;h02]Bh_P030000c;C3c;C300;<]<<>Ug2T00<0
0020GJ4000001`0000:c>b42000000BeEEIG=8`0000L1WP3000000BeEEH000000000000?YE5V0P00
00:E=dh200002Hi3J`030000La]:La]:00Uc6dX00`0003h023h02004?P08100000>7KJl00`0007=Q
[g=Q[`08Lf6_00<0001CBjYCBjX015=;ZP0700005QjI5QjI5QjI0000001I0000017oool00`000?oo
ooooo`0Coooo000Doooo0P000006mj]3000000000000mJac00001?>aQ0040000iJ>9iJ>900002>>X
U`030000e9^Je9^J00ODViX300001M:RY0030000aIJVaIJV01?5UZH010000;N:Y[N:YP0000;gk9L0
1@000?OV]?OV]?OV]0000003kM_00P000003jLF`0000g[jh00SN_[P00`000=Bh_]Bh_P0:e;Rn00D0
003<]<?<]<?<]<<000003IM`Y0<00003NU6D1P0000>c>b44000000@;06L0000000000003ZD530P00
00ZUDFH300001YDgCP800005ST=[0P0000Yc6dX200001Ch020D00004Qff_00<0001cHJmcHJl027=Q
[`030000Dd^ZDd^Z00ACBjX01`0001HNVAHNVAHNV@000000F@00000Aoooo00<0003oooooool04ooo
o`005?ooo`8000001?N[@`000?JUG00000;e[7<01@000?>aQ?>aQ?>aQ0000003iJ>900<0003SZ9OS
Z9L01N>XU`030000e9^Je9^J00[DViX4000000?BXZ@00035UZH05<FFYP060000]hZV00000000mnbG
00000oOV]0030000kM_0kM_000800003jLF`00<0003N_[SN_[P01mjn^0030000e;Rne;Rn00_D^;h4
00002IM`Y0@000000i=TV@0007YAU005NU6D00<00000FM0000001@000003EcB<00002`1W00<00006
ZD530P0000JUDFH200002iDgCP8000000hi3J`000000000;La]:00<0000n00Pn00P00ch020D00006
Qff_00<0001cHJmcHJl027=Q[`030000Dd^ZDd^Z00ACBjX00`0001HNVAHNV@025QjI00<0000005T0
00004?ooo`030000oooooooo01?oool001Goool4000000OfYE`0003e[7?e[7<0003c/H@000001NFS
R@800005hjRG00<0003DVi[DViX03]BKVPD0000BaIJV00<0002gRZH000000_O/U`040000mnJdmnJd
mnJd0`0000GYaK000`000=jn^=jn^008g[jh00<0003D^;kD^;h02]Bh_P040000aJBgZ7jV00001IM`
Y0@00005TfBI00<0001jDIAjDI@01WYAU003000004>o000000800003YbL=00@;06L0000000000008
ZD530P0000:UDFH200003YDgCP80000;La]:0P0000@n00P5000028M][`030000Lf6_Lf6_00QcHJl0
0`0005=;ZU=;ZP04Dd^Z00<0000F7YTF7YT00QHNV@030000001I000000ooool00`000?ooooooo`0D
oooo000Eoooo0P000004liTk0000mZEL00000oF/L`800007iJ>900<0003SZ9OSZ9L00^>XU`030000
e9^Je9^J00oDViX010000<F>VlF>VlF>V`P0000:aIJV00<0002gRZH000000_O/U`050000mnJdmnJd
mnJd000000OYaK000`000=jn^=jn^008g[jh00<0003D^;kD^;h02=Bh_P<00002Z7jV00<0002GL:@0
00000`0000VCI9T00`0007YAU7YAU007NU6D1P0000:W9`d300002:U1@`<0000?UCM>0P00009l3RH2
00001g<KBP800004?P081@0000^7KJl00`0007=Q[g=Q[`07Lf6_00<0001CBjYCBjX015=;ZP030000
5QjI5QjI008F7YT00`000000F@00000?oooo00<0003oooooool05?ooo`005Oooo`<000001?>I>`00
0?JUG00000;e[7<200002>FSR@050000hjRGhjRGhjRG0000017DViX00`000<F>VlF>V`09aHjK1`00
00?5UZH300000_O/U`030000mnJdmnJd00800008jLF`00<0003N_[SN_[P01mjn^0030000e;Rne;Rn
00KD^;h200000ljW/@@0000=TfBI00<0001jDIAjDI@01gYAU0030000EcB<000000H000000`00:`00
00000003ZD53100000>J9RL200002YDgCP<00006O0hV00<0001c6dYc6dX00g<KBP030000?P08?P08
008n00P5000000>EMZd00027KJl02XM][`030000Lf6_Lf6_00QcHJl00`0005=;ZU=;ZP03Dd^Z00<0
000F7YTF7YT00QHNV@030000001I000000ooool00`000?ooooooo`0Doooo000Foooo0P000004liTk
0000mZEL00000oF/L`030000iJ>9iJ>900OUXhT2000000?SZ9L0003DViX04=BKVP030000aHjKaHjK
0135SY/500000_O/U`060000mnJd00000000mljR00002>W5/0030000g[jhg[jh00ON_[P00`000=Bh
_]Bh_P04e;Rn0P0000G>Yk42YWBK00<0002CI9VCI9T039=TV@030000NU6DNU6D00MjDI@0100005Ld
S00004PPN`@000000`00C`000000000400002IXV9`800006UCM>0P0000Yl3RH2000000=c6dX00000
00000ch020D00003UGJ]00<00027KJn7KJl02HM][`030000Lf6_Lf6_00QcHJl00`0005=;ZU=;ZP04
Dd^Z00L0000F7YTF7YTF7YT0000005T000003_ooo`030000oooooooo01Goool001Koool3000000Cc
VC/0003fYE`00002mJac0P0000[UXhT200004MBKVP030000aHjKaHjK01?5SY/200000_O/U`800003
mljR00<0003YaK3YaK001^W5/0030000g[jhg[jh00ON_[P00`000=Bh_]Bh_P03e;Rn00<0003>Yk7>
Yk401<jW/@>VM9/00`0009=TVI=TV@0<TfBI00<0001jDIAjDI@01gYAU0800004B21k1@0000:_Sk@2
00002iXV9`800002UCM>0P0000al3RH400000Sh020D00005UGJ]00<00027KJn7KJl02HM][`030000
Lf6_Lf6_00QcHJl00`0005=;ZU=;ZP04Dd^Z00L0000F7YTF7YTF7YT0000005T000003_ooo`030000
oooooooo01Goool001Koool01`000?ooo`000?>I>`000?JUG0000002mJac00<0003XW7L000002^FS
R@80000@e9^J00<00035SY_5SY/04lF>V`8000000oO/U`0000000004mljR00<0003YaK3YaK001^W5
/0030000g[jhg[jh00SN_[P00`000=Bh_]Bh_P0200001/jW/@BVM9/00`0009=TVI=TV@0<TfBI00<0
001jDIAjDI@01gYAU0030000B21kB21k00=887/010/0I`00000000001`@000000jn?]00000000006
VRHW1`0000Ul3RH5000014`000D00008UGJ]00<00027KJn7KJl02HM][`030000Lf6_Lf6_00McHJl0
0`0005=;ZU=;ZP04Dd^Z00L0000F7YTF7YTF7YT0000005T000003_ooo`030000oooooooo01Goool0
01Koool01`000?ooo`0000000?>I>`000?JUG00200000nRLM`030000iJ>9iJ>900OUXhT010000=JC
S000000000kDViX00`000<F>VlF>V`0CaHjK0`000003omB10000mljR00?gcZ800`000>W5/>W5/006
jLF`00<0003N_[SN_[P02=jn^0<00008cZNa1:IdV`030000TfBITfBI00bCI9T00`0007YAU7YAU005
NU6D0`0000E887/00`000000C`000002000000=S0000000000002@0000N1000200000g`>9P@00005
C0001`0000ZEMZd00`0008M][hM][`09Qff_00<0001cHJmcHJl01g=Q[`030000Dd^ZDd^Z00ACBjX0
1`0001HNVAHNVAHNV@000000F@00000>oooo00<0003oooooool05Oooo`005oooo`060000oooo0000
liTk0000mZEL0P0000CXW7L00`000>FSRNFSR@06iJ>900@0003FThcFThcFTh`200003=BKVP030000
aHjKaHjK01?5SY/01@000?oDPOoDPOoDP@000004mljR00<0003YaK3YaK001^W5/0030000g[jhg[jh
00SN_[P00`000<jW/LjW/@07cZNa1JIdV`030000TfBITfBI00bCI9T00`0007YAU7YAU003NU6D0P00
009`?hD00`0004PPNdPPN`03B21k10000003]i:`0000000000800002G`00100000J10006000024`0
00L0000=UGJ]00<00027KJn7KJl02HM][`030000Lf6_Lf6_00QcHJl00`0005=;ZU=;ZP03Dd^Z00<0
000F7YTF7YT00QHNV@8005T00`000?ooooooo`0:oooo00<0003oooooool05_ooo`005oooo`080000
oooo00000000liTk0000mZEL00001NRLM`800006iJ>900<0003FThcFTh`00mJCS080000:e9^J00<0
0035SY_5SY/04lF>V`050000omB1omB1omB1000000CgcZ800`000>W5/>W5/006jLF`00<0003N_[SN
_[P01]jn^0<00008cZNa1ZIdV`030000TfBITfBI00bCI9T00`0007YAU7YAU002NU6D00<0001`?hE`
?hD00W0oQ@030000B21kB21k009887/5000000BgT[00002_SkB_Sk@=00001UP000800002C0001P00
0004Yhbh0000000000003iEf[@030000Qff_Qff_00V7KJl00`0007=Q[g=Q[`07Lf6_00<0001CBjYC
BjX00e=;ZP0300005QjI5QjI008F7YT2001I00<0003oooooool02_ooo`030000oooooooo01Koool0
01Ooool01`000?ooo`0000000?>I>`000?JUG00200001^RLM`030000iJ>9iJ>900?UXhT00`000=JC
S=JCS005eY><0`0000ODViX00`000<F>VlF>V`0CaHjK00D0003oe87oe87oe84000001?O>XP030000
jLF`jLF`00KYaK000`000=jn^=jn^004g[jh0P0000?GZjX00`000<jW/LjW/@05cZNa1ZIdV`030000
TfBITfBI00bCI9T00`0007YAU7YAU00200001G0oQ@060000B21kB21kB21k0000<@9S100000:gT[00
0`000:n?]:n?]005[hnd4P0000BWS;P200000imkZ`030000UGJ]UGJ]00bEMZd00`0008M][hM][`09
Qff_00<0001cHJmcHJl01g=Q[`030000Dd^ZDd^Z00ACBjX0100001HNVAHNVAHNV@8005T00`000?oo
ooooo`0:oooo00<0003oooooool05_ooo`006?ooo`050000oooo00000000liTk008000000n^BG@00
0>RLM`05j9ag00D0003UXhWUXhWUXhT000002mJCS0800005e9^J00<00035SY_5SY/04lF>V`050000
omB1omB1omB1000000CgcZ800`000>W5/>W5/007jLF`00<0003N_[SN_[P00]jn^0030000ej^Zej^Z
00?GZjX00`000<jW/LjW/@05cZNa1ZIdV`030000TfBITfBI00bCI9T300001g0oQ@040000B21kB21k
00000S42H`040000000`000000000[NB/0030000[hnd[hnd00n_Sk@00`000:N<^:N<^008Yhbh00<0
002ONj^ONj/00imkZ`030000UGJ]UGJ]00bEMZd00`0008M][hM][`09Qff_00<0001cHJmcHJl01g=Q
[`030000Dd^ZDd^Z00ACBjX00`0001HNV@00000400002oooo`030000oooooooo01Ooool001Soool0
1@000?ooo`0000000?>I>`0200000^^BG@030000j9agj9ag00CXW7L010000>FSRNFSR@0000gFTh`2
00000mBKVP030000aHjKaHjK01?5SY/01@000?oDPOoDPOoDP@000005mljR00<0003YaK3YaK001^W5
/0030000g[jhg[jh00800007ej^Z00<0003>Yk7>Yk400ljW/@NVM9/00`0009=TVI=TV@0;TfBI0P00
00U`?hD01@0004PPNdPPN`000342H`03000000<000P0002gT[000[NB/0030000[hnd[hnd00n_Sk@0
0`000:N<^:N<^005Yhbh0P0000NONj/00`0009Ef[IEf[@0;UGJ]00<00027KJn7KJl02HM][`030000
Lf6_Lf6_00QcHJl00`0005=;ZU=;ZP02Dd^Z0`00008=06l00`000000;@00000;oooo00<0003ooooo
ool05oooo`006?ooo`030000oooooooo008000000o>I>`000>^BG@02ji9M00<0003XW7OXW7L01>RL
M`030000iJ>9000000oFTh`2000000?DViX00035SY/05<F>V`050000omB1omB1omB1000000GgcZ80
0`000>W5/>W5/006jLF`0`0000WGZjX00`000<jW/LjW/@02cZNa2:IdV`030000TfBITfBI00RCI9T3
000000><EHT0001`?hD0270oQ@030000B21k0000008a0V<01@000000<000000020000003]i:`00<0
002_SkB_Sk@03jn?]0030000YhbhYhbh00BWS;P00`0009mkZimkZ`07Wg^[00<0002EMZfEMZd039Ef
[@030000Qff_Qff_00V7KJl00`0007=Q[g=Q[`07Lf6_00<0001CBjX000000P000003Ab^;00003@1_
008=06l00`000000;@00000;oooo00<0003oooooool05oooo`006Oooo`050000oooo00000000liTk
00800003ji9M00<0003XW7OXW7L01>RLM`80000AeY><100001?5SY/01@000?oDPOoDPOoDP@000005
mljR00<0003YaK3YaK001^W5/0030000ej^Zej^Z00WGZjX010000<jW/LjW/LjW/@VVM9/00`0009=T
VI=TV@05TfBI0`0000B<EHT00`00070oQG0oQ@07L3n50P0000<a0V<010000000<000000000FgT[00
0`000:n?]:n?]00?[hnd00@0002WS;RWS;RWS;P200002imkZ`030000UGJ]UGJ]00^EMZd00`0008M]
[hM][`09Qff_00<0001cHJmcHJl01W=Q[`<00004Ab^;00L0000=06l=06l=06l0000002d000002_oo
o`030000oooooooo01Soool001Woool00`000?ooooooo`0200000^R0<PC[TUd00`000>RLMnRLM`04
j9ag00<0003FThcFTh`04=JCS0030000aHF=aHF=00@0000?aHjK00D0003oe87oe87oe84000001OO>
XP030000jLF`jLF`00CYaK0300003=N[ZP030000cZNacZNa00VVM9/00`0009=TVI=TV@02TfBI0`00
00N<EHT00`00070oQG0oQ@07L3n500@0000a0V<a0V<a0V<3000000<000P0002gT[001KNB/0030000
[hnd[hnd00j_Sk@010000:N<^000000000fONj/00`0009Ef[IEf[@0;UGJ]00<00027KJn7KJl02HM]
[`030000Lf6_Lf6_00AcHJl2000000=XAYH00017:h/014L[R`0600003@1_3@1_0000000]00002ooo
o`030000oooooooo01Soool001Woool020000?ooooooo`000=9N00000>R0<P0000?[TUd00`000>RL
MnRLM`04j9ag0`00013FTh`00`000<F5SLF5S@04aHF=1@0000[5SY/01@000?oDPOoDPOoDP@000005
mljR00<0003YaK3YaK000nW5/0050000hZnPhZnPhZnP000000_GZjX00`000<jW/JIdV`09YWBK00<0
002CI9T000000P0000Z<EHT00`00070oQG0oQ@05L3n50`0000<a0V<3000000<000P0002gT[001KNB
/0030000[hnd[hnd00j_Sk@200003imkZ`030000UGJ]UGJ]00bEMZd00`0008M][hM][`08Qff_00<0
001cHJmcHJl00W=Q[`800003J4JF00<00017:h]7:h/00TL[R`0700003@1_3@1_3@1_0000000]0000
00_oool00`000?ooooooo`0Hoooo000Joooo00D0003oooooool0003BGP000^R0<P050000ji9Mji9M
ji9M000000GXW7L00`000=R:NMR:N@0200003]JCS0030000aHF=aHF=00W5QHd400001/F>V`050000
omB1omB1omB1000000GgcZ8010000>W5/>W5/>W5/0800004hZnP00<0003GZj[GZjX02]N[ZP030000
YWBKYWBK00>VM9/700003HaER@030000L3n5L3n500A`?hD0100005lTKUlTKP00008a0V<01@0000/0
?`00000020000008]i:`00<0002_SkB_Sk@02jn?]08000000jQoY`0009mkZ`0?Wg^[00<0002EMZfE
MZd02iEf[@030000Qff_Qff_00V7KJl0100007=Q[`00000000EXAYH00`0004L[RdL[R`02Ab^;00L0
000=06l=06l=06l0000002d000002_ooo`030000oooooooo01Woool001[oool01P000?ooooooo`00
0=9N000000;XP3801@000>^BGN^BGN^BG@000004j9ag00<0003HRWWHRWT00]R:N@80000<eY><00<0
0035QHg5QHd03LF5S@@000000lF>V`0000000003omB100<0003gcZ;gcZ800oO>XP040000jLF`jLF`
00001^:_X0030000ej^Zej^Z00[GZjX600001J9VS0030000S5F9S5F900b<EHT00`00070oQG0oQ@02
L3n50P0000=O96h020000342Hc42H`0000/0?`000000200000RgT[000`000:n?]:n?]009[hnd0P00
00BXOjL00`0009mkZimkZ`0=Wg^[00<0002EMZfEMZd02iEf[@030000Qff_Qff_00R7KJl300001fQ6
UP030000Ab^;Ab^;0097:h/01`0000d0K`d0K`d0K`000000;@00000:oooo00<0003oooooool06Ooo
o`006_ooo`090000oooooooooooo0000dUh00000j80b000000C[TUd010000>RLMnRLM`0000OHRWT2
00002]JCS0030000aHF=aHF=0175QHd300000ooDP@030000mljRmljR00?gcZ8300002>:_X0030000
ej^Zej^Z00WGZjX;XVJ<00<0002<EHV<EHT038aER@050000L3n5L3n5L3n5000000EO96h010000342
H`0000/0?`@00009]i:`00<0002_SkB_Sk@01Zn?]0800006Z7nW00<0002ONj^ONj/03YmkZ`030000
UGJ]UGJ]00^EMZd00`0008M][hM][`05Qff_0P000003O5JJ0000J4JF00MXAYH00`0004L[RdL[R`02
Ab^;00L0000=06l=06l=06l0000002d000002_ooo`030000oooooooo01Woool001_oool010000?oo
ooooooooo`800002j80b00<0003[TUg[TUd00^^BG@030000j9ag000000WHRWT00`000=JCS=JCS006
eY><00<00035QHg5QHd04lF5S@800003omB100<0003gcZ;gcZ800oO>XP030000hZnPhZnP00SR[j00
0`000=N[Z]N[ZP08ej^Z3:9VS0030000S5F9S5F900b<EHT01000070oQG0oQ@0000IO96h200000P/0
?`0300000009000000ZgT[000`000:n?]:n?]004[hnd0P0000VXOjL00`0009mkZimkZ`0=Wg^[00<0
002EMZfEMZd02iEf[@030000Qff_Qff_00>7KJl200000gaFVP030000J4JFJ4JF00EXAYH00`0004L[
RdL[R`03Ab^;00L0000=06l=06l=06l0000002d000002Oooo`030000oooooooo01[oool001_oool0
1`000?ooooooooooo`000=9N00000002j80b00<0003[TUg[TUd00^^BG@80000:f8Yi0P0000KFTh`0
0`000<F5SLF5S@0CaHF=0P0000?oe84010000?O>X_O>X_O>XP<0000:hZnP00<0003GZj[GZjX02=N[
ZPbRIX`00`0008aERHaER@0<S5F90`0000MO96h2000000<;03l0000000T00P0000^gT[0010000:n?
]:n?]:n?]080000;Z7nW00<0002ONj^ONj/03YmkZ`030000UGJ]UGJ]00ZEMZd0100008M][hM][hM]
[`800005O5JJ00<0001XAYIXAYH01FQ6UP030000Ab^;Ab^;00=7:h/0100000d0K`d0K`d0K`80000:
oooo00<0003oooooool06_ooo`006oooo`030000oooooooo00;oool00`000=9N00000002j80b00<0
003[TUg[TUd00^^BG@030000f8Yif8Yi00[HRWT200001=JCS0030000aHF=aHF=01?5QHd200000ooD
P@040000mljRmljR00000o2cSP030000hZnPhZnP00SR[j000`000=N[Z]N[ZP06ej^Z3J9VS0030000
S5F9S5F900^<EHT200002ElTKP0600002`0o2`0o0000000900003;NB/0040000[hnd000000003ZQo
Y`030000Wg^[Wg^[00fONj/00`0009Ef[IEf[@0;UGJ]0`0000MlEYX00`0006Q6UVQ6UP05J4JF00<0
0017:h]7:h/00dL[R`0400003@1_3@1_3@1_0P0000[oool00`000?ooooooo`0Joooo000Loooo00<0
003oooooool00_ooo`800002j80b00<0003[TUg[TUd00^^BG@<0000<f8Yi0P0000;FTh`00`000<F5
SLF5S@0CaHF=0P0000?oe84300001?2cSP030000hZnPhZnP00SR[j000`000=N[Z]N[ZP05ej^Z3Z9V
S0030000S5F9S5F900V<EHT2000000>0?W<0001O96h01elTKP8000000`/0?`0000002@0200003KNB
/0030000Z7nWZ7nW00jXOjL00`0009mkZimkZ`0=Wg^[00<0002EMZfEMZd02iEf[@030000O5JJO5JJ
00MlEYX00`0006Q6UVQ6UP05J4JF00<00017:h]7:h/00dL[R`0600003@1_3@1_0000000]00002Ooo
o`030000oooooooo01_oool001coool00`000?ooooooo`02oooo00<0003BGP0000000^R0<P050000
ji9Mji9Mji9M000000;INe`00`000=R:NMR:N@0;f8Yi0`0001G5QHd200000_oDP@800006l;>>00<0
003R[j3R[j002>:_X0030000ej^Zej^Z00GGZjX=XVJ<00<0002<EHV<EHT028aER@800003P3ic00<0
001O96iO96h015lTKP8000001Sl0B@0000/0?`0000002@0000bgT[02000000>_PJ<0002XOjL03jQo
Y`030000Wg^[Wg^[00fONj/00`0009Ef[IEf[@08UGJ]0`0000UlEYX00`0006Q6UVQ6UP05J4JF00<0
0017:h]7:h/00TL[R`0700003@1_3@1_3@1_0000000]000000Woool00`000?ooooooo`0Koooo000L
oooo00<0003oooooool00oooo`030000dUh0000000;XP38010000>^BGN^BG@0000?INe`200003MR:
N@80000DaHF=100000;k/fH7l;>>00<0003R[j3R[j002>:_X0030000ej^Zej^Z00?GZjX>XVJ<00<0
002<EHV<EHT01HaER@<00005P3ic00<0001O96iO96h00elTKP040000?`19?`19?`190P0000030009
0000000000ZgT[0200000jn1X`030000Z7nWZ7nW00jXOjL00`0009mkZimkZ`0=Wg^[00<0002EMZfE
MZd01YEf[@800002Rf2K00<0001lEYYlEYX01gaFVP030000J4JFJ4JF00EXAYH00`0004L[RdL[R`02
Ab^;00L0000=06l=06l=06l0000002d000002Oooo`030000oooooooo01_oool001goool00`000?oo
ooooo`03oooo00<0003BGP0000000^R0<P800006fG]L00<0003HRWWHRWT02]R:N@030000aGQi0000
00<0000@aHF=0P0000Ck/fH00`000?2cS_2cSP04l;>>00<0003R[j3R[j002>:_X0030000ej^Zej^Z
00?GZjX>XVJ<00<0002<EHV<EHT00haER@800008P3ic00<0001O96iO96h00UlTKP030000?`19?`19
008o04T400002KNB/0800006[h6S00<0002XOjNXOjL03ZQoY`030000Wg^[Wg^[00fONj/00`0009Ef
[IEf[@03UGJ]0P0000B;H9/00`0007aFVWaFVP07O5JJ00<0001XAYIXAYH01FQ6UP030000Ab^;Ab^;
0097:h/0100000d0K`d0K`d0K`800009oooo00<0003oooooool07?ooo`007Oooo`030000oooooooo
00Coool200000^R0<P800007fG]L0P0000[HRWT00`000<EhNLEhN@03aGQi100000c5QHd00`000=V;
0o^cIP03nk=V00<0003`/hk`/hh01?2cSP030000hZnPhZnP00SR[j000`000=N[Z]N[ZP02ej^Z3j9V
S0040000S5F9S5F9S5F90P0000V0?W<00`0005lTKUlTKP02GbA^00<0000o04To04T00cl0B@040000
0009000000002;NB/0030000[h6S[h6S00J_PJ<00`000:QoYjQoY`0>Z7nW00<0002ONj^ONj/03Imk
Z`040000UGJ]UGJ]UGJ]0P0000J;H9/00`0007aFVWaFVP07O5JJ00<0001XAYIXAYH01FQ6UP030000
Ab^;Ab^;0097:h/0100000d0K`d0K`d0K`800009oooo00<0003oooooool07?ooo`007_ooo`030000
oooooooo00?oool00`000=9N00000002j80b00<0003INecINe`01mUkG0030000f8Yif8Yi00OHRWT0
0`000<EhNLEhN@07aGQi0`0000W5QHd00`000=V;0`000003nk=V00<0003`/hk`/hh01O2cSP030000
hZnPhZnP00SR[j0010000=N[Z]N[Z]N[ZPnRIX`0100008aER@00000000^0?W<01@0005lTKUlTKUlT
KP000005?`191@0000JgT[0200002Zn1X`030000Z7nWZ7nW00jXOjL00`0009mkZimkZ`0=Wg^[0`00
00V;H9/00`0007aFVWaFVP06O5JJ00<0001XAYIXAYH01FQ6UP030000Ab^;Ab^;0097:h/0100000d0
K`d0K`d0K`800008oooo00<0003oooooool07Oooo`007_ooo`030000oooooooo00Coool010000=9N
00000>R0<P<00008fG]L0P0000OHRWT00`000<EhNLEhN@0:aGQi100000G5QHd300000o^cIP030000
l;>>l;>>00G`/hh00`000>:_X>:_X008hZnP00<0003GZj[GZjX03J9VS0D0000=P3ic00@0001O96h0
00000005?`1900@0000300X000000002_YB[00@0002gT[2gT[2gT[0200003:n1X`030000Z7nWZ7nW
00jXOjL00`0009mkZimkZ`0=Wg^[00<0002;H9^;H9/02H]PV`030000O5JJO5JJ00IlEYX00`0006Q6
UVQ6UP05J4JF00<00017:h]7:h/00TL[R`0600003@1_3@1_3@1_000]00002?ooo`030000oooooooo
01goool001ooool00`000?ooooooo`04oooo0`0000?DHBP00`000=UkG=UkG007fG]L00<0003HRWWH
RWT00mR:N@030000aGQiaGQi00o5N7T4000000C5QHd0000000000004nk=V00<0003`/hk`/hh01?2c
SP030000hZnPhZnP00SR[j000`000=N[ZZ9VS007XVJ<1P0000>KDgL00`00080nLh0nL`0<P3ic0P00
00Ho04T00`0000<02P<02P0200000[jDZ`040000]i:`000000003jn1X`030000Z7nWZ7nW00jXOjL0
0`0009mkZimkZ`0:Wg^[0`0000^;H9/00`0007aFVWaFVP06O5JJ00<0001XAYIXAYH01FQ6UP030000
Ab^;Ab^;0097:h/01P0000d0K`d0K`000000;@0000Ooool00`000?ooooooo`0Noooo000Ooooo00<0
003oooooool01?ooo`030000dUh0000000CDHBP00`000=UkG=UkG007fG]L0P0000?HRWT00`000<Eh
NLEhN@0CaGQi0`000003fH/3nk=Vnk=V00;k/fH00`000?2cS_2cSP05l;>>00<0003R[j3R[j002>:_
X0030000XVJ<XVJ<00H00009Ve=g00<00020?W>0?W<0380nL`030000?`19?`1900@o04T00`0000<0
2P<02P0200001;jDZ`030000[h6S[h6S00n_PJ<00`000:QoYjQoY`0>Z7nW00<0002ONj^ONj/029mk
Z`800002UFNJ00<0002;H9^;H9/02H]PV`030000O5JJO5JJ00IlEYX00`0006Q6UVQ6UP04J4JF00<0
0017:h]7:h/00TL[R`0700003@1_3@1_3@1_0000000]000000Ooool00`000?ooooooo`0Noooo000P
oooo00<0003oooooool01?ooo`030000/RX0/RX000CDHBP200002MUkG0040000f8Yif8Yi00005/Eh
N@8000000mV;0`000?^cIP02nk=V00<0003`/hk`/hh01O2cSP030000hZnPhZnP00SR[j0300003i]C
M`030000P3icP3ic00Z0?W<3000013l0B@8000020`0:0P0000>nU:/2000000>fPid0002_PJ<04:n1
X`030000Z7nWZ7nW00jXOjL00`0009mkZimkZ`05Wg^[0P0000FEIiX00`0008]PVh]PV`08Rf2K00<0
001lEYYlEYX01WaFVP030000J4JFJ4JF00AXAYH00`0004L[RdL[R`02Ab^;00@0000=06l=06l=06l2
00001oooo`030000oooooooo01ooool0023oool00`000?ooooooo`05oooo00@0002b:P2b:P000004
e64X00<0003INecINe`01mUkG0<0000FaGQi00@0002aIWT000000004nk=V00<0003`/hk`/hh01O2c
SP030000hZnPhZnP00OR[j0BVe=g00<00020?W>0?W<0280nL`800002JAQ@00D0000o04To04To04T0
00000`<02P800002_YB[0P0000>fPid00`000:n1Xjn1X`0?[h6S00<0002XOjNXOjL03ZQoY`030000
Wg^[Wg^[00BONj/00`0009EWVYEWVP05UFNJ00<0002;H9^;H9/028]PV`030000O5JJO5JJ00IlEYX0
0`0006Q6UVQ6UP04J4JF00<00017:h]7:h/00TL[R`0300003@1_000000<00007oooo00<0003ooooo
ool07oooo`008Oooo`030000oooooooo00Goool2000000>b:P00003DHBP00mAQ:0800009fG]L0P00
01G5N7T010000;5VN@00000000Ck/fH00`000?2cS_2cSP05l;>>00<0003R[j3R[j001^:_X1>KDgL0
0`00080nLh0nL`06P3ic0P0000AY6500100003l0BCl0B@0000<300X200000[jDZ`030000]X>M]X>M
00BfPid00`000:n1Xjn1X`0?[h6S00<0002XOjNXOjL03ZQoY`040000Wg^[Wg^[Wg^[0P0000REIiX0
0`0008]PVh]PV`08Rf2K00<0001lEYYlEYX01WaFVP030000J4JFJ4JF00AXAYH0100004L[RdL[RdL[
R`<000021`150P0000Koool00`000?ooooooo`0Poooo000Qoooo00<0003oooooool01oooo`030000
/RX0000000GDHBP00`000=UkG=UkG006fG]L00<00033I5X000000P0001;5N7T010000;5VN@000000
00Ck/fH00`000?2cS_2cSP05l;>>00<0003R[j3R[j001N:_X1BKDgL00`00080nLh0nL`04P3ic0P00
00IY65000`0003l0B@0000030`0:0P000003_YB[0000000000RfPid00`000:n1Xjn1X`0?[h6S00<0
002XOjNXOjL03JQoY`040000Wg^[000000002YEWVP030000Rf2KRf2K00R;H9/00`0007aFVWaFVP06
O5JJ00<0001XAYIXAYH016Q6UP060000Ab^;00000000>@UV00000PL0A@0300000009000000Koool0
0`000?ooooooo`0Poooo000Roooo00<0003oooooool01oooo`030000/RX0000000GDHBP00`000=Uk
G=UkG005fG]L00<00033I5[3I5X00/=TFP80000@aGQi00D0002aIWT0003IR`<000000o^cIP030000
l;>>l;>>00K`/hh00`000>:_X>:_X003hZnP5I]CM`030000P3icP3ic00:0?W<2000026THD0800003
0`0:0P000003_YB[0000]X>M00VfPid00`000:n1Xjn1X`0?[h6S00<0002XOjNXOjL03ZQoY`030000
UFNJUFNJ00^EIiX00`0008]PVh]PV`07Rf2K00<0001lEYYlEYX01WaFVP030000J4JFJ4JF00=XAYH3
00000ST9IP0400001`151`151`150P0000Koool00`000?ooooooo`0Qoooo000Soooo00<0003ooooo
ool01oooo`030000/RX0000000GDHBP200001MUkG0030000`fAJ`fAJ00C3I5X300003<EhN@040000
/FIi/FIi/FIi0P0000Ck/fH00`000?2cS_2cSP05l;>>00<0003R[j3R[j000^:_X080000DVe=g00<0
0020?W>0?W<00P0000YY6500100000<02P<02P<02P@0000<]X>M00<0002_PJ>_PJ<03jn1X`030000
Z7nWZ7nW00^XOjL300003IEWVP030000Rf2KRf2K00N;H9/00`0007aFVWaFVP06O5JJ00@0001XAYIX
AYIXAYH2000000=I9gL0000i2FH00ST9IP0600001`151`150000000900001Oooo`030000oooooooo
02;oool002?oool00`000?ooooooo`08oooo00@0002b:P0000000005e64X00D0003INecINecINe`0
00002/=TFP<00009aGQi00@0002aIWVaIWVaIWT200001?^cIP030000l;>>l;>>00G`/hh00`000>:_
X>:_X002000000>aIWT0002KDgL04i]CM`<0000:JAQ@0`00008300X300003kJ3W@030000[h6S[h6S
00j_PJ<00`000:QoYjQoY`09Z7nW0P0000>NK9P00`0009EWVYEWVP0:UFNJ00<0002;H9^;H9/028]P
V`030000O5JJO5JJ00ElEYX0100006Q6UP000000009I9gL00`0003T9IST9IP02>@UV00<0000704D7
04D00P0000Koool00`000?ooooooo`0Roooo000Toooo00<0003oooooool02?ooo`8000000k8Z0000
0=AQ:004e64X00@0003INecINe`0000=`fAJ0`0000K5N7T01`000;5VNK5VNK5VN@000=V;0`000003
nk=V00<0003`/hk`/hh01_2cSP800002f9R?00>aIWT0002KDgL04I]CM`<0000:JAQ@0P00008g00d0
100000<02P000000016fPid00`000:n1Xjn1X`0?[h6S00<0002XOjNXOjL01ZQoY`800005WVbH00<0
002EIiZEIiX02YEWVP030000Rf2KRf2K00R;H9/00`0007aFVWaFVP04O5JJ0`0000AI9gL01@0003T9
IST9IST9IP0000021`1500<0000000T000001Oooo`030000oooooooo02?oool002Goool00`000?oo
ooooo`09oooo00<0002b:P0000001MAQ:0<0000@`fAJ0P0000C5N7T00`000;5VNK5VN@02/FIi0P00
00Ck/fH00`000?2cS_2cSP05l;>>00<0003HV8oHV8l00[5VN@030000Ve=gVe=g00^KDgL500000X`c
E0030000JAQ@JAQ@00MY65000`0003L03CL03@02=`0=0`000003_8>F0000]X>M012fPid00`000:n1
Xjn1X`0>[h6S00<0002XOjNXOjL01:QoY`800007WVbH00<0002EIiZEIiX02YEWVP030000Rf2KRf2K
00R;H9/0100007aFVWaFVWaFVP<000000fhjP00005TWM`04FBMg00D0000i2FHi2FHi2FH000000PL0
A@800005oooo00<0003oooooool09?ooo`009Oooo`030000oooooooo00[oool00`000;8Z00000006
e64X0P000173I5X3000000?5N7T0002aIWT00k5VN@800004nk=V00<0003`/hk`/hh00o2cSP800000
0n>FN@000=RHS`02/FIi00<0002KDgNKDgL01I]CM`H00007S3=D00<0001Y651Y65001FTHD0800005
=`0=0P0000>lPiH00`000;J3WKJ3W@0?]X>M00<0002_PJ>_PJ<03Zn1X`040000Z7nWZ7nWZ7nW0P00
00ZNK9P00`0009EWVYEWVP0:UFNJ00<0002;H9^;H9/01h]PV`040000O5JJ0000000016hjP0030000
FBMgFBMg009I9gL00`0003T9IST9IP02>@UV00D0000704D0000000T000001Oooo`030000oooooooo
02Coool002Koool00`000?ooooooo`0:oooo00<0002b:P0000001MAQ:0040000]chN000000004/=T
FPP00004nk=V00<0003`/hk`/hh00_2cSP050000hiIihiIihiIi000000>aIWT00`0009]CMi]CM`05
00003H`cE0030000JAQ@JAQ@00=Y650200001CL03@<00004_8>F00<0002fPiffPid04;J3W@030000
[h6S[h6S00f_PJ<010000:QoY`00000000bNK9P00`0009EWVYEWVP0:UFNJ00<0002;H9^;H9/01h]P
V`800005KSZ000<0001I9gMI9gL00eTWM`050000>@UV>@UV>@UV0000008704D200001Oooo`030000
oooooooo02Goool002Koool00`000?ooooooo`0;oooo00@0002b:P0000000002e64X00<0002g?Qjg
?Qh00[Ln7P<0000@`fAJ00<0002YC5NYC5L00ZU<E`030000fH/3000000?k/fH01@000?2cS_2cS_2c
SP000005hiIi1P0001:<<e@00`0006THD6THD002JAQ@00<0000g00dg00d00cL03@@00006_8>F00<0
002fPiffPid03kJ3W@030000[h6S[h6S00j_PJ<00`0009i/V9i/V00=WVbH00<0002EIiZEIiX02IEW
VP030000Rf2KRf2K00F;H9/300001VhjP0030000FBMgFBMg00=I9gL01@0003T9IST9IST9IP000002
1`150P0000Goool00`000?ooooooo`0Uoooo000Woooo00<0003oooooool02oooo`8000001;8Z0000
0=AQ:00000Ng?Qh200003/=TFP030000ZDaGZDaG00>YC5L200001?^cIP<00005hiIi1:U<E`030000
S3=DS3=D01:<<e@00`0006THD6THD00200001CL03@<00009_8>F00<0002fPiffPid03kJ3W@030000
[h6S[h6S00^_PJ<2000000>UKY<0002NK9P03Ii/V0030000UFNJUFNJ00VEIiX00`0008]PVh]PV`03
Rf2K0P00009mAh@00`0006hjP6hjP004KSZ000<0001I9gMI9gL00eTWM`040000>@UV>@UV00000PL0
A@0300000009000000Coool00`000?ooooooo`0Voooo000Xoooo00<0003oooooool03?ooo`040000
/RX0000000002KLn7P<0000;`fAJ00<0002YC5NYC5L00jU<E`800004nk=V00<0003SUWWSUWT01>>F
N@FYC5L00`0008`cE8`cE00BS3=D0`0000Dg00d300003;b3UP030000]X>M]X>M00nfPid00`000:n1
Xjn1X`08[h6S0P0000>UKY<00`0009i/V9i/V00<WVbH00<0002EIiZEIiX02YEWVP030000Rf2KRf2K
00800004ODN400<0001^>X1^>X0016hjP0030000FBMgFBMg009I9gL01@0003T9IST9IST9IP000002
1`150P0000Coool00`000?ooooooo`0Woooo000Xoooo00<0003oooooool03Oooo`8000000h<00000
0000000:]chN0P0000W3I5X00`000:U<EjU<E`03ZDaG0P0000;k/fH2000000?[RdX0003SUWT01>>F
N@FYC5L00`0008`cE8`cE00@S3=D0`0000Hg00d300003Kb3UP030000]X>M]X>M00nfPid00`000:n1
Xjn1X`06[h6S0P0000JUKY<00`0009i/V9i/V00<WVbH00<0002EIiZEIiX02IEWVP<00006ODN400<0
001^>X1^>X0016hjP0030000FBMgFBMg009I9gL02@0003T9IST9IST9IP0000L0A@0000002@000004
oooo00<0003oooooool09oooo`00:Oooo`030000oooooooo00koool2000000>30000000000002[Ln
7P800006`fAJ00<0002YC5NYC5L01:U<E`040000fH/3000000000n^;BP030000hiIihiIi00;SUWT6
ZDaG00<0002<<eB<<e@038`cE0@00002I`0A00<0000g00dg00d00SL03@<0000@_8>F00<0002fPiff
Pid03kJ3W@030000[h6S[h6S00B_PJ<00`000:E^TjE^T`06YFjC00<0002NK9RNK9P039i/V0030000
UFNJUFNJ00REIiX2000027e7Q0030000KSZ0KSZ000=^>X000`0005TWMeTWM`03FBMg00@0000i2FHi
2FH000021`150P0000Coool00`000?ooooooo`0Xoooo000Zoooo00<0003oooooool03oooo`800000
18<000000000000000Vg?Qh300000l=TFP030000ZDaGZDaG00FYC5L200001N^;BP040000hiIihiIi
hiIi1JU<E`030000S3=DS3=D00R<<e@500001VL04@030000=`0==`0=00D0000A_8>F00<0002fPiff
Pid03kJ3W@040000[h6S[h6S[h6S0P0000ZUKY<00`0009i/V9i/V00;WVbH00<0002EIiZEIiX01YEW
VP8000000hQ?Q@0007e7Q007ODN400<0001^>X1^>X000fhjP0030000FBMgFBMg009I9gL02@0003T9
IST9IST9IP0000L0A@0000002@000003oooo00<0003oooooool0:Oooo`00:oooo`030000oooooooo
013oool3000000>30000000000002[Ln7P8000000l=TFP000:U<E`06ZDaG00<00038EP0000001N^;
BP030000hiIiZDaG00FYC5L00`0008`cE8`cE004S3=D100000YW01400`0003L03CL03@0300000l>2
S0030000_8>F_8>F00nlPiH00`000;J3WKJ3W@0>]X>M00@0002_PJ<00000000=YFjC00<0002NK9RN
K9P02ii/V0030000UFNJUFNJ00>EIiX200000hQ?Q@030000ODN4ODN400ImAh@00`0006hjP6hjP003
KSZ000<0001I9gMI9gL00UTWM`060000>@UV>@UV>@UV00001`150P0000?oool00`000?ooooooo`0Z
oooo000/oooo00<0003oooooool04_ooo`8000000h<000000000000:]chN300000G[RdX00`000>>F
NJU<E`05ZDaG00<0002<<eB<<e@0100000iW014400001/>2S0030000_8>F_8>F00nlPiH00`000;J3
WKJ3W@0>]X>M00<0002UKY>UKY<03JE^T`030000WVbHWVbH00^NK9P0100009EWVYEWVYEWVP800005
R4n500<0001mAhAmAh@01Ge7Q0030000KSZ0KSZ000A^>X000`0005TWMeTWM`02FBMg00P0000i2FHi
2FH0000704D0000000T00002oooo00<0003oooooool0:oooo`00;Oooo`030000oooooooo01?oool2
000000>30000000000002KLn7P030000TQTGTQTG00JB6AL00`000<QF00000005jh]:2P00011W0145
00002<>2S0030000_8>F_8>F00jlPiH00`000;J3WKJ3W@0<]X>M0P000003Zfn>0000YFjC00jUKY<0
0`0009i/V9i/V00;WVbH0`0000N8ChD00`0007e7Q7e7Q005ODN400<0001^>X1^>X0016hjP0060000
FBMgFBMgFBMg0000>@UV1P0000;oool00`000?ooooooo`0/oooo000]oooo00<0003oooooool05Ooo
o`80000018<000000000000000Jg?Qh00`00098I5i8I5`07TQTG0P0000C[RdX8TQTG00<0001W015W
014036L04@@000021P0000<00033PXc3PX`02<>2S0030000_8>F_8>F00nlPiH00`000;J3WKJ3W@09
]X>M0P0000B[Khh00`000:E^TjE^T`0<YFjC00<0002NK9RNK9P02ii/V0030000R4n5R4n500N8ChD0
0`0007e7Q7e7Q005ODN400<0001^>X1^>X000fhjP0040000FBMgFBMgFBMg0`000003:`0o00000`0O
00<00002oooo00<0003oooooool0;?ooo`00;_ooo`030000oooooooo01Koool3000000>300000000
00000kLn7P030000TQTGTQTG00VB6AL200000n^;BPRB6AL00`0006L04FL04@08I`0A100000031P00
000000000080000=`h:<00<0002lPiJlPiH03kb3UP030000]X>M]X>M00JfPid200001Z]_SP030000
YFjCYFjC00fUKY<00`0009i/V9i/V008WVbH0`0000V8ChD00`0007e7Q7e7Q005ODN400<0001^>X1^
>X000fhjP0030000FBMg000000800003:`0o00@0000301l000000002oooo00<0003oooooool0;Ooo
o`00;oooo`030000oooooooo01Soool2000000F300000000002g?Qh00000398I5`8000000n^;BY8I
5i8I5`07TQTG00<0001W015W014016L04@@000000`H0000000000002000000?HV8l00033PX`03l>2
S0030000_8>F_8>F00nlPiH00`000;J3WKJ3W@04]X>M00<0002[Khj[Khh01j]_SP030000YFjCYFjC
00fUKY<00`0009i/V9i/V005WVbH0P0000>@Dh<00`0008Q?QHQ?Q@07R4n500<0001mAhAmAh@017e7
Q0030000KSZ0KSZ0009^>X0300000TP5D`050000:`0o:`0o00000`0O00<000000oooo`000?ooo`0_
oooo000`oooo00<0003oooooool06Oooo`8000000h<000000000000>000000?[RdZB6ANB6AL01i8I
5`030000I`0AI`0A00@000021P000`0000?HV8l2000000?:OW`00033PX`03l>2S0030000_8>F_8>F
00jlPiH00`000;J3WKJ3W@02]X>M0P0000^[Khh00`000:E^TjE^T`0<YFjC00<0002NK9RNK9P019i/
V0030000T5>3T5>300>@Dh<00`0008Q?QHQ?Q@07R4n500<0001mAhAmAh@017e7Q0030000KSZ0KSZ0
008000001E`IG`0004P5DdP5D`000002:`0o00<0000301l000000P000003oooo0000oooo033oool0
037oool00`000?ooooooo`0Joooo200000960004000000=60000000000003@000086000400001MRH
S`030000bWilbWil00;:OW`00`000<>2S<>2S00>`h:<00<0002lPiJlPiH03[b3UP040000]X>M0000
00003Z]_SP030000YFjCYFjC00bUKY<0100009i/V9i/V9i/V0800006T5>300<00028ChF8ChD01hQ?
Q@030000ODN4ODN400AmAh@300000U`IG`050000B0ECB0ECB0EC0000008[03l4000000?oool0003o
ool0<Oooo`00<_ooo`030000oooooooo027oool<00001dH000D00002hiIi00<0003HV8oHV8l00mRH
S`030000bWilbWil00C:OW`00`000<>2S<>2S00>`h:<00<0002lPiJlPiH03[b3UP030000Zfn>Zfn>
00j[Khh00`000:E^TjE^T`0<YFjC00@0002NK9P000000009T5>300<00028ChF8ChD01XQ?Q@030000
ODN4ODN400=mAh@2000015`IG`040000B0ECB0EC00000R/0?`0600000`0O00000000oooo0000<ooo
o`00<oooo`030000oooooooo02[oool00`000>^;BP00000700001n>FN@030000f9R?f9R?00800008
bWil00<00033PXc3PX`03/>2S0030000_8>F_8>F00^lPiH2000000>`KHD0002[Khh03j]_SP030000
YFjCYFjC00bUKY<00`00091CPi1CP`09T5>300<00028ChF8ChD01XQ?Q@040000ODN4ODN4ODN40P00
0003JbMV0000G1UO009L6El0200004P5DdP5DdP5D`0002/0?`0000<07`@0000doooo000doooo00<0
003oooooool0:Oooo`800005jh]:00<0003SUWWSUWT02>>FN@03f9R?0000bWil00[:OW`00`000<>2
S<>2S00>`h:<00<0002lPiJlPiH02Kb3UP030000/6f5/6f500:`KHD00`000:]_SZ]_SP0>Zfn>00<0
002UKY>UKY<02JE^T`8000000iMFO`00091CP`09T5>300<00028ChF8ChD01XQ?Q@040000ODN40000
00000V/WIP030000G1UOG1UO009L6El0100004P5DdP5D`00008[03l50000=Oooo`00=Oooo`030000
oooooooo02Woool200001>^;BP03oooo0000hiIi00SSUWT00`000<YnO<YnO00;bWil00<00033PXc3
PX`03L>2S0030000_8>F_8>F00NlPiH200001[1]Q@030000Zfn>Zfn>00j[Khh00`000:E^TjE^T`06
YFjC0P0000>GEWl00`00091CPi1CP`09T5>300<00028ChF8ChD01HQ?Q@800004JbMV00D0001L6EmL
6EmL6El000000TP5D`030000:`0o:`0o00D0000foooo000foooo00<0003oooooool0:?ooo`030000
b5H0000000C[RdX00`000>>FNN>FN@05hiIi0P000003dGIR0000bWil00c:OW`00`000<>2S<>2S00=
`h:<00<0002lPiJlPiH01;b3UP800009/6f500<0002[Khj[Khh03Z]_SP030000YFjCYFjC00BUKY<0
0`0009MFOiMFO`04UeIo00<0002@Dh>@Dh<0291CP`030000R4n5R4n500>8ChD300001F/WIP050000
G1UOG1UOG1UO000000981E<0100002/0?`0000<07`<0000goooo000goooo00<0003oooooool0:?oo
o`800005jh]:00<0003SUWWSUWT00n>FN@030000dGIRdGIR00;AMV800`000<YnO<YnO00;bWil0P00
00k3PX`00`000;b3U[b3UP02_8>F00<0002`KHF`KHD02[1]Q@030000Zfn>Zfn>00f[Khh00`000:E^
TjE^T`02YFjC0P0000NGEWl00`00091CPi1CP`08T5>300@00028ChF8ChF8ChD200000WH`J0030000
JbMVJbMV00=[9fH0100005`IGe`IG`0000981E<0100002/0?b/0?`<07`<0000hoooo000hoooo00<0
003oooooool0:?ooo`800005jh]:00D0003SUWWSUWWSUWT000001]5fHP030000bWilbWil00c:OW`0
0`000<>2S<>2S00<`h:<00@0002lPiH00000000>/6f50P0000j[Khh010000:E^T`00000000ZGEWl0
0`00091CPi1CP`08T5>30`0000Af<6P00`0006/WIV/WIP02JbMV00D0001L6EmL6EmL6El000000TP5
D`03:`0o0000000000<0000ioooo000ioooo00<0003oooooool09oooo`030000b5H0000000C[RdX0
10000>>FN@00000000SAMV8200003LYnO0030000`h:<`h:<00c3PX`00`000;1]QK1]Q@0@/6f500<0
002[Khj[Khh03:]_SP030000UeIoUeIo00^GEWl00`00091CPi1CP`06T5>30P0000If<6P00`0006/W
IV/WIP02JbMV00D0001L6EmL6El000181E<01`0003[oool003[oool00`000?ooooooo`0Woooo00<0
0038EP0000001>^;BP030000dGIRdGIR00[AMV800`000<YnO<YnO00;bWil00<00033PXc3PX`02L>2
S08000000kEYN@000000000A/6f500<0002[Khj[Khh02J]_SP8000000iaFN@0009MFO`0;UeIo00<0
002@Dh>@Dh<0191CP`8000000gheJ00007H`J004MS1X00<0001[9fI[9fH00f/WIP030000G1UO0000
00<000000ah06P00000000020000>oooo`00>oooo`030000oooooooo02Ooool200000n^;BP030000
d5h]000000cAMV800`000<YnO<YnO00;bWil00<00033PXc3PX`01l>2S0030000]FUi]FUi00>eJGT0
0`000;1]QK1]Q@0?/6f500<0002[Khj[Khh01j]_SP030000W5IiW5Ii00:LEWT00`0009MFOiMFO`0:
UeIo00@0002@Dh>@Dh>@Dh<200000gheJ0030000MS1XMS1X00=f<6P00`0006/WIV/WIP02JbMV1000
0003=@0]00007P0J00@0000loooo000loooo00<0003oooooool09_ooo`050000b5H00000jh]:0000
00?@GRd200002m5fHP030000bWilbWil00_:OW`00`000<>2S<>2S004`h:<0P0000NeJGT200004;1]
Q@030000Zfn>Zfn>00B[Khh200001YaFN@030000UeIoUeIo00VGEWl01000091CP`00000000En=FP0
0`0007H`J7H`J003MS1X00@0001[9fI[9fI[9fH200000TL0>P8000027P0J00<1000000000000?Ooo
o`00?Oooo`030000oooooooo02Koool00`000<QF00000006d5h]00<0003AMV;AMV802M5fHP030000
bWilbWil00_:OW`00`000<>2S<>2S002`h:<00<0002eJGVeJGT02KEYN@030000/6f5/6f500j`KHD0
0`000:]_SZ]_SP02Zfn>00<0002LEWVLEWT01iaFN@030000UeIoUeIo00VGEWl00`0007heJ7heJ005
OSEX00<0001f<6Qf<6P00gH`J0030000JbMV000000800002A`0j00D0000e02d0000N01X100000P00
03koool003koool00`000?ooooooo`0Uoooo00@00038EP00002Y7@06d5h]00<0003AMV;AMV802M5f
HP030000bWilbWil00_:OW`010000<>2S000000000feJGT200003k1]Q@040000Zfn>000000002iaF
N@030000UeIoUeIo00JGEWl2000000>4=fD0001n=FP01WheJ0030000MS1XMS1X009f<6P200000U@2
@P070000A`0j0000=@0]00007P0J0@000080000ooooo000ooooo0P0002Koool01@000:TM0:TM0:TM
00000005d5h]00<0003AMV;AMV802M5fHP030000bWilbWil00_:OW`00`000;EYNKEYN@0?]FUi00<0
002`KHF`KHD03K1]Q@030000W5IiW5Ii00bLEWT00`0009MFOiMFO`04UeIo00D00024=fF4=fF4=fD0
00001gheJ0030000MS1XMS1X00<00002E09200P0001703X0000e02d0000N01X100000011oooo0011
oooo00<0003oooooool09?ooo`800002ZAd000<0003@GRg@GRd00m1N;@80000:dGIR00<0003:OWc:
OW`02LYnO0040000^69W000000004;EYN@030000/6f5/6f500Z`KHD2000000>PDW00000000003IaF
N@030000UeIoUeIo00:GEWl00`0008@gIH@gI@03Q3MU00<0001n=FQn=FP017heJ0<000001El;AP00
05@2@U@2@P000002A`0j1@0004;oool004;oool00`000?ooooooo`0Uoooo00@0002Y7@2Y7@000006
d5h]00<0003AMV;AMV802=5fHP800008bWil00<0002hHVNhHVL00[QRI`80000?]FUi0P0000R`KHD2
00001J1BL0030000W5IiW5Ii00^LEWT0100009MFO`00000000J4=fD00`0007heJ7heJ004OSEX00D0
001O2dIO2dIO2dH000000U@2@P05A`0j0000000000004`0000800013oooo0013oooo00<0003ooooo
ool09Oooo`040000ZAd0ZAd000001]1N;@030000dGIRdGIR00WAMV800`000<YnO<YnO003bWil0P00
00NhHVL200003kEYN@030000/6f5/6f500>`KHD200002:1BL080000<W5Ii00<00024=fF4=fD01h@g
I@040000OSEXOSEXOSEX0`0000=O2dH00`0005@2@P0000060000A?ooo`00A?ooo`030000oooooooo
02Goool2000000>Y7@00000000001M1N;@80000:dGIR00D0003:OWc:OWc:OW`000002kQRI`80000>
]FUi0P000003/6f50000000000bPDW02000029aFN@8000000hPfGP0008@gI@07Q3MU00@0001n=FP0
00000002IQ1600<0001O2dIO2dH00`000003<@0D0000000000<00015oooo0015oooo00<0003ooooo
ool09_ooo`040000ZAd0ZAd000001]1N;@030000dGIRdGIR00SAMV800`000<YnO000000>^69W00<0
002eJGVeJGT03KEYN@80000?X59`00<0002LEWVLEWT00iaFN@800004R3IN0P0000N4=fD00`0006H@
AVH@AP02IQ1600D0001O2dH00000000l01`01P0004Koool004Koool200009oooo`040000ZAd0ZAd0
00001]1N;@030000dGIRdGIR00SAMV8200003kQRI`80000;]FUi0P0000:RC68200003Z1BL0800000
0iaFN@0000000008R3IN00<00024=fF4=fD00X@gI@8000000f/A@`0006H@AP02IQ160P000003A00O
0000000000@00018oooo0018oooo00<0003oooooool09Oooo`8000000jTM000000000005d5h]00<0
003AMV;AMV801M5fHP800002^5990P0000nhHVL200002;EYN@030000XTaRXTaR00BRC68200003Z1B
L080000:R3IN00@00024=fD000000003Ja5300<0001V44H000000P000003A00O0000000000@00019
oooo0019oooo0P0002Ooool010000:TM0:TM000000G@GRd200001=5fHP030000^599^59900BhDTT2
00003kQRI`800005]FUi00<0002RC6:RC6801j9<HP80000:X59`0P0000:9<ED200002HPfGP800005
Ja5300<0001:025:02401P0004_oool004_oool200009_ooo`040000ZAd0ZAd000001]1N;@040000
dGIR000000002KQBB@80000?^69W0P000003]FUi0000000000bRC68200001Z1BL0800006RC5E0P00
00F8=Uh200000Vd@?@8000001F/A@`000000000004X08@060000C?ooo`00COooo`030000oooooooo
02Coool2000000>Y7@00003@GRd01M1N;@80000<^5990P0000nhHVL200003j9<HP800002X59`0P00
00Z9<ED2000000>8=Uh0000000001Fd@?@<000000dd07P00000000040000C_ooo`00C_ooo`80000V
oooo00@0002Y7@0000000003d5h]00<0002^<1:^<1800P0000bhDTT200003;QRI`030000XD1>XD1>
00<0000>XTaR0`0000f9<ED300000fd@?@800002CP0J0P000004<@00000000000000D?ooo`00D?oo
o`80000Uoooo00H0002Y7@2Y7@00003@GRd00005[S0B0P0000bhDTT200002;QRI`800006XD1>0`00
00^RC6800`0008PXAXPXAP0400001hTaE@800003K@Xd3000057oool005;oool200009?ooo`800000
0jTM000000000007[S0B0`0000^hDTT200001KQRI`030000XD1>XD1>00VQ@4h300001Z9<HP800007
R2Q6100000:9<ED00`0006d:=6d:=004K@Xd2@0005?oool005Coool200009?ooo`800002PP000P00
00N^<18200002kQBB@800002^69W00<0002Q@4jQ@4h03J50CP<00002XTaR00<00028:4J8:4H02hPX
AQ00001Eoooo001Foooo0P0002?oool200000h8000800007[S0B0P0000^hDTT400004J50CPP00006
R2Q60P0000IY0BH90000E_ooo`00F?ooo`80000Soooo0`0000:2000300001Zh`4P<00008^59900@0
002J:RjJ:RjJ:Rh400003J50CP030000PaTaPaTa00F36C4E0000F?ooo`00F_ooo`80000Toooo0P00
00>2000300001Zh`4P800005^59900<0002J:RjJ:Rh01YXZ;P@00008XD1>00<000236C636C402X<I
<@030000HP0CHP0C00=R01<90000F_ooo`00G?ooo`80000Toooo0`0000>2000300001Jh`4P800002
^59900<0002J:RjJ:Rh02iXZ;P@00003XD1>00<000236C636C402X<I<@030000HP0C000000D00000
0bP00000000000020000GOooo`00G_ooo`<0000Toooo0`0000>2000200001Jh`4PH0000>VRX^4000
009E0006000000<F000000000000Goooo`00HOooo`<0000Toooo0`0000:2000300000Zh`4P030000
R0D0R0D000>81@0900001IXZ;P80000<N08C2`00067oool006Coool300009?ooo`800003PP001P00
00^81@0K0000I?ooo`00Ioooo`<0000Soooo0`000003PP000000G00000EL000700001HP500030000
HP00HP0000AR0008000000<V0000000000000P0006Soool006[oool300008oooo`/00004G0005P00
06_oool006goool40000:_oooa000003oooo100006koool0077oool30000=oooo`<0001boooo001d
oooo1@0002goool50000MOooo`00NOooo`H0000Qoooo1P0007[oool007ooool:00003Oooo`X00020
oooo0029oooo3@0008[oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
        ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}], 
      "\[IndentingNewLine]"}]}], "Input",
  Editable->False,
  CellDingbat->None],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.4;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    StyleBox[\(\(\[CapitalDelta]1 = 0.4;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(\[CapitalDelta]8 = 0.4;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(kembed = 1;\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.43234 .44604 m .47233 .45281 L p .46933 .5 L .683 .566 .716 r
F P
0 g
s
.47233 .45281 m .47278 .45325 L .46933 .5 L .683 .566 .716 r
F
.47278 .45323 m .47303 .45348 L .46933 .5 L F
.47329 .45374 m .46933 .5 L p .47305 .45332 L F P
0 g
s
.4871 .58557 m .47297 .54756 L p .51533 .52656 L .727 .606 .722 r
F P
0 g
s
.47297 .54756 m .47298 .54753 L .51533 .52656 L .727 .606 .722 r
F
.42888 .5 m .46933 .5 L .47329 .54626 L p .683 .55 .697 r
F P
0 g
s
.47296 .54754 m .47316 .54673 L .51533 .52656 L .727 .606 .722 r
F
.47316 .54673 m .47327 .54629 L .47384 .54603 L F
.47316 .54673 m .47384 .54603 L .51533 .52656 L F
.47297 .54756 m .47296 .54754 L p .47298 .54753 L F P
0 g
s
.47295 .54658 m .47329 .54626 L .47305 .54668 L .683 .55 .697 r
F
.42888 .5 m .47329 .54626 L .47295 .54658 L F
.43234 .55396 m .42888 .5 L p .47295 .54658 L F P
0 g
s
.47295 .54658 m .47305 .54668 L .47292 .54671 L .683 .55 .697 r
F
.47295 .54658 m .47292 .54671 L .43234 .55396 L F
.4728 .54711 m .4871 .58557 L .45884 .59539 L p .745 .615 .715 r
F P
0 g
s
.45884 .59539 m .44144 .60143 L p .4728 .54711 L .745 .615 .715 r
F P
0 g
s
.44144 .60143 m .43234 .55396 L p .4577 .5732 L .679 .53 .676 r
F P
0 g
s
.38368 .55887 m .43234 .55396 L .44144 .60143 L p .715 .554 .67 r
F P
0 g
s
.45138 .65331 m .43643 .6101 L p .4871 .58557 L .733 .577 .68 r
F P
0 g
s
.43643 .6101 m .39154 .61876 L p .43654 .60629 L .715 .554 .67 r
F P
0 g
s
.43901 .60561 m .43643 .6101 L .43654 .60629 L .715 .554 .67 r
F
.39154 .61876 m .38368 .55887 L p .43901 .60561 L F P
0 g
s
.43643 .6101 m .45138 .65331 L .43512 .65862 L p .758 .59 .669 r
F P
0 g
s
.43512 .65862 m .40221 .66937 L p .43643 .6101 L .758 .59 .669 r
F P
0 g
s
.40221 .66937 m .39154 .61876 L p .42017 .63812 L .708 .526 .64 r
F P
0 g
s
.33592 .6227 m .39154 .61876 L .40221 .66937 L p .743 .548 .631 r
F P
0 g
s
.41745 .72779 m .39543 .68112 L p .44116 .67574 L .744 .55 .632 r
F P
0 g
s
.45138 .65331 m .47577 .70345 L .41745 .72779 L p .744 .55 .632 r
F P
0 g
s
.45135 .77679 m .41745 .72779 L .47577 .70345 L p .725 .506 .594 r
F P
0 g
s
.35437 .74825 m .34401 .68539 L p .35636 .69459 L .734 .511 .589 r
F P
0 g
s
.35636 .69459 m .37814 .7108 L .35674 .74451 L .734 .511 .589 r
F
.35636 .69459 m .35674 .74451 L .35437 .74825 L F
.37814 .7108 m .37797 .71109 L .35437 .74825 L F
.35942 .74657 m .35677 .74808 L .36509 .73356 L .774 .561 .612 r
F
.35782 .75025 m .35677 .74808 L p .35942 .74657 L F P
0 g
s
.35677 .74808 m .35782 .75025 L .35679 .75062 L p .81 .574 .581 r
F P
0 g
s
.41745 .72779 m .45135 .77679 L .39806 .80212 L p .753 .511 .566 r
F P
0 g
s
.39806 .80212 m .35782 .75025 L .41745 .72779 L p .753 .511 .566 r
F P
0 g
s
.44381 .84215 m .39806 .80212 L .45135 .77679 L p .724 .454 .518 r
F P
0 g
s
.35782 .75025 m .39806 .80212 L .39749 .8024 L p .784 .51 .523 r
F P
0 g
s
.39749 .8024 m .34861 .82566 L p .3516 .8012 L .784 .51 .523 r
F P
0 g
s
.3516 .8012 m .35782 .75025 L .39749 .8024 L .784 .51 .523 r
F
.28932 .73935 m .35437 .74825 L .35492 .75128 L p .768 .49 .514 r
F P
0 g
s
.3516 .8012 m .33248 .78991 L .35782 .75025 L .784 .51 .523 r
F
.32645 .8006 m .29367 .79394 L p .31834 .78733 L .768 .49 .514 r
F P
0 g
s
.33671 .78241 m .32645 .8006 L .31834 .78733 L .768 .49 .514 r
F
.29367 .79394 m .29304 .78599 L p .33671 .78241 L F P
0 g
s
.29304 .78599 m .28932 .73935 L p .32242 .76943 L .768 .49 .514 r
F P
0 g
s
.32242 .76943 m .33671 .78241 L .29304 .78599 L .768 .49 .514 r
F
.28932 .73935 m .35492 .75128 L .33671 .78241 L F
.35492 .75128 m .35437 .74825 L p .35604 .74935 L .72 .458 .529 r
F P
0 g
s
.35534 .74889 m .35635 .74881 L .35604 .74935 L .72 .458 .529 r
F
.35437 .74825 m .35677 .74808 L p .35534 .74889 L F P
0 g
s
.35679 .75062 m .35492 .75128 L p .35677 .74808 L .81 .574 .581 r
F P
0 g
s
.35604 .74935 m .35677 .74808 L .35492 .75128 L .81 .574 .581 r
F
.41745 .72779 m .35782 .75025 L p .36509 .73356 L .774 .561 .612 r
F P
0 g
s
.35677 .74808 m .42201 .74345 L p .35534 .74889 L .72 .458 .529 r
F P
0 g
s
.3001 .7708 m .35677 .74808 L .35505 .75104 L .81 .574 .581 r
F
.35491 .75129 m .35411 .75157 L p .35505 .75104 L F P
0 g
s
.35411 .75157 m .3001 .7708 L p .35505 .75104 L .81 .574 .581 r
F P
0 g
s
.30791 .84626 m .30737 .84104 L .31009 .84088 L .819 .497 .445 r
F
.34337 .82831 m .30791 .84626 L p .32645 .8006 L F P
0 g
s
.29618 .83949 m .29545 .8263 L p .29992 .83525 L .755 .415 .408 r
F P
0 g
s
.31841 .81431 m .31828 .81453 L .29618 .83949 L .755 .415 .408 r
F
.30294 .84131 m .30791 .84626 L .306 .84744 L p .845 .44 .273 r
F P
0 g
s
.306 .84744 m .29576 .85376 L p .30294 .84131 L .845 .44 .273 r
F P
0 g
s
.29576 .85376 m .29618 .83949 L p .30176 .84334 L .713 .269 .197 r
F P
0 g
s
.23046 .80475 m .29618 .83949 L .29576 .85369 L p .79 .346 .194 r
F P
0 g
s
.23046 .80475 m .29576 .85369 L .29569 .85371 L .79 .346 .194 r
F
.23046 .80475 m .29576 .85376 L .28356 .85806 L F
.29618 .83949 m .23046 .80475 L .23189 .76678 L p .813 .463 .395 r
F P
0 g
s
.18219 .73242 m .23189 .76678 L .23046 .80475 L p .864 .514 .387 r
F P
0 g
s
.23046 .80475 m .17888 .76299 L .18219 .73242 L p .864 .514 .387 r
F P
0 g
s
.22686 .82922 m .23023 .80629 L p .27273 .85255 L .79 .346 .194 r
F P
0 g
s
.28207 .86221 m .28189 .86252 L p .28061 .86113 L .731 .209 0 r
F P
0 g
s
.27922 .85962 m .28071 .86097 L p .28061 .86113 L .731 .209 0 r
F P
0 g
s
.28071 .86097 m .28207 .86221 L p .28061 .86113 L .731 .209 0 r
F P
0 g
s
.22686 .82922 m .28061 .86113 L p .27619 .86841 L .64 .079 0 r
F P
0 g
s
.28207 .86221 m .27922 .85962 L p .28072 .85908 L .845 .44 .273 r
F P
0 g
s
.2957 .8538 m .28207 .86221 L p .28768 .85659 L .845 .44 .273 r
F P
0 g
s
.29915 .84154 m .30234 .84235 L .30176 .84334 L .713 .269 .197 r
F
.30176 .84334 m .30294 .84131 L .29576 .85376 L .845 .44 .273 r
F
.30791 .84626 m .30294 .84131 L p .30737 .84104 L .819 .497 .445 r
F P
0 g
s
.34861 .82566 m .40301 .86558 L .37086 .88581 L p .767 .404 .369 r
F P
0 g
s
.37086 .88581 m .30791 .84626 L .34861 .82566 L p .767 .404 .369 r
F P
0 g
s
.29917 .84154 m .37461 .8606 L .29915 .84154 L .713 .269 .197 r
F
.30293 .84131 m .37461 .8606 L p .29914 .84153 L F P
0 g
s
.28768 .85659 m .30294 .84131 L .29574 .85372 L .845 .44 .273 r
F
.29576 .85369 m .29576 .85376 L p .29569 .85371 L .79 .346 .194 r
F P
0 g
s
.28768 .85659 m .29574 .85372 L .2957 .8538 L .845 .44 .273 r
F
.28355 .85805 m .28356 .85806 L .28353 .85808 L .79 .346 .194 r
F
.29914 .84153 m .29917 .84154 L .29915 .84154 L .713 .269 .197 r
F
.29618 .83949 m .30293 .84131 L p .29914 .84153 L F P
0 g
s
.30737 .84104 m .30457 .83848 L .30671 .83473 L .819 .497 .445 r
F
.30294 .84131 m .30457 .83848 L .30737 .84104 L F
.31009 .84088 m .30671 .83473 L .32645 .8006 L F
.30737 .84104 m .30671 .83473 L .31009 .84088 L F
.30671 .83473 m .31845 .81434 L .32645 .8006 L F
.37461 .8606 m .30294 .84131 L p .31845 .81434 L .755 .415 .408 r
F P
0 g
s
.30294 .84131 m .30293 .84131 L p .30671 .83473 L .755 .415 .408 r
F P
0 g
s
.31845 .81434 m .30294 .84131 L .30671 .83473 L .755 .415 .408 r
F
.29367 .79394 m .31841 .81431 L .29992 .83525 L F
.29545 .8263 m .29367 .79394 L p .29992 .83525 L F P
0 g
s
.30293 .84131 m .29618 .83949 L p .31845 .81434 L .755 .415 .408 r
F P
0 g
s
.23189 .76678 m .29367 .79394 L .29618 .83949 L p .813 .463 .395 r
F P
0 g
s
.30294 .84131 m .25041 .78889 L p .30457 .83848 L .819 .497 .445 r
F P
0 g
s
.25041 .78889 m .30294 .84131 L p .28768 .85659 L .845 .44 .273 r
F P
0 g
s
.28207 .86221 m .28072 .85908 L .28768 .85659 L .845 .44 .273 r
F
.28355 .85805 m .28353 .85808 L .28072 .85908 L .79 .346 .194 r
F
.23046 .80475 m .28355 .85805 L .27273 .85255 L F
.27851 .85988 m .22686 .82922 L p .28355 .85805 L F P
0 g
s
.28072 .85908 m .25041 .78889 L .28768 .85659 L .845 .44 .273 r
F
.28072 .85908 m .28061 .86113 L .27922 .85962 L .79 .346 .194 r
F
.28353 .85808 m .28061 .86113 L .28072 .85908 L F
.28971 .86426 m .29407 .86862 L .28872 .86594 L F
.29528 .86984 m .28872 .86594 L p .29407 .86862 L F P
0 g
s
.29528 .86984 m .29 .87939 L p .2838 .87446 L .64 .079 0 r
F P
0 g
s
.28061 .86113 m .27851 .85988 L p .27922 .85962 L .79 .346 .194 r
F P
0 g
s
.17888 .76299 m .23046 .80475 L .22686 .82922 L p .852 .422 .2 r
F P
0 g
s
.21736 .80329 m .27922 .85962 L p .27779 .86577 L .731 .209 0 r
F P
0 g
s
.27644 .87156 m .27517 .87009 L .27779 .86577 L .731 .209 0 r
F
.22087 .83644 m .22686 .82922 L p .27619 .86841 L .64 .079 0 r
F P
0 g
s
.27513 .87015 m .22087 .83644 L p .27619 .86841 L .64 .079 0 r
F P
0 g
s
.27517 .87009 m .21736 .80329 L .27779 .86577 L .731 .209 0 r
F
.28189 .86252 m .27644 .87156 L p .27922 .85962 L F P
0 g
s
.22686 .82922 m .17424 .78207 L .17888 .76299 L p .852 .422 .2 r
F P
0 g
s
.27644 .87156 m .209 .81225 L .21736 .80329 L p .731 .209 0 r
F P
0 g
s
.27644 .87156 m .28207 .86221 L p .28829 .8667 L .616 .048 0 r
F P
0 g
s
.29 .87939 m .28335 .87525 L p .2838 .87446 L .64 .079 0 r
F P
0 g
s
.28684 .86921 m .29528 .86984 L .2838 .87446 L .64 .079 0 r
F
.28335 .87525 m .27644 .87156 L p .28829 .8667 L .616 .048 0 r
F P
0 g
s
.28829 .8667 m .28387 .86351 L .2886 .86615 L .616 .048 0 r
F
.28207 .86221 m .28872 .86594 L p .28387 .86351 L F P
0 g
s
.28387 .86351 m .28872 .86594 L .2886 .86615 L .616 .048 0 r
F
.28872 .86594 m .28207 .86221 L .29576 .85376 L p .761 .309 .177 r
F P
0 g
s
.29576 .85376 m .29528 .86984 L p .28972 .86425 L .79 .346 .194 r
F P
0 g
s
.29895 .87101 m .29528 .86984 L .29576 .85376 L p .713 .269 .197 r
F P
0 g
s
.28872 .86594 m .29576 .85376 L .28972 .86425 L .761 .309 .177 r
F
.28356 .85806 m .29528 .86984 L .28353 .85808 L .79 .346 .194 r
F
.33369 .87875 m .28872 .86594 L .30791 .84626 L .761 .309 .177 r
F
.35146 .90115 m .29695 .87056 L p .33369 .87875 L F P
0 g
s
.29528 .86984 m .29704 .8704 L p .29665 .87049 L .505 0 0 r
F P
0 g
s
.29704 .8704 m .29895 .87101 L p .29695 .87056 L .505 0 0 r
F P
0 g
s
.29704 .8704 m .29695 .87056 L .29665 .87049 L .505 0 0 r
F
.28872 .86594 m .29528 .86984 L p .28684 .86921 L .64 .079 0 r
F P
0 g
s
.28872 .86594 m .29695 .87056 L p .2886 .86615 L .616 .048 0 r
F P
0 g
s
.29695 .87056 m .35146 .90115 L p .29685 .87074 L .616 .048 0 r
F P
0 g
s
.30791 .84626 m .37086 .88581 L .36963 .88678 L p .761 .309 .177 r
F P
0 g
s
.36963 .88678 m .35146 .90115 L p .33369 .87875 L .761 .309 .177 r
F P
0 g
s
.33369 .87875 m .30791 .84626 L .36963 .88678 L .761 .309 .177 r
F
.29 .87939 m .29511 .87014 L p .29675 .87092 L .505 0 0 r
F P
0 g
s
.29178 .87999 m .29 .87939 L p .29675 .87092 L .505 0 0 r
F P
0 g
s
.29601 .87227 m .28335 .87525 L .28829 .8667 L .616 .048 0 r
F
.3482 .90995 m .29188 .87982 L p .29601 .87227 L F P
0 g
s
.29188 .87982 m .28335 .87525 L p .29601 .87227 L .616 .048 0 r
F P
0 g
s
.35146 .90115 m .3482 .90995 L p .28829 .8667 L .616 .048 0 r
F P
0 g
s
.29511 .87014 m .29528 .86984 L p .29662 .87048 L .505 0 0 r
F P
0 g
s
.29662 .87048 m .29692 .87062 L .29511 .87014 L .505 0 0 r
F
.28829 .8667 m .2886 .86615 L .29685 .87074 L .616 .048 0 r
F
.29659 .87122 m .29685 .87074 L .35146 .90115 L F
.29692 .87062 m .29675 .87092 L .29511 .87014 L .505 0 0 r
F
.28829 .8667 m .29685 .87074 L .29659 .87122 L .616 .048 0 r
F
.4186 .92315 m .35146 .90115 L .37086 .88581 L p .668 .184 .093 r
F P
0 g
s
.29692 .87062 m .37508 .90814 L .29675 .87092 L .505 0 0 r
F
.37508 .90814 m .29178 .87999 L p .29675 .87092 L F P
0 g
s
.37867 .89642 m .37508 .90814 L p .29665 .87049 L .505 0 0 r
F P
0 g
s
.29895 .87101 m .37867 .89642 L p .29665 .87049 L .505 0 0 r
F P
0 g
s
.2886 .86615 m .29695 .87056 L .29685 .87074 L .616 .048 0 r
F
.29695 .87056 m .28872 .86594 L p .33369 .87875 L .761 .309 .177 r
F P
0 g
s
.29595 .85364 m .30791 .84626 L p .28872 .86594 L .761 .309 .177 r
F P
0 g
s
.37867 .89642 m .29895 .87101 L p .29576 .85376 L .713 .269 .197 r
F P
0 g
s
.29576 .85376 m .29595 .85364 L p .29578 .85392 L .761 .309 .177 r
F P
0 g
s
.28972 .86425 m .29576 .85376 L .29578 .85392 L .761 .309 .177 r
F
.29576 .85376 m .2957 .8538 L p .29571 .85378 L .845 .44 .273 r
F P
0 g
s
.28356 .85806 m .29576 .85376 L .28972 .86425 L .79 .346 .194 r
F
.28061 .86113 m .28872 .86594 L p .27619 .86841 L .64 .079 0 r
F P
0 g
s
.28872 .86594 m .28684 .86921 L .27619 .86841 L .64 .079 0 r
F
.27619 .86841 m .2838 .87446 L .27513 .87015 L F
.28335 .87525 m .27513 .87015 L p .2838 .87446 L F P
0 g
s
.27619 .86841 m .28684 .86921 L .2838 .87446 L .64 .079 0 r
F
.28353 .85808 m .28971 .86426 L .28061 .86113 L .79 .346 .194 r
F
.28872 .86594 m .28061 .86113 L p .28971 .86426 L F P
0 g
s
.23023 .80629 m .23046 .80475 L p .27273 .85255 L .79 .346 .194 r
F P
0 g
s
.28072 .85908 m .27921 .85961 L .28071 .85907 L .845 .44 .273 r
F
.27922 .85962 m .27921 .85961 L p .28072 .85908 L F P
0 g
s
.21736 .80329 m .25041 .78889 L p .28071 .85907 L .845 .44 .273 r
F P
0 g
s
.27921 .85961 m .21736 .80329 L p .28071 .85907 L .845 .44 .273 r
F P
0 g
s
.29571 .85378 m .30176 .84334 L .29576 .85376 L .845 .44 .273 r
F
.30176 .84334 m .37867 .89642 L .29576 .85376 L .713 .269 .197 r
F
.4328 .90959 m .37086 .88581 L .40301 .86558 L p .704 .307 .294 r
F P
0 g
s
.37086 .88581 m .4328 .90959 L .4186 .92315 L p .668 .184 .093 r
F P
0 g
s
.37461 .8606 m .37867 .89642 L p .30176 .84334 L .713 .269 .197 r
F P
0 g
s
.30234 .84235 m .37461 .8606 L .30176 .84334 L .713 .269 .197 r
F
.31841 .81431 m .31845 .81434 L .31828 .81453 L .755 .415 .408 r
F
.31841 .81431 m .32496 .80316 L .31845 .81434 L F
.30102 .79999 m .32487 .80315 L .31841 .81431 L F
.32487 .80315 m .32496 .80316 L .31841 .81431 L F
.30088 .79988 m .3019 .80001 L .30102 .79999 L F
.32645 .8006 m .34861 .82566 L .34337 .82831 L p .819 .497 .445 r
F P
0 g
s
.34861 .82566 m .32645 .8006 L p .3516 .8012 L .784 .51 .523 r
F P
0 g
s
.3019 .80001 m .36543 .80852 L .30102 .79999 L .755 .415 .408 r
F
.29367 .79394 m .32614 .80054 L p .30088 .79988 L F P
0 g
s
.32614 .80054 m .36543 .80852 L p .30088 .79988 L .755 .415 .408 r
F P
0 g
s
.23179 .71974 m .28932 .73935 L .29367 .79394 L p .814 .526 .502 r
F P
0 g
s
.29367 .79394 m .23189 .76678 L .23179 .71974 L p .814 .526 .502 r
F P
0 g
s
.25041 .78889 m .3001 .7708 L p .30669 .83453 L .819 .497 .445 r
F P
0 g
s
.30671 .83473 m .30662 .83465 L .30669 .83453 L .819 .497 .445 r
F
.30662 .83465 m .25041 .78889 L .30669 .83453 L F
.30457 .83848 m .25041 .78889 L .30671 .83473 L F
.30671 .83473 m .30669 .83453 L .31845 .81434 L F
.40301 .86558 m .34861 .82566 L .39806 .80212 L p .747 .44 .464 r
F P
0 g
s
.36543 .80852 m .37461 .8606 L p .31845 .81434 L .755 .415 .408 r
F P
0 g
s
.32496 .80316 m .36543 .80852 L .31845 .81434 L .755 .415 .408 r
F
.3001 .7708 m .32645 .8006 L p .30669 .83453 L .819 .497 .445 r
F P
0 g
s
.33248 .78991 m .33236 .78984 L .33363 .78787 L .784 .51 .523 r
F
.33248 .78991 m .33363 .78787 L .35782 .75025 L F
.35492 .75128 m .35782 .75025 L p .33236 .78984 L F P
0 g
s
.32645 .8006 m .3001 .7708 L p .3516 .8012 L .784 .51 .523 r
F P
0 g
s
.36543 .80852 m .32645 .8006 L p .33671 .78241 L .768 .49 .514 r
F P
0 g
s
.35492 .75128 m .36543 .80852 L p .33671 .78241 L .768 .49 .514 r
F P
0 g
s
.3001 .7708 m .35492 .75128 L p .33236 .78984 L .784 .51 .523 r
F P
0 g
s
.39806 .80212 m .44381 .84215 L .40301 .86558 L p .747 .44 .464 r
F P
0 g
s
.44207 .80572 m .36543 .80852 L .35492 .75128 L p .72 .458 .529 r
F P
0 g
s
.35604 .74935 m .44207 .80572 L .35492 .75128 L .72 .458 .529 r
F
.35492 .75128 m .35491 .75129 L p .35604 .74935 L .81 .574 .581 r
F P
0 g
s
.42201 .74345 m .44207 .80572 L p .35604 .74935 L .72 .458 .529 r
F P
0 g
s
.35635 .74881 m .42201 .74345 L .35604 .74935 L .72 .458 .529 r
F
.36509 .73356 m .36583 .73227 L .41745 .72779 L .774 .561 .612 r
F
.35676 .74808 m .35437 .74825 L p .37815 .7108 L .734 .511 .589 r
F P
0 g
s
.39543 .68112 m .41745 .72779 L p .36565 .73229 L .774 .561 .612 r
F P
0 g
s
.42201 .74345 m .35676 .74808 L p .37815 .7108 L .734 .511 .589 r
F P
0 g
s
.28462 .68052 m .34401 .68539 L .35437 .74825 L p .773 .538 .578 r
F P
0 g
s
.35437 .74825 m .28932 .73935 L .28462 .68052 L p .773 .538 .578 r
F P
0 g
s
.32816 .68927 m .35677 .74808 L p .3001 .7708 L .81 .574 .581 r
F P
0 g
s
.37814 .7108 m .39526 .68141 L .37815 .7108 L .734 .511 .589 r
F
.34608 .68693 m .39522 .68141 L .37814 .7108 L F
.39522 .68141 m .39526 .68141 L .37814 .7108 L F
.34401 .68539 m .39543 .68112 L p .34608 .68693 L F P
0 g
s
.39543 .68112 m .40453 .68037 L p .34608 .68693 L .734 .511 .589 r
F P
0 g
s
.34401 .68539 m .33592 .6227 L p .39464 .67205 L .743 .548 .631 r
F P
0 g
s
.39464 .67205 m .39839 .6752 L .37226 .6801 L .743 .548 .631 r
F
.39464 .67205 m .37226 .6801 L .34401 .68539 L F
.33592 .6227 m .40221 .66937 L .39839 .6752 L F
.39154 .61876 m .43643 .6101 L p .42017 .63812 L .708 .526 .64 r
F P
0 g
s
.39153 .67286 m .43643 .6101 L .40203 .6694 L .758 .59 .669 r
F
.40201 .66944 m .40113 .66972 L p .40203 .6694 L F P
0 g
s
.40113 .66972 m .39153 .67286 L p .40203 .6694 L .758 .59 .669 r
F P
0 g
s
.39543 .68112 m .34401 .68539 L p .39839 .6752 L .743 .548 .631 r
F P
0 g
s
.28064 .62034 m .33592 .6227 L .34401 .68539 L p .777 .572 .623 r
F P
0 g
s
.34401 .68539 m .28462 .68052 L .28064 .62034 L p .777 .572 .623 r
F P
0 g
s
.32816 .68927 m .39153 .67286 L p .36565 .73229 L .774 .561 .612 r
F P
0 g
s
.36509 .73356 m .36499 .73343 L .36565 .73229 L .774 .561 .612 r
F
.36499 .73343 m .32816 .68927 L .36565 .73229 L F
.35677 .74808 m .32816 .68927 L p .36509 .73356 L F P
0 g
s
.37814 .7108 m .37815 .7108 L .37797 .71109 L .734 .511 .589 r
F
.36509 .73356 m .36565 .73229 L .36583 .73227 L .774 .561 .612 r
F
.39153 .67286 m .39543 .68112 L p .36565 .73229 L F P
0 g
s
.40453 .68037 m .42201 .74345 L p .37815 .7108 L .734 .511 .589 r
F P
0 g
s
.39526 .68141 m .40453 .68037 L .37815 .7108 L .734 .511 .589 r
F
.44116 .67574 m .39543 .68112 L .45138 .65331 L .744 .55 .632 r
F
.39543 .68112 m .39505 .68031 L p .39609 .67981 L F P
0 g
s
.39543 .68112 m .39609 .67981 L .45138 .65331 L .744 .55 .632 r
F
.40221 .66937 m .45138 .65331 L p .39505 .68031 L F P
0 g
s
.40453 .68037 m .39543 .68112 L p .39839 .6752 L .743 .548 .631 r
F P
0 g
s
.40221 .66937 m .40453 .68037 L p .39839 .6752 L .743 .548 .631 r
F P
0 g
s
.39505 .68031 m .39153 .67286 L .40221 .66937 L p .744 .55 .632 r
F P
0 g
s
.40221 .66937 m .40201 .66944 L p .42017 .63812 L .758 .59 .669 r
F P
0 g
s
.42017 .63812 m .43643 .6101 L .40221 .66937 L .758 .59 .669 r
F
.47577 .70345 m .45138 .65331 L .50717 .63017 L p .718 .54 .647 r
F P
0 g
s
.46068 .66551 m .40453 .68037 L .40221 .66937 L p .708 .526 .64 r
F P
0 g
s
.42017 .63812 m .46068 .66551 L .40221 .66937 L .708 .526 .64 r
F
.4871 .58557 m .50717 .63017 L .45138 .65331 L p .733 .577 .68 r
F P
0 g
s
.44286 .60886 m .46068 .66551 L p .42017 .63812 L .708 .526 .64 r
F P
0 g
s
.43643 .6101 m .44286 .60886 L p .42017 .63812 L .708 .526 .64 r
F P
0 g
s
.43429 .60391 m .43643 .6101 L p .39153 .67286 L .758 .59 .669 r
F P
0 g
s
.43643 .6101 m .43642 .61006 L p .43647 .61004 L .733 .577 .68 r
F P
0 g
s
.43643 .6101 m .43647 .61004 L .4871 .58557 L .733 .577 .68 r
F
.44144 .60143 m .4871 .58557 L p .43642 .61006 L F P
0 g
s
.44286 .60886 m .43643 .6101 L p .43901 .60561 L .715 .554 .67 r
F P
0 g
s
.44144 .60143 m .44286 .60886 L p .43901 .60561 L .715 .554 .67 r
F P
0 g
s
.38368 .55887 m .44144 .60143 L .43901 .60561 L .715 .554 .67 r
F
.43642 .61006 m .43429 .60391 L .44144 .60143 L p .733 .577 .68 r
F P
0 g
s
.44144 .60143 m .44135 .60146 L p .4577 .5732 L .745 .615 .715 r
F P
0 g
s
.4577 .5732 m .4728 .54711 L .44144 .60143 L .745 .615 .715 r
F
.48573 .59448 m .44286 .60886 L .44144 .60143 L p .679 .53 .676 r
F P
0 g
s
.4577 .5732 m .48573 .59448 L .44144 .60143 L .679 .53 .676 r
F
.47336 .54701 m .48573 .59448 L p .4577 .5732 L F P
0 g
s
.45192 .56881 m .47214 .54825 L .4577 .5732 L .679 .53 .676 r
F
.47214 .54825 m .47336 .54701 L .4577 .5732 L F
.47261 .54658 m .47328 .54626 L p .47316 .54673 L .727 .606 .722 r
F P
0 g
s
.47296 .54754 m .4728 .54711 L p .47316 .54673 L .727 .606 .722 r
F P
0 g
s
.4728 .54711 m .43234 .55396 L p .47305 .54668 L .683 .55 .697 r
F P
0 g
s
.4728 .54711 m .47261 .54658 L p .47316 .54673 L .727 .606 .722 r
F P
0 g
s
.4728 .54711 m .47336 .54701 L p .45192 .56881 L .679 .53 .676 r
F P
0 g
s
.44135 .60146 m .43429 .60391 L p .4728 .54711 L .745 .615 .715 r
F P
0 g
s
.43234 .55396 m .4728 .54711 L p .45192 .56881 L .679 .53 .676 r
F P
0 g
s
.47261 .54658 m .4728 .54711 L p .43429 .60391 L .745 .615 .715 r
F P
0 g
s
.47329 .54626 m .46933 .5 L p .48142 .5135 L .638 .516 .698 r
F P
0 g
s
.48142 .5135 m .48797 .52082 L .47329 .54626 L .638 .516 .698 r
F
.47372 .54551 m .48797 .52082 L .50762 .5132 L .742 .65 .758 r
F
.48142 .5135 m .5 .5 L .48797 .52082 L .638 .516 .698 r
F
.48477 .5 m .5 .5 L p .48142 .5135 L F P
0 g
s
.49013 .47873 m .49904 .49833 L .48798 .47918 L .742 .562 .65 r
F
.4976 .47716 m .49983 .49963 L .49013 .47873 L F
.53556 .43841 m .51533 .47344 L .47329 .45374 L p .727 .581 .691 r
F P
0 g
s
.53556 .43841 m .47329 .45374 L .47318 .45328 L .727 .581 .691 r
F
.47329 .45374 m .51533 .47344 L p .4976 .47716 L .742 .562 .65 r
F P
0 g
s
.4976 .47716 m .48798 .47918 L .47329 .45374 L .742 .562 .65 r
F
.5 .5 m .48475 .5 L p .4733 .45376 L .638 .526 .71 r
F P
0 g
s
.48798 .47918 m .5 .5 L .4733 .45376 L .638 .526 .71 r
F
.48475 .5 m .46933 .5 L .47329 .45374 L p F P
0 g
s
.47329 .45374 m .4733 .45373 L p .48475 .5 L .638 .526 .71 r
F P
0 g
s
.48798 .47918 m .46388 .48423 L .47329 .45374 L .742 .562 .65 r
F
.4733 .45373 m .48798 .47918 L .4733 .45376 L .638 .526 .71 r
F
.47318 .45328 m .47329 .45374 L .47305 .45332 L .727 .581 .691 r
F
.48797 .52082 m .49999 .5 L .5 .5 L .742 .65 .758 r
F
.46933 .5 m .48477 .5 L p .48142 .5135 L .638 .516 .698 r
F P
0 g
s
.47261 .54658 m .46388 .51577 L .49944 .5 L p .742 .65 .758 r
F P
0 g
s
.48798 .47918 m .49977 .49995 L .46388 .48423 L .742 .562 .65 r
F
.49977 .49995 m .4998 .5 L .4997 .49996 L F
.49977 .49995 m .4997 .49996 L .46388 .48423 L F
.49983 .49963 m .49987 .5 L .49013 .47873 L F
.49987 .5 m .4998 .5 L .49013 .47873 L F
.49904 .49833 m .4998 .5 L .48798 .47918 L F
.49944 .5 m .46388 .48423 L p .4997 .49996 L F P
0 g
s
.4998 .5 m .49944 .5 L .4997 .49996 L .742 .562 .65 r
F
.49944 .5 m .49944 .5 L .4997 .49996 L F
.46933 .5 m .42888 .5 L .43234 .44604 L p .683 .566 .716 r
F P
0 g
s
.47272 .50423 m .46728 .5 L .47596 .5 L .759 .712 .808 r
F
.49944 .5 m .46388 .51577 L p .47272 .50423 L F P
0 g
s
.46122 .5 m .46388 .48423 L .49944 .5 L p .759 .528 .582 r
F P
0 g
s
.47272 .50423 m .47596 .5 L .49944 .5 L .759 .712 .808 r
F
.47261 .54658 m .49944 .5 L .49977 .5 L .742 .65 .758 r
F
.49944 .5 m .49944 .5 L p .47596 .5 L .759 .528 .582 r
F P
0 g
s
.47596 .5 m .46122 .5 L .49944 .5 L .759 .528 .582 r
F
.47596 .5 m .48967 .4821 L .49944 .5 L .759 .712 .808 r
F
.46221 .50589 m .46122 .5 L p .47272 .50423 L F P
0 g
s
.38106 .5 m .42888 .5 L .43234 .55396 L p .718 .577 .695 r
F P
0 g
s
.46388 .51577 m .42383 .52396 L p .45359 .5 L .758 .712 .808 r
F P
0 g
s
.46122 .5 m .46388 .51577 L p .45359 .5 L .758 .712 .808 r
F P
0 g
s
.46388 .48423 m .46122 .5 L p .42969 .49999 L .758 .527 .582 r
F P
0 g
s
.42888 .5 m .38106 .5 L .38368 .44113 L p .718 .596 .719 r
F P
0 g
s
.38368 .44113 m .43234 .44604 L .42888 .5 L p .718 .596 .719 r
F P
0 g
s
.42383 .47604 m .46388 .48423 L p .42967 .5 L .758 .527 .582 r
F P
0 g
s
.45315 .50035 m .42794 .5 L .45359 .5 L .758 .712 .808 r
F
.42383 .52396 m .42794 .5 L p .45315 .50035 L F P
0 g
s
.42794 .5 m .42794 .5 L p .45315 .50035 L .758 .712 .808 r
F P
0 g
s
.43234 .55396 m .38368 .55887 L .38106 .5 L p .718 .577 .695 r
F P
0 g
s
.32917 .5 m .38106 .5 L .38368 .55887 L p .749 .601 .692 r
F P
0 g
s
.42383 .52396 m .37946 .52332 L p .42659 .5 L .761 .714 .809 r
F P
0 g
s
.42383 .47604 m .42794 .5 L p .39948 .49961 L .761 .528 .581 r
F P
0 g
s
.42794 .5 m .42794 .5 L p .42783 .5 L .761 .528 .581 r
F P
0 g
s
.42794 .5 m .42783 .5 L .39948 .49961 L .761 .528 .581 r
F
.37946 .52332 m .39077 .5 L p .42326 .50164 L .761 .714 .809 r
F P
0 g
s
.38106 .5 m .32917 .5 L .33088 .439 L p .749 .623 .719 r
F P
0 g
s
.38368 .55887 m .33088 .561 L .32917 .5 L p .749 .601 .692 r
F P
0 g
s
.37946 .52332 m .33053 .51287 L p .36594 .50254 L .77 .727 .813 r
F P
0 g
s
.27714 .5 m .32917 .5 L .33088 .561 L p .779 .625 .689 r
F P
0 g
s
.32917 .5 m .27714 .5 L .27804 .43992 L p .779 .648 .717 r
F P
0 g
s
.27804 .43992 m .33088 .439 L .32917 .5 L p .779 .648 .717 r
F P
0 g
s
.33088 .561 m .27804 .56008 L .27714 .5 L p .779 .625 .689 r
F P
0 g
s
.27804 .56008 m .33088 .561 L .33592 .6227 L p .778 .6 .658 r
F P
0 g
s
.31444 .56331 m .33053 .51287 L .37946 .52332 L p .791 .69 .754 r
F P
0 g
s
.36594 .50254 m .36494 .49995 L .37481 .49996 L .77 .727 .813 r
F
.34042 .5 m .33053 .48713 L p .36168 .49791 L .77 .531 .573 r
F P
0 g
s
.36759 .49995 m .34042 .5 L .36168 .49791 L .77 .531 .573 r
F
.33088 .439 m .38368 .44113 L .38106 .5 L p .749 .623 .719 r
F P
0 g
s
.33053 .48713 m .37946 .47668 L p .36759 .49995 L .77 .531 .573 r
F P
0 g
s
.33053 .48713 m .34039 .49996 L p .32833 .49874 L .788 .53 .547 r
F P
0 g
s
.34042 .5 m .33053 .51287 L .30564 .50343 L p .787 .757 .825 r
F P
0 g
s
.34039 .49996 m .34042 .5 L p .32833 .49874 L .788 .53 .547 r
F P
0 g
s
.33088 .439 m .27804 .43992 L .28064 .37966 L p .778 .671 .745 r
F P
0 g
s
.31444 .43669 m .33053 .48713 L .2966 .5 L p .822 .617 .625 r
F P
0 g
s
.31444 .43669 m .2966 .5 L .28266 .49813 L .822 .617 .625 r
F
.22867 .5 m .27714 .5 L .27804 .56008 L p .809 .649 .684 r
F P
0 g
s
.27804 .56008 m .22897 .5564 L .22867 .5 L p .809 .649 .684 r
F P
0 g
s
.33053 .51287 m .31444 .56331 L .25206 .55457 L p .822 .726 .759 r
F P
0 g
s
.27714 .5 m .22867 .5 L .22897 .4436 L p .809 .673 .713 r
F P
0 g
s
.22897 .4436 m .27804 .43992 L .27714 .5 L p .809 .673 .713 r
F P
0 g
s
.18649 .5 m .22867 .5 L .22897 .5564 L p .84 .674 .677 r
F P
0 g
s
.22897 .5564 m .18642 .55066 L .18649 .5 L p .84 .674 .677 r
F P
0 g
s
.25206 .55457 m .19194 .5424 L p .23734 .51633 L .868 .787 .768 r
F P
0 g
s
.2836 .49631 m .28045 .49767 L .25206 .44543 L .822 .617 .625 r
F
.27508 .5 m .25206 .44543 L p .2817 .49997 L F P
0 g
s
.23734 .51633 m .26587 .49995 L .27508 .5 L .868 .787 .768 r
F
.27508 .5 m .25206 .55457 L p .23734 .51633 L F P
0 g
s
.25206 .55457 m .27508 .5 L p .33053 .51287 L .822 .726 .759 r
F P
0 g
s
.25206 .44543 m .27508 .5 L p .23626 .49981 L .869 .632 .578 r
F P
0 g
s
.18642 .44934 m .22897 .4436 L .22867 .5 L p .84 .698 .706 r
F P
0 g
s
.22867 .5 m .18649 .5 L .18642 .44934 L p .84 .698 .706 r
F P
0 g
s
.19194 .4576 m .25206 .44543 L p .24168 .48115 L .869 .632 .578 r
F P
0 g
s
.24168 .48115 m .22658 .49069 L .19194 .4576 L .869 .632 .578 r
F
.21183 .5 m .19194 .4576 L p .23623 .4999 L F P
0 g
s
.15197 .5 m .18649 .5 L .18642 .55066 L p .872 .7 .666 r
F P
0 g
s
.18642 .55066 m .15171 .54371 L .15197 .5 L p .872 .7 .666 r
F P
0 g
s
.12518 .5 m .15197 .5 L .15171 .54371 L p .904 .727 .652 r
F P
0 g
s
.18649 .5 m .15197 .5 L .15171 .45629 L p .872 .723 .695 r
F P
0 g
s
.15171 .45629 m .18642 .44934 L .18649 .5 L p .872 .723 .695 r
F P
0 g
s
.12486 .46361 m .15171 .45629 L .15197 .5 L p .904 .749 .679 r
F P
0 g
s
.14753 .46656 m .19194 .4576 L p .19178 .46191 L .935 .634 .447 r
F P
0 g
s
.19178 .46191 m .19036 .49991 L .17342 .48672 L .935 .634 .447 r
F
.19178 .46191 m .17342 .48672 L .14753 .46656 L F
.19036 .49991 m .19035 .49991 L .14753 .46656 L F
.17287 .51252 m .1636 .5 L .18814 .49992 L .935 .893 .764 r
F
.14753 .53344 m .1636 .5 L p .17287 .51252 L F P
0 g
s
.15171 .54371 m .12486 .53639 L .12518 .5 L p .904 .727 .652 r
F P
0 g
s
.13475 .53465 m .15629 .5 L .1636 .5 L .836 .919 .524 r
F
.1636 .5 m .14753 .53344 L .1382 .53433 L p F P
0 g
s
.1382 .53433 m .13475 .53465 L p .1636 .5 L .836 .919 .524 r
F P
0 g
s
.17701 .51811 m .18814 .49992 L .21183 .5 L .935 .893 .764 r
F
.14753 .53344 m .17287 .51252 L .17701 .51811 L F
.17287 .51252 m .18814 .49992 L .17701 .51811 L F
.21183 .5 m .19194 .5424 L .15614 .53518 L p F P
0 g
s
.15614 .53518 m .14753 .53344 L p .21183 .5 L .935 .893 .764 r
F P
0 g
s
.18642 .55066 m .22897 .5564 L .22979 .61245 L p .842 .651 .645 r
F P
0 g
s
.22979 .61245 m .18615 .60055 L .18642 .55066 L p .842 .651 .645 r
F P
0 g
s
.15171 .54371 m .18642 .55066 L .18615 .60055 L p .874 .678 .634 r
F P
0 g
s
.18615 .60055 m .22979 .61245 L .23088 .66741 L p .845 .627 .607 r
F P
0 g
s
.23088 .66741 m .18553 .64864 L .18615 .60055 L p .845 .627 .607 r
F P
0 g
s
.1509 .58644 m .18615 .60055 L .18553 .64864 L p .879 .656 .596 r
F P
0 g
s
.18615 .60055 m .1509 .58644 L .15171 .54371 L p .874 .678 .634 r
F P
0 g
s
.14948 .62702 m .18553 .64864 L .18431 .69335 L p .887 .633 .548 r
F P
0 g
s
.18553 .64864 m .14948 .62702 L .1509 .58644 L p .879 .656 .596 r
F P
0 g
s
.12389 .57173 m .1509 .58644 L .14948 .62702 L p .913 .687 .583 r
F P
0 g
s
.18431 .69335 m .14734 .66398 L .14948 .62702 L p .887 .633 .548 r
F P
0 g
s
.12225 .60491 m .14948 .62702 L .14734 .66398 L p .921 .666 .535 r
F P
0 g
s
.14948 .62702 m .12225 .60491 L .12389 .57173 L p .913 .687 .583 r
F P
0 g
s
.19194 .5424 m .18526 .62907 L .14085 .63072 L p .967 .808 .631 r
F P
0 g
s
.12486 .53639 m .15171 .54371 L .1509 .58644 L p .907 .707 .621 r
F P
0 g
s
.1509 .58644 m .12389 .57173 L .12486 .53639 L p .907 .707 .621 r
F P
0 g
s
.14085 .63072 m .14753 .53344 L .19194 .5424 L p .967 .808 .631 r
F P
0 g
s
.15491 .48823 m .16113 .5 L .15892 .5 L .836 .447 0 r
F
.14753 .46656 m .16356 .49993 L p .15491 .48823 L F P
0 g
s
.16356 .49993 m .18843 .5517 L p .15491 .48823 L .836 .447 0 r
F P
0 g
s
.15494 .48833 m .15892 .5 L .13816 .46567 L .836 .447 0 r
F
.13475 .53465 m .15141 .5 L p .15629 .5 L .836 .919 .524 r
F P
0 g
s
.15892 .5 m .17717 .55357 L .15339 .5 L .836 .447 0 r
F
.15892 .5 m .15339 .5 L .13816 .46567 L F
.16356 .49993 m .14753 .46656 L p .19036 .49991 L .935 .634 .447 r
F P
0 g
s
.22897 .4436 m .18642 .44934 L .18615 .39945 L p .842 .723 .733 r
F P
0 g
s
.18642 .44934 m .15171 .45629 L .1509 .41356 L p .874 .749 .721 r
F P
0 g
s
.1509 .41356 m .18615 .39945 L .18642 .44934 L p .874 .749 .721 r
F P
0 g
s
.18615 .39945 m .22979 .38755 L .22897 .4436 L p .842 .723 .733 r
F P
0 g
s
.22979 .38755 m .18615 .39945 L .18553 .35136 L p .845 .753 .762 r
F P
0 g
s
.18615 .39945 m .1509 .41356 L .14948 .37298 L p .879 .779 .747 r
F P
0 g
s
.14948 .37298 m .18553 .35136 L .18615 .39945 L p .879 .779 .747 r
F P
0 g
s
.15171 .45629 m .12486 .46361 L .12389 .42827 L p .907 .774 .704 r
F P
0 g
s
.12389 .42827 m .1509 .41356 L .15171 .45629 L p .907 .774 .704 r
F P
0 g
s
.18526 .37093 m .19194 .4576 L .14753 .46656 L p .968 .773 .588 r
F P
0 g
s
.17717 .44643 m .18843 .4483 L p .15629 .5 L .836 .919 .524 r
F P
0 g
s
.13475 .46535 m .13816 .46567 L p .15339 .5 L .836 .447 0 r
F P
0 g
s
.15197 .5 m .12518 .5 L .12486 .46361 L p .904 .749 .679 r
F P
0 g
s
.15141 .5 m .13475 .46535 L p .15339 .5 L .836 .447 0 r
F P
0 g
s
.15141 .5 m .17717 .44643 L p .15629 .5 L .836 .919 .524 r
F P
0 g
s
.18843 .5517 m .17717 .55357 L p .15892 .5 L .836 .447 0 r
F P
0 g
s
.16113 .5 m .18843 .5517 L .15892 .5 L .836 .447 0 r
F
.18814 .49992 m .19036 .49991 L .21183 .5 L .935 .893 .764 r
F
.19036 .49991 m .21183 .5 L .19036 .49991 L .935 .634 .447 r
F
.19194 .4576 m .2118 .49993 L p .19036 .49991 L F P
0 g
s
.2118 .49993 m .21183 .5 L p .19036 .49991 L .935 .634 .447 r
F P
0 g
s
.27804 .43992 m .22897 .4436 L .22979 .38755 L p .81 .697 .741 r
F P
0 g
s
.22979 .38755 m .28064 .37966 L .27804 .43992 L p .81 .697 .741 r
F P
0 g
s
.28064 .37966 m .22979 .38755 L .23088 .33259 L p .811 .725 .77 r
F P
0 g
s
.24706 .37201 m .25206 .44543 L .19194 .4576 L p .887 .717 .666 r
F P
0 g
s
.18553 .35136 m .23088 .33259 L .22979 .38755 L p .845 .753 .762 r
F P
0 g
s
.19194 .4576 m .18526 .37093 L .24706 .37201 L p .887 .717 .666 r
F P
0 g
s
.18843 .4483 m .22688 .46793 L p .18815 .49991 L .935 .893 .764 r
F P
0 g
s
.18814 .49992 m .18814 .49991 L .18815 .49991 L .935 .893 .764 r
F
.18814 .49991 m .18843 .4483 L .18815 .49991 L F
.21188 .49991 m .21183 .5 L p .19036 .49991 L F P
0 g
s
.19194 .5424 m .2119 .49986 L p .26587 .49995 L .868 .787 .768 r
F P
0 g
s
.22897 .5564 m .27804 .56008 L .28064 .62034 L p .81 .625 .652 r
F P
0 g
s
.28064 .62034 m .22979 .61245 L .22897 .5564 L p .81 .625 .652 r
F P
0 g
s
.18526 .62907 m .19194 .5424 L .25206 .55457 L p .887 .732 .684 r
F P
0 g
s
.22688 .53207 m .18843 .5517 L p .19036 .49991 L .935 .634 .447 r
F P
0 g
s
.21183 .5 m .22688 .53207 L p .19036 .49991 L .935 .634 .447 r
F P
0 g
s
.18843 .5517 m .1636 .5 L p .19036 .49991 L .935 .634 .447 r
F P
0 g
s
.1636 .5 m .16356 .49993 L p .16365 .49993 L .935 .634 .447 r
F P
0 g
s
.19036 .49991 m .1636 .5 L .16365 .49993 L .935 .634 .447 r
F
.18843 .4483 m .1636 .5 L p .15629 .5 L .836 .919 .524 r
F P
0 g
s
.17717 .55357 m .15141 .5 L p .15339 .5 L .836 .447 0 r
F P
0 g
s
.13816 .46567 m .14753 .46656 L p .15494 .48833 L .836 .447 0 r
F P
0 g
s
.1636 .5 m .18843 .4483 L p .18814 .49992 L .935 .893 .764 r
F P
0 g
s
.19036 .49991 m .19036 .49991 L .19035 .49991 L .935 .634 .447 r
F
.22688 .46793 m .21188 .49991 L p .18814 .49992 L .935 .893 .764 r
F P
0 g
s
.24168 .48115 m .23623 .4999 L .22658 .49069 L .869 .632 .578 r
F
.22688 .53207 m .21183 .5 L p .23623 .4999 L F P
0 g
s
.22688 .46793 m .27805 .49296 L p .26616 .49979 L .868 .787 .768 r
F P
0 g
s
.26587 .49995 m .26566 .49979 L .26616 .49979 L .868 .787 .768 r
F
.26566 .49979 m .22688 .46793 L .26616 .49979 L F
.23626 .49981 m .23681 .49991 L .23623 .4999 L .869 .632 .578 r
F
.27508 .5 m .27805 .50704 L p .23626 .49981 L F P
0 g
s
.2119 .49986 m .22688 .46793 L p .26587 .49995 L .868 .787 .768 r
F P
0 g
s
.27805 .50704 m .22688 .53207 L p .23623 .4999 L .869 .632 .578 r
F P
0 g
s
.23681 .49991 m .27805 .50704 L .23623 .4999 L .869 .632 .578 r
F
.27805 .49296 m .27508 .5 L p .26587 .49995 L .868 .787 .768 r
F P
0 g
s
.25206 .44543 m .31444 .43669 L p .2836 .49631 L .822 .617 .625 r
F P
0 g
s
.2836 .49631 m .2817 .49997 L .28045 .49767 L .822 .617 .625 r
F
.27508 .5 m .27526 .5 L .33053 .51287 L .822 .726 .759 r
F
.2966 .5 m .33053 .51287 L p .27509 .49996 L F P
0 g
s
.27805 .50704 m .27508 .5 L p .2817 .49997 L .822 .617 .625 r
F P
0 g
s
.27508 .5 m .27509 .49996 L p .27526 .5 L .822 .726 .759 r
F P
0 g
s
.28266 .49813 m .2966 .5 L .2817 .49997 L .822 .617 .625 r
F
.27509 .49996 m .27805 .49296 L .2966 .5 L p .822 .726 .759 r
F P
0 g
s
.2966 .5 m .27805 .50704 L p .2817 .49997 L .822 .617 .625 r
F P
0 g
s
.31895 .54824 m .27805 .50704 L .2966 .5 L p .788 .53 .547 r
F P
0 g
s
.2966 .5 m .33053 .48713 L p .3281 .49996 L .788 .53 .547 r
F P
0 g
s
.2972 .5 m .34042 .5 L .31516 .50249 L .787 .757 .825 r
F
.3281 .49996 m .34042 .5 L .2972 .5 L F
.30564 .50343 m .2966 .5 L p .31516 .50249 L F P
0 g
s
.2966 .5 m .29625 .49987 L p .31516 .50249 L .787 .757 .825 r
F P
0 g
s
.3281 .49996 m .31895 .54824 L .2966 .5 L .788 .53 .547 r
F
.29625 .49987 m .3281 .49996 L .2972 .5 L .787 .757 .825 r
F
.33053 .51287 m .34042 .5 L p .36594 .50254 L .77 .727 .813 r
F P
0 g
s
.34042 .5 m .35674 .52122 L p .32989 .49997 L .788 .53 .547 r
F P
0 g
s
.34042 .5 m .32989 .49997 L .32833 .49874 L .788 .53 .547 r
F
.35674 .52122 m .31895 .54824 L p .32832 .49879 L F P
0 g
s
.32833 .49874 m .32841 .4988 L .32832 .49879 L .788 .53 .547 r
F
.32841 .4988 m .35674 .52122 L .32832 .49879 L F
.29625 .49987 m .27805 .49296 L p .34042 .5 L .787 .757 .825 r
F P
0 g
s
.38368 .44113 m .33088 .439 L .33592 .3773 L p .747 .643 .745 r
F P
0 g
s
.28064 .37966 m .33592 .3773 L .33088 .439 L p .778 .671 .745 r
F P
0 g
s
.33053 .48713 m .31444 .43669 L .37272 .43475 L p .791 .602 .645 r
F P
0 g
s
.37272 .43475 m .37946 .47668 L .33053 .48713 L p .791 .602 .645 r
F P
0 g
s
.35674 .47878 m .34042 .5 L p .27805 .49296 L .787 .757 .825 r
F P
0 g
s
.36494 .49995 m .36494 .49995 L .36759 .49995 L .77 .727 .813 r
F
.36494 .49995 m .36759 .49995 L .37481 .49996 L F
.34042 .5 m .35674 .47878 L p .36594 .50254 L F P
0 g
s
.36594 .50254 m .37481 .49996 L .37552 .50351 L .77 .727 .813 r
F
.36594 .50254 m .37552 .50351 L .37946 .52332 L F
.35674 .52122 m .34042 .5 L p .36759 .49995 L .77 .531 .573 r
F P
0 g
s
.39077 .5 m .37946 .52332 L p .37481 .49996 L .77 .727 .813 r
F P
0 g
s
.39343 .50547 m .35674 .52122 L p .36759 .49995 L .77 .531 .573 r
F P
0 g
s
.3676 .49994 m .36764 .49995 L .36759 .49995 L .77 .531 .573 r
F
.36764 .49995 m .39343 .50547 L .36759 .49995 L F
.37946 .47668 m .39077 .5 L p .36815 .49886 L F P
0 g
s
.39077 .5 m .39343 .50547 L p .36815 .49886 L .77 .531 .573 r
F P
0 g
s
.39077 .5 m .37946 .47668 L p .39909 .49999 L .761 .528 .581 r
F P
0 g
s
.35674 .47878 m .39343 .49453 L p .37481 .49996 L .77 .727 .813 r
F P
0 g
s
.36815 .49886 m .37234 .49995 L .3676 .49994 L .77 .531 .573 r
F
.37234 .49995 m .39343 .50547 L .3676 .49994 L F
.36494 .49995 m .35674 .47878 L .37481 .49996 L .77 .727 .813 r
F
.39343 .49453 m .39077 .5 L p .37481 .49996 L F P
0 g
s
.42326 .50164 m .39077 .5 L .42659 .5 L .761 .714 .809 r
F
.39077 .5 m .39078 .49999 L p .39909 .49999 L F P
0 g
s
.39077 .5 m .39909 .49999 L .42659 .5 L .761 .714 .809 r
F
.37946 .47668 m .42383 .47604 L p .39909 .49999 L .761 .528 .581 r
F P
0 g
s
.39343 .50547 m .39077 .5 L p .39909 .49999 L .761 .528 .581 r
F P
0 g
s
.42794 .5 m .42383 .52396 L p .42659 .5 L .761 .714 .809 r
F P
0 g
s
.42794 .5 m .42807 .50074 L p .39948 .49961 L .761 .528 .581 r
F P
0 g
s
.42794 .5 m .42383 .47604 L p .42967 .5 L .758 .527 .582 r
F P
0 g
s
.39343 .49453 m .42807 .49926 L p .42659 .5 L .761 .714 .809 r
F P
0 g
s
.42807 .50074 m .39343 .50547 L p .39912 .49996 L .761 .528 .581 r
F P
0 g
s
.39948 .49961 m .40875 .49997 L .39912 .49996 L .761 .528 .581 r
F
.40875 .49997 m .42807 .50074 L .39912 .49996 L F
.39078 .49999 m .39343 .49453 L p .42659 .5 L .761 .714 .809 r
F P
0 g
s
.42807 .49926 m .42794 .5 L p .42659 .5 L .761 .714 .809 r
F P
0 g
s
.42807 .50074 m .42794 .5 L p .42967 .5 L .758 .527 .582 r
F P
0 g
s
.42807 .49926 m .46031 .49458 L p .45359 .49999 L .758 .712 .808 r
F P
0 g
s
.45359 .5 m .45337 .49999 L .45359 .49999 L .758 .712 .808 r
F
.45337 .49999 m .42807 .49926 L .45359 .49999 L F
.42969 .49999 m .45359 .5 L .42967 .5 L .758 .527 .582 r
F
.42794 .5 m .42807 .49926 L p .45359 .5 L .758 .712 .808 r
F P
0 g
s
.42967 .5 m .46122 .5 L .42935 .50015 L .758 .527 .582 r
F
.45359 .5 m .46122 .5 L .42967 .5 L F
.46031 .49458 m .46122 .5 L p .45359 .5 L .758 .712 .808 r
F P
0 g
s
.46122 .5 m .46031 .49458 L p .46724 .49997 L .759 .712 .808 r
F P
0 g
s
.46122 .5 m .46724 .49997 L .47272 .50423 L .759 .712 .808 r
F
.46031 .50542 m .42807 .50074 L p .42935 .50015 L .758 .527 .582 r
F P
0 g
s
.46122 .5 m .46031 .50542 L p .42935 .50015 L .758 .527 .582 r
F P
0 g
s
.47261 .54658 m .49977 .5 L .49999 .5 L .742 .65 .758 r
F
.47261 .54658 m .49999 .5 L .47372 .54551 L F
.50762 .48681 m .5 .5 L p .4976 .47716 L .742 .562 .65 r
F P
0 g
s
.5 .5 m .49989 .5002 L p .49987 .5 L .742 .562 .65 r
F P
0 g
s
.5 .5 m .49986 .49999 L .4976 .47716 L .742 .562 .65 r
F
.4871 .41443 m .53556 .43841 L p .47318 .45328 L .727 .581 .691 r
F P
0 g
s
.47318 .45328 m .47305 .45332 L .47309 .45319 L .727 .581 .691 r
F
.47318 .45328 m .47309 .45319 L .4871 .41443 L F
.4728 .45289 m .4871 .41443 L p .47305 .45332 L F P
0 g
s
.43234 .44604 m .38368 .44113 L .39154 .38124 L p .715 .613 .742 r
F P
0 g
s
.39154 .38124 m .42564 .38782 L p .43234 .44604 L .715 .613 .742 r
F P
0 g
s
.50717 .36983 m .4871 .41443 L .44144 .39857 L p .733 .62 .732 r
F P
0 g
s
.42564 .38782 m .43643 .3899 L p .43658 .39519 L .715 .613 .742 r
F P
0 g
s
.44111 .39363 m .44144 .39857 L .43904 .39438 L .733 .62 .732 r
F
.50717 .36983 m .44144 .39857 L .44111 .39363 L F
.45138 .34669 m .50717 .36983 L p .44199 .39331 L F P
0 g
s
.44199 .39331 m .44128 .39287 L .45138 .34669 L .733 .62 .732 r
F
.44111 .39363 m .43904 .39438 L .44072 .38787 L F
.44111 .39363 m .44072 .38787 L .45138 .34669 L F
.43643 .3899 m .39154 .38124 L .39507 .36451 L p .708 .63 .768 r
F P
0 g
s
.39507 .36451 m .40221 .33063 L p .43643 .3899 L .708 .63 .768 r
F P
0 g
s
.40221 .33063 m .45138 .34669 L p .42029 .36181 L .758 .647 .739 r
F P
0 g
s
.47577 .29655 m .45138 .34669 L .40221 .33063 L p .744 .665 .773 r
F P
0 g
s
.34401 .31461 m .39543 .31888 L p .37723 .36117 L .743 .664 .774 r
F P
0 g
s
.39154 .38124 m .33592 .3773 L .34401 .31461 L p .743 .664 .774 r
F P
0 g
s
.28462 .31948 m .34401 .31461 L .33592 .3773 L p .777 .696 .774 r
F P
0 g
s
.35782 .24975 m .41745 .27221 L p .4033 .27831 L .774 .702 .784 r
F P
0 g
s
.4033 .27831 m .37838 .28907 L .35988 .25368 L .774 .702 .784 r
F
.4033 .27831 m .35988 .25368 L .35782 .24975 L F
.37838 .28907 m .37821 .28877 L .35782 .24975 L F
.35675 .25497 m .35677 .25192 L .36519 .26639 L .734 .688 .806 r
F
.35437 .25175 m .35677 .25192 L p .35675 .25497 L F P
0 g
s
.35677 .25192 m .35437 .25175 L .35456 .25067 L p .72 .718 .848 r
F P
0 g
s
.34401 .31461 m .28462 .31948 L .28932 .26065 L p .773 .725 .808 r
F P
0 g
s
.28932 .26065 m .35437 .25175 L .34401 .31461 L p .773 .725 .808 r
F P
0 g
s
.23179 .28026 m .28932 .26065 L .28462 .31948 L p .812 .759 .803 r
F P
0 g
s
.35437 .25175 m .28932 .26065 L .28937 .26002 L p .768 .764 .849 r
F P
0 g
s
.28937 .26002 m .29367 .20606 L p .31336 .22088 L .768 .764 .849 r
F P
0 g
s
.31336 .22088 m .35437 .25175 L .28937 .26002 L .768 .764 .849 r
F
.39806 .19788 m .35782 .24975 L .35492 .24872 L p .783 .769 .84 r
F P
0 g
s
.31336 .22088 m .33269 .20996 L .35437 .25175 L .768 .764 .849 r
F
.32645 .1994 m .34861 .17434 L p .34199 .19902 L .783 .769 .84 r
F P
0 g
s
.33707 .21738 m .32645 .1994 L .34199 .19902 L .783 .769 .84 r
F
.34861 .17434 m .35581 .17777 L p .33707 .21738 L F P
0 g
s
.35581 .17777 m .39806 .19788 L p .35546 .2115 L .783 .769 .84 r
F P
0 g
s
.35546 .2115 m .33707 .21738 L .35581 .17777 L .783 .769 .84 r
F
.39806 .19788 m .35492 .24872 L .33707 .21738 L F
.35492 .24872 m .35782 .24975 L p .35604 .25065 L .81 .749 .796 r
F P
0 g
s
.35678 .25028 m .35635 .25119 L .35604 .25065 L .81 .749 .796 r
F
.35782 .24975 m .35677 .25192 L p .35678 .25028 L F P
0 g
s
.35456 .25067 m .35492 .24872 L p .35677 .25192 L .72 .718 .848 r
F P
0 g
s
.35604 .25065 m .35677 .25192 L .35492 .24872 L .72 .718 .848 r
F
.34401 .31461 m .35437 .25175 L p .36519 .26639 L .734 .688 .806 r
F P
0 g
s
.35677 .25192 m .32816 .31073 L p .35678 .25028 L .81 .749 .796 r
F P
0 g
s
.36543 .19148 m .35677 .25192 L .35507 .24895 L .72 .718 .848 r
F
.35492 .2487 m .35508 .24786 L p .35507 .24895 L F P
0 g
s
.35508 .24786 m .36543 .19148 L p .35507 .24895 L .72 .718 .848 r
F P
0 g
s
.29618 .16051 m .30097 .16265 L .29975 .1651 L .755 .818 .902 r
F
.29399 .2002 m .29618 .16051 L p .32645 .1994 L F P
0 g
s
.30791 .15374 m .31969 .15971 L p .30971 .1591 L .819 .84 .865 r
F P
0 g
s
.3186 .18558 m .31847 .18536 L .30791 .15374 L .819 .84 .865 r
F
.30294 .15869 m .29618 .16051 L .29611 .15828 L p .712 .894 .962 r
F P
0 g
s
.29611 .15828 m .29576 .14624 L p .30294 .15869 L .712 .894 .962 r
F P
0 g
s
.29576 .14624 m .30791 .15374 L p .30177 .15665 L .845 .94 .886 r
F P
0 g
s
.37086 .11419 m .30791 .15374 L .29582 .14628 L p .761 .934 .942 r
F P
0 g
s
.37086 .11419 m .29582 .14628 L .29583 .14621 L .761 .934 .942 r
F
.37086 .11419 m .29576 .14624 L .29813 .13352 L F
.30791 .15374 m .37086 .11419 L .40301 .13442 L p .767 .848 .912 r
F P
0 g
s
.45763 .10856 m .40301 .13442 L .37086 .11419 L p .703 .842 .949 r
F P
0 g
s
.37086 .11419 m .4328 .09041 L .45763 .10856 L p .703 .842 .949 r
F P
0 g
s
.35146 .09885 m .36963 .11322 L p .30831 .1269 L .761 .934 .942 r
F P
0 g
s
.29528 .13016 m .29511 .12985 L p .29695 .12944 L .505 .907 .912 r
F P
0 g
s
.29895 .12899 m .29704 .1296 L p .29695 .12944 L .505 .907 .912 r
F P
0 g
s
.29704 .1296 m .29528 .13016 L p .29695 .12944 L .505 .907 .912 r
F P
0 g
s
.35146 .09885 m .29695 .12944 L p .29285 .12197 L .616 .958 .868 r
F P
0 g
s
.29528 .13016 m .29895 .12899 L p .29867 .13056 L .712 .894 .962 r
F P
0 g
s
.29575 .14617 m .29528 .13016 L p .29734 .13783 L .712 .894 .962 r
F P
0 g
s
.30464 .15529 m .30235 .15765 L .30177 .15665 L .845 .94 .886 r
F
.30177 .15665 m .30294 .15869 L .29576 .14624 L .712 .894 .962 r
F
.29618 .16051 m .30294 .15869 L p .30097 .16265 L .755 .818 .902 r
F P
0 g
s
.29367 .20606 m .23189 .23322 L .23046 .19525 L p .813 .864 .886 r
F P
0 g
s
.23046 .19525 m .29618 .16051 L .29367 .20606 L p .813 .864 .886 r
F P
0 g
s
.30463 .15531 m .25041 .21111 L .30464 .15529 L .845 .94 .886 r
F
.30296 .15868 m .25041 .21111 L p .30466 .15528 L F P
0 g
s
.29734 .13783 m .30294 .15869 L .2958 .14625 L .712 .894 .962 r
F
.29582 .14628 m .29576 .14624 L p .29583 .14621 L .761 .934 .942 r
F P
0 g
s
.29734 .13783 m .2958 .14625 L .29575 .14617 L .712 .894 .962 r
F
.29814 .13352 m .29813 .13352 L .29813 .13349 L .761 .934 .942 r
F
.30466 .15528 m .30463 .15531 L .30464 .15529 L .845 .94 .886 r
F
.30791 .15374 m .30296 .15868 L p .30466 .15528 L F P
0 g
s
.30097 .16265 m .30459 .16151 L .30676 .16524 L .755 .818 .902 r
F
.30294 .15869 m .30459 .16151 L .30097 .16265 L F
.29975 .1651 m .30676 .16524 L .32645 .1994 L F
.30097 .16265 m .30676 .16524 L .29975 .1651 L F
.30676 .16524 m .31855 .1856 L .32645 .1994 L F
.25041 .21111 m .30294 .15869 L p .31855 .1856 L .819 .84 .865 r
F P
0 g
s
.30294 .15869 m .30296 .15868 L p .30676 .16524 L .819 .84 .865 r
F P
0 g
s
.31855 .1856 m .30294 .15869 L .30676 .16524 L .819 .84 .865 r
F
.34861 .17434 m .3186 .18558 L .30971 .1591 L F
.31969 .15971 m .34861 .17434 L p .30971 .1591 L F P
0 g
s
.30296 .15868 m .30791 .15374 L p .31855 .1856 L .819 .84 .865 r
F P
0 g
s
.40301 .13442 m .34861 .17434 L .30791 .15374 L p .767 .848 .912 r
F P
0 g
s
.30294 .15869 m .37461 .1394 L p .30459 .16151 L .755 .818 .902 r
F P
0 g
s
.37461 .1394 m .30294 .15869 L p .29734 .13783 L .712 .894 .962 r
F P
0 g
s
.29528 .13016 m .29867 .13056 L .29734 .13783 L .712 .894 .962 r
F
.29814 .13352 m .29813 .13349 L .29867 .13056 L .761 .934 .942 r
F
.37086 .11419 m .29814 .13352 L .30831 .1269 L F
.29908 .12824 m .35146 .09885 L p .29814 .13352 L F P
0 g
s
.29867 .13056 m .37461 .1394 L .29734 .13783 L .712 .894 .962 r
F
.29867 .13056 m .29695 .12944 L .29895 .12899 L .761 .934 .942 r
F
.29813 .13349 m .29695 .12944 L .29867 .13056 L F
.28968 .13575 m .28373 .13735 L .28872 .13406 L F
.28207 .13779 m .28872 .13406 L p .28373 .13735 L F P
0 g
s
.28207 .13779 m .27644 .12844 L p .2838 .12554 L .616 .958 .868 r
F P
0 g
s
.29695 .12944 m .29908 .12824 L p .29895 .12899 L .761 .934 .942 r
F P
0 g
s
.4328 .09041 m .37086 .11419 L .35146 .09885 L p .668 .907 .978 r
F P
0 g
s
.37867 .10358 m .29895 .12899 L p .29434 .12468 L .505 .907 .912 r
F P
0 g
s
.29 .12061 m .29191 .12025 L .29434 .12468 L .505 .907 .912 r
F
.3482 .09005 m .35146 .09885 L p .29285 .12197 L .616 .958 .868 r
F P
0 g
s
.29188 .12018 m .3482 .09005 L p .29285 .12197 L .616 .958 .868 r
F P
0 g
s
.29191 .12025 m .37867 .10358 L .29434 .12468 L .505 .907 .912 r
F
.29511 .12985 m .29 .12061 L p .29895 .12899 L F P
0 g
s
.35146 .09885 m .4186 .07685 L .4328 .09041 L p .668 .907 .978 r
F P
0 g
s
.29 .12061 m .37508 .09186 L .37867 .10358 L p .505 .907 .912 r
F P
0 g
s
.29 .12061 m .29528 .13016 L p .28829 .1333 L .64 .966 .854 r
F P
0 g
s
.27644 .12844 m .28335 .12475 L p .2838 .12554 L .616 .958 .868 r
F P
0 g
s
.28684 .13079 m .28207 .13779 L .2838 .12554 L .616 .958 .868 r
F
.28335 .12475 m .29 .12061 L p .28829 .1333 L .64 .966 .854 r
F P
0 g
s
.28829 .1333 m .29325 .13107 L .2886 .13385 L .64 .966 .854 r
F
.29528 .13016 m .28872 .13406 L p .29325 .13107 L F P
0 g
s
.29325 .13107 m .28872 .13406 L .2886 .13385 L .64 .966 .854 r
F
.28872 .13406 m .29528 .13016 L .29576 .14624 L p .79 .944 .925 r
F P
0 g
s
.29576 .14624 m .28207 .13779 L p .28969 .13576 L .761 .934 .942 r
F P
0 g
s
.27922 .14038 m .28207 .13779 L .29576 .14624 L p .845 .94 .886 r
F P
0 g
s
.28872 .13406 m .29576 .14624 L .28969 .13576 L .79 .944 .925 r
F
.29813 .13352 m .28207 .13779 L .29813 .13349 L .761 .934 .942 r
F
.25515 .16659 m .28872 .13406 L .29618 .16051 L .79 .944 .925 r
F
.22686 .17078 m .28061 .13887 L p .25515 .16659 L F P
0 g
s
.28207 .13779 m .28071 .13903 L p .28082 .13865 L .731 .985 .781 r
F P
0 g
s
.28071 .13903 m .27922 .14038 L p .28061 .13887 L .731 .985 .781 r
F P
0 g
s
.28071 .13903 m .28061 .13887 L .28082 .13865 L .731 .985 .781 r
F
.28872 .13406 m .28207 .13779 L p .28684 .13079 L .616 .958 .868 r
F P
0 g
s
.28872 .13406 m .28061 .13887 L p .2886 .13385 L .64 .966 .854 r
F P
0 g
s
.28061 .13887 m .22686 .17078 L p .2805 .1387 L .64 .966 .854 r
F P
0 g
s
.29618 .16051 m .23046 .19525 L .23023 .19371 L p .79 .944 .925 r
F P
0 g
s
.23023 .19371 m .22686 .17078 L p .25515 .16659 L .79 .944 .925 r
F P
0 g
s
.25515 .16659 m .29618 .16051 L .23023 .19371 L .79 .944 .925 r
F
.27644 .12844 m .28189 .13749 L p .2804 .13852 L .731 .985 .781 r
F P
0 g
s
.27503 .12968 m .27644 .12844 L p .2804 .13852 L .731 .985 .781 r
F P
0 g
s
.2796 .1372 m .28335 .12475 L .28829 .1333 L .64 .966 .854 r
F
.22087 .16356 m .27513 .12985 L p .2796 .1372 L F P
0 g
s
.27513 .12985 m .28335 .12475 L p .2796 .1372 L .64 .966 .854 r
F P
0 g
s
.22686 .17078 m .22087 .16356 L p .28829 .1333 L .64 .966 .854 r
F P
0 g
s
.28189 .13749 m .28207 .13779 L p .28085 .13863 L .731 .985 .781 r
F P
0 g
s
.28085 .13863 m .28057 .13881 L .28189 .13749 L .731 .985 .781 r
F
.28829 .1333 m .2886 .13385 L .2805 .1387 L .64 .966 .854 r
F
.28022 .13823 m .2805 .1387 L .22686 .17078 L F
.28057 .13881 m .2804 .13852 L .28189 .13749 L .731 .985 .781 r
F
.28829 .1333 m .2805 .1387 L .28022 .13823 L .64 .966 .854 r
F
.17424 .21793 m .22686 .17078 L .23046 .19525 L p .852 .97 .871 r
F P
0 g
s
.28057 .13881 m .209 .18775 L .2804 .13852 L .731 .985 .781 r
F
.209 .18775 m .27503 .12968 L p .2804 .13852 L F P
0 g
s
.21736 .19671 m .209 .18775 L p .28082 .13865 L .731 .985 .781 r
F P
0 g
s
.27922 .14038 m .21736 .19671 L p .28082 .13865 L .731 .985 .781 r
F P
0 g
s
.2886 .13385 m .28061 .13887 L .2805 .1387 L .64 .966 .854 r
F
.28061 .13887 m .28872 .13406 L p .25515 .16659 L .79 .944 .925 r
F P
0 g
s
.29576 .14646 m .29618 .16051 L p .28872 .13406 L .79 .944 .925 r
F P
0 g
s
.21736 .19671 m .27922 .14038 L p .29576 .14624 L .845 .94 .886 r
F P
0 g
s
.29576 .14624 m .29576 .14646 L p .29561 .14619 L .79 .944 .925 r
F P
0 g
s
.28969 .13576 m .29576 .14624 L .29561 .14619 L .79 .944 .925 r
F
.29576 .14624 m .29575 .14617 L p .29577 .14619 L .712 .894 .962 r
F P
0 g
s
.29813 .13352 m .29576 .14624 L .28969 .13576 L .761 .934 .942 r
F
.29695 .12944 m .28872 .13406 L p .29285 .12197 L .616 .958 .868 r
F P
0 g
s
.28872 .13406 m .28684 .13079 L .29285 .12197 L .616 .958 .868 r
F
.29285 .12197 m .2838 .12554 L .29188 .12018 L F
.28335 .12475 m .29188 .12018 L p .2838 .12554 L F P
0 g
s
.29285 .12197 m .28684 .13079 L .2838 .12554 L .616 .958 .868 r
F
.29813 .13349 m .28968 .13575 L .29695 .12944 L .761 .934 .942 r
F
.28872 .13406 m .29695 .12944 L p .28968 .13575 L F P
0 g
s
.36963 .11322 m .37086 .11419 L p .30831 .1269 L .761 .934 .942 r
F P
0 g
s
.29867 .13056 m .29897 .12899 L .29868 .13056 L .712 .894 .962 r
F
.29895 .12899 m .29897 .12899 L p .29867 .13056 L F P
0 g
s
.37867 .10358 m .37461 .1394 L p .29868 .13056 L .712 .894 .962 r
F P
0 g
s
.29897 .12899 m .37867 .10358 L p .29868 .13056 L .712 .894 .962 r
F P
0 g
s
.29577 .14619 m .30177 .15665 L .29576 .14624 L .712 .894 .962 r
F
.30177 .15665 m .21736 .19671 L .29576 .14624 L .845 .94 .886 r
F
.17888 .23701 m .23046 .19525 L .23189 .23322 L p .864 .897 .856 r
F P
0 g
s
.23046 .19525 m .17888 .23701 L .17424 .21793 L p .852 .97 .871 r
F P
0 g
s
.25041 .21111 m .21736 .19671 L p .30177 .15665 L .845 .94 .886 r
F P
0 g
s
.30235 .15765 m .25041 .21111 L .30177 .15665 L .845 .94 .886 r
F
.3186 .18558 m .31855 .1856 L .31847 .18536 L .819 .84 .865 r
F
.3186 .18558 m .32498 .19683 L .31855 .1856 L F
.33969 .17768 m .32503 .19676 L .3186 .18558 L F
.32503 .19676 m .32498 .19683 L .3186 .18558 L F
.33986 .17762 m .33923 .17843 L .33969 .17768 L F
.32645 .1994 m .29367 .20606 L .29399 .2002 L p .755 .818 .902 r
F P
0 g
s
.29367 .20606 m .32645 .1994 L p .31336 .22088 L .768 .764 .849 r
F P
0 g
s
.33923 .17843 m .3001 .2292 L .33969 .17768 L .819 .84 .865 r
F
.34861 .17434 m .32666 .19916 L p .33986 .17762 L F P
0 g
s
.32666 .19916 m .3001 .2292 L p .33986 .17762 L .819 .84 .865 r
F P
0 g
s
.44381 .15785 m .39806 .19788 L .34861 .17434 L p .747 .78 .88 r
F P
0 g
s
.34861 .17434 m .40301 .13442 L .44381 .15785 L p .747 .78 .88 r
F P
0 g
s
.37461 .1394 m .36543 .19148 L p .30694 .16533 L .755 .818 .902 r
F P
0 g
s
.30676 .16524 m .30687 .1652 L .30694 .16533 L .755 .818 .902 r
F
.30687 .1652 m .37461 .1394 L .30694 .16533 L F
.30459 .16151 m .37461 .1394 L .30676 .16524 L F
.30676 .16524 m .30694 .16533 L .31855 .1856 L F
.23189 .23322 m .29367 .20606 L .28932 .26065 L p .814 .803 .841 r
F P
0 g
s
.3001 .2292 m .25041 .21111 L p .31855 .1856 L .819 .84 .865 r
F P
0 g
s
.32498 .19683 m .3001 .2292 L .31855 .1856 L .819 .84 .865 r
F
.36543 .19148 m .32645 .1994 L p .30694 .16533 L .755 .818 .902 r
F P
0 g
s
.33269 .20996 m .33281 .2099 L .33388 .21198 L .768 .764 .849 r
F
.33269 .20996 m .33388 .21198 L .35437 .25175 L F
.35492 .24872 m .35437 .25175 L p .33281 .2099 L F P
0 g
s
.32645 .1994 m .36543 .19148 L p .31336 .22088 L .768 .764 .849 r
F P
0 g
s
.3001 .2292 m .32645 .1994 L p .33707 .21738 L .783 .769 .84 r
F P
0 g
s
.35492 .24872 m .3001 .2292 L p .33707 .21738 L .783 .769 .84 r
F P
0 g
s
.36543 .19148 m .35492 .24872 L p .33281 .2099 L .768 .764 .849 r
F P
0 g
s
.28932 .26065 m .23179 .28026 L .23189 .23322 L p .814 .803 .841 r
F P
0 g
s
.26421 .29697 m .3001 .2292 L .35492 .24872 L p .81 .749 .796 r
F P
0 g
s
.35604 .25065 m .26421 .29697 L .35492 .24872 L .81 .749 .796 r
F
.35492 .24872 m .35492 .2487 L p .35604 .25065 L .72 .718 .848 r
F P
0 g
s
.32816 .31073 m .26421 .29697 L p .35604 .25065 L .81 .749 .796 r
F P
0 g
s
.35635 .25119 m .32816 .31073 L .35604 .25065 L .81 .749 .796 r
F
.36519 .26639 m .36593 .26767 L .34401 .31461 L .734 .688 .806 r
F
.35677 .25191 m .35782 .24975 L p .37836 .28907 L .774 .702 .784 r
F P
0 g
s
.39543 .31888 m .34401 .31461 L p .36601 .2675 L .734 .688 .806 r
F P
0 g
s
.32816 .31073 m .35677 .25191 L p .37836 .28907 L .774 .702 .784 r
F P
0 g
s
.45135 .22321 m .41745 .27221 L .35782 .24975 L p .752 .718 .82 r
F P
0 g
s
.35782 .24975 m .39806 .19788 L .45135 .22321 L p .752 .718 .82 r
F P
0 g
s
.42201 .25655 m .35677 .25192 L p .36543 .19148 L .72 .718 .848 r
F P
0 g
s
.37838 .28907 m .39527 .31859 L .37836 .28907 L .774 .702 .784 r
F
.41507 .27324 m .39528 .31855 L .37838 .28907 L F
.39528 .31855 m .39527 .31859 L .37838 .28907 L F
.41745 .27221 m .39543 .31888 L p .41507 .27324 L F P
0 g
s
.39543 .31888 m .39153 .32714 L p .41507 .27324 L .774 .702 .784 r
F P
0 g
s
.41745 .27221 m .47577 .29655 L p .40367 .32273 L .744 .665 .773 r
F P
0 g
s
.40367 .32273 m .39907 .3244 L .4079 .29932 L .744 .665 .773 r
F
.40367 .32273 m .4079 .29932 L .41745 .27221 L F
.47577 .29655 m .40221 .33063 L .39907 .3244 L F
.43546 .35443 m .43456 .38664 L .42029 .36181 L .758 .647 .739 r
F
.42029 .36181 m .43643 .3899 L .40221 .33063 L .708 .63 .768 r
F
.42564 .38782 m .43658 .39519 L .43234 .44604 L .715 .613 .742 r
F
.44146 .39847 m .43727 .42033 L p .43658 .39519 L F P
0 g
s
.43727 .42033 m .43234 .44604 L p .43658 .39519 L .715 .613 .742 r
F P
0 g
s
.43643 .3899 m .43429 .39609 L p .43546 .35443 L .758 .647 .739 r
F P
0 g
s
.40453 .31963 m .43643 .3899 L .40228 .33045 L .708 .63 .768 r
F
.40226 .33042 m .40245 .32952 L p .40228 .33045 L F P
0 g
s
.40245 .32952 m .40453 .31963 L p .40228 .33045 L .708 .63 .768 r
F P
0 g
s
.39543 .31888 m .41745 .27221 L p .39907 .3244 L .744 .665 .773 r
F P
0 g
s
.50546 .24986 m .47577 .29655 L .41745 .27221 L p .725 .678 .804 r
F P
0 g
s
.41745 .27221 m .45135 .22321 L .50546 .24986 L p .725 .678 .804 r
F P
0 g
s
.42201 .25655 m .40453 .31963 L p .36601 .2675 L .734 .688 .806 r
F P
0 g
s
.36519 .26639 m .36535 .26636 L .36601 .2675 L .734 .688 .806 r
F
.36535 .26636 m .42201 .25655 L .36601 .2675 L F
.35677 .25192 m .42201 .25655 L p .36519 .26639 L F P
0 g
s
.37838 .28907 m .37836 .28907 L .37821 .28877 L .774 .702 .784 r
F
.36519 .26639 m .36601 .2675 L .36593 .26767 L .734 .688 .806 r
F
.40453 .31963 m .39543 .31888 L p .36601 .2675 L F P
0 g
s
.39153 .32714 m .32816 .31073 L p .37836 .28907 L .774 .702 .784 r
F P
0 g
s
.39527 .31859 m .39153 .32714 L .37836 .28907 L .774 .702 .784 r
F
.37723 .36117 m .39543 .31888 L .39154 .38124 L .743 .664 .774 r
F
.39543 .31888 m .39633 .31895 L p .39624 .3201 L F P
0 g
s
.39543 .31888 m .39624 .3201 L .39154 .38124 L .743 .664 .774 r
F
.40221 .33063 m .39154 .38124 L p .39633 .31895 L F P
0 g
s
.39153 .32714 m .39543 .31888 L p .39907 .3244 L .744 .665 .773 r
F P
0 g
s
.40221 .33063 m .39153 .32714 L p .39907 .3244 L .744 .665 .773 r
F P
0 g
s
.39633 .31895 m .40453 .31963 L .40221 .33063 L p .743 .664 .774 r
F P
0 g
s
.40221 .33063 m .40226 .33042 L p .42029 .36181 L .708 .63 .768 r
F P
0 g
s
.33592 .3773 m .39154 .38124 L .38368 .44113 L p .747 .643 .745 r
F P
0 g
s
.37632 .38319 m .39153 .32714 L .40221 .33063 L p .758 .647 .739 r
F P
0 g
s
.42029 .36181 m .37632 .38319 L .40221 .33063 L .758 .647 .739 r
F
.43429 .39609 m .37632 .38319 L p .42029 .36181 L F P
0 g
s
.43456 .38664 m .43429 .39609 L .42029 .36181 L .758 .647 .739 r
F
.45138 .34669 m .43643 .3899 L p .43546 .35443 L F P
0 g
s
.43643 .3899 m .45138 .34669 L p .43904 .39438 L .733 .62 .732 r
F P
0 g
s
.44286 .39114 m .43643 .3899 L p .40453 .31963 L .708 .63 .768 r
F P
0 g
s
.44199 .39331 m .44111 .39363 L .44128 .39287 L .733 .62 .732 r
F
.44144 .39857 m .4871 .41443 L p .45775 .42677 L .745 .601 .698 r
F P
0 g
s
.44292 .40101 m .4728 .45289 L .44304 .42193 L .679 .579 .735 r
F
.4728 .45289 m .43234 .44604 L .43797 .41666 L p F P
0 g
s
.47261 .45342 m .42531 .44041 L p .45775 .42677 L .745 .601 .698 r
F P
0 g
s
.47358 .42011 m .47263 .45259 L .45775 .42677 L .745 .601 .698 r
F
.47263 .45259 m .47261 .45342 L .45775 .42677 L F
.47233 .45281 m .4728 .45289 L p .47278 .45325 L .683 .566 .716 r
F P
0 g
s
.4827 .42626 m .47261 .45342 L p .47358 .42011 L .745 .601 .698 r
F P
0 g
s
.44286 .39114 m .4728 .45289 L .44292 .40101 L .679 .579 .735 r
F
.44297 .42086 m .44304 .42193 L .44297 .42186 L F
.44286 .39114 m .44304 .42193 L .44297 .42086 L F
.43797 .41666 m .44144 .39857 L p .44297 .42186 L F P
0 g
s
.44144 .39857 m .44286 .39114 L p .44297 .42186 L .679 .579 .735 r
F P
0 g
s
.43658 .39519 m .43643 .3899 L .44134 .39839 L .715 .613 .742 r
F
.43643 .3899 m .43647 .38991 L p .43904 .39438 L F P
0 g
s
.43643 .3899 m .43904 .39438 L .44134 .39839 L .715 .613 .742 r
F
.43429 .39609 m .43643 .3899 L p .43904 .39438 L .733 .62 .732 r
F P
0 g
s
.44144 .39857 m .43429 .39609 L p .43904 .39438 L .733 .62 .732 r
F P
0 g
s
.44286 .39114 m .44146 .39847 L p .44134 .39839 L .715 .613 .742 r
F P
0 g
s
.43647 .38991 m .44286 .39114 L p .44134 .39839 L .715 .613 .742 r
F P
0 g
s
.4871 .41443 m .4827 .42626 L p .47358 .42011 L .745 .601 .698 r
F P
0 g
s
.42531 .44041 m .43429 .39609 L .44144 .39857 L p .745 .601 .698 r
F P
0 g
s
.45775 .42677 m .42531 .44041 L .44144 .39857 L .745 .601 .698 r
F
.47336 .45299 m .47288 .45291 L p .44286 .39114 L .679 .579 .735 r
F P
0 g
s
.47288 .45291 m .4728 .45289 L p .47245 .45216 L .679 .579 .735 r
F P
0 g
s
.44286 .39114 m .47288 .45291 L .47245 .45216 L .679 .579 .735 r
F
.52336 .50209 m .50192 .5 L .52404 .5 L .732 .647 .764 r
F
.51533 .52656 m .5 .5 L p .52336 .50209 L F P
0 g
s
.53556 .56159 m .51533 .52656 L .55341 .5 L p .71 .6 .732 r
F P
0 g
s
.53556 .56159 m .55341 .5 L .55387 .50013 L .71 .6 .732 r
F
.58055 .53161 m .53556 .56159 L p .55387 .50013 L F P
0 g
s
.55387 .50013 m .55399 .5001 L .58055 .53161 L .71 .6 .732 r
F
.55439 .5 m .58055 .53161 L p .55391 .5 L F P
0 g
s
.58055 .46839 m .60915 .4287 L .65708 .46545 L p .67 .539 .696 r
F P
0 g
s
.65708 .46545 m .63433 .49169 L p .58055 .46839 L .67 .539 .696 r
F P
0 g
s
.60915 .5713 m .58055 .53161 L .61712 .5 L p .67 .556 .717 r
F P
0 g
s
.63433 .49169 m .62713 .5 L p .62248 .49748 L .67 .539 .696 r
F P
0 g
s
.62156 .50219 m .61712 .5 L .62195 .50002 L .67 .556 .717 r
F
.60915 .5713 m .61712 .5 L .62156 .50219 L F
.65708 .53455 m .60915 .5713 L p .6214 .50311 L F P
0 g
s
.6214 .50311 m .62213 .50271 L .65708 .53455 L .67 .556 .717 r
F
.62156 .50219 m .62195 .50002 L .62675 .50473 L F
.62156 .50219 m .62675 .50473 L .65708 .53455 L F
.62713 .5 m .65708 .46545 L .66981 .47687 L p .647 .505 .675 r
F P
0 g
s
.66981 .47687 m .69557 .5 L p .62713 .5 L .647 .505 .675 r
F P
0 g
s
.69557 .5 m .65708 .53455 L p .65953 .50007 L .647 .552 .733 r
F P
0 g
s
.6883 .58074 m .65708 .53455 L .69557 .5 L p .621 .507 .703 r
F P
0 g
s
.73855 .4576 m .70914 .5 L p .68161 .46309 L .621 .506 .702 r
F P
0 g
s
.65708 .46545 m .6883 .41926 L .73855 .4576 L p .621 .506 .702 r
F P
0 g
s
.76403 .40374 m .73855 .4576 L .6883 .41926 L p .594 .509 .728 r
F P
0 g
s
.78781 .502 m .73855 .5424 L p .74033 .5271 L .585 .496 .72 r
F P
0 g
s
.74033 .5271 m .74348 .50014 L .78338 .50181 L .585 .496 .72 r
F
.74033 .5271 m .78338 .50181 L .78781 .502 L F
.74348 .50014 m .74382 .50014 L .78781 .502 L F
.78383 .49845 m .78646 .5 L .76972 .50005 L .585 .459 .675 r
F
.78781 .498 m .78646 .5 L p .78383 .49845 L F P
0 g
s
.78646 .5 m .78781 .498 L .78865 .49872 L p .534 .394 .636 r
F P
0 g
s
.73855 .4576 m .76403 .40374 L .81262 .43722 L p .553 .462 .705 r
F P
0 g
s
.81262 .43722 m .78781 .498 L .73855 .4576 L p .553 .462 .705 r
F P
0 g
s
.8244 .37759 m .81262 .43722 L .76403 .40374 L p .521 .467 .736 r
F P
0 g
s
.78781 .498 m .81262 .43722 L .81314 .43758 L p .493 .395 .672 r
F P
0 g
s
.81314 .43758 m .85772 .46828 L p .83505 .47792 L .493 .395 .672 r
F P
0 g
s
.83505 .47792 m .78781 .498 L .81314 .43758 L .493 .395 .672 r
F
.81262 .56278 m .78781 .502 L .79016 .5 L p .493 .41 .69 r
F P
0 g
s
.83505 .47792 m .83483 .50012 L .78781 .498 L .493 .395 .672 r
F
.8471 .5 m .85772 .53172 L p .83966 .51365 L .493 .41 .69 r
F P
0 g
s
.82622 .50021 m .8471 .5 L .83966 .51365 L .493 .41 .69 r
F
.85772 .53172 m .85115 .53624 L p .82622 .50021 L F P
0 g
s
.85115 .53624 m .81262 .56278 L p .82212 .51907 L .493 .41 .69 r
F P
0 g
s
.82212 .51907 m .82622 .50021 L .85115 .53624 L .493 .41 .69 r
F
.81262 .56278 m .79016 .5 L .82622 .50021 L F
.79016 .5 m .78781 .502 L p .78792 .5 L .534 .478 .74 r
F P
0 g
s
.78788 .50083 m .7873 .5 L .78792 .5 L .534 .478 .74 r
F
.78781 .502 m .78646 .5 L p .78788 .50083 L F P
0 g
s
.78865 .49872 m .79016 .5 L p .78646 .5 L .534 .394 .636 r
F P
0 g
s
.78792 .5 m .78646 .5 L .79016 .5 L .534 .394 .636 r
F
.73855 .4576 m .78781 .498 L p .76972 .50005 L .585 .459 .675 r
F P
0 g
s
.78646 .5 m .74983 .44581 L p .78788 .50083 L .534 .478 .74 r
F P
0 g
s
.83447 .53772 m .78646 .5 L .78988 .50001 L .534 .394 .636 r
F
.79017 .50001 m .79082 .50056 L p .78988 .50001 L F P
0 g
s
.79082 .50056 m .83447 .53772 L p .78988 .50001 L .534 .394 .636 r
F P
0 g
s
.89592 .49323 m .89167 .49631 L .89016 .49403 L .391 .289 .618 r
F
.86263 .47149 m .89592 .49323 L p .8471 .5 L F P
0 g
s
.89592 .50677 m .88486 .514 L p .89037 .50565 L .391 .349 .691 r
F P
0 g
s
.863 .50011 m .86325 .50011 L .89592 .50677 L .391 .349 .691 r
F
.89411 .5 m .89592 .49323 L .89789 .49429 L p .182 .086 .503 r
F P
0 g
s
.89789 .49429 m .90849 .5 L p .89411 .5 L .182 .086 .503 r
F P
0 g
s
.90849 .5 m .89592 .50677 L p .89646 .50001 L .182 .211 .656 r
F P
0 g
s
.89869 .58106 m .89592 .50677 L .90842 .50003 L p .127 .09 .543 r
F P
0 g
s
.89869 .58106 m .90842 .50003 L .90848 .50008 L .127 .09 .543 r
F
.89869 .58106 m .90849 .5 L .91831 .50841 L F
.89592 .50677 m .89869 .58106 L .8651 .5988 L p .342 .258 .614 r
F P
0 g
s
.86019 .65902 m .8651 .5988 L .89869 .58106 L p .297 .167 .529 r
F P
0 g
s
.89869 .58106 m .88832 .6466 L .86019 .65902 L p .297 .167 .529 r
F P
0 g
s
.92168 .57193 m .90014 .58048 L p .91895 .52054 L .127 .09 .543 r
F P
0 g
s
.92265 .50763 m .923 .50763 L p .92244 .50943 L 0 0 .176 r
F P
0 g
s
.92183 .51139 m .92225 .50943 L p .92244 .50943 L 0 0 .176 r
F P
0 g
s
.92225 .50943 m .92265 .50763 L p .92244 .50943 L 0 0 .176 r
F P
0 g
s
.92168 .57193 m .92244 .50943 L p .93096 .50962 L 0 0 .297 r
F P
0 g
s
.92265 .50763 m .92183 .51139 L p .92061 .51037 L .182 .086 .503 r
F P
0 g
s
.90855 .50003 m .92265 .50763 L p .91498 .50558 L .182 .086 .503 r
F P
0 g
s
.89621 .50317 m .89531 .5 L .89646 .50001 L .182 .211 .656 r
F
.89646 .50001 m .89411 .5 L .90849 .5 L .182 .086 .503 r
F
.89592 .49323 m .89411 .5 L p .89167 .49631 L .391 .289 .618 r
F P
0 g
s
.85772 .46828 m .8651 .4012 L .89869 .41894 L p .342 .301 .667 r
F P
0 g
s
.89869 .41894 m .89592 .49323 L .85772 .46828 L p .342 .301 .667 r
F P
0 g
s
.8962 .50315 m .87498 .4283 L .89621 .50317 L .182 .211 .656 r
F
.89411 .50002 m .87498 .4283 L p .89621 .50319 L F P
0 g
s
.91498 .50558 m .89411 .5 L .90845 .50003 L .182 .086 .503 r
F
.90842 .50003 m .90849 .5 L p .90848 .50008 L .127 .09 .543 r
F P
0 g
s
.91498 .50558 m .90845 .50003 L .90855 .50003 L .182 .086 .503 r
F
.91831 .50843 m .91831 .50841 L .91834 .50843 L .127 .09 .543 r
F
.89621 .50319 m .8962 .50315 L .89621 .50317 L .182 .211 .656 r
F
.89592 .50677 m .89411 .50002 L p .89621 .50319 L F P
0 g
s
.89167 .49631 m .89085 .50001 L .88653 .50003 L .391 .289 .618 r
F
.89411 .5 m .89085 .50001 L .89167 .49631 L F
.89016 .49403 m .88653 .50003 L .8471 .5 L F
.89167 .49631 m .88653 .50003 L .89016 .49403 L F
.88653 .50003 m .86301 .50006 L .8471 .5 L F
.87498 .4283 m .89411 .5 L p .86301 .50006 L .391 .349 .691 r
F P
0 g
s
.89411 .5 m .89411 .50002 L p .88653 .50003 L .391 .349 .691 r
F P
0 g
s
.86301 .50006 m .89411 .5 L .88653 .50003 L .391 .349 .691 r
F
.85772 .53172 m .863 .50011 L .89037 .50565 L F
.88486 .514 m .85772 .53172 L p .89037 .50565 L F P
0 g
s
.89411 .50002 m .89592 .50677 L p .86301 .50006 L .391 .349 .691 r
F P
0 g
s
.8651 .5988 m .85772 .53172 L .89592 .50677 L p .342 .258 .614 r
F P
0 g
s
.89411 .5 m .87498 .5717 L p .89085 .50001 L .391 .289 .618 r
F P
0 g
s
.87498 .5717 m .89411 .5 L p .91498 .50558 L .182 .086 .503 r
F P
0 g
s
.92265 .50763 m .92061 .51037 L .91498 .50558 L .182 .086 .503 r
F
.91831 .50843 m .91834 .50843 L .92061 .51037 L .127 .09 .543 r
F
.89869 .58106 m .91831 .50843 L .91895 .52054 L F
.92241 .51188 m .92168 .57193 L p .91831 .50843 L F P
0 g
s
.92061 .51037 m .87498 .5717 L .91498 .50558 L .182 .086 .503 r
F
.92061 .51037 m .92244 .50943 L .92183 .51139 L .127 .09 .543 r
F
.91834 .50843 m .92244 .50943 L .92061 .51037 L F
.92061 .49999 m .9222 .49403 L .92256 .5 L F
.92265 .49237 m .92256 .5 L p .9222 .49403 L F P
0 g
s
.92265 .49237 m .93356 .49217 L p .93239 .5 L 0 0 .297 r
F P
0 g
s
.92244 .50943 m .92241 .51188 L p .92183 .51139 L .127 .09 .543 r
F P
0 g
s
.88832 .6466 m .89869 .58106 L .92168 .57193 L p .086 0 .429 r
F P
0 g
s
.90397 .59313 m .92183 .51139 L p .92787 .50955 L 0 0 .176 r
F P
0 g
s
.93356 .50783 m .93292 .50967 L .92787 .50955 L 0 0 .176 r
F
.93093 .57351 m .92168 .57193 L p .93096 .50962 L 0 0 .297 r
F P
0 g
s
.93299 .50967 m .93093 .57351 L p .93096 .50962 L 0 0 .297 r
F P
0 g
s
.93292 .50967 m .90397 .59313 L .92787 .50955 L 0 0 .176 r
F
.923 .50763 m .93356 .50783 L p .92183 .51139 L F P
0 g
s
.92168 .57193 m .90716 .64109 L .88832 .6466 L p .086 0 .429 r
F P
0 g
s
.93356 .50783 m .91592 .59589 L .90397 .59313 L p 0 0 .176 r
F P
0 g
s
.93356 .50783 m .92265 .50763 L p .92343 .5 L 0 0 .325 r
F P
0 g
s
.93356 .49217 m .93331 .5 L p .93239 .5 L 0 0 .297 r
F P
0 g
s
.92632 .5 m .92265 .49237 L .93239 .5 L 0 0 .297 r
F
.93331 .5 m .93356 .50783 L p .92343 .5 L 0 0 .325 r
F P
0 g
s
.92343 .5 m .92287 .50541 L .92279 .5 L 0 0 .325 r
F
.92265 .50763 m .92256 .5 L p .92287 .50541 L F P
0 g
s
.92287 .50541 m .92256 .5 L .92279 .5 L 0 0 .325 r
F
.92256 .5 m .92265 .50763 L .90849 .5 L p .127 .118 .576 r
F P
0 g
s
.90849 .5 m .92265 .49237 L p .92059 .49999 L .127 .09 .543 r
F P
0 g
s
.92183 .48861 m .92265 .49237 L .90849 .5 L p .182 .211 .656 r
F P
0 g
s
.92256 .5 m .90849 .5 L .92059 .49999 L .127 .118 .576 r
F
.91831 .50841 m .92265 .49237 L .91834 .50843 L .127 .09 .543 r
F
.91117 .45466 m .92256 .5 L .89592 .49323 L .127 .118 .576 r
F
.92168 .42807 m .92244 .49057 L p .91117 .45466 L F P
0 g
s
.92265 .49237 m .92225 .49057 L p .92253 .49086 L 0 0 .437 r
F P
0 g
s
.92225 .49057 m .92183 .48861 L p .92244 .49057 L 0 0 .437 r
F P
0 g
s
.92225 .49057 m .92244 .49057 L .92253 .49086 L 0 0 .437 r
F
.92256 .5 m .92265 .49237 L p .92632 .5 L 0 0 .297 r
F P
0 g
s
.92256 .5 m .92244 .49057 L p .92279 .5 L 0 0 .325 r
F P
0 g
s
.92244 .49057 m .92168 .42807 L p .92264 .49056 L 0 0 .325 r
F P
0 g
s
.89592 .49323 m .89869 .41894 L .90014 .41952 L p .127 .118 .576 r
F P
0 g
s
.90014 .41952 m .92168 .42807 L p .91117 .45466 L .127 .118 .576 r
F P
0 g
s
.91117 .45466 m .89592 .49323 L .90014 .41952 L .127 .118 .576 r
F
.93356 .49217 m .923 .49237 L p .92285 .49056 L 0 0 .437 r
F P
0 g
s
.93319 .49033 m .93356 .49217 L p .92285 .49056 L 0 0 .437 r
F P
0 g
s
.92439 .49052 m .93331 .5 L .92343 .5 L 0 0 .325 r
F
.93093 .42649 m .93299 .49033 L p .92439 .49052 L F P
0 g
s
.93299 .49033 m .93331 .5 L p .92439 .49052 L 0 0 .325 r
F P
0 g
s
.92168 .42807 m .93093 .42649 L p .92343 .5 L 0 0 .325 r
F P
0 g
s
.923 .49237 m .92265 .49237 L p .92254 .49089 L 0 0 .437 r
F P
0 g
s
.92254 .49089 m .92251 .49057 L .923 .49237 L 0 0 .437 r
F
.92343 .5 m .92279 .5 L .92264 .49056 L 0 0 .325 r
F
.9232 .49055 m .92264 .49056 L .92168 .42807 L F
.92251 .49057 m .92285 .49056 L .923 .49237 L 0 0 .437 r
F
.92343 .5 m .92264 .49056 L .9232 .49055 L 0 0 .325 r
F
.90716 .35891 m .92168 .42807 L .89869 .41894 L p .086 .157 .642 r
F P
0 g
s
.92251 .49057 m .91592 .40411 L .92285 .49056 L 0 0 .437 r
F
.91592 .40411 m .93319 .49033 L p .92285 .49056 L F P
0 g
s
.90397 .40687 m .91592 .40411 L p .92253 .49086 L 0 0 .437 r
F P
0 g
s
.92183 .48861 m .90397 .40687 L p .92253 .49086 L 0 0 .437 r
F P
0 g
s
.92279 .5 m .92244 .49057 L .92264 .49056 L 0 0 .325 r
F
.92244 .49057 m .92256 .5 L p .91117 .45466 L .127 .118 .576 r
F P
0 g
s
.90829 .49989 m .89592 .49323 L p .92256 .5 L .127 .118 .576 r
F P
0 g
s
.90397 .40687 m .92183 .48861 L p .90849 .5 L .182 .211 .656 r
F P
0 g
s
.90849 .5 m .90829 .49989 L p .90861 .4999 L .127 .118 .576 r
F P
0 g
s
.92059 .49999 m .90849 .5 L .90861 .4999 L .127 .118 .576 r
F
.90849 .5 m .90855 .50003 L p .90853 .50003 L .182 .086 .503 r
F P
0 g
s
.91831 .50841 m .90849 .5 L .92059 .49999 L .127 .09 .543 r
F
.92244 .50943 m .92256 .5 L p .93096 .50962 L 0 0 .297 r
F P
0 g
s
.92256 .5 m .92632 .5 L .93096 .50962 L 0 0 .297 r
F
.93096 .50962 m .93239 .5 L .93299 .50967 L F
.93331 .5 m .93299 .50967 L p .93239 .5 L F P
0 g
s
.93096 .50962 m .92632 .5 L .93239 .5 L 0 0 .297 r
F
.91834 .50843 m .92061 .49999 L .92244 .50943 L .127 .09 .543 r
F
.92256 .5 m .92244 .50943 L p .92061 .49999 L F P
0 g
s
.90014 .58048 m .89869 .58106 L p .91895 .52054 L .127 .09 .543 r
F P
0 g
s
.92061 .51037 m .92182 .51141 L .92061 .51037 L .182 .086 .503 r
F
.92183 .51139 m .92182 .51141 L p .92061 .51037 L F P
0 g
s
.90397 .59313 m .87498 .5717 L p .92061 .51037 L .182 .086 .503 r
F P
0 g
s
.92182 .51141 m .90397 .59313 L p .92061 .51037 L .182 .086 .503 r
F P
0 g
s
.90853 .50003 m .89646 .50001 L .90849 .5 L .182 .086 .503 r
F
.89646 .50001 m .90397 .40687 L .90849 .5 L .182 .211 .656 r
F
.88832 .3534 m .89869 .41894 L .8651 .4012 L p .297 .318 .714 r
F P
0 g
s
.89869 .41894 m .88832 .3534 L .90716 .35891 L p .086 .157 .642 r
F P
0 g
s
.87498 .4283 m .90397 .40687 L p .89646 .50001 L .182 .211 .656 r
F P
0 g
s
.89531 .5 m .87498 .4283 L .89646 .50001 L .182 .211 .656 r
F
.863 .50011 m .86301 .50006 L .86325 .50011 L .391 .349 .691 r
F
.863 .50011 m .85007 .50001 L .86301 .50006 L F
.85929 .52232 m .8501 .50009 L .863 .50011 L F
.8501 .50009 m .85007 .50001 L .863 .50011 L F
.85926 .5225 m .85887 .52156 L .85929 .52232 L F
.8471 .5 m .85772 .46828 L .86263 .47149 L p .391 .289 .618 r
F P
0 g
s
.85772 .46828 m .8471 .5 L p .83505 .47792 L .493 .395 .672 r
F P
0 g
s
.85887 .52156 m .83447 .46228 L .85929 .52232 L .391 .349 .691 r
F
.85772 .53172 m .8472 .5003 L p .85926 .5225 L F P
0 g
s
.8472 .5003 m .83447 .46228 L p .85926 .5225 L .391 .349 .691 r
F P
0 g
s
.8244 .62241 m .81262 .56278 L .85772 .53172 L p .454 .339 .633 r
F P
0 g
s
.85772 .53172 m .8651 .5988 L .8244 .62241 L p .454 .339 .633 r
F P
0 g
s
.87498 .5717 m .83447 .53772 L p .88637 .50014 L .391 .289 .618 r
F P
0 g
s
.88653 .50003 m .88651 .50014 L .88637 .50014 L .391 .289 .618 r
F
.88651 .50014 m .87498 .5717 L .88637 .50014 L F
.89085 .50001 m .87498 .5717 L .88653 .50003 L F
.88653 .50003 m .88637 .50014 L .86301 .50006 L F
.8651 .4012 m .85772 .46828 L .81262 .43722 L p .454 .402 .71 r
F P
0 g
s
.83447 .46228 m .87498 .4283 L p .86301 .50006 L .391 .349 .691 r
F P
0 g
s
.85007 .50001 m .83447 .46228 L .86301 .50006 L .391 .349 .691 r
F
.83447 .53772 m .8471 .5 L p .88637 .50014 L .391 .289 .618 r
F P
0 g
s
.83483 .50012 m .83483 .50026 L .83249 .50015 L .493 .395 .672 r
F
.83483 .50012 m .83249 .50015 L .78781 .498 L F
.79016 .5 m .78781 .498 L p .83483 .50026 L F P
0 g
s
.8471 .5 m .83447 .53772 L p .83505 .47792 L .493 .395 .672 r
F P
0 g
s
.83447 .46228 m .8471 .5 L p .82622 .50021 L .493 .41 .69 r
F P
0 g
s
.79016 .5 m .83447 .46228 L p .82622 .50021 L .493 .41 .69 r
F P
0 g
s
.83447 .53772 m .79016 .5 L p .83483 .50026 L .493 .395 .672 r
F P
0 g
s
.81262 .43722 m .8244 .37759 L .8651 .4012 L p .454 .402 .71 r
F P
0 g
s
.79373 .39731 m .83447 .46228 L .79016 .5 L p .534 .478 .74 r
F P
0 g
s
.78792 .5 m .79373 .39731 L .79016 .5 L .534 .478 .74 r
F
.79016 .5 m .79017 .50001 L p .78792 .5 L .534 .394 .636 r
F P
0 g
s
.74983 .44581 m .79373 .39731 L p .78792 .5 L .534 .478 .74 r
F P
0 g
s
.7873 .5 m .74983 .44581 L .78792 .5 L .534 .478 .74 r
F
.76972 .50005 m .76824 .50006 L .73855 .4576 L .585 .459 .675 r
F
.78647 .50001 m .78781 .502 L p .74349 .50012 L .585 .496 .72 r
F P
0 g
s
.70914 .5 m .73855 .4576 L p .76834 .50021 L .585 .459 .675 r
F P
0 g
s
.74983 .44581 m .78647 .50001 L p .74349 .50012 L .585 .496 .72 r
F P
0 g
s
.76403 .59626 m .73855 .5424 L .78781 .502 L p .553 .442 .681 r
F P
0 g
s
.78781 .502 m .81262 .56278 L .76403 .59626 L p .553 .442 .681 r
F P
0 g
s
.74983 .55419 m .78646 .5 L p .83447 .53772 L .534 .394 .636 r
F P
0 g
s
.74348 .50014 m .70947 .5 L .74349 .50012 L .585 .496 .72 r
F
.73885 .53983 m .7095 .50004 L .74348 .50014 L F
.7095 .50004 m .70947 .5 L .74348 .50014 L F
.73855 .5424 m .70914 .5 L p .73885 .53983 L F P
0 g
s
.70914 .5 m .70393 .49249 L p .73885 .53983 L .585 .496 .72 r
F P
0 g
s
.73855 .5424 m .6883 .58074 L p .70168 .50521 L .621 .507 .703 r
F P
0 g
s
.70168 .50521 m .70253 .50039 L .71984 .52058 L .621 .507 .703 r
F
.70168 .50521 m .71984 .52058 L .73855 .5424 L F
.6883 .58074 m .69557 .5 L .70253 .50039 L F
.65834 .51689 m .6309 .50001 L .65953 .50007 L .647 .552 .733 r
F
.65953 .50007 m .62713 .5 L .69557 .5 L .647 .505 .675 r
F
.63433 .49169 m .62248 .49748 L .58055 .46839 L .67 .539 .696 r
F
.6172 .50006 m .60036 .48551 L p .62248 .49748 L F P
0 g
s
.60036 .48551 m .58055 .46839 L p .62248 .49748 L .67 .539 .696 r
F P
0 g
s
.62713 .5 m .62284 .49505 L p .65834 .51689 L .647 .552 .733 r
F P
0 g
s
.70393 .50751 m .62713 .5 L .69569 .50015 L .647 .505 .675 r
F
.69573 .50015 m .69642 .50076 L p .69569 .50015 L F P
0 g
s
.69642 .50076 m .70393 .50751 L p .69569 .50015 L .647 .505 .675 r
F P
0 g
s
.70914 .5 m .73855 .5424 L p .70253 .50039 L .621 .507 .703 r
F P
0 g
s
.7139 .6298 m .6883 .58074 L .73855 .5424 L p .594 .461 .669 r
F P
0 g
s
.73855 .5424 m .76403 .59626 L .7139 .6298 L p .594 .461 .669 r
F P
0 g
s
.74983 .55419 m .70393 .50751 L p .76834 .50021 L .585 .459 .675 r
F P
0 g
s
.76972 .50005 m .76966 .50021 L .76834 .50021 L .585 .459 .675 r
F
.76966 .50021 m .74983 .55419 L .76834 .50021 L F
.78646 .5 m .74983 .55419 L p .76972 .50005 L F P
0 g
s
.74348 .50014 m .74349 .50012 L .74382 .50014 L .585 .496 .72 r
F
.76972 .50005 m .76834 .50021 L .76824 .50006 L .585 .459 .675 r
F
.70393 .50751 m .70914 .5 L p .76834 .50021 L F P
0 g
s
.70393 .49249 m .74983 .44581 L p .74349 .50012 L .585 .496 .72 r
F P
0 g
s
.70947 .5 m .70393 .49249 L .74349 .50012 L .585 .496 .72 r
F
.68161 .46309 m .70914 .5 L .65708 .46545 L .621 .506 .702 r
F
.70914 .5 m .70863 .50074 L p .70768 .50009 L F P
0 g
s
.70914 .5 m .70768 .50009 L .65708 .46545 L .621 .506 .702 r
F
.69557 .5 m .65708 .46545 L p .70863 .50074 L F P
0 g
s
.70393 .49249 m .70914 .5 L p .70253 .50039 L .621 .507 .703 r
F P
0 g
s
.69557 .5 m .70393 .49249 L p .70253 .50039 L .621 .507 .703 r
F P
0 g
s
.70863 .50074 m .70393 .50751 L .69557 .5 L p .621 .506 .702 r
F P
0 g
s
.69557 .5 m .69573 .50015 L p .65953 .50007 L .647 .505 .675 r
F P
0 g
s
.6883 .41926 m .65708 .46545 L .60915 .4287 L p .648 .543 .721 r
F P
0 g
s
.663 .4513 m .70393 .49249 L .69557 .5 L p .647 .552 .733 r
F P
0 g
s
.65953 .50007 m .663 .4513 L .69557 .5 L .647 .552 .733 r
F
.62284 .49505 m .663 .4513 L p .65953 .50007 L F P
0 g
s
.6309 .50001 m .62284 .49505 L .65953 .50007 L .647 .552 .733 r
F
.65708 .53455 m .62713 .5 L p .65834 .51689 L F P
0 g
s
.62713 .5 m .65708 .53455 L p .62195 .50002 L .67 .556 .717 r
F P
0 g
s
.62284 .50495 m .62713 .5 L p .70393 .50751 L .647 .505 .675 r
F P
0 g
s
.6214 .50311 m .62156 .50219 L .62213 .50271 L .67 .556 .717 r
F
.61712 .5 m .58055 .53161 L p .58454 .50003 L .694 .597 .744 r
F P
0 g
s
.61427 .50006 m .55439 .5 L .59609 .4897 L .694 .535 .668 r
F
.55439 .5 m .58055 .46839 L .60319 .48795 L p F P
0 g
s
.58055 .46839 m .55439 .5 L p .51533 .47344 L .71 .559 .682 r
F P
0 g
s
.55404 .49957 m .58895 .46512 L p .58454 .50003 L .694 .597 .744 r
F P
0 g
s
.58239 .51707 m .55474 .5 L .58454 .50003 L .694 .597 .744 r
F
.55474 .5 m .55404 .49957 L .58454 .50003 L F
.57251 .52189 m .55404 .49957 L p .58239 .51707 L F P
0 g
s
.62284 .50495 m .55439 .5 L .61427 .50006 L .694 .535 .668 r
F
.59705 .49018 m .59609 .4897 L .59619 .48968 L F
.62284 .50495 m .59609 .4897 L .59705 .49018 L F
.60319 .48795 m .61712 .5 L p .59619 .48968 L F P
0 g
s
.61712 .5 m .62284 .50495 L p .59619 .48968 L .694 .535 .668 r
F P
0 g
s
.62248 .49748 m .62713 .5 L .61733 .5 L .67 .539 .696 r
F
.62713 .5 m .62711 .50003 L p .62195 .50002 L F P
0 g
s
.62713 .5 m .62195 .50002 L .61733 .5 L .67 .539 .696 r
F
.62284 .49505 m .62713 .5 L p .62195 .50002 L .67 .556 .717 r
F P
0 g
s
.61712 .5 m .62284 .49505 L p .62195 .50002 L .67 .556 .717 r
F P
0 g
s
.62284 .50495 m .6172 .50006 L p .61733 .5 L .67 .539 .696 r
F P
0 g
s
.62711 .50003 m .62284 .50495 L p .61733 .5 L .67 .539 .696 r
F P
0 g
s
.58055 .53161 m .57251 .52189 L p .58239 .51707 L .694 .597 .744 r
F P
0 g
s
.58895 .46512 m .62284 .49505 L .61712 .5 L p .694 .597 .744 r
F P
0 g
s
.58454 .50003 m .58895 .46512 L .61712 .5 L .694 .597 .744 r
F
.55404 .50043 m .55435 .50006 L p .62284 .50495 L .694 .535 .668 r
F P
0 g
s
.55435 .50006 m .55439 .5 L p .55521 .50006 L .694 .535 .668 r
F P
0 g
s
.62284 .50495 m .55435 .50006 L .55521 .50006 L .694 .535 .668 r
F
.55387 .50013 m .55391 .5 L .55399 .5001 L .71 .6 .732 r
F
.55341 .5 m .51533 .47344 L p .55439 .5 L .71 .559 .682 r
F P
0 g
s
.55404 .49957 m .55439 .5 L p .55391 .5 L .71 .6 .732 r
F P
0 g
s
.55387 .50013 m .55341 .5 L .55391 .5 L .71 .6 .732 r
F
.55439 .5 m .55404 .50043 L .55341 .5 L p .71 .559 .682 r
F P
0 g
s
.55341 .5 m .55404 .49957 L p .55391 .5 L .71 .6 .732 r
F P
0 g
s
.53172 .4766 m .55404 .49957 L .55341 .5 L p .732 .647 .764 r
F P
0 g
s
.55341 .5 m .51533 .52656 L p .52404 .5 L .732 .647 .764 r
F P
0 g
s
.5 .5 m .50762 .4868 L p .55339 .5 L .732 .548 .644 r
F P
0 g
s
.52404 .5 m .5 .5 L .55339 .5 L .732 .548 .644 r
F
.50762 .4868 m .51533 .47344 L .55341 .5 L p F P
0 g
s
.55341 .5 m .55342 .50001 L p .50762 .4868 L .732 .548 .644 r
F P
0 g
s
.52404 .5 m .53172 .4766 L .55341 .5 L .732 .647 .764 r
F
.55342 .50001 m .52404 .5 L .55339 .5 L .732 .548 .644 r
F
.47336 .45299 m .50011 .4998 L .5 .5 L .638 .526 .71 r
F
.4733 .45373 m .47336 .45299 L p .5 .5 L F P
0 g
s
.5 .5 m .49989 .4998 L p .5001 .49982 L .732 .647 .764 r
F P
0 g
s
.5 .5 m .5001 .49982 L .52336 .50209 L .732 .647 .764 r
F
.5 .5 m .5001 .49982 L .5 .5 L F
.51533 .47344 m .50762 .48681 L p .4976 .47716 L .742 .562 .65 r
F P
0 g
s
.47336 .45299 m .5044 .46083 L .50028 .49951 L p .638 .526 .71 r
F P
0 g
s
.52404 .5 m .50016 .49982 L .53172 .4766 L .732 .647 .764 r
F
.50016 .49982 m .5001 .49982 L .50019 .49976 L F
.50016 .49982 m .50019 .49976 L .53172 .4766 L F
.50192 .5 m .5001 .49982 L .52404 .5 L F
.50028 .49951 m .53172 .4766 L p .50019 .49976 L F P
0 g
s
.5001 .49982 m .50028 .49952 L .50019 .49976 L .732 .647 .764 r
F
.50028 .49952 m .50028 .49951 L .50019 .49976 L F
.51533 .47344 m .53556 .43841 L .58055 .46839 L p .71 .559 .682 r
F P
0 g
s
.50998 .47426 m .51636 .47166 L .51202 .47918 L .565 .461 .694 r
F
.50028 .49951 m .5044 .46083 L p .50998 .47426 L F P
0 g
s
.51939 .46642 m .53172 .4766 L .50028 .49951 L p .761 .713 .807 r
F P
0 g
s
.50998 .47426 m .51202 .47918 L .50028 .49951 L .565 .461 .694 r
F
.47336 .45299 m .50028 .49951 L .50011 .4998 L .638 .526 .71 r
F
.50028 .49951 m .50028 .49951 L p .51202 .47918 L .761 .713 .807 r
F P
0 g
s
.51202 .47918 m .51939 .46642 L .50028 .49951 L .761 .713 .807 r
F
.51202 .47918 m .52067 .5 L .50028 .49951 L .565 .461 .694 r
F
.51379 .46433 m .51939 .46642 L p .50998 .47426 L F P
0 g
s
.55947 .397 m .53556 .43841 L .4871 .41443 L p .711 .594 .723 r
F P
0 g
s
.5044 .46083 m .51734 .42206 L p .52321 .45981 L .565 .46 .693 r
F P
0 g
s
.51939 .46642 m .5044 .46083 L p .52321 .45981 L .565 .46 .693 r
F P
0 g
s
.53172 .4766 m .51939 .46642 L p .53516 .43912 L .762 .713 .806 r
F P
0 g
s
.53556 .43841 m .55947 .397 L .60915 .4287 L p .691 .567 .711 r
F P
0 g
s
.60915 .4287 m .58055 .46839 L .53556 .43841 L p .691 .567 .711 r
F P
0 g
s
.55883 .44601 m .53172 .4766 L p .53517 .43909 L .762 .713 .806 r
F P
0 g
s
.52312 .45925 m .53603 .4376 L .52321 .45981 L .565 .46 .693 r
F
.51734 .42206 m .53603 .4376 L p .52312 .45925 L F P
0 g
s
.53603 .4376 m .53603 .4376 L p .52312 .45925 L .565 .46 .693 r
F P
0 g
s
.4871 .41443 m .50717 .36983 L .55947 .397 L p .711 .594 .723 r
F P
0 g
s
.58541 .35206 m .55947 .397 L .50717 .36983 L p .695 .604 .75 r
F P
0 g
s
.51734 .42206 m .54007 .38395 L p .53671 .43642 L .563 .46 .695 r
F P
0 g
s
.55883 .44601 m .53603 .4376 L p .5506 .41315 L .76 .714 .809 r
F P
0 g
s
.53603 .4376 m .53603 .4376 L p .53609 .4375 L .76 .714 .809 r
F P
0 g
s
.53603 .4376 m .53609 .4375 L .5506 .41315 L .76 .714 .809 r
F
.54007 .38395 m .55461 .40541 L p .53695 .43272 L .563 .46 .695 r
F P
0 g
s
.55947 .397 m .58541 .35206 L .63739 .38403 L p .672 .575 .737 r
F P
0 g
s
.50717 .36983 m .53173 .32304 L .58541 .35206 L p .695 .604 .75 r
F P
0 g
s
.54007 .38395 m .57359 .3468 L p .56483 .38263 L .55 .454 .699 r
F P
0 g
s
.61143 .307 m .58541 .35206 L .53173 .32304 L p .677 .612 .776 r
F P
0 g
s
.58541 .35206 m .61143 .307 L .66301 .33781 L p .652 .581 .762 r
F P
0 g
s
.66301 .33781 m .63739 .38403 L .58541 .35206 L p .652 .581 .762 r
F P
0 g
s
.53173 .32304 m .55895 .27774 L .61143 .307 L p .677 .612 .776 r
F P
0 g
s
.55895 .27774 m .53173 .32304 L .47577 .29655 L p .7 .644 .79 r
F P
0 g
s
.53795 .30765 m .57359 .3468 L .54007 .38395 L p .606 .537 .751 r
F P
0 g
s
.56483 .38263 m .56757 .38306 L .56263 .3916 L .55 .454 .699 r
F
.57979 .3618 m .59588 .35967 L p .57097 .38126 L .757 .722 .82 r
F P
0 g
s
.56625 .38536 m .57979 .3618 L .57097 .38126 L .757 .722 .82 r
F
.63739 .38403 m .60915 .4287 L .55947 .397 L p .672 .575 .737 r
F P
0 g
s
.59588 .35967 m .58047 .40727 L p .56625 .38536 L .757 .722 .82 r
F P
0 g
s
.59588 .35967 m .57984 .36179 L p .58693 .35196 L .755 .745 .844 r
F P
0 g
s
.57979 .3618 m .57359 .3468 L .59421 .32997 L p .514 .434 .704 r
F P
0 g
s
.57984 .36179 m .57979 .3618 L p .58693 .35196 L .755 .745 .844 r
F P
0 g
s
.63739 .38403 m .66301 .33781 L .7139 .3702 L p .626 .548 .747 r
F P
0 g
s
.6476 .37096 m .59588 .35967 L .6017 .32385 L p .685 .678 .838 r
F P
0 g
s
.6476 .37096 m .6017 .32385 L .61029 .31271 L .685 .678 .838 r
F
.63567 .26502 m .61143 .307 L .55895 .27774 L p .655 .619 .802 r
F P
0 g
s
.55895 .27774 m .58667 .23708 L .63567 .26502 L p .655 .619 .802 r
F P
0 g
s
.57359 .3468 m .53795 .30765 L .57671 .25799 L p .569 .529 .771 r
F P
0 g
s
.61143 .307 m .63567 .26502 L .68436 .29348 L p .63 .587 .787 r
F P
0 g
s
.68436 .29348 m .66301 .33781 L .61143 .307 L p .63 .587 .787 r
F P
0 g
s
.65675 .22849 m .63567 .26502 L .58667 .23708 L p .629 .625 .827 r
F P
0 g
s
.58667 .23708 m .61292 .2031 L .65675 .22849 L p .629 .625 .827 r
F P
0 g
s
.57671 .25799 m .61731 .21201 L p .61719 .26436 L .493 .501 .794 r
F P
0 g
s
.61139 .31443 m .61179 .31103 L .67123 .31256 L .685 .678 .838 r
F
.61246 .30521 m .67123 .31256 L p .60917 .31096 L F P
0 g
s
.61719 .26436 m .61711 .29726 L .61246 .30521 L .493 .501 .794 r
F
.61246 .30521 m .57671 .25799 L p .61719 .26436 L F P
0 g
s
.57671 .25799 m .61246 .30521 L p .57359 .3468 L .569 .529 .771 r
F P
0 g
s
.67123 .31256 m .61246 .30521 L p .63204 .27169 L .657 .713 .89 r
F P
0 g
s
.70066 .25376 m .68436 .29348 L .63567 .26502 L p .604 .593 .813 r
F P
0 g
s
.63567 .26502 m .65675 .22849 L .70066 .25376 L p .604 .593 .813 r
F P
0 g
s
.69075 .25441 m .67123 .31256 L p .64549 .28571 L .657 .713 .89 r
F P
0 g
s
.64549 .28571 m .64478 .26787 L .69075 .25441 L .657 .713 .89 r
F
.64408 .25044 m .69075 .25441 L p .63197 .27161 L F P
0 g
s
.67402 .19859 m .65675 .22849 L .61292 .2031 L p .597 .629 .853 r
F P
0 g
s
.61292 .2031 m .63629 .17651 L .67402 .19859 L p .597 .629 .853 r
F P
0 g
s
.68741 .1754 m .67402 .19859 L .63629 .17651 L p .558 .63 .879 r
F P
0 g
s
.65675 .22849 m .67402 .19859 L .712 .22023 L p .573 .597 .839 r
F P
0 g
s
.712 .22023 m .70066 .25376 L .65675 .22849 L p .573 .597 .839 r
F P
0 g
s
.71908 .19331 m .712 .22023 L .67402 .19859 L p .535 .6 .865 r
F P
0 g
s
.7052 .21147 m .69075 .25441 L p .6871 .25212 L .577 .769 .97 r
F P
0 g
s
.6871 .25212 m .6549 .23189 L .67479 .22382 L .577 .769 .97 r
F
.6871 .25212 m .67479 .22382 L .7052 .21147 L F
.6549 .23189 m .6549 .23189 L .7052 .21147 L F
.65272 .21044 m .6682 .20866 L .656 .22996 L .303 .416 .811 r
F
.64727 .17803 m .6682 .20866 L p .65272 .21044 L F P
0 g
s
.63629 .17651 m .65606 .15693 L .68741 .1754 L p .558 .63 .879 r
F P
0 g
s
.65262 .16635 m .67185 .20234 L .6682 .20866 L 0 .049 .611 r
F
.6682 .20866 m .64727 .17803 L .65117 .16951 L p F P
0 g
s
.65117 .16951 m .65262 .16635 L p .6682 .20866 L 0 .049 .611 r
F P
0 g
s
.64581 .21122 m .656 .22996 L .64408 .25044 L .303 .416 .811 r
F
.64727 .17803 m .65272 .21044 L .64581 .21122 L F
.65272 .21044 m .656 .22996 L .64581 .21122 L F
.64408 .25044 m .61731 .21201 L .64146 .18462 L p F P
0 g
s
.64146 .18462 m .64727 .17803 L p .64408 .25044 L .303 .416 .811 r
F P
0 g
s
.61292 .2031 m .58667 .23708 L .53772 .20977 L p .651 .658 .843 r
F P
0 g
s
.53772 .20977 m .56984 .17792 L .61292 .2031 L p .651 .658 .843 r
F P
0 g
s
.63629 .17651 m .61292 .2031 L .56984 .17792 L p .617 .661 .87 r
F P
0 g
s
.56984 .17792 m .53772 .20977 L .48958 .18323 L p .671 .693 .862 r
F P
0 g
s
.48958 .18323 m .52851 .15334 L .56984 .17792 L p .671 .693 .862 r
F P
0 g
s
.59969 .15445 m .56984 .17792 L .52851 .15334 L p .633 .695 .889 r
F P
0 g
s
.56984 .17792 m .59969 .15445 L .63629 .17651 L p .617 .661 .87 r
F P
0 g
s
.56526 .13293 m .52851 .15334 L .4904 .12993 L p .644 .732 .913 r
F P
0 g
s
.52851 .15334 m .56526 .13293 L .59969 .15445 L p .633 .695 .889 r
F P
0 g
s
.62593 .13841 m .59969 .15445 L .56526 .13293 L p .587 .691 .914 r
F P
0 g
s
.4904 .12993 m .53432 .11259 L .56526 .13293 L p .644 .732 .913 r
F P
0 g
s
.59802 .12041 m .56526 .13293 L .53432 .11259 L p .591 .724 .936 r
F P
0 g
s
.56526 .13293 m .59802 .12041 L .62593 .13841 L p .587 .691 .914 r
F P
0 g
s
.61731 .21201 m .54559 .16289 L .56637 .12361 L p .411 .58 .909 r
F P
0 g
s
.65606 .15693 m .63629 .17651 L .59969 .15445 L p .576 .66 .895 r
F P
0 g
s
.59969 .15445 m .62593 .13841 L .65606 .15693 L p .576 .66 .895 r
F P
0 g
s
.56637 .12361 m .64727 .17803 L .61731 .21201 L p .411 .58 .909 r
F P
0 g
s
.68273 .20703 m .66944 .20653 L .67054 .20462 L .185 .694 .9 r
F
.7052 .21147 m .66828 .20867 L p .68273 .20703 L F P
0 g
s
.66828 .20867 m .61101 .20433 L p .68273 .20703 L .185 .694 .9 r
F P
0 g
s
.68264 .20701 m .67054 .20462 L .71065 .2038 L .185 .694 .9 r
F
.65262 .16635 m .67429 .19811 L p .67185 .20234 L 0 .049 .611 r
F P
0 g
s
.67054 .20462 m .61502 .19364 L .6733 .19983 L .185 .694 .9 r
F
.67054 .20462 m .6733 .19983 L .71065 .2038 L F
.66828 .20867 m .7052 .21147 L p .65489 .23189 L .577 .769 .97 r
F P
0 g
s
.68436 .29348 m .70066 .25376 L .74401 .27847 L p .574 .559 .799 r
F P
0 g
s
.70066 .25376 m .712 .22023 L .74941 .24089 L p .542 .564 .826 r
F P
0 g
s
.74941 .24089 m .74401 .27847 L .70066 .25376 L p .542 .564 .826 r
F P
0 g
s
.74401 .27847 m .73249 .32222 L .68436 .29348 L p .574 .559 .799 r
F P
0 g
s
.73249 .32222 m .74401 .27847 L .78597 .30198 L p .537 .52 .785 r
F P
0 g
s
.74401 .27847 m .74941 .24089 L .78526 .25995 L p .503 .527 .814 r
F P
0 g
s
.78526 .25995 m .78597 .30198 L .74401 .27847 L p .503 .527 .814 r
F P
0 g
s
.712 .22023 m .71908 .19331 L .75018 .21014 L p .504 .568 .853 r
F P
0 g
s
.75018 .21014 m .74941 .24089 L .712 .22023 L p .504 .568 .853 r
F P
0 g
s
.76915 .29196 m .69075 .25441 L .7052 .21147 L p .448 .628 .93 r
F P
0 g
s
.70781 .24721 m .70056 .25603 L p .67185 .20234 L 0 .049 .611 r
F P
0 g
s
.71264 .20101 m .71065 .2038 L p .6733 .19983 L .185 .694 .9 r
F P
0 g
s
.67402 .19859 m .68741 .1754 L .71908 .19331 L p .535 .6 .865 r
F P
0 g
s
.67429 .19811 m .71264 .20101 L p .6733 .19983 L .185 .694 .9 r
F P
0 g
s
.67429 .19811 m .70781 .24721 L p .67185 .20234 L 0 .049 .611 r
F P
0 g
s
.61101 .20433 m .61502 .19364 L p .67054 .20462 L .185 .694 .9 r
F P
0 g
s
.66944 .20653 m .61101 .20433 L .67054 .20462 L .185 .694 .9 r
F
.656 .22996 m .65489 .23189 L .64408 .25044 L .303 .416 .811 r
F
.6549 .23189 m .64408 .25044 L .65489 .23189 L .577 .769 .97 r
F
.69075 .25441 m .64416 .25045 L p .6549 .23189 L F P
0 g
s
.64416 .25045 m .64408 .25044 L p .6549 .23189 L .577 .769 .97 r
F P
0 g
s
.66301 .33781 m .68436 .29348 L .73249 .32222 L p .602 .553 .772 r
F P
0 g
s
.73249 .32222 m .7139 .3702 L .66301 .33781 L p .602 .553 .772 r
F P
0 g
s
.7139 .3702 m .73249 .32222 L .77954 .35064 L p .567 .514 .756 r
F P
0 g
s
.73732 .34495 m .67123 .31256 L .69075 .25441 L p .576 .624 .863 r
F P
0 g
s
.78597 .30198 m .77954 .35064 L .73249 .32222 L p .537 .52 .785 r
F P
0 g
s
.69075 .25441 m .76915 .29196 L .73732 .34495 L p .576 .624 .863 r
F P
0 g
s
.70056 .25603 m .66433 .27951 L p .65601 .22998 L .303 .416 .811 r
F P
0 g
s
.656 .22996 m .65601 .22997 L .65601 .22998 L .303 .416 .811 r
F
.65601 .22997 m .70056 .25603 L .65601 .22998 L F
.64414 .25053 m .64408 .25044 L p .65489 .23189 L F P
0 g
s
.61731 .21201 m .64417 .25056 L p .61711 .29726 L .493 .501 .794 r
F P
0 g
s
.58667 .23708 m .55895 .27774 L .50546 .24986 L p .678 .652 .817 r
F P
0 g
s
.50546 .24986 m .53772 .20977 L .58667 .23708 L p .678 .652 .817 r
F P
0 g
s
.54559 .16289 m .61731 .21201 L .57671 .25799 L p .56 .604 .854 r
F P
0 g
s
.60879 .24744 m .61101 .20433 L p .65489 .23189 L .577 .769 .97 r
F P
0 g
s
.64408 .25044 m .60879 .24744 L p .65489 .23189 L .577 .769 .97 r
F P
0 g
s
.61101 .20433 m .6682 .20866 L p .65489 .23189 L .577 .769 .97 r
F P
0 g
s
.6682 .20866 m .66828 .20867 L p .66824 .20875 L .577 .769 .97 r
F P
0 g
s
.65489 .23189 m .6682 .20866 L .66824 .20875 L .577 .769 .97 r
F
.70056 .25603 m .6682 .20866 L p .67185 .20234 L 0 .049 .611 r
F P
0 g
s
.61502 .19364 m .67429 .19811 L p .6733 .19983 L .185 .694 .9 r
F P
0 g
s
.71065 .2038 m .7052 .21147 L p .68264 .20701 L .185 .694 .9 r
F P
0 g
s
.6682 .20866 m .70056 .25603 L p .656 .22996 L .303 .416 .811 r
F P
0 g
s
.6549 .23189 m .65489 .23189 L .6549 .23189 L .577 .769 .97 r
F
.66433 .27951 m .64414 .25053 L p .656 .22996 L .303 .416 .811 r
F P
0 g
s
.64549 .28571 m .63197 .27161 L .64478 .26787 L .657 .713 .89 r
F
.60879 .24744 m .64408 .25044 L p .63197 .27161 L F P
0 g
s
.66433 .27951 m .61707 .3113 L p .6171 .2976 L .493 .501 .794 r
F P
0 g
s
.61711 .29726 m .61735 .29717 L .6171 .2976 L .493 .501 .794 r
F
.61735 .29717 m .66433 .27951 L .6171 .2976 L F
.63204 .27169 m .63168 .27212 L .63197 .27161 L .657 .713 .89 r
F
.61246 .30521 m .60488 .30426 L p .63204 .27169 L F P
0 g
s
.64417 .25056 m .66433 .27951 L p .61711 .29726 L .493 .501 .794 r
F P
0 g
s
.60488 .30426 m .60879 .24744 L p .63197 .27161 L .657 .713 .89 r
F P
0 g
s
.63168 .27212 m .60488 .30426 L .63197 .27161 L .657 .713 .89 r
F
.61707 .3113 m .61246 .30521 L p .61711 .29726 L .493 .501 .794 r
F P
0 g
s
.67123 .31256 m .6476 .37096 L p .61139 .31443 L .685 .678 .838 r
F P
0 g
s
.61139 .31443 m .60917 .31096 L .61179 .31103 L .685 .678 .838 r
F
.61246 .30521 m .61237 .30537 L .57359 .3468 L .569 .529 .771 r
F
.6017 .32385 m .57359 .3468 L p .61249 .30525 L F P
0 g
s
.60488 .30426 m .61246 .30521 L p .60917 .31096 L .685 .678 .838 r
F P
0 g
s
.61246 .30521 m .61249 .30525 L p .61237 .30537 L .569 .529 .771 r
F P
0 g
s
.61029 .31271 m .6017 .32385 L .60917 .31096 L .685 .678 .838 r
F
.61249 .30525 m .61707 .3113 L .6017 .32385 L p .569 .529 .771 r
F P
0 g
s
.6017 .32385 m .60488 .30426 L p .60917 .31096 L .685 .678 .838 r
F P
0 g
s
.54875 .31909 m .60488 .30426 L .6017 .32385 L p .755 .745 .844 r
F P
0 g
s
.6017 .32385 m .59588 .35967 L p .58598 .35115 L .755 .745 .844 r
F P
0 g
s
.6014 .32437 m .57979 .3618 L .59026 .33868 L .514 .434 .704 r
F
.58598 .35115 m .57979 .3618 L .6014 .32437 L F
.59421 .32997 m .6017 .32385 L p .59026 .33868 L F P
0 g
s
.6017 .32385 m .60199 .32362 L p .59026 .33868 L .514 .434 .704 r
F P
0 g
s
.58598 .35115 m .54875 .31909 L .6017 .32385 L .755 .745 .844 r
F
.60199 .32362 m .58598 .35115 L .6014 .32437 L .514 .434 .704 r
F
.57359 .3468 m .57979 .3618 L p .56483 .38263 L .55 .454 .699 r
F P
0 g
s
.57979 .3618 m .55325 .36532 L p .58508 .35269 L .755 .745 .844 r
F P
0 g
s
.57979 .3618 m .58508 .35269 L .58693 .35196 L .755 .745 .844 r
F
.55325 .36532 m .54875 .31909 L p .58689 .35192 L F P
0 g
s
.58693 .35196 m .58683 .352 L .58689 .35192 L .755 .745 .844 r
F
.58683 .352 m .55325 .36532 L .58689 .35192 L F
.60199 .32362 m .61707 .3113 L p .57979 .3618 L .514 .434 .704 r
F P
0 g
s
.60915 .4287 m .63739 .38403 L .6883 .41926 L p .648 .543 .721 r
F P
0 g
s
.7139 .3702 m .6883 .41926 L .63739 .38403 L p .626 .548 .747 r
F P
0 g
s
.59588 .35967 m .6476 .37096 L .62015 .42239 L p .7 .659 .806 r
F P
0 g
s
.62015 .42239 m .58047 .40727 L .59588 .35967 L p .7 .659 .806 r
F P
0 g
s
.59001 .38654 m .57979 .3618 L p .61707 .3113 L .514 .434 .704 r
F P
0 g
s
.56757 .38306 m .56758 .38306 L .56625 .38536 L .55 .454 .699 r
F
.56757 .38306 m .56625 .38536 L .56263 .3916 L F
.57979 .3618 m .59001 .38654 L p .56483 .38263 L F P
0 g
s
.56483 .38263 m .56263 .3916 L .5592 .39044 L .55 .454 .699 r
F
.56483 .38263 m .5592 .39044 L .54007 .38395 L F
.55325 .36532 m .57979 .3618 L p .56625 .38536 L .757 .722 .82 r
F P
0 g
s
.55461 .40541 m .54007 .38395 L p .56263 .3916 L .55 .454 .699 r
F P
0 g
s
.54855 .40497 m .55325 .36532 L p .56625 .38536 L .757 .722 .82 r
F P
0 g
s
.56625 .38536 m .56622 .3854 L .56625 .38536 L .757 .722 .82 r
F
.56622 .3854 m .54855 .40497 L .56625 .38536 L F
.58047 .40727 m .55461 .40541 L p .56692 .38638 L F P
0 g
s
.55461 .40541 m .54855 .40497 L p .56692 .38638 L .757 .722 .82 r
F P
0 g
s
.55461 .40541 m .58047 .40727 L p .55047 .41261 L .76 .714 .809 r
F P
0 g
s
.59001 .38654 m .55802 .41044 L p .56263 .3916 L .55 .454 .699 r
F P
0 g
s
.56692 .38638 m .56387 .38947 L .56625 .38536 L .757 .722 .82 r
F
.56387 .38947 m .54855 .40497 L .56625 .38536 L F
.56758 .38306 m .59001 .38654 L .56263 .3916 L .55 .454 .699 r
F
.55802 .41044 m .55461 .40541 L p .56263 .3916 L F P
0 g
s
.53695 .43272 m .55461 .40541 L .53671 .43642 L .563 .46 .695 r
F
.55461 .40541 m .55462 .40542 L p .55047 .41261 L F P
0 g
s
.55461 .40541 m .55047 .41261 L .53671 .43642 L .563 .46 .695 r
F
.58047 .40727 m .55883 .44601 L p .55047 .41261 L .76 .714 .809 r
F P
0 g
s
.54855 .40497 m .55461 .40541 L p .55047 .41261 L .76 .714 .809 r
F P
0 g
s
.53603 .4376 m .51734 .42206 L p .53671 .43642 L .563 .46 .695 r
F P
0 g
s
.53603 .4376 m .53533 .43734 L p .5506 .41315 L .76 .714 .809 r
F P
0 g
s
.53603 .4376 m .55883 .44601 L p .53517 .43909 L .762 .713 .806 r
F P
0 g
s
.55802 .41044 m .5366 .43807 L p .53671 .43642 L .563 .46 .695 r
F P
0 g
s
.53533 .43734 m .54855 .40497 L p .55048 .41266 L .76 .714 .809 r
F P
0 g
s
.5506 .41315 m .54565 .42099 L .55048 .41266 L .76 .714 .809 r
F
.54565 .42099 m .53533 .43734 L .55048 .41266 L F
.55462 .40542 m .55802 .41044 L p .53671 .43642 L .563 .46 .695 r
F P
0 g
s
.5366 .43807 m .53603 .4376 L p .53671 .43642 L .563 .46 .695 r
F P
0 g
s
.53533 .43734 m .53603 .4376 L p .53517 .43909 L .762 .713 .806 r
F P
0 g
s
.5366 .43807 m .52454 .46833 L p .52321 .45982 L .565 .46 .693 r
F P
0 g
s
.52321 .45981 m .52332 .45962 L .52321 .45982 L .565 .46 .693 r
F
.52332 .45962 m .5366 .43807 L .52321 .45982 L F
.53516 .43912 m .52321 .45981 L .53517 .43909 L .762 .713 .806 r
F
.53603 .4376 m .5366 .43807 L p .52321 .45981 L .565 .46 .693 r
F P
0 g
s
.53517 .43909 m .51939 .46642 L .5352 .43874 L .762 .713 .806 r
F
.52321 .45981 m .51939 .46642 L .53517 .43909 L F
.52454 .46833 m .51939 .46642 L p .52321 .45981 L .565 .46 .693 r
F P
0 g
s
.51939 .46642 m .52454 .46833 L p .5164 .47165 L .565 .461 .694 r
F P
0 g
s
.51939 .46642 m .5164 .47165 L .50998 .47426 L .565 .461 .694 r
F
.51516 .46292 m .53533 .43734 L p .5352 .43874 L .762 .713 .806 r
F P
0 g
s
.51939 .46642 m .51516 .46292 L p .5352 .43874 L .762 .713 .806 r
F P
0 g
s
.51516 .46292 m .51939 .46642 L p .49989 .4998 L .761 .713 .807 r
F P
0 g
s
.50028 .49951 m .49989 .4998 L p .51939 .46642 L .761 .713 .807 r
F P
0 g
s
.52454 .46833 m .52067 .5 L p .51202 .47918 L .565 .461 .694 r
F P
0 g
s
.51636 .47166 m .52454 .46833 L .51202 .47918 L .565 .461 .694 r
F
.5044 .46083 m .51379 .46433 L p .50998 .47426 L F P
0 g
s
.52067 .5 m .50023 .5 L .50028 .49951 L p .565 .461 .694 r
F P
0 g
s
.50028 .49951 m .50023 .5 L p .50011 .4998 L .638 .526 .71 r
F P
0 g
s
.5 .5 m .50762 .5132 L p .48797 .52082 L .742 .65 .758 r
F P
0 g
s
.50762 .5132 m .51533 .52656 L .47329 .54626 L p .742 .65 .758 r
F P
0 g
s
.47329 .54626 m .47261 .54658 L p .50762 .5132 L .742 .65 .758 r
F P
0 g
s
.47329 .54626 m .51533 .52656 L p .47327 .54629 L .727 .606 .722 r
F P
0 g
s
.48797 .52082 m .49995 .50008 L .5044 .53917 L .638 .516 .698 r
F
.49995 .50008 m .50002 .50016 L .5044 .53917 L F
.5003 .50064 m .5044 .53917 L p .50002 .50016 L F P
0 g
s
.5 .5 m .50015 .50033 L .50002 .50016 L .638 .516 .698 r
F
.50015 .50033 m .5003 .50064 L .50002 .50016 L F
.51533 .52656 m .53556 .56159 L .4871 .58557 L p .727 .606 .722 r
F P
0 g
s
.5173 .52151 m .51636 .52834 L .51202 .52082 L .761 .53 .583 r
F
.50028 .50049 m .53172 .5234 L p .5173 .52151 L F P
0 g
s
.51939 .53358 m .5044 .53917 L .50028 .50049 L p .565 .462 .696 r
F P
0 g
s
.5173 .52151 m .51202 .52082 L .50028 .50049 L .761 .53 .583 r
F
.55404 .50043 m .53172 .5234 L .50028 .50049 L p .732 .548 .644 r
F P
0 g
s
.55404 .50043 m .50028 .50049 L .50011 .5002 L .732 .548 .644 r
F
.50028 .50049 m .50028 .50049 L p .51202 .52082 L .565 .462 .696 r
F P
0 g
s
.51202 .52082 m .51939 .53358 L .50028 .50049 L .565 .462 .696 r
F
.51202 .52082 m .48967 .5179 L .50028 .50049 L .761 .53 .583 r
F
.52399 .52978 m .51939 .53358 L p .5173 .52151 L F P
0 g
s
.55947 .603 m .53556 .56159 L .58055 .53161 L p .691 .561 .703 r
F P
0 g
s
.53172 .5234 m .55883 .55399 L p .5232 .5402 L .762 .531 .584 r
F P
0 g
s
.51939 .53358 m .53172 .5234 L p .5232 .5402 L .762 .531 .584 r
F P
0 g
s
.5044 .53917 m .51939 .53358 L p .53514 .56089 L .566 .464 .697 r
F P
0 g
s
.53556 .56159 m .55947 .603 L .50717 .63017 L p .711 .568 .691 r
F P
0 g
s
.50717 .63017 m .4871 .58557 L .53556 .56159 L p .711 .568 .691 r
F P
0 g
s
.51734 .57794 m .5044 .53917 L p .53517 .56091 L .566 .464 .697 r
F P
0 g
s
.52373 .5404 m .53603 .5624 L .5232 .5402 L .762 .531 .584 r
F
.55883 .55399 m .53603 .5624 L p .52373 .5404 L F P
0 g
s
.53603 .5624 m .53603 .5624 L p .52373 .5404 L .762 .531 .584 r
F P
0 g
s
.58055 .53161 m .60915 .5713 L .55947 .603 L p .691 .561 .703 r
F P
0 g
s
.58541 .64794 m .55947 .603 L .60915 .5713 L p .672 .523 .674 r
F P
0 g
s
.55883 .55399 m .58047 .59273 L p .53671 .56358 L .761 .528 .58 r
F P
0 g
s
.51734 .57794 m .53603 .5624 L p .54992 .58725 L .563 .46 .694 r
F P
0 g
s
.53603 .5624 m .53603 .5624 L p .53608 .5625 L .563 .46 .694 r
F P
0 g
s
.53603 .5624 m .53608 .5625 L .54992 .58725 L .563 .46 .694 r
F
.58047 .59273 m .55461 .59459 L p .53979 .56563 L .761 .528 .58 r
F P
0 g
s
.55947 .603 m .58541 .64794 L .53173 .67696 L p .695 .531 .661 r
F P
0 g
s
.60915 .5713 m .63739 .61597 L .58541 .64794 L p .672 .523 .674 r
F P
0 g
s
.58047 .59273 m .59588 .64033 L p .56923 .61482 L .758 .515 .565 r
F P
0 g
s
.61143 .693 m .58541 .64794 L .63739 .61597 L p .652 .484 .644 r
F P
0 g
s
.58541 .64794 m .61143 .693 L .55895 .72226 L p .677 .493 .63 r
F P
0 g
s
.55895 .72226 m .53173 .67696 L .58541 .64794 L p .677 .493 .63 r
F P
0 g
s
.63739 .61597 m .66301 .66219 L .61143 .693 L p .652 .484 .644 r
F P
0 g
s
.66301 .66219 m .63739 .61597 L .6883 .58074 L p .626 .474 .657 r
F P
0 g
s
.6476 .62904 m .59588 .64033 L .58047 .59273 L p .7 .485 .592 r
F P
0 g
s
.56923 .61482 m .56749 .61699 L .56256 .60844 L .758 .515 .565 r
F
.57979 .6382 m .57359 .6532 L p .56735 .62084 L .55 .443 .685 r
F P
0 g
s
.56616 .61469 m .57979 .6382 L .56735 .62084 L .55 .443 .685 r
F
.53173 .67696 m .50717 .63017 L .55947 .603 L p .695 .531 .661 r
F P
0 g
s
.57359 .6532 m .54007 .61605 L p .56616 .61469 L .55 .443 .685 r
F P
0 g
s
.57359 .6532 m .57977 .63825 L p .58474 .6493 L .514 .404 .667 r
F P
0 g
s
.57979 .6382 m .59588 .64033 L .60015 .66661 L p .756 .488 .528 r
F P
0 g
s
.57977 .63825 m .57979 .6382 L p .58474 .6493 L .514 .404 .667 r
F P
0 g
s
.53173 .67696 m .55895 .72226 L .50546 .75014 L p .701 .5 .614 r
F P
0 g
s
.53795 .69235 m .57359 .6532 L .6017 .67615 L p .569 .4 .613 r
F P
0 g
s
.53795 .69235 m .6017 .67615 L .60705 .68916 L .569 .4 .613 r
F
.63567 .73498 m .61143 .693 L .66301 .66219 L p .63 .442 .609 r
F P
0 g
s
.66301 .66219 m .68436 .70652 L .63567 .73498 L p .63 .442 .609 r
F P
0 g
s
.59588 .64033 m .6476 .62904 L .67123 .68744 L p .685 .44 .546 r
F P
0 g
s
.61143 .693 m .63567 .73498 L .58667 .76292 L p .655 .45 .595 r
F P
0 g
s
.58667 .76292 m .55895 .72226 L .61143 .693 L p .655 .45 .595 r
F P
0 g
s
.65675 .77151 m .63567 .73498 L .68436 .70652 L p .604 .394 .569 r
F P
0 g
s
.68436 .70652 m .70066 .74624 L .65675 .77151 L p .604 .394 .569 r
F P
0 g
s
.67123 .68744 m .69075 .74559 L p .64548 .71931 L .658 .36 .456 r
F P
0 g
s
.60501 .68925 m .60776 .6913 L .57671 .74201 L .569 .4 .613 r
F
.61246 .69479 m .57671 .74201 L p .60913 .68906 L F P
0 g
s
.64548 .71931 m .61703 .70279 L .61246 .69479 L .658 .36 .456 r
F
.61246 .69479 m .67123 .68744 L p .64548 .71931 L F P
0 g
s
.67123 .68744 m .61246 .69479 L p .59588 .64033 L .685 .44 .546 r
F P
0 g
s
.57671 .74201 m .61246 .69479 L p .63171 .72851 L .493 .303 .551 r
F P
0 g
s
.61292 .7969 m .58667 .76292 L .63567 .73498 L p .629 .402 .555 r
F P
0 g
s
.63567 .73498 m .65675 .77151 L .61292 .7969 L p .629 .402 .555 r
F P
0 g
s
.61731 .78799 m .57671 .74201 L p .61284 .73314 L .493 .303 .551 r
F P
0 g
s
.61284 .73314 m .62865 .74145 L .61731 .78799 L .493 .303 .551 r
F
.64408 .74956 m .61731 .78799 L p .6318 .72848 L F P
0 g
s
.67402 .80141 m .65675 .77151 L .70066 .74624 L p .573 .338 .522 r
F P
0 g
s
.70066 .74624 m .712 .77977 L .67402 .80141 L p .573 .338 .522 r
F P
0 g
s
.68741 .8246 m .67402 .80141 L .712 .77977 L p .535 .274 .466 r
F P
0 g
s
.65675 .77151 m .67402 .80141 L .63629 .82349 L p .597 .347 .508 r
F P
0 g
s
.63629 .82349 m .61292 .7969 L .65675 .77151 L p .597 .347 .508 r
F P
0 g
s
.65606 .84307 m .63629 .82349 L .67402 .80141 L p .558 .282 .453 r
F P
0 g
s
.64727 .82197 m .61731 .78799 L p .62112 .78597 L .304 .079 .399 r
F P
0 g
s
.62112 .78597 m .65474 .7682 L .65179 .78947 L .304 .079 .399 r
F
.62112 .78597 m .65179 .78947 L .64727 .82197 L F
.65474 .7682 m .65474 .76821 L .64727 .82197 L F
.67441 .77704 m .6682 .79134 L .65586 .77012 L .578 .174 .241 r
F
.7052 .78853 m .6682 .79134 L p .67441 .77704 L F P
0 g
s
.712 .77977 m .71908 .80669 L .68741 .8246 L p .535 .274 .466 r
F P
0 g
s
.71264 .79899 m .67185 .79766 L .6682 .79134 L .185 0 0 r
F
.6682 .79134 m .7052 .78853 L .71063 .79617 L p F P
0 g
s
.71063 .79617 m .71264 .79899 L p .6682 .79134 L .185 0 0 r
F P
0 g
s
.67718 .77066 m .65586 .77012 L .64408 .74956 L .578 .174 .241 r
F
.7052 .78853 m .67441 .77704 L .67718 .77066 L F
.67441 .77704 m .65586 .77012 L .67718 .77066 L F
.64408 .74956 m .69075 .74559 L .70239 .7802 L p F P
0 g
s
.70239 .7802 m .7052 .78853 L p .64408 .74956 L .578 .174 .241 r
F P
0 g
s
.70066 .74624 m .68436 .70652 L .73249 .67778 L p .574 .379 .579 r
F P
0 g
s
.73249 .67778 m .74401 .72153 L .70066 .74624 L p .574 .379 .579 r
F P
0 g
s
.712 .77977 m .70066 .74624 L .74401 .72153 L p .542 .321 .53 r
F P
0 g
s
.74401 .72153 m .73249 .67778 L .77954 .64936 L p .537 .356 .584 r
F P
0 g
s
.77954 .64936 m .78597 .69802 L .74401 .72153 L p .537 .356 .584 r
F P
0 g
s
.74941 .75911 m .74401 .72153 L .78597 .69802 L p .503 .295 .53 r
F P
0 g
s
.74401 .72153 m .74941 .75911 L .712 .77977 L p .542 .321 .53 r
F P
0 g
s
.78526 .74005 m .78597 .69802 L .82529 .67672 L p .45 .253 .52 r
F P
0 g
s
.78597 .69802 m .78526 .74005 L .74941 .75911 L p .503 .295 .53 r
F P
0 g
s
.75018 .78986 m .74941 .75911 L .78526 .74005 L p .463 .225 .466 r
F P
0 g
s
.82529 .67672 m .81835 .72342 L .78526 .74005 L p .45 .253 .52 r
F P
0 g
s
.77973 .77469 m .78526 .74005 L .81835 .72342 L p .408 .177 .449 r
F P
0 g
s
.78526 .74005 m .77973 .77469 L .75018 .78986 L p .463 .225 .466 r
F P
0 g
s
.69075 .74559 m .76915 .70804 L .79278 .74567 L p .449 .104 .288 r
F P
0 g
s
.71908 .80669 m .712 .77977 L .74941 .75911 L p .504 .256 .471 r
F P
0 g
s
.74941 .75911 m .75018 .78986 L .71908 .80669 L p .504 .256 .471 r
F P
0 g
s
.79278 .74567 m .7052 .78853 L .69075 .74559 L p .449 .104 .288 r
F P
0 g
s
.66235 .80474 m .66944 .79347 L .67054 .79538 L 0 0 0 r
F
.64727 .82197 m .66816 .7914 L p .66235 .80474 L F P
0 g
s
.66816 .7914 m .70056 .74397 L p .66235 .80474 L 0 0 0 r
F P
0 g
s
.66242 .80466 m .67054 .79538 L .65119 .83053 L 0 0 0 r
F
.71264 .79899 m .67429 .80189 L p .67185 .79766 L .185 0 0 r
F P
0 g
s
.67054 .79538 m .70781 .75279 L .6733 .80017 L 0 0 0 r
F
.67054 .79538 m .6733 .80017 L .65119 .83053 L F
.66816 .7914 m .64727 .82197 L p .65474 .7682 L .304 .079 .399 r
F P
0 g
s
.58667 .76292 m .61292 .7969 L .56984 .82208 L p .651 .406 .535 r
F P
0 g
s
.61292 .7969 m .63629 .82349 L .59969 .84555 L p .617 .347 .486 r
F P
0 g
s
.59969 .84555 m .56984 .82208 L .61292 .7969 L p .617 .347 .486 r
F P
0 g
s
.56984 .82208 m .53772 .79023 L .58667 .76292 L p .651 .406 .535 r
F P
0 g
s
.53772 .79023 m .56984 .82208 L .52851 .84666 L p .671 .403 .506 r
F P
0 g
s
.56984 .82208 m .59969 .84555 L .56526 .86707 L p .633 .34 .454 r
F P
0 g
s
.56526 .86707 m .52851 .84666 L .56984 .82208 L p .633 .34 .454 r
F P
0 g
s
.63629 .82349 m .65606 .84307 L .62593 .86159 L p .576 .28 .43 r
F P
0 g
s
.62593 .86159 m .59969 .84555 L .63629 .82349 L p .576 .28 .43 r
F P
0 g
s
.54559 .83711 m .61731 .78799 L .64727 .82197 L p .412 .091 .31 r
F P
0 g
s
.61502 .80636 m .61101 .79567 L p .67185 .79766 L .185 0 0 r
F P
0 g
s
.65262 .83365 m .65119 .83053 L p .6733 .80017 L 0 0 0 r
F P
0 g
s
.67402 .80141 m .68741 .8246 L .65606 .84307 L p .558 .282 .453 r
F P
0 g
s
.67429 .80189 m .65262 .83365 L p .6733 .80017 L 0 0 0 r
F P
0 g
s
.67429 .80189 m .61502 .80636 L p .67185 .79766 L .185 0 0 r
F P
0 g
s
.70056 .74397 m .70781 .75279 L p .67054 .79538 L 0 0 0 r
F P
0 g
s
.66944 .79347 m .70056 .74397 L .67054 .79538 L 0 0 0 r
F
.65586 .77012 m .65474 .7682 L .64408 .74956 L .578 .174 .241 r
F
.65474 .7682 m .64408 .74956 L .65474 .7682 L .304 .079 .399 r
F
.61731 .78799 m .64404 .74963 L p .65474 .7682 L F P
0 g
s
.64404 .74963 m .64408 .74956 L p .65474 .7682 L .304 .079 .399 r
F P
0 g
s
.55895 .72226 m .58667 .76292 L .53772 .79023 L p .678 .456 .576 r
F P
0 g
s
.53772 .79023 m .50546 .75014 L .55895 .72226 L p .678 .456 .576 r
F P
0 g
s
.50546 .75014 m .53772 .79023 L .48958 .81677 L p .701 .458 .552 r
F P
0 g
s
.51562 .78305 m .57671 .74201 L .61731 .78799 L p .56 .311 .495 r
F P
0 g
s
.52851 .84666 m .48958 .81677 L .53772 .79023 L p .671 .403 .506 r
F P
0 g
s
.61731 .78799 m .54559 .83711 L .51562 .78305 L p .56 .311 .495 r
F P
0 g
s
.61101 .79567 m .60879 .75256 L p .65584 .77012 L .578 .174 .241 r
F P
0 g
s
.65586 .77012 m .65585 .77013 L .65584 .77012 L .578 .174 .241 r
F
.65585 .77013 m .61101 .79567 L .65584 .77012 L F
.64398 .74957 m .64408 .74956 L p .65474 .7682 L F P
0 g
s
.69075 .74559 m .64393 .74957 L p .61703 .70279 L .658 .36 .456 r
F P
0 g
s
.68436 .70652 m .66301 .66219 L .7139 .6298 L p .602 .429 .621 r
F P
0 g
s
.7139 .6298 m .73249 .67778 L .68436 .70652 L p .602 .429 .621 r
F P
0 g
s
.76915 .70804 m .69075 .74559 L .67123 .68744 L p .576 .317 .486 r
F P
0 g
s
.66433 .72049 m .70056 .74397 L p .65474 .7682 L .304 .079 .399 r
F P
0 g
s
.64408 .74956 m .66433 .72049 L p .65474 .7682 L .304 .079 .399 r
F P
0 g
s
.70056 .74397 m .6682 .79134 L p .65474 .7682 L .304 .079 .399 r
F P
0 g
s
.6682 .79134 m .66816 .7914 L p .66811 .79132 L .304 .079 .399 r
F P
0 g
s
.65474 .7682 m .6682 .79134 L .66811 .79132 L .304 .079 .399 r
F
.61101 .79567 m .6682 .79134 L p .67185 .79766 L .185 0 0 r
F P
0 g
s
.70781 .75279 m .67429 .80189 L p .6733 .80017 L 0 0 0 r
F P
0 g
s
.65119 .83053 m .64727 .82197 L p .66242 .80466 L 0 0 0 r
F P
0 g
s
.6682 .79134 m .61101 .79567 L p .65586 .77012 L .578 .174 .241 r
F P
0 g
s
.65474 .7682 m .65474 .7682 L .65474 .76821 L .304 .079 .399 r
F
.60879 .75256 m .64398 .74957 L p .65586 .77012 L .578 .174 .241 r
F P
0 g
s
.61284 .73314 m .6318 .72848 L .62865 .74145 L .493 .303 .551 r
F
.66433 .72049 m .64408 .74956 L p .6318 .72848 L F P
0 g
s
.60879 .75256 m .60488 .69574 L p .61673 .70262 L .658 .36 .456 r
F P
0 g
s
.61703 .70279 m .61698 .70305 L .61673 .70262 L .658 .36 .456 r
F
.61698 .70305 m .60879 .75256 L .61673 .70262 L F
.63171 .72851 m .63151 .72798 L .6318 .72848 L .493 .303 .551 r
F
.61246 .69479 m .61707 .6887 L p .63171 .72851 L F P
0 g
s
.64393 .74957 m .60879 .75256 L p .61703 .70279 L .658 .36 .456 r
F P
0 g
s
.61707 .6887 m .66433 .72049 L p .6318 .72848 L .493 .303 .551 r
F P
0 g
s
.63151 .72798 m .61707 .6887 L .6318 .72848 L .493 .303 .551 r
F
.60488 .69574 m .61246 .69479 L p .61703 .70279 L .658 .36 .456 r
F P
0 g
s
.57671 .74201 m .53795 .69235 L p .60501 .68925 L .569 .4 .613 r
F P
0 g
s
.60501 .68925 m .60913 .68906 L .60776 .6913 L .569 .4 .613 r
F
.61246 .69479 m .61237 .69463 L .59588 .64033 L .685 .44 .546 r
F
.6017 .67615 m .59588 .64033 L p .61242 .69479 L F P
0 g
s
.61707 .6887 m .61246 .69479 L p .60913 .68906 L .569 .4 .613 r
F P
0 g
s
.61246 .69479 m .61242 .69479 L p .61237 .69463 L .685 .44 .546 r
F P
0 g
s
.60705 .68916 m .6017 .67615 L .60913 .68906 L .569 .4 .613 r
F
.61242 .69479 m .60488 .69574 L .6017 .67615 L p .685 .44 .546 r
F P
0 g
s
.6017 .67615 m .61707 .6887 L p .60913 .68906 L .569 .4 .613 r
F P
0 g
s
.6323 .63268 m .61707 .6887 L .6017 .67615 L p .514 .404 .667 r
F P
0 g
s
.6017 .67615 m .57359 .6532 L p .58592 .64889 L .514 .404 .667 r
F P
0 g
s
.6014 .67563 m .57979 .6382 L .59458 .65883 L .756 .488 .528 r
F
.58592 .64889 m .57979 .6382 L .6014 .67563 L F
.60015 .66661 m .6017 .67615 L p .59458 .65883 L F P
0 g
s
.6017 .67615 m .60176 .67652 L p .59458 .65883 L .756 .488 .528 r
F P
0 g
s
.58592 .64889 m .6323 .63268 L .6017 .67615 L .514 .404 .667 r
F
.60176 .67652 m .58592 .64889 L .6014 .67563 L .756 .488 .528 r
F
.59588 .64033 m .57979 .6382 L p .56923 .61482 L .758 .515 .565 r
F P
0 g
s
.57979 .6382 m .59001 .61346 L p .58503 .64734 L .514 .404 .667 r
F P
0 g
s
.57979 .6382 m .58503 .64734 L .58474 .6493 L .514 .404 .667 r
F
.59001 .61346 m .6323 .63268 L p .5848 .64928 L F P
0 g
s
.58474 .6493 m .58476 .6492 L .5848 .64928 L .514 .404 .667 r
F
.58476 .6492 m .59001 .61346 L .5848 .64928 L F
.60176 .67652 m .60488 .69574 L p .57979 .6382 L .756 .488 .528 r
F P
0 g
s
.50717 .63017 m .53173 .67696 L .47577 .70345 L p .718 .54 .647 r
F P
0 g
s
.50546 .75014 m .47577 .70345 L .53173 .67696 L p .701 .5 .614 r
F P
0 g
s
.57359 .6532 m .53795 .69235 L .50713 .64286 L p .606 .452 .647 r
F P
0 g
s
.50713 .64286 m .54007 .61605 L .57359 .6532 L p .606 .452 .647 r
F P
0 g
s
.55325 .63468 m .57979 .6382 L p .60488 .69574 L .756 .488 .528 r
F P
0 g
s
.56749 .61699 m .56748 .61699 L .56616 .61469 L .758 .515 .565 r
F
.56749 .61699 m .56616 .61469 L .56256 .60844 L F
.57979 .6382 m .55325 .63468 L p .56923 .61482 L F P
0 g
s
.56923 .61482 m .56256 .60844 L .56528 .60605 L .758 .515 .565 r
F
.56923 .61482 m .56528 .60605 L .58047 .59273 L F
.59001 .61346 m .57979 .6382 L p .56616 .61469 L .55 .443 .685 r
F P
0 g
s
.55461 .59459 m .58047 .59273 L p .56256 .60844 L .758 .515 .565 r
F P
0 g
s
.55802 .58956 m .59001 .61346 L p .56616 .61469 L .55 .443 .685 r
F P
0 g
s
.56615 .6147 m .56614 .61465 L .56616 .61469 L .55 .443 .685 r
F
.56614 .61465 m .55802 .58956 L .56616 .61469 L F
.54007 .61605 m .55461 .59459 L p .56494 .61476 L F P
0 g
s
.55461 .59459 m .55802 .58956 L p .56494 .61476 L .55 .443 .685 r
F P
0 g
s
.55461 .59459 m .54007 .61605 L p .55045 .5874 L .563 .46 .694 r
F P
0 g
s
.55325 .63468 m .54855 .59503 L p .56256 .60844 L .758 .515 .565 r
F P
0 g
s
.56494 .61476 m .56379 .61058 L .56615 .6147 L .55 .443 .685 r
F
.56379 .61058 m .55802 .58956 L .56615 .6147 L F
.56748 .61699 m .55325 .63468 L .56256 .60844 L .758 .515 .565 r
F
.54855 .59503 m .55461 .59459 L p .56256 .60844 L F P
0 g
s
.53979 .56563 m .55461 .59459 L .53671 .56358 L .761 .528 .58 r
F
.55461 .59459 m .5546 .59459 L p .55045 .5874 L F P
0 g
s
.55461 .59459 m .55045 .5874 L .53671 .56358 L .761 .528 .58 r
F
.54007 .61605 m .51734 .57794 L p .55045 .5874 L .563 .46 .694 r
F P
0 g
s
.55802 .58956 m .55461 .59459 L p .55045 .5874 L .563 .46 .694 r
F P
0 g
s
.53603 .5624 m .55883 .55399 L p .53671 .56358 L .761 .528 .58 r
F P
0 g
s
.53603 .5624 m .5366 .56193 L p .54992 .58725 L .563 .46 .694 r
F P
0 g
s
.53603 .5624 m .51734 .57794 L p .53517 .56091 L .566 .464 .697 r
F P
0 g
s
.54855 .59503 m .53533 .56266 L p .53671 .56358 L .761 .528 .58 r
F P
0 g
s
.5366 .56193 m .55802 .58956 L p .5504 .58739 L .563 .46 .694 r
F P
0 g
s
.54992 .58725 m .5456 .57904 L .5504 .58739 L .563 .46 .694 r
F
.5456 .57904 m .5366 .56193 L .5504 .58739 L F
.5546 .59459 m .54855 .59503 L p .53671 .56358 L .761 .528 .58 r
F P
0 g
s
.53533 .56266 m .53603 .5624 L p .53671 .56358 L .761 .528 .58 r
F P
0 g
s
.5366 .56193 m .53603 .5624 L p .53517 .56091 L .566 .464 .697 r
F P
0 g
s
.53533 .56266 m .51516 .53708 L p .52319 .54019 L .762 .531 .584 r
F P
0 g
s
.5232 .5402 m .52331 .54039 L .52319 .54019 L .762 .531 .584 r
F
.52331 .54039 m .53533 .56266 L .52319 .54019 L F
.53514 .56089 m .5232 .5402 L .53517 .56091 L .566 .464 .697 r
F
.53603 .5624 m .53533 .56266 L p .5232 .5402 L .762 .531 .584 r
F P
0 g
s
.53517 .56091 m .51939 .53358 L .53545 .56111 L .566 .464 .697 r
F
.5232 .5402 m .51939 .53358 L .53517 .56091 L F
.51516 .53708 m .51939 .53358 L p .5232 .5402 L .762 .531 .584 r
F P
0 g
s
.51939 .53358 m .51516 .53708 L p .51635 .52838 L .761 .53 .583 r
F P
0 g
s
.51939 .53358 m .51635 .52838 L .5173 .52151 L .761 .53 .583 r
F
.52454 .53167 m .5366 .56193 L p .53545 .56111 L .566 .464 .697 r
F P
0 g
s
.51939 .53358 m .52454 .53167 L p .53545 .56111 L .566 .464 .697 r
F P
0 g
s
.49995 .50008 m .5 .5 L .50002 .50016 L .638 .516 .698 r
F
.55404 .50043 m .50011 .5002 L .5 .5 L .732 .548 .644 r
F
.49989 .5002 m .5 .5 L p .50011 .5002 L F P
0 g
s
.55342 .50001 m .55404 .50043 L p .5 .5 L .732 .548 .644 r
F P
0 g
s
.5 .5 m .50023 .5 L .50028 .50049 L p .638 .516 .698 r
F P
0 g
s
.50028 .50049 m .5003 .50064 L p .5 .5 L .638 .516 .698 r
F P
0 g
s
.52454 .53167 m .51939 .53358 L p .50023 .5 L .565 .462 .696 r
F P
0 g
s
.50028 .50049 m .50023 .5 L p .51939 .53358 L .565 .462 .696 r
F P
0 g
s
.51516 .53708 m .48967 .5179 L p .51202 .52082 L .761 .53 .583 r
F P
0 g
s
.51636 .52834 m .51516 .53708 L .51202 .52082 L .761 .53 .583 r
F
.53172 .5234 m .52399 .52978 L p .5173 .52151 L F P
0 g
s
.48967 .5179 m .49989 .5002 L .50028 .50049 L p .761 .53 .583 r
F P
0 g
s
.50028 .50049 m .49989 .5002 L p .50011 .5002 L .732 .548 .644 r
F P
0 g
s
.50023 .5 m .5 .5 L p .50011 .4998 L .638 .526 .71 r
F P
0 g
s
.49989 .4998 m .50028 .49951 L p .5001 .49982 L .732 .647 .764 r
F P
0 g
s
.5 .5 m .49987 .5 L .49986 .49999 L .742 .562 .65 r
F
.46031 .50542 m .46122 .5 L p .49989 .5002 L .759 .528 .582 r
F P
0 g
s
.49944 .5 m .49989 .5002 L p .46122 .5 L .759 .528 .582 r
F P
0 g
s
.46031 .49458 m .48967 .4821 L p .47596 .5 L .759 .712 .808 r
F P
0 g
s
.46728 .5 m .46031 .49458 L .47596 .5 L .759 .712 .808 r
F
.46388 .51577 m .46221 .50589 L p .47272 .50423 L F P
0 g
s
.48967 .4821 m .49989 .4998 L .49944 .5 L p .759 .712 .808 r
F P
0 g
s
.49944 .5 m .49989 .4998 L p .49977 .5 L .742 .65 .758 r
F P
0 g
s
.49987 .5 m .49989 .5002 L .4998 .5 L .742 .562 .65 r
F
.49989 .4998 m .5 .49999 L p .49999 .5 L .742 .65 .758 r
F P
0 g
s
.49977 .5 m .49989 .4998 L .49999 .5 L .742 .65 .758 r
F
.49989 .5002 m .49944 .5 L p .4998 .5 L .742 .562 .65 r
F P
0 g
s
.5 .49999 m .5 .5 L p .49999 .5 L .742 .65 .758 r
F P
0 g
s
.48797 .52082 m .5044 .53917 L .47329 .54626 L .638 .516 .698 r
F
.47329 .54626 m .47336 .54701 L p .47305 .54668 L .683 .55 .697 r
F P
0 g
s
.47328 .54626 m .47329 .54626 L p .47327 .54629 L .727 .606 .722 r
F P
0 g
s
.47336 .54701 m .4728 .54711 L p .47305 .54668 L .683 .55 .697 r
F P
0 g
s
.5044 .53917 m .47336 .54701 L .47329 .54626 L p .638 .516 .698 r
F P
0 g
s
.4728 .45289 m .47305 .45332 L .47303 .45348 L .683 .566 .716 r
F
.4728 .45289 m .47303 .45348 L .47278 .45323 L F
.47329 .45374 m .47329 .45374 L p .47305 .45332 L F P
0 g
s
.47329 .45374 m .47261 .45342 L p .47305 .45332 L .727 .581 .691 r
F P
0 g
s
.46388 .48423 m .47261 .45342 L .47329 .45374 L p .742 .562 .65 r
F P
0 g
s
.4728 .45289 m .47336 .45299 L .47329 .45374 L p .683 .566 .716 r
F P
0 g
s
.47261 .45342 m .4728 .45289 L p .47305 .45332 L .727 .581 .691 r
F P
0 g
s
.53173 .32304 m .50717 .36983 L .45138 .34669 L p .718 .633 .762 r
F P
0 g
s
.63739 .61597 m .60915 .5713 L .65708 .53455 L p .648 .516 .688 r
F P
0 g
s
.33088 .561 m .38368 .55887 L .39154 .61876 L p .747 .577 .664 r
F P
0 g
s
.53172 .5234 m .55404 .50043 L .58895 .53488 L p .722 .533 .634 r
F P
0 g
s
.62284 .50495 m .58895 .53488 L .55404 .50043 L p .694 .535 .668 r
F P
0 g
s
.42383 .47604 m .42531 .44041 L .47261 .45342 L p .754 .574 .653 r
F P
0 g
s
.47261 .45342 m .46388 .48423 L .42383 .47604 L p .754 .574 .653 r
F P
0 g
s
.51734 .57794 m .48573 .59448 L .47336 .54701 L p .634 .503 .685 r
F P
0 g
s
.47336 .54701 m .5044 .53917 L .51734 .57794 L p .634 .503 .685 r
F P
0 g
s
.5044 .46083 m .47336 .45299 L .48573 .40552 L p .634 .533 .722 r
F P
0 g
s
.44286 .39114 m .48573 .40552 L .47336 .45299 L p .679 .579 .735 r
F P
0 g
s
.55883 .44601 m .58895 .46512 L .55404 .49957 L p .722 .646 .773 r
F P
0 g
s
.55404 .49957 m .53172 .4766 L .55883 .44601 L p .722 .646 .773 r
F P
0 g
s
.46388 .51577 m .47261 .54658 L .42531 .55959 L p .754 .657 .754 r
F P
0 g
s
.43429 .60391 m .42531 .55959 L .47261 .54658 L p .745 .615 .715 r
F P
0 g
s
.37272 .43475 m .37632 .38319 L .43429 .39609 L p .767 .623 .701 r
F P
0 g
s
.43429 .39609 m .42531 .44041 L .37272 .43475 L p .767 .623 .701 r
F P
0 g
s
.65708 .53455 m .6883 .58074 L .63739 .61597 L p .648 .516 .688 r
F P
0 g
s
.58895 .53488 m .62284 .50495 L .663 .5487 L p .677 .507 .648 r
F P
0 g
s
.70393 .50751 m .663 .5487 L .62284 .50495 L p .647 .505 .675 r
F P
0 g
s
.45138 .34669 m .47577 .29655 L .53173 .32304 L p .718 .633 .762 r
F P
0 g
s
.48573 .40552 m .44286 .39114 L .46068 .33449 L p .67 .589 .756 r
F P
0 g
s
.40453 .31963 m .46068 .33449 L .44286 .39114 L p .708 .63 .768 r
F P
0 g
s
.62015 .42239 m .663 .4513 L .62284 .49505 L p .676 .598 .76 r
F P
0 g
s
.62284 .49505 m .58895 .46512 L .62015 .42239 L p .676 .598 .76 r
F P
0 g
s
.50713 .64286 m .46068 .66551 L .44286 .60886 L p .67 .504 .652 r
F P
0 g
s
.44286 .60886 m .48573 .59448 L .50713 .64286 L p .67 .504 .652 r
F P
0 g
s
.39154 .61876 m .33592 .6227 L .33088 .561 L p .747 .577 .664 r
F P
0 g
s
.42531 .55959 m .43429 .60391 L .37632 .61681 L p .767 .629 .708 r
F P
0 g
s
.39153 .67286 m .37632 .61681 L .43429 .60391 L p .758 .59 .669 r
F P
0 g
s
.49989 .5002 m .48967 .5179 L .46031 .50542 L p .759 .528 .582 r
F P
0 g
s
.50023 .5 m .52067 .5 L .52454 .53167 L p .565 .462 .696 r
F P
0 g
s
.49989 .4998 m .48967 .4821 L .51516 .46292 L p .761 .713 .807 r
F P
0 g
s
.58895 .53488 m .55883 .55399 L .53172 .5234 L p .722 .533 .634 r
F P
0 g
s
.55883 .55399 m .58895 .53488 L .62015 .57761 L p .712 .513 .619 r
F P
0 g
s
.663 .5487 m .62015 .57761 L .58895 .53488 L p .677 .507 .648 r
F P
0 g
s
.37946 .47668 m .37272 .43475 L .42531 .44041 L p .77 .587 .652 r
F P
0 g
s
.42531 .44041 m .42383 .47604 L .37946 .47668 L p .77 .587 .652 r
F P
0 g
s
.54007 .61605 m .50713 .64286 L .48573 .59448 L p .625 .483 .669 r
F P
0 g
s
.48573 .59448 m .51734 .57794 L .54007 .61605 L p .625 .483 .669 r
F P
0 g
s
.42531 .55959 m .42383 .52396 L .46388 .51577 L p .754 .657 .754 r
F P
0 g
s
.42383 .52396 m .42531 .55959 L .37272 .56525 L p .769 .669 .752 r
F P
0 g
s
.37632 .61681 m .37272 .56525 L .42531 .55959 L p .767 .629 .708 r
F P
0 g
s
.58047 .40727 m .62015 .42239 L .58895 .46512 L p .712 .649 .786 r
F P
0 g
s
.58895 .46512 m .55883 .44601 L .58047 .40727 L p .712 .649 .786 r
F P
0 g
s
.48573 .40552 m .51734 .42206 L .5044 .46083 L p .634 .533 .722 r
F P
0 g
s
.51734 .42206 m .48573 .40552 L .50713 .35714 L p .625 .537 .735 r
F P
0 g
s
.46068 .33449 m .50713 .35714 L .48573 .40552 L p .67 .589 .756 r
F P
0 g
s
.62015 .57761 m .58047 .59273 L .55883 .55399 L p .712 .513 .619 r
F P
0 g
s
.50713 .35714 m .54007 .38395 L .51734 .42206 L p .625 .537 .735 r
F P
0 g
s
.37272 .56525 m .37946 .52332 L .42383 .52396 L p .769 .669 .752 r
F P
0 g
s
.46071 .51662 m .46031 .50542 L .48967 .5179 L p .772 .434 .415 r
F P
0 g
s
.48967 .5179 m .48462 .52665 L .46071 .51662 L p .772 .434 .415 r
F P
0 g
s
.48462 .52665 m .48967 .5179 L .51516 .53708 L p .804 .476 .434 r
F P
0 g
s
.53404 .52572 m .52454 .53167 L .52067 .5 L p .388 .332 .673 r
F P
0 g
s
.52067 .5 m .53077 .5 L .53404 .52572 L p .388 .332 .673 r
F P
0 g
s
.53077 .5 m .52067 .5 L .52454 .46833 L p .389 .302 .636 r
F P
0 g
s
.50526 .45766 m .51516 .46292 L .48967 .4821 L p .804 .837 .876 r
F P
0 g
s
.48967 .4821 m .48462 .47335 L .50526 .45766 L p .804 .837 .876 r
F P
0 g
s
.48462 .47335 m .48967 .4821 L .46031 .49458 L p .772 .826 .895 r
F P
0 g
s
.47577 .29655 m .50546 .24986 L .55895 .27774 L p .7 .644 .79 r
F P
0 g
s
.6883 .41926 m .7139 .3702 L .76403 .40374 L p .594 .509 .728 r
F P
0 g
s
.6883 .58074 m .7139 .6298 L .66301 .66219 L p .626 .474 .657 r
F P
0 g
s
.47577 .70345 m .50546 .75014 L .45135 .77679 L p .725 .506 .594 r
F P
0 g
s
.33592 .3773 m .28064 .37966 L .28462 .31948 L p .777 .696 .774 r
F P
0 g
s
.33592 .6227 m .28064 .62034 L .27804 .56008 L p .778 .6 .658 r
F P
0 g
s
.31444 .43669 m .31313 .37545 L .37632 .38319 L p .794 .647 .699 r
F P
0 g
s
.37632 .38319 m .37272 .43475 L .31444 .43669 L p .794 .647 .699 r
F P
0 g
s
.62015 .57761 m .663 .5487 L .7013 .59956 L p .656 .469 .619 r
F P
0 g
s
.39153 .32714 m .37632 .38319 L .31313 .37545 L p .788 .679 .744 r
F P
0 g
s
.663 .5487 m .70393 .50751 L .74983 .55419 L p .619 .461 .646 r
F P
0 g
s
.74983 .55419 m .7013 .59956 L .663 .5487 L p .619 .461 .646 r
F P
0 g
s
.53795 .69235 m .48557 .72411 L .46068 .66551 L p .653 .468 .621 r
F P
0 g
s
.46068 .66551 m .50713 .64286 L .53795 .69235 L p .653 .468 .621 r
F P
0 g
s
.40453 .68037 m .46068 .66551 L .48557 .72411 L p .695 .487 .603 r
F P
0 g
s
.37272 .56525 m .37632 .61681 L .31313 .62455 L p .794 .65 .703 r
F P
0 g
s
.37632 .61681 m .39153 .67286 L .32816 .68927 L p .788 .608 .657 r
F P
0 g
s
.32816 .68927 m .31313 .62455 L .37632 .61681 L p .788 .608 .657 r
F P
0 g
s
.6476 .37096 m .7013 .40044 L .663 .4513 L p .656 .602 .783 r
F P
0 g
s
.663 .4513 m .62015 .42239 L .6476 .37096 L p .656 .602 .783 r
F P
0 g
s
.70393 .49249 m .663 .4513 L .7013 .40044 L p .619 .549 .754 r
F P
0 g
s
.50713 .35714 m .46068 .33449 L .48557 .27589 L p .652 .598 .781 r
F P
0 g
s
.46068 .33449 m .40453 .31963 L .42201 .25655 L p .694 .647 .798 r
F P
0 g
s
.42201 .25655 m .48557 .27589 L .46068 .33449 L p .694 .647 .798 r
F P
0 g
s
.43553 .5138 m .42807 .50074 L .46031 .50542 L p .739 .407 .42 r
F P
0 g
s
.46031 .50542 m .46071 .51662 L .43553 .5138 L p .739 .407 .42 r
F P
0 g
s
.51516 .53708 m .50526 .54234 L .48462 .52665 L p .804 .476 .434 r
F P
0 g
s
.50526 .54234 m .51516 .53708 L .53533 .56266 L p .829 .523 .472 r
F P
0 g
s
.52454 .46833 m .53404 .47428 L .53077 .5 L p .389 .302 .636 r
F P
0 g
s
.53404 .47428 m .52454 .46833 L .5366 .43807 L p .412 .295 .609 r
F P
0 g
s
.54419 .54893 m .5366 .56193 L .52454 .53167 L p .412 .379 .712 r
F P
0 g
s
.52454 .53167 m .53404 .52572 L .54419 .54893 L p .412 .379 .712 r
F P
0 g
s
.46031 .49458 m .46071 .48338 L .48462 .47335 L p .772 .826 .895 r
F P
0 g
s
.46071 .48338 m .46031 .49458 L .42807 .49926 L p .739 .8 .901 r
F P
0 g
s
.52028 .43727 m .53533 .43734 L .51516 .46292 L p .829 .831 .849 r
F P
0 g
s
.51516 .46292 m .50526 .45766 L .52028 .43727 L p .829 .831 .849 r
F P
0 g
s
.58047 .59273 m .62015 .57761 L .6476 .62904 L p .7 .485 .592 r
F P
0 g
s
.7013 .59956 m .6476 .62904 L .62015 .57761 L p .656 .469 .619 r
F P
0 g
s
.54007 .38395 m .50713 .35714 L .53795 .30765 L p .606 .537 .751 r
F P
0 g
s
.48557 .27589 m .53795 .30765 L .50713 .35714 L p .652 .598 .781 r
F P
0 g
s
.37946 .52332 m .37272 .56525 L .31444 .56331 L p .791 .69 .754 r
F P
0 g
s
.31313 .62455 m .31444 .56331 L .37272 .56525 L p .794 .65 .703 r
F P
0 g
s
.31313 .37545 m .32816 .31073 L .39153 .32714 L p .788 .679 .744 r
F P
0 g
s
.48557 .72411 m .42201 .74345 L .40453 .68037 L p .695 .487 .603 r
F P
0 g
s
.7013 .40044 m .74983 .44581 L .70393 .49249 L p .619 .549 .754 r
F P
0 g
s
.41039 .51991 m .39343 .50547 L .42807 .50074 L p .717 .401 .443 r
F P
0 g
s
.42807 .50074 m .43553 .5138 L .41039 .51991 L p .717 .401 .443 r
F P
0 g
s
.53533 .56266 m .52028 .56273 L .50526 .54234 L p .829 .523 .472 r
F P
0 g
s
.52028 .56273 m .53533 .56266 L .54855 .59503 L p .84 .56 .514 r
F P
0 g
s
.56205 .56765 m .55802 .58956 L .5366 .56193 L p .449 .425 .739 r
F P
0 g
s
.5366 .56193 m .54419 .54893 L .56205 .56765 L p .449 .425 .739 r
F P
0 g
s
.5366 .43807 m .54419 .45107 L .53404 .47428 L p .412 .295 .609 r
F P
0 g
s
.54419 .45107 m .5366 .43807 L .55802 .41044 L p .449 .308 .597 r
F P
0 g
s
.42807 .49926 m .43553 .4862 L .46071 .48338 L p .739 .8 .901 r
F P
0 g
s
.43553 .4862 m .42807 .49926 L .39343 .49453 L p .716 .769 .894 r
F P
0 g
s
.52756 .41244 m .54855 .40497 L .53533 .43734 L p .84 .811 .823 r
F P
0 g
s
.53533 .43734 m .52028 .43727 L .52756 .41244 L p .84 .811 .823 r
F P
0 g
s
.46353 .51833 m .46071 .51662 L .48462 .52665 L p .363 0 0 r
F P
0 g
s
.48462 .52665 m .48437 .52708 L .46353 .51833 L p .363 0 0 r
F P
0 g
s
.48437 .52708 m .48462 .52665 L .50526 .54234 L p .515 0 0 r
F P
0 g
s
.53411 .52242 m .53404 .52572 L .53077 .5 L p 0 0 .177 r
F P
0 g
s
.53077 .5 m .53126 .5 L .53411 .52242 L p 0 0 .177 r
F P
0 g
s
.53126 .5 m .53077 .5 L .53404 .47428 L p 0 0 .006 r
F P
0 g
s
.50236 .45925 m .50526 .45766 L .48462 .47335 L p .513 .876 .649 r
F P
0 g
s
.48462 .47335 m .48437 .47292 L .50236 .45925 L p .513 .876 .649 r
F P
0 g
s
.48437 .47292 m .48462 .47335 L .46071 .48338 L p .365 .826 .738 r
F P
0 g
s
.44348 .51615 m .43553 .5138 L .45455 .51593 L p .331 0 0 r
F P
0 g
s
.43553 .5138 m .44348 .51615 L .42599 .52129 L p .428 0 0 r
F P
0 g
s
.43684 .50001 m .43503 .50609 L p .43667 .51303 L .932 .913 .528 r
F P
0 g
s
.43667 .51303 m .43234 .51638 L p .43744 .51627 L .742 .959 .941 r
F P
0 g
s
.43234 .51638 m .42599 .52129 L .44348 .51615 L p .742 .959 .941 r
F P
0 g
s
.42599 .52129 m .41039 .51991 L .43553 .5138 L p .428 0 0 r
F P
0 g
s
.42599 .52129 m .43667 .51303 L .43073 .52052 L p 0 0 0 r
F P
0 g
s
.43503 .50609 m .43073 .52052 L .43667 .51303 L p .932 .913 .528 r
F P
0 g
s
.44348 .51615 m .43667 .51303 L .43744 .51627 L .742 .959 .941 r
F
.45455 .51593 m .46071 .51662 L p .44348 .51615 L .331 0 0 r
F P
0 g
s
.46071 .51662 m .46353 .51833 L .44348 .51615 L p .331 0 0 r
F P
0 g
s
.50236 .54075 m .50526 .54234 L .52028 .56273 L p .764 .29 0 r
F P
0 g
s
.51427 .55702 m .50236 .54075 L p .51146 .55192 L .764 .29 0 r
F P
0 g
s
.52028 .56273 m .51427 .55702 L p .51146 .55192 L .764 .29 0 r
F P
0 g
s
.51427 .55702 m .52028 .56273 L .52756 .58756 L p .953 .603 .264 r
F P
0 g
s
.51857 .57474 m .51427 .55702 L p .52033 .57094 L .953 .603 .264 r
F P
0 g
s
.52756 .58756 m .51857 .57474 L p .52033 .57094 L .953 .603 .264 r
F P
0 g
s
.51857 .57474 m .51329 .59282 L p .51623 .57978 L .868 .809 .325 r
F P
0 g
s
.51427 .55702 m .51857 .57474 L p .5176 .56307 L .017 .025 .522 r
F P
0 g
s
.52038 .56136 m .51642 .54894 L p .51753 .56221 L .017 .025 .522 r
F P
0 g
s
.51857 .57474 m .52038 .56136 L p .51753 .56221 L .017 .025 .522 r
F P
0 g
s
.52038 .56136 m .51857 .57474 L p .51623 .57978 L .868 .809 .325 r
F P
0 g
s
.54855 .59503 m .52756 .58756 L .52028 .56273 L p .84 .56 .514 r
F P
0 g
s
.51687 .57025 m .52038 .56136 L p .51762 .57361 L .868 .809 .325 r
F P
0 g
s
.51329 .59282 m .51687 .57025 L p .51762 .57361 L .868 .809 .325 r
F P
0 g
s
.51687 .57025 m .50446 .5738 L p .51586 .56577 L .804 .999 .798 r
F P
0 g
s
.52038 .56136 m .51687 .57025 L p .52374 .56035 L 0 0 0 r
F P
0 g
s
.52981 .55163 m .52038 .56136 L p .52374 .56035 L 0 0 0 r
F P
0 g
s
.51687 .57025 m .53158 .5547 L .52981 .55163 L p 0 0 0 r
F P
0 g
s
.53158 .5547 m .51687 .57025 L p .51586 .56577 L .804 .999 .798 r
F P
0 g
s
.51642 .54894 m .51427 .55702 L p .5176 .56307 L .017 .025 .522 r
F P
0 g
s
.50236 .54075 m .51427 .55702 L p .5109 .54756 L .395 .419 .767 r
F P
0 g
s
.50526 .54234 m .50236 .54075 L p .49438 .53439 L .515 0 0 r
F P
0 g
s
.50629 .53459 m .50236 .54075 L p .5109 .54756 L .395 .419 .767 r
F P
0 g
s
.50236 .54075 m .48437 .52708 L p .49438 .53439 L .515 0 0 r
F P
0 g
s
.54225 .54087 m .54419 .54893 L .53652 .5314 L p 0 0 .488 r
F P
0 g
s
.54419 .54893 m .54225 .54087 L .55544 .55345 L p .057 .294 .783 r
F P
0 g
s
.53159 .5547 m .53777 .55322 L p .54295 .54833 L .208 0 0 r
F P
0 g
s
.54295 .54833 m .54801 .5504 L p .54537 .54604 L .766 .284 .09 r
F P
0 g
s
.54801 .5504 m .55544 .55345 L .54225 .54087 L p .766 .284 .09 r
F P
0 g
s
.55544 .55345 m .56205 .56765 L .54419 .54893 L p .057 .294 .783 r
F P
0 g
s
.55544 .55345 m .54295 .54833 L .5524 .54973 L p 0 .501 .841 r
F P
0 g
s
.53777 .55322 m .5524 .54973 L .54295 .54833 L p .208 0 0 r
F P
0 g
s
.54225 .54087 m .54295 .54833 L .54537 .54604 L .766 .284 .09 r
F
.53652 .5314 m .53404 .52572 L p .54225 .54087 L 0 0 .488 r
F P
0 g
s
.53404 .52572 m .53411 .52242 L .54225 .54087 L p 0 0 .488 r
F P
0 g
s
.46353 .48167 m .46071 .48338 L .43553 .4862 L p .332 .809 .899 r
F P
0 g
s
.44348 .48385 m .46353 .48167 L p .4493 .48397 L .332 .809 .899 r
F P
0 g
s
.43553 .4862 m .44348 .48385 L p .4493 .48397 L .332 .809 .899 r
F P
0 g
s
.44348 .48385 m .43553 .4862 L .41039 .48009 L p .426 .771 .997 r
F P
0 g
s
.42599 .47871 m .44348 .48385 L p .4284 .48213 L .426 .771 .997 r
F P
0 g
s
.41039 .48009 m .42599 .47871 L p .4284 .48213 L .426 .771 .997 r
F P
0 g
s
.42599 .47871 m .41297 .4651 L p .42279 .47417 L 0 .227 .717 r
F P
0 g
s
.44348 .48385 m .42599 .47871 L p .43658 .4837 L .742 .253 .076 r
F P
0 g
s
.43667 .48697 m .44941 .48975 L p .43736 .48407 L .742 .253 .076 r
F P
0 g
s
.42599 .47871 m .43667 .48697 L p .43736 .48407 L .742 .253 .076 r
F P
0 g
s
.43667 .48697 m .42599 .47871 L p .42279 .47417 L 0 .227 .717 r
F P
0 g
s
.39343 .49453 m .41039 .48009 L .43553 .4862 L p .716 .769 .894 r
F P
0 g
s
.43073 .47948 m .43667 .48697 L p .42744 .47845 L 0 .227 .717 r
F P
0 g
s
.41297 .4651 m .43073 .47948 L p .42744 .47845 L 0 .227 .717 r
F P
0 g
s
.43073 .47948 m .43386 .46697 L p .43511 .48085 L 0 0 .537 r
F P
0 g
s
.43667 .48697 m .43073 .47948 L p .43586 .49039 L .932 .608 .154 r
F P
0 g
s
.44038 .5 m .43667 .48697 L p .43586 .49039 L .932 .608 .154 r
F P
0 g
s
.43073 .47948 m .43684 .49999 L .44038 .5 L p .932 .608 .154 r
F P
0 g
s
.43684 .49999 m .43073 .47948 L p .43511 .48085 L 0 0 .537 r
F P
0 g
s
.44941 .48975 m .44348 .48385 L p .43658 .4837 L .742 .253 .076 r
F P
0 g
s
.46353 .48167 m .44348 .48385 L p .45336 .48566 L .675 .324 .371 r
F P
0 g
s
.46071 .48338 m .46353 .48167 L p .47302 .47794 L .365 .826 .738 r
F P
0 g
s
.46689 .48815 m .46353 .48167 L p .45336 .48566 L .675 .324 .371 r
F P
0 g
s
.46353 .48167 m .48437 .47292 L p .47302 .47794 L .365 .826 .738 r
F P
0 g
s
.53411 .47758 m .53404 .47428 L .54419 .45107 L p 0 0 0 r
F P
0 g
s
.54225 .45913 m .53411 .47758 L p .53923 .46411 L 0 0 0 r
F P
0 g
s
.54419 .45107 m .54225 .45913 L p .53923 .46411 L 0 0 0 r
F P
0 g
s
.54225 .45913 m .54419 .45107 L .56205 .43235 L p .056 0 .174 r
F P
0 g
s
.55544 .44655 m .54225 .45913 L p .55127 .44693 L .056 0 .174 r
F P
0 g
s
.56205 .43235 m .55544 .44655 L p .55127 .44693 L .056 0 .174 r
F P
0 g
s
.55544 .44655 m .57374 .44208 L p .56097 .44605 L 0 0 0 r
F P
0 g
s
.54225 .45913 m .55544 .44655 L p .54582 .45322 L .766 .967 .927 r
F P
0 g
s
.54295 .45167 m .53417 .46131 L p .54511 .45372 L .766 .967 .927 r
F P
0 g
s
.55544 .44655 m .54295 .45167 L p .54511 .45372 L .766 .967 .927 r
F P
0 g
s
.54295 .45167 m .55544 .44655 L p .56097 .44605 L 0 0 0 r
F P
0 g
s
.55802 .41044 m .56205 .43235 L .54419 .45107 L p .449 .308 .597 r
F P
0 g
s
.5524 .45027 m .54295 .45167 L p .55494 .44794 L 0 0 0 r
F P
0 g
s
.57374 .44208 m .5524 .45027 L p .55494 .44794 L 0 0 0 r
F P
0 g
s
.5524 .45027 m .56168 .45924 L p .54903 .45338 L .53 0 0 r
F P
0 g
s
.54295 .45167 m .5524 .45027 L p .5404 .44926 L .208 .664 .946 r
F P
0 g
s
.52981 .44837 m .54295 .45167 L p .5404 .44926 L .208 .664 .946 r
F P
0 g
s
.5524 .45027 m .53159 .4453 L .52981 .44837 L p .208 .664 .946 r
F P
0 g
s
.53159 .4453 m .5524 .45027 L p .54903 .45338 L .53 0 0 r
F P
0 g
s
.53417 .46131 m .54225 .45913 L p .54582 .45322 L .766 .967 .927 r
F P
0 g
s
.53411 .47758 m .54225 .45913 L p .53574 .46677 L .878 .849 .811 r
F P
0 g
s
.53404 .47428 m .53411 .47758 L p .53259 .48767 L 0 0 .006 r
F P
0 g
s
.52681 .47725 m .53411 .47758 L p .53574 .46677 L .878 .849 .811 r
F P
0 g
s
.53411 .47758 m .53126 .5 L p .53259 .48767 L 0 0 .006 r
F P
0 g
s
.51427 .44298 m .52028 .43727 L .50893 .45268 L p .763 .958 .648 r
F P
0 g
s
.52028 .43727 m .51427 .44298 L .51857 .42526 L p .953 .953 .693 r
F P
0 g
s
.53158 .4453 m .52721 .44068 L p .52038 .43864 L 0 .246 .759 r
F P
0 g
s
.52038 .43864 m .51964 .43322 L p .51719 .43769 L .017 .003 .495 r
F P
0 g
s
.51964 .43322 m .51857 .42526 L .51427 .44298 L p .017 .003 .495 r
F P
0 g
s
.51857 .42526 m .52756 .41244 L .52028 .43727 L p .953 .953 .693 r
F P
0 g
s
.51857 .42526 m .52038 .43864 L .51687 .42975 L p .869 .61 .081 r
F P
0 g
s
.52721 .44068 m .51687 .42975 L .52038 .43864 L p 0 .246 .759 r
F P
0 g
s
.51427 .44298 m .52038 .43864 L .51719 .43769 L .017 .003 .495 r
F
.50893 .45268 m .50526 .45766 L p .51427 .44298 L .763 .958 .648 r
F P
0 g
s
.50526 .45766 m .50236 .45925 L .51427 .44298 L p .763 .958 .648 r
F P
0 g
s
.48958 .81677 m .45135 .77679 L .50546 .75014 L p .701 .458 .552 r
F P
0 g
s
.77954 .35064 m .76403 .40374 L .7139 .3702 L p .567 .514 .756 r
F P
0 g
s
.53772 .20977 m .50546 .24986 L .45135 .22321 L p .701 .687 .834 r
F P
0 g
s
.73249 .67778 m .7139 .6298 L .76403 .59626 L p .567 .411 .63 r
F P
0 g
s
.22979 .61245 m .28064 .62034 L .28462 .68052 L p .811 .599 .615 r
F P
0 g
s
.23088 .33259 m .28462 .31948 L .28064 .37966 L p .811 .725 .77 r
F P
0 g
s
.38649 .53667 m .35674 .52122 L .39343 .50547 L p .709 .405 .461 r
F P
0 g
s
.39343 .50547 m .41039 .51991 L .38649 .53667 L p .709 .405 .461 r
F P
0 g
s
.52756 .58756 m .54855 .59503 L .55325 .63468 L p .841 .575 .537 r
F P
0 g
s
.58851 .57997 m .59001 .61346 L .55802 .58956 L p .472 .447 .749 r
F P
0 g
s
.55802 .58956 m .56205 .56765 L .58851 .57997 L p .472 .447 .749 r
F P
0 g
s
.41039 .48009 m .39343 .49453 L .35674 .47878 L p .708 .752 .887 r
F P
0 g
s
.56205 .43235 m .55802 .41044 L .59001 .38654 L p .471 .322 .597 r
F P
0 g
s
.525 .38336 m .55325 .36532 L .54855 .40497 L p .84 .797 .81 r
F P
0 g
s
.54855 .40497 m .52756 .41244 L .525 .38336 L p .84 .797 .81 r
F P
0 g
s
.46689 .51185 m .46353 .51833 L .48437 .52708 L p .582 .662 .892 r
F P
0 g
s
.48437 .52708 m .48858 .51978 L .46689 .51185 L p .582 .662 .892 r
F P
0 g
s
.48858 .51978 m .48437 .52708 L .50236 .54075 L p .507 .566 .85 r
F P
0 g
s
.52681 .52275 m .53411 .52242 L .53126 .5 L p .903 .702 .621 r
F P
0 g
s
.53126 .5 m .52284 .5 L .52681 .52275 L p .903 .702 .621 r
F P
0 g
s
.52284 .5 m .53126 .5 L .53411 .47758 L p .903 .773 .707 r
F P
0 g
s
.50629 .46541 m .50236 .45925 L .48437 .47292 L p .508 .264 .479 r
F P
0 g
s
.48437 .47292 m .48858 .48022 L .50629 .46541 L p .508 .264 .479 r
F P
0 g
s
.48858 .48022 m .48437 .47292 L .46353 .48167 L p .582 .288 .435 r
F P
0 g
s
.44941 .51025 m .44348 .51615 L .46353 .51833 L p .675 .779 .928 r
F P
0 g
s
.46353 .51833 m .46689 .51185 L .44941 .51025 L p .675 .779 .928 r
F P
0 g
s
.50236 .54075 m .50629 .53459 L .48858 .51978 L p .507 .566 .85 r
F P
0 g
s
.53417 .53869 m .54225 .54087 L .53411 .52242 L p .878 .585 .488 r
F P
0 g
s
.53411 .52242 m .52681 .52275 L .53417 .53869 L p .878 .585 .488 r
F P
0 g
s
.46353 .48167 m .46689 .48815 L .48858 .48022 L p .582 .288 .435 r
F P
0 g
s
.53411 .47758 m .52681 .47725 L .52284 .5 L p .903 .773 .707 r
F P
0 g
s
.51642 .45106 m .51427 .44298 L .50236 .45925 L p .395 .227 .532 r
F P
0 g
s
.50236 .45925 m .50629 .46541 L .51642 .45106 L p .395 .227 .532 r
F P
0 g
s
.25206 .44543 m .24706 .37201 L .31313 .37545 L p .832 .677 .69 r
F P
0 g
s
.31313 .37545 m .31444 .43669 L .25206 .44543 L p .832 .677 .69 r
F P
0 g
s
.32816 .31073 m .31313 .37545 L .24706 .37201 L p .827 .719 .746 r
F P
0 g
s
.57671 .74201 m .51562 .78305 L .48557 .72411 L p .621 .411 .575 r
F P
0 g
s
.48557 .72411 m .53795 .69235 L .57671 .74201 L p .621 .411 .575 r
F P
0 g
s
.42201 .74345 m .48557 .72411 L .51562 .78305 L p .672 .431 .548 r
F P
0 g
s
.6476 .62904 m .7013 .59956 L .73732 .65505 L p .627 .413 .572 r
F P
0 g
s
.77954 .64936 m .76403 .59626 L .81262 .56278 L p .521 .384 .635 r
F P
0 g
s
.76403 .59626 m .77954 .64936 L .73249 .67778 L p .567 .411 .63 r
F P
0 g
s
.7013 .59956 m .74983 .55419 L .79373 .60269 L p .578 .399 .602 r
F P
0 g
s
.79373 .60269 m .73732 .65505 L .7013 .59956 L p .578 .399 .602 r
F P
0 g
s
.67123 .31256 m .73732 .34495 L .7013 .40044 L p .627 .611 .815 r
F P
0 g
s
.7013 .40044 m .6476 .37096 L .67123 .31256 L p .627 .611 .815 r
F P
0 g
s
.31444 .56331 m .31313 .62455 L .24706 .62799 L p .832 .682 .697 r
F P
0 g
s
.74983 .44581 m .7013 .40044 L .73732 .34495 L p .578 .545 .782 r
F P
0 g
s
.23088 .66741 m .28462 .68052 L .28932 .73935 L p .812 .567 .568 r
F P
0 g
s
.28462 .68052 m .23088 .66741 L .22979 .61245 L p .811 .599 .615 r
F P
0 g
s
.31313 .62455 m .32816 .68927 L .26421 .70303 L p .827 .631 .638 r
F P
0 g
s
.26421 .70303 m .24706 .62799 L .31313 .62455 L p .827 .631 .638 r
F P
0 g
s
.53795 .30765 m .48557 .27589 L .51562 .21695 L p .621 .604 .811 r
F P
0 g
s
.48958 .18323 m .45135 .22321 L .39806 .19788 L p .724 .729 .854 r
F P
0 g
s
.45135 .22321 m .48958 .18323 L .53772 .20977 L p .701 .687 .834 r
F P
0 g
s
.48557 .27589 m .42201 .25655 L .44207 .19428 L p .671 .666 .836 r
F P
0 g
s
.44207 .19428 m .51562 .21695 L .48557 .27589 L p .671 .666 .836 r
F P
0 g
s
.73732 .65505 m .67123 .68744 L .6476 .62904 L p .627 .413 .572 r
F P
0 g
s
.24706 .62799 m .25206 .55457 L .31444 .56331 L p .832 .682 .697 r
F P
0 g
s
.51562 .21695 m .57671 .25799 L .53795 .30765 L p .621 .604 .811 r
F P
0 g
s
.51427 .55702 m .51642 .54894 L .50629 .53459 L p .395 .419 .767 r
F P
0 g
s
.44348 .51615 m .44941 .51025 L .43667 .51303 L p .742 .959 .941 r
F P
0 g
s
.54225 .54087 m .53417 .53869 L .54295 .54833 L p .766 .284 .09 r
F P
0 g
s
.44348 .48385 m .44941 .48975 L .46689 .48815 L p .675 .324 .371 r
F P
0 g
s
.54225 .45913 m .53417 .46131 L .52681 .47725 L p .878 .849 .811 r
F P
0 g
s
.51427 .44298 m .51642 .45106 L .52038 .43864 L p .017 .003 .495 r
F P
0 g
s
.51857 .57474 m .52756 .58756 L .525 .61664 L p .961 .7 .495 r
F P
0 g
s
.55325 .63468 m .525 .61664 L .52756 .58756 L p .841 .575 .537 r
F P
0 g
s
.41297 .5349 m .38649 .53667 L .41039 .51991 L p .509 .118 .235 r
F P
0 g
s
.41039 .51991 m .42599 .52129 L .41297 .5349 L p .509 .118 .235 r
F P
0 g
s
.57374 .55792 m .58851 .57997 L .56205 .56765 L p .329 .481 .859 r
F P
0 g
s
.56205 .56765 m .55544 .55345 L .57374 .55792 L p .329 .481 .859 r
F P
0 g
s
.42599 .47871 m .41039 .48009 L .38649 .46333 L p .507 .712 .964 r
F P
0 g
s
.35674 .47878 m .38649 .46333 L .41039 .48009 L p .708 .752 .887 r
F P
0 g
s
.55544 .44655 m .56205 .43235 L .58851 .42003 L p .328 .054 .337 r
F P
0 g
s
.59001 .38654 m .58851 .42003 L .56205 .43235 L p .471 .322 .597 r
F P
0 g
s
.51329 .40718 m .525 .38336 L .52756 .41244 L p .96 .869 .703 r
F P
0 g
s
.52756 .41244 m .51857 .42526 L .51329 .40718 L p .96 .869 .703 r
F P
0 g
s
.46848 .5 m .46689 .51185 L .48858 .51978 L p .692 .606 .755 r
F P
0 g
s
.48858 .51978 m .49995 .50009 L .46848 .5 L p .692 .606 .755 r
F P
0 g
s
.49995 .50009 m .48858 .51978 L .50629 .53459 L p .661 .572 .744 r
F P
0 g
s
.51576 .4727 m .50629 .46541 L .48858 .48022 L p .668 .516 .669 r
F P
0 g
s
.48858 .48022 m .49995 .49991 L .51576 .4727 L p .668 .516 .669 r
F P
0 g
s
.49995 .49991 m .48858 .48022 L .46689 .48815 L p .692 .518 .647 r
F P
0 g
s
.51576 .5273 m .52681 .52275 L .52284 .5 L p .755 .605 .691 r
F P
0 g
s
.52284 .5 m .50011 .5 L .51576 .5273 L p .755 .605 .691 r
F P
0 g
s
.50011 .5 m .52284 .5 L .52681 .47725 L p .761 .636 .722 r
F P
0 g
s
.50629 .53459 m .51576 .5273 L .49995 .50009 L p .661 .572 .744 r
F P
0 g
s
.51576 .5273 m .50629 .53459 L .51642 .54894 L p .621 .499 .692 r
F P
0 g
s
.45155 .5 m .44941 .51025 L .46689 .51185 L p .752 .667 .768 r
F P
0 g
s
.46689 .51185 m .46848 .5 L .45155 .5 L p .752 .667 .768 r
F P
0 g
s
.52423 .54195 m .53417 .53869 L .52681 .52275 L p .734 .538 .627 r
F P
0 g
s
.52681 .52275 m .51576 .5273 L .52423 .54195 L p .734 .538 .627 r
F P
0 g
s
.46689 .48815 m .46848 .5 L .49995 .49991 L p .692 .518 .647 r
F P
0 g
s
.46848 .5 m .46689 .48815 L .44941 .48975 L p .752 .56 .637 r
F P
0 g
s
.52422 .45804 m .51642 .45106 L .50629 .46541 L p .621 .515 .712 r
F P
0 g
s
.50629 .46541 m .51576 .4727 L .52422 .45804 L p .621 .515 .712 r
F P
0 g
s
.52681 .47725 m .51576 .4727 L .50011 .5 L p .761 .636 .722 r
F P
0 g
s
.51576 .4727 m .52681 .47725 L .53417 .46131 L p .734 .661 .778 r
F P
0 g
s
.81262 .56278 m .8244 .62241 L .77954 .64936 L p .521 .384 .635 r
F P
0 g
s
.83447 .53772 m .79373 .60269 L .74983 .55419 L p .534 .394 .636 r
F P
0 g
s
.28932 .73935 m .23179 .71974 L .23088 .66741 L p .812 .567 .568 r
F P
0 g
s
.3001 .7708 m .26421 .70303 L .32816 .68927 L p .81 .574 .581 r
F P
0 g
s
.45135 .77679 m .48958 .81677 L .44381 .84215 L p .724 .454 .518 r
F P
0 g
s
.51562 .78305 m .44207 .80572 L .42201 .74345 L p .672 .431 .548 r
F P
0 g
s
.28462 .31948 m .23088 .33259 L .23179 .28026 L p .812 .759 .803 r
F P
0 g
s
.24706 .37201 m .26421 .29697 L .32816 .31073 L p .827 .719 .746 r
F P
0 g
s
.76403 .40374 m .77954 .35064 L .8244 .37759 L p .521 .467 .736 r
F P
0 g
s
.73732 .34495 m .79373 .39731 L .74983 .44581 L p .578 .545 .782 r
F P
0 g
s
.39806 .19788 m .44381 .15785 L .48958 .18323 L p .724 .729 .854 r
F P
0 g
s
.36543 .19148 m .44207 .19428 L .42201 .25655 L p .72 .718 .848 r
F P
0 g
s
.51642 .54894 m .52422 .54196 L .51576 .5273 L p .621 .499 .692 r
F P
0 g
s
.44941 .48975 m .45155 .5 L .46848 .5 L p .752 .56 .637 r
F P
0 g
s
.53417 .46131 m .52423 .45805 L .51576 .4727 L p .734 .661 .778 r
F P
0 g
s
.52422 .54196 m .51642 .54894 L .52038 .56136 L p .485 .291 .541 r
F P
0 g
s
.44038 .5 m .43667 .51303 L .44941 .51025 L p .874 .792 .766 r
F P
0 g
s
.44941 .51025 m .45155 .5 L .44038 .5 L p .874 .792 .766 r
F P
0 g
s
.52981 .55163 m .54295 .54833 L .53417 .53869 L p .651 .348 .446 r
F P
0 g
s
.53417 .53869 m .52423 .54195 L .52981 .55163 L p .651 .348 .446 r
F P
0 g
s
.45155 .5 m .44941 .48975 L .43667 .48697 L p .874 .636 .575 r
F P
0 g
s
.52423 .45805 m .53417 .46131 L .54295 .45167 L p .651 .715 .895 r
F P
0 g
s
.52981 .44837 m .52038 .43864 L .51642 .45106 L p .486 .502 .799 r
F P
0 g
s
.51642 .45106 m .52422 .45804 L .52981 .44837 L p .486 .502 .799 r
F P
0 g
s
.52038 .56136 m .52981 .55163 L .52422 .54196 L p .485 .291 .541 r
F P
0 g
s
.43667 .48697 m .44038 .5 L .45155 .5 L p .874 .636 .575 r
F P
0 g
s
.54295 .45167 m .52981 .44837 L .52423 .45805 L p .651 .715 .895 r
F P
0 g
s
.525 .61664 m .55325 .63468 L .54875 .68091 L p .844 .571 .525 r
F P
0 g
s
.60488 .69574 m .54875 .68091 L .55325 .63468 L p .756 .488 .528 r
F P
0 g
s
.36516 .56469 m .31895 .54824 L .35674 .52122 L p .71 .398 .448 r
F P
0 g
s
.35674 .52122 m .38649 .53667 L .36516 .56469 L p .71 .398 .448 r
F P
0 g
s
.62345 .58443 m .6323 .63268 L .59001 .61346 L p .458 .436 .747 r
F P
0 g
s
.59001 .61346 m .58851 .57997 L .62345 .58443 L p .458 .436 .747 r
F P
0 g
s
.38649 .46333 m .35674 .47878 L .31895 .45176 L p .708 .761 .893 r
F P
0 g
s
.27805 .49296 m .31895 .45176 L .35674 .47878 L p .787 .757 .825 r
F P
0 g
s
.58851 .42003 m .59001 .38654 L .6323 .36732 L p .457 .309 .592 r
F P
0 g
s
.61707 .3113 m .6323 .36732 L .59001 .38654 L p .514 .434 .704 r
F P
0 g
s
.5114 .35088 m .54875 .31909 L .55325 .36532 L p .843 .807 .816 r
F P
0 g
s
.55325 .36532 m .525 .38336 L .5114 .35088 L p .843 .807 .816 r
F P
0 g
s
.525 .61664 m .51329 .59282 L .51857 .57474 L p .961 .7 .495 r
F P
0 g
s
.43073 .52052 m .41297 .5349 L .42599 .52129 L p 0 0 0 r
F P
0 g
s
.5524 .54973 m .57374 .55792 L .55544 .55345 L p 0 .501 .841 r
F P
0 g
s
.38649 .46333 m .41297 .4651 L .42599 .47871 L p .507 .712 .964 r
F P
0 g
s
.51687 .42975 m .51329 .40718 L .51857 .42526 L p .869 .61 .081 r
F P
0 g
s
.58851 .42003 m .57374 .44208 L .55544 .44655 L p .328 .054 .337 r
F P
0 g
s
.54295 .54833 m .52981 .55163 L .53159 .5547 L p .208 0 0 r
F P
0 g
s
.43667 .51303 m .44038 .5 L .43684 .50001 L p .932 .913 .528 r
F P
0 g
s
.52038 .43864 m .52981 .44837 L .53158 .4453 L p 0 .246 .759 r
F P
0 g
s
.40627 .55759 m .36516 .56469 L .38649 .53667 L p .538 .187 .32 r
F P
0 g
s
.38649 .53667 m .41297 .5349 L .40627 .55759 L p .538 .187 .32 r
F P
0 g
s
.51329 .59282 m .525 .61664 L .5114 .64912 L p .943 .71 .555 r
F P
0 g
s
.54875 .68091 m .5114 .64912 L .525 .61664 L p .844 .571 .525 r
F P
0 g
s
.59674 .55238 m .62345 .58443 L .58851 .57997 L p .407 .523 .863 r
F P
0 g
s
.58851 .57997 m .57374 .55792 L .59674 .55238 L p .407 .523 .863 r
F P
0 g
s
.49699 .39003 m .5114 .35088 L .525 .38336 L p .943 .831 .705 r
F P
0 g
s
.525 .38336 m .51329 .40718 L .49699 .39003 L p .943 .831 .705 r
F P
0 g
s
.41297 .4651 m .38649 .46333 L .36516 .43531 L p .536 .69 .938 r
F P
0 g
s
.31895 .45176 m .36516 .43531 L .38649 .46333 L p .708 .761 .893 r
F P
0 g
s
.57374 .44208 m .58851 .42003 L .62345 .41557 L p .407 .141 .394 r
F P
0 g
s
.6323 .36732 m .62345 .41557 L .58851 .42003 L p .457 .309 .592 r
F P
0 g
s
.78597 .69802 m .77954 .64936 L .8244 .62241 L p .487 .321 .582 r
F P
0 g
s
.48958 .81677 m .52851 .84666 L .4904 .87007 L p .688 .391 .465 r
F P
0 g
s
.4904 .87007 m .44381 .84215 L .48958 .81677 L p .688 .391 .465 r
F P
0 g
s
.18553 .64864 m .23088 .66741 L .23179 .71974 L p .85 .599 .559 r
F P
0 g
s
.52851 .15334 m .48958 .18323 L .44381 .15785 L p .688 .733 .885 r
F P
0 g
s
.77954 .35064 m .78597 .30198 L .82529 .32328 L p .487 .474 .769 r
F P
0 g
s
.82529 .32328 m .8244 .37759 L .77954 .35064 L p .487 .474 .769 r
F P
0 g
s
.23088 .33259 m .18553 .35136 L .18431 .30665 L p .85 .789 .792 r
F P
0 g
s
.18431 .30665 m .23179 .28026 L .23088 .33259 L p .85 .789 .792 r
F P
0 g
s
.51687 .57025 m .51329 .59282 L .49699 .60997 L p .983 .9 .646 r
F P
0 g
s
.5114 .64912 m .49699 .60997 L .51329 .59282 L p .943 .71 .555 r
F P
0 g
s
.43386 .53303 m .40627 .55759 L .41297 .5349 L p .196 0 .191 r
F P
0 g
s
.41297 .5349 m .43073 .52052 L .43386 .53303 L p .196 0 .191 r
F P
0 g
s
.56168 .54076 m .59674 .55238 L .57374 .55792 L p .401 .699 .981 r
F P
0 g
s
.57374 .55792 m .5524 .54973 L .56168 .54076 L p .401 .699 .981 r
F P
0 g
s
.43073 .47948 m .41297 .4651 L .40627 .44241 L p .195 .433 .862 r
F P
0 g
s
.36516 .43531 m .40627 .44241 L .41297 .4651 L p .536 .69 .938 r
F P
0 g
s
.50446 .4262 m .49699 .39003 L .51329 .40718 L p .983 .706 .409 r
F P
0 g
s
.51329 .40718 m .51687 .42975 L .50446 .4262 L p .983 .706 .409 r
F P
0 g
s
.5524 .45027 m .57374 .44208 L .59674 .44762 L p .402 0 .071 r
F P
0 g
s
.62345 .41557 m .59674 .44762 L .57374 .44208 L p .407 .141 .394 r
F P
0 g
s
.67123 .68744 m .73732 .65505 L .76915 .70804 L p .576 .317 .486 r
F P
0 g
s
.25206 .55457 m .24706 .62799 L .18526 .62907 L p .887 .732 .684 r
F P
0 g
s
.57671 .25799 m .51562 .21695 L .54559 .16289 L p .56 .604 .854 r
F P
0 g
s
.44207 .80572 m .51562 .78305 L .54559 .83711 L p .628 .336 .455 r
F P
0 g
s
.26421 .29697 m .24706 .37201 L .18526 .37093 L p .881 .777 .742 r
F P
0 g
s
.8244 .62241 m .82529 .67672 L .78597 .69802 L p .487 .321 .582 r
F P
0 g
s
.82529 .67672 m .8244 .62241 L .8651 .5988 L p .414 .265 .568 r
F P
0 g
s
.73732 .65505 m .79373 .60269 L .83256 .64667 L p .506 .294 .525 r
F P
0 g
s
.83256 .64667 m .76915 .70804 L .73732 .65505 L p .506 .294 .525 r
F P
0 g
s
.23179 .71974 m .18431 .69335 L .18553 .64864 L p .85 .599 .559 r
F P
0 g
s
.18431 .69335 m .23179 .71974 L .23189 .76678 L p .857 .564 .492 r
F P
0 g
s
.24706 .62799 m .26421 .70303 L .2067 .71467 L p .881 .662 .602 r
F P
0 g
s
.2067 .71467 m .18526 .62907 L .24706 .62799 L p .881 .662 .602 r
F P
0 g
s
.79373 .39731 m .73732 .34495 L .76915 .29196 L p .506 .533 .818 r
F P
0 g
s
.44381 .15785 m .4904 .12993 L .52851 .15334 L p .688 .733 .885 r
F P
0 g
s
.4904 .12993 m .44381 .15785 L .40301 .13442 L p .702 .782 .914 r
F P
0 g
s
.51562 .21695 m .44207 .19428 L .46074 .13866 L p .628 .689 .888 r
F P
0 g
s
.46074 .13866 m .54559 .16289 L .51562 .21695 L p .628 .689 .888 r
F P
0 g
s
.49699 .60997 m .50446 .5738 L .51687 .57025 L p .983 .9 .646 r
F P
0 g
s
.52834 .54906 m .56168 .54076 L .5524 .54973 L p .529 .904 .957 r
F P
0 g
s
.5524 .54973 m .53159 .5547 L .52834 .54906 L p .529 .904 .957 r
F P
0 g
s
.44334 .50001 m .43386 .53303 L .43073 .52052 L p 0 0 .22 r
F P
0 g
s
.43073 .52052 m .43684 .50001 L .44334 .50001 L p 0 0 .22 r
F P
0 g
s
.40627 .44241 m .43386 .46697 L .43073 .47948 L p .195 .433 .862 r
F P
0 g
s
.52832 .45093 m .50446 .4262 L .51687 .42975 L p .804 .315 0 r
F P
0 g
s
.51687 .42975 m .53158 .4453 L .52832 .45093 L p .804 .315 0 r
F P
0 g
s
.59674 .44762 m .56168 .45924 L .5524 .45027 L p .402 0 .071 r
F P
0 g
s
.6794 .64692 m .66433 .72049 L .61707 .6887 L p .429 .321 .629 r
F P
0 g
s
.61707 .6887 m .6323 .63268 L .6794 .64692 L p .429 .321 .629 r
F P
0 g
s
.28306 .5819 m .22688 .53207 L .27805 .50704 L p .815 .514 .479 r
F P
0 g
s
.27805 .50704 m .31895 .54824 L .28306 .5819 L p .815 .514 .479 r
F P
0 g
s
.54875 .68091 m .60488 .69574 L .60879 .75256 L p .753 .433 .443 r
F P
0 g
s
.31895 .45176 m .27805 .49296 L .22688 .46793 L p .814 .818 .852 r
F P
0 g
s
.6323 .36732 m .61707 .3113 L .66433 .27951 L p .429 .379 .701 r
F P
0 g
s
.53754 .27117 m .60879 .24744 L .60488 .30426 L p .752 .796 .888 r
F P
0 g
s
.60488 .30426 m .54875 .31909 L .53754 .27117 L p .752 .796 .888 r
F P
0 g
s
.50446 .5738 m .52832 .54907 L .53158 .5547 L p .804 .999 .798 r
F P
0 g
s
.43386 .46697 m .44334 .49999 L .43684 .49999 L p 0 0 .537 r
F P
0 g
s
.56168 .45924 m .52834 .45094 L .53159 .4453 L p .53 0 0 r
F P
0 g
s
.26421 .70303 m .3001 .7708 L .25041 .78889 L p .857 .583 .522 r
F P
0 g
s
.25041 .78889 m .2067 .71467 L .26421 .70303 L p .857 .583 .522 r
F P
0 g
s
.79373 .60269 m .83447 .53772 L .87498 .5717 L p .445 .286 .57 r
F P
0 g
s
.87498 .5717 m .83256 .64667 L .79373 .60269 L p .445 .286 .57 r
F P
0 g
s
.44381 .84215 m .4904 .87007 L .45763 .89144 L p .702 .364 .402 r
F P
0 g
s
.54559 .83711 m .46074 .86134 L .44207 .80572 L p .628 .336 .455 r
F P
0 g
s
.45763 .89144 m .40301 .86558 L .44381 .84215 L p .702 .364 .402 r
F P
0 g
s
.36543 .80852 m .44207 .80572 L .46074 .86134 L p .693 .372 .427 r
F P
0 g
s
.23179 .28026 m .18431 .30665 L .18219 .26758 L p .857 .836 .824 r
F P
0 g
s
.18526 .37093 m .2067 .28533 L .26421 .29697 L p .881 .777 .742 r
F P
0 g
s
.18219 .26758 m .23189 .23322 L .23179 .28026 L p .857 .836 .824 r
F P
0 g
s
.3001 .2292 m .26421 .29697 L .2067 .28533 L p .857 .817 .809 r
F P
0 g
s
.8244 .37759 m .82529 .32328 L .86019 .34098 L p .414 .411 .748 r
F P
0 g
s
.76915 .29196 m .83256 .35333 L .79373 .39731 L p .506 .533 .818 r
F P
0 g
s
.86019 .34098 m .8651 .4012 L .8244 .37759 L p .414 .411 .748 r
F P
0 g
s
.83447 .46228 m .79373 .39731 L .83256 .35333 L p .445 .441 .76 r
F P
0 g
s
.44207 .19428 m .36543 .19148 L .37461 .1394 L p .693 .76 .903 r
F P
0 g
s
.37461 .1394 m .46074 .13866 L .44207 .19428 L p .693 .76 .903 r
F P
0 g
s
.5114 .64912 m .54875 .68091 L .53754 .72883 L p .859 .548 .459 r
F P
0 g
s
.60879 .75256 m .53754 .72883 L .54875 .68091 L p .753 .433 .443 r
F P
0 g
s
.66264 .58202 m .6794 .64692 L .6323 .63268 L p .379 .381 .735 r
F P
0 g
s
.6323 .63268 m .62345 .58443 L .66264 .58202 L p .379 .381 .735 r
F P
0 g
s
.34764 .59984 m .28306 .5819 L .31895 .54824 L p .707 .351 .371 r
F P
0 g
s
.31895 .54824 m .36516 .56469 L .34764 .59984 L p .707 .351 .371 r
F P
0 g
s
.36516 .43531 m .31895 .45176 L .28306 .4181 L p .706 .802 .925 r
F P
0 g
s
.22688 .46793 m .28306 .4181 L .31895 .45176 L p .814 .818 .852 r
F P
0 g
s
.62345 .41557 m .6323 .36732 L .6794 .35308 L p .379 .237 .559 r
F P
0 g
s
.66433 .27951 m .6794 .35308 L .6323 .36732 L p .429 .379 .701 r
F P
0 g
s
.48971 .31814 m .53754 .27117 L .54875 .31909 L p .858 .855 .837 r
F P
0 g
s
.54875 .31909 m .5114 .35088 L .48971 .31814 L p .858 .855 .837 r
F P
0 g
s
.49699 .60997 m .5114 .64912 L .48971 .68186 L p .956 .711 .528 r
F P
0 g
s
.53754 .72883 m .48971 .68186 L .5114 .64912 L p .859 .548 .459 r
F P
0 g
s
.4058 .58629 m .34764 .59984 L .36516 .56469 L p .515 .143 .272 r
F P
0 g
s
.36516 .56469 m .40627 .55759 L .4058 .58629 L p .515 .143 .272 r
F P
0 g
s
.62183 .53844 m .66264 .58202 L .62345 .58443 L p .366 .507 .866 r
F P
0 g
s
.62345 .58443 m .59674 .55238 L .62183 .53844 L p .366 .507 .866 r
F P
0 g
s
.40627 .44241 m .36516 .43531 L .34764 .40016 L p .514 .697 .952 r
F P
0 g
s
.28306 .4181 m .34764 .40016 L .36516 .43531 L p .706 .802 .925 r
F P
0 g
s
.59674 .44762 m .62345 .41557 L .66264 .41798 L p .367 .091 .357 r
F P
0 g
s
.6794 .35308 m .66264 .41798 L .62345 .41557 L p .379 .237 .559 r
F P
0 g
s
.47237 .37527 m .48971 .31814 L .5114 .35088 L p .955 .85 .698 r
F P
0 g
s
.5114 .35088 m .49699 .39003 L .47237 .37527 L p .955 .85 .698 r
F P
0 g
s
.52851 .84666 m .56526 .86707 L .53432 .88741 L p .644 .32 .408 r
F P
0 g
s
.53432 .88741 m .4904 .87007 L .52851 .84666 L p .644 .32 .408 r
F P
0 g
s
.78597 .30198 m .78526 .25995 L .81835 .27658 L p .45 .482 .801 r
F P
0 g
s
.81835 .27658 m .82529 .32328 L .78597 .30198 L p .45 .482 .801 r
F P
0 g
s
.18553 .35136 m .14948 .37298 L .14734 .33602 L p .887 .816 .773 r
F P
0 g
s
.14734 .33602 m .18431 .30665 L .18553 .35136 L p .887 .816 .773 r
F P
0 g
s
.2067 .28533 m .25041 .21111 L .3001 .2292 L p .857 .817 .809 r
F P
0 g
s
.83256 .35333 m .87498 .4283 L .83447 .46228 L p .445 .441 .76 r
F P
0 g
s
.46074 .86134 m .37461 .8606 L .36543 .80852 L p .693 .372 .427 r
F P
0 g
s
.50446 .5738 m .49699 .60997 L .47237 .62473 L p .979 .894 .668 r
F P
0 g
s
.48971 .68186 m .47237 .62473 L .49699 .60997 L p .956 .711 .528 r
F P
0 g
s
.56984 .52308 m .62183 .53844 L .59674 .55238 L p .438 .706 .979 r
F P
0 g
s
.59674 .55238 m .56168 .54076 L .56984 .52308 L p .438 .706 .979 r
F P
0 g
s
.4451 .54894 m .4058 .58629 L .40627 .55759 L p .239 0 .239 r
F P
0 g
s
.40627 .55759 m .43386 .53303 L .4451 .54894 L p .239 0 .239 r
F P
0 g
s
.43386 .46697 m .40627 .44241 L .4058 .41371 L p .238 .448 .863 r
F P
0 g
s
.34764 .40016 m .4058 .41371 L .40627 .44241 L p .514 .697 .952 r
F P
0 g
s
.48506 .42798 m .47237 .37527 L .49699 .39003 L p .979 .705 .437 r
F P
0 g
s
.49699 .39003 m .50446 .4262 L .48506 .42798 L p .979 .705 .437 r
F P
0 g
s
.56168 .45924 m .59674 .44762 L .62183 .46156 L p .439 .009 .124 r
F P
0 g
s
.66264 .41798 m .62183 .46156 L .59674 .44762 L p .367 .091 .357 r
F P
0 g
s
.52069 .5358 m .56984 .52308 L .56168 .54076 L p .623 .909 .983 r
F P
0 g
s
.56168 .54076 m .52834 .54906 L .52069 .5358 L p .623 .909 .983 r
F P
0 g
s
.52832 .54907 m .50446 .5738 L .48506 .57202 L p .851 .988 .851 r
F P
0 g
s
.47237 .62473 m .48506 .57202 L .50446 .5738 L p .979 .894 .668 r
F P
0 g
s
.45865 .50002 m .4451 .54894 L .43386 .53303 L p .002 0 .361 r
F P
0 g
s
.43386 .53303 m .44334 .50001 L .45865 .50002 L p .002 0 .361 r
F P
0 g
s
.44334 .49999 m .43386 .46697 L .4451 .45106 L p .002 .109 .624 r
F P
0 g
s
.4058 .41371 m .4451 .45106 L .43386 .46697 L p .238 .448 .863 r
F P
0 g
s
.52066 .46418 m .48506 .42798 L .50446 .4262 L p .852 .403 .134 r
F P
0 g
s
.50446 .4262 m .52832 .45093 L .52066 .46418 L p .852 .403 .134 r
F P
0 g
s
.52834 .45094 m .56168 .45924 L .56984 .47692 L p .624 .109 .002 r
F P
0 g
s
.62183 .46156 m .56984 .47692 L .56168 .45924 L p .439 .009 .124 r
F P
0 g
s
.59969 .84555 m .62593 .86159 L .59802 .87959 L p .587 .268 .395 r
F P
0 g
s
.59802 .87959 m .56526 .86707 L .59969 .84555 L p .587 .268 .395 r
F P
0 g
s
.74941 .24089 m .75018 .21014 L .77973 .22531 L p .463 .532 .842 r
F P
0 g
s
.77973 .22531 m .78526 .25995 L .74941 .24089 L p .463 .532 .842 r
F P
0 g
s
.1509 .41356 m .12389 .42827 L .12225 .39509 L p .913 .803 .726 r
F P
0 g
s
.12225 .39509 m .14948 .37298 L .1509 .41356 L p .913 .803 .726 r
F P
0 g
s
.48506 .57202 m .52066 .53582 L .52832 .54907 L p .851 .988 .851 r
F P
0 g
s
.4451 .45106 m .45865 .49998 L .44334 .49999 L p .002 .109 .624 r
F P
0 g
s
.56984 .47692 m .52069 .4642 L .52834 .45094 L p .624 .109 .002 r
F P
0 g
s
.4904 .87007 m .53432 .88741 L .50849 .90574 L p .646 .281 .336 r
F P
0 g
s
.50849 .90574 m .45763 .89144 L .4904 .87007 L p .646 .281 .336 r
F P
0 g
s
.18431 .30665 m .14734 .33602 L .14437 .30449 L p .897 .862 .797 r
F P
0 g
s
.14437 .30449 m .18219 .26758 L .18431 .30665 L p .897 .862 .797 r
F P
0 g
s
.82529 .32328 m .81835 .27658 L .84714 .28977 L p .373 .423 .784 r
F P
0 g
s
.84714 .28977 m .86019 .34098 L .82529 .32328 L p .373 .423 .784 r
F P
0 g
s
.8651 .5988 m .86019 .65902 L .82529 .67672 L p .414 .265 .568 r
F P
0 g
s
.81835 .72342 m .82529 .67672 L .86019 .65902 L p .373 .186 .494 r
F P
0 g
s
.40301 .13442 m .45763 .10856 L .4904 .12993 L p .702 .782 .914 r
F P
0 g
s
.53432 .11259 m .4904 .12993 L .45763 .10856 L p .646 .775 .942 r
F P
0 g
s
.23189 .76678 m .18219 .73242 L .18431 .69335 L p .857 .564 .492 r
F P
0 g
s
.14734 .66398 m .18431 .69335 L .18219 .73242 L p .897 .604 .481 r
F P
0 g
s
.56526 .86707 m .59802 .87959 L .57344 .89648 L p .591 .24 .344 r
F P
0 g
s
.57344 .89648 m .53432 .88741 L .56526 .86707 L p .591 .24 .344 r
F P
0 g
s
.14948 .37298 m .12225 .39509 L .11992 .36536 L p .921 .838 .745 r
F P
0 g
s
.11992 .36536 m .14734 .33602 L .14948 .37298 L p .921 .838 .745 r
F P
0 g
s
.78526 .25995 m .77973 .22531 L .80664 .23816 L p .408 .489 .831 r
F P
0 g
s
.80664 .23816 m .81835 .27658 L .78526 .25995 L p .408 .489 .831 r
F P
0 g
s
.69734 .1582 m .68741 .1754 L .65606 .15693 L p .511 .627 .902 r
F P
0 g
s
.68741 .1754 m .69734 .1582 L .72288 .17258 L p .489 .599 .889 r
F P
0 g
s
.72288 .17258 m .71908 .19331 L .68741 .1754 L p .489 .599 .889 r
F P
0 g
s
.69734 .8418 m .68741 .8246 L .71908 .80669 L p .489 .2 .4 r
F P
0 g
s
.68741 .8246 m .69734 .8418 L .67211 .85673 L p .511 .207 .388 r
F P
0 g
s
.67211 .85673 m .65606 .84307 L .68741 .8246 L p .511 .207 .388 r
F P
0 g
s
.10532 .5 m .12518 .5 L .12486 .53639 L p .935 .753 .632 r
F P
0 g
s
.12518 .5 m .10532 .5 L .10501 .47069 L p .935 .773 .658 r
F P
0 g
s
.10501 .47069 m .12486 .46361 L .12518 .5 L p .935 .773 .658 r
F P
0 g
s
.12486 .46361 m .10501 .47069 L .10408 .44235 L p .937 .797 .679 r
F P
0 g
s
.10408 .44235 m .12389 .42827 L .12486 .46361 L p .937 .797 .679 r
F P
0 g
s
.65606 .84307 m .67211 .85673 L .64803 .8717 L p .525 .203 .364 r
F P
0 g
s
.64803 .8717 m .62593 .86159 L .65606 .84307 L p .525 .203 .364 r
F P
0 g
s
.71908 .19331 m .72288 .17258 L .74789 .18595 L p .459 .569 .879 r
F P
0 g
s
.74789 .18595 m .75018 .21014 L .71908 .19331 L p .459 .569 .879 r
F P
0 g
s
.72288 .82742 m .71908 .80669 L .75018 .78986 L p .459 .18 .403 r
F P
0 g
s
.71908 .80669 m .72288 .82742 L .69734 .8418 L p .489 .2 .4 r
F P
0 g
s
.10501 .52931 m .12486 .53639 L .12389 .57173 L p .937 .734 .602 r
F P
0 g
s
.12486 .53639 m .10501 .52931 L .10532 .5 L p .935 .753 .632 r
F P
0 g
s
.67211 .14327 m .65606 .15693 L .62593 .13841 L p .525 .655 .917 r
F P
0 g
s
.65606 .15693 m .67211 .14327 L .69734 .1582 L p .511 .627 .902 r
F P
0 g
s
.40301 .86558 m .45763 .89144 L .4328 .90959 L p .704 .307 .294 r
F P
0 g
s
.8651 .4012 m .86019 .34098 L .88832 .3534 L p .297 .318 .714 r
F P
0 g
s
.23189 .23322 m .18219 .26758 L .17888 .23701 L p .864 .897 .856 r
F P
0 g
s
.71635 .65669 m .70056 .74397 L .66433 .72049 L p .207 .114 .523 r
F P
0 g
s
.66433 .72049 m .6794 .64692 L .71635 .65669 L p .207 .114 .523 r
F P
0 g
s
.28306 .4181 m .22688 .46793 L .18843 .4483 L p .839 .93 .889 r
F P
0 g
s
.25613 .60902 m .18843 .5517 L .22688 .53207 L p .84 .442 .292 r
F P
0 g
s
.22688 .53207 m .28306 .5819 L .25613 .60902 L p .84 .442 .292 r
F P
0 g
s
.53754 .72883 m .60879 .75256 L .61101 .79567 L p .725 .293 .225 r
F P
0 g
s
.52752 .23429 m .61101 .20433 L .60879 .24744 L p .724 .89 .956 r
F P
0 g
s
.60879 .24744 m .53754 .27117 L .52752 .23429 L p .724 .89 .956 r
F P
0 g
s
.6794 .35308 m .66433 .27951 L .70056 .25603 L p .207 .223 .656 r
F P
0 g
s
.75018 .21014 m .74789 .18595 L .77149 .19779 L p .418 .535 .869 r
F P
0 g
s
.77149 .19779 m .77973 .22531 L .75018 .21014 L p .418 .535 .869 r
F P
0 g
s
.62593 .86159 m .64803 .8717 L .62597 .88622 L p .532 .187 .328 r
F P
0 g
s
.62597 .88622 m .59802 .87959 L .62593 .86159 L p .532 .187 .328 r
F P
0 g
s
.64803 .1283 m .62593 .13841 L .59802 .12041 L p .532 .682 .934 r
F P
0 g
s
.62593 .13841 m .64803 .1283 L .67211 .14327 L p .525 .655 .917 r
F P
0 g
s
.12389 .42827 m .10408 .44235 L .10254 .41599 L p .943 .824 .697 r
F P
0 g
s
.10254 .41599 m .12225 .39509 L .12389 .42827 L p .943 .824 .697 r
F P
0 g
s
.74789 .81405 m .75018 .78986 L .77973 .77469 L p .418 .147 .393 r
F P
0 g
s
.75018 .78986 m .74789 .81405 L .72288 .82742 L p .459 .18 .403 r
F P
0 g
s
.10408 .55765 m .12389 .57173 L .12225 .60491 L p .943 .717 .565 r
F P
0 g
s
.12389 .57173 m .10408 .55765 L .10501 .52931 L p .937 .734 .602 r
F P
0 g
s
.64727 .82197 m .56637 .87639 L .54559 .83711 L p .412 .091 .31 r
F P
0 g
s
.46074 .86134 m .54559 .83711 L .56637 .87639 L p .52 .134 .25 r
F P
0 g
s
.14753 .46656 m .14085 .36928 L .18526 .37093 L p .968 .773 .588 r
F P
0 g
s
.2067 .28533 m .18526 .37093 L .14085 .36928 L p .956 .865 .709 r
F P
0 g
s
.86019 .65902 m .84714 .71023 L .81835 .72342 L p .373 .186 .494 r
F P
0 g
s
.84714 .71023 m .86019 .65902 L .88832 .6466 L p .254 .077 .438 r
F P
0 g
s
.76915 .70804 m .83256 .64667 L .86094 .67635 L p .341 .073 .354 r
F P
0 g
s
.86094 .67635 m .79278 .74567 L .76915 .70804 L p .341 .073 .354 r
F P
0 g
s
.18219 .73242 m .14437 .69551 L .14734 .66398 L p .897 .604 .481 r
F P
0 g
s
.14437 .69551 m .18219 .73242 L .17888 .76299 L p .907 .563 .38 r
F P
0 g
s
.18526 .62907 m .2067 .71467 L .16681 .72441 L p .956 .696 .502 r
F P
0 g
s
.16681 .72441 m .14085 .63072 L .18526 .62907 L p .956 .696 .502 r
F P
0 g
s
.45763 .10856 m .50849 .09426 L .53432 .11259 L p .646 .775 .942 r
F P
0 g
s
.50849 .09426 m .45763 .10856 L .4328 .09041 L p .631 .823 .974 r
F P
0 g
s
.54559 .16289 m .46074 .13866 L .47225 .09924 L p .52 .714 .961 r
F P
0 g
s
.47225 .09924 m .56637 .12361 L .54559 .16289 L p .52 .714 .961 r
F P
0 g
s
.7052 .21147 m .79278 .25433 L .76915 .29196 L p .448 .628 .93 r
F P
0 g
s
.83256 .35333 m .76915 .29196 L .79278 .25433 L p .34 .483 .857 r
F P
0 g
s
.69373 .57839 m .71635 .65669 L .6794 .64692 L p .144 .219 .683 r
F P
0 g
s
.6794 .64692 m .66264 .58202 L .69373 .57839 L p .144 .219 .683 r
F P
0 g
s
.48971 .68186 m .53754 .72883 L .52752 .76571 L p .874 .472 .262 r
F P
0 g
s
.61101 .79567 m .52752 .76571 L .53754 .72883 L p .725 .293 .225 r
F P
0 g
s
.34764 .40016 m .28306 .4181 L .25613 .39098 L p .658 .882 .981 r
F P
0 g
s
.18843 .4483 m .25613 .39098 L .28306 .4181 L p .839 .93 .889 r
F P
0 g
s
.33524 .62858 m .25613 .60902 L .28306 .5819 L p .659 .194 .138 r
F P
0 g
s
.28306 .5819 m .34764 .59984 L .33524 .62858 L p .659 .194 .138 r
F P
0 g
s
.66264 .41798 m .6794 .35308 L .71635 .34331 L p .144 .016 .434 r
F P
0 g
s
.70056 .25603 m .71635 .34331 L .6794 .35308 L p .207 .223 .656 r
F P
0 g
s
.47102 .29303 m .52752 .23429 L .53754 .27117 L p .874 .956 .857 r
F P
0 g
s
.53754 .27117 m .48971 .31814 L .47102 .29303 L p .874 .956 .857 r
F P
0 g
s
.45763 .89144 m .50849 .90574 L .48961 .92109 L p .631 .207 .22 r
F P
0 g
s
.56637 .87639 m .47225 .90076 L .46074 .86134 L p .52 .134 .25 r
F P
0 g
s
.48961 .92109 m .4328 .90959 L .45763 .89144 L p .631 .207 .22 r
F P
0 g
s
.37461 .8606 m .46074 .86134 L .47225 .90076 L p .622 .197 .214 r
F P
0 g
s
.83256 .64667 m .87498 .5717 L .90397 .59313 L p .252 .069 .427 r
F P
0 g
s
.90397 .59313 m .86094 .67635 L .83256 .64667 L p .252 .069 .427 r
F P
0 g
s
.18219 .26758 m .14437 .30449 L .14052 .28045 L p .907 .918 .815 r
F P
0 g
s
.14085 .36928 m .16681 .27559 L .2067 .28533 L p .956 .865 .709 r
F P
0 g
s
.14052 .28045 m .17888 .23701 L .18219 .26758 L p .907 .918 .815 r
F P
0 g
s
.25041 .21111 m .2067 .28533 L .16681 .27559 L p .912 .919 .808 r
F P
0 g
s
.86019 .34098 m .84714 .28977 L .86987 .29846 L p .254 .338 .757 r
F P
0 g
s
.79278 .25433 m .86094 .32365 L .83256 .35333 L p .34 .483 .857 r
F P
0 g
s
.86987 .29846 m .88832 .3534 L .86019 .34098 L p .254 .338 .757 r
F P
0 g
s
.87498 .4283 m .83256 .35333 L .86094 .32365 L p .252 .343 .763 r
F P
0 g
s
.2067 .71467 m .25041 .78889 L .21736 .80329 L p .912 .571 .382 r
F P
0 g
s
.21736 .80329 m .16681 .72441 L .2067 .71467 L p .912 .571 .382 r
F P
0 g
s
.46074 .13866 m .37461 .1394 L .37867 .10358 L p .621 .818 .976 r
F P
0 g
s
.37867 .10358 m .47225 .09924 L .46074 .13866 L p .621 .818 .976 r
F P
0 g
s
.80664 .76184 m .81835 .72342 L .84714 .71023 L p .33 .104 .413 r
F P
0 g
s
.81835 .72342 m .80664 .76184 L .77973 .77469 L p .408 .177 .449 r
F P
0 g
s
.57344 .10352 m .53432 .11259 L .50849 .09426 L p .582 .759 .963 r
F P
0 g
s
.53432 .11259 m .57344 .10352 L .59802 .12041 L p .591 .724 .936 r
F P
0 g
s
.53432 .88741 m .57344 .89648 L .55341 .91153 L p .582 .191 .267 r
F P
0 g
s
.55341 .91153 m .50849 .90574 L .53432 .88741 L p .582 .191 .267 r
F P
0 g
s
.81835 .27658 m .80664 .23816 L .82969 .24798 L p .33 .435 .817 r
F P
0 g
s
.82969 .24798 m .84714 .28977 L .81835 .27658 L p .33 .435 .817 r
F P
0 g
s
.11992 .63464 m .14734 .66398 L .14437 .69551 L p .932 .643 .47 r
F P
0 g
s
.14734 .66398 m .11992 .63464 L .12225 .60491 L p .921 .666 .535 r
F P
0 g
s
.14734 .33602 m .11992 .36536 L .1169 .34049 L p .932 .88 .76 r
F P
0 g
s
.1169 .34049 m .14437 .30449 L .14734 .33602 L p .932 .88 .76 r
F P
0 g
s
.47237 .62473 m .48971 .68186 L .47102 .70697 L p .983 .699 .378 r
F P
0 g
s
.52752 .76571 m .47102 .70697 L .48971 .68186 L p .874 .472 .262 r
F P
0 g
s
.64163 .52539 m .69373 .57839 L .66264 .58202 L p .155 .412 .855 r
F P
0 g
s
.66264 .58202 m .62183 .53844 L .64163 .52539 L p .155 .412 .855 r
F P
0 g
s
.4072 .60996 m .33524 .62858 L .34764 .59984 L p .378 0 .027 r
F P
0 g
s
.34764 .59984 m .4058 .58629 L .4072 .60996 L p .378 0 .027 r
F P
0 g
s
.4058 .41371 m .34764 .40016 L .33524 .37142 L p .377 .698 .983 r
F P
0 g
s
.25613 .39098 m .33524 .37142 L .34764 .40016 L p .658 .882 .981 r
F P
0 g
s
.45117 .36465 m .47102 .29303 L .48971 .31814 L p .983 .908 .634 r
F P
0 g
s
.48971 .31814 m .47237 .37527 L .45117 .36465 L p .983 .908 .634 r
F P
0 g
s
.62183 .46156 m .66264 .41798 L .69373 .42161 L p .156 0 .155 r
F P
0 g
s
.71635 .34331 m .69373 .42161 L .66264 .41798 L p .144 .016 .434 r
F P
0 g
s
.62597 .11378 m .59802 .12041 L .57344 .10352 L p .528 .709 .954 r
F P
0 g
s
.59802 .12041 m .62597 .11378 L .64803 .1283 L p .532 .682 .934 r
F P
0 g
s
.77149 .80221 m .77973 .77469 L .80664 .76184 L p .363 .096 .37 r
F P
0 g
s
.77973 .77469 m .77149 .80221 L .74789 .81405 L p .418 .147 .393 r
F P
0 g
s
.10254 .58401 m .12225 .60491 L .11992 .63464 L p .951 .699 .518 r
F P
0 g
s
.12225 .60491 m .10254 .58401 L .10408 .55765 L p .943 .717 .565 r
F P
0 g
s
.77973 .22531 m .77149 .19779 L .79276 .20761 L p .363 .496 .858 r
F P
0 g
s
.79276 .20761 m .80664 .23816 L .77973 .22531 L p .363 .496 .858 r
F P
0 g
s
.59802 .87959 m .62597 .88622 L .60684 .89973 L p .528 .154 .274 r
F P
0 g
s
.60684 .89973 m .57344 .89648 L .59802 .87959 L p .528 .154 .274 r
F P
0 g
s
.12225 .39509 m .10254 .41599 L .1004 .39266 L p .951 .855 .71 r
F P
0 g
s
.1004 .39266 m .11992 .36536 L .12225 .39509 L p .951 .855 .71 r
F P
0 g
s
.57575 .50695 m .64163 .52539 L .62183 .53844 L p .287 .673 .972 r
F P
0 g
s
.62183 .53844 m .56984 .52308 L .57575 .50695 L p .287 .673 .972 r
F P
0 g
s
.48506 .57202 m .47237 .62473 L .45117 .63535 L p .974 .911 .576 r
F P
0 g
s
.47102 .70697 m .45117 .63535 L .47237 .62473 L p .983 .699 .378 r
F P
0 g
s
.45611 .56213 m .4072 .60996 L .4058 .58629 L p .043 0 .038 r
F P
0 g
s
.4058 .58629 m .4451 .54894 L .45611 .56213 L p .043 0 .038 r
F P
0 g
s
.4451 .45106 m .4058 .41371 L .4072 .39004 L p .043 .359 .831 r
F P
0 g
s
.33524 .37142 m .4072 .39004 L .4058 .41371 L p .377 .698 .983 r
F P
0 g
s
.46814 .43092 m .45117 .36465 L .47237 .37527 L p .974 .681 .294 r
F P
0 g
s
.47237 .37527 m .48506 .42798 L .46814 .43092 L p .974 .681 .294 r
F P
0 g
s
.56984 .47692 m .62183 .46156 L .64163 .47461 L p .287 0 0 r
F P
0 g
s
.69373 .42161 m .64163 .47461 L .62183 .46156 L p .156 0 .155 r
F P
0 g
s
.70444 .14591 m .69734 .1582 L .67211 .14327 L p .455 .62 .921 r
F P
0 g
s
.69734 .1582 m .70444 .14591 L .7244 .15713 L p .435 .594 .91 r
F P
0 g
s
.7244 .15713 m .72288 .17258 L .69734 .1582 L p .435 .594 .91 r
F P
0 g
s
.70444 .85409 m .69734 .8418 L .72288 .82742 L p .435 .117 .325 r
F P
0 g
s
.69734 .8418 m .70444 .85409 L .68473 .86578 L p .455 .124 .314 r
F P
0 g
s
.68473 .86578 m .67211 .85673 L .69734 .8418 L p .455 .124 .314 r
F P
0 g
s
.09113 .5 m .10532 .5 L .10501 .52931 L p .962 .776 .606 r
F P
0 g
s
.10532 .5 m .09113 .5 L .09086 .4771 L p .962 .795 .629 r
F P
0 g
s
.09086 .4771 m .10501 .47069 L .10532 .5 L p .962 .795 .629 r
F P
0 g
s
.86094 .32365 m .90397 .40687 L .87498 .4283 L p .252 .343 .763 r
F P
0 g
s
.16681 .27559 m .21736 .19671 L .25041 .21111 L p .912 .919 .808 r
F P
0 g
s
.47225 .90076 m .37867 .89642 L .37461 .8606 L p .622 .197 .214 r
F P
0 g
s
.67211 .85673 m .68473 .86578 L .66602 .8775 L p .466 .118 .29 r
F P
0 g
s
.66602 .8775 m .64803 .8717 L .67211 .85673 L p .466 .118 .29 r
F P
0 g
s
.72288 .17258 m .7244 .15713 L .74391 .16747 L p .407 .567 .9 r
F P
0 g
s
.74391 .16747 m .74789 .18595 L .72288 .17258 L p .407 .567 .9 r
F P
0 g
s
.68473 .13422 m .67211 .14327 L .64803 .1283 L p .466 .644 .934 r
F P
0 g
s
.67211 .14327 m .68473 .13422 L .70444 .14591 L p .455 .62 .921 r
F P
0 g
s
.10501 .47069 m .09086 .4771 L .09007 .45503 L p .964 .815 .647 r
F P
0 g
s
.09007 .45503 m .10408 .44235 L .10501 .47069 L p .964 .815 .647 r
F P
0 g
s
.7244 .84287 m .72288 .82742 L .74789 .81405 L p .407 .097 .325 r
F P
0 g
s
.72288 .82742 m .7244 .84287 L .70444 .85409 L p .435 .117 .325 r
F P
0 g
s
.09086 .5229 m .10501 .52931 L .10408 .55765 L p .964 .759 .578 r
F P
0 g
s
.10501 .52931 m .09086 .5229 L .09113 .5 L p .962 .776 .606 r
F P
0 g
s
.51351 .52336 m .57575 .50695 L .56984 .52308 L p .533 .906 .957 r
F P
0 g
s
.56984 .52308 m .52069 .5358 L .51351 .52336 L p .533 .906 .957 r
F P
0 g
s
.47301 .50002 m .45611 .56213 L .4451 .54894 L p 0 0 .225 r
F P
0 g
s
.4451 .54894 m .45865 .50002 L .47301 .50002 L p 0 0 .225 r
F P
0 g
s
.51348 .47662 m .46814 .43092 L .48506 .42798 L p .803 .313 0 r
F P
0 g
s
.48506 .42798 m .52066 .46418 L .51348 .47662 L p .803 .313 0 r
F P
0 g
s
.52066 .53582 m .48506 .57202 L .46814 .56908 L p .803 .999 .801 r
F P
0 g
s
.45117 .63535 m .46814 .56908 L .48506 .57202 L p .974 .911 .576 r
F P
0 g
s
.45865 .49998 m .4451 .45106 L .45611 .43787 L p 0 0 .536 r
F P
0 g
s
.4072 .39004 m .45611 .43787 L .4451 .45106 L p .043 .359 .831 r
F P
0 g
s
.52069 .4642 m .56984 .47692 L .57575 .49305 L p .534 0 0 r
F P
0 g
s
.64163 .47461 m .57575 .49305 L .56984 .47692 L p .287 0 0 r
F P
0 g
s
.46814 .56908 m .51348 .52338 L .52066 .53582 L p .803 .999 .801 r
F P
0 g
s
.45611 .43787 m .47301 .49998 L .45865 .49998 L p 0 0 .536 r
F P
0 g
s
.57575 .49305 m .51351 .47664 L .52069 .4642 L p .534 0 0 r
F P
0 g
s
.74789 .18595 m .74391 .16747 L .76222 .17654 L p .367 .536 .89 r
F P
0 g
s
.76222 .17654 m .77149 .19779 L .74789 .18595 L p .367 .536 .89 r
F P
0 g
s
.64803 .8717 m .66602 .8775 L .64901 .88882 L p .468 .098 .253 r
F P
0 g
s
.64901 .88882 m .62597 .88622 L .64803 .8717 L p .468 .098 .253 r
F P
0 g
s
.09007 .54497 m .10408 .55765 L .10254 .58401 L p .969 .743 .543 r
F P
0 g
s
.10408 .55765 m .09007 .54497 L .09086 .5229 L p .964 .759 .578 r
F P
0 g
s
.10408 .44235 m .09007 .45503 L .08876 .43464 L p .969 .839 .66 r
F P
0 g
s
.08876 .43464 m .10254 .41599 L .10408 .44235 L p .969 .839 .66 r
F P
0 g
s
.66602 .1225 m .64803 .1283 L .62597 .11378 L p .468 .666 .949 r
F P
0 g
s
.64803 .1283 m .66602 .1225 L .68473 .13422 L p .466 .644 .934 r
F P
0 g
s
.74391 .83253 m .74789 .81405 L .77149 .80221 L p .367 .063 .312 r
F P
0 g
s
.74789 .81405 m .74391 .83253 L .7244 .84287 L p .407 .097 .325 r
F P
0 g
s
.57344 .89648 m .60684 .89973 L .59153 .91166 L p .51 .098 .196 r
F P
0 g
s
.59153 .91166 m .55341 .91153 L .57344 .89648 L p .51 .098 .196 r
F P
0 g
s
.14437 .69551 m .1169 .65951 L .11992 .63464 L p .932 .643 .47 r
F P
0 g
s
.1004 .60734 m .11992 .63464 L .1169 .65951 L p .96 .678 .456 r
F P
0 g
s
.11992 .63464 m .1004 .60734 L .10254 .58401 L p .951 .699 .518 r
F P
0 g
s
.80664 .23816 m .79276 .20761 L .81074 .2149 L p .286 .446 .845 r
F P
0 g
s
.81074 .2149 m .82969 .24798 L .80664 .23816 L p .286 .446 .845 r
F P
0 g
s
.11992 .36536 m .1004 .39266 L .09772 .37344 L p .96 .89 .715 r
F P
0 g
s
.09772 .37344 m .1169 .34049 L .11992 .36536 L p .96 .89 .715 r
F P
0 g
s
.50849 .09426 m .55341 .08847 L .57344 .10352 L p .582 .759 .963 r
F P
0 g
s
.60684 .10027 m .57344 .10352 L .55341 .08847 L p .51 .734 .975 r
F P
0 g
s
.57344 .10352 m .60684 .10027 L .62597 .11378 L p .528 .709 .954 r
F P
0 g
s
.84714 .71023 m .82969 .75202 L .80664 .76184 L p .33 .104 .413 r
F P
0 g
s
.79276 .79239 m .80664 .76184 L .82969 .75202 L p .286 .021 .325 r
F P
0 g
s
.80664 .76184 m .79276 .79239 L .77149 .80221 L p .363 .096 .37 r
F P
0 g
s
.10254 .41599 m .08876 .43464 L .08698 .41676 L p .975 .864 .666 r
F P
0 g
s
.08698 .41676 m .1004 .39266 L .10254 .41599 L p .975 .864 .666 r
F P
0 g
s
.77149 .19779 m .76222 .17654 L .7786 .18394 L p .313 .499 .88 r
F P
0 g
s
.7786 .18394 m .79276 .20761 L .77149 .19779 L p .313 .499 .88 r
F P
0 g
s
.64901 .11118 m .62597 .11378 L .60684 .10027 L p .458 .686 .964 r
F P
0 g
s
.62597 .11378 m .64901 .11118 L .66602 .1225 L p .468 .666 .949 r
F P
0 g
s
.62597 .88622 m .64901 .88882 L .63442 .8993 L p .458 .062 .2 r
F P
0 g
s
.63442 .8993 m .60684 .89973 L .62597 .88622 L p .458 .062 .2 r
F P
0 g
s
.08876 .56536 m .10254 .58401 L .1004 .60734 L p .975 .727 .498 r
F P
0 g
s
.10254 .58401 m .08876 .56536 L .09007 .54497 L p .969 .743 .543 r
F P
0 g
s
.76222 .82346 m .77149 .80221 L .79276 .79239 L p .313 .012 .284 r
F P
0 g
s
.77149 .80221 m .76222 .82346 L .74391 .83253 L p .367 .063 .312 r
F P
0 g
s
.50849 .90574 m .55341 .91153 L .53919 .92397 L p .551 .107 .149 r
F P
0 g
s
.53919 .92397 m .48961 .92109 L .50849 .90574 L p .551 .107 .149 r
F P
0 g
s
.84714 .28977 m .82969 .24798 L .84757 .25407 L p .214 .359 .794 r
F P
0 g
s
.84757 .25407 m .86987 .29846 L .84714 .28977 L p .214 .359 .794 r
F P
0 g
s
.14437 .30449 m .1169 .34049 L .11324 .32196 L p .941 .927 .763 r
F P
0 g
s
.11324 .32196 m .14052 .28045 L .14437 .30449 L p .941 .927 .763 r
F P
0 g
s
.4328 .09041 m .48961 .07891 L .50849 .09426 L p .631 .823 .974 r
F P
0 g
s
.55341 .08847 m .50849 .09426 L .48961 .07891 L p .551 .793 .989 r
F P
0 g
s
.88832 .6466 m .86987 .70154 L .84714 .71023 L p .254 .077 .438 r
F P
0 g
s
.82969 .75202 m .84714 .71023 L .86987 .70154 L p .214 0 .343 r
F P
0 g
s
.17888 .76299 m .14052 .71955 L .14437 .69551 L p .907 .563 .38 r
F P
0 g
s
.1169 .65951 m .14437 .69551 L .14052 .71955 L p .941 .61 .374 r
F P
0 g
s
.70935 .86261 m .70444 .85409 L .7244 .84287 L p .375 .027 .242 r
F P
0 g
s
.70444 .85409 m .70935 .86261 L .69441 .87148 L p .392 .033 .232 r
F P
0 g
s
.69441 .87148 m .68473 .86578 L .70444 .85409 L p .392 .033 .232 r
F P
0 g
s
.70935 .13739 m .70444 .14591 L .68473 .13422 L p .392 .607 .934 r
F P
0 g
s
.70444 .14591 m .70935 .13739 L .72451 .14589 L p .375 .585 .924 r
F P
0 g
s
.72451 .14589 m .7244 .15713 L .70444 .14591 L p .375 .585 .924 r
F P
0 g
s
.0813 .5 m .09113 .5 L .09086 .5229 L p .983 .795 .573 r
F P
0 g
s
.09113 .5 m .0813 .5 L .08108 .48263 L p .983 .811 .593 r
F P
0 g
s
.08108 .48263 m .09086 .4771 L .09113 .5 L p .983 .811 .593 r
F P
0 g
s
.69441 .12852 m .68473 .13422 L .66602 .1225 L p .399 .626 .945 r
F P
0 g
s
.68473 .13422 m .69441 .12852 L .70935 .13739 L p .392 .607 .934 r
F P
0 g
s
.72451 .85411 m .7244 .84287 L .74391 .83253 L p .348 .008 .24 r
F P
0 g
s
.7244 .84287 m .72451 .85411 L .70935 .86261 L p .375 .027 .242 r
F P
0 g
s
.68473 .86578 m .69441 .87148 L .68027 .88038 L p .399 .026 .21 r
F P
0 g
s
.68027 .88038 m .66602 .8775 L .68473 .86578 L p .399 .026 .21 r
F P
0 g
s
.7244 .15713 m .72451 .14589 L .73928 .15369 L p .348 .56 .915 r
F P
0 g
s
.73928 .15369 m .74391 .16747 L .7244 .15713 L p .348 .56 .915 r
F P
0 g
s
.08108 .51737 m .09086 .5229 L .09007 .54497 L p .985 .78 .548 r
F P
0 g
s
.09086 .5229 m .08108 .51737 L .0813 .5 L p .983 .795 .573 r
F P
0 g
s
.09086 .4771 m .08108 .48263 L .08045 .46593 L p .985 .828 .607 r
F P
0 g
s
.08045 .46593 m .09007 .45503 L .09086 .4771 L p .985 .828 .607 r
F P
0 g
s
.08045 .53407 m .09007 .54497 L .08876 .56536 L p .987 .765 .515 r
F P
0 g
s
.09007 .54497 m .08045 .53407 L .08108 .51737 L p .985 .78 .548 r
F P
0 g
s
.68027 .11962 m .66602 .1225 L .64901 .11118 L p .397 .643 .956 r
F P
0 g
s
.66602 .1225 m .68027 .11962 L .69441 .12852 L p .399 .626 .945 r
F P
0 g
s
.73928 .84631 m .74391 .83253 L .76222 .82346 L p .311 0 .224 r
F P
0 g
s
.74391 .83253 m .73928 .84631 L .72451 .85411 L p .348 .008 .24 r
F P
0 g
s
.74391 .16747 m .73928 .15369 L .7531 .16048 L p .311 .532 .906 r
F P
0 g
s
.7531 .16048 m .76222 .17654 L .74391 .16747 L p .311 .532 .906 r
F P
0 g
s
.09007 .45503 m .08045 .46593 L .07942 .45057 L p .987 .847 .615 r
F P
0 g
s
.07942 .45057 m .08876 .43464 L .09007 .45503 L p .987 .847 .615 r
F P
0 g
s
.66602 .8775 m .68027 .88038 L .66749 .88895 L p .397 .005 .174 r
F P
0 g
s
.66749 .88895 m .64901 .88882 L .66602 .8775 L p .397 .005 .174 r
F P
0 g
s
.1004 .39266 m .08698 .41676 L .08478 .4022 L p .98 .891 .662 r
F P
0 g
s
.08478 .4022 m .09772 .37344 L .1004 .39266 L p .98 .891 .662 r
F P
0 g
s
.60684 .89973 m .63442 .8993 L .62291 .90849 L p .433 .005 .124 r
F P
0 g
s
.62291 .90849 m .59153 .91166 L .60684 .89973 L p .433 .005 .124 r
F P
0 g
s
.82969 .75202 m .81074 .7851 L .79276 .79239 L p .286 .021 .325 r
F P
0 g
s
.7786 .81606 m .79276 .79239 L .81074 .7851 L p .24 0 .235 r
F P
0 g
s
.79276 .79239 m .7786 .81606 L .76222 .82346 L p .313 .012 .284 r
F P
0 g
s
.55341 .08847 m .59153 .08834 L .60684 .10027 L p .51 .734 .975 r
F P
0 g
s
.63442 .1007 m .60684 .10027 L .59153 .08834 L p .433 .702 .978 r
F P
0 g
s
.60684 .10027 m .63442 .1007 L .64901 .11118 L p .458 .686 .964 r
F P
0 g
s
.79276 .20761 m .7786 .18394 L .79231 .18931 L p .24 .454 .867 r
F P
0 g
s
.79231 .18931 m .81074 .2149 L .79276 .20761 L p .24 .454 .867 r
F P
0 g
s
.1169 .65951 m .09772 .62656 L .1004 .60734 L p .96 .678 .456 r
F P
0 g
s
.08698 .58324 m .1004 .60734 L .09772 .62656 L p .98 .709 .44 r
F P
0 g
s
.1004 .60734 m .08698 .58324 L .08876 .56536 L p .975 .727 .498 r
F P
0 g
s
.55341 .91153 m .59153 .91166 L .58093 .92143 L p .468 .01 .081 r
F P
0 g
s
.58093 .92143 m .53919 .92397 L .55341 .91153 L p .468 .01 .081 r
F P
0 g
s
.82969 .24798 m .81074 .2149 L .82451 .2192 L p .177 .379 .824 r
F P
0 g
s
.82451 .2192 m .84757 .25407 L .82969 .24798 L p .177 .379 .824 r
F P
0 g
s
.1169 .34049 m .09772 .37344 L .09457 .35937 L p .965 .925 .705 r
F P
0 g
s
.09457 .35937 m .11324 .32196 L .1169 .34049 L p .965 .925 .705 r
F P
0 g
s
.14052 .71955 m .11324 .67804 L .1169 .65951 L p .941 .61 .374 r
F P
0 g
s
.09772 .62656 m .1169 .65951 L .11324 .67804 L p .965 .651 .369 r
F P
0 g
s
.48961 .07891 m .53919 .07603 L .55341 .08847 L p .551 .793 .989 r
F P
0 g
s
.59153 .08834 m .55341 .08847 L .53919 .07603 L p .468 .754 .992 r
F P
0 g
s
.86987 .70154 m .84757 .74593 L .82969 .75202 L p .214 0 .343 r
F P
0 g
s
.81074 .7851 m .82969 .75202 L .84757 .74593 L p .177 0 .249 r
F P
0 g
s
.64901 .88882 m .66749 .88895 L .6566 .89685 L p .383 0 .124 r
F P
0 g
s
.6566 .89685 m .63442 .8993 L .64901 .88882 L p .383 0 .124 r
F P
0 g
s
.76222 .17654 m .7531 .16048 L .76538 .16595 L p .261 .499 .895 r
F P
0 g
s
.76538 .16595 m .7786 .18394 L .76222 .17654 L p .261 .499 .895 r
F P
0 g
s
.08876 .43464 m .07942 .45057 L .07802 .4372 L p .99 .866 .615 r
F P
0 g
s
.07802 .4372 m .08698 .41676 L .08876 .43464 L p .99 .866 .615 r
F P
0 g
s
.7531 .83952 m .76222 .82346 L .7786 .81606 L p .261 0 .194 r
F P
0 g
s
.76222 .82346 m .7531 .83952 L .73928 .84631 L p .311 0 .224 r
F P
0 g
s
.66749 .11105 m .64901 .11118 L .63442 .1007 L p .383 .657 .966 r
F P
0 g
s
.64901 .11118 m .66749 .11105 L .68027 .11962 L p .397 .643 .956 r
F P
0 g
s
.07942 .54943 m .08876 .56536 L .08698 .58324 L p .99 .751 .474 r
F P
0 g
s
.08876 .56536 m .07942 .54943 L .08045 .53407 L p .987 .765 .515 r
F P
0 g
s
.14052 .71955 m .17888 .76299 L .17424 .78207 L p .9 .492 .212 r
F P
0 g
s
.88832 .3534 m .86987 .29846 L .88479 .30165 L p .056 .201 .699 r
F P
0 g
s
.88479 .30165 m .90716 .35891 L .88832 .3534 L p .056 .201 .699 r
F P
0 g
s
.48961 .07891 m .4328 .09041 L .4186 .07685 L p .571 .864 .996 r
F P
0 g
s
.86987 .70154 m .88832 .6466 L .90716 .64109 L p .056 0 .319 r
F P
0 g
s
.17888 .23701 m .14052 .28045 L .13583 .26593 L p .9 .977 .806 r
F P
0 g
s
.13583 .26593 m .17424 .21793 L .17888 .23701 L p .9 .977 .806 r
F P
0 g
s
.4328 .90959 m .48961 .92109 L .47938 .93241 L p .571 .069 .022 r
F P
0 g
s
.47938 .93241 m .4186 .92315 L .4328 .90959 L p .571 .069 .022 r
F P
0 g
s
.71268 .13163 m .70935 .13739 L .69441 .12852 L p .323 .588 .939 r
F P
0 g
s
.70935 .13739 m .71268 .13163 L .72384 .13788 L p .309 .569 .931 r
F P
0 g
s
.72384 .13788 m .72451 .14589 L .70935 .13739 L p .309 .569 .931 r
F P
0 g
s
.71268 .86837 m .70935 .86261 L .72451 .85411 L p .309 0 .155 r
F P
0 g
s
.70935 .86261 m .71268 .86837 L .70169 .87491 L p .323 0 .146 r
F P
0 g
s
.70169 .87491 m .69441 .87148 L .70935 .86261 L p .323 0 .146 r
F P
0 g
s
.07464 .5 m .0813 .5 L .08108 .51737 L p .996 .806 .535 r
F P
0 g
s
.0813 .5 m .07464 .5 L .07448 .48721 L p .996 .82 .551 r
F P
0 g
s
.07448 .48721 m .08108 .48263 L .0813 .5 L p .996 .82 .551 r
F P
0 g
s
.07448 .51279 m .08108 .51737 L .08045 .53407 L p .996 .793 .512 r
F P
0 g
s
.08108 .51737 m .07448 .51279 L .07464 .5 L p .996 .806 .535 r
F P
0 g
s
.70169 .12509 m .69441 .12852 L .68027 .11962 L p .328 .603 .947 r
F P
0 g
s
.69441 .12852 m .70169 .12509 L .71268 .13163 L p .323 .588 .939 r
F P
0 g
s
.72384 .86212 m .72451 .85411 L .73928 .84631 L p .286 0 .151 r
F P
0 g
s
.72451 .85411 m .72384 .86212 L .71268 .86837 L p .309 0 .155 r
F P
0 g
s
.69441 .87148 m .70169 .87491 L .6913 .88146 L p .328 0 .127 r
F P
0 g
s
.6913 .88146 m .68027 .88038 L .69441 .87148 L p .328 0 .127 r
F P
0 g
s
.72451 .14589 m .72384 .13788 L .7347 .1436 L p .286 .548 .923 r
F P
0 g
s
.7347 .1436 m .73928 .15369 L .72451 .14589 L p .286 .548 .923 r
F P
0 g
s
.08108 .48263 m .07448 .48721 L .074 .47494 L p .996 .834 .561 r
F P
0 g
s
.074 .47494 m .08045 .46593 L .08108 .48263 L p .996 .834 .561 r
F P
0 g
s
.08045 .46593 m .074 .47494 L .07322 .4637 L p .997 .847 .565 r
F P
0 g
s
.07322 .4637 m .07942 .45057 L .08045 .46593 L p .997 .847 .565 r
F P
0 g
s
.68027 .88038 m .6913 .88146 L .68195 .88775 L p .324 0 .095 r
F P
0 g
s
.68195 .88775 m .66749 .88895 L .68027 .88038 L p .324 0 .095 r
F P
0 g
s
.6913 .11854 m .68027 .11962 L .66749 .11105 L p .324 .615 .954 r
F P
0 g
s
.68027 .11962 m .6913 .11854 L .70169 .12509 L p .328 .603 .947 r
F P
0 g
s
.73928 .15369 m .7347 .1436 L .74483 .14855 L p .253 .524 .913 r
F P
0 g
s
.74483 .14855 m .7531 .16048 L .73928 .15369 L p .253 .524 .913 r
F P
0 g
s
.7347 .8564 m .73928 .84631 L .7531 .83952 L p .253 0 .136 r
F P
0 g
s
.73928 .84631 m .7347 .8564 L .72384 .86212 L p .286 0 .151 r
F P
0 g
s
.074 .52506 m .08045 .53407 L .07942 .54943 L p .997 .781 .483 r
F P
0 g
s
.08045 .53407 m .074 .52506 L .07448 .51279 L p .996 .793 .512 r
F P
0 g
s
.63442 .8993 m .6566 .89685 L .64811 .90374 L p .354 0 .054 r
F P
0 g
s
.64811 .90374 m .62291 .90849 L .63442 .8993 L p .354 0 .054 r
F P
0 g
s
.7786 .18394 m .76538 .16595 L .77559 .16986 L p .195 .459 .881 r
F P
0 g
s
.77559 .16986 m .79231 .18931 L .7786 .18394 L p .195 .459 .881 r
F P
0 g
s
.59153 .08834 m .62291 .09151 L .63442 .1007 L p .433 .702 .978 r
F P
0 g
s
.6566 .10315 m .63442 .1007 L .62291 .09151 L p .354 .664 .973 r
F P
0 g
s
.63442 .1007 m .6566 .10315 L .66749 .11105 L p .383 .657 .966 r
F P
0 g
s
.81074 .7851 m .79231 .81069 L .7786 .81606 L p .24 0 .235 r
F P
0 g
s
.76538 .83405 m .7786 .81606 L .79231 .81069 L p .195 0 .146 r
F P
0 g
s
.7786 .81606 m .76538 .83405 L .7531 .83952 L p .261 0 .194 r
F P
0 g
s
.08698 .41676 m .07802 .4372 L .0763 .4264 L p .991 .884 .605 r
F P
0 g
s
.0763 .4264 m .08478 .4022 L .08698 .41676 L p .991 .884 .605 r
F P
0 g
s
.09772 .62656 m .08478 .5978 L .08698 .58324 L p .98 .709 .44 r
F P
0 g
s
.07802 .5628 m .08698 .58324 L .08478 .5978 L p .991 .734 .422 r
F P
0 g
s
.08698 .58324 m .07802 .5628 L .07942 .54943 L p .99 .751 .474 r
F P
0 g
s
.84757 .74593 m .82451 .7808 L .81074 .7851 L p .177 0 .249 r
F P
0 g
s
.79231 .81069 m .81074 .7851 L .82451 .7808 L p .142 0 .159 r
F P
0 g
s
.81074 .2149 m .79231 .18931 L .80268 .19235 L p .142 .396 .846 r
F P
0 g
s
.80268 .19235 m .82451 .2192 L .81074 .2149 L p .142 .396 .846 r
F P
0 g
s
.59153 .91166 m .62291 .90849 L .61509 .91595 L p .385 0 .019 r
F P
0 g
s
.61509 .91595 m .58093 .92143 L .59153 .91166 L p .385 0 .019 r
F P
0 g
s
.53919 .07603 m .58093 .07857 L .59153 .08834 L p .468 .754 .992 r
F P
0 g
s
.62291 .09151 m .59153 .08834 L .58093 .07857 L p .385 .709 .986 r
F P
0 g
s
.11324 .67804 m .09457 .64063 L .09772 .62656 L p .965 .651 .369 r
F P
0 g
s
.08478 .5978 m .09772 .62656 L .09457 .64063 L p .98 .686 .362 r
F P
0 g
s
.09772 .37344 m .08478 .4022 L .08223 .3917 L p .98 .915 .643 r
F P
0 g
s
.08223 .3917 m .09457 .35937 L .09772 .37344 L p .98 .915 .643 r
F P
0 g
s
.86987 .29846 m .84757 .25407 L .85909 .25586 L p .035 .244 .745 r
F P
0 g
s
.85909 .25586 m .88479 .30165 L .86987 .29846 L p .035 .244 .745 r
F P
0 g
s
.48961 .92109 m .53919 .92397 L .53189 .93305 L p .476 0 0 r
F P
0 g
s
.53189 .93305 m .47938 .93241 L .48961 .92109 L p .476 0 0 r
F P
0 g
s
.14052 .28045 m .11324 .32196 L .10902 .31109 L p .933 .969 .735 r
F P
0 g
s
.10902 .31109 m .13583 .26593 L .14052 .28045 L p .933 .969 .735 r
F P
0 g
s
.17424 .78207 m .13583 .73407 L .14052 .71955 L p .9 .492 .212 r
F P
0 g
s
.11324 .67804 m .14052 .71955 L .13583 .73407 L p .933 .554 .227 r
F P
0 g
s
.4186 .07685 m .47938 .06759 L .48961 .07891 L p .571 .864 .996 r
F P
0 g
s
.53919 .07603 m .48961 .07891 L .47938 .06759 L p .476 .811 .999 r
F P
0 g
s
.90716 .64109 m .88479 .69835 L .86987 .70154 L p .056 0 .319 r
F P
0 g
s
.84757 .74593 m .86987 .70154 L .88479 .69835 L p .035 0 .217 r
F P
0 g
s
.66749 .88895 m .68195 .88775 L .67404 .89354 L p .308 0 .05 r
F P
0 g
s
.67404 .89354 m .6566 .89685 L .66749 .88895 L p .308 0 .05 r
F P
0 g
s
.07942 .45057 m .07322 .4637 L .07217 .45395 L p .997 .86 .562 r
F P
0 g
s
.07217 .45395 m .07802 .4372 L .07942 .45057 L p .997 .86 .562 r
F P
0 g
s
.7531 .16048 m .74483 .14855 L .7538 .15251 L p .209 .495 .902 r
F P
0 g
s
.7538 .15251 m .76538 .16595 L .7531 .16048 L p .209 .495 .902 r
F P
0 g
s
.74483 .85145 m .7531 .83952 L .76538 .83405 L p .209 0 .107 r
F P
0 g
s
.7531 .83952 m .74483 .85145 L .7347 .8564 L p .253 0 .136 r
F P
0 g
s
.68195 .11225 m .66749 .11105 L .6566 .10315 L p .308 .623 .959 r
F P
0 g
s
.66749 .11105 m .68195 .11225 L .6913 .11854 L p .324 .615 .954 r
F P
0 g
s
.07322 .5363 m .07942 .54943 L .07802 .5628 L p .997 .767 .447 r
F P
0 g
s
.07942 .54943 m .07322 .5363 L .074 .52506 L p .997 .781 .483 r
F P
0 g
s
.71489 .12779 m .71268 .13163 L .70169 .12509 L p .255 .565 .936 r
F P
0 g
s
.71268 .13163 m .71489 .12779 L .72284 .13225 L p .244 .55 .93 r
F P
0 g
s
.72284 .13225 m .72384 .13788 L .71268 .13163 L p .244 .55 .93 r
F P
0 g
s
.71489 .87221 m .71268 .86837 L .72384 .86212 L p .244 0 .069 r
F P
0 g
s
.71268 .86837 m .71489 .87221 L .70706 .87686 L p .255 0 .063 r
F P
0 g
s
.70706 .87686 m .70169 .87491 L .71268 .86837 L p .255 0 .063 r
F P
0 g
s
.07021 .5 m .07464 .5 L .07448 .51279 L p 1 .811 .493 r
F P
0 g
s
.07464 .5 m .07021 .5 L .0701 .49089 L p 1 .822 .506 r
F P
0 g
s
.0701 .49089 m .07448 .48721 L .07464 .5 L p 1 .822 .506 r
F P
0 g
s
.14085 .36928 m .14753 .46656 L .13475 .46535 L p .92 .715 .223 r
F P
0 g
s
.7052 .78853 m .79278 .74567 L .80306 .7543 L p 0 0 0 r
F P
0 g
s
.80306 .7543 m .71264 .79899 L .7052 .78853 L p 0 0 0 r
F P
0 g
s
.14753 .53344 m .14085 .63072 L .12823 .63531 L p .92 .787 .31 r
F P
0 g
s
.12823 .63531 m .13475 .53465 L .14753 .53344 L p .92 .787 .31 r
F P
0 g
s
.79278 .25433 m .7052 .21147 L .71264 .20101 L p 0 .461 .854 r
F P
0 g
s
.56637 .87639 m .64727 .82197 L .65262 .83365 L p 0 0 0 r
F P
0 g
s
.64727 .17803 m .56637 .12361 L .5687 .11039 L p 0 .364 .811 r
F P
0 g
s
.5687 .11039 m .65262 .16635 L .64727 .17803 L p 0 .364 .811 r
F P
0 g
s
.52752 .76571 m .61101 .79567 L .61502 .80636 L p .421 0 0 r
F P
0 g
s
.72392 .66217 m .70781 .75279 L .70056 .74397 L p 0 0 .07 r
F P
0 g
s
.70056 .74397 m .71635 .65669 L .72392 .66217 L p 0 0 .07 r
F P
0 g
s
.25613 .39098 m .18843 .4483 L .17717 .44643 L p .63 .939 .711 r
F P
0 g
s
.24759 .61284 m .17717 .55357 L .18843 .5517 L p .63 .089 0 r
F P
0 g
s
.18843 .5517 m .25613 .60902 L .24759 .61284 L p .63 .089 0 r
F P
0 g
s
.71635 .34331 m .70056 .25603 L .70781 .24721 L p 0 0 .311 r
F P
0 g
s
.52848 .22499 m .61502 .19364 L .61101 .20433 L p .421 .867 .831 r
F P
0 g
s
.61101 .20433 m .52752 .23429 L .52848 .22499 L p .421 .867 .831 r
F P
0 g
s
.07448 .48721 m .0701 .49089 L .06975 .48216 L p 1 .832 .513 r
F P
0 g
s
.06975 .48216 m .074 .47494 L .07448 .48721 L p 1 .832 .513 r
F P
0 g
s
.72384 .13788 m .72284 .13225 L .73058 .13631 L p .224 .533 .922 r
F P
0 g
s
.73058 .13631 m .7347 .1436 L .72384 .13788 L p .224 .533 .922 r
F P
0 g
s
.70169 .87491 m .70706 .87686 L .69967 .88153 L p .258 0 .046 r
F P
0 g
s
.69967 .88153 m .6913 .88146 L .70169 .87491 L p .258 0 .046 r
F P
0 g
s
.72284 .86775 m .72384 .86212 L .7347 .8564 L p .224 0 .065 r
F P
0 g
s
.72384 .86212 m .72284 .86775 L .71489 .87221 L p .244 0 .069 r
F P
0 g
s
.70706 .12314 m .70169 .12509 L .6913 .11854 L p .258 .576 .941 r
F P
0 g
s
.70169 .12509 m .70706 .12314 L .71489 .12779 L p .255 .565 .936 r
F P
0 g
s
.0701 .50911 m .07448 .51279 L .074 .52506 L p 1 .8 .474 r
F P
0 g
s
.07448 .51279 m .0701 .50911 L .07021 .5 L p 1 .811 .493 r
F P
0 g
s
.65262 .83365 m .5687 .88961 L .56637 .87639 L p 0 0 0 r
F P
0 g
s
.47225 .90076 m .56637 .87639 L .5687 .88961 L p .127 0 0 r
F P
0 g
s
.14085 .63072 m .16681 .72441 L .15588 .73177 L p .909 .599 .111 r
F P
0 g
s
.15588 .73177 m .12823 .63531 L .14085 .63072 L p .909 .599 .111 r
F P
0 g
s
.79278 .74567 m .86094 .67635 L .87277 .68213 L p 0 0 0 r
F P
0 g
s
.87277 .68213 m .80306 .7543 L .79278 .74567 L p 0 0 0 r
F P
0 g
s
.13475 .46535 m .12823 .36469 L .14085 .36928 L p .92 .715 .223 r
F P
0 g
s
.16681 .27559 m .14085 .36928 L .12823 .36469 L p .909 .885 .462 r
F P
0 g
s
.71264 .20101 m .80306 .2457 L .79278 .25433 L p 0 .461 .854 r
F P
0 g
s
.86094 .32365 m .79278 .25433 L .80306 .2457 L p 0 .224 .738 r
F P
0 g
s
.56637 .12361 m .47225 .09924 L .47134 .0861 L p .127 .615 .913 r
F P
0 g
s
.47134 .0861 m .5687 .11039 L .56637 .12361 L p .127 .615 .913 r
F P
0 g
s
.32976 .63286 m .24759 .61284 L .25613 .60902 L p .298 0 0 r
F P
0 g
s
.25613 .60902 m .33524 .62858 L .32976 .63286 L p .298 0 0 r
F P
0 g
s
.70018 .581 m .72392 .66217 L .71635 .65669 L p 0 0 .326 r
F P
0 g
s
.71635 .65669 m .69373 .57839 L .70018 .581 L p 0 0 .326 r
F P
0 g
s
.33524 .37142 m .25613 .39098 L .24759 .38716 L p .298 .794 .807 r
F P
0 g
s
.17717 .44643 m .24759 .38716 L .25613 .39098 L p .63 .939 .711 r
F P
0 g
s
.47102 .70697 m .52752 .76571 L .52848 .77501 L p .634 .125 0 r
F P
0 g
s
.61502 .80636 m .52848 .77501 L .52752 .76571 L p .421 0 0 r
F P
0 g
s
.47006 .28614 m .52848 .22499 L .52752 .23429 L p .634 .91 .613 r
F P
0 g
s
.52752 .23429 m .47102 .29303 L .47006 .28614 L p .634 .91 .613 r
F P
0 g
s
.69373 .42161 m .71635 .34331 L .72392 .33783 L p 0 0 0 r
F P
0 g
s
.70781 .24721 m .72392 .33783 L .71635 .34331 L p 0 0 .311 r
F P
0 g
s
.47938 .06759 m .53189 .06695 L .53919 .07603 L p .476 .811 .999 r
F P
0 g
s
.58093 .07857 m .53919 .07603 L .53189 .06695 L p .386 .755 .992 r
F P
0 g
s
.84757 .25407 m .82451 .2192 L .83321 .22016 L p .021 .285 .781 r
F P
0 g
s
.83321 .22016 m .85909 .25586 L .84757 .25407 L p .021 .285 .781 r
F P
0 g
s
.53919 .92397 m .58093 .92143 L .57574 .92849 L p .386 0 0 r
F P
0 g
s
.57574 .92849 m .53189 .93305 L .53919 .92397 L p .386 0 0 r
F P
0 g
s
.11324 .32196 m .09457 .35937 L .09105 .35135 L p .953 .951 .664 r
F P
0 g
s
.09105 .35135 m .10902 .31109 L .11324 .32196 L p .953 .951 .664 r
F P
0 g
s
.13583 .73407 m .10902 .68891 L .11324 .67804 L p .933 .554 .227 r
F P
0 g
s
.09457 .64063 m .11324 .67804 L .10902 .68891 L p .953 .606 .243 r
F P
0 g
s
.88479 .69835 m .85909 .74414 L .84757 .74593 L p .035 0 .217 r
F P
0 g
s
.82451 .7808 m .84757 .74593 L .85909 .74414 L p .021 0 .126 r
F P
0 g
s
.82451 .7808 m .80268 .80765 L .79231 .81069 L p .142 0 .159 r
F P
0 g
s
.77559 .83014 m .79231 .81069 L .80268 .80765 L p .111 0 .076 r
F P
0 g
s
.79231 .81069 m .77559 .83014 L .76538 .83405 L p .195 0 .146 r
F P
0 g
s
.09457 .64063 m .08223 .6083 L .08478 .5978 L p .98 .686 .362 r
F P
0 g
s
.0763 .5736 m .08478 .5978 L .08223 .6083 L p .986 .713 .355 r
F P
0 g
s
.08478 .5978 m .0763 .5736 L .07802 .5628 L p .991 .734 .422 r
F P
0 g
s
.58093 .07857 m .61509 .08405 L .62291 .09151 L p .385 .709 .986 r
F P
0 g
s
.64811 .09626 m .62291 .09151 L .61509 .08405 L p .307 .663 .973 r
F P
0 g
s
.62291 .09151 m .64811 .09626 L .6566 .10315 L p .354 .664 .973 r
F P
0 g
s
.62291 .90849 m .64811 .90374 L .64243 .90929 L p .307 0 0 r
F P
0 g
s
.64243 .90929 m .61509 .91595 L .62291 .90849 L p .307 0 0 r
F P
0 g
s
.79231 .18931 m .77559 .16986 L .78324 .17201 L p .111 .411 .86 r
F P
0 g
s
.78324 .17201 m .80268 .19235 L .79231 .18931 L p .111 .411 .86 r
F P
0 g
s
.08478 .4022 m .0763 .4264 L .07433 .4187 L p .986 .897 .581 r
F P
0 g
s
.07433 .4187 m .08223 .3917 L .08478 .4022 L p .986 .897 .581 r
F P
0 g
s
.07217 .54605 m .07802 .5628 L .0763 .5736 L p .994 .752 .402 r
F P
0 g
s
.07802 .5628 m .07217 .54605 L .07322 .5363 L p .997 .767 .447 r
F P
0 g
s
.67404 .10646 m .6566 .10315 L .64811 .09626 L p .279 .624 .961 r
F P
0 g
s
.6566 .10315 m .67404 .10646 L .68195 .11225 L p .308 .623 .959 r
F P
0 g
s
.07802 .4372 m .07217 .45395 L .07089 .44613 L p .994 .871 .548 r
F P
0 g
s
.07089 .44613 m .0763 .4264 L .07802 .4372 L p .994 .871 .548 r
F P
0 g
s
.6566 .89685 m .67404 .89354 L .6679 .89856 L p .279 0 0 r
F P
0 g
s
.6679 .89856 m .64811 .90374 L .6566 .89685 L p .279 0 0 r
F P
0 g
s
.7538 .84749 m .76538 .83405 L .77559 .83014 L p .153 0 .063 r
F P
0 g
s
.76538 .83405 m .7538 .84749 L .74483 .85145 L p .209 0 .107 r
F P
0 g
s
.76538 .16595 m .7538 .15251 L .76121 .15531 L p .153 .462 .888 r
F P
0 g
s
.76121 .15531 m .77559 .16986 L .76538 .16595 L p .153 .462 .888 r
F P
0 g
s
.074 .47494 m .06975 .48216 L .06919 .47417 L p .998 .841 .514 r
F P
0 g
s
.06919 .47417 m .07322 .4637 L .074 .47494 L p .998 .841 .514 r
F P
0 g
s
.7347 .1436 m .73058 .13631 L .73778 .13982 L p .196 .512 .913 r
F P
0 g
s
.73778 .13982 m .74483 .14855 L .7347 .1436 L p .196 .512 .913 r
F P
0 g
s
.69967 .11847 m .6913 .11854 L .68195 .11225 L p .252 .584 .945 r
F P
0 g
s
.6913 .11854 m .69967 .11847 L .70706 .12314 L p .258 .576 .941 r
F P
0 g
s
.6913 .88146 m .69967 .88153 L .69304 .88601 L p .252 0 .019 r
F P
0 g
s
.69304 .88601 m .68195 .88775 L .6913 .88146 L p .252 0 .019 r
F P
0 g
s
.73058 .86369 m .7347 .8564 L .74483 .85145 L p .196 0 .051 r
F P
0 g
s
.7347 .8564 m .73058 .86369 L .72284 .86775 L p .224 0 .065 r
F P
0 g
s
.06975 .51784 m .074 .52506 L .07322 .5363 L p .998 .789 .45 r
F P
0 g
s
.074 .52506 m .06975 .51784 L .0701 .50911 L p 1 .8 .474 r
F P
0 g
s
.40427 .61343 m .32976 .63286 L .33524 .62858 L p 0 0 0 r
F P
0 g
s
.33524 .62858 m .4072 .60996 L .40427 .61343 L p 0 0 0 r
F P
0 g
s
.6461 .52619 m .70018 .581 L .69373 .57839 L p 0 .049 .562 r
F P
0 g
s
.69373 .57839 m .64163 .52539 L .6461 .52619 L p 0 .049 .562 r
F P
0 g
s
.45117 .63535 m .47102 .70697 L .47006 .71386 L p .746 .456 0 r
F P
0 g
s
.52848 .77501 m .47006 .71386 L .47102 .70697 L p .634 .125 0 r
F P
0 g
s
.4072 .39004 m .33524 .37142 L .32976 .36714 L p 0 .467 .749 r
F P
0 g
s
.24759 .38716 m .32976 .36714 L .33524 .37142 L p .298 .794 .807 r
F P
0 g
s
.44963 .36038 m .47006 .28614 L .47102 .29303 L p .746 .762 .255 r
F P
0 g
s
.47102 .29303 m .45117 .36465 L .44963 .36038 L p .746 .762 .255 r
F P
0 g
s
.64163 .47461 m .69373 .42161 L .70018 .419 L p 0 0 0 r
F P
0 g
s
.72392 .33783 m .70018 .419 L .69373 .42161 L p 0 0 0 r
F P
0 g
s
.5687 .88961 m .47134 .9139 L .47225 .90076 L p .127 0 0 r
F P
0 g
s
.37867 .89642 m .47225 .90076 L .47134 .9139 L p .333 0 0 r
F P
0 g
s
.16681 .72441 m .21736 .80329 L .209 .81225 L p .836 .397 0 r
F P
0 g
s
.209 .81225 m .15588 .73177 L .16681 .72441 L p .836 .397 0 r
F P
0 g
s
.86094 .67635 m .90397 .59313 L .91592 .59589 L p 0 0 .008 r
F P
0 g
s
.91592 .59589 m .87277 .68213 L .86094 .67635 L p 0 0 .008 r
F P
0 g
s
.80306 .2457 m .87277 .31787 L .86094 .32365 L p 0 .224 .738 r
F P
0 g
s
.90397 .40687 m .86094 .32365 L .87277 .31787 L p 0 .015 .59 r
F P
0 g
s
.12823 .36469 m .15588 .26823 L .16681 .27559 L p .909 .885 .462 r
F P
0 g
s
.21736 .19671 m .16681 .27559 L .15588 .26823 L p .836 .968 .648 r
F P
0 g
s
.47225 .09924 m .37867 .10358 L .37508 .09186 L p .333 .794 .939 r
F P
0 g
s
.37508 .09186 m .47134 .0861 L .47225 .09924 L p .333 .794 .939 r
F P
0 g
s
.57805 .50716 m .6461 .52619 L .64163 .52539 L p 0 .41 .692 r
F P
0 g
s
.64163 .52539 m .57575 .50695 L .57805 .50716 L p 0 .41 .692 r
F P
0 g
s
.46814 .56908 m .45117 .63535 L .44963 .63962 L p .696 .712 .187 r
F P
0 g
s
.47006 .71386 m .44963 .63962 L .45117 .63535 L p .746 .456 0 r
F P
0 g
s
.45477 .56402 m .40427 .61343 L .4072 .60996 L p 0 0 0 r
F P
0 g
s
.4072 .60996 m .45611 .56213 L .45477 .56402 L p 0 0 0 r
F P
0 g
s
.45611 .43787 m .4072 .39004 L .40427 .38657 L p 0 .018 .517 r
F P
0 g
s
.32976 .36714 m .40427 .38657 L .4072 .39004 L p 0 .467 .749 r
F P
0 g
s
.46717 .42882 m .44963 .36038 L .45117 .36465 L p .696 .425 0 r
F P
0 g
s
.45117 .36465 m .46814 .43092 L .46717 .42882 L p .696 .425 0 r
F P
0 g
s
.57575 .49305 m .64163 .47461 L .6461 .47381 L p 0 0 0 r
F P
0 g
s
.70018 .419 m .6461 .47381 L .64163 .47461 L p 0 0 0 r
F P
0 g
s
.44963 .63962 m .46717 .57118 L .46814 .56908 L p .696 .712 .187 r
F P
0 g
s
.51348 .52338 m .46814 .56908 L .46717 .57118 L p 0 0 0 r
F P
0 g
s
.40427 .38657 m .45477 .43598 L .45611 .43787 L p 0 .018 .517 r
F P
0 g
s
.47301 .49998 m .45611 .43787 L .45477 .43598 L p .703 .423 0 r
F P
0 g
s
.51392 .52406 m .57805 .50716 L .57575 .50695 L p 0 0 0 r
F P
0 g
s
.57575 .50695 m .51351 .52336 L .51392 .52406 L p 0 0 0 r
F P
0 g
s
.4722 .50002 m .45477 .56402 L .45611 .56213 L p .703 .726 .207 r
F P
0 g
s
.45611 .56213 m .47301 .50002 L .4722 .50002 L p .703 .726 .207 r
F P
0 g
s
.6461 .47381 m .57805 .49284 L .57575 .49305 L p 0 0 0 r
F P
0 g
s
.51351 .47664 m .57575 .49305 L .57805 .49284 L p 0 .428 .705 r
F P
0 g
s
.51388 .47592 m .46717 .42882 L .46814 .43092 L p 0 .014 .519 r
F P
0 g
s
.46814 .43092 m .51348 .47662 L .51388 .47592 L p 0 .014 .519 r
F P
0 g
s
.46717 .57118 m .51388 .52408 L .51348 .52338 L p 0 0 0 r
F P
0 g
s
.45477 .43598 m .4722 .49998 L .47301 .49998 L p .703 .423 0 r
F P
0 g
s
.57805 .49284 m .51392 .47594 L .51351 .47664 L p 0 .428 .705 r
F P
0 g
s
.47134 .9139 m .37508 .90814 L .37867 .89642 L p .333 0 0 r
F P
0 g
s
.15588 .26823 m .209 .18775 L .21736 .19671 L p .836 .968 .648 r
F P
0 g
s
.87277 .31787 m .91592 .40411 L .90397 .40687 L p 0 .015 .59 r
F P
0 g
s
.73778 .86018 m .74483 .85145 L .7538 .84749 L p .16 0 .026 r
F P
0 g
s
.74483 .85145 m .73778 .86018 L .73058 .86369 L p .196 0 .051 r
F P
0 g
s
.69304 .11399 m .68195 .11225 L .67404 .10646 L p .237 .587 .947 r
F P
0 g
s
.68195 .11225 m .69304 .11399 L .69967 .11847 L p .252 .584 .945 r
F P
0 g
s
.07322 .4637 m .06919 .47417 L .06843 .46727 L p .996 .849 .508 r
F P
0 g
s
.06843 .46727 m .07217 .45395 L .07322 .4637 L p .996 .849 .508 r
F P
0 g
s
.74483 .14855 m .73778 .13982 L .74413 .14261 L p .16 .489 .902 r
F P
0 g
s
.74413 .14261 m .7538 .15251 L .74483 .14855 L p .16 .489 .902 r
F P
0 g
s
.06919 .52583 m .07322 .5363 L .07217 .54605 L p .996 .777 .42 r
F P
0 g
s
.07322 .5363 m .06919 .52583 L .06975 .51784 L p .998 .789 .45 r
F P
0 g
s
.68195 .88775 m .69304 .88601 L .68744 .89011 L p .237 0 0 r
F P
0 g
s
.68744 .89011 m .67404 .89354 L .68195 .88775 L p .237 0 0 r
F P
0 g
s
.82451 .2192 m .80268 .19235 L .80914 .19285 L p .012 .32 .808 r
F P
0 g
s
.80914 .19285 m .83321 .22016 L .82451 .2192 L p .012 .32 .808 r
F P
0 g
s
.58093 .92143 m .61509 .91595 L .61143 .9213 L p .305 0 0 r
F P
0 g
s
.61143 .9213 m .57574 .92849 L .58093 .92143 L p .305 0 0 r
F P
0 g
s
.53189 .06695 m .57574 .07151 L .58093 .07857 L p .386 .755 .992 r
F P
0 g
s
.61509 .08405 m .58093 .07857 L .57574 .07151 L p .305 .698 .977 r
F P
0 g
s
.85909 .74414 m .83321 .77984 L .82451 .7808 L p .021 0 .126 r
F P
0 g
s
.80268 .80765 m .82451 .7808 L .83321 .77984 L p .012 0 .046 r
F P
0 g
s
.10902 .68891 m .09105 .64865 L .09457 .64063 L p .953 .606 .243 r
F P
0 g
s
.08223 .6083 m .09457 .64063 L .09105 .64865 L p .965 .649 .258 r
F P
0 g
s
.09457 .35937 m .08223 .3917 L .07943 .38585 L p .965 .926 .597 r
F P
0 g
s
.07943 .38585 m .09105 .35135 L .09457 .35937 L p .965 .926 .597 r
F P
0 g
s
.71634 .12528 m .71489 .12779 L .70706 .12314 L p .191 .54 .927 r
F P
0 g
s
.71489 .12779 m .71634 .12528 L .72181 .12834 L p .182 .529 .922 r
F P
0 g
s
.72181 .12834 m .72284 .13225 L .71489 .12779 L p .182 .529 .922 r
F P
0 g
s
.71634 .87472 m .71489 .87221 L .72284 .86775 L p .182 0 0 r
F P
0 g
s
.71489 .87221 m .71634 .87472 L .71096 .87792 L p .191 0 0 r
F P
0 g
s
.71096 .87792 m .70706 .87686 L .71489 .87221 L p .191 0 0 r
F P
0 g
s
.06731 .5 m .07021 .5 L .0701 .50911 L p .996 .81 .452 r
F P
0 g
s
.07021 .5 m .06731 .5 L .06723 .49374 L p .996 .818 .461 r
F P
0 g
s
.06723 .49374 m .0701 .49089 L .07021 .5 L p .996 .818 .461 r
F P
0 g
s
.06723 .50626 m .0701 .50911 L .06975 .51784 L p .996 .801 .437 r
F P
0 g
s
.0701 .50911 m .06723 .50626 L .06731 .5 L p .996 .81 .452 r
F P
0 g
s
.72181 .87166 m .72284 .86775 L .73058 .86369 L p .167 0 0 r
F P
0 g
s
.72284 .86775 m .72181 .87166 L .71634 .87472 L p .182 0 0 r
F P
0 g
s
.72284 .13225 m .72181 .12834 L .72712 .13113 L p .167 .515 .915 r
F P
0 g
s
.72712 .13113 m .73058 .13631 L .72284 .13225 L p .167 .515 .915 r
F P
0 g
s
.71096 .12208 m .70706 .12314 L .69967 .11847 L p .192 .547 .93 r
F P
0 g
s
.70706 .12314 m .71096 .12208 L .71634 .12528 L p .191 .54 .927 r
F P
0 g
s
.70706 .87686 m .71096 .87792 L .70589 .88113 L p .192 0 0 r
F P
0 g
s
.70589 .88113 m .69967 .88153 L .70706 .87686 L p .192 0 0 r
F P
0 g
s
.0701 .49089 m .06723 .49374 L .06699 .48774 L p .996 .825 .466 r
F P
0 g
s
.06699 .48774 m .06975 .48216 L .0701 .49089 L p .996 .825 .466 r
F P
0 g
s
.80268 .80765 m .78324 .82799 L .77559 .83014 L p .111 0 .076 r
F P
0 g
s
.76121 .84469 m .77559 .83014 L .78324 .82799 L p .084 0 .003 r
F P
0 g
s
.77559 .83014 m .76121 .84469 L .7538 .84749 L p .153 0 .063 r
F P
0 g
s
.61509 .08405 m .64243 .09071 L .64811 .09626 L p .307 .663 .973 r
F P
0 g
s
.6679 .10144 m .64811 .09626 L .64243 .09071 L p .236 .618 .956 r
F P
0 g
s
.64811 .09626 m .6679 .10144 L .67404 .10646 L p .279 .624 .961 r
F P
0 g
s
.08223 .6083 m .07433 .5813 L .0763 .5736 L p .986 .713 .355 r
F P
0 g
s
.07089 .55387 m .0763 .5736 L .07433 .5813 L p .986 .733 .348 r
F P
0 g
s
.0763 .5736 m .07089 .55387 L .07217 .54605 L p .994 .752 .402 r
F P
0 g
s
.64811 .90374 m .6679 .89856 L .66385 .90258 L p .236 0 0 r
F P
0 g
s
.66385 .90258 m .64243 .90929 L .64811 .90374 L p .236 0 0 r
F P
0 g
s
.77559 .16986 m .76121 .15531 L .76672 .15681 L p .084 .422 .868 r
F P
0 g
s
.76672 .15681 m .78324 .17201 L .77559 .16986 L p .084 .422 .868 r
F P
0 g
s
.0763 .4264 m .07089 .44613 L .06943 .4406 L p .986 .876 .523 r
F P
0 g
s
.06943 .4406 m .07433 .4187 L .0763 .4264 L p .986 .876 .523 r
F P
0 g
s
.07217 .45395 m .06843 .46727 L .06751 .46176 L p .991 .854 .495 r
F P
0 g
s
.06751 .46176 m .07089 .44613 L .07217 .45395 L p .991 .854 .495 r
F P
0 g
s
.7538 .15251 m .74413 .14261 L .74936 .14457 L p .115 .461 .889 r
F P
0 g
s
.74936 .14457 m .76121 .15531 L .7538 .15251 L p .115 .461 .889 r
F P
0 g
s
.67404 .89354 m .68744 .89011 L .68313 .89366 L p .211 0 0 r
F P
0 g
s
.68313 .89366 m .6679 .89856 L .67404 .89354 L p .211 0 0 r
F P
0 g
s
.68744 .10989 m .67404 .10646 L .6679 .10144 L p .211 .585 .944 r
F P
0 g
s
.67404 .10646 m .68744 .10989 L .69304 .11399 L p .237 .587 .947 r
F P
0 g
s
.74413 .85739 m .7538 .84749 L .76121 .84469 L p .115 0 0 r
F P
0 g
s
.7538 .84749 m .74413 .85739 L .73778 .86018 L p .16 0 .026 r
F P
0 g
s
.06843 .53273 m .07217 .54605 L .07089 .55387 L p .991 .764 .384 r
F P
0 g
s
.07217 .54605 m .06843 .53273 L .06919 .52583 L p .996 .777 .42 r
F P
0 g
s
.69967 .88153 m .70589 .88113 L .70134 .8842 L p .187 0 0 r
F P
0 g
s
.70134 .8842 m .69304 .88601 L .69967 .88153 L p .187 0 0 r
F P
0 g
s
.73058 .13631 m .72712 .13113 L .73206 .13353 L p .145 .499 .908 r
F P
0 g
s
.73206 .13353 m .73778 .13982 L .73058 .13631 L p .145 .499 .908 r
F P
0 g
s
.06975 .48216 m .06699 .48774 L .0666 .48227 L p .993 .831 .466 r
F P
0 g
s
.0666 .48227 m .06919 .47417 L .06975 .48216 L p .993 .831 .466 r
F P
0 g
s
.72712 .86887 m .73058 .86369 L .73778 .86018 L p .145 0 0 r
F P
0 g
s
.73058 .86369 m .72712 .86887 L .72181 .87166 L p .167 0 0 r
F P
0 g
s
.70589 .11887 m .69967 .11847 L .69304 .11399 L p .187 .552 .931 r
F P
0 g
s
.69967 .11847 m .70589 .11887 L .71096 .12208 L p .192 .547 .93 r
F P
0 g
s
.06699 .51226 m .06975 .51784 L .06919 .52583 L p .993 .792 .418 r
F P
0 g
s
.06975 .51784 m .06699 .51226 L .06723 .50626 L p .996 .801 .437 r
F P
0 g
s
.17424 .78207 m .22686 .82922 L .22087 .83644 L p .741 .223 0 r
F P
0 g
s
.90716 .64109 m .92168 .57193 L .93093 .57351 L p 0 0 .176 r
F P
0 g
s
.4186 .07685 m .35146 .09885 L .3482 .09005 L p .504 .905 .918 r
F P
0 g
s
.22686 .17078 m .17424 .21793 L .16831 .2128 L p .741 .987 .781 r
F P
0 g
s
.16831 .2128 m .22087 .16356 L .22686 .17078 L p .741 .987 .781 r
F P
0 g
s
.92168 .42807 m .90716 .35891 L .91457 .35635 L p 0 0 .45 r
F P
0 g
s
.91457 .35635 m .93093 .42649 L .92168 .42807 L p 0 0 .45 r
F P
0 g
s
.35146 .90115 m .4186 .92315 L .41712 .93085 L p .504 0 0 r
F P
0 g
s
.41712 .93085 m .3482 .90995 L .35146 .90115 L p .504 0 0 r
F P
0 g
s
.0666 .51773 m .06919 .52583 L .06843 .53273 L p .99 .782 .394 r
F P
0 g
s
.06919 .52583 m .0666 .51773 L .06699 .51226 L p .993 .792 .418 r
F P
0 g
s
.73206 .86647 m .73778 .86018 L .74413 .85739 L p .117 0 0 r
F P
0 g
s
.73778 .86018 m .73206 .86647 L .72712 .86887 L p .145 0 0 r
F P
0 g
s
.70134 .1158 m .69304 .11399 L .68744 .10989 L p .174 .553 .931 r
F P
0 g
s
.69304 .11399 m .70134 .1158 L .70589 .11887 L p .187 .552 .931 r
F P
0 g
s
.73778 .13982 m .73206 .13353 L .7364 .13544 L p .117 .48 .898 r
F P
0 g
s
.7364 .13544 m .74413 .14261 L .73778 .13982 L p .117 .48 .898 r
F P
0 g
s
.69304 .88601 m .70134 .8842 L .69752 .88701 L p .174 0 0 r
F P
0 g
s
.69752 .88701 m .68744 .89011 L .69304 .88601 L p .174 0 0 r
F P
0 g
s
.06919 .47417 m .0666 .48227 L .06608 .47755 L p .99 .835 .459 r
F P
0 g
s
.06608 .47755 m .06843 .46727 L .06919 .47417 L p .99 .835 .459 r
F P
0 g
s
.61509 .91595 m .64243 .90929 L .63986 .91324 L p .235 0 0 r
F P
0 g
s
.63986 .91324 m .61143 .9213 L .61509 .91595 L p .235 0 0 r
F P
0 g
s
.80268 .19235 m .78324 .17201 L .78795 .17226 L p .006 .351 .827 r
F P
0 g
s
.78795 .17226 m .80914 .19285 L .80268 .19235 L p .006 .351 .827 r
F P
0 g
s
.57574 .07151 m .61143 .0787 L .61509 .08405 L p .305 .698 .977 r
F P
0 g
s
.64243 .09071 m .61509 .08405 L .61143 .0787 L p .235 .646 .959 r
F P
0 g
s
.08223 .3917 m .07433 .4187 L .07219 .4145 L p .969 .899 .535 r
F P
0 g
s
.07219 .4145 m .07943 .38585 L .08223 .3917 L p .969 .899 .535 r
F P
0 g
s
.83321 .77984 m .80914 .80715 L .80268 .80765 L p .012 0 .046 r
F P
0 g
s
.78324 .82799 m .80268 .80765 L .80914 .80715 L p .006 0 0 r
F P
0 g
s
.09105 .64865 m .07943 .61415 L .08223 .6083 L p .965 .649 .258 r
F P
0 g
s
.07433 .5813 m .08223 .6083 L .07943 .61415 L p .969 .683 .271 r
F P
0 g
s
.17424 .21793 m .13583 .26593 L .13046 .26248 L p .814 .983 .704 r
F P
0 g
s
.13046 .26248 m .16831 .2128 L .17424 .21793 L p .814 .983 .704 r
F P
0 g
s
.93093 .57351 m .91457 .64365 L .90716 .64109 L p 0 0 .176 r
F P
0 g
s
.88479 .69835 m .90716 .64109 L .91457 .64365 L p 0 0 .077 r
F P
0 g
s
.22087 .83644 m .16831 .7872 L .17424 .78207 L p .741 .223 0 r
F P
0 g
s
.13583 .73407 m .17424 .78207 L .16831 .7872 L p .814 .346 0 r
F P
0 g
s
.4186 .92315 m .47938 .93241 L .47907 .93879 L p .402 0 0 r
F P
0 g
s
.47907 .93879 m .41712 .93085 L .4186 .92315 L p .402 0 0 r
F P
0 g
s
.3482 .09005 m .41712 .06915 L .4186 .07685 L p .504 .905 .918 r
F P
0 g
s
.47938 .06759 m .4186 .07685 L .41712 .06915 L p .402 .841 .942 r
F P
0 g
s
.90716 .35891 m .88479 .30165 L .89047 .29873 L p 0 0 .552 r
F P
0 g
s
.89047 .29873 m .91457 .35635 L .90716 .35891 L p 0 0 .552 r
F P
0 g
s
.64243 .09071 m .66385 .09742 L .6679 .10144 L p .236 .618 .956 r
F P
0 g
s
.68313 .10634 m .6679 .10144 L .66385 .09742 L p .175 .576 .937 r
F P
0 g
s
.6679 .10144 m .68313 .10634 L .68744 .10989 L p .211 .585 .944 r
F P
0 g
s
.07433 .5813 m .06943 .5594 L .07089 .55387 L p .986 .733 .348 r
F P
0 g
s
.06751 .53824 m .07089 .55387 L .06943 .5594 L p .981 .748 .341 r
F P
0 g
s
.07089 .55387 m .06751 .53824 L .06843 .53273 L p .991 .764 .384 r
F P
0 g
s
.6679 .89856 m .68313 .89366 L .6803 .8965 L p .175 0 0 r
F P
0 g
s
.6803 .8965 m .66385 .90258 L .6679 .89856 L p .175 0 0 r
F P
0 g
s
.78324 .82799 m .76672 .84319 L .76121 .84469 L p .084 0 .003 r
F P
0 g
s
.74936 .85543 m .76121 .84469 L .76672 .84319 L p .062 0 0 r
F P
0 g
s
.76121 .84469 m .74936 .85543 L .74413 .85739 L p .115 0 0 r
F P
0 g
s
.76121 .15531 m .74936 .14457 L .75323 .1456 L p .062 .431 .872 r
F P
0 g
s
.75323 .1456 m .76672 .15681 L .76121 .15531 L p .062 .431 .872 r
F P
0 g
s
.07089 .44613 m .06751 .46176 L .06647 .45789 L p .981 .855 .471 r
F P
0 g
s
.06647 .45789 m .06943 .4406 L .07089 .44613 L p .981 .855 .471 r
F P
0 g
s
.06543 .5 m .06731 .5 L .06723 .50626 L p .988 .804 .414 r
F P
0 g
s
.06731 .5 m .06543 .5 L .06538 .49587 L p .988 .81 .421 r
F P
0 g
s
.06538 .49587 m .06723 .49374 L .06731 .5 L p .988 .81 .421 r
F P
0 g
s
.71728 .12365 m .71634 .12528 L .71096 .12208 L p .135 .515 .913 r
F P
0 g
s
.71634 .12528 m .71728 .12365 L .72088 .12567 L p .129 .508 .91 r
F P
0 g
s
.72088 .12567 m .72181 .12834 L .71634 .12528 L p .129 .508 .91 r
F P
0 g
s
.71728 .87635 m .71634 .87472 L .72181 .87166 L p .129 0 0 r
F P
0 g
s
.71634 .87472 m .71728 .87635 L .71374 .87846 L p .135 0 0 r
F P
0 g
s
.71374 .87846 m .71096 .87792 L .71634 .87472 L p .135 0 0 r
F P
0 g
s
.69752 .11299 m .68744 .10989 L .68313 .10634 L p .153 .55 .927 r
F P
0 g
s
.68744 .10989 m .69752 .11299 L .70134 .1158 L p .174 .553 .931 r
F P
0 g
s
.06843 .46727 m .06608 .47755 L .06545 .47379 L p .984 .836 .447 r
F P
0 g
s
.06545 .47379 m .06751 .46176 L .06843 .46727 L p .984 .836 .447 r
F P
0 g
s
.7364 .86456 m .74413 .85739 L .74936 .85543 L p .083 0 0 r
F P
0 g
s
.74413 .85739 m .7364 .86456 L .73206 .86647 L p .117 0 0 r
F P
0 g
s
.74413 .14261 m .7364 .13544 L .73997 .13677 L p .083 .46 .886 r
F P
0 g
s
.73997 .13677 m .74936 .14457 L .74413 .14261 L p .083 .46 .886 r
F P
0 g
s
.06608 .52245 m .06843 .53273 L .06751 .53824 L p .984 .77 .366 r
F P
0 g
s
.06843 .53273 m .06608 .52245 L .0666 .51773 L p .99 .782 .394 r
F P
0 g
s
.68744 .89011 m .69752 .88701 L .69458 .88944 L p .153 0 0 r
F P
0 g
s
.69458 .88944 m .68313 .89366 L .68744 .89011 L p .153 0 0 r
F P
0 g
s
.06538 .50413 m .06723 .50626 L .06699 .51226 L p .987 .798 .403 r
F P
0 g
s
.06723 .50626 m .06538 .50413 L .06543 .5 L p .988 .804 .414 r
F P
0 g
s
.71374 .12154 m .71096 .12208 L .70589 .11887 L p .136 .521 .915 r
F P
0 g
s
.71096 .12208 m .71374 .12154 L .71728 .12365 L p .135 .515 .913 r
F P
0 g
s
.72088 .87433 m .72181 .87166 L .72712 .86887 L p .118 0 0 r
F P
0 g
s
.72181 .87166 m .72088 .87433 L .71728 .87635 L p .129 0 0 r
F P
0 g
s
.71096 .87792 m .71374 .87846 L .7104 .88057 L p .136 0 0 r
F P
0 g
s
.7104 .88057 m .70589 .88113 L .71096 .87792 L p .136 0 0 r
F P
0 g
s
.72181 .12834 m .72088 .12567 L .72438 .12751 L p .118 .498 .905 r
F P
0 g
s
.72438 .12751 m .72712 .13113 L .72181 .12834 L p .118 .498 .905 r
F P
0 g
s
.06723 .49374 m .06538 .49587 L .06522 .49193 L p .987 .814 .424 r
F P
0 g
s
.06522 .49193 m .06699 .48774 L .06723 .49374 L p .987 .814 .424 r
F P
0 g
s
.7104 .11943 m .70589 .11887 L .70134 .1158 L p .131 .523 .916 r
F P
0 g
s
.70589 .11887 m .7104 .11943 L .71374 .12154 L p .136 .521 .915 r
F P
0 g
s
.72438 .87249 m .72712 .86887 L .73206 .86647 L p .102 0 0 r
F P
0 g
s
.72712 .86887 m .72438 .87249 L .72088 .87433 L p .118 0 0 r
F P
0 g
s
.06522 .50807 m .06699 .51226 L .0666 .51773 L p .985 .79 .389 r
F P
0 g
s
.06699 .51226 m .06522 .50807 L .06538 .50413 L p .987 .798 .403 r
F P
0 g
s
.72712 .13113 m .72438 .12751 L .72763 .12908 L p .102 .486 .899 r
F P
0 g
s
.72763 .12908 m .73206 .13353 L .72712 .13113 L p .102 .486 .899 r
F P
0 g
s
.70589 .88113 m .7104 .88057 L .70741 .88259 L p .131 0 0 r
F P
0 g
s
.70741 .88259 m .70134 .8842 L .70589 .88113 L p .131 0 0 r
F P
0 g
s
.06699 .48774 m .06522 .49193 L .06496 .48833 L p .985 .818 .423 r
F P
0 g
s
.06496 .48833 m .0666 .48227 L .06699 .48774 L p .985 .818 .423 r
F P
0 g
s
.61143 .0787 m .63986 .08676 L .64243 .09071 L p .235 .646 .959 r
F P
0 g
s
.66385 .09742 m .64243 .09071 L .63986 .08676 L p .176 .599 .94 r
F P
0 g
s
.80914 .80715 m .78795 .82774 L .78324 .82799 L p .006 0 0 r
F P
0 g
s
.76672 .84319 m .78324 .82799 L .78795 .82774 L p .003 0 0 r
F P
0 g
s
.78324 .17201 m .76672 .15681 L .77008 .15693 L p .003 .376 .84 r
F P
0 g
s
.77008 .15693 m .78795 .17226 L .78324 .17201 L p .003 .376 .84 r
F P
0 g
s
.07943 .61415 m .07219 .5855 L .07433 .5813 L p .969 .683 .271 r
F P
0 g
s
.06943 .5594 m .07433 .5813 L .07219 .5855 L p .969 .709 .283 r
F P
0 g
s
.64243 .90929 m .66385 .90258 L .66207 .90543 L p .176 0 0 r
F P
0 g
s
.66207 .90543 m .63986 .91324 L .64243 .90929 L p .176 0 0 r
F P
0 g
s
.07433 .4187 m .06943 .4406 L .06785 .43764 L p .969 .873 .482 r
F P
0 g
s
.06785 .43764 m .07219 .4145 L .07433 .4187 L p .969 .873 .482 r
F P
0 g
s
.91457 .64365 m .89047 .70127 L .88479 .69835 L p 0 0 .077 r
F P
0 g
s
.85909 .74414 m .88479 .69835 L .89047 .70127 L p 0 0 0 r
F P
0 g
s
.13583 .26593 m .10902 .31109 L .10444 .30887 L p .863 .963 .632 r
F P
0 g
s
.10444 .30887 m .13046 .26248 L .13583 .26593 L p .863 .963 .632 r
F P
0 g
s
.88479 .30165 m .85909 .25586 L .8633 .253 L p 0 .068 .632 r
F P
0 g
s
.8633 .253 m .89047 .29873 L .88479 .30165 L p 0 .068 .632 r
F P
0 g
s
.41712 .06915 m .47907 .06121 L .47938 .06759 L p .402 .841 .942 r
F P
0 g
s
.53189 .06695 m .47938 .06759 L .47907 .06121 L p .315 .774 .948 r
F P
0 g
s
.16831 .7872 m .13046 .73752 L .13583 .73407 L p .814 .346 0 r
F P
0 g
s
.10902 .68891 m .13583 .73407 L .13046 .73752 L p .863 .447 0 r
F P
0 g
s
.47938 .93241 m .53189 .93305 L .53226 .93812 L p .315 0 0 r
F P
0 g
s
.53226 .93812 m .47907 .93879 L .47938 .93241 L p .315 0 0 r
F P
0 g
s
.06496 .51167 m .0666 .51773 L .06608 .52245 L p .981 .782 .372 r
F P
0 g
s
.0666 .51773 m .06496 .51167 L .06522 .50807 L p .985 .79 .389 r
F P
0 g
s
.70741 .11741 m .70134 .1158 L .69752 .11299 L p .121 .523 .914 r
F P
0 g
s
.70134 .1158 m .70741 .11741 L .7104 .11943 L p .131 .523 .916 r
F P
0 g
s
.72763 .87092 m .73206 .86647 L .7364 .86456 L p .082 0 0 r
F P
0 g
s
.73206 .86647 m .72763 .87092 L .72438 .87249 L p .102 0 0 r
F P
0 g
s
.73206 .13353 m .72763 .12908 L .73049 .13033 L p .082 .472 .891 r
F P
0 g
s
.73049 .13033 m .7364 .13544 L .73206 .13353 L p .082 .472 .891 r
F P
0 g
s
.0666 .48227 m .06496 .48833 L .06462 .48523 L p .981 .82 .417 r
F P
0 g
s
.06462 .48523 m .06608 .47755 L .0666 .48227 L p .981 .82 .417 r
F P
0 g
s
.70134 .8842 m .70741 .88259 L .7049 .88444 L p .121 0 0 r
F P
0 g
s
.7049 .88444 m .69752 .88701 L .70134 .8842 L p .121 0 0 r
F P
0 g
s
.74936 .14457 m .73997 .13677 L .74261 .13746 L p .044 .437 .872 r
F P
0 g
s
.74261 .13746 m .75323 .1456 L .74936 .14457 L p .044 .437 .872 r
F P
0 g
s
.06751 .46176 m .06545 .47379 L .06473 .47117 L p .975 .834 .428 r
F P
0 g
s
.06473 .47117 m .06647 .45789 L .06751 .46176 L p .975 .834 .428 r
F P
0 g
s
.68313 .89366 m .69458 .88944 L .69267 .89137 L p .125 0 0 r
F P
0 g
s
.69267 .89137 m .6803 .8965 L .68313 .89366 L p .125 0 0 r
F P
0 g
s
.06943 .5594 m .06647 .54211 L .06751 .53824 L p .981 .748 .341 r
F P
0 g
s
.06545 .52621 m .06751 .53824 L .06647 .54211 L p .975 .758 .334 r
F P
0 g
s
.06751 .53824 m .06545 .52621 L .06608 .52245 L p .984 .77 .366 r
F P
0 g
s
.76672 .84319 m .75323 .8544 L .74936 .85543 L p .062 0 0 r
F P
0 g
s
.73997 .86323 m .74936 .85543 L .75323 .8544 L p .044 0 0 r
F P
0 g
s
.74936 .85543 m .73997 .86323 L .7364 .86456 L p .083 0 0 r
F P
0 g
s
.66385 .09742 m .6803 .1035 L .68313 .10634 L p .175 .576 .937 r
F P
0 g
s
.69458 .11056 m .68313 .10634 L .6803 .1035 L p .125 .541 .919 r
F P
0 g
s
.68313 .10634 m .69458 .11056 L .69752 .11299 L p .153 .55 .927 r
F P
0 g
s
.53189 .93305 m .57574 .92849 L .57643 .9324 L p .242 0 0 r
F P
0 g
s
.57643 .9324 m .53226 .93812 L .53189 .93305 L p .242 0 0 r
F P
0 g
s
.85909 .25586 m .83321 .22016 L .83625 .21761 L p 0 .152 .693 r
F P
0 g
s
.83625 .21761 m .8633 .253 L .85909 .25586 L p 0 .152 .693 r
F P
0 g
s
.47907 .06121 m .53226 .06188 L .53189 .06695 L p .315 .774 .948 r
F P
0 g
s
.57574 .07151 m .53189 .06695 L .53226 .06188 L p .242 .711 .944 r
F P
0 g
s
.10902 .31109 m .09105 .35135 L .08732 .34999 L p .897 .937 .566 r
F P
0 g
s
.08732 .34999 m .10444 .30887 L .10902 .31109 L p .897 .937 .566 r
F P
0 g
s
.89047 .70127 m .8633 .747 L .85909 .74414 L p 0 0 0 r
F P
0 g
s
.83321 .77984 m .85909 .74414 L .8633 .747 L p 0 0 0 r
F P
0 g
s
.13046 .73752 m .10444 .69113 L .10902 .68891 L p .863 .447 0 r
F P
0 g
s
.09105 .64865 m .10902 .68891 L .10444 .69113 L p .897 .527 .065 r
F P
0 g
s
.7364 .13544 m .73049 .13033 L .73283 .1312 L p .058 .457 .882 r
F P
0 g
s
.73283 .1312 m .73997 .13677 L .7364 .13544 L p .058 .457 .882 r
F P
0 g
s
.69752 .88701 m .7049 .88444 L .70298 .88603 L p .106 0 0 r
F P
0 g
s
.70298 .88603 m .69458 .88944 L .69752 .88701 L p .106 0 0 r
F P
0 g
s
.7049 .11556 m .69752 .11299 L .69458 .11056 L p .106 .519 .91 r
F P
0 g
s
.69752 .11299 m .7049 .11556 L .70741 .11741 L p .121 .523 .914 r
F P
0 g
s
.06608 .47755 m .06462 .48523 L .0642 .48277 L p .976 .819 .408 r
F P
0 g
s
.0642 .48277 m .06545 .47379 L .06608 .47755 L p .976 .819 .408 r
F P
0 g
s
.06462 .51477 m .06608 .52245 L .06545 .52621 L p .976 .774 .352 r
F P
0 g
s
.06608 .52245 m .06462 .51477 L .06496 .51167 L p .981 .782 .372 r
F P
0 g
s
.73049 .86967 m .7364 .86456 L .73997 .86323 L p .058 0 0 r
F P
0 g
s
.7364 .86456 m .73049 .86967 L .72763 .87092 L p .082 0 0 r
F P
0 g
s
.06423 .5 m .06543 .5 L .06538 .50413 L p .978 .797 .382 r
F P
0 g
s
.06543 .5 m .06423 .5 L .0642 .49742 L p .978 .8 .387 r
F P
0 g
s
.0642 .49742 m .06538 .49587 L .06543 .5 L p .978 .8 .387 r
F P
0 g
s
.71789 .87739 m .71728 .87635 L .72088 .87433 L p .086 0 0 r
F P
0 g
s
.71728 .87635 m .71789 .87739 L .71567 .87871 L p .09 0 0 r
F P
0 g
s
.71567 .87871 m .71374 .87846 L .71728 .87635 L p .09 0 0 r
F P
0 g
s
.71789 .12261 m .71728 .12365 L .71374 .12154 L p .09 .494 .9 r
F P
0 g
s
.71728 .12365 m .71789 .12261 L .72014 .12387 L p .086 .489 .897 r
F P
0 g
s
.72014 .12387 m .72088 .12567 L .71728 .12365 L p .086 .489 .897 r
F P
0 g
s
.71374 .87846 m .71567 .87871 L .71358 .88003 L p .091 0 0 r
F P
0 g
s
.71358 .88003 m .7104 .88057 L .71374 .87846 L p .091 0 0 r
F P
0 g
s
.72088 .12567 m .72014 .12387 L .72233 .12502 L p .079 .482 .894 r
F P
0 g
s
.72233 .12502 m .72438 .12751 L .72088 .12567 L p .079 .482 .894 r
F P
0 g
s
.06538 .49587 m .0642 .49742 L .0641 .49495 L p .977 .803 .389 r
F P
0 g
s
.0641 .49495 m .06522 .49193 L .06538 .49587 L p .977 .803 .389 r
F P
0 g
s
.0642 .50258 m .06538 .50413 L .06522 .50807 L p .977 .792 .375 r
F P
0 g
s
.06538 .50413 m .0642 .50258 L .06423 .5 L p .978 .797 .382 r
F P
0 g
s
.72014 .87613 m .72088 .87433 L .72438 .87249 L p .079 0 0 r
F P
0 g
s
.72088 .87433 m .72014 .87613 L .71789 .87739 L p .086 0 0 r
F P
0 g
s
.71567 .12129 m .71374 .12154 L .7104 .11943 L p .091 .497 .901 r
F P
0 g
s
.71374 .12154 m .71567 .12129 L .71789 .12261 L p .09 .494 .9 r
F P
0 g
s
.06943 .4406 m .06647 .45789 L .06534 .45585 L p .966 .849 .438 r
F P
0 g
s
.06534 .45585 m .06785 .43764 L .06943 .4406 L p .966 .849 .438 r
F P
0 g
s
.66385 .90258 m .6803 .8965 L .67909 .8985 L p .128 0 0 r
F P
0 g
s
.67909 .8985 m .66207 .90543 L .66385 .90258 L p .128 0 0 r
F P
0 g
s
.76672 .15681 m .75323 .1456 L .75557 .14565 L p .001 .396 .849 r
F P
0 g
s
.75557 .14565 m .77008 .15693 L .76672 .15681 L p .001 .396 .849 r
F P
0 g
s
.63986 .08676 m .66207 .09457 L .66385 .09742 L p .176 .599 .94 r
F P
0 g
s
.6803 .1035 m .66385 .09742 L .66207 .09457 L p .128 .559 .922 r
F P
0 g
s
.78795 .82774 m .77008 .84307 L .76672 .84319 L p .003 0 0 r
F P
0 g
s
.75323 .8544 m .76672 .84319 L .77008 .84307 L p .001 0 0 r
F P
0 g
s
.07219 .5855 m .06785 .56236 L .06943 .5594 L p .969 .709 .283 r
F P
0 g
s
.06647 .54211 m .06943 .5594 L .06785 .56236 L p .966 .729 .292 r
F P
0 g
s
.71358 .11997 m .7104 .11943 L .70741 .11741 L p .087 .499 .9 r
F P
0 g
s
.7104 .11943 m .71358 .11997 L .71567 .12129 L p .091 .497 .901 r
F P
0 g
s
.72233 .87498 m .72438 .87249 L .72763 .87092 L p .068 0 0 r
F P
0 g
s
.72438 .87249 m .72233 .87498 L .72014 .87613 L p .079 0 0 r
F P
0 g
s
.0641 .50505 m .06522 .50807 L .06496 .51167 L p .975 .787 .365 r
F P
0 g
s
.06522 .50807 m .0641 .50505 L .0642 .50258 L p .977 .792 .375 r
F P
0 g
s
.72438 .12751 m .72233 .12502 L .72436 .12601 L p .068 .474 .889 r
F P
0 g
s
.72436 .12601 m .72763 .12908 L .72438 .12751 L p .068 .474 .889 r
F P
0 g
s
.06522 .49193 m .0641 .49495 L .06393 .49269 L p .975 .805 .388 r
F P
0 g
s
.06393 .49269 m .06496 .48833 L .06522 .49193 L p .975 .805 .388 r
F P
0 g
s
.7104 .88057 m .71358 .88003 L .71171 .8813 L p .087 0 0 r
F P
0 g
s
.71171 .8813 m .70741 .88259 L .7104 .88057 L p .087 0 0 r
F P
0 g
s
.06393 .50731 m .06496 .51167 L .06462 .51477 L p .972 .781 .354 r
F P
0 g
s
.06496 .51167 m .06393 .50731 L .0641 .50505 L p .975 .787 .365 r
F P
0 g
s
.72436 .87399 m .72763 .87092 L .73049 .86967 L p .054 0 0 r
F P
0 g
s
.72763 .87092 m .72436 .87399 L .72233 .87498 L p .068 0 0 r
F P
0 g
s
.06496 .48833 m .06393 .49269 L .06372 .49076 L p .972 .806 .384 r
F P
0 g
s
.06372 .49076 m .06462 .48523 L .06496 .48833 L p .972 .806 .384 r
F P
0 g
s
.71171 .1187 m .70741 .11741 L .7049 .11556 L p .08 .498 .899 r
F P
0 g
s
.70741 .11741 m .71171 .1187 L .71358 .11997 L p .087 .499 .9 r
F P
0 g
s
.72763 .12908 m .72436 .12601 L .72614 .12679 L p .054 .465 .884 r
F P
0 g
s
.72614 .12679 m .73049 .13033 L .72763 .12908 L p .054 .465 .884 r
F P
0 g
s
.70741 .88259 m .71171 .8813 L .71014 .88245 L p .08 0 0 r
F P
0 g
s
.71014 .88245 m .7049 .88444 L .70741 .88259 L p .08 0 0 r
F P
0 g
s
.53226 .06188 m .57643 .0676 L .57574 .07151 L p .242 .711 .944 r
F P
0 g
s
.61143 .0787 m .57574 .07151 L .57643 .0676 L p .183 .654 .934 r
F P
0 g
s
.10444 .69113 m .08732 .65001 L .09105 .64865 L p .897 .527 .065 r
F P
0 g
s
.07943 .61415 m .09105 .64865 L .08732 .65001 L p .918 .591 .122 r
F P
0 g
s
.8633 .747 m .83625 .78239 L .83321 .77984 L p 0 0 0 r
F P
0 g
s
.80914 .80715 m .83321 .77984 L .83625 .78239 L p 0 0 0 r
F P
0 g
s
.09105 .35135 m .07943 .38585 L .07651 .38506 L p .918 .908 .51 r
F P
0 g
s
.07651 .38506 m .08732 .34999 L .09105 .35135 L p .918 .908 .51 r
F P
0 g
s
.83321 .22016 m .80914 .19285 L .81129 .19071 L p 0 .221 .74 r
F P
0 g
s
.81129 .19071 m .83625 .21761 L .83321 .22016 L p 0 .221 .74 r
F P
0 g
s
.57574 .92849 m .61143 .9213 L .6122 .92423 L p .183 0 0 r
F P
0 g
s
.6122 .92423 m .57643 .9324 L .57574 .92849 L p .183 0 0 r
F P
0 g
s
.6803 .1035 m .69267 .10863 L .69458 .11056 L p .125 .541 .919 r
F P
0 g
s
.70298 .11397 m .69458 .11056 L .69267 .10863 L p .086 .512 .903 r
F P
0 g
s
.69458 .11056 m .70298 .11397 L .7049 .11556 L p .106 .519 .91 r
F P
0 g
s
.75323 .8544 m .74261 .86254 L .73997 .86323 L p .044 0 0 r
F P
0 g
s
.73283 .8688 m .73997 .86323 L .74261 .86254 L p .03 0 0 r
F P
0 g
s
.73997 .86323 m .73283 .8688 L .73049 .86967 L p .058 0 0 r
F P
0 g
s
.06647 .54211 m .06473 .52883 L .06545 .52621 L p .975 .758 .334 r
F P
0 g
s
.0642 .51723 m .06545 .52621 L .06473 .52883 L p .968 .764 .329 r
F P
0 g
s
.06545 .52621 m .0642 .51723 L .06462 .51477 L p .976 .774 .352 r
F P
0 g
s
.73997 .13677 m .73283 .1312 L .73455 .13165 L p .03 .441 .871 r
F P
0 g
s
.73455 .13165 m .74261 .13746 L .73997 .13677 L p .03 .441 .871 r
F P
0 g
s
.69458 .88944 m .70298 .88603 L .70173 .8873 L p .086 0 0 r
F P
0 g
s
.70173 .8873 m .69267 .89137 L .69458 .88944 L p .086 0 0 r
F P
0 g
s
.06545 .47379 m .0642 .48277 L .06372 .48105 L p .968 .817 .393 r
F P
0 g
s
.06372 .48105 m .06473 .47117 L .06545 .47379 L p .968 .817 .393 r
F P
0 g
s
.06647 .45789 m .06473 .47117 L .06395 .46979 L p .963 .828 .403 r
F P
0 g
s
.06395 .46979 m .06534 .45585 L .06647 .45789 L p .963 .828 .403 r
F P
0 g
s
.06785 .56236 m .06534 .54415 L .06647 .54211 L p .966 .729 .292 r
F P
0 g
s
.06473 .52883 m .06647 .54211 L .06534 .54415 L p .963 .744 .299 r
F P
0 g
s
.77008 .84307 m .75557 .85435 L .75323 .8544 L p .001 0 0 r
F P
0 g
s
.74261 .86254 m .75323 .8544 L .75557 .85435 L p 0 0 0 r
F P
0 g
s
.66207 .09457 m .67909 .1015 L .6803 .1035 L p .128 .559 .922 r
F P
0 g
s
.69267 .10863 m .6803 .1035 L .67909 .1015 L p .09 .527 .907 r
F P
0 g
s
.6803 .8965 m .69267 .89137 L .69186 .89273 L p .09 0 0 r
F P
0 g
s
.69186 .89273 m .67909 .8985 L .6803 .8965 L p .09 0 0 r
F P
0 g
s
.75323 .1456 m .74261 .13746 L .74418 .13748 L p 0 .412 .855 r
F P
0 g
s
.74418 .13748 m .75557 .14565 L .75323 .1456 L p 0 .412 .855 r
F P
0 g
s
.7049 .88444 m .71014 .88245 L .70894 .88345 L p .07 0 0 r
F P
0 g
s
.70894 .88345 m .70298 .88603 L .7049 .88444 L p .07 0 0 r
F P
0 g
s
.06462 .48523 m .06372 .49076 L .06346 .48922 L p .968 .805 .377 r
F P
0 g
s
.06346 .48922 m .0642 .48277 L .06462 .48523 L p .968 .805 .377 r
F P
0 g
s
.71014 .11755 m .7049 .11556 L .70298 .11397 L p .07 .495 .895 r
F P
0 g
s
.7049 .11556 m .71014 .11755 L .71171 .1187 L p .08 .498 .899 r
F P
0 g
s
.73049 .13033 m .72614 .12679 L .7276 .12733 L p .038 .454 .877 r
F P
0 g
s
.7276 .12733 m .73283 .1312 L .73049 .13033 L p .038 .454 .877 r
F P
0 g
s
.72614 .87321 m .73049 .86967 L .73283 .8688 L p .038 0 0 r
F P
0 g
s
.73049 .86967 m .72614 .87321 L .72436 .87399 L p .054 0 0 r
F P
0 g
s
.06372 .50924 m .06462 .51477 L .0642 .51723 L p .968 .775 .34 r
F P
0 g
s
.06462 .51477 m .06372 .50924 L .06393 .50731 L p .972 .781 .354 r
F P
0 g
s
.71826 .12196 m .71789 .12261 L .71567 .12129 L p .056 .477 .888 r
F P
0 g
s
.71789 .12261 m .71826 .12196 L .71959 .1227 L p .054 .474 .886 r
F P
0 g
s
.71959 .1227 m .72014 .12387 L .71789 .12261 L p .054 .474 .886 r
F P
0 g
s
.71826 .87804 m .71789 .87739 L .72014 .87613 L p .054 0 0 r
F P
0 g
s
.71789 .87739 m .71826 .87804 L .71696 .87882 L p .056 0 0 r
F P
0 g
s
.71696 .87882 m .71567 .87871 L .71789 .87739 L p .056 0 0 r
F P
0 g
s
.06347 .5 m .06423 .5 L .0642 .50258 L p .968 .79 .358 r
F P
0 g
s
.06423 .5 m .06347 .5 L .06345 .49848 L p .968 .792 .361 r
F P
0 g
s
.06345 .49848 m .0642 .49742 L .06423 .5 L p .968 .792 .361 r
F P
0 g
s
.71567 .87871 m .71696 .87882 L .71573 .8796 L p .057 0 0 r
F P
0 g
s
.71573 .8796 m .71358 .88003 L .71567 .87871 L p .057 0 0 r
F P
0 g
s
.72014 .12387 m .71959 .1227 L .72087 .12337 L p .049 .47 .884 r
F P
0 g
s
.72087 .12337 m .72233 .12502 L .72014 .12387 L p .049 .47 .884 r
F P
0 g
s
.0642 .49742 m .06345 .49848 L .06339 .49703 L p .968 .794 .362 r
F P
0 g
s
.06339 .49703 m .0641 .49495 L .0642 .49742 L p .968 .794 .362 r
F P
0 g
s
.71959 .8773 m .72014 .87613 L .72233 .87498 L p .049 0 0 r
F P
0 g
s
.72014 .87613 m .71959 .8773 L .71826 .87804 L p .054 0 0 r
F P
0 g
s
.71696 .12118 m .71567 .12129 L .71358 .11997 L p .057 .479 .888 r
F P
0 g
s
.71567 .12129 m .71696 .12118 L .71826 .12196 L p .056 .477 .888 r
F P
0 g
s
.06345 .50152 m .0642 .50258 L .0641 .50505 L p .968 .787 .353 r
F P
0 g
s
.0642 .50258 m .06345 .50152 L .06347 .5 L p .968 .79 .358 r
F P
0 g
s
.08732 .65001 m .07651 .61494 L .07943 .61415 L p .918 .591 .122 r
F P
0 g
s
.07219 .5855 m .07943 .61415 L .07651 .61494 L p .931 .64 .169 r
F P
0 g
s
.83625 .78239 m .81129 .80929 L .80914 .80715 L p 0 0 0 r
F P
0 g
s
.78795 .82774 m .80914 .80715 L .81129 .80929 L p 0 0 0 r
F P
0 g
s
.61143 .9213 m .63986 .91324 L .64058 .91538 L p .136 0 0 r
F P
0 g
s
.64058 .91538 m .6122 .92423 L .61143 .9213 L p .136 0 0 r
F P
0 g
s
.57643 .0676 m .6122 .07577 L .61143 .0787 L p .183 .654 .934 r
F P
0 g
s
.63986 .08676 m .61143 .0787 L .6122 .07577 L p .136 .606 .922 r
F P
0 g
s
.80914 .19285 m .78795 .17226 L .78944 .17056 L p 0 .278 .775 r
F P
0 g
s
.78944 .17056 m .81129 .19071 L .80914 .19285 L p 0 .278 .775 r
F P
0 g
s
.07943 .38585 m .07219 .4145 L .06998 .41406 L p .931 .88 .463 r
F P
0 g
s
.06998 .41406 m .07651 .38506 L .07943 .38585 L p .931 .88 .463 r
F P
0 g
s
.72233 .12502 m .72087 .12337 L .72206 .12395 L p .042 .464 .881 r
F P
0 g
s
.72206 .12395 m .72436 .12601 L .72233 .12502 L p .042 .464 .881 r
F P
0 g
s
.06339 .50297 m .0641 .50505 L .06393 .50731 L p .966 .783 .347 r
F P
0 g
s
.0641 .50505 m .06339 .50297 L .06345 .50152 L p .968 .787 .353 r
F P
0 g
s
.0641 .49495 m .06339 .49703 L .0633 .49571 L p .966 .795 .361 r
F P
0 g
s
.0633 .49571 m .06393 .49269 L .0641 .49495 L p .966 .795 .361 r
F P
0 g
s
.71358 .88003 m .71573 .8796 L .71464 .88034 L p .054 0 0 r
F P
0 g
s
.71464 .88034 m .71171 .8813 L .71358 .88003 L p .054 0 0 r
F P
0 g
s
.71573 .1204 m .71358 .11997 L .71171 .1187 L p .054 .48 .888 r
F P
0 g
s
.71358 .11997 m .71573 .1204 L .71696 .12118 L p .057 .479 .888 r
F P
0 g
s
.72087 .87663 m .72233 .87498 L .72436 .87399 L p .042 0 0 r
F P
0 g
s
.72233 .87498 m .72087 .87663 L .71959 .8773 L p .049 0 0 r
F P
0 g
s
.06393 .49269 m .0633 .49571 L .06317 .49458 L p .964 .795 .358 r
F P
0 g
s
.06317 .49458 m .06372 .49076 L .06393 .49269 L p .964 .795 .358 r
F P
0 g
s
.72436 .12601 m .72206 .12395 L .72311 .12441 L p .034 .458 .877 r
F P
0 g
s
.72311 .12441 m .72614 .12679 L .72436 .12601 L p .034 .458 .877 r
F P
0 g
s
.71171 .8813 m .71464 .88034 L .71372 .88102 L p .05 0 0 r
F P
0 g
s
.71372 .88102 m .71014 .88245 L .71171 .8813 L p .05 0 0 r
F P
0 g
s
.71464 .11966 m .71171 .1187 L .71014 .11755 L p .05 .479 .886 r
F P
0 g
s
.71171 .1187 m .71464 .11966 L .71573 .1204 L p .054 .48 .888 r
F P
0 g
s
.72206 .87605 m .72436 .87399 L .72614 .87321 L p .034 0 0 r
F P
0 g
s
.72436 .87399 m .72206 .87605 L .72087 .87663 L p .042 0 0 r
F P
0 g
s
.0633 .50429 m .06393 .50731 L .06372 .50924 L p .964 .779 .34 r
F P
0 g
s
.06393 .50731 m .0633 .50429 L .06339 .50297 L p .966 .783 .347 r
F P
0 g
s
.73283 .1312 m .7276 .12733 L .72868 .12761 L p .019 .443 .869 r
F P
0 g
s
.72868 .12761 m .73455 .13165 L .73283 .1312 L p .019 .443 .869 r
F P
0 g
s
.0642 .48277 m .06346 .48922 L .06316 .48816 L p .962 .803 .367 r
F P
0 g
s
.06316 .48816 m .06372 .48105 L .0642 .48277 L p .962 .803 .367 r
F P
0 g
s
.06473 .52883 m .06372 .51895 L .0642 .51723 L p .968 .764 .329 r
F P
0 g
s
.06346 .51078 m .0642 .51723 L .06372 .51895 L p .962 .769 .325 r
F P
0 g
s
.0642 .51723 m .06346 .51078 L .06372 .50924 L p .968 .775 .34 r
F P
0 g
s
.74261 .86254 m .73455 .86835 L .73283 .8688 L p .03 0 0 r
F P
0 g
s
.7276 .87267 m .73283 .8688 L .73455 .86835 L p .019 0 0 r
F P
0 g
s
.73283 .8688 m .7276 .87267 L .72614 .87321 L p .038 0 0 r
F P
0 g
s
.69267 .10863 m .70173 .1127 L .70298 .11397 L p .086 .512 .903 r
F P
0 g
s
.70894 .11655 m .70298 .11397 L .70173 .1127 L p .056 .49 .89 r
F P
0 g
s
.70298 .11397 m .70894 .11655 L .71014 .11755 L p .07 .495 .895 r
F P
0 g
s
.70298 .88603 m .70894 .88345 L .70816 .88424 L p .056 0 0 r
F P
0 g
s
.70816 .88424 m .70173 .8873 L .70298 .88603 L p .056 0 0 r
F P
0 g
s
.67909 .1015 m .69186 .10727 L .69267 .10863 L p .09 .527 .907 r
F P
0 g
s
.70173 .1127 m .69267 .10863 L .69186 .10727 L p .061 .502 .894 r
F P
0 g
s
.06473 .47117 m .06372 .48105 L .06322 .48016 L p .959 .812 .375 r
F P
0 g
s
.06322 .48016 m .06395 .46979 L .06473 .47117 L p .959 .812 .375 r
F P
0 g
s
.75557 .85435 m .74418 .86252 L .74261 .86254 L p 0 0 0 r
F P
0 g
s
.73455 .86835 m .74261 .86254 L .74418 .86252 L p 0 0 0 r
F P
0 g
s
.06534 .54415 m .06395 .53021 L .06473 .52883 L p .963 .744 .299 r
F P
0 g
s
.06372 .51895 m .06473 .52883 L .06395 .53021 L p .959 .754 .305 r
F P
0 g
s
.69267 .89137 m .70173 .8873 L .70121 .88819 L p .061 0 0 r
F P
0 g
s
.70121 .88819 m .69186 .89273 L .69267 .89137 L p .061 0 0 r
F P
0 g
s
.74261 .13746 m .73455 .13165 L .73557 .13165 L p 0 .423 .858 r
F P
0 g
s
.73557 .13165 m .74418 .13748 L .74261 .13746 L p 0 .423 .858 r
F P
0 g
s
.6122 .07577 m .64058 .08462 L .63986 .08676 L p .136 .606 .922 r
F P
0 g
s
.66207 .09457 m .63986 .08676 L .64058 .08462 L p .099 .565 .91 r
F P
0 g
s
.07651 .61494 m .06998 .58594 L .07219 .5855 L p .931 .64 .169 r
F P
0 g
s
.06785 .56236 m .07219 .5855 L .06998 .58594 L p .939 .678 .208 r
F P
0 g
s
.63986 .91324 m .66207 .90543 L .66268 .90696 L p .099 0 0 r
F P
0 g
s
.66268 .90696 m .64058 .91538 L .63986 .91324 L p .099 0 0 r
F P
0 g
s
.81129 .80929 m .78944 .82944 L .78795 .82774 L p 0 0 0 r
F P
0 g
s
.77008 .84307 m .78795 .82774 L .78944 .82944 L p 0 0 0 r
F P
0 g
s
.78795 .17226 m .77008 .15693 L .7711 .15563 L p 0 .323 .801 r
F P
0 g
s
.7711 .15563 m .78944 .17056 L .78795 .17226 L p 0 .323 .801 r
F P
0 g
s
.07219 .4145 m .06785 .43764 L .06622 .43741 L p .939 .856 .425 r
F P
0 g
s
.06622 .43741 m .06998 .41406 L .07219 .4145 L p .939 .856 .425 r
F P
0 g
s
.06372 .49076 m .06317 .49458 L .06302 .49368 L p .961 .794 .354 r
F P
0 g
s
.06302 .49368 m .06346 .48922 L .06372 .49076 L p .961 .794 .354 r
F P
0 g
s
.72614 .12679 m .72311 .12441 L .72397 .12472 L p .023 .452 .872 r
F P
0 g
s
.72397 .12472 m .7276 .12733 L .72614 .12679 L p .023 .452 .872 r
F P
0 g
s
.71014 .88245 m .71372 .88102 L .71301 .8816 L p .043 0 0 r
F P
0 g
s
.71301 .8816 m .70894 .88345 L .71014 .88245 L p .043 0 0 r
F P
0 g
s
.72311 .87559 m .72614 .87321 L .7276 .87267 L p .023 0 0 r
F P
0 g
s
.72614 .87321 m .72311 .87559 L .72206 .87605 L p .034 0 0 r
F P
0 g
s
.06317 .50542 m .06372 .50924 L .06346 .51078 L p .961 .775 .331 r
F P
0 g
s
.06372 .50924 m .06317 .50542 L .0633 .50429 L p .964 .779 .34 r
F P
0 g
s
.71372 .11898 m .71014 .11755 L .70894 .11655 L p .043 .477 .884 r
F P
0 g
s
.71014 .11755 m .71372 .11898 L .71464 .11966 L p .05 .479 .886 r
F P
0 g
s
.06301 .5 m .06347 .5 L .06345 .50152 L p .961 .784 .341 r
F P
0 g
s
.06347 .5 m .06301 .5 L .063 .49918 L p .961 .785 .342 r
F P
0 g
s
.063 .49918 m .06345 .49848 L .06347 .5 L p .961 .785 .342 r
F P
0 g
s
.71849 .12156 m .71826 .12196 L .71696 .12118 L p .033 .465 .878 r
F P
0 g
s
.71826 .12196 m .71849 .12156 L .71921 .12196 L p .031 .463 .877 r
F P
0 g
s
.71921 .12196 m .71959 .1227 L .71826 .12196 L p .031 .463 .877 r
F P
0 g
s
.71849 .87844 m .71826 .87804 L .71959 .8773 L p .031 0 0 r
F P
0 g
s
.71826 .87804 m .71849 .87844 L .71779 .87886 L p .033 0 0 r
F P
0 g
s
.71779 .87886 m .71696 .87882 L .71826 .87804 L p .033 0 0 r
F P
0 g
s
.71779 .12114 m .71696 .12118 L .71573 .1204 L p .033 .466 .878 r
F P
0 g
s
.71696 .12118 m .71779 .12114 L .71849 .12156 L p .033 .465 .878 r
F P
0 g
s
.063 .50082 m .06345 .50152 L .06339 .50297 L p .96 .782 .338 r
F P
0 g
s
.06345 .50152 m .063 .50082 L .06301 .5 L p .961 .784 .341 r
F P
0 g
s
.06345 .49848 m .063 .49918 L .06297 .4984 L p .96 .786 .343 r
F P
0 g
s
.06297 .4984 m .06339 .49703 L .06345 .49848 L p .96 .786 .343 r
F P
0 g
s
.71921 .87804 m .71959 .8773 L .72087 .87663 L p .028 0 0 r
F P
0 g
s
.71959 .8773 m .71921 .87804 L .71849 .87844 L p .031 0 0 r
F P
0 g
s
.71696 .87882 m .71779 .87886 L .71713 .87928 L p .033 0 0 r
F P
0 g
s
.71713 .87928 m .71573 .8796 L .71696 .87882 L p .033 0 0 r
F P
0 g
s
.71959 .1227 m .71921 .12196 L .7199 .12232 L p .028 .46 .876 r
F P
0 g
s
.7199 .12232 m .72087 .12337 L .71959 .1227 L p .028 .46 .876 r
F P
0 g
s
.06339 .49703 m .06297 .4984 L .06292 .49768 L p .959 .786 .342 r
F P
0 g
s
.06292 .49768 m .0633 .49571 L .06339 .49703 L p .959 .786 .342 r
F P
0 g
s
.72087 .12337 m .7199 .12232 L .72055 .12263 L p .024 .457 .874 r
F P
0 g
s
.72055 .12263 m .72206 .12395 L .72087 .12337 L p .024 .457 .874 r
F P
0 g
s
.71573 .8796 m .71713 .87928 L .71653 .87968 L p .031 0 0 r
F P
0 g
s
.71653 .87968 m .71464 .88034 L .71573 .8796 L p .031 0 0 r
F P
0 g
s
.71713 .12072 m .71573 .1204 L .71464 .11966 L p .031 .466 .878 r
F P
0 g
s
.71573 .1204 m .71713 .12072 L .71779 .12114 L p .033 .466 .878 r
F P
0 g
s
.7199 .87768 m .72087 .87663 L .72206 .87605 L p .024 0 0 r
F P
0 g
s
.72087 .87663 m .7199 .87768 L .71921 .87804 L p .028 0 0 r
F P
0 g
s
.06297 .5016 m .06339 .50297 L .0633 .50429 L p .959 .78 .334 r
F P
0 g
s
.06339 .50297 m .06297 .5016 L .063 .50082 L p .96 .782 .338 r
F P
0 g
s
.77008 .15693 m .75557 .14565 L .75625 .14471 L p 0 .359 .821 r
F P
0 g
s
.75625 .14471 m .7711 .15563 L .77008 .15693 L p 0 .359 .821 r
F P
0 g
s
.66207 .90543 m .67909 .8985 L .67957 .89956 L p .07 0 0 r
F P
0 g
s
.67957 .89956 m .66268 .90696 L .66207 .90543 L p .07 0 0 r
F P
0 g
s
.64058 .08462 m .66268 .09304 L .66207 .09457 L p .099 .565 .91 r
F P
0 g
s
.67909 .1015 m .66207 .09457 L .66268 .09304 L p .07 .533 .899 r
F P
0 g
s
.06785 .43764 m .06534 .45585 L .06419 .45573 L p .944 .834 .394 r
F P
0 g
s
.06419 .45573 m .06622 .43741 L .06785 .43764 L p .944 .834 .394 r
F P
0 g
s
.78944 .82944 m .7711 .84437 L .77008 .84307 L p 0 0 0 r
F P
0 g
s
.75557 .85435 m .77008 .84307 L .7711 .84437 L p 0 0 0 r
F P
0 g
s
.06998 .58594 m .06622 .56259 L .06785 .56236 L p .939 .678 .208 r
F P
0 g
s
.06534 .54415 m .06785 .56236 L .06622 .56259 L p .944 .707 .238 r
F P
0 g
s
.06346 .48922 m .06302 .49368 L .06284 .49305 L p .957 .792 .347 r
F P
0 g
s
.06284 .49305 m .06316 .48816 L .06346 .48922 L p .957 .792 .347 r
F P
0 g
s
.70894 .88345 m .71301 .8816 L .71256 .88206 L p .034 0 0 r
F P
0 g
s
.71256 .88206 m .70816 .88424 L .70894 .88345 L p .034 0 0 r
F P
0 g
s
.7276 .12733 m .72397 .12472 L .72459 .12488 L p .012 .445 .867 r
F P
0 g
s
.72459 .12488 m .72868 .12761 L .7276 .12733 L p .012 .445 .867 r
F P
0 g
s
.70173 .1127 m .70816 .11576 L .70894 .11655 L p .056 .49 .89 r
F P
0 g
s
.71301 .1184 m .70894 .11655 L .70816 .11576 L p .034 .474 .88 r
F P
0 g
s
.70894 .11655 m .71301 .1184 L .71372 .11898 L p .043 .477 .884 r
F P
0 g
s
.73455 .86835 m .72868 .87239 L .7276 .87267 L p .019 0 0 r
F P
0 g
s
.72397 .87528 m .7276 .87267 L .72868 .87239 L p .012 0 0 r
F P
0 g
s
.7276 .87267 m .72397 .87528 L .72311 .87559 L p .023 0 0 r
F P
0 g
s
.06372 .51895 m .06316 .51184 L .06346 .51078 L p .962 .769 .325 r
F P
0 g
s
.06302 .50632 m .06346 .51078 L .06316 .51184 L p .957 .771 .322 r
F P
0 g
s
.06346 .51078 m .06302 .50632 L .06317 .50542 L p .961 .775 .331 r
F P
0 g
s
.69186 .10727 m .70121 .11181 L .70173 .1127 L p .061 .502 .894 r
F P
0 g
s
.70816 .11576 m .70173 .1127 L .70121 .11181 L p .039 .483 .883 r
F P
0 g
s
.74418 .86252 m .73557 .86835 L .73455 .86835 L p 0 0 0 r
F P
0 g
s
.72868 .87239 m .73455 .86835 L .73557 .86835 L p 0 0 0 r
F P
0 g
s
.73455 .13165 m .72868 .12761 L .72931 .12761 L p 0 .432 .861 r
F P
0 g
s
.72931 .12761 m .73557 .13165 L .73455 .13165 L p 0 .432 .861 r
F P
0 g
s
.70173 .8873 m .70816 .88424 L .70785 .88479 L p .039 0 0 r
F P
0 g
s
.70785 .88479 m .70121 .88819 L .70173 .8873 L p .039 0 0 r
F P
0 g
s
.06395 .53021 m .06322 .51984 L .06372 .51895 L p .959 .754 .305 r
F P
0 g
s
.06316 .51184 m .06372 .51895 L .06322 .51984 L p .956 .762 .309 r
F P
0 g
s
.06372 .48105 m .06316 .48816 L .06284 .48761 L p .956 .799 .354 r
F P
0 g
s
.06284 .48761 m .06322 .48016 L .06372 .48105 L p .956 .799 .354 r
F P
0 g
s
.72206 .12395 m .72055 .12263 L .72111 .12288 L p .019 .454 .872 r
F P
0 g
s
.72111 .12288 m .72311 .12441 L .72206 .12395 L p .019 .454 .872 r
F P
0 g
s
.71464 .88034 m .71653 .87968 L .71604 .88005 L p .029 0 0 r
F P
0 g
s
.71604 .88005 m .71372 .88102 L .71464 .88034 L p .029 0 0 r
F P
0 g
s
.71653 .12032 m .71464 .11966 L .71372 .11898 L p .029 .466 .877 r
F P
0 g
s
.71464 .11966 m .71653 .12032 L .71713 .12072 L p .031 .466 .878 r
F P
0 g
s
.06292 .50232 m .0633 .50429 L .06317 .50542 L p .958 .778 .33 r
F P
0 g
s
.0633 .50429 m .06292 .50232 L .06297 .5016 L p .959 .78 .334 r
F P
0 g
s
.72055 .87737 m .72206 .87605 L .72311 .87559 L p .019 0 0 r
F P
0 g
s
.72206 .87605 m .72055 .87737 L .7199 .87768 L p .024 0 0 r
F P
0 g
s
.0633 .49571 m .06292 .49768 L .06285 .49707 L p .958 .786 .341 r
F P
0 g
s
.06285 .49707 m .06317 .49458 L .0633 .49571 L p .958 .786 .341 r
F P
0 g
s
.06317 .49458 m .06285 .49707 L .06276 .49658 L p .956 .786 .338 r
F P
0 g
s
.06276 .49658 m .06302 .49368 L .06317 .49458 L p .956 .786 .338 r
F P
0 g
s
.72311 .12441 m .72111 .12288 L .72158 .12305 L p .013 .45 .869 r
F P
0 g
s
.72158 .12305 m .72397 .12472 L .72311 .12441 L p .013 .45 .869 r
F P
0 g
s
.71372 .88102 m .71604 .88005 L .71566 .88037 L p .025 0 0 r
F P
0 g
s
.71566 .88037 m .71301 .8816 L .71372 .88102 L p .025 0 0 r
F P
0 g
s
.06285 .50293 m .06317 .50542 L .06302 .50632 L p .956 .775 .325 r
F P
0 g
s
.06317 .50542 m .06285 .50293 L .06292 .50232 L p .958 .778 .33 r
F P
0 g
s
.71604 .11995 m .71372 .11898 L .71301 .1184 L p .025 .465 .876 r
F P
0 g
s
.71372 .11898 m .71604 .11995 L .71653 .12032 L p .029 .466 .877 r
F P
0 g
s
.72111 .87712 m .72311 .87559 L .72397 .87528 L p .013 0 0 r
F P
0 g
s
.72311 .87559 m .72111 .87712 L .72055 .87737 L p .019 0 0 r
F P
0 g
s
.06534 .45585 m .06395 .46979 L .06316 .46974 L p .946 .817 .371 r
F P
0 g
s
.06316 .46974 m .06419 .45573 L .06534 .45585 L p .946 .817 .371 r
F P
0 g
s
.75557 .14565 m .74418 .13748 L .74463 .13682 L p 0 .386 .835 r
F P
0 g
s
.74463 .13682 m .75625 .14471 L .75557 .14565 L p 0 .386 .835 r
F P
0 g
s
.67909 .8985 m .69186 .89273 L .69221 .89344 L p .048 0 0 r
F P
0 g
s
.69221 .89344 m .67957 .89956 L .67909 .8985 L p .048 0 0 r
F P
0 g
s
.66268 .09304 m .67957 .10044 L .67909 .1015 L p .07 .533 .899 r
F P
0 g
s
.69186 .10727 m .67909 .1015 L .67957 .10044 L p .048 .507 .889 r
F P
0 g
s
.7711 .84437 m .75625 .85529 L .75557 .85435 L p 0 0 0 r
F P
0 g
s
.74418 .86252 m .75557 .85435 L .75625 .85529 L p 0 0 0 r
F P
0 g
s
.06622 .56259 m .06419 .54427 L .06534 .54415 L p .944 .707 .238 r
F P
0 g
s
.06395 .53021 m .06534 .54415 L .06419 .54427 L p .946 .728 .262 r
F P
0 g
s
.71863 .12132 m .71849 .12156 L .71779 .12114 L p .017 .457 .872 r
F P
0 g
s
.71849 .12156 m .71863 .12132 L .71897 .12152 L p .016 .456 .871 r
F P
0 g
s
.71897 .12152 m .71921 .12196 L .71849 .12156 L p .016 .456 .871 r
F P
0 g
s
.71863 .87868 m .71849 .87844 L .71921 .87804 L p .016 0 0 r
F P
0 g
s
.71849 .87844 m .71863 .87868 L .71829 .87888 L p .017 0 0 r
F P
0 g
s
.71829 .87888 m .71779 .87886 L .71849 .87844 L p .017 0 0 r
F P
0 g
s
.06274 .5 m .06301 .5 L .063 .50082 L p .955 .78 .329 r
F P
0 g
s
.06301 .5 m .06274 .5 L .06274 .4996 L p .955 .78 .33 r
F P
0 g
s
.06274 .4996 m .063 .49918 L .06301 .5 L p .955 .78 .33 r
F P
0 g
s
.063 .49918 m .06274 .4996 L .06272 .49923 L p .955 .781 .33 r
F P
0 g
s
.06272 .49923 m .06297 .4984 L .063 .49918 L p .955 .781 .33 r
F P
0 g
s
.71921 .12196 m .71897 .12152 L .71931 .12169 L p .015 .454 .87 r
F P
0 g
s
.71931 .12169 m .7199 .12232 L .71921 .12196 L p .015 .454 .87 r
F P
0 g
s
.71829 .12112 m .71779 .12114 L .71713 .12072 L p .017 .457 .872 r
F P
0 g
s
.71779 .12114 m .71829 .12112 L .71863 .12132 L p .017 .457 .872 r
F P
0 g
s
.71897 .87848 m .71921 .87804 L .7199 .87768 L p .015 0 0 r
F P
0 g
s
.71921 .87804 m .71897 .87848 L .71863 .87868 L p .016 0 0 r
F P
0 g
s
.06274 .5004 m .063 .50082 L .06297 .5016 L p .955 .779 .328 r
F P
0 g
s
.063 .50082 m .06274 .5004 L .06274 .5 L p .955 .78 .329 r
F P
0 g
s
.71779 .87886 m .71829 .87888 L .71797 .87908 L p .017 0 0 r
F P
0 g
s
.71797 .87908 m .71713 .87928 L .71779 .87886 L p .017 0 0 r
F P
0 g
s
.06322 .51984 m .06284 .51239 L .06316 .51184 L p .956 .762 .309 r
F P
0 g
s
.06284 .50695 m .06316 .51184 L .06284 .51239 L p .953 .767 .312 r
F P
0 g
s
.06316 .51184 m .06284 .50695 L .06302 .50632 L p .957 .771 .322 r
F P
0 g
s
.73557 .86835 m .72931 .87239 L .72868 .87239 L p 0 0 0 r
F P
0 g
s
.72459 .87512 m .72868 .87239 L .72931 .87239 L p 0 0 0 r
F P
0 g
s
.72868 .87239 m .72459 .87512 L .72397 .87528 L p .012 0 0 r
F P
0 g
s
.70121 .11181 m .70785 .11521 L .70816 .11576 L p .039 .483 .883 r
F P
0 g
s
.71256 .11794 m .70816 .11576 L .70785 .11521 L p .024 .469 .876 r
F P
0 g
s
.70816 .11576 m .71256 .11794 L .71301 .1184 L p .034 .474 .88 r
F P
0 g
s
.06316 .48816 m .06284 .49305 L .06266 .49273 L p .953 .79 .34 r
F P
0 g
s
.06266 .49273 m .06284 .48761 L .06316 .48816 L p .953 .79 .34 r
F P
0 g
s
.72868 .12761 m .72459 .12488 L .72497 .12488 L p 0 .438 .862 r
F P
0 g
s
.72497 .12488 m .72931 .12761 L .72868 .12761 L p 0 .438 .862 r
F P
0 g
s
.70816 .88424 m .71256 .88206 L .71238 .88238 L p .024 0 0 r
F P
0 g
s
.71238 .88238 m .70785 .88479 L .70816 .88424 L p .024 0 0 r
F P
0 g
s
.06276 .50342 m .06302 .50632 L .06284 .50695 L p .954 .773 .319 r
F P
0 g
s
.06302 .50632 m .06276 .50342 L .06285 .50293 L p .956 .775 .325 r
F P
0 g
s
.72397 .12472 m .72158 .12305 L .72191 .12314 L p .007 .446 .866 r
F P
0 g
s
.72191 .12314 m .72459 .12488 L .72397 .12472 L p .007 .446 .866 r
F P
0 g
s
.72158 .87695 m .72397 .87528 L .72459 .87512 L p .007 0 0 r
F P
0 g
s
.72397 .87528 m .72158 .87695 L .72111 .87712 L p .013 0 0 r
F P
0 g
s
.06302 .49368 m .06276 .49658 L .06267 .49625 L p .954 .785 .334 r
F P
0 g
s
.06267 .49625 m .06284 .49305 L .06302 .49368 L p .954 .785 .334 r
F P
0 g
s
.71566 .11963 m .71301 .1184 L .71256 .11794 L p .02 .462 .873 r
F P
0 g
s
.71301 .1184 m .71566 .11963 L .71604 .11995 L p .025 .465 .876 r
F P
0 g
s
.71301 .8816 m .71566 .88037 L .71542 .88061 L p .02 0 0 r
F P
0 g
s
.71542 .88061 m .71256 .88206 L .71301 .8816 L p .02 0 0 r
F P
0 g
s
.71797 .12092 m .71713 .12072 L .71653 .12032 L p .016 .457 .871 r
F P
0 g
s
.71713 .12072 m .71797 .12092 L .71829 .12112 L p .017 .457 .872 r
F P
0 g
s
.71931 .87831 m .7199 .87768 L .72055 .87737 L p .013 0 0 r
F P
0 g
s
.7199 .87768 m .71931 .87831 L .71897 .87848 L p .015 0 0 r
F P
0 g
s
.7199 .12232 m .71931 .12169 L .71962 .12184 L p .013 .453 .869 r
F P
0 g
s
.71962 .12184 m .72055 .12263 L .7199 .12232 L p .013 .453 .869 r
F P
0 g
s
.71713 .87928 m .71797 .87908 L .71768 .87928 L p .016 0 0 r
F P
0 g
s
.71768 .87928 m .71653 .87968 L .71713 .87928 L p .016 0 0 r
F P
0 g
s
.06272 .50077 m .06297 .5016 L .06292 .50232 L p .954 .778 .326 r
F P
0 g
s
.06297 .5016 m .06272 .50077 L .06274 .5004 L p .955 .779 .328 r
F P
0 g
s
.06297 .4984 m .06272 .49923 L .0627 .49888 L p .954 .781 .33 r
F P
0 g
s
.0627 .49888 m .06292 .49768 L .06297 .4984 L p .954 .781 .33 r
F P
0 g
s
.0627 .50112 m .06292 .50232 L .06285 .50293 L p .954 .776 .323 r
F P
0 g
s
.06292 .50232 m .0627 .50112 L .06272 .50077 L p .954 .778 .326 r
F P
0 g
s
.71962 .87816 m .72055 .87737 L .72111 .87712 L p .01 0 0 r
F P
0 g
s
.72055 .87737 m .71962 .87816 L .71931 .87831 L p .013 0 0 r
F P
0 g
s
.71768 .12072 m .71653 .12032 L .71604 .11995 L p .015 .457 .871 r
F P
0 g
s
.71653 .12032 m .71768 .12072 L .71797 .12092 L p .016 .457 .871 r
F P
0 g
s
.06292 .49768 m .0627 .49888 L .06266 .49859 L p .954 .781 .329 r
F P
0 g
s
.06266 .49859 m .06285 .49707 L .06292 .49768 L p .954 .781 .329 r
F P
0 g
s
.71653 .87968 m .71768 .87928 L .71744 .87945 L p .015 0 0 r
F P
0 g
s
.71744 .87945 m .71604 .88005 L .71653 .87968 L p .015 0 0 r
F P
0 g
s
.72055 .12263 m .71962 .12184 L .71989 .12196 L p .01 .451 .868 r
F P
0 g
s
.71989 .12196 m .72111 .12288 L .72055 .12263 L p .01 .451 .868 r
F P
0 g
s
.69186 .89273 m .70121 .88819 L .70145 .88865 L p .032 0 0 r
F P
0 g
s
.70145 .88865 m .69221 .89344 L .69186 .89273 L p .032 0 0 r
F P
0 g
s
.06419 .54427 m .06316 .53026 L .06395 .53021 L p .946 .728 .262 r
F P
0 g
s
.06322 .51984 m .06395 .53021 L .06316 .53026 L p .948 .744 .28 r
F P
0 g
s
.74418 .13748 m .73557 .13165 L .73585 .13121 L p 0 .406 .845 r
F P
0 g
s
.73585 .13121 m .74463 .13682 L .74418 .13748 L p 0 .406 .845 r
F P
0 g
s
.06395 .46979 m .06322 .48016 L .06269 .48014 L p .948 .804 .353 r
F P
0 g
s
.06269 .48014 m .06316 .46974 L .06395 .46979 L p .948 .804 .353 r
F P
0 g
s
.67957 .10044 m .69221 .10656 L .69186 .10727 L p .048 .507 .889 r
F P
0 g
s
.70121 .11181 m .69186 .10727 L .69221 .10656 L p .032 .488 .881 r
F P
0 g
s
.75625 .85529 m .74463 .86318 L .74418 .86252 L p 0 0 0 r
F P
0 g
s
.73557 .86835 m .74418 .86252 L .74463 .86318 L p 0 0 0 r
F P
0 g
s
.71989 .87804 m .72111 .87712 L .72158 .87695 L p .007 0 0 r
F P
0 g
s
.72111 .87712 m .71989 .87804 L .71962 .87816 L p .01 0 0 r
F P
0 g
s
.71744 .12055 m .71604 .11995 L .71566 .11963 L p .013 .456 .87 r
F P
0 g
s
.71604 .11995 m .71744 .12055 L .71768 .12072 L p .015 .457 .871 r
F P
0 g
s
.72111 .12288 m .71989 .12196 L .72012 .12204 L p .007 .449 .867 r
F P
0 g
s
.72012 .12204 m .72158 .12305 L .72111 .12288 L p .007 .449 .867 r
F P
0 g
s
.06266 .50141 m .06285 .50293 L .06276 .50342 L p .953 .775 .321 r
F P
0 g
s
.06285 .50293 m .06266 .50141 L .0627 .50112 L p .954 .776 .323 r
F P
0 g
s
.71604 .88005 m .71744 .87945 L .71726 .8796 L p .013 0 0 r
F P
0 g
s
.71726 .8796 m .71566 .88037 L .71604 .88005 L p .013 0 0 r
F P
0 g
s
.06285 .49707 m .06266 .49859 L .06262 .49835 L p .953 .781 .328 r
F P
0 g
s
.06262 .49835 m .06276 .49658 L .06285 .49707 L p .953 .781 .328 r
F P
0 g
s
.06284 .51239 m .06266 .50727 L .06284 .50695 L p .953 .767 .312 r
F P
0 g
s
.06267 .50375 m .06284 .50695 L .06266 .50727 L p .951 .77 .314 r
F P
0 g
s
.06284 .50695 m .06267 .50375 L .06276 .50342 L p .954 .773 .319 r
F P
0 g
s
.06284 .49305 m .06267 .49625 L .06257 .49608 L p .951 .783 .33 r
F P
0 g
s
.06257 .49608 m .06266 .49273 L .06284 .49305 L p .951 .783 .33 r
F P
0 g
s
.70785 .11521 m .71238 .11762 L .71256 .11794 L p .024 .469 .876 r
F P
0 g
s
.71542 .11939 m .71256 .11794 L .71238 .11762 L p .014 .46 .871 r
F P
0 g
s
.71256 .11794 m .71542 .11939 L .71566 .11963 L p .02 .462 .873 r
F P
0 g
s
.72459 .12488 m .72191 .12314 L .72211 .12314 L p 0 .442 .863 r
F P
0 g
s
.72211 .12314 m .72497 .12488 L .72459 .12488 L p 0 .442 .863 r
F P
0 g
s
.71256 .88206 m .71542 .88061 L .71532 .88079 L p .014 0 0 r
F P
0 g
s
.71532 .88079 m .71238 .88238 L .71256 .88206 L p .014 0 0 r
F P
0 g
s
.72931 .87239 m .72497 .87512 L .72459 .87512 L p 0 0 0 r
F P
0 g
s
.72191 .87686 m .72459 .87512 L .72497 .87512 L p 0 0 0 r
F P
0 g
s
.72459 .87512 m .72191 .87686 L .72158 .87695 L p .007 0 0 r
F P
0 g
s
.06322 .48016 m .06284 .48761 L .06251 .4876 L p .948 .793 .34 r
F P
0 g
s
.06251 .4876 m .06269 .48014 L .06322 .48016 L p .948 .793 .34 r
F P
0 g
s
.06316 .53026 m .06269 .51986 L .06322 .51984 L p .948 .744 .28 r
F P
0 g
s
.06284 .51239 m .06322 .51984 L .06269 .51986 L p .948 .755 .293 r
F P
0 g
s
.73557 .13165 m .72931 .12761 L .72948 .12733 L p 0 .421 .852 r
F P
0 g
s
.72948 .12733 m .73585 .13121 L .73557 .13165 L p 0 .421 .852 r
F P
0 g
s
.70121 .88819 m .70785 .88479 L .708 .88507 L p .021 0 0 r
F P
0 g
s
.708 .88507 m .70145 .88865 L .70121 .88819 L p .021 0 0 r
F P
0 g
s
.74463 .86318 m .73585 .86879 L .73557 .86835 L p 0 0 0 r
F P
0 g
s
.72931 .87239 m .73557 .86835 L .73585 .86879 L p 0 0 0 r
F P
0 g
s
.69221 .10656 m .70145 .11135 L .70121 .11181 L p .032 .488 .881 r
F P
0 g
s
.70785 .11521 m .70121 .11181 L .70145 .11135 L p .021 .473 .875 r
F P
0 g
s
.06262 .50165 m .06276 .50342 L .06267 .50375 L p .951 .774 .318 r
F P
0 g
s
.06276 .50342 m .06262 .50165 L .06266 .50141 L p .953 .775 .321 r
F P
0 g
s
.71726 .1204 m .71566 .11963 L .71542 .11939 L p .01 .455 .869 r
F P
0 g
s
.71566 .11963 m .71726 .1204 L .71744 .12055 L p .013 .456 .87 r
F P
0 g
s
.72012 .87796 m .72158 .87695 L .72191 .87686 L p .004 0 0 r
F P
0 g
s
.72158 .87695 m .72012 .87796 L .71989 .87804 L p .007 0 0 r
F P
0 g
s
.72158 .12305 m .72012 .12204 L .72028 .12209 L p .004 .447 .865 r
F P
0 g
s
.72028 .12209 m .72191 .12314 L .72158 .12305 L p .004 .447 .865 r
F P
0 g
s
.06276 .49658 m .06262 .49835 L .06258 .49819 L p .951 .78 .326 r
F P
0 g
s
.06258 .49819 m .06267 .49625 L .06276 .49658 L p .951 .78 .326 r
F P
0 g
s
.71566 .88037 m .71726 .8796 L .71714 .87972 L p .01 0 0 r
F P
0 g
s
.71714 .87972 m .71542 .88061 L .71566 .88037 L p .01 0 0 r
F P
0 g
s
.7187 .1212 m .71863 .12132 L .71829 .12112 L p .008 .452 .868 r
F P
0 g
s
.71863 .12132 m .7187 .1212 L .71884 .12128 L p .008 .451 .867 r
F P
0 g
s
.71884 .12128 m .71897 .12152 L .71863 .12132 L p .008 .451 .867 r
F P
0 g
s
.7187 .8788 m .71863 .87868 L .71897 .87848 L p .008 0 0 r
F P
0 g
s
.71863 .87868 m .7187 .8788 L .71856 .87888 L p .008 0 0 r
F P
0 g
s
.71856 .87888 m .71829 .87888 L .71863 .87868 L p .008 0 0 r
F P
0 g
s
.0626 .5 m .06274 .5 L .06274 .5004 L p .952 .777 .322 r
F P
0 g
s
.06274 .5 m .0626 .5 L .0626 .49984 L p .952 .777 .323 r
F P
0 g
s
.0626 .49984 m .06274 .4996 L .06274 .5 L p .952 .777 .323 r
F P
0 g
s
.71897 .12152 m .71884 .12128 L .71898 .12135 L p .007 .45 .867 r
F P
0 g
s
.71898 .12135 m .71931 .12169 L .71897 .12152 L p .007 .45 .867 r
F P
0 g
s
.06274 .4996 m .0626 .49984 L .06259 .49968 L p .952 .777 .323 r
F P
0 g
s
.06259 .49968 m .06272 .49923 L .06274 .4996 L p .952 .777 .323 r
F P
0 g
s
.71829 .87888 m .71856 .87888 L .71843 .87897 L p .008 0 0 r
F P
0 g
s
.71843 .87897 m .71797 .87908 L .71829 .87888 L p .008 0 0 r
F P
0 g
s
.0626 .50016 m .06274 .5004 L .06272 .50077 L p .952 .776 .322 r
F P
0 g
s
.06274 .5004 m .0626 .50016 L .0626 .5 L p .952 .777 .322 r
F P
0 g
s
.71884 .87872 m .71897 .87848 L .71931 .87831 L p .007 0 0 r
F P
0 g
s
.71897 .87848 m .71884 .87872 L .7187 .8788 L p .008 0 0 r
F P
0 g
s
.71856 .12112 m .71829 .12112 L .71797 .12092 L p .008 .452 .868 r
F P
0 g
s
.71829 .12112 m .71856 .12112 L .7187 .1212 L p .008 .452 .868 r
F P
0 g
s
.06259 .50032 m .06272 .50077 L .0627 .50112 L p .951 .776 .321 r
F P
0 g
s
.06272 .50077 m .06259 .50032 L .0626 .50016 L p .952 .776 .322 r
F P
0 g
s
.71898 .87865 m .71931 .87831 L .71962 .87816 L p .006 0 0 r
F P
0 g
s
.71931 .87831 m .71898 .87865 L .71884 .87872 L p .007 0 0 r
F P
0 g
s
.71843 .12103 m .71797 .12092 L .71768 .12072 L p .008 .452 .867 r
F P
0 g
s
.71797 .12092 m .71843 .12103 L .71856 .12112 L p .008 .452 .868 r
F P
0 g
s
.06272 .49923 m .06259 .49968 L .06258 .49954 L p .951 .778 .323 r
F P
0 g
s
.06258 .49954 m .0627 .49888 L .06272 .49923 L p .951 .778 .323 r
F P
0 g
s
.71931 .12169 m .71898 .12135 L .71911 .12141 L p .006 .45 .866 r
F P
0 g
s
.71911 .12141 m .71962 .12184 L .71931 .12169 L p .006 .45 .866 r
F P
0 g
s
.71797 .87908 m .71843 .87897 L .71831 .87905 L p .008 0 0 r
F P
0 g
s
.71831 .87905 m .71768 .87928 L .71797 .87908 L p .008 0 0 r
F P
0 g
s
.0627 .49888 m .06258 .49954 L .06257 .49942 L p .951 .778 .322 r
F P
0 g
s
.06257 .49942 m .06266 .49859 L .0627 .49888 L p .951 .778 .322 r
F P
0 g
s
.71768 .87928 m .71831 .87905 L .71821 .87912 L p .007 0 0 r
F P
0 g
s
.71821 .87912 m .71744 .87945 L .71768 .87928 L p .007 0 0 r
F P
0 g
s
.71962 .12184 m .71911 .12141 L .71922 .12146 L p .005 .449 .866 r
F P
0 g
s
.71922 .12146 m .71989 .12196 L .71962 .12184 L p .005 .449 .866 r
F P
0 g
s
.71911 .87859 m .71962 .87816 L .71989 .87804 L p .005 0 0 r
F P
0 g
s
.71962 .87816 m .71911 .87859 L .71898 .87865 L p .006 0 0 r
F P
0 g
s
.06258 .50046 m .0627 .50112 L .06266 .50141 L p .951 .775 .32 r
F P
0 g
s
.0627 .50112 m .06258 .50046 L .06259 .50032 L p .951 .776 .321 r
F P
0 g
s
.71831 .12095 m .71768 .12072 L .71744 .12055 L p .007 .452 .867 r
F P
0 g
s
.71768 .12072 m .71831 .12095 L .71843 .12103 L p .008 .452 .867 r
F P
0 g
s
.06284 .48761 m .06266 .49273 L .06247 .49273 L p .949 .786 .331 r
F P
0 g
s
.06247 .49273 m .06251 .4876 L .06284 .48761 L p .949 .786 .331 r
F P
0 g
s
.06269 .51986 m .06251 .5124 L .06284 .51239 L p .948 .755 .293 r
F P
0 g
s
.06266 .50727 m .06284 .51239 L .06251 .5124 L p .949 .763 .302 r
F P
0 g
s
.73585 .86879 m .72948 .87267 L .72931 .87239 L p 0 0 0 r
F P
0 g
s
.72497 .87512 m .72931 .87239 L .72948 .87267 L p 0 0 0 r
F P
0 g
s
.70785 .88479 m .71238 .88238 L .71247 .88255 L p .013 0 0 r
F P
0 g
s
.71247 .88255 m .708 .88507 L .70785 .88479 L p .013 0 0 r
F P
0 g
s
.70145 .11135 m .708 .11493 L .70785 .11521 L p .021 .473 .875 r
F P
0 g
s
.71238 .11762 m .70785 .11521 L .708 .11493 L p .013 .463 .871 r
F P
0 g
s
.72931 .12761 m .72497 .12488 L .72506 .12472 L p 0 .431 .857 r
F P
0 g
s
.72506 .12472 m .72948 .12733 L .72931 .12761 L p 0 .431 .857 r
F P
0 g
s
.06266 .49859 m .06257 .49942 L .06255 .49932 L p .95 .777 .321 r
F P
0 g
s
.06255 .49932 m .06262 .49835 L .06266 .49859 L p .95 .777 .321 r
F P
0 g
s
.71744 .87945 m .71821 .87912 L .71814 .87918 L p .006 0 0 r
F P
0 g
s
.71814 .87918 m .71726 .8796 L .71744 .87945 L p .006 0 0 r
F P
0 g
s
.71821 .12088 m .71744 .12055 L .71726 .1204 L p .006 .451 .867 r
F P
0 g
s
.71744 .12055 m .71821 .12088 L .71831 .12095 L p .007 .452 .867 r
F P
0 g
s
.71989 .12196 m .71922 .12146 L .71931 .12149 L p .003 .448 .865 r
F P
0 g
s
.71931 .12149 m .72012 .12204 L .71989 .12196 L p .003 .448 .865 r
F P
0 g
s
.06257 .50058 m .06266 .50141 L .06262 .50165 L p .95 .775 .318 r
F P
0 g
s
.06266 .50141 m .06257 .50058 L .06258 .50046 L p .951 .775 .32 r
F P
0 g
s
.71922 .87854 m .71989 .87804 L .72012 .87796 L p .003 0 0 r
F P
0 g
s
.71989 .87804 m .71922 .87854 L .71911 .87859 L p .005 0 0 r
F P
0 g
s
.72497 .87512 m .72211 .87686 L .72191 .87686 L p 0 0 0 r
F P
0 g
s
.72028 .87791 m .72191 .87686 L .72211 .87686 L p 0 0 0 r
F P
0 g
s
.72191 .87686 m .72028 .87791 L .72012 .87796 L p .004 0 0 r
F P
0 g
s
.06266 .50727 m .06257 .50392 L .06267 .50375 L p .951 .77 .314 r
F P
0 g
s
.06258 .50181 m .06267 .50375 L .06257 .50392 L p .95 .772 .315 r
F P
0 g
s
.06267 .50375 m .06258 .50181 L .06262 .50165 L p .951 .774 .318 r
F P
0 g
s
.71238 .11762 m .71532 .11921 L .71542 .11939 L p .014 .46 .871 r
F P
0 g
s
.71714 .12028 m .71542 .11939 L .71532 .11921 L p .007 .454 .868 r
F P
0 g
s
.71542 .11939 m .71714 .12028 L .71726 .1204 L p .01 .455 .869 r
F P
0 g
s
.72191 .12314 m .72028 .12209 L .72038 .12209 L p 0 .444 .863 r
F P
0 g
s
.72038 .12209 m .72211 .12314 L .72191 .12314 L p 0 .444 .863 r
F P
0 g
s
.71542 .88061 m .71714 .87972 L .7171 .87981 L p .007 0 0 r
F P
0 g
s
.7171 .87981 m .71532 .88079 L .71542 .88061 L p .007 0 0 r
F P
0 g
s
.06267 .49625 m .06258 .49819 L .06253 .49811 L p .95 .779 .323 r
F P
0 g
s
.06253 .49811 m .06257 .49608 L .06267 .49625 L p .95 .779 .323 r
F P
0 g
s
.71814 .12082 m .71726 .1204 L .71714 .12028 L p .005 .451 .866 r
F P
0 g
s
.71726 .1204 m .71814 .12082 L .71821 .12088 L p .006 .451 .867 r
F P
0 g
s
.06255 .50068 m .06262 .50165 L .06258 .50181 L p .95 .774 .317 r
F P
0 g
s
.06262 .50165 m .06255 .50068 L .06257 .50058 L p .95 .775 .318 r
F P
0 g
s
.71931 .87851 m .72012 .87796 L .72028 .87791 L p .002 0 0 r
F P
0 g
s
.72012 .87796 m .71931 .87851 L .71922 .87854 L p .003 0 0 r
F P
0 g
s
.72012 .12204 m .71931 .12149 L .71938 .12151 L p .002 .447 .864 r
F P
0 g
s
.71938 .12151 m .72028 .12209 L .72012 .12204 L p .002 .447 .864 r
F P
0 g
s
.71726 .8796 m .71814 .87918 L .71809 .87923 L p .005 0 0 r
F P
0 g
s
.71809 .87923 m .71714 .87972 L .71726 .8796 L p .005 0 0 r
F P
0 g
s
.06262 .49835 m .06255 .49932 L .06253 .49926 L p .95 .777 .321 r
F P
0 g
s
.06253 .49926 m .06258 .49819 L .06262 .49835 L p .95 .777 .321 r
F P
0 g
s
.71873 .12114 m .7187 .1212 L .71856 .12112 L p .003 .449 .865 r
F P
0 g
s
.7187 .1212 m .71873 .12114 L .71878 .12117 L p .003 .449 .865 r
F P
0 g
s
.71878 .12117 m .71884 .12128 L .7187 .1212 L p .003 .449 .865 r
F P
0 g
s
.06253 .5 m .0626 .5 L .0626 .50016 L p .95 .775 .319 r
F P
0 g
s
.0626 .5 m .06253 .5 L .06253 .49995 L p .95 .776 .319 r
F P
0 g
s
.06253 .49995 m .0626 .49984 L .0626 .5 L p .95 .776 .319 r
F P
0 g
s
.71873 .87886 m .7187 .8788 L .71884 .87872 L p .003 0 0 r
F P
0 g
s
.7187 .8788 m .71873 .87886 L .71869 .87889 L p .003 0 0 r
F P
0 g
s
.71869 .87889 m .71856 .87888 L .7187 .8788 L p .003 0 0 r
F P
0 g
s
.06266 .49273 m .06257 .49608 L .06247 .49607 L p .949 .781 .324 r
F P
0 g
s
.06247 .49607 m .06247 .49273 L .06266 .49273 L p .949 .781 .324 r
F P
0 g
s
.72497 .12488 m .72211 .12314 L .72217 .12305 L p 0 .438 .86 r
F P
0 g
s
.72217 .12305 m .72506 .12472 L .72497 .12488 L p 0 .438 .86 r
F P
0 g
s
.06251 .5124 m .06247 .50727 L .06266 .50727 L p .949 .763 .302 r
F P
0 g
s
.06257 .50392 m .06266 .50727 L .06247 .50727 L p .949 .768 .308 r
F P
0 g
s
.71238 .88238 m .71532 .88079 L .71537 .88088 L p .007 0 0 r
F P
0 g
s
.71537 .88088 m .71247 .88255 L .71238 .88238 L p .007 0 0 r
F P
0 g
s
.708 .11493 m .71247 .11745 L .71238 .11762 L p .013 .463 .871 r
F P
0 g
s
.71532 .11921 m .71238 .11762 L .71247 .11745 L p .007 .456 .868 r
F P
0 g
s
.72948 .87267 m .72506 .87528 L .72497 .87512 L p 0 0 0 r
F P
0 g
s
.72211 .87686 m .72497 .87512 L .72506 .87528 L p 0 0 0 r
F P
0 g
s
.71884 .12128 m .71878 .12117 L .71882 .12119 L p .003 .448 .865 r
F P
0 g
s
.71882 .12119 m .71898 .12135 L .71884 .12128 L p .003 .448 .865 r
F P
0 g
s
.0626 .49984 m .06253 .49995 L .06253 .4999 L p .95 .776 .319 r
F P
0 g
s
.06253 .4999 m .06259 .49968 L .0626 .49984 L p .95 .776 .319 r
F P
0 g
s
.71856 .87888 m .71869 .87889 L .71865 .87891 L p .003 0 0 r
F P
0 g
s
.71865 .87891 m .71843 .87897 L .71856 .87888 L p .003 0 0 r
F P
0 g
s
.71869 .12111 m .71856 .12112 L .71843 .12103 L p .003 .449 .865 r
F P
0 g
s
.71856 .12112 m .71869 .12111 L .71873 .12114 L p .003 .449 .865 r
F P
0 g
s
.71878 .87883 m .71884 .87872 L .71898 .87865 L p .003 0 0 r
F P
0 g
s
.71884 .87872 m .71878 .87883 L .71873 .87886 L p .003 0 0 r
F P
0 g
s
.06253 .50005 m .0626 .50016 L .06259 .50032 L p .95 .775 .318 r
F P
0 g
s
.0626 .50016 m .06253 .50005 L .06253 .5 L p .95 .775 .319 r
F P
0 g
s
.06253 .5001 m .06259 .50032 L .06258 .50046 L p .95 .775 .318 r
F P
0 g
s
.06259 .50032 m .06253 .5001 L .06253 .50005 L p .95 .775 .318 r
F P
0 g
s
.71865 .12109 m .71843 .12103 L .71831 .12095 L p .003 .449 .865 r
F P
0 g
s
.71843 .12103 m .71865 .12109 L .71869 .12111 L p .003 .449 .865 r
F P
0 g
s
.71882 .87881 m .71898 .87865 L .71911 .87859 L p .002 0 0 r
F P
0 g
s
.71898 .87865 m .71882 .87881 L .71878 .87883 L p .003 0 0 r
F P
0 g
s
.71898 .12135 m .71882 .12119 L .71886 .12121 L p .002 .448 .865 r
F P
0 g
s
.71886 .12121 m .71911 .12141 L .71898 .12135 L p .002 .448 .865 r
F P
0 g
s
.71843 .87897 m .71865 .87891 L .71861 .87894 L p .003 0 0 r
F P
0 g
s
.71861 .87894 m .71831 .87905 L .71843 .87897 L p .003 0 0 r
F P
0 g
s
.06259 .49968 m .06253 .4999 L .06253 .49985 L p .95 .776 .319 r
F P
0 g
s
.06253 .49985 m .06258 .49954 L .06259 .49968 L p .95 .776 .319 r
F P
0 g
s
.71861 .12106 m .71831 .12095 L .71821 .12088 L p .003 .449 .865 r
F P
0 g
s
.71831 .12095 m .71861 .12106 L .71865 .12109 L p .003 .449 .865 r
F P
0 g
s
.71886 .87879 m .71911 .87859 L .71922 .87854 L p .002 0 0 r
F P
0 g
s
.71911 .87859 m .71886 .87879 L .71882 .87881 L p .002 0 0 r
F P
0 g
s
.06253 .50015 m .06258 .50046 L .06257 .50058 L p .95 .775 .318 r
F P
0 g
s
.06258 .50046 m .06253 .50015 L .06253 .5001 L p .95 .775 .318 r
F P
0 g
s
.71911 .12141 m .71886 .12121 L .7189 .12122 L p .002 .448 .865 r
F P
0 g
s
.7189 .12122 m .71922 .12146 L .71911 .12141 L p .002 .448 .865 r
F P
0 g
s
.71831 .87905 m .71861 .87894 L .71858 .87896 L p .003 0 0 r
F P
0 g
s
.71858 .87896 m .71821 .87912 L .71831 .87905 L p .003 0 0 r
F P
0 g
s
.06258 .49954 m .06253 .49985 L .06252 .49982 L p .95 .776 .318 r
F P
0 g
s
.06252 .49982 m .06257 .49942 L .06258 .49954 L p .95 .776 .318 r
F P
0 g
s
.06258 .49819 m .06253 .49926 L .06251 .49922 L p .949 .777 .319 r
F P
0 g
s
.06251 .49922 m .06253 .49811 L .06258 .49819 L p .949 .777 .319 r
F P
0 g
s
.72028 .12209 m .71938 .12151 L .71942 .12151 L p 0 .446 .864 r
F P
0 g
s
.71942 .12151 m .72038 .12209 L .72028 .12209 L p 0 .446 .864 r
F P
0 g
s
.71532 .11921 m .7171 .12019 L .71714 .12028 L p .007 .454 .868 r
F P
0 g
s
.71809 .12077 m .71714 .12028 L .7171 .12019 L p .003 .45 .866 r
F P
0 g
s
.71714 .12028 m .71809 .12077 L .71814 .12082 L p .005 .451 .866 r
F P
0 g
s
.71714 .87972 m .71809 .87923 L .71807 .87926 L p .003 0 0 r
F P
0 g
s
.71807 .87926 m .7171 .87981 L .71714 .87972 L p .003 0 0 r
F P
0 g
s
.72211 .87686 m .72038 .87791 L .72028 .87791 L p 0 0 0 r
F P
0 g
s
.71938 .87849 m .72028 .87791 L .72038 .87791 L p 0 0 0 r
F P
0 g
s
.72028 .87791 m .71938 .87849 L .71931 .87851 L p .002 0 0 r
F P
0 g
s
.06257 .50392 m .06253 .50189 L .06258 .50181 L p .95 .772 .315 r
F P
0 g
s
.06253 .50074 m .06258 .50181 L .06253 .50189 L p .949 .774 .316 r
F P
0 g
s
.06258 .50181 m .06253 .50074 L .06255 .50068 L p .95 .774 .317 r
F P
0 g
s
.06252 .50018 m .06257 .50058 L .06255 .50068 L p .949 .775 .317 r
F P
0 g
s
.06257 .50058 m .06252 .50018 L .06253 .50015 L p .95 .775 .318 r
F P
0 g
s
.71858 .12104 m .71821 .12088 L .71814 .12082 L p .002 .449 .865 r
F P
0 g
s
.71821 .12088 m .71858 .12104 L .71861 .12106 L p .003 .449 .865 r
F P
0 g
s
.7189 .87878 m .71922 .87854 L .71931 .87851 L p .001 0 0 r
F P
0 g
s
.71922 .87854 m .7189 .87878 L .71886 .87879 L p .002 0 0 r
F P
0 g
s
.71922 .12146 m .7189 .12122 L .71893 .12123 L p .001 .447 .864 r
F P
0 g
s
.71893 .12123 m .71931 .12149 L .71922 .12146 L p .001 .447 .864 r
F P
0 g
s
.71821 .87912 m .71858 .87896 L .71856 .87898 L p .002 0 0 r
F P
0 g
s
.71856 .87898 m .71814 .87918 L .71821 .87912 L p .002 0 0 r
F P
0 g
s
.06257 .49942 m .06252 .49982 L .06252 .49979 L p .949 .776 .318 r
F P
0 g
s
.06252 .49979 m .06255 .49932 L .06257 .49942 L p .949 .776 .318 r
F P
0 g
s
.72211 .12314 m .72038 .12209 L .7204 .12204 L p 0 .442 .862 r
F P
0 g
s
.7204 .12204 m .72217 .12305 L .72211 .12314 L p 0 .442 .862 r
F P
0 g
s
.71532 .88079 m .7171 .87981 L .71712 .87985 L p .004 0 0 r
F P
0 g
s
.71712 .87985 m .71537 .88088 L .71532 .88079 L p .004 0 0 r
F P
0 g
s
.06257 .49608 m .06253 .49811 L .06248 .49811 L p .949 .778 .32 r
F P
0 g
s
.06248 .49811 m .06247 .49607 L .06257 .49608 L p .949 .778 .32 r
F P
0 g
s
.06247 .50727 m .06247 .50393 L .06257 .50392 L p .949 .768 .308 r
F P
0 g
s
.06253 .50189 m .06257 .50392 L .06247 .50393 L p .949 .771 .312 r
F P
0 g
s
.71247 .11745 m .71537 .11912 L .71532 .11921 L p .007 .456 .868 r
F P
0 g
s
.7171 .12019 m .71532 .11921 L .71537 .11912 L p .004 .452 .866 r
F P
0 g
s
.72506 .87528 m .72217 .87695 L .72211 .87686 L p 0 0 0 r
F P
0 g
s
.72038 .87791 m .72211 .87686 L .72217 .87695 L p 0 0 0 r
F P
0 g
s
.06252 .50021 m .06255 .50068 L .06253 .50074 L p .949 .774 .317 r
F P
0 g
s
.06255 .50068 m .06252 .50021 L .06252 .50018 L p .949 .775 .317 r
F P
0 g
s
.71893 .87877 m .71931 .87851 L .71938 .87849 L p .001 0 0 r
F P
0 g
s
.71931 .87851 m .71893 .87877 L .7189 .87878 L p .001 0 0 r
F P
0 g
s
.71856 .12102 m .71814 .12082 L .71809 .12077 L p .002 .449 .865 r
F P
0 g
s
.71814 .12082 m .71856 .12102 L .71858 .12104 L p .002 .449 .865 r
F P
0 g
s
.06255 .49932 m .06252 .49979 L .06251 .49976 L p .949 .776 .318 r
F P
0 g
s
.06251 .49976 m .06253 .49926 L .06255 .49932 L p .949 .776 .318 r
F P
0 g
s
.71931 .12149 m .71893 .12123 L .71895 .12124 L p .001 .447 .864 r
F P
0 g
s
.71895 .12124 m .71938 .12151 L .71931 .12149 L p .001 .447 .864 r
F P
0 g
s
.71814 .87918 m .71856 .87898 L .71854 .879 L p .002 0 0 r
F P
0 g
s
.71854 .879 m .71809 .87923 L .71814 .87918 L p .002 0 0 r
F P
0 g
s
.71875 .12112 m .71873 .12114 L .71869 .12111 L p .001 .448 .864 r
F P
0 g
s
.71873 .12114 m .71875 .12112 L .71876 .12112 L p .001 .448 .864 r
F P
0 g
s
.71876 .12112 m .71878 .12117 L .71873 .12114 L p .001 .448 .864 r
F P
0 g
s
.71875 .87888 m .71873 .87886 L .71878 .87883 L p .001 0 0 r
F P
0 g
s
.71873 .87886 m .71875 .87888 L .71874 .87889 L p .001 0 0 r
F P
0 g
s
.71874 .87889 m .71869 .87889 L .71873 .87886 L p .001 0 0 r
F P
0 g
s
.06251 .5 m .06253 .5 L .06253 .50005 L p .949 .775 .317 r
F P
0 g
s
.06253 .5 m .06251 .5 L .06251 .49999 L p .949 .775 .317 r
F P
0 g
s
.06251 .49999 m .06253 .49995 L .06253 .5 L p .949 .775 .317 r
F P
0 g
s
.71876 .87888 m .71878 .87883 L .71882 .87881 L p .001 0 0 r
F P
0 g
s
.71878 .87883 m .71876 .87888 L .71875 .87888 L p .001 0 0 r
F P
0 g
s
.71874 .12111 m .71869 .12111 L .71865 .12109 L p .001 .448 .864 r
F P
0 g
s
.71869 .12111 m .71874 .12111 L .71875 .12112 L p .001 .448 .864 r
F P
0 g
s
.06251 .50001 m .06253 .50005 L .06253 .5001 L p .949 .775 .317 r
F P
0 g
s
.06253 .50005 m .06251 .50001 L .06251 .5 L p .949 .775 .317 r
F P
0 g
s
.71869 .87889 m .71874 .87889 L .71873 .87889 L p .001 0 0 r
F P
0 g
s
.71873 .87889 m .71865 .87891 L .71869 .87889 L p .001 0 0 r
F P
0 g
s
.71878 .12117 m .71876 .12112 L .71876 .12113 L p .001 .448 .864 r
F P
0 g
s
.71876 .12113 m .71882 .12119 L .71878 .12117 L p .001 .448 .864 r
F P
0 g
s
.06253 .49995 m .06251 .49999 L .06251 .49998 L p .949 .775 .317 r
F P
0 g
s
.06251 .49998 m .06253 .4999 L .06253 .49995 L p .949 .775 .317 r
F P
0 g
s
.7171 .12019 m .71807 .12074 L .71809 .12077 L p .003 .45 .866 r
F P
0 g
s
.71854 .121 m .71809 .12077 L .71807 .12074 L p .001 .448 .865 r
F P
0 g
s
.71809 .12077 m .71854 .121 L .71856 .12102 L p .002 .449 .865 r
F P
0 g
s
.71938 .12151 m .71895 .12124 L .71896 .12124 L p 0 .447 .864 r
F P
0 g
s
.71896 .12124 m .71942 .12151 L .71938 .12151 L p 0 .447 .864 r
F P
0 g
s
.06253 .49926 m .06251 .49976 L .0625 .49975 L p .949 .775 .317 r
F P
0 g
s
.0625 .49975 m .06251 .49922 L .06253 .49926 L p .949 .775 .317 r
F P
0 g
s
.72038 .87791 m .71942 .87849 L .71938 .87849 L p 0 0 0 r
F P
0 g
s
.71895 .87876 m .71938 .87849 L .71942 .87849 L p 0 0 0 r
F P
0 g
s
.71938 .87849 m .71895 .87876 L .71893 .87877 L p .001 0 0 r
F P
0 g
s
.71809 .87923 m .71854 .879 L .71854 .87901 L p .001 0 0 r
F P
0 g
s
.71854 .87901 m .71807 .87926 L .71809 .87923 L p .001 0 0 r
F P
0 g
s
.06253 .50189 m .06251 .50078 L .06253 .50074 L p .949 .774 .316 r
F P
0 g
s
.06251 .50024 m .06253 .50074 L .06251 .50078 L p .949 .774 .316 r
F P
0 g
s
.06253 .50074 m .06251 .50024 L .06252 .50021 L p .949 .774 .317 r
F P
0 g
s
.06251 .50002 m .06253 .5001 L .06253 .50015 L p .949 .775 .317 r
F P
0 g
s
.06253 .5001 m .06251 .50002 L .06251 .50001 L p .949 .775 .317 r
F P
0 g
s
.71865 .87891 m .71873 .87889 L .71872 .8789 L p .001 0 0 r
F P
0 g
s
.71872 .8789 m .71861 .87894 L .71865 .87891 L p .001 0 0 r
F P
0 g
s
.71873 .12111 m .71865 .12109 L .71861 .12106 L p .001 .448 .864 r
F P
0 g
s
.71865 .12109 m .71873 .12111 L .71874 .12111 L p .001 .448 .864 r
F P
0 g
s
.71882 .12119 m .71876 .12113 L .71877 .12113 L p .001 .447 .864 r
F P
0 g
s
.71877 .12113 m .71886 .12121 L .71882 .12119 L p .001 .447 .864 r
F P
0 g
s
.71876 .87887 m .71882 .87881 L .71886 .87879 L p .001 0 0 r
F P
0 g
s
.71882 .87881 m .71876 .87887 L .71876 .87888 L p .001 0 0 r
F P
0 g
s
.06253 .4999 m .06251 .49998 L .0625 .49997 L p .949 .775 .317 r
F P
0 g
s
.0625 .49997 m .06253 .49985 L .06253 .4999 L p .949 .775 .317 r
F P
0 g
s
.06253 .49985 m .0625 .49997 L .0625 .49996 L p .949 .775 .317 r
F P
0 g
s
.0625 .49996 m .06252 .49982 L .06253 .49985 L p .949 .775 .317 r
F P
0 g
s
.71861 .87894 m .71872 .8789 L .71872 .8789 L p .001 0 0 r
F P
0 g
s
.71872 .8789 m .71858 .87896 L .71861 .87894 L p .001 0 0 r
F P
0 g
s
.71886 .12121 m .71877 .12113 L .71878 .12114 L p .001 .447 .864 r
F P
0 g
s
.71878 .12114 m .7189 .12122 L .71886 .12121 L p .001 .447 .864 r
F P
0 g
s
.0625 .50003 m .06253 .50015 L .06252 .50018 L p .949 .775 .317 r
F P
0 g
s
.06253 .50015 m .0625 .50003 L .06251 .50002 L p .949 .775 .317 r
F P
0 g
s
.71872 .1211 m .71861 .12106 L .71858 .12104 L p .001 .448 .864 r
F P
0 g
s
.71861 .12106 m .71872 .1211 L .71873 .12111 L p .001 .448 .864 r
F P
0 g
s
.71877 .87887 m .71886 .87879 L .7189 .87878 L p .001 0 0 r
F P
0 g
s
.71886 .87879 m .71877 .87887 L .71876 .87887 L p .001 0 0 r
F P
0 g
s
.06247 .50393 m .06248 .50189 L .06253 .50189 L p .949 .771 .312 r
F P
0 g
s
.06251 .50078 m .06253 .50189 L .06248 .50189 L p .949 .773 .314 r
F P
0 g
s
.71537 .11912 m .71712 .12015 L .7171 .12019 L p .004 .452 .866 r
F P
0 g
s
.71807 .12074 m .7171 .12019 L .71712 .12015 L p .002 .449 .865 r
F P
0 g
s
.72217 .87695 m .7204 .87796 L .72038 .87791 L p 0 0 0 r
F P
0 g
s
.71942 .87849 m .72038 .87791 L .7204 .87796 L p 0 0 0 r
F P
0 g
s
.7171 .87981 m .71807 .87926 L .71808 .87928 L p .002 0 0 r
F P
0 g
s
.71808 .87928 m .71712 .87985 L .7171 .87981 L p .002 0 0 r
F P
0 g
s
.72038 .12209 m .71942 .12151 L .71943 .12149 L p 0 .445 .863 r
F P
0 g
s
.71943 .12149 m .7204 .12204 L .72038 .12209 L p 0 .445 .863 r
F P
0 g
s
.06253 .49811 m .06251 .49922 L .06249 .49922 L p .949 .776 .318 r
F P
0 g
s
.06249 .49922 m .06248 .49811 L .06253 .49811 L p .949 .776 .318 r
F P
0 g
s
.0625 .50004 m .06252 .50018 L .06252 .50021 L p .949 .775 .316 r
F P
0 g
s
.06252 .50018 m .0625 .50004 L .0625 .50003 L p .949 .775 .317 r
F P
0 g
s
.71872 .1211 m .71858 .12104 L .71856 .12102 L p .001 .448 .864 r
F P
0 g
s
.71858 .12104 m .71872 .1211 L .71872 .1211 L p .001 .448 .864 r
F P
0 g
s
.7189 .12122 m .71878 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.71879 .12114 m .71893 .12123 L .7189 .12122 L p 0 .447 .864 r
F P
0 g
s
.71858 .87896 m .71872 .8789 L .71871 .8789 L p .001 0 0 r
F P
0 g
s
.71871 .8789 m .71856 .87898 L .71858 .87896 L p .001 0 0 r
F P
0 g
s
.71878 .87886 m .7189 .87878 L .71893 .87877 L p 0 0 0 r
F P
0 g
s
.7189 .87878 m .71878 .87886 L .71877 .87887 L p .001 0 0 r
F P
0 g
s
.06252 .49982 m .0625 .49996 L .0625 .49996 L p .949 .775 .317 r
F P
0 g
s
.0625 .49996 m .06252 .49979 L .06252 .49982 L p .949 .775 .317 r
F P
0 g
s
.71893 .12123 m .71879 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.71879 .12114 m .71895 .12124 L .71893 .12123 L p 0 .447 .864 r
F P
0 g
s
.71856 .87898 m .71871 .8789 L .71871 .87891 L p .001 0 0 r
F P
0 g
s
.71871 .87891 m .71854 .879 L .71856 .87898 L p .001 0 0 r
F P
0 g
s
.0625 .50004 m .06252 .50021 L .06251 .50024 L p .949 .775 .316 r
F P
0 g
s
.06252 .50021 m .0625 .50004 L .0625 .50004 L p .949 .775 .316 r
F P
0 g
s
.06252 .49979 m .0625 .49996 L .0625 .49995 L p .949 .775 .317 r
F P
0 g
s
.0625 .49995 m .06251 .49976 L .06252 .49979 L p .949 .775 .317 r
F P
0 g
s
.71871 .1211 m .71856 .12102 L .71854 .121 L p .001 .448 .864 r
F P
0 g
s
.71856 .12102 m .71871 .1211 L .71872 .1211 L p .001 .448 .864 r
F P
0 g
s
.71879 .87886 m .71893 .87877 L .71895 .87876 L p 0 0 0 r
F P
0 g
s
.71893 .87877 m .71879 .87886 L .71878 .87886 L p 0 0 0 r
F P
0 g
s
.71712 .12015 m .71808 .12072 L .71807 .12074 L p .002 .449 .865 r
F P
0 g
s
.71854 .12099 m .71807 .12074 L .71808 .12072 L p .001 .448 .864 r
F P
0 g
s
.71807 .12074 m .71854 .12099 L .71854 .121 L p .001 .448 .865 r
F P
0 g
s
.71942 .12151 m .71896 .12124 L .71896 .12123 L p 0 .446 .864 r
F P
0 g
s
.71896 .12123 m .71943 .12149 L .71942 .12151 L p 0 .446 .864 r
F P
0 g
s
.71807 .87926 m .71854 .87901 L .71854 .87901 L p .001 0 0 r
F P
0 g
s
.71854 .87901 m .71808 .87928 L .71807 .87926 L p .001 0 0 r
F P
0 g
s
.7204 .87796 m .71943 .87851 L .71942 .87849 L p 0 0 0 r
F P
0 g
s
.71896 .87876 m .71942 .87849 L .71943 .87851 L p 0 0 0 r
F P
0 g
s
.71942 .87849 m .71896 .87876 L .71895 .87876 L p 0 0 0 r
F P
0 g
s
.06251 .49922 m .0625 .49975 L .0625 .49975 L p .949 .775 .317 r
F P
0 g
s
.0625 .49975 m .06249 .49922 L .06251 .49922 L p .949 .775 .317 r
F P
0 g
s
.06248 .50189 m .06249 .50078 L .06251 .50078 L p .949 .773 .314 r
F P
0 g
s
.0625 .50025 m .06251 .50078 L .06249 .50078 L p .949 .774 .315 r
F P
0 g
s
.06251 .50078 m .0625 .50025 L .06251 .50024 L p .949 .774 .316 r
F P
0 g
s
.0625 .50005 m .06251 .50024 L .0625 .50025 L p .949 .774 .316 r
F P
0 g
s
.06251 .50024 m .0625 .50005 L .0625 .50004 L p .949 .775 .316 r
F P
0 g
s
.06251 .49976 m .0625 .49995 L .0625 .49995 L p .949 .775 .317 r
F P
0 g
s
.0625 .49995 m .0625 .49975 L .06251 .49976 L p .949 .775 .317 r
F P
0 g
s
.71895 .12124 m .71879 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.71879 .12114 m .71896 .12124 L .71895 .12124 L p 0 .447 .864 r
F P
0 g
s
.71871 .12109 m .71854 .121 L .71854 .12099 L p 0 .448 .864 r
F P
0 g
s
.71854 .121 m .71871 .12109 L .71871 .1211 L p .001 .448 .864 r
F P
0 g
s
.71854 .879 m .71871 .87891 L .71871 .87891 L p 0 0 0 r
F P
0 g
s
.71871 .87891 m .71854 .87901 L .71854 .879 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71895 .87876 L .71896 .87876 L p 0 0 0 r
F P
0 g
s
.71895 .87876 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.0625 .5 m .06251 .5 L .06251 .50001 L p .949 .775 .316 r
F P
0 g
s
.06251 .5 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .06251 .49999 L .06251 .5 L p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71874 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71876 .87888 L p 0 0 0 r
F P
0 g
s
.71875 .87888 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71875 .87888 L p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71873 .12111 L p 0 .447 .864 r
F P
0 g
s
.71874 .12111 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.06251 .49999 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .06251 .49998 L .06251 .49999 L p .949 .775 .316 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87887 L p 0 0 0 r
F P
0 g
s
.71876 .87888 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.0625 .5 m .06251 .50001 L .06251 .50002 L p .949 .775 .316 r
F P
0 g
s
.06251 .50001 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.71874 .87889 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71873 .87889 L .71874 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .12112 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12113 L .71876 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .12111 L .71872 .1211 L p 0 .447 .864 r
F P
0 g
s
.71873 .12111 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .06251 .50002 L .0625 .50003 L p .949 .775 .316 r
F P
0 g
s
.06251 .50002 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.71873 .87889 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .8789 L .71873 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .12113 m .71875 .12111 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71877 .12113 L .71876 .12113 L p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71876 .87887 L .71877 .87887 L p 0 0 0 r
F P
0 g
s
.71876 .87887 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.06251 .49998 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49997 L .06251 .49998 L p .949 .775 .316 r
F P
0 g
s
.71875 .87888 m .71877 .87887 L .71878 .87886 L p 0 0 0 r
F P
0 g
s
.71877 .87887 m .71875 .87888 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71872 .1211 L .71872 .1211 L p 0 .447 .864 r
F P
0 g
s
.71872 .1211 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .50003 L .0625 .50004 L p .949 .775 .316 r
F P
0 g
s
.0625 .50003 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.71877 .12113 m .71875 .12112 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71878 .12114 L .71877 .12113 L p 0 .447 .864 r
F P
0 g
s
.0625 .49997 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49996 L .0625 .49997 L p .949 .775 .316 r
F P
0 g
s
.71872 .8789 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .8789 L .71872 .8789 L p 0 0 0 r
F P
0 g
s
.71872 .8789 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71871 .8789 L .71872 .8789 L p 0 0 0 r
F P
0 g
s
.71878 .12114 m .71875 .12112 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71879 .12114 L .71878 .12114 L p 0 .447 .864 r
F P
0 g
s
.0625 .49996 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49996 L .0625 .49996 L p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71872 .1211 L .71871 .1211 L p 0 .447 .864 r
F P
0 g
s
.71872 .1211 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .50004 L .0625 .50004 L p .949 .775 .316 r
F P
0 g
s
.0625 .50004 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.71875 .87888 m .71878 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71878 .87886 m .71875 .87888 L .71875 .87888 L p 0 0 0 r
F P
0 g
s
.71896 .12124 m .71879 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.71879 .12114 m .71896 .12123 L .71896 .12124 L p 0 .447 .864 r
F P
0 g
s
.0625 .49975 m .0625 .49995 L .0625 .49995 L p .949 .775 .316 r
F P
0 g
s
.0625 .49995 m .0625 .49975 L .0625 .49975 L p .949 .775 .316 r
F P
0 g
s
.71854 .87901 m .71871 .87891 L .71871 .87891 L p 0 0 0 r
F P
0 g
s
.71871 .87891 m .71854 .87901 L .71854 .87901 L p 0 0 0 r
F P
0 g
s
.71808 .12072 m .71854 .12099 L .71854 .12099 L p .001 .448 .864 r
F P
0 g
s
.71871 .12109 m .71854 .12099 L .71854 .12099 L p 0 .447 .864 r
F P
0 g
s
.71854 .12099 m .71871 .12109 L .71871 .12109 L p 0 .448 .864 r
F P
0 g
s
.71943 .87851 m .71896 .87877 L .71896 .87876 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71896 .87876 L .71896 .87877 L p 0 0 0 r
F P
0 g
s
.71896 .87876 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.06249 .50078 m .0625 .50025 L .0625 .50025 L p .949 .774 .315 r
F P
0 g
s
.0625 .50005 m .0625 .50025 L .0625 .50025 L p .949 .774 .316 r
F P
0 g
s
.0625 .50025 m .0625 .50005 L .0625 .50005 L p .949 .774 .316 r
F P
0 g
s
.71879 .12114 m .71875 .12112 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71879 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71871 .1211 L .71871 .12109 L p 0 .447 .864 r
F P
0 g
s
.71871 .1211 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .87888 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71875 .87888 L .71875 .87888 L p 0 0 0 r
F P
0 g
s
.0625 .49996 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49995 L .0625 .49996 L p .949 .775 .316 r
F P
0 g
s
.71871 .8789 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71871 .87891 L .71871 .8789 L p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50004 L .0625 .50005 L p .949 .775 .316 r
F P
0 g
s
.0625 .50004 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .49995 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49995 L .0625 .49995 L p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71871 .12109 L .71871 .12109 L p 0 .447 .864 r
F P
0 g
s
.71871 .12109 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .50005 L .0625 .50005 L p .949 .775 .316 r
F P
0 g
s
.0625 .50005 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.71875 .87888 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71875 .87888 L .71875 .87888 L p 0 0 0 r
F P
0 g
s
.71871 .87891 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71871 .87891 L .71871 .87891 L p 0 0 0 r
F P
0 g
s
.71879 .12114 m .71875 .12112 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71879 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.0625 .49995 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49995 L .0625 .49995 L p .949 .775 .316 r
F P
0 g
s
.71879 .12114 m .71875 .12112 L .71875 .12112 L p 0 .447 .864 r
F P
0 g
s
.71875 .12112 m .71879 .12114 L .71879 .12114 L p 0 .447 .864 r
F P
0 g
s
.71871 .87891 m .71875 .87889 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71871 .87891 L .71871 .87891 L p 0 0 0 r
F P
0 g
s
.0625 .50025 m .0625 .50005 L .0625 .50005 L p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50005 L .0625 .50005 L p .949 .775 .316 r
F P
0 g
s
.0625 .50005 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.71854 .12099 m .71871 .12109 L .71871 .12109 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71871 .12109 L .71871 .12109 L p 0 .447 .864 r
F P
0 g
s
.71871 .12109 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71896 .87877 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71875 .87888 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71875 .87888 L .71875 .87888 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71875 .87888 L .71875 .87888 L p 0 0 0 r
F P
0 g
s
.71871 .12109 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.0625 .50005 m .0625 .5 L .0625 .5 L p .949 .775 .316 r
F P
0 g
s
.36481 .91609 m
.39601 .92445 L
s
.32205 .89968 m
.34661 .9091 L
s
.35117 .91085 m
.36481 .91609 L
s
.28125 .87889 m
.32205 .89968 L
s
.24284 .85394 m
.28125 .87889 L
s
.20726 .82513 m
.2186 .83431 L
s
.2224 .83739 m
.24284 .85394 L
s
.18441 .80228 m
.20726 .82513 L
s
.08841 .64692 m
.09053 .65242 L
s
.07463 .60055 m
.08038 .622 L
s
.06517 .54743 m
.07151 .5875 L
s
.0625 .5 m
.06485 .54493 L
s
.0625 .5 m
.06485 .45507 L
s
.06517 .45257 m
.07151 .4125 L
s
.07463 .39945 m
.08038 .378 L
s
.08841 .35308 m
.09053 .34758 L
s
.18441 .19772 m
.20726 .17487 L
s
.20726 .17487 m
.2186 .16569 L
s
.2224 .16261 m
.24284 .14606 L
s
.24284 .14606 m
.28125 .12111 L
s
.28125 .12111 m
.32205 .10032 L
s
.32205 .10032 m
.34661 .0909 L
s
.35117 .08915 m
.36481 .08391 L
s
.36481 .08391 m
.39601 .07555 L
s
.57274 .93083 m
.57855 .9299 L
s
.60416 .9244 m
.6256 .91866 L
s
.63847 .91483 m
.67634 .90029 L
s
.67866 .89931 m
.71875 .87889 L
s
.71875 .87889 m
.75648 .85438 L
s
.75849 .85286 m
.79002 .82733 L
s
.79977 .8181 m
.81547 .8024 L
s
.83303 .78298 m
.83674 .7784 L
s
.91958 .62217 m
.92794 .59096 L
s
.92794 .59096 m
.93022 .57654 L
s
.93099 .57171 m
.9351 .54573 L
s
.9375 .5 m
.9351 .54573 L
s
.9351 .45427 m
.9375 .5 L
s
.92794 .40904 m
.93022 .42346 L
s
.93099 .42829 m
.9351 .45427 L
s
.91958 .37783 m
.92794 .40904 L
s
.83303 .21702 m
.83674 .2216 L
s
.79977 .1819 m
.81547 .1976 L
s
.75849 .14714 m
.79002 .17267 L
s
.71875 .12111 m
.75648 .14562 L
s
.67866 .10069 m
.71875 .12111 L
s
.63847 .08517 m
.67634 .09971 L
s
.60416 .0756 m
.6256 .08134 L
s
.57274 .06917 m
.57855 .0701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
      ImageSize->{288, 288},
      ImageMargins->{{0, 0}, {0, 0}},
      ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00QOoooaL00024
oooo001loooo2@0000AVeo400`000536lU36lP0<D<Kb00@0000m]_4m]_4m]_460000O_ooo`00M_oo
o`H0000=I]Oa5P0000<m]_460000N?ooo`00L_ooo`@000000h7Wj`0006KGl@08I]Oa1P0000>BgOh0
0`0007W?ogW?o`0<NLoo00<0001R`OeR`Od00f;1o@h0001coooo001_oooo0`0000J1in/00`0006KG
lFKGl@0600002Y;MoP030000NLooNLoo00Eicol>000016;1o@030000C[;jC[;j00@000000bjWk`00
000000020000Koooo`00K?ooo`@00008PNO[0`00016BgOh7000028g;o@030000Ml7mMl7m00=g`Od8
000014jbnPL0001/oooo001Xoooo1@0000J1in/400000Z_XnP800009T]gn1P0000>Qd_T00`0008g;
oHg;o@0<SL_m00<0001g`Oeg`Od027O1o@030000H[Gl000000@0000014jbnP0003bUmCbUm@@0001Z
oooo001Uoooo1@0000J1in/300002:_XnP040000T]gnT]gnT]gn2`0000BQd_T00`0008g;oHg;o@0<
SL_m00<0001g`Oeg`Od027O1o@030000H[GlH[Gl00=R]O`500000cbUm@<0001Woooo001Soooo0`00
00N1in/300000Z_XnPh00007EL_`00<0000PWNTPWNT010000003XM;i0000SL_m00Z=bodC00000f:e
o0030000CZWi0000008000000cbUm@0002fIl0040000Hoooo`00HOooo`<00005PNO[2@0001EEbo00
0`00022MjB2Mj@0489gY100000>=bod6000019C2mP800009P[_i0P00009^/oXB0000H?ooo`00G_oo
o`@00002WOGN00<00021in/000000`000003PNSY0000EL_`01YEbo000`00022MjB2Mj@0889gY1000
00^D`_H00`0008:knH:kn@08P[_i0P0000I^/oX2000000=JZOT0000000000P000003?9kd00000000
00@0001Noooo001Koooo100000FMmMh300001H7Xj@030000EL_`EL_`00]Ebo0?00003B2Mj@@00008
U<;f0P0000F2^oT@00000UZYn@8000000cbNm00002bCk`040000G?ooo`00FOooo`@00004WOGN0`00
00N1j>T?00003IkAn@030000QKKf000000<0000=89gY100000FD`_H600001XNem0030000MJofMJof
00Ee[oH2000000=RZ?L0000000002P0005[oool005Ooool2000000?oool0002MmMh00YgegP<00007
PNSY0`000003]^Cf0000W]7i01RNdOT00`0008FfmXFfmP04QKKf100000dPWNT500000YNik`800009
QkGd0P0000Me[oH0100006:Xmf:Xmf:Xm`L0000011N6j0000000000005Soool005Goool2000000Co
ool00000002MmMh300001h7Xj@<00004]^Cf00<0002NdOVNdOT05ikAn@030000QKKfQKKf00R5]_H4
00003B2Mj@800003UkW_00<00027]OB7]O@028Nem0030000MJofMJof009e[oH:000000=>WoD0000l
U_801`0005Goool005?oool2000000?oool0000000000`0000N1j>T300001kKTmP030000W]7iW]7i
01NNdOT00`0008FfmXFfmP0<QKKf100000XPWNT300000YNik`030000QkGdQkGd00J7]O@6000017NZ
lP030000IJCdIJCd009UY?@<0000E?ooo`00DOooo`8000000oooo`00000000020000287Xj@80000:
]^Cf00<0002NdOVNdOT05ikAn@030000QKKfQKKf0125]_H400001R2Mj@04000005g?05g?00000YNi
k`800002QkGd100000>8[^l200001WNZlP800004IJCd00D0001BWO@000000010UO401`0005;oool0
053oool00`000?ooo`0000020000287Xj@<0000<]^Cf00<0002NdOVNdOT05YkAn@030000QKKfQKKf
01F5]_H300000R2Mj@03000005g?05g?0080GLl2000000BG^Nl0000000000009R:k_00<0001gZ_9g
Z_801GNZlP030000IJCdIJCd00l0001@oooo001>oooo100000:MmMh6PNSY0`0000jfi?H00`0009kA
nIkAn@0GW]7i00<00025]_J5]_H06HFfmP80000605g?00<0002F/>VF/>T00P0000V8[^l200000gNZ
lPD00004IZ3a0P000003Di[b0000000000L0001?oooo001=oooo00@0003oool000000004WOGN00>1
j>T0000000000P00016fi?H00`0009kAnIkAn@0GW]7i00<00025]_J5]_H06HFfmP040000JICX0000
00001@1Mc`800002U[3Y0P0000R8[^l4000017NTk`800005IZ3a00<0001BU_1BU_002@0004goool0
04_oool2000000?oool0002SmmX00Z?gfP:MmMh300005;KTmP030000W]7iW]7i01NNdOT00`0008Ff
mXFfmP0IQKKf00D0001YU>QYU>QYU>P000001P1Mc`050000U[3YU[3YU[3Y000000F8[^l200000XJW
jP800006MjC_0P000004IZ3a00000000I9__0P00009BU_000`0003j<kSj<kP050000C?ooo`00BOoo
o`8000001?ooo`0000000;_la`:SmmX300000/;_lAFfi?H00`0009kAnIkAn@0FW]7i00<00025]_J5
]_H06HFfmP030000JICXJICX00=YU>P200001@1Mc`800002U[3Y0P000003R:k_0000000000J6YnX0
0`0007NTkgNTk`05MjC_00<0001TVnmTVnl00fBKk`030000DYK`000000@000000bEoj00000000002
0000B_ooo`00B?ooo`030000oooo000000800003^oc700D0003:lNc:lNc:lNc2ko405[KTmP030000
W]7iW]7i00ZNdOT>00006XFfmP030000JICXJICX00EYU>P00`00001Mc`1Mc`0405g?00D0002F/>VF
/>VF/>T000002HJWjP030000MjC_MjC_009gY>l200000WBNj`800003I9__0P00009?TNh01@0003V8
k000000001eji@030000BOooo`00A_ooo`8000001?ooo`000000000000Bko<L01@000<[ak<[ak000
0<;_l@0D]^Cf3`0000ba`^L00`000:2`h`00000300005HFfmP030000JICXJICX00MYU>P00`00001M
c`1Mc`0405g?0`000003TjSU0000000000R6YnX2000000=gY>l0001dW^/01GBNj`8000000fBKk`00
05nEk005000000<bPnT000000000100004Ooool004Goool00`000?ooo`00000200001K_la`030000
f?3Rf?3R00;Hl>800kKTmP000;KTmP0>]^Cf0`0000?1dNH00`000;72ik72i`0E/L;W00<0002P/>>P
/><01:2`h`<0000BQKKf00<0001YU>QYU>P026VDj080000605g?00D0002CZ>FCZ>FCZ>D000002HJW
jP030000M9k[M9k[00MdW^/00`0005nEk5nEk002GiG/00<00019S>a9S>`00`000003:7gV00000000
00800016oooo0014oooo0`000003XoOJ0000^oc700Bko<L00`000=S`h]S`hP04f?3R3;KTmP@00006
`M7V00<0002a`^Na`^L05K72i`030000X;3SX;3S00NP/><400003HFfmP030000JICXJICX00]YU>P0
0`00001Mc`1Mc`0405g?0P0000:CZ>D200001XJWjP030000PZ3VPZ3V00800006M9k[0P0000=OUN`3
000000=9S>`0000000001`0004Coool004;oool300000Z?gfP030000^oc7^oc700>ko<L00`000=S`
h]S`hP06f?3R1kKTmP@00009`M7V00<0002a`^Na`^L05[72i`030000X;3SX;3S00^P/><300002XFf
mP030000JICXJICX00aYU>P200001P1Mc`050000TjSUTjSUTjSU000000B6YnX00`0008:PiX:PiP03
PZ3V0P0000=dW^/00`0006nHj6nHj002000000AOUN`0001ISnYISnX200000T26j@D000000`1KdP00
0?ooo`12oooo0011oooo0`0000:SmmX00`000;_lak_la`02^oc70P0000WHl>83]^Cf100000g1dNH0
0`000;72ik72i`0E/L;W00<0002P/>>P/><03j2`h`<00006QKKf00<0001YU>QYU>P03fVDj0030000
05g?05g?00@0GLl200000Y>Xi@8000000hJWjP0008:PiP07PZ3V0P000003M9k[0000KiSX00=_V>P2
000015V?jP<00002=GkV1@0004;oool0043oool200000Z?gfP800004^oc700<0003Hl>;Hl>802MS`
hP<0000A`M7V00<0002a`^Na`^L05K72i`030000X;3SX;3S01:P/><400000XFfmP030000JICXJICX
011YU>P200001P1Mc`050000TjSUTjSUTjSU000000^2X>H00`0006nHj6nHj004KiSX0P0000=ISnX0
1`0004n8i`00000003EniP0002Mfh`040000@Oooo`00?oooo`050000XoOJXoOJXoOJ000000Fko<L0
0`000=S`h]S`hP09f?3R00<0003Aemg1dNH04/7AiP030000/L;W/L;W01Ba`^L00`000:2`hj2`h`0G
X;3S0P0001EYU>P00`00001Mc`1Mc`0405g?0`000003SZ7Q0000000000R2X>H0100007fIh`000000
00A_V>P01P0006RAiP00000005V?jP0000=?R>L3000000<WM^<0000000000`0003ooool003koool0
1@000;gla`000:?gfP000005^oc700<0003Hl>;Hl>802MS`hP040000dMOMdMOMdMOM4/7AiP030000
/L;W/L;W01Ba`^L00`000:2`hj2`h`0GX;3S00@0002?V]X00000000DJICX00<00000GLl0GLl01@1M
c`040000SZ7QSZ7QSZ7Q0P0000J2X>H0100007fIhgfIhgfIh`800002KiSX00@0001XTNIXTNIXTNH3
00000Tn8i`030000@WoU000000L0000noooo000moooo00<0002mo<Nmo<L00P0000Fko<L00`000=S`
h]S`hP09f?3R00<0003AemgAemd00m7GgA31dNH00`000;72ik72i`0E/L;W00<0002P/>>P/><05j2`
h`050000Si[JSi[JSi[J000001AYU>P200001@1Mc`800004SZ7Q0P0000>2X>H00`0007fIhgfIh`04
OIWS0`0000EXTNH200000Tn8i`030000@WoU@WoU00@000000`1Pe`000000000moooo000loooo00<0
002mo<Nmo<L00[gla`030000^oc7^oc700:ko<L00`000=S`h]S`hP09f?3R00<0003AemgAemd01=7G
gA31dNH00`000;72ik72i`0D/L;W00<0002P/>>P/><05j2`h`030000Si[JSi[J00>?V]X2000056VD
j007000005g?05g?05g?000000bL000000J>XN42000000>2X>H0001mVN<01gfIh`030000J97VJ97V
00=XTNH00`0005f9h`00000200000d9oi@030000<GGQ000000@0000loooo000koooo00<0002mo<Nm
o<L00[gla`030000^oc7^oc700:ko<L00`000=S`h]S`hP09f?3R00<0003AemgAemd01]7Gg@o1dNH0
0`000;72ik72i`0D/L;W00<0002P/>>P/><05j2`h`030000Si[JSi[J00F?V]X00`0006VDj6VDj00B
JICX00@00000GLl0GLl0000200bL00<0002>XN6>XN401HjQh@030000OIWSOIWS00MmVN<300000fRA
iP040000GHWSGHWSGHWS0`000004@WoU0000<GGQ<GGQ0P0000030EWC0000000003_oool003[oool0
0`000;glakgla`02_Oc700<0002ko<Nko<L00[_la`030000f?3Rf?3R00WHl>800`000=7GgM7Gg@07
dMOM3l7AiP030000/L;W/L;W01Ba`^L00`000:2`hj2`h`0FX;3S00<0002?V]Z?V]X01hnJfP80000D
JICX00<0000039`039`00P0<W0030000SZ7QSZ7Q00>>XN40100008RIg@00000000MmVN<00`0007FA
hGFAh@0200000VRAiP060000GHWSGHWSGHWS0000D7oQ0`000005<GGQ000076WL00000EWC0080000j
oooo000ioooo00@0002mo<Nmo<Nmo<L200000k_la`80000;f?3R00<0003AemgAemd02M7Gg@g1dNH0
0`000;72ik72i`0D/L;W00<0002P/>>P/><05j2`h`030000Si[JSi[J00V?V]X00`0006VDj6VDj00@
JICX00<0001=J/l000000`0<W0030000SZ7QSZ7Q00>>XN40100008RIgHRIgHRIg@800005OIWS00<0
001eTN5eTN400WFAh@<00004GHWS00<0001@On5@On401000000376WL00000EWC0080000ioooo000g
oooo0P0000>mo<L00`000;_lak_la`02^oc700<0003Hl>;Hl>802]S`hP030000dMOMdMOM00[Aemd=
`M7V00<0002a`^Na`^L05;72i`030000X;3SX;3S01JP/><00`0008nJfXnJfP0;Si[J0P0000mYU>P0
100004eZcdeZc`0000@039`01@0008jQhHjQhHjQh@000006R9WM0P00009mVN<00`0007FAhGFAh@05
MI7Q0P0000=MRN<00`00051ohE1oh@02D7oQ0`00000376WL00000EWC0080000hoooo000foooo0P00
00>mo<L200000k_la`030000f?3Rf?3R00[Hl>800`000=7GgM7Gg@0<dMOM2l7AiPd0000:/L;W00<0
002P/>>P/><05j2`h`030000Si[JSi[J00f?V]X00`0006VDj6VDj00;JICX00<0001=J/m=J/l00TeZ
c`03000000bL00bL008039`00`0008jQh@000009R9WM0`0000MeTN40100006^8gP000000009MRN<0
1@00051ohE1ohE1oh@000002?GCM0`0000030EWC0000000003Ooool003Goool200000kgla`060000
e_NUe_NU0000^oc700003=S`hP030000dMOMdMOM00gAemd7`M7V10000003a<?I^;OI^;OI00Zh]mT<
00005j2`h`030000Si[JSi[J00n?V]X2000016VDj0X00003CF[?00L0000039`039`039`0002>XN40
00002hRIg@030000MI7QMI7Q00EeTN40100006^8gV^8gV^8gP<00004D7oQ00<0000mM=dmM=d01P00
03Koool003Coool200000kgla`030000e_NUe_NU00;FmjD200002mS`hP030000dMOMdMOM00oAemd2
`M7V100000G4`mTF^;OI00<0002[Z]H000000P0001>P/><00`0008nJfXnJfP0BSi[J10000003JmgD
0000;k7V00L_/NH>00001hRIg@<00005MI7Q00<0001[R=i[R=h00f^8gP<00002D7oQ00@0000mM=dm
M=d0000296GH00@00003DLh00000000eoooo000doooo00D0002mo<Nmo<Nmo<L000001MKgY@;Yjlh2
00002=S`hP030000dMOMdMOM013Aemd200001<C3f@05b<CGa<?Ia<?Ia<?I000001Fh]mT00`000:^Z
eZ^ZeP03Zj[F0`00012P/><00`0008nJfXnJfP0ASi[J0P0000=[gM@00`0002naiRnaiP0?;k7V00<0
39`0000_/NH00bnaiPP00002PI7J0P0000AeTN400`0006^8gV^8gP03JhSN00H0001LO]/00000001@
On400002?GCM00D0000TIMPTIMP00003DLh00P0003Coool003?oool010000;glakglakgla`800004
e_NU00<0003YjlkYjlh00^W[cP800005f?3R00<0003AemgAemd04=7Gg@030000b<CGa<?I00S4`mT0
0`000;RgfKRgf@0C^;OI00<0002[Z]J[Z]H01Z^ZeP<0000<X;3S00<0002?V]Z?V]X03hnJfP<00004
JmgD2P0000P_/NH200bL00<0000_/NH_/NH01RnaiP03000007KJ07KJ00800003PI7J0P00009eTN40
0`0006^8gV^8gP03JhSN00@0001LO]]LO]]LO]/200000cedg@05000096GH96GH00000e7>0080000c
oooo000boooo00<0002mo<Nmo<L00`0000CFmjD00`000>W[c^W[cP05jN_>0P0000;Hl>800`000=7G
gM7Gg@0@dMOM00H00038a=O8a=O8a=O4`mW8a=L6a<?I00<0002h]mVh]mT04kRgf@030000Zj[FZj[F
00V[Z]H300002J2`h`030000Si[JSi[J00b?V]X3000016_Me0<000000kWSm00009?4n007TlCh2000
00<039`8;k7V00<00000M]X0M]X00P1ffP800003PI7J0`0000I[R=h00`0005anfeanf`02G7kK0P00
008mM=d01`0002AUf00000=AcP00000h_@00000boooo000aoooo00H0002mo<Nmo<L0003Jn=h00004
e_NU00<0003YjlkYjlh02>W[cP<0000AdMOM00<00038a=O8a=L00/S4e`S4`mT00`000;RgfKRgf@0C
^;OI00<0002[Z]J[Z]H03:^ZeP<00005X;3S00<0002?V]Z?V]X02XnJfP<00005JmgD0P0000Biho@0
0`0009?4n9?4n00=TlCh00==J/l0000039`00P0<W0P0000607KJ0P0000>1TMX200001F^8gP030000
G7kKG7kK009LO]/00`0004Ubf000000200000RAUf00500000e7>000003Rm0000037oool0033oool2
000000Fmo<L0003Jn=kJn=h000001=KgY@030000jN_>jN_>00SYjlh00`000=_Acm_Ac`0300003]7G
g@030000b<CGb<CG00?8a=L7a<?I00<0002h]mVh]mT04[Rgf@030000Zj[FZj[F012[Z]H300000Z2`
h`030000Si[JSi[J00N?V]X300001F_Me0<00006^N?d00<0002Ca?RCa?P039?4n09=J/l00`00000<
W00<W00200bL00<0002Ca?RCa?P00Y?4n0040000LZ3^000000001P1ffP8000000h6AfP0007J8e`02
00000f^8gP030000G7kKG7kK00=LO]/00`0004Ubf4Ubf005000000@3DLh00000>;d0000`oooo000_
oooo00@0003@nkC@nk@00002f_SN00<0003FmjGFmjD00]KgY@030000jN_>jN_>00WYjlh00`000=_A
cm_Ac`03fm7?0`0000[Aemd00`000<S4elS4e`04b<CG1lC3f@030000^;OI^;OI01:h]mT00`000:^Z
eZ^ZeP0CZj[F0P0000R?V]X200001F_Me0<00009^N?d00<0002Ca?RCa?P039?4n0==J/l01@00000<
W00<W00<W0000003TlCh00<0001bX>ibX>h00W:PkP80000607KJ0P0000=fR=L2000000=[R=h0001L
O]/015anf`030000BG;HBG;H0099L]P00`0002eQdP0000050000;oooo`00;_ooo`030000d?^dd?^d
008000000m[hgP000=KgY@03e_NU00<0003YjlkYjlh02NW[cP030000fm7?fm7?00OKdLl300001]7G
g@030000b<CGb<CG00K8a=L5a<?I00<0002h]mVh]mT04kRgf@030000Zj[FZj[F01B[Z]H300000hnJ
fP800006JmgD0P0000biho@00`0009?4n9?4n00;TlCh1DeZc`05000000bL00bL00bL000000:Ca?P0
0`0007:PkW:PkP04LZ3^0P0000H0M]X200000gJ8e`<00005G7kK00D00019L]Q9L]Q9L]P000000beQ
dPD0000^oooo000^oooo00L0003@nk@0003Vn/h0003Jn=h000001=KgY@030000jN_>jN_>00WYjlh0
0`000=_Acm_Ac`0:fm7?0`0000;Aemd00`000<S4elS4e`08b<CG1<C3f@030000^;OI^;OI01>h]mT0
0`000:^ZeZ^ZeP0CZj[F00@0002NV/nNV/nNV/l200001V_Me0<0000>^N?d00<0002Ca?RCa?P02i?4
n0I=J/l01`00000<W00<W00<W00009?4n0000008LZ3^0P0000H0M]X200000gJ8e`800004G7kK00<0
0019L]Q9L]P00TUbf0040000;F7B;F7B00000PE8a`80000^oooo000]oooo00<0003@nk@000000^Kj
cP800004e_NU00<0003YjlkYjlh02NW[cP030000fm7?fm7?00kKdLl300002/S4e`C4`mT00`000;Rg
fKRgf@0B^;OI00<0002[Z]J[Z]H05:^ZeP040000WY[?WY[?WY[?0P0000=[gM@300004;WSm0030000
TlChTlCh00^Ca?P7CF[?00@0000039`039`039`200002g:PkP80000607KJ0P000003MXSG0000J7gD
00800003G7kK00D00019L]Q9L]Q9L]P000000beQdP0500001DS7000002Ja000002goool002coool0
10000=3k]=3k]00000?Vn/h01@000=KgYMKgYMKgY@00000<jN_>00<0003KdLoKdLl03]_Ac`030000
cko;cko;00800009b<CG0lC3f@030000^;OI^;OI01:h]mT00`000:^ZeZ^ZeP0CZj[F00P0002NV/nN
V/nNV/l0002Rj9`0001[gM@200004kWSm0030000TlChTlCh00^Ca?P00deZci?4n4eZc`05CF[?00D0
000039`039`039`000003G:PkP80000607KJ0P0000=XOM@2000000=LO]/00019L]P00dUbf0090000
;F7B;F7B;F7B00001DS7000002Ja000002coool002_oool010000=3k]=3k]00000?Vn/h00`000=Kg
YMKgY@02e_NU00<0003YjlkYjlh02NW[cP030000fm7?fm7?00oKdLl00`000<noblnob`02cko;0`00
00K8a=L3a<?I00<0002h]mVh]mT04[Rgf@030000Zj[FZj[F01>[Z]H0100009jJcijJc`0000:Rj9`2
00005KWSm0030000TlChTlCh00ZCa?P3CF[?0Y?4n0E=J/l01@00000<W00<W00<W000000>LZ3^0P00
00H0M]X200000fQme0<00004BG;H00@0000]HM8]HM8000021DS70P0002coool002_oool00`000=3k
]0000003i_[>00<0003FmjGFmjD00]KgY@030000jN_>jN_>00WYjlh00`000=_Acm_Ac`0?fm7?00<0
003?_l_?_l/01/nob`800005b<CG0/C3f@030000^;OI^;OI016h]mT00`000:^ZeZ^ZeP0CZj[F00@0
002NV/nNV/l00002X^RL0P0001Jiho@00`0009?4n9?4n009TlCh1TeZc`03TlChCF[?CF[?009=J/l0
0`00000<W00<W00200bL00<0001bX>ibX>h03G:PkP80000607KJ0P0000=XOM@200000dUbf0090000
;F7B;F7B;F7B00001DS7000002Ja000002_oool002[oool00`000=3k]0000004i_[>00<0003FmjGF
mjD00]KgY@030000jN_>jN_>00WYjlh00`000=_Acm_Ac`0?fm7?00<0003?_l_?_l/02<nob`<00002
b<CG00?4`mT0002h]mT04kRgf@030000Zj[FZj[F01>[Z]H00`0009jJc`000002X^RL00@0003Om=_O
m=/0000E^N?d00<0002Ca?RCa?P02I?4n0Q=J/l01I?4n4eZcdeZcdeZc`00000300bL00<0001bX>ib
X>h03g:PkP80000607KJ0P000003J7gD0000E6oA00800002BG;H00T0000]HM8]HM8]HM800005B<L0
00009[400000:_ooo`00:Oooo`030000d?^d000000CVn/h00`000=KgYMKgY@02e_NU00<0003YjlkY
jlh02NW[cP030000fm7?fm7?00oKdLl00`000<noblnob`0<cko;0P000003b<CG0000^;OI01>h]mT0
0`000:^ZeZ^ZeP0BZj[F00<0002NV/l000000Z;XW0050000goCKgoCKgoCK000001Fiho@00`0009?4
n9?4n008TlCh2deZc`04TlChCF[?CF[?00000`0<W0030000LZ3^LZ3^011bX>h200001P1ffP030000
J7gD0000009DKm43000012eQdP0500001DS7000002Ja000002Woool002Soool00`000=3k]0000004
i_[>00<0003FmjGFmjD00]KgY@030000jN_>jN_>00[Yjlh00`000=_Acm_Ac`0?fm7?00<0003?_l_?
_l/03/nob`030000^;OI000001>h]mT00`000:^ZeZ^ZeP0BZj[F0P0000:Rj9`00`000=odfmodf`02
goCK00<0002ihoBiho@04[WSm0`0000?CF[?00@0000039`00000000DLZ3^0P000080M]X2000000<0
>K`00000000015A_d@@000001ReQdP0000E8a`E8a`0V/@0002Woool002Ooool00`000=3k]0000005
i_[>00<0003FmjGFmjD00]KgY@030000jN_>jN_>00WYjlh00`000=_Acm_Ac`0?fm7?00<0003?_l_?
_l/04Lnob`X00009^;OI00<0002[Z]J[Z]H04Z^ZeP800002X^RL00<0003Om=_Om=/00modf`030000
^N?d^N?d00jiho@4000000?0bn<0002X]^<02:Rfh`03OX3;0000CF[?00e=J/l01000000<W0000000
01IbX>h20000100i_0030000E6oAE6oA00=DKm400`0003IKbcIKb`05000000<09[40003oool09ooo
o`009oooo`030000d?^d000000CVn/h00`000=KgYMKgY@02e_NU00<0003YjlkYjlh02^W[cP030000
fm7?fm7?00oKdLl00`000<noblnob`0Acko;00<0002k/<jk/<h01k^`cP/0000CZj[F0P000003X^RL
0000goCK00KOm=/00`000;WSm;WSm00:^N?d0`0000G0bn<00`000:RfhjRfh`06Z;KS0Wj0b`030000
CF[?CF[?00e=J/l00`000000C`00000FLZ3^00<0001GNm/00000100i_0030000E6oAE6oA00=DKm40
1P0003IKbcIKbcIKb`0000Pn_P8000000`0AX@000?ooo`0Voooo000Voooo00<0003@nk@000001>Kj
cP030000e_NUe_NU00;FmjD00`000>W[c^W[cP0:jN_>00<0003KdLoKdLl03m_Ac`030000cko;cko;
017?_l/00`000<Jcb;^`cP0A^k3>00<0002aYL`000000P0000n[Z]H2000000>Rj9`0003Om=/01mod
f`030000^N?d^N?d00Niho@300002<3;h`030000Z;KSZ;KS00JX]^<3OX3;00<0001=J/m=J/l02TeZ
c`<00002001?00<0001bX>ibX>h04g:PkP040000Eg_KEg_K0000100i_0030000E6oAE6oA009DKm40
0`0003IKbcIKb`02=U_;00<00008?[h8?[h00P0002Ooool002Goool00`000=3k]0000005i_[>00<0
003FmjGFmjD00]KgY@030000jN_>jN_>00WYjlh00`000=_Acm_Ac`0@fm7?00<0003?_l_?_l/04Lno
b`030000a[?8a[?8012k/<h00`000;6Uc;6Uc003/JG<0`0000b[Z]H00`000:;XW0000009goCK00<0
002ihoBiho@00kWSm0@0000;`<_S00<0002X]^>X]^<01JRfh`EnP</00`0004eZcdeZc`08CF[?00@0
000d>JLd>JL00002001?00<0001bX>ibX>h04W:PkP030000Eg_KEg_K009GNm/00`00000i_00i_002
03Vl00<0001DKm5DKm400UA_d@050000=U_;=U_;=U_;00000088?[h00`00000AX@00000Voooo000T
oooo00<0003LmZ4000001NKjcP030000e_NUe_NU00;FmjD00`000>W[c^W[cP0:jN_>00<0003KdLoK
dLl03m_Ac`030000cko;cko;017?_l/010000<Jcb<Jcb<Jcb12k/<h00`000;6Uc;6Uc006/JG<0`00
00R[Z]H010000:;XW:;XW00000[Om=/00`000;WSm000000200003l3;h`030000Z;KSZ;KS00FX]^<5
OX3;00<0001=J/m=J/l01TeZc`800003=3VW00<0000004l004l00P00019bX>h00`0005MkfeMkf`04
Eg_K00<00000>K`0>K`00P0i_0050000E6oAE6oAE6oA000000@fFl/00`0000Pn_PPn_P0200009_oo
o`009?ooo`030000g?JQ000000CVn/h300000]KgY@030000jN_>jN_>00[Yjlh00`000=_Acm_Ac`0?
fm7?00<0003?_l_?_l/04/nob`030000a[?8a[?800;6/lP?^k3>00<0002aYLbaYL`02K6Uc0<00004
Zj[F00@0002Rj9bRj9`0000;goCK0P0001;0bn<00`000:RfhjRfh`04Z;KS1gj0b`030000CF[?CF[?
00==J/l200001S@iY`040000001?0000TioL0P00011bX>h00`0005MkfeMkf`05Eg_K00<00000>K`0
>K`00P0i_0040000E6oAE6oA000013IKb`06000023jn23jn0000016Q00009Oooo`008oooo`050000
g?JQ0000k_Rl000000;Vn/h200000^SRMP030000e_NU000000cYjlh00`000=_Acm_Ac`0?fm7?00<0
003?_l_?_l/04Lnob`030000a[?8a[?800C6/lP>^k3>00<0002aYLbaYL`03;6Uc0@00002X^RL00<0
003Om=_Om=/02Modf`80000C`<_S00<0002X]^>X]^<01:Rfh`QnP</01@0004eZcdeZcdeZc`000008
=3VW00<0000004l000000i>Og0<0000<LZ3^00<0001GNm]GNm/01eMkf`03000003Vl03Vl0080>K`0
100005A_dEA_d@0000@fFl/01P0000Pn_PPn_P00000AX@0002Coool002?oool200000^kh_0050000
i_[>0000j>_@000000?XhWH400002NW[cP030000fm7?fm7?00oKdLl00`000<noblnob`0Bcko;00<0
0036/lS6/lP01LJcb0bk/<h00`000;6Uc;6Uc00?/JG<00@0002Rj9bRj9`0000;goCK00<0003Kf]H0
00004l3;h`030000Z;KSZ;KS00BX]^<8OX3;00@0001=J/l000000009=3VW00<0000004l000001Y>O
g080000:LZ3^00<0001GNm]GNm/025Mkf`03000003Vl03Vl0080>K`00`0005A_d@000004=U_;00H0
0008?[h8?[h000004J40000Toooo000Roooo00<0003LmZ4000000nkh_0040000j>_@j>_@00000nSR
MP040000m=fem=fem=fe1P0000?Yjlh00`000=_Acm_Ac`0?fm7?00<0003?_l_?_l/04Lnob`030000
a[?8a[?800K6/lP<^k3>00<0002aYLbaYL`03[6Uc0040000X^RLX^RL00002modf`050000fm[Ffm[F
fm[F00000170bn<00`000:RfhjRfh`04Z;KS2Wj0b`030000=3VW=3VW00Td>JL010000000C`00C`00
00NCWm`200001g:PkP030000Eg_KEg_K00YGNm/00`00000i_00i_00203Vl00<0001DKm40000013IK
b`06000023jn23jn0000016Q00008oooo`008Oooo`030000g?JQ000000?^n;`200000^S[d0040000
j>9fj>9fj>9f2_CM]@D0000?fm7?00<0003?_l_?_l/04/nob`030000a[?8a[?800O6/lP;^k3>00<0
002aYLbaYL`03K6Uc0040000X^RLX^RL00002modf`030000fm[Ffm[F00;Kf]H00`000<3;hl3;h`0?
`<_S00<0002X]^>X]^<00jRfh`UnP</300002c@iY`040000001?001?00002I>Og0800004LZ3^00<0
001GNm]GNm/035Mkf`07000003Vl03Vl03Vl0000E6oA000000@fFl/0100000Pn_PPn_P0000804J40
0`000?ooooooo`0Poooo000Qoooo00<0003LmZ4000000nkh_08000000nS[d0000>SRMP02j>9f00<0
003dgKGdgKD02_CM]@030000hLJmhLJm00@0000;fm7?00<0003?_l_?_l/04Lnob`030000a[?8a[?8
00W6/lP:^k3>00<0002aYLbaYL`03;6Uc0040000X^RLX^RL00002modf`030000fm[Ffm[F00?Kf]H0
0`000<3;hl3;h`0?`<_S00<0002X]^>X]^<00ZRfh`UnP</0100006eQ/feQ/`0000/d>JL010000000
C`00C`0000^CWm`200000W:PkP030000Eg_KEg_K00eGNm/01P00000i_00i_00i_00005A_d@DfFl/0
1P0000Pn_PPn_P00000AX@0002;oool0023oool00`000=cfX@000003k_Rl00D0003`kL<0003Xjm00
00000nSRMP030000m=fem=fe00[dgKD00`000>76_N76_@04hLJm100000KKdLl00`000<noblnob`0B
cko;00<00036/lS6/lP02LJcb0Vk/<h00`000;6Uc;6Uc00=/JG<00<0002Rj9`000002modf`030000
fm[Ffm[F00CKf]H00`000<3;hl3;h`0?`<_S00<0002X]^>X]^<00ZRfh`MnP</2000016eQ/`030000
=3VW=3VW00Td>JL00`000000C`00000=TioL0P00015GNm/01000000i_00i_00i_0<00003=U_;00@0
0008?[h8?[h00002016Q00<0003oooooool07oooo`007oooo`040000g?JQg?JQ00000^kh_0040000
l>g3l>g3l>g30P0000?XhWH00`000?CM]OCM]@09m=fe00<0003Qa[gQa[d02N76_@@00002fm7?00<0
003?_l_?_l/04Lnob`030000a[?8a[?800_6/lP8^k3>00<0002aYLbaYL`03K6Uc080000;goCK00<0
003Kf]KKf]H01M_JeP030000`<_S`<_S00o0bn<010000:RfhjRfhjRfh`MnP</00`0006eQ/feQ/`04
KF6c00<0000d>JLd>JL02C@iY`030000001?000000fCWm`00`000868d@00000AEg_K00H00000>K`0
>K`0>K`00011E/43000000LfFl/8?[h8?[h8?[h000004J4000008Oooo`007oooo`030000g?JQ0000
00?^n;`01@000?3]`o3]`o3]``000003j>9f00<0003dgKGdgKD02_CM]@030000hLJmhLJm00gQa[d4
00004/nob`030000a[?8a[?800_6/lP8^k3>00<0002aYLbaYL`03;6Uc0040000_/=1000000002Mod
f`030000fm[Ffm[F00OKf]H00`000<3;hl3;h`0>`<_S00@0002X]^>X]^>X]^<6OX3;00<0001]HK=]
HK<01FeQ/`030000=3VW=3VW00Td>JL00`000000C`00000=TioL00@00021R=61R=40000AEg_K00D0
0000>K`0>K`0>K`000000d5F`@D000000`0AX@000000000Poooo000Noooo00@0003LmZ7LmZ400002
k_Rl00<0003`kL?`kL<00_3]``050000j>9fj>9fj>9f000000cdgKD00`000>76_N76_@0>hLJm00<0
003C^;kC^;h01@0000c?_l/00`000<Jcb<Jcb00=a[?81[^`cP030000/JG</JG<00faYL`2000000?k
j:80003Om=/01modf`030000fm[Ffm[F00SKf]H00`000<3;hl3;h`0>`<_S00<0002X]^>X]^<01Gj0
b`800008KF6c00<0000d>JLd>JL02C@iY`030000001?000000bCWm`00`000868dH68d@02PHSA00<0
001GNm]GNm/03eMkf`05000003Vl03Vl03Vl000000=1E/400`0000hc/Phc/P02000000<008d0003o
ool07oooo`007_ooo`030000g?JQ000000;^n;`00`000?3]`o3]``03l>g300D0003XhWKXhWKXhWH0
00003?CM]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P05dkRn100000S?_l/00`000<Jcb<Jcb00=
a[?81[^`cP030000/JG</JG<00faYL`200000__XXP030000goCKgoCK00COm=/00`000=_Je]_JeP09
fm[F00<00030bn?0bn<03<3;h`H00003OX3;00<0001]HK=]HK<026eQ/`030000=3VW=3VW00Td>JL0
10000000C`00C`0000^CWm`00`000868dH68d@03PHSA00<0001GNm]GNm/03eMkf`05000003Vl03Vl
03Vl000000=1E/40100000hc/Phc/P00008008d00`000?ooooooo`0Moooo000Moooo0P000005g?JQ
0000k_Rlk_Rl000000C`kL<200000nSRMP030000m=fem=fe00WdgKD00`000>76_N76_@0>hLJm00<0
003C^;kC^;h02]>h_PD00002cko;00<00036/lS6/lP03lJcb0Fk/<h00`000;6Uc;6Uc00=/JG<0P00
00?kj:800`000=odfmodf`02goCK00<0003Kf]KKf]H02]_JeP030000`<_S`<_S00S0bn<400000/6n
f0050000[jgFTHO50000OX3;0080000<KF6c00<0000d>JLd>JL023@iY`040000001?001?00002Y>O
g0030000PHSAPHSA00F1R=400`0005MkfeMkf`0?Eg_K00D00000>K`0>K`0>K`000000T5F`@070000
3S>b3S>b3S>b0000002=000001ooool001goool00`000>G_T0000002k_Rl00<0003`kL?`kL<00_3]
``800003j>9f00<0003dgKGdgKD02_CM]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P0?dkRn1@00
00o6/lP5^k3>00<0002aYLbaYL`03;6Uc0030000_/=1000000Ckj:8010000=odfmodf`0000kKf]H0
0`000<3;hl3;h`03`<_S100000K1_]P01@000967aI67aI67a@00000>KF6c00<0000d>JLd>JL02C@i
Y`030000001?000000VCWm`00`000868dH68d@07PHSA00<0001GNm]GNm/03eMkf`07000003Vl03Vl
03Vl0000@EK1000000<><k8010000000S@00S@0001koool001coool01P000>G_T>G_T0000>kh_000
00G`kL<200000nSRMP030000m=fem=fe00[dgKD00`000>76_N76_@0>hLJm00<0003C^;kC^;h04M>h
_P030000bJfnbJfn00@0000<a[?80k^`cP030000/JG</JG<00faYL`200001O_XXP030000goCK0000
00oKf]H00`000<3;h`00000300002L6nf0030000[jgFTHO500<0000>KF6c00<0000d>JLd>JL02C@i
Y`030000001?000000VCWm`00`000868dH68d@08PHSA00<0001GNm]GNm/03eMkf`07000003Vl03Vl
03Vl0000@EK1000000<><k800`000000S@00000Noooo000Loooo00@0003Uki00003cljT200001?3]
``030000k^72000000?XhWH00`000?CM]OCM]@0:m=fe00<0003Qa[gQa[d03^76_@030000dkRndkRn
013C^;h00`000<V]_/V]_P05bJfn1@0000O6/lP600003K6Uc0800006nnRR00<0003Kf]KKf]H03]_J
eP80000=`KkH0`0000:3Kk@00`0006eQ/feQ/`0<KF6c00<0000d>JLd>JL02C@iY`030000001?0000
00RCWm`00`000868dH68d@0:PHSA00<0001GNm]GNm/03eMkf`03000003Vl03Vl00<000033S>b00<0
000008d000007_ooo`007?ooo`050000iNn@0000lo>Y000000C`kL<00`000>kQ`P000004j>9f00<0
003dgKGdgKD02OCM]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P0AdkRn00<00039[Kk9[Kh02/V]
_P@00003a[?800@0002nZLJnZLH00002]J74100000VaYL`200001__XXP80000>fm[F0P0000k1_]P0
0`0008=_]8=_]003Pfnd00<0001]HK=]HK<02feQ/`030000=3VW=3VW00Td>JL00`000000C`000008
TioL00<00021R=61R=402h68d@030000Eg_KEg_K00mGNm/2000000<00iL0000000000`hc/P040000
002=002=00007Oooo`006oooo`030000iNn@000000;cljT01@000?3]`o3]`o3]``000002k^7200D0
003XhWKXhWKXhWH000003?CM]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P0AdkRn00<00039[Kk9
[Kh03/V]_P@000000kjYaP000;FQa006]J74100000BaYL`200001__XXP030000m=Vb000000cKf]H2
000000?Gc]000031_]P03L6nf0J3Kk@00`0006eQ/feQ/`0;KF6c00<0000d>JLd>JL02C@iY`040000
001?001?00001Y>Og0030000PHSAPHSA00f1R=400`0005MkfeMkf`0=Eg_K0P0000<00iL00`0000hc
/Phc/P023S>b00<0000008d000007Oooo`006oooo`040000iNn@0000lo>Y0P0000;`kL<01@000>kQ
`^kQ`^kQ`P000003j>9f00<0003dgKGdgKD02_CM]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P0A
dkRn00<00039[Kk9[Kh04<V]_P040000`ZFm000000002kFQa0H00006nnRR00@0003dfK;dfK80000:
fm[F00D0003Gc]3Gc]3Gc]0000003L6nf0N3Kk@00`0006eQ/feQ/`0<KF6c00<0000d>JLd>JL023@i
Y`040000001?001?00001I>Og0030000PHSAPHSA00n1R=400`0005MkfeMkf`0;Eg_K00@00010El=0
El<0000200>G0P0000<><k8010000000S@00S@0001coool001_oool200000_?cZ@050000mnbd0000
l>g3000000?^hL801@000>SRM^SRM^SRMP00000<m=fe00<0003Qa[gQa[d03^76_@030000dkRndkRn
013C^;h00`000<V]_/V]_P0AbJfn00@00032YKg2YKg2YKd?]J740P0000Kkj:801@000?CI/_CI/_CI
/P000008fm[F00<0003Gc]3Gc]000]O>d0030000`KkH`KkH00_1_]P7Pfnd00<0001]HK=]HK<036eQ
/`030000=3VW=3VW00Td>JL2001?00<0002CWmbCWm`00i>Og0030000PHSAPHSA0121R=400`0005Mk
feMkf`09Eg_K00D00010El=0El=0El<000000`03U`0300003S>b3S>b008><k800`000000S@00000L
oooo000Joooo00D0003Uki00003cljT000000_O/]0800003k^7200D0003XhWKXhWKXhWH000003?CM
]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P0AdkRn00<00039[Kk9[Kh04<V]_P030000`ZFm`ZFm
00?2YKd>]J7400<0003kj:;kj:801?_XXP030000m=Vbm=Vb00;dfK800`000=_Je]_JeP05fm[F00<0
003Gc]3Gc]000mO>d0030000`KkH`KkH00[1_]P9Pfnd00<0001]HK=]HK<02feQ/`030000=3VW=3VW
00Td>JL2001?00<0002CWmbCWm`00Y>Og0030000PHSAPHSA01:1R=400`0005MkfeMkf`07Eg_K00<0
0010El=0El<00d1G``04000000>G00>G000010hc/P040000002=002=00006oooo`006_ooo`800002
lo>Y00@0003gk;Cgk;@00004k^7200D0003XhWKXhWKXhWH000003?CM]@030000hLJmhLJm00kQa[d0
0`000=>h_]>h_P0AdkRn00<00039[Kk9[Kh04<V]_P030000`ZFm`ZFm00?2YKd=]J740P0000Kkj:80
0`000?CI/_CI/P03m=Vb00<0003Kf]KKf]H00m_JeP030000elk@elk@00CGc]000`000<6nf<6nf00:
`KkH2H=_]0030000KF6cKF6c00]]HK<00`0003@iYc@iY`09=3VW00<004l0000000000P0000:CWm`0
0`000868dH68d@0CPHSA00<0001GNm]GNm/01EMkf`030000@5O3@5O300A0El<01@000003U`03U`03
U`0000043S>b00<0000008d000006oooo`006_ooo`8000000o?cZ@000?O/]002mnbd00<0003^hL;^
hL800^kQ`P050000j>9fj>9fj>9f000000cdgKD00`000>76_N76_@0>hLJm00<0003C^;kC^;h04M>h
_P030000bJfnbJfn0139[Kh00`000<:U_L:U_@04`ZFm3;FQa0800006nnRR00<0003dfK;dfK801?CI
/P030000fm[Ffm[F00800008elk@00<00031_]S1_]P02<6nf0Z3Kk@00`0006eQ/feQ/`0;KF6c00<0
000d>JLd>JL023@iY`<00003X9c@0P0001N1R=400`0005MkfeMkf`03Eg_K00<00010El=0El<01T1G
``04000000>G00>G000010hc/P030000002=000001_oool001Woool200000_?cZ@030000mnbdmnbd
00800003k^7200<0003XhWKXhWH00^SRMP030000m=fem=fe00[dgKD00`000>76_N76_@0>hLJm00<0
003C^;kC^;h04=>h_P030000bJfnbJfn0179[Kh00`000<:U_L:U_@04`ZFm3;FQa0800006nnRR00<0
003dfK;dfK801?CI/P030000fm[F000000[Gc]000`000<6nf<6nf008`KkH2X=_]0030000KF6cKF6c
00a]HK<00`0003@iYc@iY`03=3VW1000000390A_0000000000>PW=000`0009>;b000000GPHSA00D0
001GNm]GNm]GNm/000002D1G``05000000>G00>G00>G000000<><k8010000000S@00S@0001[oool0
01Woool2000000?cljT0003gk;@00_O/]0800003k^7200D0003XhWKXhWKXhWH000003?CM]@030000
hLJmhLJm00kQa[d00`000=>h_]>h_P0AdkRn00<00039[Kk9[Kh04<V]_P030000`ZFm`ZFm00K2YKd;
]J7400<0003kj:;kj:801?_XXP030000m=Vbm=Vb00KdfK800`000=O>d=O>d009elk@00<00031_]S1
_]P01l6nf0b3Kk@00`0006eQ/feQ/`0;KF6c00<0000d>JL000000`0000@T16l300000j2Ld0040000
Th_8Th_800005h68d@030000Eg_K000000]0El<010000003U`03U`0000@><k800`000000S@00000J
oooo000Ioooo0P000005lo>Y0000mnbdmnbd000000;ehkL010000>kQ`^kQ`P0000?XhWH00`000?CM
]OCM]@0:m=fe00<0003Qa[gQa[d03^76_@030000dkRndkRn017C^;h00`000<V]_/V]_P0@bJfn00<0
0032YKg2YKd01/:U_@ZeXL@200001__XXP030000m=Vbm=Vb00KdfK800`000=O>d=O>d009elk@00<0
0031_]S1_]P01l6nf0b3Kk@00`0006eQ/feQ/`0:KF6c0`0000PT16l300000Z2Ld0030000Th_8Th_8
00:CRlP00`000868dH68d@0EPHSA00<00010El=0El<02T1G``05000000>G00>G00>G000000<><k80
10000000S@00S@0001Woool001Soool2000000?gkIP0003gk;@00_O/]0050000mN>gmN>g0000k^72
00800003j>9f00<0003dgKGdgKD02_CM]@030000hLJmhLJm00kQa[d00`000=>h_]>h_P0@dkRn00<0
0039[Kk9[Kh04LV]_P030000`ZFm`ZFm00O2YKd9]J740P0000Kkj:800`000?CI/_CI/P05m=Vb00<0
003ae;@000002]O>d0030000`KkH`KkH00K1_]P=Pfnd00<0001]HK=]HK<01feQ/`<000000f4lS`00
02@4K`0890A_0P0000>PW=000`0009>;b9>;b003Th_800<00021R=61R=404h68d@030000LG320000
00a0El<00`000003U`03U`04000000@><k8008d00000000Ioooo000Hoooo0P000005mnfH0000mnbd
mnbd000000?ehkL300001>SRMP030000m=fem=fe00[dgKD00`000>76_N76_@0>hLJm00<0003C^;kC
^;h04=>h_P030000bJfnbJfn0179[Kh00`000<:U_L:U_@07`ZFm2KFQa0030000nnRRnnRR00Ckj:80
0`000?CI/_CI/P06m=Vb00<0003ae;@000002]O>d0040000`KkH`KkH`KkH1@0000f3Kk@00`0006eQ
/feQ/`03KF6c100000AQ?8l00`0002@4Kb@4K`0790A_0P0000:PW=000`0009>;b9>;b005Th_800<0
0021R=61R=404H68d@040000LG32LG320000341G``05000000>G00>G00>G0000008F::@2000000<0
07<0003oool06?ooo`005oooo`800002mnfH00@0003gk;Cgk;@00003mN>g00<0003[e[h000000P00
0003j>9f0000m=fe00_dgKD00`000>76_N76_@0>hLJm00<0003C^;kC^;h04M>h_P030000bJfnbJfn
0139[Kh00`000<:U_L:U_@09`ZFm2;FQa0800005nnRR00<0003dfK;dfK801_CI/P040000lMBdlMBd
00002MO>d0@00004`KSA00<00023KkB3Kk@038=_]0030000KF6c000000800007HCb?00<0000T16lT
16l01b@4K`<000000j2Ld00009>;b008Th_800<00021R=61R=403h68d@030000LG32LG32009aL<80
0`00041G`d1G``0:@5O300@000000iL00iL000035RRT00<0000007<000006Oooo`005oooo`800000
1OO]V00000000?O/]0000003mN>g0P000004jmJn0000jkLijkLi200000KdgKD00`000>76_N76_@0>
hLJm00<0003C^;kC^;h04M>h_P030000bJfnbJfn00@0000<bJfn00<00032YKg2YKd02/:U_@NeXL@0
10000?V^B`00000000?kj:800`000?CI/_CI/P05m=Vb00D0003ae;Cae;Cae;@000001mO>d0<00006
`KSA0Xad/P030000PfndPfnd00Z3Kk@300002V4lS`03000090A_90A_00LT16l200000Z2Ld0030000
Th_8Th_800RCRlP00`000868dH68d@0>PHSA00<0001aL<9aL<800W5``P030000@5O3@5O300Y0El<0
1@000003U`03U`03U`0000025RRT00@0000007<007<0000Hoooo000Goooo0P000003mnfH0000n^ZT
00800003mN>g0P000003jmJn0000jkLi00;[]cT00`000?O5U_O5UP04mlFF8@0000WC^;h400000dc;
cPD00008bJfn00<00032YKg2YKd02/:U_@NeXL@200000_V^B`<00008m=Vb00D0003ae;Cae;Cae;@0
00001]O>d0040000elc?elc?00001/6hd@:<M;800`0008=_]8=_]008Pfnd0P000003M4nG0000HCb?
00YQ?8l00`0002@4Kb@4K`0790A_0P000003X9c@0000Th_800^CRlP00`000868dH68d@0<PHSA00<0
001aL<9aL<80175``P030000@5O3@5O300Y0El<010000003U`03U`0000<F::@00`000000L`00000H
oooo000Foooo0P000005mnfH0000n^ZTn^ZT000000?ehkL01@000??J]@000>_F_P000003jkLi00<0
003gaIKgaIH02_O5UP030000hkNZhkNZ00kS]jX00`000=B]/=B]/007e:f`2@00009<blh4000000BX
hO/0001P/_]P/_/700000lV]_P030000`ZFm`ZFm00_2YKd5]J7400<0002[U/4000001?V^B`030000
m=Vbm=Vb00GdfK800`000?7D]?7D]003lMBd00<0003Gc]3Gc]000]O>d0050000elc?elc?elc?0000
00G1^=44S7Bb00<00023KkB3Kk@018=_]0<00003M4nG00<0001Q?8mQ?8l02F4lS`03000090A_90A_
00LT16l300003Y>;b0030000PHSAPHSA00Z1R=400`00075``W5``P06LG3200<00010El=0El<02D1G
``05000000>G00>G00>G0000008F::@00`000000L`00000Hoooo000Foooo0P000005mnfH0000n^ZT
n^ZT000000;ehkL01P000??J]O?J]@000>_F_P0000?[]cT00`000?O5U_O5UP0:mlFF00<0003S]j[S
]jX03^>gZP030000e:f`e:f`00SD[K0400000Tc;cP@00006Z>7k00<0001P/_]P/_/00f2bn`800000
0`1g_`000000000200003/:U_@BeXL@00`000:^F`@000004nJi;0`0000GdfK800`000?7D]?7D]003
lMBd00<0003Gc]3Gc]000P0000CGc<l00`000<6hdL6hd@03`KSA18ad/P030000PfndPfnd00:3Kk@2
00001GA?U`030000HCb?HCb?00UQ?8l00`0002@4Kb@4K`0790A_100000nCRlP00`000868dH68d@08
PHSA00<0001aL<9aL<801g5``P030000@5O3@5O300Y0El<010000003U`03U`00008F::@00`000000
L`00000Hoooo000Eoooo100000;jjZ@2000000?ehkL0003cf[D00o?J]@800003jkLi00<0003gaIKg
aIH02_O5UP030000hkNZhkNZ00kS]jX00`000=B]/=B]/004e:f`1000009<blh400002ZSQn`030000
H;;kH;;k00MP/_/2000000<0Mkl0000000000P0000[2YKd4]J7400<0002[U/4000001OV^B`040000
n[A_000000000oCI/P030000lMBdlMBd00Cae;@200001]O<c`030000`KSA`KSA00;1^=46S7Bb00@0
0023Kk@000000007M4nG00<0001Q?8mQ?8l02F4lS`03000090A_90A_00LT16l300004I>;b0030000
PHSAPHSA00J1R=400`00075``W5``P09LG3200<00010El=0El<02D1G``08000000>G00>G00>G0000
5RRT0000001c0P0001Ooool001Goool2000000CgkIP0003jjZCjjZ@2000000?ehkL0003cf[D00o?J
]@800003jkLi00<0003gaIKgaIH02_O5UP030000hkNZhkNZ00kS]jX00`000=B]/=B]/00400000Tc;
cP@0000>Z>7k00<0001P/_]P/_/02f2bn`800000101g_`000000000000S2YKd3]J7400@0002[U/6[
U/400004nJi;00@0003j]6oj]6oj]6l300001o7D]0030000elc?elc?00GGc<l010000<6hdL6hdL6h
d@N<M;8200002GA?U`030000HCb?HCb?00UQ?8l00`0002@4Kb@4K`0790A_0`0001:CRlP00`000868
dH68d@04PHSA00<0001aL<9aL<802g5``P030000@5O3@5O300U0El<01P000003U`03U`0001HXY000
008007<00`000?ooooooo`0Eoooo000Eoooo0`0000;jjZ@010000?[TZ@00000000Gcf[D200000n^g
>@030000mlFFmlFF00[gaIH00`000>>gZ^>gZP0>hkNZ0`00009<blh400004jSQn`030000H;;kH;;k
00iP/_/400001/:U_@<00003ZiK100<0003i[T_i[T/00_V^B`030000n[A_n[A_00?j]6l00`000?7D
]?7D]005lMBd00<0003Gc<oGc<l01=O<c`030000`KSA`KSA00;1^=46S7Bb0P0000YdCiL00`00064l
Sf4lS`09HCb?00<0000T16lT16l01b@4K`80000DTh_800<00021R=61R=400h68d@030000LG32LG32
00]aL<800`00041G`d1G``09@5O300T000000iL00iL00iL0000F::@0000007<000005oooo`005Ooo
o`<00002n^ZT00<0003ji:T000001_?J]@<00002jkLi00<0003gaIKgaIH02_O5UP030000hkNZhkNZ
00kS]jX00`000:7`]Z7`]P0200005jSQn`030000H;;kH;;k00mP/_/700000/:U_@040000]ibm0000
00000Z^F`@030000nJi;nJi;00;i[T/00`000?ZdKoZdK`03n[A_0P0000Gae;@200001]O<c`040000
`KSA`KSA`KSA1Had/P8000000gQBV00007A?U`09M4nG00<0001Q?8mQ?8l02F4lS`03000090A_90A_
00HT16l200005Y>;b0050000PHSAPHSAPHSA000000maL<800`00041G`d1G``09@5O300P000000iL0
0iL0000F::@0000007<0000Goooo000Eoooo00H0003hiXP0003jjZ@0003ji:T200001_?J]@030000
jLfi000000?[]cT00`000?O5U_O5UP0:mlFF00<0003S]j[S]jX02n>gZP800002XO2f00<0003Fk^<0
00006:SQn`030000H;;kH;;k00iP/_/0100000]Ke000000000?4Wk<3000000>gW;d0002]U;`00`00
00Gi[T/00`000?ZdKoZdK`02n[A_00<0003k]6P000001?7D]0800006elc?00@00031^=71^=71^=44
S7Bb00D0001hDYQhDYQhDYP000002GA?U`030000HCb?HCb?00UQ?8l00`0002@4Kb@4K`0790A_0P00
01NCRlP00`000868d@00000@LG3200<00010El=0El<02D1G``04000000>G00>G00>G0P00008007<0
0`000?ooooooo`0Doooo000Eoooo00<0003hiXP000000P000003n^BY0000000000Gcf[D2000000?Y
cKT0003[]cT00^^g>@030000mlFFmlFF00[gaIH00`000>>gZ^>gZP0:hkNZ00D0002Ql;JQl;JQl;H0
00000mK^h`030000Z>7kZ>7k01BXhO/400003V2bn`0300002e_D2e_D00800003a9nc00<0002nVK80
00001JfD_0030000nJi;nJi;00;i[T/00`000?ZdKoZdK`03n[A_00<0003k]6P000000_7D]0030000
mMjc000000KGc<l00`000<6hdL6hd@04S7Bb00<0001hDYQhDYP00WQBV0030000M4nGM4nG00MdCiL0
0`00064lSf4lS`09HCb?00<0000T16lT16l01b@4K`80000HTh_800<0001aL<9aL<80475``P030000
@5O3@5O300U0El<00`000003U`03U`0200000P00L`030000oooooooo01Coool001Coool3000000Kl
iI@0003ji:T0003igJX00004lmZe00D0003ad[80003YcKT000000n^g>@030000mlFFmlFF00[gaIH0
0`000>>gZ^>gZP09hkNZ00<0002Ql;JQl;H00P0000GFk^<200004:SQn`@000001;C=k00008>blh>b
l`@0000:H;;k00@0000;Fm@;Fm@;Fm@200000/BO/`030000_YVb_YVb00F]U;`00`000?V^BoV^B`02
nJi;00<0003j]6oj]6l00oZdK`060000nkAXnkAX0000lMBd00000_GN/`030000elc?elc?00?Gc<l0
0`000<6hdL6hd@02S7Bb0P0000EhDYP00`0007A?UgA?U`07M4nG00<0001Q?8mQ?8l02F4lS`030000
90A_90A_00LT16l200005i>;b0030000R7Zm0000019aL<800`00041G`d1G``08@5O300<000000iL0
0iL00`000003001c0000oooo01Goool001Coool3000000CliI@0003ji:T00002nMfZ00@0003cf[Gc
f[D00002lM:b00<0003YcKT000000n^g>@030000mlFFmlFF00[gaIH00`000>>gZ^>gZP08hkNZ00@0
002Ql;JQl;H00009e^kS00<0002XhO^XhO/02JSQn`@00006]<g/00<00023/_>3/_<00h>bl`@00006
H;;k00<0000;Fm@;Fm@00P]Ke08000000lBO/`000;jI/P02_YVb1:fD_0030000nJi;nJi;00;i[T/0
0`000?ZdKoZdK`03n[A_00D0003k]6Sk]6Sk]6P000000oGN/`030000elc?elc?00;Gc<l4000000><
M;80001hDYP01GQBV0030000M4nGM4nG00QdCiL00`00064lSf4lS`09HCb?00<0000T16lT16l01R@4
K`8000000ij<`@0009>;b00DTh_800@00028N[f8N[d0000BLG3200<00010El=0El<02D1G``800002
001_00@0000007<00000000Eoooo000Doooo00<0003hiXP000000`0000?igJX00`000??J]@000003
lM:b00<0003YcKT000000n^g>@030000mlFFmlFF00[gaIH00`000>>gZ^>gZP06hkNZ0P0000:Ql;H0
0`000=K^hmK^h`09e^kS00<0002XhO^XhO/01JSQn`<0000:]<g/00<00023/_>3/_<01h>bl`@00002
H;;k00<0000;Fm@;Fm@00`]Ke0800004_YVb1:fD_0030000nJi;nJi;00?i[T/00`000?ZdKoZdK`02
n[A_00D0003k]6Sk]6Sk]6P000000oGN/`030000elc?0000008000001MO?dP00091e/I1e/@000007
N5:H00<0001dCiMdCiL01gA?U`030000HCb?HCb?00UQ?8l00`0002@4Kb@4K`0790A_0P0000:NS<40
0`0009>;b9>;b00ATh_800<00028N[f8N[d00XQj_@030000LG32LG32011aL<800`00041G`d1G``06
@5O30P000005;SJW001_001_001_0000008007<00`000?ooooooo`0Coooo000Doooo00<0003hiXP0
00000`0000?igJX200001?7B/P030000jLfi000000?[]cT00`000?O5U_O5UP0:mlFF00<0003S]j[S
]jX01N>gZP050000XO2fXO2fXO2f000000gFk^<00`000:SQnjSQn`0400003[C=k0030000Pk;cPk;c
00Z3/_<300001P]Ke0030000_YVb_YVb00>nVK84[IBl00<0003i[T_i[T/00_V^B`030000n[A_n[A_
00;j]6l01@000?^dJ?^dJ?^dJ0000003mMjc0P0000?Gcm800`000<:fci1e/@0200001gQBV0030000
M4nGM4nG00MdCiL00`00064lSf4lS`09HCb?00<0000T16lT16l01b@4K`800003WXc100<0002CRlRC
RlP03i>;b0030000R7ZmR7Zm00B8N[d00`00075``W5``P0@LG3200<00010El=0El<0141G``040000
;SJW;SJW;SJW0`00K`040000001c001c00005Oooo`005?ooo`<000000ogRVP000?WMZP03nMfZ00<0
003ad[;ad[800o7B/P030000jLfi000000?[]cT00`000?O5U_O5UP0:mlFF00<0003S]j[S]jX01>>g
ZP050000XO2fXO2fXO2f000000oFk^<200004[C=k0030000Pk;cPk;c00b3/_<200001P]Ke0030000
_YVb_YVb00>nVK83[IBl00<0003i[T_i[T/00_V^B`030000n[A_n[A_00;j]6l01@000?^dJ?^dJ?^d
J0000002mMjc0P0000CGcm800`00091e/I1e/@0200001gQBV0030000M4nGM4nG009dCiLD00001b@4
K`030000WXc1WXc100>NS<400`0009>;b9>;b00=Th_800<00028N[f8N[d01HQj_@030000LG32LG32
011aL<800`00041G`d1G``03@5O300<0000^=ZL^=ZL00RhfY`040000001_001_00000P00L`030000
oooooooo01?oool001Coool3000000?mhYX0003igJX00_WMZP800005lM:b00<0003YcKT000000n^g
>@030000mlFFmlFF00[gaIH00`000>>gZ^>gZP03hkNZ00<0002Ql;JQl;H00P0000oFk^<00`000=3A
fP00000C]<g/00<00023/_>3/_<02h>bl`030000?7;L000000H;Fm@00`000;jI/[jI/P02_YVb0jfD
_0030000nJi;nJi;00;i[T/00`000?ZdKoZdK`03n[A_00L0003k]6Sk]6Sk]6P0003eg[<000001=O?
dP060000T7FaT7Fa0000LTjH00001gQBV0D00004J2AT00<0001M5e]M5e/02EdGF`0400009`0W9`0W
9`0W1000008T16l200001Yj<`@80000<Th_800<00028N[f8N[d01hQj_@030000LG32LG32011aL<80
0`00041G`d1G``0200001BhfY`040000001_001_00000P00L`030000oooooooo01?oool001?oool3
000000?mhYX0000000000_WMZP030000n=JX000000Gad[8300000n^g>@030000mlFFmlFF00[gaIH0
0`000>>gZ^>gZP02hkNZ00@0002Ql;JQl;H0000@e^kS00D0003@dM[@dM[@dMX000004[C=k0030000
Pk;cPk;c00^3/_<0100003abg3abg00000H;Fm@00`000;jI/[jI/P02_YVb0ZfD_0030000nJi;nJi;
00?i[T/00`000?ZdKoZdK`02n[A_00@0003k]6Sk]6Sk]6P300001=O?dP030000T7Fa000000=bCYP0
0`0007QBV7QBV002N5:H0P0000QX96@00`0005dGFedGF`09GAMK00<0000W02LW02L01RL09`<00009
WXc100<0002CRlRCRlP02I>;b0030000R7ZmR7Zm00R8N[d00`00075``W5``P0?LG3200<00010El<0
00001bhfY`040000001_001_00000P00L`80000Doooo000Coooo00/0003hgg/0003mhYX0003mgId0
003igJX0003heZP000001O7B/P030000j<Jd000000?[]cT00`000?O5U_O5UP0:mlFF00<0003S]j[S
]jX00P0000:Ql;H00`000=K^hmK^h`0>e^kS00<0003@dM[@dMX00m3AfP030000]<g/]<g/012dcN`0
0`0008>blh>bl`0:Pk;c00D0000lL]`lL]`lL]`000001P]Ke0040000_YVb_YVb_YVb0jfD_0030000
nJi;nJi;00X000001?^dJ0000??c/@0000?Gcm800`00091e/@000004LTjH00<0001hDYQhDYP00P00
0003D`eF0000J2AT00MX96@00`0005dGFedGF`08GAMK00<0000W02LW02L022L09`030000WXc1WXc1
00VNS<400`0009>;b9>;b007Th_800<00028N[f8N[d02HQj_@030000LG32LG32011aL<800`0002hf
YbhfY`06;SJW00<0000006l006l01@0001Coool001?oool3000000?mhYX0003mgId00P0000;heZP0
10000?7B/_7B/_7B/P<000000nS6]0000>^g>@02jkLi00<0003gaIKgaIH02_O5UP030000hkNZ0000
00>Ql;H00`000=K^hmK^h`0>e^kS00<0003@dM[@dMX01M3AfP030000]<g/]<g/00ndcN`00`0008>b
lh>bl`0:Pk;c00<0000lL]`lL]`00Sabg00300002e_D2e_D00@;Fm@010000;jI/[jI/[jI/P:]U;`3
00000le@00030000fVLRfVLR00;JIb801P000<e@000000000??c/@0000?Gcm800`00091e/@000004
LTjH0`00009C3EH00`0006PTI6PTI006J2AT00<0001M5e]M5e/025dGF`0300009`0W9`0W00PW02L0
0`0009j<`Ij<`@0;WXc100<0002CRlRCRlP01I>;b0030000R7ZmR7Zm00^8N[d00`00075``W5``P0>
LG320P0000P^=ZL01@000000K`00K`00K`000002001C00<0003oooooool04_ooo`004oooo`@00002
oMfM00D0003heZSheZSheZP000000_7B/P060000klb]klb]0000j<Jd00000n^g>@030000mlFFmlFF
00[gaIH200000j7`]P030000e^kSe^kS00kFk^<00`000=3Af]3AfP07d=7J00<0002dcNbdcN`03[C=
k0D00008Pk;c00<0000lL]`lL]`00cabg00300002e_D2e_D00@;Fm@010000;jI/[jI/[jI/P:]U;`0
0`000<e@0<e@0003cE0000<0003JIb;JIb800]YW8P040000cE00cE0000000mO?dP030000T7Fa0000
00EbCYP01@0005<=EU<=EU<=EP000008J2AT00<0001M5e]M5e/025dGF`0300009`0W9`0W00PW02L0
0`0009j<`Ij<`@0=WXc100<0002CRlRCRlP00i>;b0030000R7ZmR7Zm00f8N[d00`00075``W5``P0;
LG320P000003I5V`0000;SJW00P^=ZL010000000K`00K`00008005<00`000?ooooooo`0Boooo000C
oooo00D0003lh8D00000003mgId00P0000?heZP300000no<[@030000j<Jd000000?[]cT00`000?O5
U_O5UP0:mlFF00<0002Ql;JQl;H00P00013Fk^<00`000=3Af]3AfP09d=7J00<0002dcNbdcN`02kC=
k0800002]L;T00<00029/?29/?001P0000:3/_<00`0003abg3abg004?7;L00<0000;Fm@;Fm@010]K
e0030000_YVb_YVb00>]U;`00`000<e@0<e@0003cE0000<0003JIb;JIb800]YW8P030000cE00cE00
00D00005LTjH0P0000=C3EH00`0006PTI6PTI005J2AT00<0001M5e]M5e/025dGF`0300009`0W9`0W
00PW02L00`0009j<`Ij<`@0?WXc100D0002CRlRCRlRCRlP0000048Qj_@030000LG32LG3200YaL<80
0`0006AI/6AI/002I5V`2BhfY`040000001_001_00000P00D`030000oooooooo01;oool001?oool2
000000?ngX`0003mgId00P0000?heZP00`000>o<[No<[@03klb]00@0003Xa[CXa[@00002jkLi00<0
003gaIKgaIH02?O5UP800002XO2f00<0003Fk^?Fk^<03]K^h`80000=d=7J00<0002dcNbdcN`01kC=
k0<00004]L;T00<00029/?29/?001XV`l0<00007?7;L00<0000;Fm@;Fm@00P]Ke0800003_YVb0ZfD
_0800005cE0000<0003JIb;JIb800]YW8P030000cE00cE00008000000i1e/@00079>V003LTjH0P00
009C3EH300001fPTI0030000GAMKGAMK00QM5e/00`0002L09bL09`079`0W00<0002NS<6NS<404Ij<
`@030000Th_8000001:8N[d00`00075``W5``P08LG3200<0001TFK1TFK000fAI/0T^=ZL010000000
K`00K`00008005<00`000?ooooooo`0Boooo000Boooo1P000004o=RM0000n=JXn=JX0P0000G_c:d0
10000>S6]>S6]00000?[]cT00`000?O5U_O5UP06mlFF00D0002Ql;JQl;JQl;H000004=K^h`030000
d=7Jd=7J00k@dMX00`000;C=k;C=k003]<g/0`0000Re`^@00`0008V`l8V`l007RK3`0P0000LlL]`0
1`0000]Ke0]Ke0]Ke0000000R@000002_YVb0ZfD_0030000XXRh000000G=D0000`000=YW8]YW8P02
fVLR00<0003=D03=D0000P000006JD^K0000LTjHLTjH00003P0/0`0000=V018400000VPTI0030000
GAMKGAMK00QM5e/00`0002L09bL09`079`0W00<0002NS<6NS<404ij<`@030000R7ZmR7Zm01:8N[d0
0`00075``W5``P06LG3200<0001TFK1TFK0016AI/0030000;SJW;SJW00H^=ZL010000000K`00K`00
008005<200004oooo`004_ooo`H000001_cHW@000?SFZ0000?K@Y@0000G_c:d010000>S6]>S6]000
00?[]cT00`000?O5U_O5UP05mlFF1@00013Fk^<00`000=3Af]3AfP0@d=7J00<0002dcNbdcN`00P00
00be`^@00`0008V`l8V`l007RK3`0P0000LlL]`00`0000]Ke0000002002900H0002nVK:nVK:nVK:]
U;`00002XXRh00<0003=D03=D0000/e@00030000fVLRfVLR00?JIb800`000<e@00000002Q`001P00
00UV018200002UdGF`0300009`0W9`0W00LW02L00`0009j<`Ij<`@0CWXc100<0002EO[P000004hQj
_@030000LG32LG3200EaL<800`0006AI/6AI/005I5V`00<0000^=ZL^=ZL01RhfY`060000001_001_
001_0000001C0P0001?oool001;oool3000000Cog8l0003lf9glf9d200000_K@Y@030000klb]klb]
00?_c:d010000>S6]>S6]00000?[]cT00`000?O5U_O5UP05mlFF00D0003FjhKFjhH0003_i<<00P00
00gFk^<00`000=3Af]3AfP0Bd=7J0P0000ne`^@00`0008V`l8V`l006RK3`00<0000aK]`000001cab
g00400000029002900290`000003_YVb0000XXRh00>RR;P00`000<e@0<e@0002cE0000<0003JIb;J
Ib800mYW8P<00003Q`000P0000MV018400000W027`800007GAMK00<0000W02LW02L01bL09`030000
WXc1WXc101>NS<40100009En^9En^00001B8N[d00`00075``W5``P02LG320P0000UTFK09;SJW00D0
000006l006l0000005<00P0001?oool001;oool3000000Gog8l0003lf9glf9d000000oK@Y@030000
klb]klb]00?_c:d010000>S6]>S6]00000?[]cT00`000?O5U_O5UP04mlFF00D0003FjhKFjhKFjhH0
00000noT``80000:e^kS00<0003@dM[@dMX04]3AfP040000bL7C000000003[G2i0030000RK3`RK3`
00J9/?001000035^g35^g00000DlL]`200000`00R@030000`I:W`I:W00@00003XXRh00<0003=D03=
D0000/e@00030000fVLRfVLR00;JIb800`0009lK09lK000700000VH04P<00008L08O0P0000AM5e/0
0`0002L09bL09`079`0W0P0001BNS<400`0009En^9En^002UGjh00<00028N[f8N[d04XQj_@040000
LG32LG3200002fAI/0T^=ZL01@000000K`00K`000000D`0200004oooo`004_ooo`<000000ooLS`00
0?cHW@0200001?K@Y@030000klb]klb]00;_c:d010000>S6]>S6]00000?[]cT00`000?O5U_O5UP04
mlFF00@0003FjhKFjhH00006knC30P0000OFk^<00`000=3Af]3AfP0Bd=7J00<00039`M?9`M<00/W1
d`030000]L;T]L;T00be`^@00`0008V`l8V`l005RK3`00D0000aK]`aK]`aK]`0000013abg0030000
01^O000000<008T010000<6BYl6BY`0000:SQ[D500001<e@00040000fVLRfVLR000029lK00@0000=
L08O0P000003GAMK00009`0W00PW02L010000:F=^jF=^`0001:NS<400`0009En^9En^003UGjh00<0
0028N[f8N[d04XQj_@030000LG32000000aTFK000`0002hfYbhfY`06;SJW00D0000006l006l00000
05<00P0001?oool001;oool4000000Cof900000000000004m]2U00<0003_c:g_c:d00^o<[@040000
j<Jd000000000n^g>@040000mlFFmlFFmlFF0`0000?FjhH00`000>oT`noT``06knC30P0000CFk^<0
0`000=3Af]3AfP0Bd=7J00<00039`M?9`M<01<W1d`030000]L;T]L;T00be`^@500000hV`l0050000
<FkL<FkL<FkL0000008lL]`01000000KW`0KW`0000<008T01@000<6BYl6BY`000;f?YP05XhJe0P00
00C=D0000`000=YW8P00000:Wa/000<0001`0Qm`0Ql03G027`8000099`0W00<0002USK^USK/00ZF=
^`030000WXc1WXc100jNS<400`0009En^9En^005UGjh00<00028N[f8N[d04XQj_@030000I5V`I5V`
00]TFK000`0002hfYbhfY`06;SJW00D0000006l006l0000005<00P0001?oool001;oool2000000Kn
fH80003of900003ldi/00004m]2U00@0003_c:g_c:g_c:d3000000?W_jd0000000001P0000;_XW80
10000=K[Q]K[QP0000__i<<2000000?Fk^<0003@dMX04m3AfP030000bL7CbL7C00K9`M<200002[G2
i08000000kG0h`0000000002PKKf100000@aK]`00`0003abg000000201^O00L0000008T008T008T0
0031TZL000000[f?YPBSQ[D2000000>2@gX0003=D0000le@00<0000:Wa/000<0001`0Qm`0Ql02702
7`@00002B@000P0000HW02L00`000:F=^jF=^`04YHfk00<0002NS<6NS<4039j<`@030000UGjhUGjh
00NEO[P00`0008Qj_HQj_@0@R7Zm0P0000iTFK09;SJW00<0000006l006l00`0001?oool001;oool6
00000_cCV`060000m]2Um]2Um]2U0000klb]0P000005klFX0000ikn]ikn]000000CFLP04kj9b00D0
003FjhKFjhKFjhH000003NoT``80000Cd=7J00<00039`M?9`M<02LW1d`030000]L;T]L;T00Fe`^@2
00001KG0h`030000PKKfPKKf00>1]_H00`00035^g35^g002<FkL00D000006il06il06il000000`00
R@030000`I:W000000>mSjH2XhJe00@00022@gZ2@gZ2@gX200000/e@00040000R000R000R0001@00
00FO6`000`0007027g027`04L08O100000Q900000`0002L09bL09`029`0W00<0002USK^USK/01ZF=
^`030000WXc1WXc100^NS<400`0009En^9En^007UGjh00<00028N[f8N[d03hQj_@040000OVR`OVR`
00003FAI/0T^=ZL00`000000K`00K`0300004oooo`004_ooo`H00002o=>K00<0003fd:D000000`00
00?_aJP01@000>No[NNo[NNo[@000003eW8000D0003_XW;_XW;_XW8000000]K[QP030000knC3knC3
00__i<<00`000=k9a=k9a00200004=3AfP030000bL7CbL7C00_9`M<00`000;G2i;G2i003]L;T00<0
002e`>>e`><01[G0h`030000PKKfPKKf00>1]_H200000S5^g003000001^O01^O00806il010000000
R@00R@00R@800003_HnV0P0000:2@gX200000Z^4Z`030000cE00000000R8000400000YlK00030000
L08O000000<0000=B@00100000ZUSK/00`0009j<`Ij<`@09WXc100<0002EO[REO[P02IEn^0030000
R7ZmR7Zm00b8N[d200000giX/0030000I5V`I5V`00]TFK000`0002hfYbhfY`06;SJW00<0000006l0
06l00`0001?oool0017oool3000000Coeh<0003neHl00002o=>K0P0000;fbj400`000>o5Z>o5Z002
klFX00D0003W_jgW_jgW_jd000000mIb00040000kj9bkj9b00000mK[QP030000knC3knC300__i<<0
0`000=k9a=k9a002g/W40P0000g@dMX00`000<W1dlW1d`0=bL7C0P000003]L;T0000000000Ze`><2
0000186fmPD0000301^O00@0000008T008T008T2000000NmSjH00000002DBFl00022@gX000001J^4
Z`80000<R000100000m9000500003:F=^`030000WXc1WXc100NNS<400`0009En^9En^00;UGjh00<0
0028N[f8N[d02XQj_@030000OVR`OVR`00=nJ;000`0006AI/6AI/00;I5V`00<0000^=ZL^=ZL01Rhf
Y`030000001_001_00<0000Coooo000Aoooo0`000003omN30000o]F?00@00003m/^Q00<0003_aJS_
aJP00^o5Z0030000ikn]ikn]00;W_jd01`000=Ib0=Ib0=Ib00000>nRLP000002e^^600<0003_i<?_
i<<02noT``030000g/W4g/W400GNbL@200002]3AfP030000bL7CbL7C0139`M<00`000;G0hkG0h`0<
]L3S2@0000<06il010000000R@00R@00R@<00003U4U_0P0000J[Q:/00`000<:R^000000300002XP0
00030000B@00B@0000]9000700003ZF=^`030000WXc1WXc100FNS<400`0009En^9En^00<UGjh00<0
0028N[f8N[d02HQj_@030000OVR`OVR`00EnJ;000`0006AI/6AI/00;I5V`22hfY`030000001_001_
008000000oooo`000?ooo`0Aoooo000Aoooo1`0000;kciL01@000?K;XOK;XOK;X@000004klFX00<0
003W_jgW_jd00^No[@040000eW80eW80eW800P0000?FjhH00`000>oT`noT``0;knC300<0003NbLCN
bL@01mk9a0800007d=7J00<00039`M?9`M<04<W1d`030000aK[@aK[@0080000:]L3S00<0002ga>Bg
a>@01`0000@06il01@000000R@00R@00R@000002U4U_0P000003/HBU0000ZhB[00B[Q:/00`000<:R
^<:R^002`Z:h00<0003WaK@000000`0000N800000`0004T004T00007B@001@0000>]VL800`000:F=
^jF=^`0>YHfk00<0002NS<6NS<400ij<`@030000UGjhUGjh00jEO[P00`0008Qj_HQj_@07R7Zm00<0
001nJ;1nJ;001WiX/0030000I5V`I5V`00]TFK09;SJW00H0000006l006l0003oool0000Boooo000A
oooo1@000005o]6=0000nlnGnlnG000000?fbj400`000>o5Z>o5Z002klFX00<0003W_jgW_jd00nNo
[@030000eW80eW8000800002e^^600<0003_i<?_i<<02noT``030000g/W4g/W400[NbL@200001=3A
fP030000bL7CbL7C0139`M<00`000<Fjd<Fjd003aK[@0`0000Fe`><200001kO4i08000000`00R@00
000KW`0201^O00@0000008T008T008T300001;64Y@030000ZhB[ZhB[00:[Q:/00`000<:R^<:R^002
`Z:h00H0003WaK@0002kYL<0002hYLD3000018P000030000B@00B@0000=9000600001JfI`P030000
YHfkYHfk012USK/01@0009j<`Ij<`Ij<`@00000AUGjh00<00028N[f8N[d01XQj_@030000OVR`OVR`
00QnJ;000`0006AI/6AI/00:I5V`00<0000^=ZL^=ZL01RhfY`060000001_001_0000oooo00004_oo
o`004Oooo`D000001OkAS@000?_?Uo_?U`000003m/^Q00<0003_aJS_aJP00^o5Z0030000ikn]ikn]
00?W_jd010000=Ib0=Ib000000?FjhH00`000>oT`noT``0;knC300<0003NbLCNbL@03=k9a0800000
0m3AfP000<W1d`0BbL7C00<00035^]35^]001/Fjd0800002]L3S00<0002ga>Bga>@02;O4i0030000
0029000000<06il01@000000R@00R@00R@000006/HBU00D0002[Q:^[Q:^[Q:/000001<:R^0040000
ilFdilFd00000[^U``040000^:G5^:G5^:G510000003R0000000B@0000@00005/IRn00D0002]VL:]
VL:]VL8000005:F=^`030000WXc1000001>EO[P00`0008Qj_HQj_@03R7Zm0P0000]nJ;000`0006AI
/6AI/00:I5V`00<0000^=ZL^=ZL01RhfY`060000001_001_0000oooo00004_ooo`004Oooo`D00000
1OkAS@000?_?Uo_?U`000003m/^Q00<0003_aJS_aJP00^o5Z0030000ikn]ikn]00CW_jd00`000=Ib
00000002e^^600<0003_i<?_i<<02noT``030000g/W4g/W400oNbL@00`000<W1dlW1d`0AbL7C00<0
0035^]35^]002LFjd0@00008]lCT0P0000030029000001^O00806il01@000000R@00R@00R@000007
/HBU00<0002[Q:/000001L:R^0030000ilFd000000BkYL<01@000;RUaKRUaKRUa@000002/IRn0`00
00ZaV;h00`000:fI`P00000FYHfk00<0002EO[REO[P04iEn^0050000R7ZmR7ZmR7Zm000000enJ;00
0`0006AI/6AI/00;I5V`1bhfY`0781jC0000001C001C0000oooo000001;oool0017oool5000000Gn
dHd0003kciOkciL000000oK;X@030000klFXklFX00;_aJP00`000>No[NNo[@04ikn]0P0000?FjhH0
0`000>oT`noT``0;knC300<0003NbLCNbL@03mk9a0030000d[W200000080000>bL7C00<00035^]35
^]002lFjd0030000`[K?`[K?00D00003]lCT00@0002mc>H008T008T401^O1000R@030000/HBU/HBU
00BaQ:D00`000:^4Z`000005`Z:h00<0003WaK@000001K^U``030000^:G50000016aV;h00`000:F=
^jF=^`0CYHfk0`0001FEO[P0100008Qj_HQj_@0000mnJ;000`0006AI/6AI/00:I5V`1RhfY`8P7Y<0
1P000000D`00D`000?ooo`0001;oool0017ooolK00000]K[QP030000knC3knC300__i<<00`000=k9
a=k9a00?g/W400<0003B^L;B^L800m:i`P80000;bL7C00<00035^]35^]003<Fjd0030000`[K?`[K?
00G2]/lQ00001K^<Y080000A/IRn00@0002[S[L0002UPJ`BYHfk00D0002NPK>NPK>NPK<0000049En
^003UGF/UGjhUGjh00:EO[P2000047iX/0040000I5V`I5V`I5V`26A9WP03I5V`;SJW;SJW008^=ZL0
1BhFP20NTb0NTb0NT`000002001C00<0003oool000004_ooo`004Oooo`D000001Ok>R0000?_;T__;
TP000003m/JK00<0003_`:7_`:400^o0X@030000ikZVikZV00GW^ZH01@000=Ib0=Ib0=Ib0000000=
kj9b00<0003NXI?NXI<03]jQT`030000dYfOdYfO00<0000>bHN<00<00035Qi;5Qi802lF7TP030000
`XND`XND00D00002]fIa00H0002mJ6^mJ6/0000003P00003001L00D0000003T003T003T000001k6K
`@800005`IZ`00<0003W/ih000001K^<Y0030000^8RR0000016aR:/00`000:F1[:F1[00CYH6/0P00
0003WX6c0000UGF/01>EMJ`0100008QTXXQTXP0000mnIJ`00`0006A9WVA9WP0:I4VN00<0000^5X0^
5X000bhFP08P5h/01P000000C000C0000?ooo`0001;oool0017oool5000000GncXP0003kbi;kbi80
00000oK6V`030000kl2Qkl2Q00;_`:400`000>NjY^NjYP04ikZV00<0003FjhH000000]Ib00030000
kj9bkj9b00__XW800`000=jQTmjQT`0>gZ6C0`0001;9Qh`00`000<F7T/F7TP09aHNB100000RgIW42
000000<003P0000005`00P00G0050000000i000i000i000000NaVl400`000:VB_P000005`IZ`00<0
003W/ih000001;^<Y0050000^8RR^8RR^8RR000000:aR:/300002[68Z`030000[H6U000001JUPJ`0
0`0009Ee[9Ee[00CUGF/00D00028I::8I::8I:8000003GiU[0030000I4VNI4VN00]TBIh00`0002hF
P2hFP004;QJ000LP5h/0000004`004`0003oool000004_ooo`004Oooo`D000001Ok>R0000?_;T__;
TP000003m/JK00<0003_`:7_`:400^o0X@030000ikZVikZV00CW^ZH00`000=K[QP000003eW8000<0
003_XW;_XW802nnRLP030000gZ6CgZ6C00_NXI<200000]23NP030000bHN<bHN<0139Qh`00`000<F7
T/F7TP07aHNB0P0000:eIgH00`000;MVLKMVL@07]fIa0P000003000h0000001L008005`01@000000
>@00>@00>@000007/I_100@0002YT[jYT[h00004`IZ`00<0003W/ih000000k^<Y0040000^8RR^8RR
^8RR10000003R>Od0000BJch00@00005/HR[00D0002]PJF]PJF]PJD000005:F1[0030000WWJU0000
01>EMJ`00`0008QTXXQTXP03R6BR0P0000]nIJ`00`0006A9WVA9WP0:I4VN00<0000^5X0^5X001RhF
P0060000001<001<0000oooo00004_ooo`004Oooo`L00002nl^B00D0003faY_faY_faY/000001>o0
X@030000ikZVikZV00?W^ZH00`000=K[Q]K[QP0200000]Ib00030000kj9bkj9b00__XW800`000=jQ
TmjQT`09gZ6C0P0000G@PgX00`000<V7S<V7S00@bHN<00<00035Qi;5Qi800lF7TP<00005]FMf0P00
00NgIW42000000<003P0000005`00P00G0040000000i000i000i0`0000BaVl401@000:VB_ZVB_ZVB
_P000005`IZ`00@0003W/ih0002kS:@5000018SWm0030000BJchBJch00A9[?P500001Jf1Y@030000
YH6/YH6/012UPJ`01@0009ifYIifYIifY@00000BUGF/00<00028I::8I:801HQTXP030000OVF/OVF/
00QnIJ`00`0006A9WVA9WP0:I4VN00<0000^5X0^5X001RhFP0060000000]000]0000oooo00004_oo
o`004Oooo`D000001Ok;P`000?_;T__;TP000003m/JK00<0003_`:7_`:400^o0X@030000ikZVikZV
00?W^ZH00`000=K[Q]K[QP0200000mIb00030000kj9bkj9b00__XW800`000=jQTmjQT`06gZ6C0P00
00S@PgX00`000<V7S<V7S00@bHN<00<00035Qi;5Qi800P0000ZeIgH00`000;MVLKMVL@05000000<0
03P0000005`00`00G0050000000i000i000i000000:DZN@200000[6K`@030000ZI:nZI:n00:YT[h0
0`000<6J/<6J/002`IZ`00<0003W/ih000000P0000R8io@00`0004V/n4V/n007BJch1@0000>]PJD0
0`000:F1[:F1[00>YH6/00<0002NMZFNMZD00iifY@030000UGF/UGF/00jEMJ`00`0008QTXXQTXP07
R6BR00<0001nIJanIJ`01WiU[0030000I4VNI4VN00]TBIh00`0002hFP2hFP006;QJ000H0000002d0
0000003oool0000Boooo000Aoooo1@000003o/^30000000000800003m/JK00<0003_`:7_`:400^o0
X@030000ikZVikZV00;W^ZH01`000=K[Q]K[Q]K[QP000>oT``000002eW8000<0003_XW;_XW802nnR
LP030000gZ6CgZ6C00CNXI<200002m23NP030000bHN<bHN<0139Qh`200003KEWMPL000000`00>000
0000G002001L00@0000003T003T003T400000YBYi0800006ZI:n00<00031V[0000000`0000Z8io@0
0`0004V/n4V/n00;BJch1`0000jUPJ`00`0009ifYIifY@05WWJU00<0002EMJbEMJ`039Ee[0030000
R6BRR6BR00V8I:800`0007iU[7iU[005OVF/00<0001TBIiTBIh02fA9WP030000;QJ0;QJ000D^5X00
0`000000;@00;@02000000?oool0003oool04Oooo`004Oooo`<000001?o9L`000?k;P`0000;lah`3
000000?faY/0003_`:400no0X@030000ikZVikZV00;W^ZH010000=K[Q]K[QP0000;_i<<01@000=Ib
0=Ib0=Ib0000000=kj9b00@0003NXI?NXI?NXI<200003]23NP030000bHN<bHN<00g9Qh`2000000>e
IG80000000002[EWMP800004PQhl0`000003000h0000001L008005`01@000000>@00>@00>@000002
_JK20P0000:DZN@200001JVB_P80000<R>Od10000119[?P400003:F1[0030000WWJUWWJU00NNMZD0
0`0009Ee[9Ee[00;UGF/00<00028I::8I:802XQTXP030000OVF/OVF/00=nIJ`00`0006A9WVA9WP0;
I4VN00<0000^5X0^5X001RhFP0030000000]000]00<0000Coooo000Boooo1P0000;lah`00`000?K2
ToK2T`0300000no0X@050000ikZVikZVikZV000000?FjhH01@000>oT`noT`noT``000002eW8000<0
003_XW;_XW802nnRLP040000gZ6C000000004M23NP030000bHN<bHN<00_9Qh`00`000;EUL[EULP03
]FEb0P0000NeIgH00`00088N?88N?003PQhl0P00008b03000`000000G000G002001L00@0000003T0
03T003T200000kfV`P800002PI3I0P0000:YT[h00`000<goc@000007R>Od1@0000:Oj?/00`00072d
nP00000300003DV/n0@0000:YH6/00<0002NMZFNMZD02IifY@030000UGF/UGF/00VEMJ`00`0008QT
XXQTXP0=R6BR00D0001nIJanIJanIJ`000003FA9WP030000;QJ0;QJ000H^5X000`000000;@00;@03
00004oooo`004_ooo`H00002o<N<00H0003f`Y?f`Y?f`Y<0003_^iX2000000?_`:40003W^ZH00^Nj
YP040000e^^6e^^600001>oT``050000eW80eW80eW80000000g_XW800`000=23N]23NP0Bd8=j00<0
0039Qhc9Qh`02LV7S0030000]FEb]FEb00JeIG800`000;EWM[EWMP03]FMf00<000227Sb27S`00h8N
?0030000<P0`<P0`008b03001@000000G000G000G0000004000i0P0000>mY/82XhBb00@00021T=V1
T=V1T=T200000/goc@040000R>OdR>OdR>Od100000JOj?/00`00072dnW2dnP04L;Cj100000Q9[?P0
0`0002MYfRMYfP029fWJ00<0002UPJbUPJ`01ZF1[0030000WWJUWWJU00ZNMZD00`0009Ee[9Ee[008
UGF/00<00028I::8I:803hQTXP040000OVF/OVF/00003FA9WP030000;QJ0;QJ000H^5X000`000000
;@00;@0300004oooo`004_ooo`8000001?k6J`000?o7N`0000;lah`01@000?K2ToK2ToK2T`000003
kk^J0`000003ikZV0000000000L000001NoT``000=Ib0=Ib0000000;kj9b0P000003eg5:0000d8=j
01?@PgX00`000<V7S<V7S006bHN<0P0000ZeIG82000000BeIgH0000000227S`500001380<0030000
?@0m0000008005`01`000000>@00>@00>@000<6X`@000002_JK21:>4/P8000000h6@f@000<goc@03
cOo=0`0000ZOj?/00`00072dnW2dnP08L;Cj10000099[?P200001RMYfP030000YH6/YH6/00BUPJ`0
0`0009ifYIifY@0<WWJU00<0002EMJbEMJ`01iEe[0030000R6BRR6BR0128I:8200003VA9WP030000
;QJ0;QJ000H^5X0010000000;@000000C080000Coooo000Boooo0P000003o/I[0000olMk00<00004
m/:C00<0003_^i[_^iX00^nkVP040000j;BN000000000n_9C`040000mljQmljQmljQ0`0000?FLP00
0`000>nRL^nRLP06kj9b0P0000CGLDX00`000=23N]23NP0Bd8=j00<00039Qhc9Qh`01<V7S0030000
]FEb]FEb00beIG84000018T_D@050000<P0`<P0`<P0`0000008m03d010000000G000G00000<003T0
0`000<6X`@000002_JK21J>4/P800004cOo=0P0000^Oj?/00`00072dnW2dnP0=L;Cj0P0000TWJMX0
0`000:F1[:F1[002YH6/00<0002NMZFNMZD03YifY@030000UGF/UGF/00FEMJ`00`0008QTXXQTXP0B
R6BR00<0001TBIiTBIh02fA9WP030000;QJ0;QJ000H^5X001@000000;@00;@000000C00200004ooo
o`004_ooo`<000000oo4L_o7N`00000200001?K2T`030000kk^Jkk^J00;_^iX010000>RdW^RdWP00
00?[bDl00`000?O>XOO>X@04mljQ00@0003FLP3FLP000006kj9b0P0000OGLDX00`000=23N]23NP0B
d8=j00<00039Qhc9Qh`00/V7S0030000]FEb]FEb00beIG800`0008T_DHT_D@05RBmA00D0000b030b
030b0300000013d0?@030000001L000000<003T010000<6X`L6X`@0000:SQ;8500001<goc@040000
fOcIfOcI000029oXn`@0000=L;Cj0P000003GH7M00009fWJ00PWJMX010000:F1[:F1[00001:NMZD0
0`0009Ee[9Ee[004UGF/00<00028I::8I:804HQTXP030000LDVA000000aTBIh00`0002hFP2hFP006
;QJ000D0000002d002d0000004`00P0001?oool001;oool3000000Goa780003l`h?l`h<000000oK2
T`030000kk^Jkk^J00?_^iX010000>RdW^RdWP0000?[bDl00`000?O>XOO>X@04mljQ00D0003FLP3F
LP3FLP0000000nnRLP80000:eg5:00<0003@Pg[@PgX04]23NP040000bHN<000000003kEULP030000
RBmARBmA00F9;e4010000380<380<00000Dm03d200000`00>@030000`JS1`JS100@00003XX2_00<0
003=olg=old00/goc@050000fOcIfOcIfOcI000000>Oj?/700000VJbn`@00007L;Cj0P0000AMPMd0
0`0002MYfRMYfP079fWJ0P0001BNMZD00`0009Ee[9Ee[002UGF/00<00028I::8I:804XQTXP030000
LDVALDVA0080000:I4VN00<0000^5X0^5X001RhFP0050000000]000]0000001<0080000Coooo000B
oooo0`000004olAb0000o<>3o<>30P0000;f`Y<00`000>nkV^nkVP03kk^J00@0003X]9kX]9h00003
jlU?00<0003gcZ7gcZ401OO>X@050000eW80eW800000kj9b0080000=eg5:00<0003@Pg[@PgX04]23
NP80000?]FEb00<00029;e69;e401XT_D@030000<P0`000000Lm03d010000000>@00>@00>@<00000
0kjM]`000::0[`03XX2_00<0003=olg=old00/goc@030000fOcIfOcI00?Io=T300000hOWm0<00007
I[;k0`00009`]?X200001ef1g@0300009fWJ9fWJ00LWJMX00`0009ifYIifY@0CWWJU00@0002EMJbE
MJ`0000DR6BR00<0001aBI5aBI400g59T@030000I4VNI4VN00MTBIh00`0002hFP2hFP006;QJ000D0
000002d002d0000004`00P0001?oool001;oool6000000Kl`h<0003h_X/0003f`Y<00005kk^J00@0
003X]9kX]9h00003jlU?00<0003gcZ7gcZ401OO>X@D0000@eg5:00<0003@Pg[@PgX04=23NP030000
]5UN]5UN0080000<]FEb00<00029;e69;e401hT_D@800007?@0m00<0000;00T000000P00>@060000
_Yfg_Yfg_Yfg[HN]00000Z:0[`030000cOo=cOo=00;=old00`000=WlfMWlf@03fOcI0P0000:7io@8
000026Jbn`80000:GH7M00<0000WJMXWJMX01bMYfP030000WWJUWWJU01>NMZD00`0009Ee[000000C
R6BR00<0001aBI5aBI401G59T@030000I4VNI4VN00ITBIh9;QJ000D0000002d002d0000004`00P00
01?oool001;oool6000000Cl`h<0003h_X_h_X/200001NnkVP040000j;BNj;BN00000n_9C`030000
mljQmljQ00KgcZ401@000:4F0:4F0:4F0000000@eg5:0P0000o@PgX00`000;AIG[AIGP03]5UN0`00
00ReIG800`0008T_DHT_D@07RBmA0P0000Lm03d0100000/02@/02@00008003T00`000;jM]kjM]`02
[HN]00<0002RP:l000001Lgoc@030000fOcIfOcI00;Io=T00`000<goc<goc002000000AYHKH0001b
K;ebK;d2000000ADNm/0000000000002I[;k1000009XQM`00`0005f1gEf1g@08GH7M00<0000WJMXW
JMX01bMYfP030000WWJUWWJU01>NMZD00`0008QTXXQTXP0BR6BR00<0001aBI5aBI401W59T@030000
I4VNI4VN00ATBIh00`0002hFP2hFP006;QJ000@0000002d002d00002001<0P0001?oool001?oool0
1@000?bkFOk0IP000?g0N@0200000oRnR`030000kk^Jkk^J00?_^iX010000>RdW^RdWP0000?[bDl0
0`000?O>XOO>X@07mljQ0P0000:Q5P000`000=MaB]MaBP0?eg5:00<0003@Pg[@PgX02m23NP030000
]5UN]5UN00NdFEh300001KEULP030000RBmARBmA00B9;e4400001cd0?@0300002`092`09008;00T2
00000kjM]`:]Qjd200001Lgoc@030000fOcIfOcI00;Io=T00`000<goc<goc002000000>@M[800000
00000g9/_@800002E7_K0`0000MXQM`00`0005f1gEf1g@08GH7M00<0000WJMXWJMX01bMYfP030000
WWJUWWJU016NMZD00`0009=VVP00000BR6BR00<0001aBI5aBI402759T@030000I4VNI4VN00=TBIh0
0`0002hFP2hFP006;QJ000@0000002d002d00002001<0P0001?oool001?oool01@000?bkFOk0IP00
0?g0N@0200000oRnR`<00003kk^J00<0003X]9h000000n_9C`030000mljQmljQ00[gcZ400`000:4F
0:4F000200004=MaBP030000d8=jd8=j00W@PgX00`000;AIG[AIGP0;]5UN0P0000:eIG800`0008T_
D@00000500000h<TA@030000?@0m?@0m00@m03d00`0000/02@/02@042`0900<0002nWKNnWKL00jf7
[@030000cOo=cOo=00?=old00`000=WlfMWlf@02fOcI00<0003=ol`000001@0000EbK;d00`0005Ak
feAkf`02E7_K00<0001XQMaXQM`01FR5g0030000GH7MGH7M00QMPMd00`0002MYfRMYfP089fWJ00<0
002NMZFNMZD03iifY@050000TfJJTfJJTfJJ00000128I:800`000759TG59T@0:LDVA0P0000=TBIh0
0`0002hFP2hFP006;QJ000@0000002d002d00002001<00<0003oooooool04_ooo`004oooo`@00002
oL1i00D0003h_X_h_X_h_X/000000_6gT0060000kk^Jkk^J0000j;BN00000n_9C`030000mljQmljQ
00[gcZ4200000j4F00030000eg5:eg5:00kGLDX00`000=23N]23NP07d8=j00<0002dFEjdFEh03[AI
GP@00009PbA500<0000m03dm03d00cd0?@0300002`092`0900@;00T00`000;jM]kjM]`03[HN]00<0
003=olg=old00lgoc@030000fOcIfOcI00;Io=T010000<goc<goc00000?GSh<00`000<:7U0000005
LVbm00D0001DNm]DNm]DNm/0000026R5g0030000GH7MGH7M00QMPMd00`0002MYfRMYfP089fWJ00<0
002NMZFNMZD03IifY@030000TfJJTfJJ00>CIYX00`0008QTXXQTXP0=R6BR00<0001aBI5aBI403759
T@030000I4VNI4VN00T^5X0010000000;@00;@00008004`00`000?ooooooo`0Boooo000Coooo0`00
0003oK]/0000oL1i00800002n;j;00@0003a]i3a]i3a]i03000000?X]9h0003[bDl00^_9C`030000
mljQmljQ00[gcZ400`000>>k[`000003XAH000<0003GLD[GLDX03]MaBP030000d8=jd8=j00G@PgX0
0`000;AIG[AIGP0@]5UN00<0002394F394D02H<TA@030000?@0m?@0m008m03d00`0000/02@/02@04
2`0900@0002nWKNnWKNnWKL2[HN]0`0000?=old00`000=WlfMWlf@02fOcI10000003liY30000ehn3
00;GSh<200001G9/_@<00002E7_K00<0001XQMaXQM`01VR5g0030000GH7MGH7M00QMPMd00`0002MY
fRMYfP089fWJ00<0002NMZFNMZD02iifY@030000TfJJTfJJ00FCIYX00`0008QTXXQTXP0;R6BR00<0
001aBI5aBI403W59T@030000I4VN;QJ000L^5X001@000000;@00;@00;@000002001<00<0003ooooo
ool04_ooo`004oooo`<000002?fkK0000?g0N@000?VjO`000?RnR`0000Ga]i0300000n_9C`030000
mljQmljQ00[gcZ400`000>>k[n>k[`0200000Z4F00030000eg5:eg5:00kGLDX00`000=23N]23NP03
d8=j00<0002dFEjdFEh04;AIGP030000PbA5PbA500Z394D01@0003d0?Cd0?Cd0?@0000062`0900@0
002nWKNnWKNnWKL3[HN]00<0003ijI?ijI<02@0000;kiZD00`000?>J@`000003ehn300<00032Qi@0
0000179/_@030000N7:oN7:o008000000eAkf`0006R5g007J8GL00<0001MPMeMPMd025f1g@030000
9fWJ9fWJ00PWJMX00`0009ifYIifY@09WWJU00<0002CIYZCIYX01i=VVP030000R6BRR6BR00V8I:80
0`000759TG59T@0@LDVA00<0000^5X0^5X001RhFP0030000000]000]00D0000Doooo000Coooo0`00
0003oK]/0000000000;i^Wl00`000?RnR`000005lKN@00<0003Y[iD000000n_9C`030000mljQmljQ
00[gcZ400`000>>k[n>k[`02hk^_00@0002Q5P2Q5P00000@eg5:00D0003@Pg[@Pg[@PgX000004kAI
GP030000PbA5PbA500Z394D0100003d0?Cd0?@0000H;00T00`000;jM]kjM]`02_Yfg0Zf7[@800004
nNVC00<0003ji:_ji:/00_[TZ`040000nnJUnnJUnnJU0`0000CGSh<00`000<:7U0000003LVbm00<0
001hL[mhL[l00WQb_`800008J8GL00<0001MPMeMPMd02Ef1g@0300009fWJ9fWJ00HWJMX3000029if
Y@80000;TfJJ00<00028I::8I:8028QTXP030000LDVALDVA00maBI401000040AK@00000000H^5X00
0`000000;@00;@02000000<002d0000000005?ooo`005?ooo`<000000ofkK0000?VjO`02nKYo0P00
00Ga]i000`000>V_U@000003jlU?00<0003gcZ7gcZ402_O>X@030000hk^_hk^_00?S^jl00`000:4F
0:4F000200003mMaBP030000d8=j000001>dFEh00`0008<TAH<TA@0;PbA500<0000m03d000001P/0
2@030000_Yfg_Yfg00:nWKL3[HN]00<0003ijI?ijI<00_WYT`030000n^B[n^B[00?ji:/010000?_V
YO_VYO_VY@<00004ehn300H00032QiB@MK40001bK;d00007N7:o1P0000=XQM`00`0005f1gEf1g@09
GH7M00@0000WJMXWJMXWJMX400000R@h[P800006WWJU00<0002CIYZCIYX02i=VVP030000R6BRR6BR
00N8I:800`000759TG59T@0@LDVA00D000104Fe04Fe04Fd000001BhFP0030000000]000]00800000
0`00;@000000000Doooo000Doooo0`000003oK]/0000nKYo00?i^Wl00`000?6gT?6gT003lKN@00<0
003Y[iD000000n_9C`030000mljQmljQ00[gcZ400`000>>k[n>k[`04hk^_00D0002Q5P2Q5P2Q5P00
00003mMaBP80000C]5UN00<0002394F394D02h<TA@8000062`0900<0002nWKNnWKL00kjM]`>]Qjd0
0`000?WYToWYT`02nNVC00<0003ji:_ji:/00_[TZ`040000nnJUnnJUnnJU0P000003m[=n00000000
00CGSh<01@000<:7U000079/_@000007N7:o00<0001eKkmeKkl00gE__a<0000793R^00<0002NMZFN
MZD00iifY@030000TfJJTfJJ00fCIYX00`0008QTXXQTXP05R6BR00<0001aBI5aBI404759T@030000
@15]@15]00=04Fd00`0002hFP2hFP002;QJ000@0000002d002d00002000]00<0003oooooool04ooo
o`005?ooo`030000n:i5o;IJ00<00003nKYo0P0000Ca]i000`000>V_U@000003jlU?00<0003gcZ7g
cZ402_O>X@030000hk^_hk^_00GS^jl01@000:4F0:4F0:4F0000000=eg5:00<0002X<B>X<B<01000
00jdFEh00`0008<TAH<TA@0:PbA50`0000H;00T00`000;jM]kjM]`03_Yfg1:f7[@030000nNVCnNVC
00;ijI<00`000?[TZo[TZ`02n^B[00D0003kiZGkiZGkiZD000000oJcOP800003ehn300<00032QiB@
MK400P0000MhL[l00`0007E__gE__`07MFno00<0001QHKaQHK`02F5Q_003000093R^93R^00LT>:h2
00000iifY@030000TfJJTfJJ00nCIYX00`0008QTXXQTXP04R6BR00<0001aBI5aBI404759T@030000
@15]@15]00A04Fd2000000<^5X00000002d00P00;@040000000]000]00005Oooo`005?ooo`030000
n:i5000000<00003nKYo00<0003c/X@000000o6gT0030000jJnE000000?[bDl00`000?O>XOO>X@0:
mljQ00<0003S^joS^jl01^>k[`800002XAH000<0003GLD[GLDX02MMaBP030000Z34SZ34S00FX<B<4
00002[AIGP030000PbA5PbA500J394D400000V001P0300002`092`0900<;00T200001;jM]`B]Qjd2
00001?WYT`030000n^B[n^B[00;ji:/01@000?_VYO_VYO_VY@000003m[=n00<0003GThT000000P00
0005ehn30000`XNDT7Fa000000MhL[l00`0007E__gE__`07MFno00<0001QHKaQHK`02F5Q_0030000
93R^93R^00LT>:h200000YifY@030000TfJJTfJJ016CIYX00`0008QTXXQTXP02R6BR00<0001aBI5a
BI404759T@030000@15]@15]00M04Fd200000P00;@800002000]00<0003oooooool04oooo`005?oo
o`070000n:i50000o;IJ0000n[E`000000;i^Wl010000?>bQ?>bQ00000;a]i000`000>V_U@000003
jlU?00<0003gcZ7gcZ402_O>X@030000hk^_hk^_00SS^jl010000:4F0:4F000000SGLDX200003:Pa
8`<00006]5UN00<0002394F394D00h<TA@@00006H00600<0000;00T;00T00P/02@8000000lBQ]@00
0;jM]`02_Yfg1:f7[@030000nNVCnNVC00;ijI<00`000?[TZo[TZ`03n^B[00D0003kiZGkiZGkiZD0
00000oJcOP030000ei>9ei>900;GThT4000000><LJl0001hL[l01GQb_`030000MFnoMFno00QeKkl0
0`00065Q_65Q_009HF6l00<0000T>:hT>:h01R@h[P8000000iifY@0009=VVP0DTfJJ00@00028I::8
I:80000BLDVA00<000104Fe04Fd02D0AK@8000000`00;@0000000002000]00<0003oooooool04ooo
o`005?ooo`<000001_bfFP000?ZeL0000?VjO`0000Cc/X@01@000?6gT0000>V_U@000003jlU?00<0
003gcZ7gcZ402_O>X@030000hk^_hk^_00WS^jl00`000:4F0:4F000200001MMaBP030000Z34SZ34S
00nX<B<400000[AIGP030000PbA5000000<0000:H00600@0000;00T;00T;00T200000/BQ]@030000
_Yfg_Yfg00F]Qjd00`000?WYToWYT`02nNVC00<0003ji:_ji:/00o[TZ`030000nnJUnnJU00800003
m[=n00<0003GThWGThT00mNCR@030000`X>@`X>@00:<LJl2000017Qb_`030000MFnoMFno00QeKkl0
0`00065Q_65Q_009HF6l00<0000T>:hT>:h01b@h[P80000GTfJJ00<00028I:8000004W59T@030000
@15]@15]00U04Fd00`0000000P000002000000<002d0003oool05Oooo`005?ooo`<000001?bfFP00
0?ZeL?ZeL0800005lk:40P000003jJnE0000jlU?00;[bDl00`000?O>XOO>X@0:mljQ00<0003S^joS
^jl02^>k[`050000XAH0XAH0XAH0000000?GLDX00`000:Pa8jPa8`0DZ34S100000iP00H00`0000/0
2@/02@0200000lBQ]@<00005[HN]00<0003ijI?ijI<00_WYT`030000n^B[n^B[00?ji:/00`000?_V
Y@000002lKF>00@0003f/gkf/gh00005ei>900<00032Pi32Pi0018aa[`030000N7:oN7:o009hL[l0
0`0007E__gE__`07MFno00<0001QHKaQHK`02F5Q_003000093R^93R^00LT>:h2000069=VVP030000
LDVALDVA011aBI400`00040AKD0AK@09@15]00D0000000800080008000000P00;@030000oooooooo
01Coool001Goool01P000?R^A@000?Z_G0000?ZeL0800006lk:400<0003Y[iD000000n_9C`030000
mljQmljQ00[gcZ400`000>>k[n>k[`0;hk^_00L0002Q5P2Q5P2Q5P00003GLDX000006:Pa8`030000
H006H00600iP00H0100000/02@00000000;4XKD3000000BkTjh0002]Qjf]Qjd400001?WYT`030000
n^B[n^B[00;ji:/00`000?_VY@000003lKF>00<0003f/gh000001]NCR@040000`X>@`X>@`X>@18aa
[`050000N7:oN7:oN7:o000000UeKkl00`00065Q_65Q_009HF6l00<0000T>:hT>:h01b@h[P80000G
TfJJ00<00021BhH000004759T@030000@15]@15]00Y04Fd00`0000000P000P0200000P00;@030000
oooooooo01Coool001Goool3000000Gj[e`0003j]G3j]G0000001_>bQ0<00003jlU?00<0003gcZ7g
cZ402OO>X@030000hk^_hk^_00kS^jl2XAH00`0001NX<B<00`0006001V001P0?H0061P0000;2Uj/0
0`000;^C[P00000200000Z^1YP030000nNVCnNVC00;ijI<00`000?[TZo[TZ`03n^B[0P0000Ga]Hh2
00001]NCR@040000`X>@`X>@`X>@1Haa[`8000000gQb_`0007E__`08MFno00<0001QHKaQHK`02V5Q
_003000093R^93R^00HT>:h200005Y=VVP050000PD^6PD^6PD^6000000maBI400`00040AKD0AK@09
@15]00@00000008000800082000000<002d0000000005_ooo`005Oooo`<00002nZmL00@0003j]G00
00000005lk:40P0000?[bDl00`000?O>XOO>X@0:mljQ00<0003S^joS^jl03^>k[`<00002C0001000
01>X<B<00`0006001V001P0=H006100000O2Uj/00`000;F6X`000003Zh6V00<0003ijI?ijI<00_WY
T`030000n^B[n^B[00?ji:/00`000?6eS_6eSP04lKF>0P0000KGThT00`000<:3T<:3T002`X>@1Xaa
[`80000:MFno00<0001QHKaQHK`02F5Q_003000093R^93R^00LT>:h2000059=VVP030000PD^6PD^6
00>1BhH00`000759TG59T@0;LDVA00<000104Fe04Fd02T0AK@0800000002000200005P1]0000000]
00005oooo`005Oooo`8000001ONV@P000?Z_G0000?ZeL00200001O>bQ0800003jlU?00<0003gcZ7g
cZ402_O>X@030000hk^_hk^_00kS^jl00`000=B^/]B^/P0400000T`000@0000?Z34S00<0001P00IP
00H02F001PL00008`YN[0kF6X`040000Zh6VZh6V00001?WYT`040000n^B[n^B[n^B[0`0000Oa]Hh0
0`000=NCRMNCR@04ei>900<00032Pi32Pi000/:3T0N<LJl200002GE__`030000HF6lHF6l00UQHK`0
0`0002@h[R@h[P0793R^0`0001:CIYX00`00085;QX5;QP04PD^600<0001aBI5aBI402g59T@030000
@15]@15]00U04Fd0100000000P000P000P800002000]00<0003oooooool05Oooo`005Oooo`040000
jiLO000000000_Z_G08000000oF]M0000?>bQ003lk:40P0000?[bDl00`000?O>XOO>X@0:mljQ00<0
003S^joS^jl03^>k[`030000e:jbe:jb00CD[[8400000T`000@0000:Z34S00<0001P00IP00H01V00
1PP0000:`YN[1;F6X`040000Zh6V000000001?WYT`040000n^B[000000000oBfQ`030000lKF>lKF>
00Ca]Hh300001MNCR@030000`X>@`X>@00;2Pi06S76_00@00023IjX000000007MFno00<0001QHKaQ
HK`02F5Q_003000093R^93R^00LT>:h300004I=VVP030000PD^6PD^600J1BhH00`000759TG59T@09
LDVA00<000104Fe04Fd02T0AK@0700000002000200005P1]0000000]0080000Goooo000Foooo0P00
0003mjI20000nZmL00800002mJed00H0003c/XCc/X@0003[ZXP00003jlU?00<0003gcZ7gcZ402_O>
X@030000hk^_hk^_00kS^jl00`000=B^/]B^/P08e:jb1000009<000400001ZPa8`030000H006H006
009P00H800003/:GZ`BeQZ<00`000:^1YP000004nNVC0`0000Gd]XL00`000?6eS_6eSP03lKF>00D0
003HTXKHTXKHTXH000001=NCR@030000`X>@`X>@00?2Pi04S76_00<00023IjZ3IjX00X=WZP<00004
MFno00<0001QHKaQHK`02F5Q_003000093R^93R^00LT>:h2000000>PJI80002CIYX03Y=VVP030000
PD^6PD^600R1BhH00`000759TG59T@07LDVA00<000104Fe04Fd02T0AK@0800000002000200020000
5P1]0000000]0P0001Ooool001Koool2000000GgYT80003j[ecj[e`000000oF]M0050000lk:40000
jjZ8000000?[bDl00`000?O>XOO>X@0:mljQ00<0003S^joS^jl03^>k[`030000e:jbe:jb00OD[[88
00000d`000@000000jPa8`0006001P0700000lVKZ0030000`YN[`YN[00c2Uj/6]HJS0P0000?ijI<2
00001oBfQ`030000lKF>lKF>00?a]Hh00`000=RBQ]RBQP02f9:600D0003GThWGThWGThT000001L:3
T0B<LJl00`0008=WZX=WZP05PfNZ0P0000=eKkl00`00065Q_65Q_009HF6l00<0000T>:hT>:h01b@h
[P8000000j1YTP0009=VVP0;TfJJ0P0000b1BhH00`000759TG59T@06LDVA00<000104Fe04Fd02T0A
K@0400000002000200000QH0K@030000000]000001Soool001Ooool2000000CgYT80003j[e`00003
mJed00D0003c/X@0003[ZXP000000n_9C`030000mljQmljQ00CgcZ4Q00002M>QX`800004C0001P00
00S9VjP00`000<:GZl:GZ`0:`YN[1kF6X`8000001OWYT`0000000?^bH0000008m;J700D0003a]Hka
]Hka]Hh000001]RBQP8000000mNCR@000<:3T005`X>@0Xaa[`030000PfNZPfNZ00R3IjX2000000=e
Kkl0001QHK`02V5Q_003000093R^93R^00LT>:h2000000>PJI80002CIYX02Y=VVP030000PD^6PD^6
00f1BhH00`000759TG59T@04LDVA00<000104Fe04Fd02T0AK@0500000002000200020000008F06d0
0`000000;@00000Hoooo000Goooo0P000003mjI20000nZmL00800003mJed0P000003jjZ80000jlU?
00T00006m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S017CXJ<00`000<VKZ<VKZ00400003<VK
Z0030000`YN[`YN[00[2Uj/7]HJS0`0000Ck/V000`000?BfQoBfQ`05m;J700D0003a]Hka]Hka]Hh0
00002=RBQP800006`X>@0Xaa[`030000PfNZPfNZ00Z3IjX300002V5Q_003000093R^93R^00LT>:h2
00000Z1YTP030000TfJJTfJJ00NCIYX00`00085;QX5;QP0?PD^600<0001aBI5aBI400W59T@030000
@15]@15]00]04Fd0100000000P000P00008F06d010000000;@00;@0001Soool001Ooool200000_NV
@P030000mjIN000000Ce[G@010000>^ZR000000000?XVA`<m;:000<0003QZI[QZIX03^6YVP030000
dj6Sdj6S017CXJ<00`000<VKZ<VKZ00@bI^X00<00032Uj_2Uj/02L:GZ`ReQZ<00`000?^bH?^bH004
nk9P00<0003d]XOd]XL01_BfQ`040000lKF>lKF>00002MRBQPD00003`X>@00<00023IjZ3IjX038=W
ZP030000KE:Q000000800007HF6l00<0000T>:hT>:h01b@h[P030000001C000000:PJI800`0009=V
VY=VVP05TfJJ00<00021BhJ1BhH0485;QP030000LDVALDVA009aBI400`00040AKD0AK@0:@15]00D0
000000800080008000000QH0K@040000000]000]00006?ooo`006?ooo`8000001ONV@P000?NVG_NV
GP000003mJed0`0000CXVA`00`000?BbP?BbP00:m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S
013CXJ<00`000<VKZ<VKZ00@bI^X00<00032Uj_2Uj/02<:GZ`VeQZ<00`000?^bH?^bH004nk9P00<0
003d]XOd]XL01_BfQ`030000lKF>000000[HTXH00`000<5lQl5lQ`02`Gb7100000j3IjX00`0006eB
XFeBX@02KE:Q100000AQHK`00`0002@h[R@h[P0793R^0P0000:PJI800`0009=VVY=VVP04TfJJ00<0
0021BhJ1BhH04X5;QP040000LDVALDVA00003D0AK@0400000002000200000QH0K@@0000Ioooo000H
oooo0P000005mjI20000mjINmjIN000000?e[G@010000>jTN000000000?XVA`00`000?BbP?BbP00:
m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S013CXJ<00`000<VKZ<VKZ00AbI^X00<00032Uj_2
Uj/01l:GZ`VeQZ<200001_^bH0030000m;J7m;J700Gd]XL00`000?6eSP00000:f9:600<00031O8O1
O8L01/5lQ`J3IjX00jm`Rh=WZX=WZP04PfNZ00<0001]DZ5]DZ401feBX@<000000f5Q_00002@h[P08
93R^0P0000>PJI800`0009=VVY=VVP02TfJJ00<00021BhJ1BhH0585;QP030000LDVA000000a04Fd0
100000000P000P000P<0000010h0D@0000004`0001Woool001Woool2000000GcVch0003gYUkgYUh0
00000_F]M0040000kZAhkZAh00000nRI70030000m;:0m;:000[d/X000`000>6YV^6YVP0>hJVJ00<0
003CXJ?CXJ<04M>QX`030000bI^XbI^X0139VjP00`000<:GZl:GZ`06`YN[2[F6X`800006nk9P00<0
003d]XOd]XL01_BfQ`030000f9:6f9:600WHTXH00`000<5lQl5lQ`07`Gb70X=WZP03`Gb7PfNZPfNZ
00N3IjX00`0006eBXFeBX@0:KE:Q0`0000PT>:h00`000000D`000003X6VB00@0002CIYZCIYX0000H
PD^600<000104Fe04Fd02d0AK@0400000002000200000`h0D@040000000C000C00006Oooo`006Ooo
o`8000001o>K?P000?NVG_NVGP000?F]M0000003kZAh00D0003XVAcXVAcXVA`000003?BbP0030000
hJVJhJVJ00kQZIX00`000=>QXm>QX`0Adj6S00<00039VjS9VjP04<VKZ0030000`YN[`YN[00K2Uj/;
]HJS00<0003k/V3k/V001?^bH0030000m;J7m;J700Kd]XL00`000=RBQ]RBQP09f9:600<00031O8O1
O8L01l5lQ`b3IjX00`0006eBXFeBX@0;KE:Q00<0000d7HD000000`0000@T>:h00`000000D`000003
X6VB00<0002CIYX00000685;QP030000Ea9J000000]04Fd01@0000000P000P000P0000033P1A00<0
000001<000006_ooo`006Oooo`050000iHH@li/nli/n000000;gYUh200000njTN0030000j9TLj9TL
00;XVA`00`000?BbP?BbP00:m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S013CXJ<00`000<VK
Z<VKZ00@bI^X00<00032Uj_2Uj/01L:GZ`beQZ<00`000?^bH?^bH004nk9P00<0003d]XOd]XL01OBf
Q`030000fhae000000[HTXH00`000<5lQl5lQ`08`Gb72h=WZP030000KE:QKE:Q00]]DZ400`0003@M
QC@MQ@03=1f51000000393R^0000000000BPJI800`00085;QX5;QP0FPD^600D0001G4UYG4UYG4UX0
00002T0AK@0400000002000200000`h0D@040000000C000C00006_ooo`006_ooo`8000001?>K?P00
0?NVG_NVGP800004kZAh00D0003XVAcXVAcXVA`000003?BbP0030000hJVJhJVJ00kQZIX00`000=>Q
Xm>QX`0@dj6S00<00039VjS9VjP04LVKZ0030000`YN[`YN[00C2Uj/<]HJS0P0000Kk/V000`000?Bf
QoBfQ`04m;J700<0003KS7GKS7D00P0000SHTXH00`000<5lQl5lQ`09`Gb72H=WZP030000KE:QKE:Q
00]]DZ400`0003@MQC@MQ@08=1f50`0000:PJI82000000>CDG`00021BhH05H5;QP030000Ea9JEa9J
00=G4UX00`00040AKD0AK@06@15]00D0000000800080008000000`h0D@030000000C000001_oool0
01[oool200000_>K?P040000mjINmjIN00001>jTN0050000j9TLj9TLj9TL000000cd/X000`000>6Y
V^6YVP0>hJVJ00<0003CXJ?CXJ<04M>QX`030000bI^XbI^X0139VjP00`000<:GZl:GZ`03`YN[3KF6
X`800006nk9P00<0003d]XOd]XL00oBfQ`030000fhaefhae00?KS7D00`000=RBQ]RBQP04f9:600<0
0031O8O1O8L02/5lQ`V3IjX00`0006eBXFeBX@0;KE:Q00<0000d7HDd7HD02C@MQ@@00003Te5l00<0
0021BhJ1BhH04h5;QP030000Ea9JEa9J00EG4UX00`00040AKD0AK@05@15]00@00000008000800004
3P1A00<0000001<000006oooo`006_ooo`050000iHH@0000li/n000000;gYUh200000njTN0050000
j9TLj9TLj9TL000000cd/X000`000>6YV^6YVP0>hJVJ00<0003CXJ?CXJ<04M>QX`030000bI^XbI^X
0139VjP00`000<:GZl:GZ`03`YN[3[F6X`030000nk9Pnk9P00Ck/V000`000?BfQoBfQ`02m;J700<0
003KS7GKS7D01M^<M@030000f9:6f9:600?HTXH00`000<5lQl5lQ`0;`Gb728=WZP030000KE:QKE:Q
00]]DZ400`0003@MQC@MQ@09=1f500<00000014000001I=AO0030000PD^6PD^60161BhH00`0005LB
FULBFP07Ea9J00<000104Fe04Fd00d0AK@050000000200020002000000<>0540100000004`004`00
01_oool001_oool200000_>K?P050000mjIN0000l9aO000000?^Y7P01@000>RI7>RI7>RI7000000<
m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S013CXJ<00`000<VKZ<VKZ00@bI^X00<00032Uj_2
Uj/00/:GZ`beQZ<500001_^bH0050000m;J7m;J7m;J7000000SKS7D00`000=RBQ]RBQP02f9:600<0
0031O8O1O8L02l5lQ`R3IjX00`0006eBXFeBX@0;KE:Q00<0000d7HDd7HD02C@MQ@030000000A0000
00FCDG`00`00085;QX5;QP0@PD^600<0001G4UYG4UX02ELBFP030000@15]@15]00904Fd3000200<0
000>054>05400Ph0D@030000000C000001coool001_oool010000>F640000?>K?P800002l9aO00D0
003^Y7S^Y7S^Y7P000000nRI70030000m;:0m;:000[d/X000`000>6YV^6YVP0>hJVJ00<0003CXJ?C
XJ<04M>QX`030000bI^XbI^X0139VjP010000<:GZ`00000000ReQZ<400000k5lVP800006nk9P00@0
003d]XOd]XL0000:fhae00D0003HTXKHTXKHTXH000003/5lQ`J3IjX00`0006eBXFeBX@0<KE:Q00<0
000d7HDd7HD023@MQ@040000000A000A00001Y=AO0030000PD^6PD^600j1BhH00`0005LBFULBFP0;
Ea9J00@000104Fe04Fd00003000200D0000>054>054>054000000P004`030000oooooooo01[oool0
01_oool00`000>F640000002li/n00D0003`W5o`W5o`W5l000000^jTN0050000j9TLj9TLj9TL0000
00cd/X000`000>6YV^6YVP0>hJVJ00<0003CXJ?CXJ<04M>QX`030000bI^XbI^X00k9VjP4000000>n
S:40002eQZ<01;F6X`<00007/GbJ0P0000Kk/V000`000?BfQ`00000<fhae0P000003f9:60000`Gb7
00g1O8L6PfNZ00<0001]DZ5]DZ402feBX@030000=1f5=1f500Td7HD0100000004@004@0000JCDG`0
0`00085;QX5;QP0=PD^600<0001G4UYG4UX03ELBFP030000@15]00020080008200000`h0D@030000
000C000001goool001coool01@000>F640000?>K?P000004l9aO00<0003^Y7P000000nRI70030000
m;:0m;:000[d/X000`000>6YV^6YVP0>hJVJ00<0003CXJ?CXJ<04M>QX`030000bI^XbI^X00[9VjP4
00000/J?W0060000_XbQ_XbQ_XbQ0000]HJS0`0000^aO9X200001_^bH080000>fhae0P0000k1O8L0
0`0008=WZX=WZP03PfNZ00<0001]DZ5]DZ402feBX@030000=1f5=1f500Td7HD00`0000004@000008
Te5l00<00021BhJ1BhH02h5;QP030000Ea9JEa9J00mG4UX200000P000P0500003P1A3P1A3P1A0000
008001<00`000?ooooooo`0Koooo000Loooo00@0003UQQ00003cVch200001?2LG`030000kZAh0000
00?XVA`00`000?BbP?BbP00:m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S013CXJ<00`000<VK
Z<VKZ005bI^X1@0000O6Si`500003[5lVP800006nk9P00<0003KS7GKS7D03]^<M@<0000<`Gb70`00
00>3IjX00`0006eBXFeBX@0;KE:Q00<0000d7HDd7HD02C@MQ@030000000A000000RCDG`00`00085;
QX5;QP0:PD^600<0001G4UYG4UX03eLBFPH000033P1A00<0000001<000007_ooo`007?ooo`060000
iHH@iHH@0000kXdj00001O2LG`800003j9TL00<0003d/X3d/X002_BbP0030000hJVJhJVJ00kQZIX0
0`000=>QXm>QX`0Adj6S00<00039VjS9VjP0100000c6Si`3^h:F00<0002aO9ZaO9X03K5lVP800005
nk9P00<0003ON4<000003m^<M@030000`6ia`6ia00@00008`Gb700<0002_L8^AIY`00`0000i]DZ40
0`0003@MQC@MQ@09=1f500<00000014000002I=AO0030000PD^6PD^600R1BhH00`0005LBFULBFP0?
Ea9J1@000003@A=`00003P1A008>05400`0000004`00000Noooo000Moooo0`0000;^SCX00`000?2L
Go2LG`02l9aO0P0000?XVA`00`000?BbP?BbP00:m;:000<0003QZI[QZIX03^6YVP030000dj6Sdj6S
00oCXJ<500003lJ?W0FkPYH00`000;5lV[5lVP0</GbJ0P0000Gk/V0010000=mh@mmh@`0000kKS7D0
0`000<1^LL1^L@04`6ia100000G1O8L01@00095VW95VW95VW000000>KE:Q00<0000d7HDd7HD02C@M
Q@030000000A000000ZCDG`00`00085;QX5;QP06PD^600<0001G4UYG4UX03eLBFPD000000d4CL000
00h0D@023P1A00@0000001<001<0000Noooo000Moooo00@0003LLP3LLP000002kXdj00<0003`W5o`
W5l00_2LG`800003j9TL00<0003d/X3d/X002OBbP0030000hJVJhJVJ00kQZIX00`000=>QXm>QX`0:
dj6S1@0000;?TY@00`000<J?W<J?W00?aXnL1K^2UP030000/GbJ/GbJ00faO9X200000o^bH0030000
ggQ3ggQ300;ON4<00`000=^<MM^<M@0:fhae00<00030KW70KW402L1^L@@000001/5lQ`000:m`Ri5V
W00007i=S@80000<KE:Q00<0000d7HDd7HD023@MQ@040000000A000A00002Y=AO0030000PD^6PD^6
00F1BhH00`0005LBFULBFP0?Ea9J1@0000914g001`0000h0D@h0D@h0D@0000004`00000Ooooo000N
oooo00<0003LLP0000000^j=>P030000l9aOl9aO00?`W5l01@000>RI7>RI7>RI7000000<m;:000<0
003QZI[QZIX03^6YVP030000dj6Sdj6S00GCXJ<400002<nBU0030000aXnLaXnL00g6Si`6^h:F00<0
002aO9ZaO9X03K5lVP800002nk9P00<0003ON4?ON4<01=mh@`030000fhaefhae00WKS7D00`000<1^
LL1^L@0=`6ia1@0000=nCHd00`0006eBXFeBX@08KE:Q00<0000d7HDd7HD02C@MQ@040000000A000A
00002i=AO0030000PD^6PD^600>1BhH00`0005LBFULBFP0?Ea9J1@0000=14g00100000h0D@h0D@00
008001<00`000?ooooooo`0Moooo000Noooo00@0003LLP3LLP000002kXdj00<0003`W5o`W5l00_2L
G`050000j9TLj9TLj9TL000000cd/X000`000>6YV^6YVP0>hJVJ00<0003CXJ?CXJ<01@0000c?TY@0
0`000<J?W<J?W00<aXnL1k^2UP030000/GbJ/GbJ00faO9X2000000?k/V00003ON4<01mmh@`030000
fhaefhae00SKS7D00`000<1^LL1^L@0>`6ia00<0002XG7BXG7@01Gi=S@800008KE:Q00<0000d7HDd
7HD02C@MQ@030000000A000000bCDG`00`00085;QX5;QP02PD^600<0001G4UYG4UX03eLBFPD00003
@A=`00<0000>054000001000023oool001ooool00`000=ab00000003kXdj00D0003`W5o`W5o`W5l0
00000nRI70030000m;:0m;:000[d/X000`000>6YV^6YVP0<hJVJ1@0001;?TY@00`000<J?W<J?W00;
aXnL2;^2UP030000/GbJ/GbJ00baO9X010000;id0000000000WON4<00`000=^<MM^<M@07fhae00<0
0030KW70KW403/1^L@040000Z5adZ5adZ5ad1Wi=S@030000KE:QKE:Q00E]DZ400`0003@MQC@MQ@09
=1f500<00000014000003I=AO0040000PD^6PD^600004ELBFPD00003@A=`0`000003200g00000000
0080000Poooo000Ooooo00@0003LLP3LLP000002kXdj00@0003`W5o`W5o`W5l200000nRI70030000
m;:0m;:000Wd/X000`000>6YV^6YVP08hJVJ100000?KUHD00`000<nBU<nBU00Aci:D00<00036Sic6
Si`02/J?W0VkPYH00`000;5lV[5lVP0=/GbJ0P0000_ON4<00`000=^<MM^<M@06fhae00<00030KW70
KW403/1^L@030000Z5adZ5ad00:XG7@6OTf=00<0001]DZ5]DZ4016eBX@030000=1f5=1f500Td7HD0
0`0000004@00000=Te5l00<00021BhH000004ELBFPD000001T4CL0000000000003H0E`00008803L3
00008Oooo`008?ooo`030000g780000000?^SCX01@000?2LG`000>R@H@000003j9TL00<0003d/X3d
/X002_BbP0030000hJVJhJVJ00?QZIX400001m^EQ@030000ci:Dci:D01;?TY@00`000<J?W<J?W008
aXnL2[^2UP030000/GbJ/GbJ00faO9X300002mmh@`030000fhaefhae00CKS7D00`000<1^LL1^L@0?
`6ia00<0002XG7BXG7@00ZQLM0MnCHd2000016eBX@030000=1f5=1f500Td7HD00`0000004@00000=
Te5l0P00015G4UX700000cH0E`030000200g200g00@0000Qoooo000Qoooo00<0003LLP0000000nj=
>P8000000nR@H@000>RI7002j9TL00<0003d/X3d/X002_BbP0030000hJVJ000000<0000<fiF500<0
003?TYC?TY@04LnBU0030000aXnLaXnL00S6Si`:^h:F00<0002aO9ZaO9X03K5lVP040000XQl0XQl0
00002mmh@`030000fhaefhae00?KS7D00`000<1^LL1^L@0?`6ia00<0002XG7BXG7@00jQLM0QnCHd0
100006eBXFeBX@0000/d7HD0100000004@004@0000^CDG`200000W8JB@030000Ea9JEa9J00eG4UX5
000000=D6VT0000f05L00cH0E`030000200g200g00<0000Roooo000Qoooo00<0003LLP0000000nj=
>P800002j91Q00@0003XVAcXVA`00009m;:01@00013KUHD00`000<nBU<nBU00Bci:D00<00036Sic6
Si`01/J?W0bkPYH00`000;5lV[5lVP0=/GbJ00@0002R7`2R7`00000;ggQ300<0003KS7GKS7D00]^<
M@030000`6ia`6ia00o0KW400`000:QLM:QLM003Z5ad2Gi=S@<0000;=1f500@00000014001400009
Te5l0P0000Ab6TT00`0005LBFULBFP0<Ea9J1@000003E1YY0000=P1G00<f05L00`0000P0=`P0=`04
00008_ooo`008_ooo`030000g780000000?^SCX010000>R@HNR@H@0000?XVA`00`000?BbP?BbP006
00001>VBH@030000fiF5fiF500oKUHD00`000<nBU<nBU00Aci:D00<00036Sic6Si`01/J?W0bkPYH0
0`000;5lV[5lVP0>/GbJ00@0002R7`2R7`00000;ggQ300D0003KS7GKS7GKS7D000004L1^L@030000
Z5adZ5ad00BXG7@:OTf=00<0000d7HDd7HD02C@MQ@040000000A000A00001i=AO0800007LQY900<0
001G4UYG4UX02ULBFPH000000e@JJ@0003H0E`03=P1G00<0000803L803L00`0002?oool002?oool2
00000nj=>P8000000nR@H@000>RI7002j9TL0`0000[YTV400`000=^EQM^EQ@0?fiF500<0003?TYC?
TY@04/nBU0030000aXnLaXnL00C6Si`=^h:F00<0002aO9ZaO9X03k5lVP040000XQl0XQl000002mmh
@`030000fhae000001;0KW400`000:QLM:QLM004Z5ad2Gi=S@040000CAAV000000002C@MQ@030000
000A000000JCDG`200002W8JB@030000Ea9JEa9J00QG4UX6000000=D6VT0000f05L00cH0E`030000
200g200g00<0000Toooo000Soooo00D0003LLP00003^SCX000000^Im=P800002j9TL00<0003FI@00
00003>VBH@030000fiF5fiF500oKUHD00`000<nBU<nBU00Aci:D00<00036Sic6Si`01<J?W0jkPYH0
0`000;5lV[5lVP0</GbJ100000:R7`000`000=mh@mmh@`09ggQ30P0001?0KW400`000:QLM:QLM004
Z5ad27i=S@050000CAAVCAAVCAAV000000Pd7HD00`0000004@000003Te5l0`0000ab6TT00`0005LB
FULBFP07Ea9J1P00009D6VT00`0003H0EcH0E`02=P1G00<0000803L803L00`0002Coool002Coool2
000000?^SCX0003VOCH00^Im=P<00002eVD000<0003YTV7YTV402^VBH@030000fiF5fiF500oKUHD0
0`000<nBU<nBU00Bci:D00<00036Sic6Si`00/J?W0nkPYH00`000;5lV[5lVP09/GbJ0`0000B/KX`0
10000:8O0:8O000000_ON4<200004/1^L@030000Z5adZ5ad00BXG7@7OTf=00<0001=56I=56H00ddD
IP800006=1f500@000000140002CDG`20000478JB@030000Ea9JEa9J00EG4UX600000e@JJ@050000
=P1G=P1G=P1G0000008803L300009Oooo`009?ooo`030000g780000000GVOCH00`000=IU0=IU0002
eVD000<0003YTV7YTV402^VBH@030000fiF5fiF500oKUHD00`000<nBU<nBU00Aci:D00<00036Sic6
Si`00/J?W0nkPYH00`000;5lV[5lVP06/GbJ0`0000R/KX`010000:8O0:8O000000[ON4<00`000;U;
>@00000300003/1^L@030000Z5adZ5ad00FXG7@5OTf=00<0001=56I=56H01TdDIP800003=1f500<0
0000014001400P00019b6TT00`0005LBFULBFP04Ea9J1P0000=D6VT00`0003H0EcH0E`02=P1G00<0
000803L803L00P0002Koool002Goool00`000=1H00000005iWdf00<0003FI@3FI@000]IU00030000
jI9QjI9Q00WYTV400`000=^EQM^EQ@0?fiF500<0003?TYC?TY@04/nBU0030000aXnLaXnL012kPYH0
0`000;5lV[5lVP03/GbJ0`0000b/KX`00`000:8O00000009ggQ300<0002iBcViBcT01;U;>@<0000;
`6ia00<0002XG7BXG7@01JQLM0EnCHd00`0004dDITdDIP08CAAV00@0000d7HDd7HD00002000A00<0
001b6TUb6TT04W8JB@030000Ea9JEa9J009G4UX6000015@JJ@050000=P1G=P1G=P1G0000008803L3
00009_ooo`009_ooo`030000d5P0000000CVOCH00`000=IU0=IU0002eVD000<0003YTV7YTV402^VB
H@030000fiF5fiF500oKUHD00`000<nBU<nBU00Aci:D00<00036SibkPYH04K^2UP030000/GbJ0000
0080000?[6j<0P000003XQl00000ggQ300OON4<00`000;U;>KU;>@07^D/i0`0000S0KW400`000:QL
M:QLM006Z5ad0gi=S@030000CAAVCAAV00Y=56H300000P004@030000LQY9LQY901=b6TT00`0005LB
FULBFP06000015@JJ@030000=P1G=P1G008f05L00`0000P0=`P0=`0200009oooo`009oooo`030000
d5P0000000CVOCH00`000=IU0=IU0002eVD000<0003YTV7YTV402^VBH@030000fiF5fiF500oKUHD0
0`000<nBU<nBU00Aci:D00<0002kPYJkPYH01k^2UP/0000C[6j<00@0002R7`2R7`000007ggQ300<0
002iBcViBcT02[U;>@@00004`6ia00<0002XG7BXG7@01ZQLM09nCHd00`0004dDITdDIP0=CAAV00<0
0000014000005W8JB@030000Ea9J000000D00005E1YY00H0000f05Lf05Lf05L0000803L400009ooo
o`009oooo`030000d5P0000000GVOCH00`000=IU0=IU0002eVD000<0003YTV7YTV402NVBH@030000
fiF5fiF500oKUHD00`000<nBU<nBU00Aci:D2P0000VhMHL00`000:a^S:a^S00B[6j<0P0000:R7`00
0`000=mh@mmh@`04ggQ300<0002iBcViBcT03[U;>@<000000l1^L@000:QLM008Z5ad00=nCHd0001=
56H03DdDIP@0000FLQY91`0000ED6VT00`0003H0EcH0E`070000:?ooo`00:?ooo`030000d5P00000
00CVOCH00`000=IU0=IU0002eVD000<0003YTV7YTV402^VBH@030000fiF5fiF500oKUHD00`000<nB
U<nBU00>ci:D00<0003?TYBhMHL04kQeQ`030000[6j<[6j<01:/KX`200000Z8O00030000ggQ3ggQ3
00;ON4<00`000;U;>KU;>@0B^D/i300000m=56H40000578JB@T00004E1YY10000004;@0o00001@0P
1@0P0P0002Woool002Woool00`000=1H00000004iWdf00<0003FI@3FI@000]IU00030000jI9QjI9Q
00WYTV400`000=^EQM^EQ@0?fiF500<0003?TYC?TY@03<nBU08000000lR2Q@000;QeQ`0C^7F700<0
002/KXb/KX`04Za^S0030000WVVC000000:R7`001@000=mh@mmh@mmh@`00000E^D/i00<0002C;3fC
;3d029</?@i=56H500004W8JB@T0000016P]LP0005@JJE@JJ@<00004;@0o00<00005020000000P00
02Woool002[oool00`000=1H00000004iWdf00<0003FI@3FI@000]IU00030000jI9QjI9Q00WYTV40
0`000=^EQM^EQ@0?fiF500<0003?TYC?TY@02LnBU0800002b8:500?4OH<0002hMHL04kQeQ`030000
[6j<[6j<01>/KX`00`0009iYT`000002XQl000@0003ON4?ON4<0000E^D/i00<0002C;3fC;3d02I</
?@a=56H500004G8JB@T00002J2eb00@0001D6VT000000002B@EC00H0000]03l]03l]03l000050203
0000:_ooo`00:_ooo`040000d5P0d5P000000nIm=P030000eVD0eVD000;FI@000`000>VBHNVBH@09
jI9Q00<0003KUHGKUHD03m^EQ@030000ci:Dci:D00K?TY@200001LR2Q@;4OH<00`000;QeQkQeQ`0A
^7F700<0002/KXb/KX`04ja^S0040000WVVCWVVC00000Z8O0080000F^D/i00<0002C;3fC;3d02I</
?@]=56H600003g8JB@T00003J2eb0`0000=91E<01@0002d0?bd0?bd0?`0000021@0P0P0002_oool0
02_oool010000=1H0=1H000000?VOCH00`000=IU0=IU0002eVD000<0003YTV7YTV402NVBH@030000
fiF5fiF500oKUHD00`000<nBU<nBU003ci:D0P0000K8PXD3a7f300<0002hMHNhMHL04[QeQ`030000
[6j<[6j<01>/KX`0100009iYTiiYT`0000:R7`0200005KU;>@030000Tb`mTb`m00ZC;3d:CAAV1@00
00ib6TT900000fP]LP8000000e`HGP0004T5D`03B@EC00H0000]03l]03l]03l0000502030000:ooo
o`00;?ooo`040000d5P0d5P000000nIm=P050000eVD0eVD0eVD0000000cYTV400`000=^EQM^EQ@0>
fiF500D0003?TYC?TYC?TY@000002LR2Q@?4OH<00`000;QeQkQeQ`0B^7F700<0002/KXb/KX`04ja^
S0070000WVVCWVVCWVVC0000XQl00000009[000200004[U;>@030000Tb`mTb`m00^C;3d8CAAV1@00
00eb6TT:00000VP]LP800002G1QN00<000191E=91E<00TT5D`060000;@0o;@0o;@0o00001@0P0`00
02coool002goool00`000=1H00000003iWdf00<0003FI@3FI@000]IU00030000jI9QjI9Q00WYTV40
0`000=^EQM^EQ@0>fiF50`0000[8PXD4a7f300<0002hMHNhMHL04[QeQ`030000[6j<[6j<01B/KX`0
100009iYTiiYTiiYT`800004J`000P00012iBcT00`0009</?I</?@0;Tb`m1ddDIPH0000;LQY92@00
009f>GL3000015`HGP050000B@ECB@ECB@EC000000<]03l00`0000D0800000020000;Oooo`00;_oo
o`070000d5P00000iWdf0000fV`c000000CFI@000`000>VBHNVBH@09jI9Q00<0003KUHGKUHD02]^E
Q@<00002dGma00<00038PXG8PXD02<R2Q@C4OH<00`000;QeQkQeQ`0B^7F700<0002/KXb/KX`05:a^
S0040000WVVCWVVCWVVC0`0000E[000300003[U;>@030000Tb`mTb`m00^C;3d6CAAV1@000003Tb`m
0000LQY900Mb6TT900000gHiM`800005G1QN00<000191E=91E<00TT5D`040000;@0o;@0o00000PD0
8080000^oooo000^oooo00<0003@F03@F0000P000003fV`c0000eVD000?FI@000`000>VBHNVBH@09
jI9Q00<0003KUHGKUHD01m^EQ@<00006dGma00<00038PXG8PXD01/R2Q@G4OH<00`000;QeQkQeQ`0C
^7F700<0002/KXb/KX`05:a^S0<00003Sdmn0`0000E[000300002kU;>@030000Tb`mTb`m00^C;3d5
CAAV1@0000:C;3d00`00078JBG8JB@04LQY92@0000=f>GL2000000=[9F@0001L65h015`HGP050000
B@ECB@ECB@EC000000<]03l00`D08000000000020000;_ooo`00;oooo`040000d5P0000000000]Y/
<`030000eVD0eVD000;FI@000`000>VBHNVBH@09jI9Q00<0003KUHGKUHD00m^EQ@<0000:dGma00<0
0038PXG8PXD01LR2Q@K4OH<00`000;QeQkQeQ`0B^7F700<0002/KXb/KX`04ja^S0800008Sdmn0P00
00I[000200002KU;>@030000Tb`mTb`m00bC;3d3CAAV1@0000>C;3d00`00078JBG8JB@02LQY92P00
009f>GL200000f/UI0030000G1QNG1QN009L65h00`0004T5DdT5D`02B@EC00<]03l0000000001@00
02ooool0033oool010000;di0;di000000;JK3<00`000=IU0=IU0002eVD000<0003YTV7YTV402>VB
H@030000fiF5fiF500<0000=dGma00D00038PXG8PXG8PXG4OH<00/R2Q@O4OH<00`000;QeQkQeQ`0B
^7F700<0002/KXb/KX`04:a^S0<00002X5Id00<0002?Cgj?Cgh01hm?OP<00005J`000`0000JiBcT0
0`0009</?I</?@0<Tb`m0TdDIPH00004Tb`m00<0001b6TT00000200000:1@GP3000016/UI0030000
G1QNG1QN00=L65h00`0004T5DdT5D`03000000<T02P0000300/00`00033oool0037oool01P000;di
0;di00000=Y/<`0000CFI@000`000>VBHNVBH@08jI9Q0`00017AOg400`000<R2QLR2Q@02b8:52<Am
P`030000^7F7^7F701>hMHL00`000:a^S:a^S00<[6j<0`0000FPEW@00`0008m?OXm?OP0:Sdmn0`00
00E[000300000kU;>@030000Tb`mTb`m00fC;3d00ddDIP000000000A00001851N0030000JbETJbET
00A[9F@00`0005`HGU`HGP02G1QN00<000191E<000000P00008T02P00`0000<02`0000020000<Ooo
o`00<_ooo`030000_CT0_CT000<00004eVD000<0003YTV7YTV401NVBH@800002f71500<0003AOg7A
Og404=5oL@040000b8:5b8:5b8:52<AmP`030000^7F7^7F701>hMHL00`000:a^S:a^S009[6j<0`00
00VPEW@00`0008m?OXm?OP0<Sdmn0`0000E[0002000000>iBcT0002C;3d01Y</?@h00005;`001`00
00B1@GP300001V/UI0040000G1QNG1QNG1QN0`00008m03`00`0002@0:00000020`0;0P0003;oool0
03?oool010000;di0;di0;di00800004eVD000<0003YTV7YTV400^VBH@800005f71500<0003AOg7A
Og404=5oL@030000b8:5a7f300S4OH<00`000;QeQkQeQ`0C^7F700<0002/KXb/KX`01Za^S0<0000<
X5Id00<0002?Cgj?Cgh03hm?OP<00004J`002@0000T_0003000022l000@00004PD5h0P00009e;VL0
0`0006/UI6/UI004JbET00<0001L65h000000P0000<m03`01@0002@0:2@0:00000<02`020000<ooo
o`00=?ooo`050000_CT0_CT0_CT0000000CFI@000`000>VBHNVBH@0200002=Q`A@030000dGmadGma
013AOg4200002<AmP`030000^7F7^7F701>hMHL00`000:a^S:a^S003[6j<0`00012PEW@00`0008m?
OXm?OP0ASdmn0P0000=[00000`0002l002l0000?;`000P0000@_000700000h51N0800004MBiW00<0
001[9FA[9F@00f/UI0<00002D0=800@0000m03`m03`00002900X00@0000300/00000000doooo000d
oooo0P0000>m>@000`000=IU0=IU0002eVD00P0000_HL4D00`000=5oLM5oL@0?dGma0/5ZJ0@00005
a7f300<0002hMHNhMHL04kQeQ`030000[6j<00000080000CX5Id00<0002?Cgj?Cgh04Xm?OP@00000
0f/0000002l00007;`003P0000N8AWL300001GD^I`030000JbETJbET00=[9F@200000e03B0040000
?@0l?@0l00000R@0:00400000`0;00000000=Oooo`00=Oooo`800003_CT000H0003FI@3FI@00002k
=@00000<f71500<0003AOg7AOg403M5oL@O1JVP4000000?4OH<0002hMHL02KQeQ`d0000GX5Id00<0
002?Cgj?Cgh03hm?OP800004JAM?2P0000==56H5000000>>B7<00028AWL02XQ6M`030000MBiWMBiW
00Ee;VL0100006/UI6/UI6/UI08000000ed@C`000503B002D0=800<0000m03`m03`01P0003Koool0
03Koool200000kdi00800003^cD000<0003HL4GHL4D02]Q`A@030000dGmadGma00cAOg4;`FYX3000
00^aGfd00`000:1FM:1FM00FX5Id00<0002?Cgj?Cgh03Xm?OP030000JAM?JAM?00]Y5dl00`0004dD
ITdDIP02CAAV1P000003STQc0000R4Ig00R8AWL300001gD^I`040000JbET000000000Ud@C`060000
D0=8D0=8D0=80000?@0l100000030@000000000003Ooool003Ooool200000kdi00030000^cD0^cD0
00:k=@000`000=Q`AMQ`A@0:f71500<0003AOg7AOg402]5oL@g1JVP00`000;5OKK5OK@0D/Em]00<0
002PEWBPEW@05Z1FM0030000SdmnSdmn00^?Cgh200003fTGC`040000CAAVCAAVCAAV1@0000>>B7<0
0`0008Q6MhQ6M`04R4Ig0P00009m<fH00`0007D^IgD^I`05MBiW0P0000AM44l010000503B503B503
B0<000000a`04`00004000020000>?ooo`00>Oooo`040000_CT0_CT0_CT00P0000>k=@0200002mQ`
A@030000dGmadGma00WAOg4=`FYX00<0002aGffaGfd05;5OK@030000X5IdX5Id01NPEW@00`0008m?
OXm?OP09Sdmn00<0001Y5dmY5dl046TGC`030000CAAV000000@00005STQc00@00028AWN8AWN8AWL2
000017dcIP030000MBiWMBiW00=e;VL3000015d@C`030000D0=8D0=8008000001C409@0001`04`00
004000020000>Oooo`00>_ooo`030000_CT0_CT000:m>@000`000;/e0;/e0002^cD000<0003HL4GH
L4D02MQ`A@030000dGmadGma00OAOg4?`FYX00<0002aGffaGfd04k5OK@030000X5IdX5Id01NPEW@0
0`0008m?OXm?OP07Sdmn0P0001AY5dl600001Hi8L`040000R4Ig000000001gdcIP030000MBiWMBiW
00800002J1QC00<0001M44mM44l00Ud@C`04D0=80000000000000S409@8000000`4000000000000j
oooo000koooo00<0002m>@2m>@000[di00030000^cD0^cD000:k=@000`000=Q`AMQ`A@09f71500<0
003AOg7AOg401]5oL@o1JVP00`000;5OKK5OK@0D/Em]00<0002PEWBPEW@05j1FM0030000SdmnSdmn
00F?Cgh00`0006TGCfTGC`0BJAM?1`0000N>B7<00`0007dcIWdcIP07OC=V0`0000=X65<0100005d@
Ced@Ced@C`<000001480<@0003409C409@8000000`4000000000000koooo000loooo00<0002m>@2m
>@000[di00030000^cD0^cD000:k=@000`000=Q`AMQ`A@09f71500<0003AOg7AOg401=5oLA31JVP0
0`000;5OKK5OK@0D/Em]00<0002PEWBPEW@05j1FM0030000SdmnSdmn00>?Cgh2000056TGC`L00006
STQc0P000003PSAS0000OC=V00Mm<fH00`0006PHDfPHD`03J1QC00H0001M44l00000001?03T00002
@P0a00<0000a02D00000100003coool003goool00`000;di0;di000200001K/e00030000f715f715
00WHL4D00`000=5oLM5oL@03dGma4<5ZJ0030000/Em]/Em]01FaGfd00`000:1FM:1FM00GX5Id00D0
002?Cgj?Cgj?Cgh0000056TGC`T00004STQc0P0000>2=6<00`0007dcIWdcIP04OC=V0`0000AX65<3
00000Tl0>@030000@P0a@P0a00L0000moooo000noooo00D0002m>@00002S500000001K/e00030000
f715f71500WHL4D00`000=5oLM5oL@02dGma4<5ZJ0030000/Em]/Em]01FaGfd00`000:1FM:1FM00G
X5Id00@0002?Cgh00000000DJAM?2@0000>>B7<200001X8dH`040000OC=VOC=VOC=V0P00009_7E<0
0`0006PHDfPHD`02000000=I0Sd0001?03T00Tl0>@T0000noooo000ooooo00D0002S502S502S5000
00001K/e00030000f715f71500WHL4D00`000=5oLL5ZJ00B`FYX00<0002aGffaGfd05;5OK@030000
X5IdX5Id01NPEW@200005FTGC`X000000hi8L`0000000008PSAS00@0001m<fH000000004KaeC0`00
00=I0Sd00`0004l0>@000003000000<W0100000000000`0003ooool0043oool200000Z<D00800004
^cD000<0003HL4GHL4D02MQ`A@<0000A`FYX00<0002aGffaGfd05K5OK@030000X5IdX5Id01:PEW@4
00000XDR?`030000JAM?JAM?011Y5dl900000i=7KP030000PSASPSAS00R2=6<200001VlMD`030000
F@8mF@8m009I0Sd400000SD06`D00011oooo0011oooo0`0000:S50000`000;/e0;/e0002^cD00P00
00WHL4D5]T@b0P0000g1JVP00`000;5OKK5OK@0E/Em]00<0002PEWBPEW@03j1FM0<00006QB8o00<0
001Y5dmY5dl03fTGC`T00002TdM^0P000003QS=M0000PSAS00J2=6<2000000=d7e00001_7E<016lM
D`800004F@8m00D0001002900280000e01/01@0004;oool004?oool200000Z<D00030000^cD0^cD0
00>k=@000`000=Q`AMQ`A@05f71500<0002fA3:fA3801kI4<P800009`FYX00<0002aGffaGfd05K5O
K@030000X5IdX5Id00^PEW@400002XDR?`030000JAM?JAM?00aY5dl900000i=7KP030000QS=MQS=M
00:6<ed00`00088dHh8dH`02PSAS0P0000Ad7e000`0006lMDflMD`02000000AO1Sd0001I0SeI0Sd2
00000T008PL00013oooo0014oooo0`000003Xa@00000^cD000Bk=@000`000=Q`AMQ`A@03f71500<0
002fA3:fA3803;I4<P800006`FYX00<0002aGffaGfd05K5OK@030000X5IdX5Id00NPEW@300003XDR
?`030000JAM?JAM?00]Y5dl900000Y=7KP800006QS=M00@00022=6<000000006M1m@00<0001_7E<0
00000el6?@<000000dT09P00000000060000AOooo`00AOooo`030000oooo000000800005^cD000D0
003HL4GHL4GHL4D000004kI4<P800002`FYX00<0002aGffaGfd05K5OK@030000X5IdX5Id00BPEW@3
00004XDR?`030000JAM?JAM?00QY5dl900000i=7KP030000QS=MQS=M00N6<ed00`0007@OD7@OD006
M1m@0P0000=O1Sd200000TT09P<000000bP01P00000000020000A_ooo`00A_ooo`8000000oooo`00
00000005^cD000D0003:F37:F37:F372Cbd05[I4<Pd0000</Em]00<0002PEW@000000`0001F58Sl0
0`0006TGCfTGC`07JAM?2P000003TdM^0000000000R6<ed2000000=g7TX00000000017@OD0800000
0f@8>`0005l6?@02000000=?02L000000000200004Ooool004Soool00`000?ooo`00000200000k/e
00800002bUPa00?2CbffA3:fA3805;I4<P030000Wc8fWc8f00ZO<SH>00006XDR?`030000JAM?JAM?
00EY5dl800000iI4I@800008QS=M00<0001g7TYg7TX00gLNBP040000M1m@0000000016@8>`080000
C`0WC`0WC`0W0000>@0@00009@00100004Woool004Woool2000000Coool00000002k=@03Xa@00P00
0003`Tl]]T@b]T@b01BfA3800`0009lb=Ylb=P0FWc8f00<000258Sn58Sl06HDR?`030000JAM?JAM?
00=Y5dl900000YI4I@800002R2mC0P0000F6<ed00`0007LNBWLNBP05Mai:00<0001T23]T23/00V@8
>`<000000dl09`00000000070000B_ooo`00Boooo`8000000oooo`000:<D0002Xa@000>M302S5000
00000P0001BfA3800`0009lb=Ylb=P0GWc8f00<000258Sn58Sl06HDR?`040000JAM?JAM?JAM?2000
00:FA6D200001XP_D`8000000hHcG@0000000006Mai:0P000005IPHe00000000I0Pk000000=B02D0
0`0003h04@0000050000C?ooo`00COooo`040000oooo000000000id<00030000P@00P@0000<0000A
]T@b00<0002O<SJO<SH05ilb=P030000QB8oQB8o01V58Sl00`0006TGC`00000800000YI4I@030000
R2mCR2mC00R8;e<400000gLNBP800004IPHe0`000003DP0U0000000000H0001>oooo001>oooo0P00
0004oooo00000000W@`01X4000<0000>]T@b00<0002O<SJO<SH05ilb=P030000QB8oQB8o01V58Sl9
00000YI4I@800009R2mC0P0000Ag6D0500000VH6=@800002D`0P2@0004ooool0053oool2000000?o
ool000000000284000<0000<]T@b00<0002O<SJO<SH05Ylb=P030000QB8oQB8o01F58Sl4000000<P
0000000000001@000003UceH0000000000800008R2mC00<0001g6D1g6D001GLI@0040000I@4/I@4/
I@4/3@00057oool005;oool6000028400080000:]T@b00<0002O<SJO<SH05ilb=P030000QB8oQB8o
01258Sl400001B0000D00002UceH0P0000>79dH400000XP_D`800006MaU00P0000=U0B`2000000AB
01P00000001000@60000Doooo`00E?ooo`L00007P@000`0000NfA3800`0009lb=Ylb=P0GWc8f00<0
00258Sn58Sl038DR?`@0000:80000`0000:G?EP00`0008LWAXLWAP07QbM61@0000Ag6D000`0006D1
;6D1;002I@4/300005Coool005Koool4000000BM3000000000000007P@000`0000BfA3800`0009lb
=Ylb=P0GWc8f00<000258Sn58Sl028DR?`@0000<80000`0000>G?EP00`0008LWAXLWAP08QbM600<0
001e3c=e3c<00WD?<`X000000dh03000000000060000E_ooo`00F?ooo`@00002W@`00`0000N10002
00000[I4<P030000Wc8fWc8f01NO<SH00`0008DR?hDR?`04QB8o100000`P000600000YLmF0800009
QbM60P0000Ie3c<200000f807`/0001Hoooo001Joooo0`0000BM300300001h4000l0000=Wc8f00<0
00258Sl000000`0000`P000400001Y@`A0L00005QbM600<0001e3c=e3c<01GD?<`030000HP0O0000
00`0001Joooo001Loooo0`000003ooooW@`0W@`000:M300300001H4000030000E@00E@0000]E000>
00003B0000@00009U3140P0000J26C8?00000UX03@<000000c`00000000000030000G?ooo`00G_oo
o`@00002W@`000<00021002100000`000003P@000000E@0001YE00000`0002000200000780001000
00bD<4@00`00088I<X8I<P08PQTb0P0000E^0Al2000000=J00d0000000002P0005koool0067oool3
00001X4000T0000DE@0000<0000P000P00000b0000@00004SA/V1P0000BD<4@200002H8I<P800002
KP4O2`00008]00050000H?ooo`00Hoooo`@00006P@000`0000>[;aL>00001UD00003000080000000
00<00002XC@h00<0002=6bJ=6bH02HdK9Q<00003HP041@00008l00050000Hoooo`00IOooo`D00006
P@00100000J[;aL200000i8A1@X00005XC@h00<0002=6bJ=6bH038dK9P030000M`8DM`8D00Qg0Q@0
0`00068016801003HP04100000<l00040000Ioooo`00JOooo`@00007P@000`0000:[;aL00`00098A
1I8A1@09TQ451@0000>Q=3P00`0008dK9XdK9P0<SA/V00<0001g0QAg0Q@027L250030000HP040000
00@00002CP001P0006[oool006coool400001h4000@0000?TQ452P0000N=6bH00`0007L257L25002
M`8D2@0000A>00060000KOooo`00Koooo`@00005P@0000@0001V001V001V000500002Y8A1@030000
N@00N@0000Ii000<00001V8000030000CP00000000P0001_oooo001coooo0`000003P@000000IP00
00QV000600000i8A1@030000N@00N@0000ai00000`00068006800003HP0020000003;P0000000000
00<0001coooo001foooo1P0000]V000H00000cd000H0001hoooo001loooo2@0000AV00000`000500
0500000<D00000@0000m000m000m00060000O_ooo`00QOoooaL00024oooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
      ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}]}], "Input",
  Editable->False,
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", " ", 
      RowBox[{
        StyleBox["Non",
          FontSize->14,
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["-",
          FontSize->14,
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox[
            RowBox[{
              StyleBox["sy",
                FontSize->14,
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox["mmetric",
                FontSize->14,
                FontTracking->"Plain",
                FontColor->RGBColor[0, 0, 1],
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}]], 
          StyleBox[" ",
            FontSize->14,
            FontTracking->"Plain",
            FontColor->RGBColor[0, 0, 1],
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox["embedded",
            FontSize->14,
            FontTracking->"Plain",
            FontColor->RGBColor[0, 0, 1],
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox[" ",
            FontSize->14,
            FontTracking->"Plain",
            FontColor->RGBColor[0, 0, 1],
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox["trinoid",
            FontSize->14,
            FontTracking->"Plain",
            FontColor->RGBColor[0, 0, 1],
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}]}]}]], "Input",
  Editable->False,
  CellDingbat->None],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.39;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    StyleBox[\(\(\[CapitalDelta]1 = 0.43;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(\[CapitalDelta]8 = 0.45;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(kembed = 0;\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62692 .64159 m .65755 .72628 L .62438 .73961 L p .7 .578 .715 r
F P
0 g
s
.62438 .73961 m .59323 .65189 L .62692 .64159 L p .7 .578 .715 r
F P
0 g
s
.59323 .65189 m .62438 .73961 L .59069 .7538 L p .734 .595 .702 r
F P
0 g
s
.66401 .81942 m .62438 .73961 L .65755 .72628 L p .664 .486 .633 r
F P
0 g
s
.62438 .73961 m .66401 .81942 L .63959 .83232 L p .695 .498 .617 r
F P
0 g
s
.63959 .83232 m .59069 .7538 L .62438 .73961 L p .695 .498 .617 r
F P
0 g
s
.65882 .63219 m .689 .71422 L .65755 .72628 L p .665 .559 .725 r
F P
0 g
s
.65755 .72628 m .62692 .64159 L .65882 .63219 L p .665 .559 .725 r
F P
0 g
s
.65755 .72628 m .68851 .80716 L .66401 .81942 L p .664 .486 .633 r
F P
0 g
s
.68851 .80716 m .65755 .72628 L .689 .71422 L p .631 .469 .644 r
F P
0 g
s
.60649 .58101 m .62692 .64159 L .59323 .65189 L p .717 .649 .781 r
F P
0 g
s
.59323 .65189 m .57821 .58784 L .60649 .58101 L p .717 .649 .781 r
F P
0 g
s
.57821 .58784 m .59323 .65189 L .55897 .66278 L p .752 .671 .771 r
F P
0 g
s
.59069 .7538 m .55897 .66278 L .59323 .65189 L p .734 .595 .702 r
F P
0 g
s
.63352 .57467 m .65882 .63219 L .62692 .64159 L p .682 .63 .791 r
F P
0 g
s
.62692 .64159 m .60649 .58101 L .63352 .57467 L p .682 .63 .791 r
F P
0 g
s
.55897 .66278 m .59069 .7538 L .55799 .7683 L p .769 .613 .686 r
F P
0 g
s
.59069 .7538 m .63959 .83232 L .6164 .84532 L p .725 .506 .594 r
F P
0 g
s
.6164 .84532 m .55799 .7683 L .59069 .7538 L p .725 .506 .594 r
F P
0 g
s
.55897 .66278 m .54978 .59489 L .57821 .58784 L p .752 .671 .771 r
F P
0 g
s
.54978 .59489 m .55897 .66278 L .52567 .67379 L p .79 .697 .762 r
F P
0 g
s
.55799 .7683 m .52567 .67379 L .55897 .66278 L p .769 .613 .686 r
F P
0 g
s
.688 .62394 m .71781 .70376 L .689 .71422 L p .626 .538 .735 r
F P
0 g
s
.689 .71422 m .65882 .63219 L .688 .62394 L p .626 .538 .735 r
F P
0 g
s
.71215 .79596 m .689 .71422 L .71781 .70376 L p .593 .446 .65 r
F P
0 g
s
.689 .71422 m .71215 .79596 L .68851 .80716 L p .631 .469 .644 r
F P
0 g
s
.3381 .5171 m .27463 .53579 L .26839 .50216 L p .663 .526 .687 r
F P
0 g
s
.26839 .50216 m .33032 .48691 L .3381 .5171 L p .663 .526 .687 r
F P
0 g
s
.33032 .48691 m .26839 .50216 L .26182 .46939 L p .672 .563 .723 r
F P
0 g
s
.19437 .51311 m .26839 .50216 L .27463 .53579 L p .726 .569 .676 r
F P
0 g
s
.26839 .50216 m .19437 .51311 L .19058 .48207 L p .732 .602 .712 r
F P
0 g
s
.19058 .48207 m .26182 .46939 L .26839 .50216 L p .732 .602 .712 r
F P
0 g
s
.65843 .569 m .688 .62394 L .65882 .63219 L p .642 .61 .802 r
F P
0 g
s
.65882 .63219 m .63352 .57467 L .65843 .569 L p .642 .61 .802 r
F P
0 g
s
.32237 .4573 m .26182 .46939 L .25523 .43866 L p .678 .596 .757 r
F P
0 g
s
.26182 .46939 m .32237 .4573 L .33032 .48691 L p .672 .563 .723 r
F P
0 g
s
.26182 .46939 m .19058 .48207 L .18646 .45285 L p .737 .635 .745 r
F P
0 g
s
.18646 .45285 m .25523 .43866 L .26182 .46939 L p .737 .635 .745 r
F P
0 g
s
.34534 .5465 m .28024 .56882 L .27463 .53579 L p .648 .482 .645 r
F P
0 g
s
.27463 .53579 m .3381 .5171 L .34534 .5465 L p .648 .482 .645 r
F P
0 g
s
.19765 .54485 m .27463 .53579 L .28024 .56882 L p .719 .53 .634 r
F P
0 g
s
.27463 .53579 m .19765 .54485 L .19437 .51311 L p .726 .569 .676 r
F P
0 g
s
.52567 .67379 m .55799 .7683 L .52805 .78238 L p .809 .633 .664 r
F P
0 g
s
.55799 .7683 m .6164 .84532 L .59566 .85779 L p .755 .508 .559 r
F P
0 g
s
.59566 .85779 m .52805 .78238 L .55799 .7683 L p .755 .508 .559 r
F P
0 g
s
.25523 .43866 m .31457 .42935 L .32237 .4573 L p .678 .596 .757 r
F P
0 g
s
.31457 .42935 m .25523 .43866 L .24882 .41083 L p .68 .629 .791 r
F P
0 g
s
.25523 .43866 m .18646 .45285 L .18218 .42634 L p .741 .668 .779 r
F P
0 g
s
.18218 .42634 m .24882 .41083 L .25523 .43866 L p .741 .668 .779 r
F P
0 g
s
.12959 .51577 m .19437 .51311 L .19765 .54485 L p .795 .618 .662 r
F P
0 g
s
.19437 .51311 m .12959 .51577 L .12826 .49194 L p .797 .648 .697 r
F P
0 g
s
.12826 .49194 m .19058 .48207 L .19437 .51311 L p .797 .648 .697 r
F P
0 g
s
.52567 .67379 m .52246 .60188 L .54978 .59489 L p .79 .697 .762 r
F P
0 g
s
.52246 .60188 m .52567 .67379 L .49513 .68439 L p .832 .729 .751 r
F P
0 g
s
.52805 .78238 m .49513 .68439 L .52567 .67379 L p .809 .633 .664 r
F P
0 g
s
.19058 .48207 m .12826 .49194 L .12648 .46921 L p .801 .678 .729 r
F P
0 g
s
.12648 .46921 m .18646 .45285 L .19058 .48207 L p .801 .678 .729 r
F P
0 g
s
.38085 .49694 m .3381 .5171 L .33032 .48691 L p .603 .489 .696 r
F P
0 g
s
.33032 .48691 m .37316 .47216 L .38085 .49694 L p .603 .489 .696 r
F P
0 g
s
.37316 .47216 m .33032 .48691 L .32237 .4573 L p .616 .528 .732 r
F P
0 g
s
.71373 .61703 m .74327 .69508 L .71781 .70376 L p .58 .513 .744 r
F P
0 g
s
.71781 .70376 m .688 .62394 L .71373 .61703 L p .58 .513 .744 r
F P
0 g
s
.73412 .78617 m .71781 .70376 L .74327 .69508 L p .547 .415 .652 r
F P
0 g
s
.71781 .70376 m .73412 .78617 L .71215 .79596 L p .593 .446 .65 r
F P
0 g
s
.36535 .44758 m .32237 .4573 L .31457 .42935 L p .623 .562 .766 r
F P
0 g
s
.32237 .4573 m .36535 .44758 L .37316 .47216 L p .616 .528 .732 r
F P
0 g
s
.28024 .56882 m .2002 .57589 L .19765 .54485 L p .719 .53 .634 r
F P
0 g
s
.13037 .53976 m .19765 .54485 L .2002 .57589 L p .794 .586 .621 r
F P
0 g
s
.19765 .54485 m .13037 .53976 L .12959 .51577 L p .795 .618 .662 r
F P
0 g
s
.68051 .56416 m .71373 .61703 L .688 .62394 L p .596 .588 .814 r
F P
0 g
s
.688 .62394 m .65843 .569 L .68051 .56416 L p .596 .588 .814 r
F P
0 g
s
.35159 .57353 m .28483 .59943 L .28024 .56882 L p .626 .425 .591 r
F P
0 g
s
.28024 .56882 m .34534 .5465 L .35159 .57353 L p .626 .425 .591 r
F P
0 g
s
.2002 .57589 m .28024 .56882 L .28483 .59943 L p .708 .483 .58 r
F P
0 g
s
.38804 .52077 m .34534 .5465 L .3381 .5171 L p .581 .44 .654 r
F P
0 g
s
.3381 .5171 m .38085 .49694 L .38804 .52077 L p .581 .44 .654 r
F P
0 g
s
.18646 .45285 m .12648 .46921 L .12435 .44833 L p .806 .711 .76 r
F P
0 g
s
.12435 .44833 m .18218 .42634 L .18646 .45285 L p .806 .711 .76 r
F P
0 g
s
.59532 .54456 m .60649 .58101 L .57821 .58784 L p .722 .705 .834 r
F P
0 g
s
.57821 .58784 m .5735 .54902 L .59532 .54456 L p .722 .705 .834 r
F P
0 g
s
.5735 .54902 m .57821 .58784 L .54978 .59489 L p .757 .73 .828 r
F P
0 g
s
.61642 .54034 m .63352 .57467 L .60649 .58101 L p .686 .684 .843 r
F P
0 g
s
.60649 .58101 m .59532 .54456 L .61642 .54034 L p .686 .684 .843 r
F P
0 g
s
.31457 .42935 m .35771 .42413 L .36535 .44758 L p .623 .562 .766 r
F P
0 g
s
.35771 .42413 m .31457 .42935 L .30719 .40391 L p .624 .595 .8 r
F P
0 g
s
.24882 .41083 m .30719 .40391 L .31457 .42935 L p .68 .629 .791 r
F P
0 g
s
.30719 .40391 m .24882 .41083 L .2428 .38656 L p .679 .663 .828 r
F P
0 g
s
.24882 .41083 m .18218 .42634 L .1779 .40316 L p .744 .704 .813 r
F P
0 g
s
.1779 .40316 m .2428 .38656 L .24882 .41083 L p .744 .704 .813 r
F P
0 g
s
.54978 .59489 m .55183 .55353 L .5735 .54902 L p .757 .73 .828 r
F P
0 g
s
.55183 .55353 m .54978 .59489 L .52246 .60188 L p .794 .761 .823 r
F P
0 g
s
.28483 .59943 m .20181 .60453 L .2002 .57589 L p .708 .483 .58 r
F P
0 g
s
.13054 .56281 m .2002 .57589 L .20181 .60453 L p .794 .549 .568 r
F P
0 g
s
.2002 .57589 m .13054 .56281 L .13037 .53976 L p .794 .586 .621 r
F P
0 g
s
.63605 .5365 m .65843 .569 L .63352 .57467 L p .647 .665 .854 r
F P
0 g
s
.63352 .57467 m .61642 .54034 L .63605 .5365 L p .647 .665 .854 r
F P
0 g
s
.69416 .86198 m .66401 .81942 L .68851 .80716 L p .596 .351 .516 r
F P
0 g
s
.66401 .81942 m .69416 .86198 L .68102 .86981 L p .62 .356 .496 r
F P
0 g
s
.68102 .86981 m .63959 .83232 L .66401 .81942 L p .62 .356 .496 r
F P
0 g
s
.68851 .80716 m .70768 .85439 L .69416 .86198 L p .596 .351 .516 r
F P
0 g
s
.70768 .85439 m .68851 .80716 L .71215 .79596 L p .566 .336 .526 r
F P
0 g
s
.49513 .68439 m .52805 .78238 L .50287 .79521 L p .857 .655 .629 r
F P
0 g
s
.52805 .78238 m .59566 .85779 L .57867 .86902 L p .787 .501 .503 r
F P
0 g
s
.57867 .86902 m .50287 .79521 L .52805 .78238 L p .787 .501 .503 r
F P
0 g
s
.39432 .54238 m .35159 .57353 L .34534 .5465 L p .546 .375 .6 r
F P
0 g
s
.34534 .5465 m .38804 .52077 L .39432 .54238 L p .546 .375 .6 r
F P
0 g
s
.18218 .42634 m .12435 .44833 L .12196 .42992 L p .813 .747 .791 r
F P
0 g
s
.12196 .42992 m .1779 .40316 L .18218 .42634 L p .813 .747 .791 r
F P
0 g
s
.49513 .68439 m .49773 .60845 L .52246 .60188 L p .832 .729 .751 r
F P
0 g
s
.49773 .60845 m .49513 .68439 L .46935 .69394 L p .884 .772 .733 r
F P
0 g
s
.50287 .79521 m .46935 .69394 L .49513 .68439 L p .857 .655 .629 r
F P
0 g
s
.7355 .61156 m .76487 .68833 L .74327 .69508 L p .52 .478 .751 r
F P
0 g
s
.74327 .69508 m .71373 .61703 L .7355 .61156 L p .52 .478 .751 r
F P
0 g
s
.75378 .77804 m .74327 .69508 L .76487 .68833 L p .485 .371 .648 r
F P
0 g
s
.74327 .69508 m .75378 .77804 L .73412 .78617 L p .547 .415 .652 r
F P
0 g
s
.30719 .40391 m .35052 .4026 L .35771 .42413 L p .624 .595 .8 r
F P
0 g
s
.35052 .4026 m .30719 .40391 L .30042 .38161 L p .618 .626 .836 r
F P
0 g
s
.2428 .38656 m .30042 .38161 L .30719 .40391 L p .679 .663 .828 r
F P
0 g
s
.63959 .83232 m .68102 .86981 L .66888 .87751 L p .639 .351 .465 r
F P
0 g
s
.66888 .87751 m .6164 .84532 L .63959 .83232 L p .639 .351 .465 r
F P
0 g
s
.69922 .56024 m .7355 .61156 L .71373 .61703 L p .535 .562 .829 r
F P
0 g
s
.71373 .61703 m .68051 .56416 L .69922 .56024 L p .535 .562 .829 r
F P
0 g
s
.72102 .84733 m .71215 .79596 L .73412 .78617 L p .529 .312 .528 r
F P
0 g
s
.71215 .79596 m .72102 .84733 L .70768 .85439 L p .566 .336 .526 r
F P
0 g
s
.40782 .47958 m .38085 .49694 L .37316 .47216 L p .552 .458 .702 r
F P
0 g
s
.37316 .47216 m .40102 .45991 L .40782 .47958 L p .552 .458 .702 r
F P
0 g
s
.40102 .45991 m .37316 .47216 L .36535 .44758 L p .568 .5 .738 r
F P
0 g
s
.39408 .44016 m .36535 .44758 L .35771 .42413 L p .576 .535 .772 r
F P
0 g
s
.36535 .44758 m .39408 .44016 L .40102 .45991 L p .568 .5 .738 r
F P
0 g
s
.35643 .59645 m .28803 .62562 L .28483 .59943 L p .586 .341 .512 r
F P
0 g
s
.28483 .59943 m .35159 .57353 L .35643 .59645 L p .586 .341 .512 r
F P
0 g
s
.20181 .60453 m .28483 .59943 L .28803 .62562 L p .69 .415 .502 r
F P
0 g
s
.52246 .60188 m .53131 .5579 L .55183 .55353 L p .794 .761 .823 r
F P
0 g
s
.53131 .5579 m .52246 .60188 L .49773 .60845 L p .835 .801 .819 r
F P
0 g
s
.65356 .53316 m .68051 .56416 L .65843 .569 L p .6 .646 .868 r
F P
0 g
s
.65843 .569 m .63605 .5365 L .65356 .53316 L p .6 .646 .868 r
F P
0 g
s
.62782 .2727 m .64014 .25238 L .662 .26527 L p .696 .558 .694 r
F P
0 g
s
.60639 .25922 m .61872 .23903 L .64014 .25238 L p .727 .599 .713 r
F P
0 g
s
.64014 .25238 m .62782 .2727 L .60639 .25922 L p .727 .599 .713 r
F P
0 g
s
.64014 .25238 m .65293 .23121 L .67422 .24369 L p .684 .565 .715 r
F P
0 g
s
.67422 .24369 m .662 .26527 L .64014 .25238 L p .684 .565 .715 r
F P
0 g
s
.65293 .23121 m .64014 .25238 L .61872 .23903 L p .714 .605 .733 r
F P
0 g
s
.61637 .29154 m .62782 .2727 L .64972 .28565 L p .706 .551 .675 r
F P
0 g
s
.59532 .2782 m .60639 .25922 L .62782 .2727 L p .738 .593 .695 r
F P
0 g
s
.62782 .2727 m .61637 .29154 L .59532 .2782 L p .738 .593 .695 r
F P
0 g
s
.662 .26527 m .64972 .28565 L .62782 .2727 L p .696 .558 .694 r
F P
0 g
s
.41416 .49827 m .38804 .52077 L .38085 .49694 L p .524 .406 .661 r
F P
0 g
s
.38085 .49694 m .40782 .47958 L .41416 .49827 L p .524 .406 .661 r
F P
0 g
s
.64972 .28565 m .662 .26527 L .68335 .27713 L p .662 .514 .673 r
F P
0 g
s
.662 .26527 m .67422 .24369 L .69503 .25521 L p .65 .522 .694 r
F P
0 g
s
.69503 .25521 m .68335 .27713 L .662 .26527 L p .65 .522 .694 r
F P
0 g
s
.30042 .38161 m .2428 .38656 L .2373 .3663 L p .672 .701 .869 r
F P
0 g
s
.2428 .38656 m .1779 .40316 L .17374 .38381 L p .745 .746 .852 r
F P
0 g
s
.17374 .38381 m .2373 .3663 L .2428 .38656 L p .745 .746 .852 r
F P
0 g
s
.61872 .23903 m .63206 .21831 L .65293 .23121 L p .714 .605 .733 r
F P
0 g
s
.65293 .23121 m .66565 .2101 L .68577 .22181 L p .67 .572 .736 r
F P
0 g
s
.68577 .22181 m .67422 .24369 L .65293 .23121 L p .67 .572 .736 r
F P
0 g
s
.66565 .2101 m .65293 .23121 L .63206 .21831 L p .7 .611 .754 r
F P
0 g
s
.64972 .28565 m .63791 .3043 L .61637 .29154 L p .706 .551 .675 r
F P
0 g
s
.63791 .3043 m .64972 .28565 L .6711 .29752 L p .672 .506 .652 r
F P
0 g
s
.68335 .27713 m .6711 .29752 L .64972 .28565 L p .662 .514 .673 r
F P
0 g
s
.58636 .24586 m .59866 .22581 L .61872 .23903 L p .757 .64 .731 r
F P
0 g
s
.61872 .23903 m .60639 .25922 L .58636 .24586 L p .757 .64 .731 r
F P
0 g
s
.63206 .21831 m .61872 .23903 L .59866 .22581 L p .744 .646 .751 r
F P
0 g
s
.35771 .42413 m .38728 .42113 L .39408 .44016 L p .576 .535 .772 r
F P
0 g
s
.38728 .42113 m .35771 .42413 L .35052 .4026 L p .577 .566 .805 r
F P
0 g
s
.57571 .26493 m .58636 .24586 L .60639 .25922 L p .769 .634 .712 r
F P
0 g
s
.60639 .25922 m .59532 .2782 L .57571 .26493 L p .769 .634 .712 r
F P
0 g
s
.60594 .30865 m .61637 .29154 L .63791 .3043 L p .715 .544 .657 r
F P
0 g
s
.58553 .29561 m .59532 .2782 L .61637 .29154 L p .747 .587 .677 r
F P
0 g
s
.61637 .29154 m .60594 .30865 L .58553 .29561 L p .747 .587 .677 r
F P
0 g
s
.67422 .24369 m .68577 .22181 L .70543 .23262 L p .636 .53 .717 r
F P
0 g
s
.70543 .23262 m .69503 .25521 L .67422 .24369 L p .636 .53 .717 r
F P
0 g
s
.59866 .22581 m .61248 .20553 L .63206 .21831 L p .744 .646 .751 r
F P
0 g
s
.64592 .198 m .63206 .21831 L .61248 .20553 L p .728 .651 .772 r
F P
0 g
s
.63206 .21831 m .64592 .198 L .66565 .2101 L p .7 .611 .754 r
F P
0 g
s
.63791 .3043 m .62687 .32101 L .60594 .30865 L p .715 .544 .657 r
F P
0 g
s
.62687 .32101 m .63791 .3043 L .65891 .31589 L p .68 .498 .633 r
F P
0 g
s
.6711 .29752 m .65891 .31589 L .63791 .3043 L p .672 .506 .652 r
F P
0 g
s
.6164 .84532 m .66888 .87751 L .65835 .88475 L p .653 .332 .417 r
F P
0 g
s
.65835 .88475 m .59566 .85779 L .6164 .84532 L p .653 .332 .417 r
F P
0 g
s
.73366 .84105 m .73412 .78617 L .75378 .77804 L p .483 .275 .521 r
F P
0 g
s
.73412 .78617 m .73366 .84105 L .72102 .84733 L p .529 .312 .528 r
F P
0 g
s
.08981 .51204 m .12959 .51577 L .13037 .53976 L p .87 .678 .64 r
F P
0 g
s
.12959 .51577 m .08981 .51204 L .08959 .4973 L p .869 .703 .673 r
F P
0 g
s
.08959 .4973 m .12826 .49194 L .12959 .51577 L p .869 .703 .673 r
F P
0 g
s
.5666 .28256 m .57571 .26493 L .59532 .2782 L p .778 .629 .695 r
F P
0 g
s
.59532 .2782 m .58553 .29561 L .5666 .28256 L p .778 .629 .695 r
F P
0 g
s
.12826 .49194 m .08959 .4973 L .08902 .48298 L p .872 .73 .702 r
F P
0 g
s
.08902 .48298 m .12648 .46921 L .12826 .49194 L p .872 .73 .702 r
F P
0 g
s
.28803 .62562 m .20231 .62893 L .20181 .60453 L p .69 .415 .502 r
F P
0 g
s
.13003 .58371 m .20181 .60453 L .20231 .62893 L p .794 .5 .492 r
F P
0 g
s
.20181 .60453 m .13003 .58371 L .13054 .56281 L p .794 .549 .568 r
F P
0 g
s
.66565 .2101 m .67763 .19016 L .69599 .20076 L p .653 .578 .758 r
F P
0 g
s
.69599 .20076 m .68577 .22181 L .66565 .2101 L p .653 .578 .758 r
F P
0 g
s
.67763 .19016 m .66565 .2101 L .64592 .198 L p .683 .617 .776 r
F P
0 g
s
.59655 .324 m .60594 .30865 L .62687 .32101 L p .722 .538 .641 r
F P
0 g
s
.57691 .31133 m .58553 .29561 L .60594 .30865 L p .754 .581 .661 r
F P
0 g
s
.60594 .30865 m .59655 .324 L .57691 .31133 L p .754 .581 .661 r
F P
0 g
s
.1779 .40316 m .12196 .42992 L .11939 .41447 L p .821 .791 .824 r
F P
0 g
s
.11939 .41447 m .17374 .38381 L .1779 .40316 L p .821 .791 .824 r
F P
0 g
s
.3993 .56045 m .35643 .59645 L .35159 .57353 L p .485 .276 .521 r
F P
0 g
s
.35159 .57353 m .39432 .54238 L .3993 .56045 L p .485 .276 .521 r
F P
0 g
s
.6711 .29752 m .68335 .27713 L .70323 .28749 L p .621 .462 .646 r
F P
0 g
s
.68335 .27713 m .69503 .25521 L .71443 .26529 L p .608 .472 .67 r
F P
0 g
s
.71443 .26529 m .70323 .28749 L .68335 .27713 L p .608 .472 .67 r
F P
0 g
s
.65891 .31589 m .6711 .29752 L .69096 .30783 L p .631 .453 .623 r
F P
0 g
s
.70323 .28749 m .69096 .30783 L .6711 .29752 L p .621 .462 .646 r
F P
0 g
s
.68577 .22181 m .69599 .20076 L .71392 .21054 L p .619 .537 .74 r
F P
0 g
s
.71392 .21054 m .70543 .23262 L .68577 .22181 L p .619 .537 .74 r
F P
0 g
s
.56854 .23323 m .58077 .21331 L .59866 .22581 L p .789 .684 .749 r
F P
0 g
s
.59866 .22581 m .58636 .24586 L .56854 .23323 L p .789 .684 .749 r
F P
0 g
s
.61248 .20553 m .59866 .22581 L .58077 .21331 L p .774 .689 .77 r
F P
0 g
s
.30042 .38161 m .344 .3836 L .35052 .4026 L p .618 .626 .836 r
F P
0 g
s
.344 .3836 m .30042 .38161 L .29445 .36294 L p .603 .658 .877 r
F P
0 g
s
.2373 .3663 m .29445 .36294 L .30042 .38161 L p .672 .701 .869 r
F P
0 g
s
.08966 .52659 m .13037 .53976 L .13054 .56281 L p .874 .653 .6 r
F P
0 g
s
.13037 .53976 m .08966 .52659 L .08981 .51204 L p .87 .678 .64 r
F P
0 g
s
.62687 .32101 m .61677 .33584 L .59655 .324 L p .722 .538 .641 r
F P
0 g
s
.61677 .33584 m .62687 .32101 L .64726 .33212 L p .687 .49 .615 r
F P
0 g
s
.65891 .31589 m .64726 .33212 L .62687 .32101 L p .68 .498 .633 r
F P
0 g
s
.61248 .20553 m .6274 .18602 L .64592 .198 L p .728 .651 .772 r
F P
0 g
s
.65963 .1792 m .64592 .198 L .6274 .18602 L p .71 .656 .794 r
F P
0 g
s
.64592 .198 m .65963 .1792 L .67763 .19016 L p .683 .617 .776 r
F P
0 g
s
.55833 .25237 m .56854 .23323 L .58636 .24586 L p .801 .679 .729 r
F P
0 g
s
.58636 .24586 m .57571 .26493 L .55833 .25237 L p .801 .679 .729 r
F P
0 g
s
.12648 .46921 m .08902 .48298 L .08814 .46964 L p .877 .759 .729 r
F P
0 g
s
.08814 .46964 m .12435 .44833 L .12648 .46921 L p .877 .759 .729 r
F P
0 g
s
.55882 .29856 m .5666 .28256 L .58553 .29561 L p .787 .624 .679 r
F P
0 g
s
.58553 .29561 m .57691 .31133 L .55882 .29856 L p .787 .624 .679 r
F P
0 g
s
.69503 .25521 m .70543 .23262 L .72379 .24209 L p .594 .481 .695 r
F P
0 g
s
.72379 .24209 m .71443 .26529 L .69503 .25521 L p .594 .481 .695 r
F P
0 g
s
.41969 .51501 m .39432 .54238 L .38804 .52077 L p .478 .334 .607 r
F P
0 g
s
.38804 .52077 m .41416 .49827 L .41969 .51501 L p .478 .334 .607 r
F P
0 g
s
.58077 .21331 m .59499 .19344 L .61248 .20553 L p .774 .689 .77 r
F P
0 g
s
.6274 .18602 m .61248 .20553 L .59499 .19344 L p .756 .694 .792 r
F P
0 g
s
.35052 .4026 m .38088 .40351 L .38728 .42113 L p .577 .566 .805 r
F P
0 g
s
.38088 .40351 m .35052 .4026 L .344 .3836 L p .568 .595 .841 r
F P
0 g
s
.64726 .33212 m .65891 .31589 L .67839 .32589 L p .639 .443 .602 r
F P
0 g
s
.69096 .30783 m .67839 .32589 L .65891 .31589 L p .631 .453 .623 r
F P
0 g
s
.58944 .5227 m .59532 .54456 L .5735 .54902 L p .72 .743 .87 r
F P
0 g
s
.60554 .5198 m .61642 .54034 L .59532 .54456 L p .684 .721 .877 r
F P
0 g
s
.59532 .54456 m .58944 .5227 L .60554 .5198 L p .684 .721 .877 r
F P
0 g
s
.5735 .54902 m .57293 .52571 L .58944 .5227 L p .72 .743 .87 r
F P
0 g
s
.57293 .52571 m .5735 .54902 L .55183 .55353 L p .754 .769 .865 r
F P
0 g
s
.54992 .27021 m .55833 .25237 L .57571 .26493 L p .812 .673 .71 r
F P
0 g
s
.57571 .26493 m .5666 .28256 L .54992 .27021 L p .812 .673 .71 r
F P
0 g
s
.66846 .5304 m .69922 .56024 L .68051 .56416 L p .538 .625 .886 r
F P
0 g
s
.68051 .56416 m .65356 .53316 L .66846 .5304 L p .538 .625 .886 r
F P
0 g
s
.58813 .33775 m .59655 .324 L .61677 .33584 L p .727 .531 .626 r
F P
0 g
s
.56926 .32544 m .57691 .31133 L .59655 .324 L p .76 .576 .647 r
F P
0 g
s
.59655 .324 m .58813 .33775 L .56926 .32544 L p .76 .576 .647 r
F P
0 g
s
.75288 .60762 m .7822 .6836 L .76487 .68833 L p .432 .427 .753 r
F P
0 g
s
.76487 .68833 m .7355 .61156 L .75288 .60762 L p .432 .427 .753 r
F P
0 g
s
.77061 .77173 m .76487 .68833 L .7822 .6836 L p .397 .304 .632 r
F P
0 g
s
.76487 .68833 m .77061 .77173 L .75378 .77804 L p .485 .371 .648 r
F P
0 g
s
.49773 .60845 m .51301 .5619 L .53131 .5579 L p .835 .801 .819 r
F P
0 g
s
.51301 .5619 m .49773 .60845 L .47712 .6142 L p .881 .855 .813 r
F P
0 g
s
.46935 .69394 m .47712 .6142 L .49773 .60845 L p .884 .772 .733 r
F P
0 g
s
.70543 .23262 m .71392 .21054 L .73068 .2191 L p .577 .491 .721 r
F P
0 g
s
.73068 .2191 m .72379 .24209 L .70543 .23262 L p .577 .491 .721 r
F P
0 g
s
.61677 .33584 m .60766 .34903 L .58813 .33775 L p .727 .531 .626 r
F P
0 g
s
.60766 .34903 m .61677 .33584 L .63646 .34631 L p .692 .482 .599 r
F P
0 g
s
.64726 .33212 m .63646 .34631 L .61677 .33584 L p .687 .49 .615 r
F P
0 g
s
.55206 .31293 m .55882 .29856 L .57691 .31133 L p .793 .619 .665 r
F P
0 g
s
.57691 .31133 m .56926 .32544 L .55206 .31293 L p .793 .619 .665 r
F P
0 g
s
.71414 .55733 m .75288 .60762 L .7355 .61156 L p .448 .524 .843 r
F P
0 g
s
.7355 .61156 m .69922 .56024 L .71414 .55733 L p .448 .524 .843 r
F P
0 g
s
.62064 .51712 m .63605 .5365 L .61642 .54034 L p .645 .702 .888 r
F P
0 g
s
.61642 .54034 m .60554 .5198 L .62064 .51712 L p .645 .702 .888 r
F P
0 g
s
.67763 .19016 m .68826 .17243 L .70437 .18166 L p .634 .585 .781 r
F P
0 g
s
.70437 .18166 m .69599 .20076 L .67763 .19016 L p .634 .585 .781 r
F P
0 g
s
.68826 .17243 m .67763 .19016 L .65963 .1792 L p .662 .622 .799 r
F P
0 g
s
.63646 .34631 m .64726 .33212 L .66613 .34158 L p .645 .434 .582 r
F P
0 g
s
.67839 .32589 m .66613 .34158 L .64726 .33212 L p .639 .443 .602 r
F P
0 g
s
.59499 .19344 m .61082 .17465 L .6274 .18602 L p .756 .694 .792 r
F P
0 g
s
.64271 .16832 m .6274 .18602 L .61082 .17465 L p .735 .698 .816 r
F P
0 g
s
.6274 .18602 m .64271 .16832 L .65963 .1792 L p .71 .656 .794 r
F P
0 g
s
.55183 .55353 m .55672 .52871 L .57293 .52571 L p .754 .769 .865 r
F P
0 g
s
.55672 .52871 m .55183 .55353 L .53131 .5579 L p .789 .803 .864 r
F P
0 g
s
.543 .28648 m .54992 .27021 L .5666 .28256 L p .821 .668 .693 r
F P
0 g
s
.5666 .28256 m .55882 .29856 L .543 .28648 L p .821 .668 .693 r
F P
0 g
s
.46935 .69394 m .50287 .79521 L .48441 .8059 L p .918 .679 .561 r
F P
0 g
s
.50287 .79521 m .57867 .86902 L .56665 .87831 L p .819 .473 .402 r
F P
0 g
s
.56665 .87831 m .48441 .8059 L .50287 .79521 L p .819 .473 .402 r
F P
0 g
s
.69599 .20076 m .70437 .18166 L .72012 .19018 L p .6 .545 .765 r
F P
0 g
s
.72012 .19018 m .71392 .21054 L .69599 .20076 L p .6 .545 .765 r
F P
0 g
s
.4137 .43439 m .39408 .44016 L .38728 .42113 L p .547 .517 .774 r
F P
0 g
s
.41961 .45019 m .40102 .45991 L .39408 .44016 L p .537 .481 .741 r
F P
0 g
s
.39408 .44016 m .4137 .43439 L .41961 .45019 L p .537 .481 .741 r
F P
0 g
s
.42536 .46578 m .40782 .47958 L .40102 .45991 L p .517 .438 .705 r
F P
0 g
s
.40102 .45991 m .41961 .45019 L .42536 .46578 L p .517 .438 .705 r
F P
0 g
s
.12435 .44833 m .08814 .46964 L .087 .45773 L p .886 .794 .754 r
F P
0 g
s
.087 .45773 m .12196 .42992 L .12435 .44833 L p .886 .794 .754 r
F P
0 g
s
.67245 .16286 m .65963 .1792 L .64271 .16832 L p .688 .66 .817 r
F P
0 g
s
.65963 .1792 m .67245 .16286 L .68826 .17243 L p .662 .622 .799 r
F P
0 g
s
.74514 .83577 m .75378 .77804 L .77061 .77173 L p .42 .221 .501 r
F P
0 g
s
.75378 .77804 m .74514 .83577 L .73366 .84105 L p .483 .275 .521 r
F P
0 g
s
.08913 .54029 m .13054 .56281 L .13003 .58371 L p .881 .627 .549 r
F P
0 g
s
.13054 .56281 m .08913 .54029 L .08966 .52659 L p .874 .653 .6 r
F P
0 g
s
.47712 .6142 m .46935 .69394 L .45033 .70176 L p .948 .831 .695 r
F P
0 g
s
.48441 .8059 m .45033 .70176 L .46935 .69394 L p .918 .679 .561 r
F P
0 g
s
.69096 .30783 m .70323 .28749 L .72077 .29594 L p .567 .396 .61 r
F P
0 g
s
.70323 .28749 m .71443 .26529 L .73159 .27352 L p .554 .408 .638 r
F P
0 g
s
.73159 .27352 m .72077 .29594 L .70323 .28749 L p .554 .408 .638 r
F P
0 g
s
.58051 .35015 m .58813 .33775 L .60766 .34903 L p .731 .525 .613 r
F P
0 g
s
.56232 .3381 m .56926 .32544 L .58813 .33775 L p .765 .571 .635 r
F P
0 g
s
.58813 .33775 m .58051 .35015 L .56232 .3381 L p .765 .571 .635 r
F P
0 g
s
.67839 .32589 m .69096 .30783 L .70844 .31622 L p .577 .384 .583 r
F P
0 g
s
.72077 .29594 m .70844 .31622 L .69096 .30783 L p .567 .396 .61 r
F P
0 g
s
.59566 .85779 m .65835 .88475 L .65001 .89113 L p .657 .293 .343 r
F P
0 g
s
.65001 .89113 m .57867 .86902 L .59566 .85779 L p .657 .293 .343 r
F P
0 g
s
.55358 .22189 m .56571 .20206 L .58077 .21331 L p .824 .735 .767 r
F P
0 g
s
.58077 .21331 m .56854 .23323 L .55358 .22189 L p .824 .735 .767 r
F P
0 g
s
.59499 .19344 m .58077 .21331 L .56571 .20206 L p .806 .74 .791 r
F P
0 g
s
.71443 .26529 m .72379 .24209 L .74004 .24982 L p .539 .421 .666 r
F P
0 g
s
.74004 .24982 m .73159 .27352 L .71443 .26529 L p .539 .421 .666 r
F P
0 g
s
.29445 .36294 m .2373 .3663 L .23245 .35039 L p .653 .744 .917 r
F P
0 g
s
.2373 .3663 m .17374 .38381 L .16981 .36864 L p .741 .797 .897 r
F P
0 g
s
.16981 .36864 m .23245 .35039 L .2373 .3663 L p .741 .797 .897 r
F P
0 g
s
.54379 .24113 m .55358 .22189 L .56854 .23323 L p .838 .729 .744 r
F P
0 g
s
.56854 .23323 m .55833 .25237 L .54379 .24113 L p .838 .729 .744 r
F P
0 g
s
.63646 .34631 m .62665 .35875 L .60766 .34903 L p .692 .482 .599 r
F P
0 g
s
.62665 .35875 m .63646 .34631 L .65458 .35509 L p .65 .425 .564 r
F P
0 g
s
.66613 .34158 m .65458 .35509 L .63646 .34631 L p .645 .434 .582 r
F P
0 g
s
.38728 .42113 m .40789 .41903 L .4137 .43439 L p .547 .517 .774 r
F P
0 g
s
.40789 .41903 m .38728 .42113 L .38088 .40351 L p .547 .548 .807 r
F P
0 g
s
.60766 .34903 m .59952 .36086 L .58051 .35015 L p .731 .525 .613 r
F P
0 g
s
.59952 .36086 m .60766 .34903 L .62665 .35875 L p .695 .475 .585 r
F P
0 g
s
.54603 .32574 m .55206 .31293 L .56926 .32544 L p .798 .615 .654 r
F P
0 g
s
.56926 .32544 m .56232 .3381 L .54603 .32574 L p .798 .615 .654 r
F P
0 g
s
.4307 .48044 m .41416 .49827 L .40782 .47958 L p .485 .383 .664 r
F P
0 g
s
.40782 .47958 m .42536 .46578 L .4307 .48044 L p .485 .383 .664 r
F P
0 g
s
.53719 .30109 m .543 .28648 L .55882 .29856 L p .828 .664 .679 r
F P
0 g
s
.55882 .29856 m .55206 .31293 L .53719 .30109 L p .828 .664 .679 r
F P
0 g
s
.66613 .34158 m .67839 .32589 L .69547 .33396 L p .586 .372 .558 r
F P
0 g
s
.70844 .31622 m .69547 .33396 L .67839 .32589 L p .577 .384 .583 r
F P
0 g
s
.56571 .20206 m .58023 .18253 L .59499 .19344 L p .806 .74 .791 r
F P
0 g
s
.61082 .17465 m .59499 .19344 L .58023 .18253 L p .786 .745 .815 r
F P
0 g
s
.35943 .61352 m .28953 .64535 L .28803 .62562 L p .505 .194 .373 r
F P
0 g
s
.28803 .62562 m .35643 .59645 L .35943 .61352 L p .505 .194 .373 r
F P
0 g
s
.20231 .62893 m .28803 .62562 L .28953 .64535 L p .651 .302 .368 r
F P
0 g
s
.71392 .21054 m .72012 .19018 L .73482 .1976 L p .557 .5 .748 r
F P
0 g
s
.73482 .1976 m .73068 .2191 L .71392 .21054 L p .557 .5 .748 r
F P
0 g
s
.6342 .51475 m .65356 .53316 L .63605 .5365 L p .597 .684 .902 r
F P
0 g
s
.63605 .5365 m .62064 .51712 L .6342 .51475 L p .597 .684 .902 r
F P
0 g
s
.53605 .25919 m .54379 .24113 L .55833 .25237 L p .85 .724 .723 r
F P
0 g
s
.55833 .25237 m .54992 .27021 L .53605 .25919 L p .85 .724 .723 r
F P
0 g
s
.344 .3836 m .37509 .38784 L .38088 .40351 L p .568 .595 .841 r
F P
0 g
s
.37509 .38784 m .344 .3836 L .33832 .3676 L p .546 .623 .88 r
F P
0 g
s
.29445 .36294 m .33832 .3676 L .344 .3836 L p .603 .658 .877 r
F P
0 g
s
.61082 .17465 m .62757 .15799 L .64271 .16832 L p .735 .698 .816 r
F P
0 g
s
.65759 .15335 m .64271 .16832 L .62757 .15799 L p .711 .701 .839 r
F P
0 g
s
.64271 .16832 m .65759 .15335 L .67245 .16286 L p .688 .66 .817 r
F P
0 g
s
.53131 .5579 m .54154 .53157 L .55672 .52871 L p .789 .803 .864 r
F P
0 g
s
.54154 .53157 m .53131 .5579 L .51301 .5619 L p .825 .846 .864 r
F P
0 g
s
.4241 .52881 m .3993 .56045 L .39432 .54238 L p .399 .225 .527 r
F P
0 g
s
.39432 .54238 m .41969 .51501 L .4241 .52881 L p .399 .225 .527 r
F P
0 g
s
.72379 .24209 m .73068 .2191 L .74552 .22606 L p .521 .433 .696 r
F P
0 g
s
.74552 .22606 m .74004 .24982 L .72379 .24209 L p .521 .433 .696 r
F P
0 g
s
.17374 .38381 m .11939 .41447 L .11674 .40234 L p .829 .845 .86 r
F P
0 g
s
.11674 .40234 m .16981 .36864 L .17374 .38381 L p .829 .845 .86 r
F P
0 g
s
.57353 .36153 m .58051 .35015 L .59952 .36086 L p .734 .519 .601 r
F P
0 g
s
.55581 .3495 m .56232 .3381 L .58051 .35015 L p .768 .567 .626 r
F P
0 g
s
.58051 .35015 m .57353 .36153 L .55581 .3495 L p .768 .567 .626 r
F P
0 g
s
.65458 .35509 m .66613 .34158 L .68258 .34915 L p .592 .361 .534 r
F P
0 g
s
.69547 .33396 m .68258 .34915 L .66613 .34158 L p .586 .372 .558 r
F P
0 g
s
.58023 .18253 m .59684 .16436 L .61082 .17465 L p .786 .745 .815 r
F P
0 g
s
.62757 .15799 m .61082 .17465 L .59684 .16436 L p .761 .748 .84 r
F P
0 g
s
.68826 .17243 m .69711 .15762 L .71071 .16536 L p .61 .59 .806 r
F P
0 g
s
.71071 .16536 m .70437 .18166 L .68826 .17243 L p .61 .59 .806 r
F P
0 g
s
.69711 .15762 m .68826 .17243 L .67245 .16286 L p .638 .627 .822 r
F P
0 g
s
.52992 .27572 m .53605 .25919 L .54992 .27021 L p .86 .719 .705 r
F P
0 g
s
.54992 .27021 m .543 .28648 L .52992 .27572 L p .86 .719 .705 r
F P
0 g
s
.62665 .35875 m .61791 .36975 L .59952 .36086 L p .695 .475 .585 r
F P
0 g
s
.61791 .36975 m .62665 .35875 L .64402 .36673 L p .652 .415 .548 r
F P
0 g
s
.65458 .35509 m .64402 .36673 L .62665 .35875 L p .65 .425 .564 r
F P
0 g
s
.33832 .3676 m .29445 .36294 L .28939 .34824 L p .569 .692 .924 r
F P
0 g
s
.23245 .35039 m .28939 .34824 L .29445 .36294 L p .653 .744 .917 r
F P
0 g
s
.53217 .31409 m .53719 .30109 L .55206 .31293 L p .834 .661 .668 r
F P
0 g
s
.55206 .31293 m .54603 .32574 L .53217 .31409 L p .834 .661 .668 r
F P
0 g
s
.54044 .33709 m .54603 .32574 L .56232 .3381 L p .802 .613 .646 r
F P
0 g
s
.56232 .3381 m .55581 .3495 L .54044 .33709 L p .802 .613 .646 r
F P
0 g
s
.59952 .36086 m .59232 .37169 L .57353 .36153 L p .734 .519 .601 r
F P
0 g
s
.59232 .37169 m .59952 .36086 L .61791 .36975 L p .696 .467 .572 r
F P
0 g
s
.70437 .18166 m .71071 .16536 L .72398 .17248 L p .576 .553 .791 r
F P
0 g
s
.72398 .17248 m .72012 .19018 L .70437 .18166 L p .576 .553 .791 r
F P
0 g
s
.38088 .40351 m .40241 .4047 L .40789 .41903 L p .547 .548 .807 r
F P
0 g
s
.40241 .4047 m .38088 .40351 L .37509 .38784 L p .537 .576 .842 r
F P
0 g
s
.68376 .14958 m .67245 .16286 L .65759 .15335 L p .661 .663 .841 r
F P
0 g
s
.67245 .16286 m .68376 .14958 L .69711 .15762 L p .638 .627 .822 r
F P
0 g
s
.28953 .64535 m .20155 .64724 L .20231 .62893 L p .651 .302 .368 r
F P
0 g
s
.12882 .6012 m .20231 .62893 L .20155 .64724 L p .787 .423 .366 r
F P
0 g
s
.20231 .62893 m .12882 .6012 L .13003 .58371 L p .794 .5 .492 r
F P
0 g
s
.12196 .42992 m .087 .45773 L .08563 .44766 L p .897 .834 .776 r
F P
0 g
s
.08563 .44766 m .11939 .41447 L .12196 .42992 L p .897 .834 .776 r
F P
0 g
s
.43535 .49343 m .41969 .51501 L .41416 .49827 L p .431 .307 .61 r
F P
0 g
s
.41416 .49827 m .4307 .48044 L .43535 .49343 L p .431 .307 .61 r
F P
0 g
s
.68034 .52831 m .71414 .55733 L .69922 .56024 L p .449 .595 .904 r
F P
0 g
s
.69922 .56024 m .66846 .5304 L .68034 .52831 L p .449 .595 .904 r
F P
0 g
s
.40259 .57368 m .35943 .61352 L .35643 .59645 L p .364 .105 .381 r
F P
0 g
s
.35643 .59645 m .3993 .56045 L .40259 .57368 L p .364 .105 .381 r
F P
0 g
s
.64402 .36673 m .65458 .35509 L .67031 .36203 L p .596 .349 .513 r
F P
0 g
s
.68258 .34915 m .67031 .36203 L .65458 .35509 L p .592 .361 .534 r
F P
0 g
s
.08822 .55244 m .13003 .58371 L .12882 .6012 L p .891 .595 .478 r
F P
0 g
s
.13003 .58371 m .08822 .55244 L .08913 .54029 L p .881 .627 .549 r
F P
0 g
s
.525 .29062 m .52992 .27572 L .543 .28648 L p .868 .714 .689 r
F P
0 g
s
.543 .28648 m .53719 .30109 L .525 .29062 L p .868 .714 .689 r
F P
0 g
s
.73068 .2191 m .73482 .1976 L .74785 .20362 L p .5 .445 .727 r
F P
0 g
s
.74785 .20362 m .74552 .22606 L .73068 .2191 L p .5 .445 .727 r
F P
0 g
s
.56693 .37228 m .57353 .36153 L .59232 .37169 L p .735 .513 .591 r
F P
0 g
s
.54939 .3598 m .55581 .3495 L .57353 .36153 L p .771 .563 .618 r
F P
0 g
s
.57353 .36153 m .56693 .37228 L .54939 .3598 L p .771 .563 .618 r
F P
0 g
s
.72012 .19018 m .72398 .17248 L .73637 .17868 L p .533 .51 .776 r
F P
0 g
s
.73637 .17868 m .73482 .1976 L .72012 .19018 L p .533 .51 .776 r
F P
0 g
s
.59684 .16436 m .61479 .14862 L .62757 .15799 L p .761 .748 .84 r
F P
0 g
s
.64428 .1443 m .62757 .15799 L .61479 .14862 L p .732 .749 .866 r
F P
0 g
s
.62757 .15799 m .64428 .1443 L .65759 .15335 L p .711 .701 .839 r
F P
0 g
s
.61791 .36975 m .6103 .3796 L .59232 .37169 L p .696 .467 .572 r
F P
0 g
s
.6103 .3796 m .61791 .36975 L .63457 .37682 L p .653 .406 .534 r
F P
0 g
s
.64402 .36673 m .63457 .37682 L .61791 .36975 L p .652 .415 .548 r
F P
0 g
s
.52763 .32555 m .53217 .31409 L .54603 .32574 L p .838 .659 .661 r
F P
0 g
s
.54603 .32574 m .54044 .33709 L .52763 .32555 L p .838 .659 .661 r
F P
0 g
s
.64577 .51278 m .66846 .5304 L .65356 .53316 L p .535 .664 .92 r
F P
0 g
s
.65356 .53316 m .6342 .51475 L .64577 .51278 L p .535 .664 .92 r
F P
0 g
s
.70844 .31622 m .72077 .29594 L .7352 .30218 L p .487 .301 .554 r
F P
0 g
s
.72077 .29594 m .73159 .27352 L .74574 .27958 L p .474 .318 .589 r
F P
0 g
s
.74574 .27958 m .7352 .30218 L .72077 .29594 L p .474 .318 .589 r
F P
0 g
s
.67121 .14158 m .65759 .15335 L .64428 .1443 L p .681 .703 .864 r
F P
0 g
s
.65759 .15335 m .67121 .14158 L .68376 .14958 L p .661 .663 .841 r
F P
0 g
s
.7822 .6836 m .7842 .76738 L .77061 .77173 L p .397 .304 .632 r
F P
0 g
s
.75508 .83166 m .77061 .77173 L .7842 .76738 L p .333 .14 .462 r
F P
0 g
s
.77061 .77173 m .75508 .83166 L .74514 .83577 L p .42 .221 .501 r
F P
0 g
s
.69547 .33396 m .70844 .31622 L .72276 .3224 L p .499 .285 .52 r
F P
0 g
s
.7352 .30218 m .72276 .3224 L .70844 .31622 L p .487 .301 .554 r
F P
0 g
s
.53504 .34705 m .54044 .33709 L .55581 .3495 L p .805 .612 .641 r
F P
0 g
s
.55581 .3495 m .54939 .3598 L .53504 .34705 L p .805 .612 .641 r
F P
0 g
s
.59232 .37169 m .5861 .38187 L .56693 .37228 L p .735 .513 .591 r
F P
0 g
s
.5861 .38187 m .59232 .37169 L .6103 .3796 L p .695 .459 .561 r
F P
0 g
s
.42793 .4297 m .4137 .43439 L .40789 .41903 L p .537 .511 .774 r
F P
0 g
s
.4329 .44248 m .41961 .45019 L .4137 .43439 L p .526 .474 .741 r
F P
0 g
s
.4137 .43439 m .42793 .4297 L .4329 .44248 L p .526 .474 .741 r
F P
0 g
s
.58614 .50845 m .58944 .5227 L .57293 .52571 L p .717 .76 .886 r
F P
0 g
s
.59852 .50637 m .60554 .5198 L .58944 .5227 L p .682 .737 .892 r
F P
0 g
s
.58944 .5227 m .58614 .50845 L .59852 .50637 L p .682 .737 .892 r
F P
0 g
s
.43772 .45501 m .42536 .46578 L .41961 .45019 L p .504 .43 .706 r
F P
0 g
s
.41961 .45019 m .4329 .44248 L .43772 .45501 L p .504 .43 .706 r
F P
0 g
s
.73159 .27352 m .74004 .24982 L .75348 .25548 L p .458 .335 .625 r
F P
0 g
s
.75348 .25548 m .74574 .27958 L .73159 .27352 L p .458 .335 .625 r
F P
0 g
s
.54197 .21234 m .554 .19254 L .56571 .20206 L p .864 .799 .784 r
F P
0 g
s
.56571 .20206 m .55358 .22189 L .54197 .21234 L p .864 .799 .784 r
F P
0 g
s
.58023 .18253 m .56571 .20206 L .554 .19254 L p .843 .804 .813 r
F P
0 g
s
.57293 .52571 m .57356 .51059 L .58614 .50845 L p .717 .76 .886 r
F P
0 g
s
.57356 .51059 m .57293 .52571 L .55672 .52871 L p .751 .787 .883 r
F P
0 g
s
.53255 .23171 m .54197 .21234 L .55358 .22189 L p .882 .792 .757 r
F P
0 g
s
.55358 .22189 m .54379 .24113 L .53255 .23171 L p .882 .792 .757 r
F P
0 g
s
.47712 .6142 m .49798 .56532 L .51301 .5619 L p .881 .855 .813 r
F P
0 g
s
.49798 .56532 m .47712 .6142 L .46211 .61876 L p .926 .925 .789 r
F P
0 g
s
.45033 .70176 m .46211 .61876 L .47712 .6142 L p .948 .831 .695 r
F P
0 g
s
.63457 .37682 m .64402 .36673 L .65898 .37294 L p .597 .338 .494 r
F P
0 g
s
.67031 .36203 m .65898 .37294 L .64402 .36673 L p .596 .349 .513 r
F P
0 g
s
.68258 .34915 m .69547 .33396 L .7094 .3399 L p .507 .269 .488 r
F P
0 g
s
.72276 .3224 m .7094 .3399 L .69547 .33396 L p .499 .285 .52 r
F P
0 g
s
.554 .19254 m .56877 .17325 L .58023 .18253 L p .843 .804 .813 r
F P
0 g
s
.59684 .16436 m .58023 .18253 L .56877 .17325 L p .817 .807 .842 r
F P
0 g
s
.52091 .30389 m .525 .29062 L .53719 .30109 L p .874 .711 .678 r
F P
0 g
s
.53719 .30109 m .53217 .31409 L .52091 .30389 L p .874 .711 .678 r
F P
0 g
s
.40789 .41903 m .42302 .41718 L .42793 .4297 L p .537 .511 .774 r
F P
0 g
s
.42302 .41718 m .40789 .41903 L .40241 .4047 L p .539 .543 .807 r
F P
0 g
s
.61019 .50443 m .62064 .51712 L .60554 .5198 L p .643 .717 .902 r
F P
0 g
s
.60554 .5198 m .59852 .50637 L .61019 .50443 L p .643 .717 .902 r
F P
0 g
s
.51301 .5619 m .52816 .53414 L .54154 .53157 L p .825 .846 .864 r
F P
0 g
s
.52816 .53414 m .51301 .5619 L .49798 .56532 L p .861 .903 .861 r
F P
0 g
s
.52535 .25 m .53255 .23171 L .54379 .24113 L p .896 .786 .731 r
F P
0 g
s
.54379 .24113 m .53605 .25919 L .52535 .25 L p .896 .786 .731 r
F P
0 g
s
.37509 .38784 m .39743 .39188 L .40241 .4047 L p .537 .576 .842 r
F P
0 g
s
.39743 .39188 m .37509 .38784 L .37007 .37458 L p .512 .601 .88 r
F P
0 g
s
.33832 .3676 m .37007 .37458 L .37509 .38784 L p .546 .623 .88 r
F P
0 g
s
.76555 .60527 m .79494 .68096 L .7822 .6836 L p .289 .34 .742 r
F P
0 g
s
.7822 .6836 m .75288 .60762 L .76555 .60527 L p .289 .34 .742 r
F P
0 g
s
.7842 .76738 m .7822 .6836 L .79494 .68096 L p .257 .193 .59 r
F P
0 g
s
.44217 .46669 m .4307 .48044 L .42536 .46578 L p .468 .373 .665 r
F P
0 g
s
.42536 .46578 m .43772 .45501 L .44217 .46669 L p .468 .373 .665 r
F P
0 g
s
.37007 .37458 m .33832 .3676 L .33362 .35497 L p .501 .648 .923 r
F P
0 g
s
.28939 .34824 m .33362 .35497 L .33832 .3676 L p .569 .692 .924 r
F P
0 g
s
.74004 .24982 m .74552 .22606 L .7578 .23113 L p .438 .352 .662 r
F P
0 g
s
.7578 .23113 m .75348 .25548 L .74004 .24982 L p .438 .352 .662 r
F P
0 g
s
.55672 .52871 m .56129 .51269 L .57356 .51059 L p .751 .787 .883 r
F P
0 g
s
.56129 .51269 m .55672 .52871 L .54154 .53157 L p .783 .822 .883 r
F P
0 g
s
.72492 .55549 m .76555 .60527 L .75288 .60762 L p .304 .458 .849 r
F P
0 g
s
.75288 .60762 m .71414 .55733 L .72492 .55549 L p .304 .458 .849 r
F P
0 g
s
.69711 .15762 m .70403 .14601 L .71506 .15225 L p .581 .595 .832 r
F P
0 g
s
.71506 .15225 m .71071 .16536 L .69711 .15762 L p .581 .595 .832 r
F P
0 g
s
.70403 .14601 m .69711 .15762 L .68376 .14958 L p .608 .63 .847 r
F P
0 g
s
.52339 .33558 m .52763 .32555 L .54044 .33709 L p .84 .659 .657 r
F P
0 g
s
.54044 .33709 m .53504 .34705 L .52339 .33558 L p .84 .659 .657 r
F P
0 g
s
.6103 .3796 m .60387 .38856 L .5861 .38187 L p .695 .459 .561 r
F P
0 g
s
.60387 .38856 m .6103 .3796 L .62629 .38568 L p .651 .397 .522 r
F P
0 g
s
.63457 .37682 m .62629 .38568 L .6103 .3796 L p .653 .406 .534 r
F P
0 g
s
.56034 .38307 m .56693 .37228 L .5861 .38187 L p .734 .505 .582 r
F P
0 g
s
.5426 .36894 m .54939 .3598 L .56693 .37228 L p .772 .561 .612 r
F P
0 g
s
.56693 .37228 m .56034 .38307 L .5426 .36894 L p .772 .561 .612 r
F P
0 g
s
.67031 .36203 m .68258 .34915 L .69594 .3547 L p .513 .254 .459 r
F P
0 g
s
.7094 .3399 m .69594 .3547 L .68258 .34915 L p .507 .269 .488 r
F P
0 g
s
.70768 .85439 m .71551 .87233 L .70974 .87571 L p .465 .14 .33 r
F P
0 g
s
.70974 .87571 m .69416 .86198 L .70768 .85439 L p .465 .14 .33 r
F P
0 g
s
.71551 .87233 m .70768 .85439 L .72102 .84733 L p .443 .13 .339 r
F P
0 g
s
.56877 .17325 m .58597 .15558 L .59684 .16436 L p .817 .807 .842 r
F P
0 g
s
.61479 .14862 m .59684 .16436 L .58597 .15558 L p .786 .808 .87 r
F P
0 g
s
.57867 .86902 m .65001 .89113 L .64435 .89631 L p .642 .216 .219 r
F P
0 g
s
.64435 .89631 m .56665 .87831 L .57867 .86902 L p .642 .216 .219 r
F P
0 g
s
.71071 .16536 m .71506 .15225 L .72581 .15798 L p .548 .559 .818 r
F P
0 g
s
.72581 .15798 m .72398 .17248 L .71071 .16536 L p .548 .559 .818 r
F P
0 g
s
.6932 .13951 m .68376 .14958 L .67121 .14158 L p .629 .665 .866 r
F P
0 g
s
.68376 .14958 m .6932 .13951 L .70403 .14601 L p .608 .63 .847 r
F P
0 g
s
.69416 .86198 m .70974 .87571 L .70423 .87914 L p .479 .138 .309 r
F P
0 g
s
.70423 .87914 m .68102 .86981 L .69416 .86198 L p .479 .138 .309 r
F P
0 g
s
.51989 .26682 m .52535 .25 L .53605 .25919 L p .907 .779 .709 r
F P
0 g
s
.53605 .25919 m .52992 .27572 L .51989 .26682 L p .907 .779 .709 r
F P
0 g
s
.52966 .35563 m .53504 .34705 L .54939 .3598 L p .807 .612 .639 r
F P
0 g
s
.54939 .3598 m .5426 .36894 L .52966 .35563 L p .807 .612 .639 r
F P
0 g
s
.73482 .1976 m .73637 .17868 L .74734 .18368 L p .475 .458 .759 r
F P
0 g
s
.74734 .18368 m .74785 .20362 L .73482 .1976 L p .475 .458 .759 r
F P
0 g
s
.5861 .38187 m .58115 .39176 L .56034 .38307 L p .734 .505 .582 r
F P
0 g
s
.58115 .39176 m .5861 .38187 L .60387 .38856 L p .692 .449 .551 r
F P
0 g
s
.43905 .50402 m .4241 .52881 L .41969 .51501 L p .339 .192 .53 r
F P
0 g
s
.41969 .51501 m .43535 .49343 L .43905 .50402 L p .339 .192 .53 r
F P
0 g
s
.62629 .38568 m .63457 .37682 L .64877 .38225 L p .597 .327 .479 r
F P
0 g
s
.65898 .37294 m .64877 .38225 L .63457 .37682 L p .597 .338 .494 r
F P
0 g
s
.51734 .3156 m .52091 .30389 L .53217 .31409 L p .878 .71 .67 r
F P
0 g
s
.53217 .31409 m .52763 .32555 L .51734 .3156 L p .878 .71 .67 r
F P
0 g
s
.61479 .14862 m .63305 .13607 L .64428 .1443 L p .732 .749 .866 r
F P
0 g
s
.65998 .13396 m .64428 .1443 L .63305 .13607 L p .697 .747 .89 r
F P
0 g
s
.64428 .1443 m .65998 .13396 L .67121 .14158 L p .681 .703 .864 r
F P
0 g
s
.7213 .86913 m .72102 .84733 L .73366 .84105 L p .41 .106 .336 r
F P
0 g
s
.72102 .84733 m .7213 .86913 L .71551 .87233 L p .443 .13 .339 r
F P
0 g
s
.40241 .4047 m .41836 .40543 L .42302 .41718 L p .539 .543 .807 r
F P
0 g
s
.41836 .40543 m .40241 .4047 L .39743 .39188 L p .53 .571 .841 r
F P
0 g
s
.62071 .5027 m .6342 .51475 L .62064 .51712 L p .595 .699 .916 r
F P
0 g
s
.62064 .51712 m .61019 .50443 L .62071 .5027 L p .595 .699 .916 r
F P
0 g
s
.28939 .34824 m .23245 .35039 L .22835 .3391 L p .606 .792 .97 r
F P
0 g
s
.23245 .35039 m .16981 .36864 L .1662 .35792 L p .722 .86 .947 r
F P
0 g
s
.1662 .35792 m .22835 .3391 L .23245 .35039 L p .722 .86 .947 r
F P
0 g
s
.11939 .41447 m .08563 .44766 L .08411 .43974 L p .91 .882 .795 r
F P
0 g
s
.08411 .43974 m .11674 .40234 L .11939 .41447 L p .91 .882 .795 r
F P
0 g
s
.08959 .4973 m .07183 .49933 L .07167 .49194 L p .944 .784 .652 r
F P
0 g
s
.07167 .49194 m .08902 .48298 L .08959 .4973 L p .944 .784 .652 r
F P
0 g
s
.07183 .49933 m .08959 .4973 L .08981 .51204 L p .943 .762 .628 r
F P
0 g
s
.07181 .50684 m .08981 .51204 L .08966 .52659 L p .945 .743 .598 r
F P
0 g
s
.08981 .51204 m .07181 .50684 L .07183 .49933 L p .943 .762 .628 r
F P
0 g
s
.42708 .53875 m .40259 .57368 L .3993 .56045 L p .246 .038 .387 r
F P
0 g
s
.3993 .56045 m .4241 .52881 L .42708 .53875 L p .246 .038 .387 r
F P
0 g
s
.65898 .37294 m .67031 .36203 L .683 .36707 L p .516 .239 .432 r
F P
0 g
s
.69594 .3547 m .683 .36707 L .67031 .36203 L p .513 .254 .459 r
F P
0 g
s
.68102 .86981 m .70423 .87914 L .69924 .88246 L p .484 .12 .273 r
F P
0 g
s
.69924 .88246 m .66888 .87751 L .68102 .86981 L p .484 .12 .273 r
F P
0 g
s
.72398 .17248 m .72581 .15798 L .73584 .16296 L p .505 .519 .805 r
F P
0 g
s
.73584 .16296 m .73637 .17868 L .72398 .17248 L p .505 .519 .805 r
F P
0 g
s
.74552 .22606 m .74785 .20362 L .75862 .20797 L p .416 .37 .699 r
F P
0 g
s
.75862 .20797 m .7578 .23113 L .74552 .22606 L p .416 .37 .699 r
F P
0 g
s
.5157 .28202 m .51989 .26682 L .52992 .27572 L p .915 .774 .69 r
F P
0 g
s
.52992 .27572 m .525 .29062 L .5157 .28202 L p .915 .774 .69 r
F P
0 g
s
.68302 .13304 m .67121 .14158 L .65998 .13396 L p .645 .702 .888 r
F P
0 g
s
.67121 .14158 m .68302 .13304 L .6932 .13951 L p .629 .665 .866 r
F P
0 g
s
.44603 .47695 m .43535 .49343 L .4307 .48044 L p .41 .295 .611 r
F P
0 g
s
.4307 .48044 m .44217 .46669 L .44603 .47695 L p .41 .295 .611 r
F P
0 g
s
.51929 .34425 m .52339 .33558 L .53504 .34705 L p .842 .661 .658 r
F P
0 g
s
.53504 .34705 m .52966 .35563 L .51929 .34425 L p .842 .661 .658 r
F P
0 g
s
.54154 .53157 m .5499 .51466 L .56129 .51269 L p .783 .822 .883 r
F P
0 g
s
.5499 .51466 m .54154 .53157 L .52816 .53414 L p .816 .866 .884 r
F P
0 g
s
.08902 .48298 m .07167 .49194 L .07133 .48496 L p .948 .808 .671 r
F P
0 g
s
.07133 .48496 m .08814 .46964 L .08902 .48298 L p .948 .808 .671 r
F P
0 g
s
.58597 .15558 m .60488 .14059 L .61479 .14862 L p .786 .808 .87 r
F P
0 g
s
.63305 .13607 m .61479 .14862 L .60488 .14059 L p .75 .806 .897 r
F P
0 g
s
.60387 .38856 m .5987 .39678 L .58115 .39176 L p .692 .449 .551 r
F P
0 g
s
.5987 .39678 m .60387 .38856 L .6192 .39353 L p .647 .387 .512 r
F P
0 g
s
.62629 .38568 m .6192 .39353 L .60387 .38856 L p .651 .397 .522 r
F P
0 g
s
.655 .51125 m .68034 .52831 L .66846 .5304 L p .445 .637 .938 r
F P
0 g
s
.66846 .5304 m .64577 .51278 L .655 .51125 L p .445 .637 .938 r
F P
0 g
s
.16981 .36864 m .11674 .40234 L .11408 .39383 L p .83 .912 .893 r
F P
0 g
s
.11408 .39383 m .1662 .35792 L .16981 .36864 L p .83 .912 .893 r
F P
0 g
s
.5514 .39791 m .56034 .38307 L .58115 .39176 L p .73 .494 .57 r
F P
0 g
s
.53506 .37636 m .5426 .36894 L .56034 .38307 L p .774 .558 .606 r
F P
0 g
s
.56034 .38307 m .5514 .39791 L .53506 .37636 L p .774 .558 .606 r
F P
0 g
s
.07159 .51413 m .08966 .52659 L .08913 .54029 L p .95 .725 .561 r
F P
0 g
s
.08966 .52659 m .07159 .51413 L .07181 .50684 L p .945 .743 .598 r
F P
0 g
s
.51409 .32587 m .51734 .3156 L .52763 .32555 L p .88 .71 .667 r
F P
0 g
s
.52763 .32555 m .52339 .33558 L .51409 .32587 L p .88 .71 .667 r
F P
0 g
s
.72686 .86626 m .73366 .84105 L .74514 .83577 L p .367 .068 .32 r
F P
0 g
s
.73366 .84105 m .72686 .86626 L .7213 .86913 L p .41 .106 .336 r
F P
0 g
s
.52425 .36278 m .52966 .35563 L .5426 .36894 L p .807 .616 .643 r
F P
0 g
s
.5426 .36894 m .53506 .37636 L .52425 .36278 L p .807 .616 .643 r
F P
0 g
s
.6192 .39353 m .62629 .38568 L .63974 .39027 L p .594 .317 .466 r
F P
0 g
s
.64877 .38225 m .63974 .39027 L .62629 .38568 L p .597 .327 .479 r
F P
0 g
s
.33362 .35497 m .28939 .34824 L .28536 .33779 L p .496 .72 .972 r
F P
0 g
s
.22835 .3391 m .28536 .33779 L .28939 .34824 L p .606 .792 .97 r
F P
0 g
s
.43897 .42571 m .42793 .4297 L .42302 .41718 L p .546 .515 .773 r
F P
0 g
s
.44318 .43627 m .4329 .44248 L .42793 .4297 L p .533 .477 .74 r
F P
0 g
s
.42793 .4297 m .43897 .42571 L .44318 .43627 L p .533 .477 .74 r
F P
0 g
s
.58115 .39176 m .57814 .40135 L .5514 .39791 L p .73 .494 .57 r
F P
0 g
s
.57814 .40135 m .58115 .39176 L .5987 .39678 L p .686 .438 .542 r
F P
0 g
s
.44724 .44654 m .43772 .45501 L .4329 .44248 L p .51 .432 .704 r
F P
0 g
s
.4329 .44248 m .44318 .43627 L .44724 .44654 L p .51 .432 .704 r
F P
0 g
s
.64877 .38225 m .65898 .37294 L .67096 .37742 L p .517 .225 .41 r
F P
0 g
s
.683 .36707 m .67096 .37742 L .65898 .37294 L p .516 .239 .432 r
F P
0 g
s
.51236 .29558 m .5157 .28202 L .525 .29062 L p .921 .77 .677 r
F P
0 g
s
.525 .29062 m .52091 .30389 L .51236 .29558 L p .921 .77 .677 r
F P
0 g
s
.20155 .64724 m .12693 .61407 L .12882 .6012 L p .787 .423 .366 r
F P
0 g
s
.08696 .56238 m .12882 .6012 L .12693 .61407 L p .9 .548 .367 r
F P
0 g
s
.12882 .6012 m .08696 .56238 L .08822 .55244 L p .891 .595 .478 r
F P
0 g
s
.45033 .70176 m .48441 .8059 L .47442 .81357 L p .975 .679 .389 r
F P
0 g
s
.48441 .8059 m .56665 .87831 L .5606 .88498 L p .826 .383 .183 r
F P
0 g
s
.5606 .88498 m .47442 .81357 L .48441 .8059 L p .826 .383 .183 r
F P
0 g
s
.68886 .52693 m .72492 .55549 L .71414 .55733 L p .305 .541 .914 r
F P
0 g
s
.71414 .55733 m .68034 .52831 L .68886 .52693 L p .305 .541 .914 r
F P
0 g
s
.42302 .41718 m .4348 .41532 L .43897 .42571 L p .546 .515 .773 r
F P
0 g
s
.4348 .41532 m .42302 .41718 L .41836 .40543 L p .549 .548 .805 r
F P
0 g
s
.66888 .87751 m .69924 .88246 L .69499 .88553 L p .476 .086 .219 r
F P
0 g
s
.69499 .88553 m .65835 .88475 L .66888 .87751 L p .476 .086 .219 r
F P
0 g
s
.08814 .46964 m .07133 .48496 L .07082 .47867 L p .955 .835 .685 r
F P
0 g
s
.07082 .47867 m .087 .45773 L .08814 .46964 L p .955 .835 .685 r
F P
0 g
s
.37007 .37458 m .39314 .38099 L .39743 .39188 L p .512 .601 .88 r
F P
0 g
s
.39314 .38099 m .37007 .37458 L .36596 .36409 L p .462 .621 .92 r
F P
0 g
s
.33362 .35497 m .36596 .36409 L .37007 .37458 L p .501 .648 .923 r
F P
0 g
s
.46211 .61876 m .45033 .70176 L .43985 .70721 L p .991 .883 .57 r
F P
0 g
s
.47442 .81357 m .43985 .70721 L .45033 .70176 L p .975 .679 .389 r
F P
0 g
s
.62973 .50124 m .64577 .51278 L .6342 .51475 L p .532 .679 .932 r
F P
0 g
s
.6342 .51475 m .62071 .5027 L .62973 .50124 L p .532 .679 .932 r
F P
0 g
s
.39743 .39188 m .41413 .39487 L .41836 .40543 L p .53 .571 .841 r
F P
0 g
s
.41413 .39487 m .39743 .39188 L .39314 .38099 L p .505 .597 .879 r
F P
0 g
s
.51528 .35166 m .51929 .34425 L .52966 .35563 L p .842 .664 .662 r
F P
0 g
s
.52966 .35563 m .52425 .36278 L .51528 .35166 L p .842 .664 .662 r
F P
0 g
s
.73637 .17868 m .73584 .16296 L .74471 .16695 L p .446 .47 .791 r
F P
0 g
s
.74471 .16695 m .74734 .18368 L .73637 .17868 L p .446 .47 .791 r
F P
0 g
s
.45097 .45607 m .44217 .46669 L .43772 .45501 L p .473 .375 .663 r
F P
0 g
s
.43772 .45501 m .44724 .44654 L .45097 .45607 L p .473 .375 .663 r
F P
0 g
s
.72276 .3224 m .7352 .30218 L .74589 .30598 L p .351 .144 .452 r
F P
0 g
s
.7352 .30218 m .74574 .27958 L .75626 .28323 L p .336 .169 .501 r
F P
0 g
s
.75626 .28323 m .74589 .30598 L .7352 .30218 L p .336 .169 .501 r
F P
0 g
s
.70403 .14601 m .70913 .13742 L .71773 .14227 L p .546 .599 .858 r
F P
0 g
s
.71773 .14227 m .71506 .15225 L .70403 .14601 L p .546 .599 .858 r
F P
0 g
s
.70913 .13742 m .70403 .14601 L .6932 .13951 L p .571 .631 .872 r
F P
0 g
s
.58411 .49816 m .58614 .50845 L .57356 .51059 L p .718 .759 .884 r
F P
0 g
s
.5938 .4966 m .59852 .50637 L .58614 .50845 L p .683 .735 .89 r
F P
0 g
s
.58614 .50845 m .58411 .49816 L .5938 .4966 L p .683 .735 .89 r
F P
0 g
s
.5987 .39678 m .59485 .40425 L .57814 .40135 L p .686 .438 .542 r
F P
0 g
s
.59485 .40425 m .5987 .39678 L .61328 .40055 L p .641 .378 .505 r
F P
0 g
s
.6192 .39353 m .61328 .40055 L .5987 .39678 L p .647 .387 .512 r
F P
0 g
s
.63305 .13607 m .65051 .12701 L .65998 .13396 L p .697 .747 .89 r
F P
0 g
s
.6739 .12686 m .65998 .13396 L .65051 .12701 L p .654 .742 .914 r
F P
0 g
s
.65998 .13396 m .6739 .12686 L .68302 .13304 L p .645 .702 .888 r
F P
0 g
s
.74785 .20362 m .74734 .18368 L .75641 .18726 L p .39 .388 .736 r
F P
0 g
s
.75641 .18726 m .75862 .20797 L .74785 .20362 L p .39 .388 .736 r
F P
0 g
s
.7094 .3399 m .72276 .3224 L .73332 .32621 L p .362 .119 .405 r
F P
0 g
s
.74589 .30598 m .73332 .32621 L .72276 .3224 L p .351 .144 .452 r
F P
0 g
s
.57356 .51059 m .57429 .49974 L .58411 .49816 L p .718 .759 .884 r
F P
0 g
s
.57429 .49974 m .57356 .51059 L .56129 .51269 L p .751 .787 .882 r
F P
0 g
s
.51099 .33482 m .51409 .32587 L .52339 .33558 L p .881 .712 .668 r
F P
0 g
s
.52339 .33558 m .51929 .34425 L .51099 .33482 L p .881 .712 .668 r
F P
0 g
s
.79494 .68096 m .79422 .76508 L .7842 .76738 L p .257 .193 .59 r
F P
0 g
s
.76316 .82883 m .7842 .76738 L .79422 .76508 L p .203 .016 .39 r
F P
0 g
s
.7842 .76738 m .76316 .82883 L .75508 .83166 L p .333 .14 .462 r
F P
0 g
s
.74574 .27958 m .75348 .25548 L .76349 .25883 L p .32 .196 .551 r
F P
0 g
s
.76349 .25883 m .75626 .28323 L .74574 .27958 L p .32 .196 .551 r
F P
0 g
s
.71506 .15225 m .71773 .14227 L .72611 .14672 L p .513 .565 .845 r
F P
0 g
s
.72611 .14672 m .72581 .15798 L .71506 .15225 L p .513 .565 .845 r
F P
0 g
s
.61328 .40055 m .6192 .39353 L .63189 .39728 L p .59 .308 .457 r
F P
0 g
s
.63974 .39027 m .63189 .39728 L .6192 .39353 L p .594 .317 .466 r
F P
0 g
s
.36027 .62323 m .28906 .65678 L .28953 .64535 L p .298 0 .068 r
F P
0 g
s
.28953 .64535 m .35943 .61352 L .36027 .62323 L p .298 0 .068 r
F P
0 g
s
.20155 .64724 m .28953 .64535 L .28906 .65678 L p .536 .063 .08 r
F P
0 g
s
.70068 .13237 m .6932 .13951 L .68302 .13304 L p .589 .664 .89 r
F P
0 g
s
.6932 .13951 m .70068 .13237 L .70913 .13742 L p .571 .631 .872 r
F P
0 g
s
.07118 .52089 m .08913 .54029 L .08822 .55244 L p .958 .706 .514 r
F P
0 g
s
.08913 .54029 m .07118 .52089 L .07159 .51413 L p .95 .725 .561 r
F P
0 g
s
.53408 .20498 m .54605 .18514 L .554 .19254 L p .91 .881 .794 r
F P
0 g
s
.554 .19254 m .54197 .21234 L .53408 .20498 L p .91 .881 .794 r
F P
0 g
s
.56877 .17325 m .554 .19254 L .54605 .18514 L p .882 .887 .832 r
F P
0 g
s
.60488 .14059 m .62436 .12901 L .63305 .13607 L p .75 .806 .897 r
F P
0 g
s
.65051 .12701 m .63305 .13607 L .62436 .12901 L p .706 .799 .923 r
F P
0 g
s
.63974 .39027 m .64877 .38225 L .66004 .38613 L p .516 .212 .391 r
F P
0 g
s
.67096 .37742 m .66004 .38613 L .64877 .38225 L p .517 .225 .41 r
F P
0 g
s
.50956 .30759 m .51236 .29558 L .52091 .30389 L p .925 .768 .668 r
F P
0 g
s
.52091 .30389 m .51734 .3156 L .50956 .30759 L p .925 .768 .668 r
F P
0 g
s
.5249 .22452 m .53408 .20498 L .54197 .21234 L p .931 .873 .757 r
F P
0 g
s
.54197 .21234 m .53255 .23171 L .5249 .22452 L p .931 .873 .757 r
F P
0 g
s
.60299 .49514 m .61019 .50443 L .59852 .50637 L p .644 .715 .899 r
F P
0 g
s
.59852 .50637 m .5938 .4966 L .60299 .49514 L p .644 .715 .899 r
F P
0 g
s
.5271 .38158 m .53506 .37637 L .55128 .39796 L p .776 .558 .604 r
F P
0 g
s
.53506 .37637 m .5271 .38158 L .51877 .36872 L p .81 .616 .64 r
F P
0 g
s
.51877 .36872 m .52425 .36278 L .53506 .37637 L p .81 .616 .64 r
F P
0 g
s
.49798 .56532 m .51731 .53629 L .52816 .53414 L p .861 .903 .861 r
F P
0 g
s
.51731 .53629 m .49798 .56532 L .48721 .56793 L p .884 .968 .84 r
F P
0 g
s
.46211 .61876 m .48721 .56793 L .49798 .56532 L p .926 .925 .789 r
F P
0 g
s
.69594 .3547 m .7094 .3399 L .71961 .34356 L p .371 .096 .361 r
F P
0 g
s
.73332 .32621 m .71961 .34356 L .7094 .3399 L p .362 .119 .405 r
F P
0 g
s
.54605 .18514 m .56099 .16599 L .56877 .17325 L p .882 .887 .832 r
F P
0 g
s
.58597 .15558 m .56877 .17325 L .56099 .16599 L p .848 .889 .868 r
F P
0 g
s
.41836 .40543 m .43083 .40552 L .4348 .41532 L p .549 .548 .805 r
F P
0 g
s
.43083 .40552 m .41836 .40543 L .41413 .39487 L p .543 .578 .84 r
F P
0 g
s
.73198 .86382 m .74514 .83577 L .75508 .83166 L p .309 .012 .288 r
F P
0 g
s
.74514 .83577 m .73198 .86382 L .72686 .86626 L p .367 .068 .32 r
F P
0 g
s
.57735 .41007 m .57814 .40136 L .59485 .40425 L p .686 .447 .554 r
F P
0 g
s
.57814 .40136 m .57735 .41007 L .56068 .41188 L p .73 .504 .584 r
F P
0 g
s
.56068 .41188 m .55141 .39804 L .57814 .40136 L p .73 .504 .584 r
F P
0 g
s
.44909 .48524 m .43905 .50402 L .43535 .49343 L p .312 .177 .53 r
F P
0 g
s
.43535 .49343 m .44603 .47695 L .44909 .48524 L p .312 .177 .53 r
F P
0 g
s
.51808 .24304 m .5249 .22452 L .53255 .23171 L p .948 .863 .723 r
F P
0 g
s
.53255 .23171 m .52535 .25 L .51808 .24304 L p .948 .863 .723 r
F P
0 g
s
.56129 .51269 m .56479 .50129 L .57429 .49974 L p .751 .787 .882 r
F P
0 g
s
.56479 .50129 m .56129 .51269 L .5499 .51466 L p .784 .823 .883 r
F P
0 g
s
.52816 .53414 m .53994 .51641 L .5499 .51466 L p .816 .866 .884 r
F P
0 g
s
.53994 .51641 m .52816 .53414 L .51731 .53629 L p .846 .922 .883 r
F P
0 g
s
.75348 .25548 m .7578 .23113 L .76696 .23407 L p .3 .224 .6 r
F P
0 g
s
.76696 .23407 m .76349 .25883 L .75348 .25548 L p .3 .224 .6 r
F P
0 g
s
.36596 .36409 m .33362 .35497 L .33002 .34599 L p .409 .659 .962 r
F P
0 g
s
.28536 .33779 m .33002 .34599 L .33362 .35497 L p .496 .72 .972 r
F P
0 g
s
.72581 .15798 m .72611 .14672 L .73392 .15056 L p .47 .526 .834 r
F P
0 g
s
.73392 .15056 m .73584 .16296 L .72581 .15798 L p .47 .526 .834 r
F P
0 g
s
.52425 .36278 m .51877 .36872 L .51124 .35813 L p .842 .664 .661 r
F P
0 g
s
.51124 .35813 m .51528 .35166 L .52425 .36278 L p .842 .664 .661 r
F P
0 g
s
.69274 .12733 m .68302 .13304 L .6739 .12686 L p .601 .697 .911 r
F P
0 g
s
.68302 .13304 m .69274 .12733 L .70068 .13237 L p .589 .664 .89 r
F P
0 g
s
.683 .36707 m .69594 .3547 L .70567 .35812 L p .376 .075 .321 r
F P
0 g
s
.71961 .34356 m .70567 .35812 L .69594 .3547 L p .371 .096 .361 r
F P
0 g
s
.56099 .16599 m .57864 .14866 L .58597 .15558 L p .848 .889 .868 r
F P
0 g
s
.60488 .14059 m .58597 .15558 L .57864 .14866 L p .806 .886 .903 r
F P
0 g
s
.44156 .51155 m .42708 .53875 L .4241 .52881 L p .168 0 .39 r
F P
0 g
s
.4241 .52881 m .43905 .50402 L .44156 .51155 L p .168 0 .39 r
F P
0 g
s
.45419 .46438 m .44603 .47695 L .44217 .46669 L p .414 .296 .609 r
F P
0 g
s
.44217 .46669 m .45097 .45607 L .45419 .46438 L p .414 .296 .609 r
F P
0 g
s
.28906 .65678 m .1995 .65782 L .20155 .64724 L p .536 .063 .08 r
F P
0 g
s
.12693 .61407 m .20155 .64724 L .1995 .65782 L p .744 .27 .121 r
F P
0 g
s
.50798 .34259 m .51099 .33482 L .51929 .34425 L p .88 .715 .673 r
F P
0 g
s
.51929 .34425 m .51528 .35166 L .50798 .34259 L p .88 .715 .673 r
F P
0 g
s
.087 .45773 m .07082 .47867 L .07017 .47332 L p .963 .865 .694 r
F P
0 g
s
.07017 .47332 m .08563 .44766 L .087 .45773 L p .963 .865 .694 r
F P
0 g
s
.51309 .26014 m .51808 .24304 L .52535 .25 L p .96 .853 .692 r
F P
0 g
s
.52535 .25 m .51989 .26682 L .51309 .26014 L p .96 .853 .692 r
F P
0 g
s
.55128 .39796 m .53391 .39728 L .5271 .38158 L p .776 .558 .604 r
F P
0 g
s
.53391 .39728 m .55128 .39796 L .54214 .41373 L p .76 .529 .583 r
F P
0 g
s
.55141 .39804 m .56068 .41188 L .54941 .41836 L p .741 .504 .572 r
F P
0 g
s
.54941 .41836 m .54214 .41373 L .55141 .39804 L p .741 .504 .572 r
F P
0 g
s
.61131 .49383 m .62071 .5027 L .61019 .50443 L p .596 .695 .912 r
F P
0 g
s
.61019 .50443 m .60299 .49514 L .61131 .49383 L p .596 .695 .912 r
F P
0 g
s
.61328 .40055 m .60846 .40683 L .59485 .40425 L p .641 .378 .505 r
F P
0 g
s
.59212 .41109 m .59485 .40425 L .60845 .40683 L p .641 .388 .519 r
F P
0 g
s
.59485 .40425 m .59212 .41109 L .57735 .41007 L p .686 .447 .554 r
F P
0 g
s
.50706 .31816 m .50956 .30759 L .51734 .3156 L p .927 .768 .665 r
F P
0 g
s
.51734 .3156 m .51409 .32587 L .50706 .31816 L p .927 .768 .665 r
F P
0 g
s
.44808 .4222 m .43897 .42571 L .4348 .41532 L p .567 .526 .769 r
F P
0 g
s
.45169 .43114 m .44318 .43627 L .43897 .42571 L p .552 .487 .736 r
F P
0 g
s
.43897 .42571 m .44808 .4222 L .45169 .43114 L p .552 .487 .736 r
F P
0 g
s
.63189 .39728 m .63974 .39027 L .65032 .39354 L p .512 .201 .376 r
F P
0 g
s
.66004 .38613 m .65032 .39354 L .63974 .39027 L p .516 .212 .391 r
F P
0 g
s
.60846 .40683 m .61328 .40055 L .62517 .40346 L p .584 .3 .451 r
F P
0 g
s
.63189 .39728 m .62517 .40346 L .61328 .40055 L p .59 .308 .457 r
F P
0 g
s
.40391 .581 m .36027 .62323 L .35943 .61352 L p .08 0 .077 r
F P
0 g
s
.35943 .61352 m .40259 .57368 L .40391 .581 L p .08 0 .077 r
F P
0 g
s
.45516 .4398 m .44724 .44654 L .44318 .43627 L p .529 .441 .701 r
F P
0 g
s
.44318 .43627 m .45169 .43114 L .45516 .4398 L p .529 .441 .701 r
F P
0 g
s
.65835 .88475 m .69499 .88553 L .69171 .88819 L p .453 .028 .141 r
F P
0 g
s
.69171 .88819 m .65001 .89113 L .65835 .88475 L p .453 .028 .141 r
F P
0 g
s
.4348 .41532 m .44448 .41337 L .44808 .4222 L p .567 .526 .769 r
F P
0 g
s
.44448 .41337 m .4348 .41532 L .43083 .40552 L p .573 .56 .802 r
F P
0 g
s
.11674 .40234 m .08411 .43974 L .08248 .43421 L p .918 .937 .802 r
F P
0 g
s
.08248 .43421 m .11408 .39383 L .11674 .40234 L p .918 .937 .802 r
F P
0 g
s
.51961 .3852 m .5271 .38158 L .53391 .39728 L p .785 .577 .618 r
F P
0 g
s
.5271 .38158 m .51961 .3852 L .51327 .37372 L p .81 .621 .647 r
F P
0 g
s
.51327 .37372 m .51877 .36872 L .5271 .38158 L p .81 .621 .647 r
F P
0 g
s
.67096 .37742 m .683 .36707 L .69218 .37018 L p .379 .056 .286 r
F P
0 g
s
.70567 .35812 m .69218 .37018 L .683 .36707 L p .376 .075 .321 r
F P
0 g
s
.7578 .23113 m .75862 .20797 L .76665 .21044 L p .279 .252 .65 r
F P
0 g
s
.76665 .21044 m .76696 .23407 L .7578 .23113 L p .279 .252 .65 r
F P
0 g
s
.50941 .27563 m .51309 .26014 L .51989 .26682 L p .968 .844 .667 r
F P
0 g
s
.51989 .26682 m .5157 .28202 L .50941 .27563 L p .968 .844 .667 r
F P
0 g
s
.41413 .39487 m .42721 .39667 L .43083 .40552 L p .543 .578 .84 r
F P
0 g
s
.42721 .39667 m .41413 .39487 L .41048 .38586 L p .522 .606 .878 r
F P
0 g
s
.39314 .38099 m .41048 .38586 L .41413 .39487 L p .505 .597 .879 r
F P
0 g
s
.63692 .5001 m .655 .51125 L .64577 .51278 L p .442 .653 .949 r
F P
0 g
s
.64577 .51278 m .62973 .50124 L .63692 .5001 L p .442 .653 .949 r
F P
0 g
s
.5499 .51466 m .55601 .50273 L .56479 .50129 L p .784 .823 .883 r
F P
0 g
s
.55601 .50273 m .5499 .51466 L .53994 .51641 L p .816 .867 .885 r
F P
0 g
s
.41048 .38586 m .39314 .38099 L .38965 .37235 L p .455 .616 .919 r
F P
0 g
s
.36596 .36409 m .38965 .37235 L .39314 .38099 L p .462 .621 .92 r
F P
0 g
s
.74734 .18368 m .74471 .16695 L .75203 .16978 L p .36 .405 .772 r
F P
0 g
s
.75203 .16978 m .75641 .18726 L .74734 .18368 L p .36 .405 .772 r
F P
0 g
s
.57864 .14866 m .59822 .13424 L .60488 .14059 L p .806 .886 .903 r
F P
0 g
s
.62436 .12901 m .60488 .14059 L .59822 .13424 L p .757 .877 .933 r
F P
0 g
s
.57775 .41743 m .57735 .41007 L .59212 .41109 L p .679 .439 .551 r
F P
0 g
s
.57735 .41007 m .57775 .41743 L .56503 .41935 L p .714 .478 .566 r
F P
0 g
s
.56503 .41935 m .56068 .41188 L .57735 .41007 L p .714 .478 .566 r
F P
0 g
s
.45833 .44777 m .45097 .45607 L .44724 .44654 L p .492 .384 .659 r
F P
0 g
s
.44724 .44654 m .45516 .4398 L .45833 .44777 L p .492 .384 .659 r
F P
0 g
s
.51877 .36872 m .51327 .37372 L .50706 .36392 L p .839 .668 .67 r
F P
0 g
s
.50706 .36392 m .51124 .35813 L .51877 .36872 L p .839 .668 .67 r
F P
0 g
s
.62436 .12901 m .6432 .12104 L .65051 .12701 L p .706 .799 .923 r
F P
0 g
s
.66623 .12122 m .65051 .12701 L .6432 .12104 L p .654 .788 .946 r
F P
0 g
s
.65051 .12701 m .66623 .12122 L .6739 .12686 L p .654 .742 .914 r
F P
0 g
s
.0706 .52678 m .08822 .55244 L .08696 .56238 L p .966 .686 .451 r
F P
0 g
s
.08822 .55244 m .0706 .52678 L .07118 .52089 L p .958 .706 .514 r
F P
0 g
s
.51528 .35166 m .51124 .35813 L .50491 .34952 L p .878 .715 .676 r
F P
0 g
s
.50491 .34952 m .50798 .34259 L .51528 .35166 L p .878 .715 .676 r
F P
0 g
s
.48721 .56793 m .46211 .61876 L .45397 .62177 L p .915 .973 .683 r
F P
0 g
s
.43985 .70721 m .45397 .62177 L .46211 .61876 L p .991 .883 .57 r
F P
0 g
s
.73584 .16296 m .73392 .15056 L .74081 .15363 L p .41 .481 .822 r
F P
0 g
s
.74081 .15363 m .74471 .16695 L .73584 .16296 L p .41 .481 .822 r
F P
0 g
s
.50471 .32743 m .50706 .31816 L .51409 .32587 L p .927 .771 .667 r
F P
0 g
s
.51409 .32587 m .51099 .33482 L .50471 .32743 L p .927 .771 .667 r
F P
0 g
s
.66159 .51022 m .68886 .52693 L .68034 .52831 L p .301 .588 .943 r
F P
0 g
s
.68034 .52831 m .655 .51125 L .66159 .51022 L p .301 .588 .943 r
F P
0 g
s
.68563 .12251 m .6739 .12686 L .66623 .12122 L p .603 .732 .936 r
F P
0 g
s
.6739 .12686 m .68563 .12251 L .69274 .12733 L p .601 .697 .911 r
F P
0 g
s
.62517 .40346 m .63189 .39728 L .64178 .39996 L p .507 .191 .367 r
F P
0 g
s
.65032 .39354 m .64178 .39996 L .63189 .39728 L p .512 .201 .376 r
F P
0 g
s
.60845 .40683 m .6045 .41262 L .59212 .41109 L p .641 .388 .519 r
F P
0 g
s
.59025 .41739 m .59212 .41109 L .6045 .41262 L p .636 .384 .52 r
F P
0 g
s
.59212 .41109 m .59025 .41739 L .57775 .41743 L p .679 .439 .551 r
F P
0 g
s
.54214 .41373 m .53396 .41047 L .53391 .39728 L p .76 .529 .583 r
F P
0 g
s
.53391 .39728 m .52445 .3977 L .51961 .3852 L p .785 .577 .618 r
F P
0 g
s
.52445 .3977 m .53391 .39728 L .53396 .41047 L p .768 .541 .59 r
F P
0 g
s
.43083 .40552 m .44105 .40499 L .44448 .41337 L p .573 .56 .802 r
F P
0 g
s
.44105 .40499 m .43083 .40552 L .42721 .39667 L p .57 .593 .837 r
F P
0 g
s
.62517 .40346 m .6195 .40897 L .60846 .40683 L p .584 .3 .451 r
F P
0 g
s
.6045 .41262 m .60845 .40683 L .61949 .40898 L p .584 .31 .466 r
F P
0 g
s
.66004 .38613 m .67096 .37742 L .67957 .38017 L p .379 .038 .256 r
F P
0 g
s
.69218 .37018 m .67957 .38017 L .67096 .37742 L p .379 .056 .286 r
F P
0 g
s
.61844 .49272 m .62973 .50124 L .62071 .5027 L p .534 .675 .928 r
F P
0 g
s
.62071 .5027 m .61131 .49383 L .61844 .49272 L p .534 .675 .928 r
F P
0 g
s
.5066 .28949 m .50941 .27563 L .5157 .28202 L p .973 .838 .648 r
F P
0 g
s
.5157 .28202 m .51236 .29558 L .5066 .28949 L p .973 .838 .648 r
F P
0 g
s
.70913 .13742 m .7127 .1314 L .71915 .13503 L p .502 .599 .883 r
F P
0 g
s
.71915 .13503 m .71773 .14227 L .70913 .13742 L p .502 .599 .883 r
F P
0 g
s
.7127 .1314 m .70913 .13742 L .70068 .13237 L p .525 .629 .897 r
F P
0 g
s
.58269 .49002 m .58411 .49816 L .57429 .49974 L p .722 .745 .87 r
F P
0 g
s
.59051 .48881 m .5938 .4966 L .58411 .49816 L p .687 .72 .875 r
F P
0 g
s
.58411 .49816 m .58269 .49002 L .59051 .48881 L p .687 .72 .875 r
F P
0 g
s
.73644 .8619 m .75508 .83166 L .76316 .82883 L p .233 0 .235 r
F P
0 g
s
.75508 .83166 m .73644 .8619 L .73198 .86382 L p .309 .012 .288 r
F P
0 g
s
.56068 .41188 m .56503 .41935 L .55507 .42336 L p .734 .49 .559 r
F P
0 g
s
.55507 .42336 m .54941 .41836 L .56068 .41188 L p .734 .49 .559 r
F P
0 g
s
.77324 .60455 m .80282 .68045 L .79494 .68096 L p .021 .168 .677 r
F P
0 g
s
.79494 .68096 m .76555 .60527 L .77324 .60455 L p .021 .168 .677 r
F P
0 g
s
.79422 .76508 m .79494 .68096 L .80282 .68045 L p .008 0 .485 r
F P
0 g
s
.57429 .49974 m .57482 .49125 L .58269 .49002 L p .722 .745 .87 r
F P
0 g
s
.57482 .49125 m .57429 .49974 L .56479 .50129 L p .756 .774 .868 r
F P
0 g
s
.51289 .38806 m .51961 .3852 L .52445 .3977 L p .786 .586 .63 r
F P
0 g
s
.51961 .3852 m .51289 .38806 L .50788 .37799 L p .808 .627 .657 r
F P
0 g
s
.50788 .37799 m .51327 .37372 L .51961 .3852 L p .808 .627 .657 r
F P
0 g
s
.71773 .14227 m .71915 .13503 L .72543 .13835 L p .47 .567 .871 r
F P
0 g
s
.72543 .13835 m .72611 .14672 L .71773 .14227 L p .47 .567 .871 r
F P
0 g
s
.56665 .87831 m .64435 .89631 L .64176 .89998 L p .578 .067 .002 r
F P
0 g
s
.64176 .89998 m .5606 .88498 L .56665 .87831 L p .578 .067 .002 r
F P
0 g
s
.70636 .12762 m .70068 .13237 L .69274 .12733 L p .54 .658 .913 r
F P
0 g
s
.70068 .13237 m .70636 .12762 L .7127 .1314 L p .525 .629 .897 r
F P
0 g
s
.38965 .37235 m .36596 .36409 L .36289 .35663 L p .36 .623 .953 r
F P
0 g
s
.33002 .34599 m .36289 .35663 L .36596 .36409 L p .409 .659 .962 r
F P
0 g
s
.73129 .55477 m .77324 .60455 L .76555 .60527 L p .037 .319 .805 r
F P
0 g
s
.76555 .60527 m .72492 .55549 L .73129 .55477 L p .037 .319 .805 r
F P
0 g
s
.45674 .47104 m .44909 .48524 L .44603 .47695 L p .315 .177 .528 r
F P
0 g
s
.44603 .47695 m .45419 .46438 L .45674 .47104 L p .315 .177 .528 r
F P
0 g
s
.59793 .48766 m .60299 .49514 L .5938 .4966 L p .648 .698 .883 r
F P
0 g
s
.5938 .4966 m .59051 .48881 L .59793 .48766 L p .648 .698 .883 r
F P
0 g
s
.45596 .41904 m .44808 .4222 L .44448 .41337 L p .594 .539 .763 r
F P
0 g
s
.45912 .42683 m .45169 .43114 L .44808 .4222 L p .578 .499 .73 r
F P
0 g
s
.44808 .4222 m .45596 .41904 L .45912 .42683 L p .578 .499 .73 r
F P
0 g
s
.75862 .20797 m .75641 .18726 L .76315 .18924 L p .255 .282 .697 r
F P
0 g
s
.76315 .18924 m .76665 .21044 L .75862 .20797 L p .255 .282 .697 r
F P
0 g
s
.51327 .37372 m .50788 .37799 L .50277 .36908 L p .835 .672 .681 r
F P
0 g
s
.50277 .36908 m .50706 .36392 L .51327 .37372 L p .835 .672 .681 r
F P
0 g
s
.5024 .33553 m .50471 .32743 L .51099 .33482 L p .926 .774 .674 r
F P
0 g
s
.51099 .33482 m .50798 .34259 L .5024 .33553 L p .926 .774 .674 r
F P
0 g
s
.46105 .4547 m .45419 .46438 L .45097 .45607 L p .435 .305 .605 r
F P
0 g
s
.45097 .45607 m .45833 .44777 L .46105 .4547 L p .435 .305 .605 r
F P
0 g
s
.46214 .43434 m .45516 .4398 L .45169 .43114 L p .555 .454 .694 r
F P
0 g
s
.45169 .43114 m .45912 .42683 L .46214 .43434 L p .555 .454 .694 r
F P
0 g
s
.51124 .35813 m .50706 .36392 L .50166 .35587 L p .874 .719 .687 r
F P
0 g
s
.50166 .35587 m .50491 .34952 L .51124 .35813 L p .874 .719 .687 r
F P
0 g
s
.08563 .44766 m .07017 .47332 L .06941 .4691 L p .971 .896 .692 r
F P
0 g
s
.06941 .4691 m .08411 .43974 L .08563 .44766 L p .971 .896 .692 r
F P
0 g
s
.59822 .13424 m .61856 .1234 L .62436 .12901 L p .757 .877 .933 r
F P
0 g
s
.6432 .12104 m .62436 .12901 L .61856 .1234 L p .699 .861 .959 r
F P
0 g
s
.44448 .41337 m .45279 .41131 L .45596 .41904 L p .594 .539 .763 r
F P
0 g
s
.45279 .41131 m .44448 .41337 L .44105 .40499 L p .602 .575 .796 r
F P
0 g
s
.57846 .42363 m .57775 .41743 L .59025 .41739 L p .672 .433 .552 r
F P
0 g
s
.57775 .41743 m .57846 .42363 L .56809 .42533 L p .705 .467 .562 r
F P
0 g
s
.56809 .42533 m .56503 .41935 L .57775 .41743 L p .705 .467 .562 r
F P
0 g
s
.6195 .40897 m .62517 .40346 L .63438 .40558 L p .5 .184 .362 r
F P
0 g
s
.64178 .39996 m .63438 .40558 L .62517 .40346 L p .507 .191 .367 r
F P
0 g
s
.53396 .41047 m .52609 .40875 L .52445 .3977 L p .768 .541 .59 r
F P
0 g
s
.52445 .3977 m .51683 .39855 L .51289 .38806 L p .786 .586 .63 r
F P
0 g
s
.51683 .39855 m .52445 .3977 L .52609 .40875 L p .769 .549 .6 r
F P
0 g
s
.56479 .50129 m .56723 .49245 L .57482 .49125 L p .756 .774 .868 r
F P
0 g
s
.56723 .49245 m .56479 .50129 L .55601 .50273 L p .789 .81 .869 r
F P
0 g
s
.65032 .39354 m .66004 .38613 L .66808 .38851 L p .376 .023 .232 r
F P
0 g
s
.67957 .38017 m .66808 .38851 L .66004 .38613 L p .379 .038 .256 r
F P
0 g
s
.50432 .30178 m .5066 .28949 L .51236 .29558 L p .976 .834 .637 r
F P
0 g
s
.51236 .29558 m .50956 .30759 L .50432 .30178 L p .976 .834 .637 r
F P
0 g
s
.42839 .54411 m .40391 .581 L .40259 .57368 L p 0 0 .095 r
F P
0 g
s
.40259 .57368 m .42708 .53875 L .42839 .54411 L p 0 0 .095 r
F P
0 g
s
.72611 .14672 m .72543 .13835 L .73128 .14121 L p .427 .532 .861 r
F P
0 g
s
.73128 .14121 m .73392 .15056 L .72611 .14672 L p .427 .532 .861 r
F P
0 g
s
.45117 .49108 m .44156 .51155 L .43905 .50402 L p .134 0 .39 r
F P
0 g
s
.43905 .50402 m .44909 .48524 L .45117 .49108 L p .134 0 .39 r
F P
0 g
s
.28536 .33779 m .22835 .3391 L .22509 .33266 L p .48 .82 .999 r
F P
0 g
s
.22835 .3391 m .1662 .35792 L .16301 .35188 L p .648 .92 .977 r
F P
0 g
s
.16301 .35188 m .22509 .33266 L .22835 .3391 L p .648 .92 .977 r
F P
0 g
s
.61949 .40898 m .6146 .41408 L .6045 .41262 L p .584 .31 .466 r
F P
0 g
s
.60121 .4181 m .6045 .41262 L .6146 .41408 L p .579 .309 .471 r
F P
0 g
s
.6045 .41262 m .60121 .4181 L .59025 .41739 L p .636 .384 .52 r
F P
0 g
s
.70039 .12384 m .69274 .12733 L .68563 .12251 L p .547 .687 .931 r
F P
0 g
s
.69274 .12733 m .70039 .12384 L .70636 .12762 L p .54 .658 .913 r
F P
0 g
s
.51731 .53629 m .53194 .51785 L .53994 .51641 L p .846 .922 .883 r
F P
0 g
s
.53194 .51785 m .51731 .53629 L .50964 .53787 L p .855 .981 .86 r
F P
0 g
s
.48721 .56793 m .50964 .53787 L .51731 .53629 L p .884 .968 .84 r
F P
0 g
s
.58896 .42311 m .59025 .41739 L .60121 .4181 L p .629 .383 .525 r
F P
0 g
s
.59025 .41739 m .58896 .42311 L .57846 .42363 L p .672 .433 .552 r
F P
0 g
s
.53994 .51641 m .54839 .50399 L .55601 .50273 L p .816 .867 .885 r
F P
0 g
s
.54839 .50399 m .53994 .51641 L .53194 .51785 L p .845 .923 .884 r
F P
0 g
s
.60467 .48662 m .61131 .49383 L .60299 .49514 L p .601 .678 .895 r
F P
0 g
s
.60299 .49514 m .59793 .48766 L .60467 .48662 L p .601 .678 .895 r
F P
0 g
s
.42721 .39667 m .43791 .39741 L .44105 .40499 L p .57 .593 .837 r
F P
0 g
s
.43791 .39741 m .42721 .39667 L .42409 .3891 L p .555 .625 .876 r
F P
0 g
s
.41048 .38586 m .42409 .3891 L .42721 .39667 L p .522 .606 .878 r
F P
0 g
s
.46487 .44122 m .45833 .44777 L .45516 .4398 L p .52 .397 .653 r
F P
0 g
s
.45516 .4398 m .46214 .43434 L .46487 .44122 L p .52 .397 .653 r
F P
0 g
s
.50676 .39062 m .51289 .38806 L .51683 .39855 L p .782 .592 .643 r
F P
0 g
s
.51289 .38806 m .50676 .39062 L .50264 .38173 L p .803 .632 .67 r
F P
0 g
s
.50264 .38173 m .50788 .37799 L .51289 .38806 L p .803 .632 .67 r
F P
0 g
s
.56503 .41935 m .56809 .42533 L .55936 .42816 L p .728 .483 .557 r
F P
0 g
s
.55936 .42816 m .55507 .42336 L .56503 .41935 L p .728 .483 .557 r
F P
0 g
s
.42409 .3891 m .41048 .38586 L .40753 .3787 L p .477 .63 .92 r
F P
0 g
s
.38965 .37235 m .40753 .3787 L .41048 .38586 L p .455 .616 .919 r
F P
0 g
s
.50798 .34259 m .50491 .34952 L .50001 .34284 L p .922 .776 .681 r
F P
0 g
s
.50001 .34284 m .5024 .33554 L .50798 .34259 L p .922 .776 .681 r
F P
0 g
s
.44105 .40499 m .44975 .40395 L .45279 .41131 L p .602 .575 .796 r
F P
0 g
s
.44975 .40395 m .44105 .40499 L .43791 .39741 L p .603 .61 .831 r
F P
0 g
s
.74471 .16695 m .74081 .15363 L .74649 .1558 L p .326 .422 .807 r
F P
0 g
s
.74649 .1558 m .75203 .16978 L .74471 .16695 L p .326 .422 .807 r
F P
0 g
s
.1662 .35792 m .11408 .39383 L .1115 .38915 L p .798 .979 .902 r
F P
0 g
s
.1115 .38915 m .16301 .35188 L .1662 .35792 L p .798 .979 .902 r
F P
0 g
s
.53396 .41047 m .54214 .41373 L .53794 .42117 L p .755 .502 .549 r
F P
0 g
s
.54214 .41373 m .54941 .41836 L .54352 .42421 L p .746 .49 .544 r
F P
0 g
s
.54352 .42421 m .53795 .42117 L .54214 .41373 L p .746 .49 .544 r
F P
0 g
s
.50788 .37799 m .50264 .38173 L .4984 .37369 L p .828 .676 .694 r
F P
0 g
s
.4984 .37369 m .50277 .36908 L .50788 .37799 L p .828 .676 .694 r
F P
0 g
s
.50706 .36392 m .50277 .36908 L .49821 .36164 L p .868 .724 .7 r
F P
0 g
s
.49821 .36164 m .50166 .35587 L .50706 .36392 L p .868 .724 .7 r
F P
0 g
s
.6432 .12104 m .66032 .11637 L .66623 .12122 L p .654 .788 .946 r
F P
0 g
s
.67965 .11811 m .66623 .12122 L .66032 .11637 L p .593 .77 .964 r
F P
0 g
s
.66623 .12122 m .67965 .11811 L .68563 .12251 L p .603 .732 .936 r
F P
0 g
s
.52609 .40875 m .51896 .40811 L .51683 .39855 L p .769 .549 .6 r
F P
0 g
s
.51683 .39855 m .51017 .39971 L .50676 .39062 L p .782 .592 .643 r
F P
0 g
s
.51017 .39971 m .51683 .39855 L .51896 .40811 L p .764 .554 .613 r
F P
0 g
s
.53794 .42117 m .53197 .41871 L .53396 .41047 L p .755 .502 .549 r
F P
0 g
s
.52609 .40875 m .53396 .41047 L .53197 .41871 L p .757 .508 .556 r
F P
0 g
s
.50233 .31262 m .50432 .30178 L .50956 .30759 L p .977 .834 .633 r
F P
0 g
s
.50956 .30759 m .50706 .31816 L .50233 .31262 L p .977 .834 .633 r
F P
0 g
s
.33002 .34599 m .28536 .33779 L .28245 .33181 L p .325 .708 .981 r
F P
0 g
s
.22509 .33266 m .28245 .33181 L .28536 .33779 L p .48 .82 .999 r
F P
0 g
s
.64178 .39996 m .65032 .39354 L .6578 .39555 L p .371 .01 .215 r
F P
0 g
s
.66808 .38851 m .6578 .39555 L .65032 .39354 L p .376 .023 .232 r
F P
0 g
s
.1995 .65782 m .12444 .62131 L .12693 .61407 L p .744 .27 .121 r
F P
0 g
s
.0854 .56953 m .12693 .61407 L .12444 .62131 L p .887 .465 .18 r
F P
0 g
s
.12693 .61407 m .0854 .56953 L .08696 .56238 L p .9 .548 .367 r
F P
0 g
s
.63438 .40558 m .62801 .41058 L .6195 .40897 L p .5 .184 .362 r
F P
0 g
s
.6146 .41408 m .61949 .40898 L .62801 .41059 L p .501 .195 .38 r
F P
0 g
s
.46302 .41615 m .45596 .41904 L .45279 .41131 L p .622 .552 .755 r
F P
0 g
s
.46585 .42315 m .45912 .42683 L .45596 .41904 L p .606 .512 .722 r
F P
0 g
s
.45596 .41904 m .46302 .41615 L .46585 .42315 L p .606 .512 .722 r
F P
0 g
s
.65001 .89113 m .69171 .88819 L .68955 .89032 L p .405 0 .031 r
F P
0 g
s
.68955 .89032 m .64435 .89631 L .65001 .89113 L p .405 0 .031 r
F P
0 g
s
.54941 .41836 m .55507 .42336 L .54854 .42768 L p .745 .486 .539 r
F P
0 g
s
.54854 .42768 m .54352 .42421 L .54941 .41836 L p .745 .486 .539 r
F P
0 g
s
.55601 .50273 m .56025 .49356 L .56723 .49245 L p .789 .81 .869 r
F P
0 g
s
.56025 .49356 m .55601 .50273 L .54839 .50399 L p .824 .855 .871 r
F P
0 g
s
.62414 .49184 m .63692 .5001 L .62973 .50124 L p .444 .647 .945 r
F P
0 g
s
.62973 .50124 m .61844 .49272 L .62414 .49184 L p .444 .647 .945 r
F P
0 g
s
.57914 .42906 m .57846 .42363 L .58896 .42311 L p .666 .433 .557 r
F P
0 g
s
.57846 .42363 m .57914 .42906 L .5704 .43053 L p .699 .465 .566 r
F P
0 g
s
.5704 .43053 m .56809 .42533 L .57846 .42363 L p .699 .465 .566 r
F P
0 g
s
.46852 .42987 m .46214 .43434 L .45912 .42683 L p .583 .467 .686 r
F P
0 g
s
.45912 .42683 m .46585 .42315 L .46852 .42987 L p .583 .467 .686 r
F P
0 g
s
.69379 .52631 m .73129 .55477 L .72492 .55549 L p .05 .424 .868 r
F P
0 g
s
.72492 .55549 m .68886 .52693 L .69379 .52631 L p .05 .424 .868 r
F P
0 g
s
.53197 .41871 m .52578 .41693 L .52609 .40875 L p .757 .508 .556 r
F P
0 g
s
.51896 .40811 m .52609 .40875 L .52578 .41693 L p .755 .512 .566 r
F P
0 g
s
.45279 .41131 m .46016 .40916 L .46302 .41615 L p .622 .552 .755 r
F P
0 g
s
.46016 .40916 m .45279 .41131 L .44975 .40395 L p .633 .59 .788 r
F P
0 g
s
.73392 .15056 m .73128 .14121 L .73644 .1435 L p .369 .49 .851 r
F P
0 g
s
.73644 .1435 m .74081 .15363 L .73392 .15056 L p .369 .49 .851 r
F P
0 g
s
.6146 .41408 m .61031 .41898 L .60121 .4181 L p .579 .309 .471 r
F P
0 g
s
.59852 .42328 m .60121 .4181 L .61031 .41898 L p .573 .31 .48 r
F P
0 g
s
.60121 .4181 m .59852 .42328 L .58896 .42311 L p .629 .383 .525 r
F P
0 g
s
.50102 .39303 m .50676 .39062 L .51017 .39971 L p .774 .595 .656 r
F P
0 g
s
.50676 .39062 m .50102 .39303 L .49751 .3851 L p .795 .635 .684 r
F P
0 g
s
.49751 .3851 m .50264 .38173 L .50676 .39062 L p .795 .635 .684 r
F P
0 g
s
.69505 .12022 m .68563 .12251 L .67965 .11811 L p .543 .717 .953 r
F P
0 g
s
.68563 .12251 m .69505 .12022 L .70039 .12384 L p .547 .687 .931 r
F P
0 g
s
.75641 .18726 m .75203 .16978 L .75746 .17133 L p .228 .31 .741 r
F P
0 g
s
.75746 .17133 m .76315 .18924 L .75641 .18726 L p .228 .31 .741 r
F P
0 g
s
.58161 .48315 m .58269 .49002 L .57482 .49125 L p .727 .723 .847 r
F P
0 g
s
.58811 .48216 m .59051 .48881 L .58269 .49002 L p .691 .698 .851 r
F P
0 g
s
.58269 .49002 m .58161 .48315 L .58811 .48216 L p .691 .698 .851 r
F P
0 g
s
.58806 .42835 m .58896 .42311 L .59852 .42328 L p .624 .385 .535 r
F P
0 g
s
.58896 .42311 m .58806 .42835 L .57914 .42906 L p .666 .433 .557 r
F P
0 g
s
.64204 .49932 m .66159 .51022 L .655 .51125 L p .299 .605 .952 r
F P
0 g
s
.655 .51125 m .63692 .5001 L .64204 .49932 L p .299 .605 .952 r
F P
0 g
s
.46722 .44717 m .46105 .4547 L .45833 .44777 L p .465 .319 .598 r
F P
0 g
s
.45833 .44777 m .46487 .44122 L .46722 .44717 L p .465 .319 .598 r
F P
0 g
s
.73332 .32621 m .74589 .30598 L .75234 .3072 L p .067 0 .226 r
F P
0 g
s
.74589 .30598 m .75626 .28323 L .76265 .28431 L p .055 0 .304 r
F P
0 g
s
.76265 .28431 m .75234 .3072 L .74589 .30598 L p .055 0 .304 r
F P
0 g
s
.40753 .3787 m .38965 .37235 L .38707 .36621 L p .354 .618 .951 r
F P
0 g
s
.36289 .35663 m .38707 .36621 L .38965 .37235 L p .36 .623 .953 r
F P
0 g
s
.56809 .42533 m .5704 .43053 L .56271 .43267 L p .724 .483 .562 r
F P
0 g
s
.56271 .43267 m .55936 .42816 L .56809 .42533 L p .724 .483 .562 r
F P
0 g
s
.06986 .53153 m .08696 .56238 L .0854 .56953 L p .969 .657 .362 r
F P
0 g
s
.08696 .56238 m .06986 .53153 L .0706 .52678 L p .966 .686 .451 r
F P
0 g
s
.4632 .46022 m .45674 .47104 L .45419 .46438 L p .339 .187 .524 r
F P
0 g
s
.45419 .46438 m .46105 .4547 L .4632 .46022 L p .339 .187 .524 r
F P
0 g
s
.61047 .48574 m .61844 .49272 L .61131 .49383 L p .539 .655 .911 r
F P
0 g
s
.61131 .49383 m .60467 .48662 L .61047 .48574 L p .539 .655 .911 r
F P
0 g
s
.50491 .34952 m .50166 .35587 L .4974 .3496 L p .917 .78 .695 r
F P
0 g
s
.4974 .3496 m .50001 .34284 L .50491 .34952 L p .917 .78 .695 r
F P
0 g
s
.61856 .1234 m .63835 .11629 L .6432 .12104 L p .699 .861 .959 r
F P
0 g
s
.66032 .11637 m .6432 .12104 L .63835 .11629 L p .633 .837 .979 r
F P
0 g
s
.51896 .40811 m .51245 .40818 L .51017 .39971 L p .764 .554 .613 r
F P
0 g
s
.51017 .39971 m .50406 .40112 L .50102 .39303 L p .774 .595 .656 r
F P
0 g
s
.50406 .40112 m .51017 .39971 L .51245 .40818 L p .757 .556 .625 r
F P
0 g
s
.71961 .34356 m .73332 .32621 L .73964 .3275 L p .077 0 .153 r
F P
0 g
s
.75234 .3072 m .73964 .3275 L .73332 .32621 L p .067 0 .226 r
F P
0 g
s
.57482 .49125 m .57508 .48416 L .58161 .48315 L p .727 .723 .847 r
F P
0 g
s
.57508 .48416 m .57482 .49125 L .56723 .49245 L p .761 .752 .845 r
F P
0 g
s
.75626 .28323 m .76349 .25883 L .76959 .25971 L p .043 0 .384 r
F P
0 g
s
.76959 .25971 m .76265 .28431 L .75626 .28323 L p .043 0 .384 r
F P
0 g
s
.50264 .38173 m .49751 .3851 L .49392 .37783 L p .818 .679 .709 r
F P
0 g
s
.49392 .37783 m .4984 .37369 L .50264 .38173 L p .818 .679 .709 r
F P
0 g
s
.55507 .42336 m .55936 .42816 L .55288 .43136 L p .745 .486 .539 r
F P
0 g
s
.55288 .43136 m .54854 .42768 L .55507 .42336 L p .745 .486 .539 r
F P
0 g
s
.50046 .32217 m .50233 .31262 L .50706 .31816 L p .977 .837 .637 r
F P
0 g
s
.50706 .31816 m .50471 .32743 L .50046 .32217 L p .977 .837 .637 r
F P
0 g
s
.59431 .48122 m .59793 .48766 L .59051 .48881 L p .652 .674 .859 r
F P
0 g
s
.59051 .48881 m .58811 .48216 L .59431 .48122 L p .652 .674 .859 r
F P
0 g
s
.50277 .36908 m .4984 .37369 L .49454 .36688 L p .859 .727 .716 r
F P
0 g
s
.49454 .36688 m .49821 .36164 L .50277 .36908 L p .859 .727 .716 r
F P
0 g
s
.80282 .68045 m .80042 .76487 L .79422 .76508 L p .008 0 .485 r
F P
0 g
s
.7691 .82738 m .79422 .76508 L .80042 .76487 L p .001 0 .255 r
F P
0 g
s
.79422 .76508 m .7691 .82738 L .76316 .82883 L p .203 .016 .39 r
F P
0 g
s
.53016 .20012 m .54214 .18017 L .54605 .18514 L p .928 .97 .754 r
F P
0 g
s
.54605 .18514 m .53408 .20498 L .53016 .20012 L p .928 .97 .754 r
F P
0 g
s
.56099 .16599 m .54605 .18514 L .54214 .18017 L p .893 .981 .812 r
F P
0 g
s
.47093 .436 m .46487 .44122 L .46214 .43434 L p .549 .41 .644 r
F P
0 g
s
.46214 .43434 m .46852 .42987 L .47093 .436 L p .549 .41 .644 r
F P
0 g
s
.50964 .53787 m .48721 .56793 L .48151 .56955 L p .828 .991 .735 r
F P
0 g
s
.45397 .62177 m .48151 .56955 L .48721 .56793 L p .915 .973 .683 r
F P
0 g
s
.52578 .41693 m .51965 .41585 L .51896 .40811 L p .755 .512 .566 r
F P
0 g
s
.51245 .40818 m .51896 .40811 L .51965 .41585 L p .749 .515 .576 r
F P
0 g
s
.63438 .40558 m .64178 .39996 L .64872 .4016 L p .364 0 .205 r
F P
0 g
s
.6578 .39555 m .64872 .4016 L .64178 .39996 L p .371 .01 .215 r
F P
0 g
s
.52108 .21984 m .53016 .20012 L .53408 .20498 L p .953 .953 .696 r
F P
0 g
s
.53408 .20498 m .5249 .22452 L .52108 .21984 L p .953 .953 .696 r
F P
0 g
s
.43791 .39741 m .44696 .39726 L .44975 .40395 L p .603 .61 .831 r
F P
0 g
s
.44696 .39726 m .43791 .39741 L .43519 .3909 L p .595 .646 .871 r
F P
0 g
s
.42409 .3891 m .43519 .3909 L .43791 .39741 L p .555 .625 .876 r
F P
0 g
s
.70567 .35812 m .71961 .34356 L .72566 .34487 L p .086 0 .087 r
F P
0 g
s
.73964 .3275 m .72566 .34487 L .71961 .34356 L p .077 0 .153 r
F P
0 g
s
.54214 .18017 m .55722 .16104 L .56099 .16599 L p .893 .981 .812 r
F P
0 g
s
.57864 .14866 m .56099 .16599 L .55722 .16104 L p .846 .982 .866 r
F P
0 g
s
.44975 .40395 m .4574 .40248 L .46016 .40916 L p .633 .59 .788 r
F P
0 g
s
.4574 .40248 m .44975 .40395 L .44696 .39726 L p .638 .627 .823 r
F P
0 g
s
.62801 .41059 m .62241 .41524 L .6146 .41408 L p .501 .195 .38 r
F P
0 g
s
.61031 .41898 m .6146 .41408 L .62241 .41524 L p .495 .196 .388 r
F P
0 g
s
.07183 .49933 m .06528 .49989 L .06523 .49678 L p .994 .819 .562 r
F P
0 g
s
.06523 .49678 m .07167 .49194 L .07183 .49933 L p .994 .819 .562 r
F P
0 g
s
.06528 .49989 m .07183 .49933 L .07181 .50684 L p .993 .805 .546 r
F P
0 g
s
.46951 .41347 m .46302 .41615 L .46016 .40916 L p .649 .564 .745 r
F P
0 g
s
.4721 .41998 m .46585 .42315 L .46302 .41615 L p .632 .524 .712 r
F P
0 g
s
.46302 .41615 m .46951 .41347 L .4721 .41998 L p .632 .524 .712 r
F P
0 g
s
.7127 .1314 m .71507 .12738 L .71973 .13 L p .449 .596 .905 r
F P
0 g
s
.71973 .13 m .71915 .13503 L .7127 .1314 L p .449 .596 .905 r
F P
0 g
s
.71507 .12738 m .7127 .1314 L .70636 .12762 L p .47 .623 .918 r
F P
0 g
s
.49549 .3954 m .50102 .39303 L .50406 .40112 L p .764 .596 .67 r
F P
0 g
s
.50102 .39303 m .49549 .3954 L .49241 .3882 L p .783 .636 .698 r
F P
0 g
s
.49241 .3882 m .49751 .3851 L .50102 .39303 L p .783 .636 .698 r
F P
0 g
s
.51444 .23861 m .52108 .21984 L .5249 .22452 L p .969 .933 .641 r
F P
0 g
s
.5249 .22452 m .51808 .24304 L .51444 .23861 L p .969 .933 .641 r
F P
0 g
s
.06525 .50301 m .07181 .50684 L .07159 .51413 L p .994 .791 .523 r
F P
0 g
s
.07181 .50684 m .06525 .50301 L .06528 .49989 L p .993 .805 .546 r
F P
0 g
s
.76349 .25883 m .76696 .23407 L .77254 .23474 L p .033 0 .463 r
F P
0 g
s
.77254 .23474 m .76959 .25971 L .76349 .25883 L p .033 0 .463 r
F P
0 g
s
.74007 .86058 m .76316 .82883 L .7691 .82738 L p .132 0 .155 r
F P
0 g
s
.76316 .82883 m .74007 .86058 L .73644 .8619 L p .233 0 .235 r
F P
0 g
s
.56723 .49245 m .5688 .48514 L .57508 .48416 L p .761 .752 .845 r
F P
0 g
s
.5688 .48514 m .56723 .49245 L .56025 .49356 L p .796 .788 .845 r
F P
0 g
s
.43519 .3909 m .42409 .3891 L .42157 .38307 L p .519 .655 .92 r
F P
0 g
s
.40753 .3787 m .42157 .38307 L .42409 .3891 L p .477 .63 .92 r
F P
0 g
s
.51245 .40818 m .50638 .40877 L .50406 .40112 L p .757 .556 .625 r
F P
0 g
s
.50406 .40112 m .49828 .40274 L .49549 .3954 L p .764 .596 .67 r
F P
0 g
s
.49828 .40274 m .50406 .40112 L .50638 .40877 L p .746 .557 .639 r
F P
0 g
s
.47453 .42619 m .46852 .42987 L .46585 .42315 L p .61 .478 .677 r
F P
0 g
s
.46585 .42315 m .4721 .41998 L .47453 .42619 L p .61 .478 .677 r
F P
0 g
s
.71915 .13503 m .71973 .13 L .72426 .13238 L p .419 .567 .895 r
F P
0 g
s
.72426 .13238 m .72543 .13835 L .71915 .13503 L p .419 .567 .895 r
F P
0 g
s
.07167 .49194 m .06523 .49678 L .06511 .49382 L p .994 .834 .573 r
F P
0 g
s
.06511 .49382 m .07133 .48496 L .07167 .49194 L p .994 .834 .573 r
F P
0 g
s
.57975 .434 m .57914 .42906 L .58806 .42835 L p .661 .437 .569 r
F P
0 g
s
.57914 .42906 m .57975 .434 L .5722 .43527 L p .695 .468 .576 r
F P
0 g
s
.5722 .43527 m .5704 .43053 L .57914 .42906 L p .695 .468 .576 r
F P
0 g
s
.45848 .4757 m .45117 .49108 L .44909 .48524 L p .135 0 .388 r
F P
0 g
s
.44909 .48524 m .45674 .47104 L .45848 .4757 L p .135 0 .388 r
F P
0 g
s
.7105 .12465 m .70636 .12762 L .70039 .12384 L p .481 .648 .931 r
F P
0 g
s
.70636 .12762 m .7105 .12465 L .71507 .12738 L p .47 .623 .918 r
F P
0 g
s
.46016 .40916 m .46686 .40694 L .46951 .41347 L p .649 .564 .745 r
F P
0 g
s
.46686 .40694 m .46016 .40916 L .4574 .40248 L p .662 .602 .778 r
F P
0 g
s
.51965 .41585 m .5137 .4154 L .51245 .40818 L p .749 .515 .576 r
F P
0 g
s
.50638 .40877 m .51245 .40818 L .5137 .4154 L p .74 .516 .589 r
F P
0 g
s
.44271 .51552 m .42839 .54411 L .42708 .53875 L p 0 0 .109 r
F P
0 g
s
.42708 .53875 m .44156 .51155 L .44271 .51552 L p 0 0 .109 r
F P
0 g
s
.36289 .35663 m .33002 .34599 L .3276 .34089 L p .212 .618 .951 r
F P
0 g
s
.28245 .33181 m .3276 .34089 L .33002 .34599 L p .325 .708 .981 r
F P
0 g
s
.69218 .37018 m .70567 .35812 L .71138 .35938 L p .093 0 .03 r
F P
0 g
s
.72566 .34487 m .71138 .35938 L .70567 .35812 L p .086 0 .087 r
F P
0 g
s
.59996 .48037 m .60467 .48662 L .59793 .48766 L p .606 .652 .869 r
F P
0 g
s
.59793 .48766 m .59431 .48122 L .59996 .48037 L p .606 .652 .869 r
F P
0 g
s
.61031 .41898 m .60661 .4237 L .59852 .42328 L p .573 .31 .48 r
F P
0 g
s
.59634 .42817 m .59852 .42328 L .60661 .4237 L p .567 .315 .494 r
F P
0 g
s
.59852 .42328 m .59634 .42817 L .58806 .42835 L p .624 .385 .535 r
F P
0 g
s
.55722 .16104 m .57513 .1439 L .57864 .14866 L p .846 .982 .866 r
F P
0 g
s
.59822 .13424 m .57864 .14866 L .57513 .1439 L p .789 .972 .913 r
F P
0 g
s
.55936 .42816 m .56271 .43267 L .55654 .43511 L p .746 .491 .546 r
F P
0 g
s
.55654 .43511 m .55288 .43136 L .55936 .42816 L p .746 .491 .546 r
F P
0 g
s
.50166 .35587 m .49821 .36164 L .49454 .35583 L p .909 .786 .712 r
F P
0 g
s
.49454 .35583 m .4974 .3496 L .50166 .35587 L p .909 .786 .712 r
F P
0 g
s
.49751 .3851 m .49241 .3882 L .4893 .38157 L p .806 .68 .725 r
F P
0 g
s
.4893 .38157 m .49392 .37783 L .49751 .3851 L p .806 .68 .725 r
F P
0 g
s
.5704 .43053 m .5722 .43527 L .56537 .43697 L p .723 .489 .572 r
F P
0 g
s
.56537 .43697 m .56271 .43267 L .5704 .43053 L p .723 .489 .572 r
F P
0 g
s
.49861 .33055 m .50046 .32217 L .50471 .32743 L p .975 .842 .647 r
F P
0 g
s
.50471 .32743 m .5024 .33553 L .49861 .33055 L p .975 .842 .647 r
F P
0 g
s
.50967 .25596 m .51444 .23861 L .51808 .24304 L p .978 .912 .594 r
F P
0 g
s
.51808 .24304 m .51309 .26014 L .50967 .25596 L p .978 .912 .594 r
F P
0 g
s
.58741 .43323 m .58806 .42835 L .59634 .42817 L p .619 .391 .549 r
F P
0 g
s
.58806 .42835 m .58741 .43323 L .57975 .434 L p .661 .437 .569 r
F P
0 g
s
.4984 .37369 m .49392 .37783 L .49063 .3716 L p .848 .73 .734 r
F P
0 g
s
.49063 .3716 m .49454 .36688 L .4984 .37369 L p .848 .73 .734 r
F P
0 g
s
.08411 .43974 m .06941 .4691 L .06857 .46617 L p .972 .925 .674 r
F P
0 g
s
.06857 .46617 m .08248 .43421 L .08411 .43974 L p .972 .925 .674 r
F P
0 g
s
.06514 .50603 m .07159 .51413 L .07118 .52089 L p .995 .777 .493 r
F P
0 g
s
.07159 .51413 m .06514 .50603 L .06525 .50301 L p .994 .791 .523 r
F P
0 g
s
.53509 .42637 m .53017 .42443 L .53197 .41871 L p .753 .471 .506 r
F P
0 g
s
.53197 .41871 m .53794 .42117 L .53509 .42637 L p .753 .471 .506 r
F P
0 g
s
.52578 .41693 m .53197 .41871 L .53017 .42443 L p .749 .472 .511 r
F P
0 g
s
.53795 .42117 m .54352 .42421 L .53976 .42869 L p .75 .469 .505 r
F P
0 g
s
.53976 .42869 m .53509 .42637 L .53795 .42117 L p .75 .469 .505 r
F P
0 g
s
.49004 .39774 m .49549 .3954 L .49828 .40274 L p .751 .595 .684 r
F P
0 g
s
.49549 .3954 m .49004 .39774 L .48725 .39109 L p .77 .636 .713 r
F P
0 g
s
.48725 .39109 m .49241 .3882 L .49549 .3954 L p .77 .636 .713 r
F P
0 g
s
.62801 .41058 m .63438 .40558 L .6408 .40689 L p .357 0 .201 r
F P
0 g
s
.64872 .4016 m .6408 .40689 L .63438 .40558 L p .364 0 .205 r
F P
0 g
s
.50638 .40877 m .50058 .40977 L .49828 .40274 L p .746 .557 .639 r
F P
0 g
s
.49828 .40274 m .49266 .40454 L .49004 .39774 L p .751 .595 .684 r
F P
0 g
s
.49266 .40454 m .49828 .40274 L .50058 .40977 L p .733 .555 .652 r
F P
0 g
s
.54839 .50399 m .55422 .49452 L .56025 .49356 L p .824 .855 .871 r
F P
0 g
s
.55422 .49452 m .54839 .50399 L .5423 .50501 L p .856 .913 .87 r
F P
0 g
s
.53194 .51785 m .5423 .50501 L .54839 .50399 L p .845 .923 .884 r
F P
0 g
s
.4756 .41098 m .46951 .41347 L .46686 .40694 L p .674 .574 .735 r
F P
0 g
s
.47804 .41723 m .4721 .41998 L .46951 .41347 L p .657 .534 .702 r
F P
0 g
s
.46951 .41347 m .4756 .41098 L .47804 .41723 L p .657 .534 .702 r
F P
0 g
s
.47298 .44127 m .46722 .44717 L .46487 .44122 L p .499 .334 .589 r
F P
0 g
s
.46487 .44122 m .47093 .436 L .47298 .44127 L p .499 .334 .589 r
F P
0 g
s
.47668 .43183 m .47093 .436 L .46852 .42987 L p .579 .423 .634 r
F P
0 g
s
.46852 .42987 m .47453 .42619 L .47668 .43183 L p .579 .423 .634 r
F P
0 g
s
.5137 .4154 m .50795 .41551 L .50638 .40877 L p .74 .516 .589 r
F P
0 g
s
.50058 .40977 m .50638 .40877 L .50795 .41551 L p .728 .515 .602 r
F P
0 g
s
.72543 .13835 m .72426 .13238 L .72847 .13444 L p .377 .534 .885 r
F P
0 g
s
.72847 .13444 m .73128 .14121 L .72543 .13835 L p .377 .534 .885 r
F P
0 g
s
.53017 .42443 m .52498 .42288 L .52578 .41693 L p .749 .472 .511 r
F P
0 g
s
.51965 .41585 m .52578 .41693 L .52498 .42288 L p .743 .471 .519 r
F P
0 g
s
.70619 .12193 m .70039 .12384 L .69505 .12022 L p .483 .672 .947 r
F P
0 g
s
.70039 .12384 m .70619 .12193 L .7105 .12465 L p .481 .648 .931 r
F P
0 g
s
.54352 .42421 m .54854 .42768 L .54417 .43136 L p .755 .471 .503 r
F P
0 g
s
.54417 .43136 m .53976 .42869 L .54352 .42421 L p .755 .471 .503 r
F P
0 g
s
.4574 .40248 m .46427 .40068 L .46686 .40694 L p .662 .602 .778 r
F P
0 g
s
.46427 .40068 m .4574 .40248 L .45485 .3964 L p .671 .642 .813 r
F P
0 g
s
.44696 .39726 m .45485 .3964 L .4574 .40248 L p .638 .627 .823 r
F P
0 g
s
.07133 .48496 m .06511 .49382 L .06491 .49114 L p .996 .849 .577 r
F P
0 g
s
.06491 .49114 m .07082 .47867 L .07133 .48496 L p .996 .849 .577 r
F P
0 g
s
.5423 .50501 m .53194 .51785 L .52634 .51888 L p .852 .982 .861 r
F P
0 g
s
.50964 .53787 m .52634 .51888 L .53194 .51785 L p .855 .981 .86 r
F P
0 g
s
.76696 .23407 m .76665 .21044 L .77154 .2109 L p .023 .042 .539 r
F P
0 g
s
.77154 .2109 m .77254 .23474 L .76696 .23407 L p .023 .042 .539 r
F P
0 g
s
.62241 .41524 m .61739 .41974 L .61031 .41898 L p .495 .196 .388 r
F P
0 g
s
.60661 .4237 m .61031 .41898 L .61739 .41974 L p .489 .2 .402 r
F P
0 g
s
.67957 .38017 m .69218 .37018 L .6975 .37134 L p .097 0 0 r
F P
0 g
s
.71138 .35938 m .6975 .37134 L .69218 .37018 L p .093 0 .03 r
F P
0 g
s
.11408 .39383 m .08248 .43421 L .0808 .43126 L p .903 .984 .776 r
F P
0 g
s
.0808 .43126 m .1115 .38915 L .11408 .39383 L p .903 .984 .776 r
F P
0 g
s
.48028 .42316 m .47453 .42619 L .4721 .41998 L p .635 .488 .666 r
F P
0 g
s
.4721 .41998 m .47804 .41723 L .48028 .42316 L p .635 .488 .666 r
F P
0 g
s
.46686 .40694 m .47307 .40467 L .4756 .41098 L p .674 .574 .735 r
F P
0 g
s
.47307 .40467 m .46686 .40694 L .46427 .40068 L p .689 .613 .767 r
F P
0 g
s
.71551 .87233 m .71797 .87743 L .71612 .87853 L p .271 0 .083 r
F P
0 g
s
.71612 .87853 m .70974 .87571 L .71551 .87233 L p .271 0 .083 r
F P
0 g
s
.71797 .87743 m .71551 .87233 L .7213 .86913 L p .258 0 .089 r
F P
0 g
s
.74081 .15363 m .73644 .1435 L .74067 .14509 L p .287 .436 .837 r
F P
0 g
s
.74067 .14509 m .74649 .1558 L .74081 .15363 L p .287 .436 .837 r
F P
0 g
s
.45485 .3964 m .44696 .39726 L .44454 .39152 L p .636 .667 .863 r
F P
0 g
s
.43519 .3909 m .44454 .39152 L .44696 .39726 L p .595 .646 .871 r
F P
0 g
s
.66032 .11637 m .67506 .11433 L .67965 .11811 L p .593 .77 .964 r
F P
0 g
s
.69057 .11692 m .67965 .11811 L .67506 .11433 L p .524 .744 .975 r
F P
0 g
s
.67965 .11811 m .69057 .11692 L .69505 .12022 L p .543 .717 .953 r
F P
0 g
s
.50624 .2717 m .50967 .25596 L .51309 .26014 L p .983 .894 .555 r
F P
0 g
s
.51309 .26014 m .50941 .27563 L .50624 .2717 L p .983 .894 .555 r
F P
0 g
s
.46906 .45189 m .4632 .46022 L .46105 .4547 L p .374 .203 .516 r
F P
0 g
s
.46105 .4547 m .46722 .44717 L .46906 .45189 L p .374 .203 .516 r
F P
0 g
s
.49241 .3882 m .48725 .39109 L .48449 .38496 L p .791 .679 .741 r
F P
0 g
s
.48449 .38496 m .4893 .38157 L .49241 .3882 L p .791 .679 .741 r
F P
0 g
s
.52498 .42288 m .51965 .4218 L .51965 .41585 L p .743 .471 .519 r
F P
0 g
s
.5137 .4154 m .51965 .41585 L .51965 .4218 L p .734 .47 .529 r
F P
0 g
s
.70974 .87571 m .71612 .87853 L .71438 .87963 L p .275 0 .066 r
F P
0 g
s
.71438 .87963 m .70423 .87914 L .70974 .87571 L p .275 0 .066 r
F P
0 g
s
.50058 .40977 m .49495 .41113 L .49266 .40454 L p .733 .555 .652 r
F P
0 g
s
.49266 .40454 m .48708 .40652 L .48456 .40006 L p .735 .593 .697 r
F P
0 g
s
.48456 .40006 m .49004 .39774 L .49266 .40454 L p .735 .593 .697 r
F P
0 g
s
.48708 .40652 m .49266 .40454 L .49495 .41113 L p .717 .553 .665 r
F P
0 g
s
.5807 .4771 m .58161 .48315 L .57508 .48416 L p .73 .697 .819 r
F P
0 g
s
.58632 .47624 m .58811 .48216 L .58161 .48315 L p .694 .671 .823 r
F P
0 g
s
.58161 .48315 m .5807 .4771 L .58632 .47624 L p .694 .671 .823 r
F P
0 g
s
.49004 .39774 m .48456 .40006 L .48195 .39379 L p .753 .633 .727 r
F P
0 g
s
.48195 .39379 m .48725 .39109 L .49004 .39774 L p .753 .633 .727 r
F P
0 g
s
.56025 .49356 m .56305 .48604 L .5688 .48514 L p .796 .788 .845 r
F P
0 g
s
.56305 .48604 m .56025 .49356 L .55422 .49452 L p .834 .834 .847 r
F P
0 g
s
.57513 .1439 m .5951 .12982 L .59822 .13424 L p .789 .972 .913 r
F P
0 g
s
.61856 .1234 m .59822 .13424 L .5951 .12982 L p .721 .951 .951 r
F P
0 g
s
.48142 .40867 m .4756 .41098 L .47307 .40467 L p .697 .582 .723 r
F P
0 g
s
.48376 .41486 m .47804 .41723 L .4756 .41098 L p .679 .542 .69 r
F P
0 g
s
.4756 .41098 m .48142 .40867 L .48376 .41486 L p .679 .542 .69 r
F P
0 g
s
.56271 .43267 m .56537 .43697 L .55962 .43888 L p .747 .5 .557 r
F P
0 g
s
.55962 .43888 m .55654 .43511 L .56271 .43267 L p .747 .5 .557 r
F P
0 g
s
.50795 .41551 m .50234 .41611 L .50058 .40977 L p .728 .515 .602 r
F P
0 g
s
.49495 .41113 m .50058 .40977 L .50234 .41611 L p .714 .513 .615 r
F P
0 g
s
.42157 .38307 m .40753 .3787 L .40538 .37362 L p .383 .638 .956 r
F P
0 g
s
.38707 .36621 m .40538 .37362 L .40753 .3787 L p .354 .618 .951 r
F P
0 g
s
.71983 .87639 m .7213 .86913 L .72686 .86626 L p .237 0 .084 r
F P
0 g
s
.7213 .86913 m .71983 .87639 L .71797 .87743 L p .258 0 .089 r
F P
0 g
s
.58028 .43864 m .57975 .434 L .58741 .43323 L p .658 .446 .585 r
F P
0 g
s
.57975 .434 m .58028 .43864 L .57366 .43975 L p .693 .477 .59 r
F P
0 g
s
.57366 .43975 m .5722 .43527 L .57975 .434 L p .693 .477 .59 r
F P
0 g
s
.54854 .42768 m .55288 .43136 L .54823 .43431 L p .76 .478 .506 r
F P
0 g
s
.54823 .43431 m .54417 .43136 L .54854 .42768 L p .76 .478 .506 r
F P
0 g
s
.6151 .48504 m .62414 .49184 L .61844 .49272 L p .451 .626 .927 r
F P
0 g
s
.61844 .49272 m .61047 .48574 L .6151 .48504 L p .451 .626 .927 r
F P
0 g
s
.57508 .48416 m .57507 .47797 L .5807 .4771 L p .73 .697 .819 r
F P
0 g
s
.57507 .47797 m .57508 .48416 L .5688 .48514 L p .765 .727 .817 r
F P
0 g
s
.75203 .16978 m .74649 .1558 L .75069 .15695 L p .2 .338 .78 r
F P
0 g
s
.75069 .15695 m .75746 .17133 L .75203 .16978 L p .2 .338 .78 r
F P
0 g
s
.49821 .36164 m .49454 .36688 L .4914 .36151 L p .898 .79 .733 r
F P
0 g
s
.4914 .36151 m .49454 .35583 L .49821 .36164 L p .898 .79 .733 r
F P
0 g
s
.5024 .33554 m .50001 .34284 L .49665 .33814 L p .971 .846 .66 r
F P
0 g
s
.49665 .33814 m .49861 .33055 L .5024 .33554 L p .971 .846 .66 r
F P
0 g
s
.49392 .37783 m .4893 .38157 L .48646 .37585 L p .833 .731 .752 r
F P
0 g
s
.48646 .37585 m .49063 .3716 L .49392 .37783 L p .833 .731 .752 r
F P
0 g
s
.49495 .41113 m .48937 .41283 L .48708 .40652 L p .717 .553 .665 r
F P
0 g
s
.48708 .40652 m .48142 .40867 L .47893 .40238 L p .717 .588 .71 r
F P
0 g
s
.47893 .40238 m .48456 .40006 L .48708 .40652 L p .717 .588 .71 r
F P
0 g
s
.48142 .40867 m .48708 .40652 L .48937 .41283 L p .7 .548 .678 r
F P
0 g
s
.47307 .40467 m .47893 .40238 L .48142 .40867 L p .697 .582 .723 r
F P
0 g
s
.47893 .40238 m .47307 .40467 L .47056 .3986 L p .713 .622 .754 r
F P
0 g
s
.46427 .40068 m .47056 .3986 L .47307 .40467 L p .689 .613 .767 r
F P
0 g
s
.5917 .47543 m .59431 .48122 L .58811 .48216 L p .655 .647 .829 r
F P
0 g
s
.58811 .48216 m .58632 .47624 L .5917 .47543 L p .655 .647 .829 r
F P
0 g
s
.5722 .43527 m .57366 .43975 L .56753 .44114 L p .723 .499 .587 r
F P
0 g
s
.56753 .44114 m .56537 .43697 L .5722 .43527 L p .723 .499 .587 r
F P
0 g
s
.48937 .41283 m .48376 .41486 L .48142 .40867 L p .7 .548 .678 r
F P
0 g
s
.66534 .50972 m .69379 .52631 L .68886 .52693 L p .059 .48 .889 r
F P
0 g
s
.68886 .52693 m .66159 .51022 L .66534 .50972 L p .059 .48 .889 r
F P
0 g
s
.48586 .42068 m .48028 .42316 L .47804 .41723 L p .658 .497 .654 r
F P
0 g
s
.47804 .41723 m .48376 .41486 L .48586 .42068 L p .658 .497 .654 r
F P
0 g
s
.63835 .11629 m .65642 .11251 L .66032 .11637 L p .633 .837 .979 r
F P
0 g
s
.67506 .11433 m .66032 .11637 L .65642 .11251 L p .559 .805 .991 r
F P
0 g
s
.48456 .40006 m .47893 .40238 L .47642 .3963 L p .734 .629 .741 r
F P
0 g
s
.47642 .3963 m .48195 .39379 L .48456 .40006 L p .734 .629 .741 r
F P
0 g
s
.60661 .4237 m .60346 .42827 L .59634 .42817 L p .567 .315 .494 r
F P
0 g
s
.5946 .43285 m .59634 .42817 L .60346 .42827 L p .562 .325 .513 r
F P
0 g
s
.59634 .42817 m .5946 .43285 L .58741 .43323 L p .619 .391 .549 r
F P
0 g
s
.51965 .4218 m .51429 .42121 L .5137 .4154 L p .734 .47 .529 r
F P
0 g
s
.50795 .41551 m .5137 .4154 L .51429 .42121 L p .723 .469 .541 r
F P
0 g
s
.60482 .47964 m .61047 .48574 L .60467 .48662 L p .545 .626 .883 r
F P
0 g
s
.60467 .48662 m .59996 .48037 L .60482 .47964 L p .545 .626 .883 r
F P
0 g
s
.50234 .41611 m .49684 .41718 L .49495 .41113 L p .714 .513 .615 r
F P
0 g
s
.48937 .41283 m .49495 .41113 L .49684 .41718 L p .698 .509 .628 r
F P
0 g
s
.47056 .3986 m .47642 .3963 L .47893 .40238 L p .713 .622 .754 r
F P
0 g
s
.48224 .4285 m .47668 .43183 L .47453 .42619 L p .606 .434 .622 r
F P
0 g
s
.47453 .42619 m .48028 .42316 L .48224 .4285 L p .606 .434 .622 r
F P
0 g
s
.47056 .3986 m .46427 .40068 L .46186 .39496 L p .701 .654 .801 r
F P
0 g
s
.45485 .3964 m .46186 .39496 L .46427 .40068 L p .671 .642 .813 r
F P
0 g
s
.58696 .43786 m .58741 .43323 L .5946 .43285 L p .616 .402 .568 r
F P
0 g
s
.58741 .43323 m .58696 .43786 L .58028 .43864 L p .658 .446 .585 r
F P
0 g
s
.6408 .40689 m .63394 .41159 L .62801 .41058 L p .357 0 .201 r
F P
0 g
s
.62241 .41524 m .62801 .41059 L .63394 .41159 L p .358 .005 .223 r
F P
0 g
s
.44454 .39152 m .43519 .3909 L .433 .38571 L p .569 .684 .918 r
F P
0 g
s
.42157 .38307 m .433 .38571 L .43519 .3909 L p .519 .655 .92 r
F P
0 g
s
.48725 .39109 m .48195 .39379 L .47942 .388 L p .772 .676 .757 r
F P
0 g
s
.47942 .388 m .48449 .38496 L .48725 .39109 L p .772 .676 .757 r
F P
0 g
s
.06495 .50879 m .07118 .52089 L .0706 .52678 L p .996 .763 .455 r
F P
0 g
s
.07118 .52089 m .06495 .50879 L .06514 .50603 L p .995 .777 .493 r
F P
0 g
s
.66808 .38851 m .67957 .38017 L .6845 .38121 L p .098 0 0 r
F P
0 g
s
.6975 .37134 m .6845 .38121 L .67957 .38017 L p .097 0 0 r
F P
0 g
s
.70423 .87914 m .71438 .87963 L .71281 .88068 L p .27 0 .039 r
F P
0 g
s
.71281 .88068 m .69924 .88246 L .70423 .87914 L p .27 0 .039 r
F P
0 g
s
.49136 .4187 m .48586 .42068 L .48376 .41486 L p .679 .504 .641 r
F P
0 g
s
.48376 .41486 m .48937 .41283 L .49136 .4187 L p .679 .504 .641 r
F P
0 g
s
.49684 .41718 m .49136 .4187 L .48937 .41283 L p .698 .509 .628 r
F P
0 g
s
.50369 .2858 m .50624 .2717 L .50941 .27563 L p .984 .88 .528 r
F P
0 g
s
.50941 .27563 m .5066 .28949 L .50369 .2858 L p .984 .88 .528 r
F P
0 g
s
.62819 .49122 m .64204 .49932 L .63692 .5001 L p .301 .598 .948 r
F P
0 g
s
.63692 .5001 m .62414 .49184 L .62819 .49122 L p .301 .598 .948 r
F P
0 g
s
.55288 .43136 m .55654 .43511 L .55185 .43746 L p .765 .489 .515 r
F P
0 g
s
.55185 .43746 m .54823 .43431 L .55288 .43136 L p .765 .489 .515 r
F P
0 g
s
.51429 .42121 m .50894 .42112 L .50795 .41551 L p .723 .469 .541 r
F P
0 g
s
.50234 .41611 m .50795 .41551 L .50894 .42112 L p .709 .466 .555 r
F P
0 g
s
.4785 .43665 m .47298 .44127 L .47093 .436 L p .532 .348 .577 r
F P
0 g
s
.47093 .436 m .47668 .43183 L .4785 .43665 L p .532 .348 .577 r
F P
0 g
s
.5688 .48514 m .56968 .47881 L .57507 .47797 L p .765 .727 .817 r
F P
0 g
s
.56968 .47881 m .5688 .48514 L .56305 .48604 L p .802 .762 .816 r
F P
0 g
s
.72164 .87545 m .72686 .86626 L .73198 .86382 L p .207 0 .069 r
F P
0 g
s
.72686 .86626 m .72164 .87545 L .71983 .87639 L p .237 0 .084 r
F P
0 g
s
.73128 .14121 m .72847 .13444 L .73218 .13607 L p .321 .496 .875 r
F P
0 g
s
.73218 .13607 m .73644 .1435 L .73128 .14121 L p .321 .496 .875 r
F P
0 g
s
.70234 .11931 m .69505 .12022 L .69057 .11692 L p .473 .694 .964 r
F P
0 g
s
.69505 .12022 m .70234 .11931 L .70619 .12193 L p .483 .672 .947 r
F P
0 g
s
.47642 .3963 m .47056 .3986 L .4682 .39304 L p .728 .664 .787 r
F P
0 g
s
.46186 .39496 m .4682 .39304 L .47056 .3986 L p .701 .654 .801 r
F P
0 g
s
.48195 .39379 m .47642 .3963 L .47402 .3907 L p .751 .671 .773 r
F P
0 g
s
.47402 .3907 m .47942 .388 L .48195 .39379 L p .751 .671 .773 r
F P
0 g
s
.61739 .41974 m .61295 .42414 L .60661 .4237 L p .489 .2 .402 r
F P
0 g
s
.60346 .42827 m .60661 .4237 L .61295 .42414 L p .483 .209 .421 r
F P
0 g
s
.46186 .39496 m .45485 .3964 L .45263 .39116 L p .675 .685 .852 r
F P
0 g
s
.44454 .39152 m .45263 .39116 L .45485 .3964 L p .636 .667 .863 r
F P
0 g
s
.56537 .43697 m .56753 .44114 L .5622 .44268 L p .75 .514 .574 r
F P
0 g
s
.5622 .44268 m .55962 .43888 L .56537 .43697 L p .75 .514 .574 r
F P
0 g
s
.38707 .36621 m .36289 .35663 L .36093 .35242 L p .153 .568 .93 r
F P
0 g
s
.3276 .34089 m .36093 .35242 L .36289 .35663 L p .212 .618 .951 r
F P
0 g
s
.07082 .47867 m .06491 .49114 L .06464 .48885 L p .996 .863 .573 r
F P
0 g
s
.06464 .48885 m .07017 .47332 L .07082 .47867 L p .996 .863 .573 r
F P
0 g
s
.59661 .4747 m .59996 .48037 L .59431 .48122 L p .609 .622 .838 r
F P
0 g
s
.59431 .48122 m .5917 .47543 L .59661 .4747 L p .609 .622 .838 r
F P
0 g
s
.46467 .46405 m .45848 .4757 L .45674 .47104 L p .163 0 .382 r
F P
0 g
s
.45674 .47104 m .4632 .46022 L .46467 .46405 L p .163 0 .382 r
F P
0 g
s
.4893 .38157 m .48449 .38496 L .48198 .37964 L p .815 .73 .771 r
F P
0 g
s
.48198 .37964 m .48646 .37585 L .4893 .38157 L p .815 .73 .771 r
F P
0 g
s
.4682 .39304 m .47402 .3907 L .47642 .3963 L p .728 .664 .787 r
F P
0 g
s
.48766 .42589 m .48224 .4285 L .48028 .42316 L p .631 .443 .61 r
F P
0 g
s
.48028 .42316 m .48586 .42068 L .48766 .42589 L p .631 .443 .61 r
F P
0 g
s
.76665 .21044 m .76315 .18924 L .76724 .18954 L p .015 .1 .609 r
F P
0 g
s
.76724 .18954 m .77154 .2109 L .76665 .21044 L p .015 .1 .609 r
F P
0 g
s
.50894 .42112 m .50362 .42153 L .50234 .41611 L p .709 .466 .555 r
F P
0 g
s
.49684 .41718 m .50234 .41611 L .50362 .42153 L p .693 .462 .568 r
F P
0 g
s
.50001 .34284 m .4974 .3496 L .49446 .3452 L p .965 .854 .68 r
F P
0 g
s
.49446 .3452 m .49665 .33814 L .50001 .34284 L p .965 .854 .68 r
F P
0 g
s
.49454 .36688 m .49063 .3716 L .48793 .36666 L p .884 .794 .755 r
F P
0 g
s
.48793 .36666 m .4914 .36151 L .49454 .36688 L p .884 .794 .755 r
F P
0 g
s
.58077 .4431 m .58028 .43864 L .58696 .43786 L p .657 .459 .605 r
F P
0 g
s
.58028 .43864 m .58077 .4431 L .57487 .44409 L p .692 .49 .609 r
F P
0 g
s
.57487 .44409 m .57366 .43975 L .58028 .43864 L p .692 .49 .609 r
F P
0 g
s
.57366 .43975 m .57487 .44409 L .56931 .44526 L p .724 .514 .606 r
F P
0 g
s
.56931 .44526 m .56753 .44114 L .57366 .43975 L p .724 .514 .606 r
F P
0 g
s
.5951 .12982 m .6159 .11948 L .61856 .1234 L p .721 .951 .951 r
F P
0 g
s
.63835 .11629 m .61856 .1234 L .6159 .11948 L p .644 .918 .978 r
F P
0 g
s
.50362 .42153 m .49831 .42245 L .49684 .41718 L p .693 .462 .568 r
F P
0 g
s
.49136 .4187 m .49684 .41718 L .49831 .42245 L p .675 .457 .582 r
F P
0 g
s
.49301 .42389 m .48766 .42589 L .48586 .42068 L p .654 .451 .596 r
F P
0 g
s
.48586 .42068 m .49136 .4187 L .49301 .42389 L p .654 .451 .596 r
F P
0 g
s
.55654 .43511 m .55962 .43888 L .55504 .44076 L p .771 .504 .53 r
F P
0 g
s
.55504 .44076 m .55185 .43746 L .55654 .43511 L p .771 .504 .53 r
F P
0 g
s
.6578 .39555 m .66808 .38851 L .67263 .3894 L p .097 0 0 r
F P
0 g
s
.6845 .38121 m .67263 .3894 L .66808 .38851 L p .098 0 0 r
F P
0 g
s
.47458 .44543 m .46906 .45189 L .46722 .44717 L p .415 .22 .505 r
F P
0 g
s
.46722 .44717 m .47298 .44127 L .47458 .44543 L p .415 .22 .505 r
F P
0 g
s
.45215 .49409 m .44271 .51552 L .44156 .51155 L p 0 0 .116 r
F P
0 g
s
.44156 .51155 m .45117 .49108 L .45215 .49409 L p 0 0 .116 r
F P
0 g
s
.49831 .42245 m .49301 .42389 L .49136 .4187 L p .675 .457 .582 r
F P
0 g
s
.50168 .29832 m .50369 .2858 L .5066 .28949 L p .985 .872 .512 r
F P
0 g
s
.5066 .28949 m .50432 .30178 L .50168 .29832 L p .985 .872 .512 r
F P
0 g
s
.60346 .42827 m .60084 .43272 L .5946 .43285 L p .562 .325 .513 r
F P
0 g
s
.59323 .43737 m .5946 .43285 L .60084 .43272 L p .559 .338 .537 r
F P
0 g
s
.5946 .43285 m .59323 .43737 L .58696 .43786 L p .616 .402 .568 r
F P
0 g
s
.57989 .47159 m .5807 .4771 L .57507 .47797 L p .732 .671 .79 r
F P
0 g
s
.58495 .47082 m .58632 .47624 L .5807 .4771 L p .696 .644 .794 r
F P
0 g
s
.5807 .4771 m .57989 .47159 L .58495 .47082 L p .696 .644 .794 r
F P
0 g
s
.63394 .41159 m .62785 .41597 L .62241 .41524 L p .358 .005 .223 r
F P
0 g
s
.61739 .41974 m .62241 .41524 L .62785 .41597 L p .351 .008 .235 r
F P
0 g
s
.52634 .51888 m .50964 .53787 L .50567 .5388 L p .779 .989 .753 r
F P
0 g
s
.48151 .56955 m .50567 .5388 L .50964 .53787 L p .828 .991 .735 r
F P
0 g
s
.58667 .44234 m .58696 .43786 L .59323 .43737 L p .613 .416 .591 r
F P
0 g
s
.58696 .43786 m .58667 .44234 L .58077 .4431 L p .657 .459 .605 r
F P
0 g
s
.53306 .43014 m .52875 .42853 L .53017 .42443 L p .749 .429 .441 r
F P
0 g
s
.53017 .42443 m .53509 .42637 L .53306 .43014 L p .749 .429 .441 r
F P
0 g
s
.52498 .42288 m .53017 .42443 L .52875 .42853 L p .74 .423 .445 r
F P
0 g
s
.48449 .38496 m .47942 .388 L .47714 .38298 L p .794 .727 .79 r
F P
0 g
s
.47714 .38298 m .48198 .37964 L .48449 .38496 L p .794 .727 .79 r
F P
0 g
s
.53509 .42637 m .53976 .42869 L .53718 .43204 L p .753 .434 .443 r
F P
0 g
s
.53718 .43204 m .53306 .43015 L .53509 .42637 L p .753 .434 .443 r
F P
0 g
s
.48386 .43303 m .4785 .43665 L .47668 .43183 L p .564 .361 .564 r
F P
0 g
s
.47668 .43183 m .48224 .4285 L .48386 .43303 L p .564 .361 .564 r
F P
0 g
s
.52875 .42853 m .52418 .42721 L .52498 .42288 L p .74 .423 .445 r
F P
0 g
s
.51965 .4218 m .52498 .42288 L .52418 .42721 L p .729 .417 .452 r
F P
0 g
s
.4682 .39304 m .46186 .39496 L .45975 .39002 L p .71 .701 .839 r
F P
0 g
s
.45263 .39116 m .45975 .39002 L .46186 .39496 L p .675 .685 .852 r
F P
0 g
s
.57507 .47797 m .57484 .47239 L .57989 .47159 L p .732 .671 .79 r
F P
0 g
s
.57484 .47239 m .57507 .47797 L .56968 .47881 L p .768 .7 .787 r
F P
0 g
s
.69924 .88246 m .71281 .88068 L .7115 .88165 L p .255 0 0 r
F P
0 g
s
.7115 .88165 m .69499 .88553 L .69924 .88246 L p .255 0 0 r
F P
0 g
s
.58982 .47008 m .5917 .47543 L .58632 .47624 L p .657 .618 .799 r
F P
0 g
s
.58632 .47624 m .58495 .47082 L .58982 .47008 L p .657 .618 .799 r
F P
0 g
s
.56753 .44114 m .56931 .44526 L .56434 .44653 L p .754 .532 .595 r
F P
0 g
s
.56434 .44653 m .5622 .44268 L .56753 .44114 L p .754 .532 .595 r
F P
0 g
s
.45263 .39116 m .44454 .39152 L .44259 .38693 L p .62 .712 .911 r
F P
0 g
s
.433 .38571 m .44259 .38693 L .44454 .39152 L p .569 .684 .918 r
F P
0 g
s
.53976 .42869 m .54417 .43136 L .54116 .43425 L p .763 .444 .445 r
F P
0 g
s
.54116 .43425 m .53718 .43204 L .53976 .42869 L p .763 .444 .445 r
F P
0 g
s
.55422 .49452 m .55811 .48682 L .56305 .48604 L p .834 .834 .847 r
F P
0 g
s
.55811 .48682 m .55422 .49452 L .54943 .49529 L p .872 .892 .845 r
F P
0 g
s
.5423 .50501 m .54943 .49529 L .55422 .49452 L p .856 .913 .87 r
F P
0 g
s
.52418 .42721 m .51941 .42624 L .51965 .4218 L p .729 .417 .452 r
F P
0 g
s
.51429 .42121 m .51965 .4218 L .51941 .42624 L p .717 .412 .462 r
F P
0 g
s
.433 .38571 m .42157 .38307 L .41975 .37879 L p .437 .675 .964 r
F P
0 g
s
.40538 .37362 m .41975 .37879 L .42157 .38307 L p .383 .638 .956 r
F P
0 g
s
.56305 .48604 m .56477 .47959 L .56968 .47881 L p .802 .762 .816 r
F P
0 g
s
.56477 .47959 m .56305 .48604 L .55811 .48682 L p .842 .806 .815 r
F P
0 g
s
.71507 .12738 m .71659 .12481 L .71981 .12662 L p .387 .587 .922 r
F P
0 g
s
.71981 .12662 m .71973 .13 L .71507 .12738 L p .387 .587 .922 r
F P
0 g
s
.71659 .12481 m .71507 .12738 L .7105 .12465 L p .405 .61 .933 r
F P
0 g
s
.49063 .3716 m .48646 .37585 L .48412 .37129 L p .866 .796 .779 r
F P
0 g
s
.48412 .37129 m .48793 .36666 L .49063 .3716 L p .866 .796 .779 r
F P
0 g
s
.47942 .388 m .47402 .3907 L .47188 .38585 L p .769 .721 .808 r
F P
0 g
s
.47188 .38585 m .47714 .38298 L .47942 .388 L p .769 .721 .808 r
F P
0 g
s
.4974 .3496 m .49454 .35583 L .49198 .35173 L p .956 .862 .706 r
F P
0 g
s
.49198 .35173 m .49446 .3452 L .4974 .3496 L p .956 .862 .706 r
F P
0 g
s
.72331 .87464 m .73198 .86382 L .73644 .8619 L p .168 0 .041 r
F P
0 g
s
.73198 .86382 m .72331 .87464 L .72164 .87545 L p .207 0 .069 r
F P
0 g
s
.47402 .3907 m .4682 .39304 L .46612 .38822 L p .741 .712 .824 r
F P
0 g
s
.45975 .39002 m .46612 .38822 L .4682 .39304 L p .71 .701 .839 r
F P
0 g
s
.58125 .44749 m .58077 .4431 L .58667 .44234 L p .656 .476 .628 r
F P
0 g
s
.58077 .4431 m .58125 .44749 L .5759 .44838 L p .693 .507 .631 r
F P
0 g
s
.5759 .44838 m .57487 .44409 L .58077 .4431 L p .693 .507 .631 r
F P
0 g
s
.51941 .42624 m .51452 .42568 L .51429 .42121 L p .717 .412 .462 r
F P
0 g
s
.50894 .42112 m .51429 .42121 L .51452 .42568 L p .702 .407 .474 r
F P
0 g
s
.57487 .44409 m .5759 .44838 L .57078 .44939 L p .726 .531 .628 r
F P
0 g
s
.57078 .44939 m .56931 .44526 L .57487 .44409 L p .726 .531 .628 r
F P
0 g
s
.61295 .42414 m .6091 .42845 L .60346 .42827 L p .483 .209 .421 r
F P
0 g
s
.60084 .43272 m .60346 .42827 L .6091 .42845 L p .478 .222 .447 r
F P
0 g
s
.55962 .43888 m .5622 .44268 L .5578 .44419 L p .778 .522 .549 r
F P
0 g
s
.5578 .44419 m .55504 .44076 L .55962 .43888 L p .778 .522 .549 r
F P
0 g
s
.54417 .43136 m .54823 .43431 L .54493 .43673 L p .774 .457 .452 r
F P
0 g
s
.54493 .43673 m .54116 .43425 L .54417 .43136 L p .774 .457 .452 r
F P
0 g
s
.46612 .38822 m .47188 .38585 L .47402 .3907 L p .741 .712 .824 r
F P
0 g
s
.71973 .13 m .71981 .12662 L .72295 .12826 L p .359 .561 .913 r
F P
0 g
s
.72295 .12826 m .72426 .13238 L .71973 .13 L p .359 .561 .913 r
F P
0 g
s
.60085 .47407 m .60482 .47964 L .59996 .48037 L p .55 .593 .85 r
F P
0 g
s
.59996 .48037 m .59661 .4747 L .60085 .47407 L p .55 .593 .85 r
F P
0 g
s
.71342 .12292 m .7105 .12465 L .70619 .12193 L p .413 .631 .944 r
F P
0 g
s
.7105 .12465 m .71342 .12292 L .71659 .12481 L p .405 .61 .933 r
F P
0 g
s
.48912 .43026 m .48386 .43303 L .48224 .4285 L p .593 .372 .55 r
F P
0 g
s
.48224 .4285 m .48766 .42589 L .48912 .43026 L p .593 .372 .55 r
F P
0 g
s
.49994 .30938 m .50168 .29832 L .50432 .30178 L p .984 .87 .507 r
F P
0 g
s
.50432 .30178 m .50233 .31262 L .49994 .30938 L p .984 .87 .507 r
F P
0 g
s
.60871 .47906 m .6151 .48504 L .61047 .48574 L p .458 .593 .899 r
F P
0 g
s
.61047 .48574 m .60482 .47964 L .60871 .47906 L p .458 .593 .899 r
F P
0 g
s
.64872 .4016 m .6578 .39555 L .66199 .3963 L p .092 0 0 r
F P
0 g
s
.67263 .3894 m .66199 .3963 L .6578 .39555 L p .097 0 0 r
F P
0 g
s
.56968 .47881 m .57003 .47316 L .57484 .47239 L p .768 .7 .787 r
F P
0 g
s
.57003 .47316 m .56968 .47881 L .56477 .47959 L p .806 .734 .785 r
F P
0 g
s
.51452 .42568 m .50954 .42555 L .50894 .42112 L p .702 .407 .474 r
F P
0 g
s
.50362 .42153 m .50894 .42112 L .50954 .42555 L p .684 .402 .488 r
F P
0 g
s
.06469 .51117 m .0706 .52678 L .06986 .53153 L p .994 .747 .408 r
F P
0 g
s
.0706 .52678 m .06469 .51117 L .06495 .50879 L p .996 .763 .455 r
F P
0 g
s
.54943 .49529 m .5423 .50501 L .53808 .50573 L p .871 .975 .848 r
F P
0 g
s
.52634 .51888 m .53808 .50573 L .5423 .50501 L p .852 .982 .861 r
F P
0 g
s
.64435 .89631 m .68955 .89032 L .68863 .89182 L p .322 0 0 r
F P
0 g
s
.68863 .89182 m .64176 .89998 L .64435 .89631 L p .322 0 0 r
F P
0 g
s
.59427 .46943 m .59661 .4747 L .5917 .47543 L p .612 .591 .805 r
F P
0 g
s
.5917 .47543 m .58982 .47008 L .59427 .46943 L p .612 .591 .805 r
F P
0 g
s
.59323 .43737 m .59221 .4418 L .58667 .44234 L p .613 .416 .591 r
F P
0 g
s
.58656 .44676 m .58667 .44234 L .59221 .4418 L p .612 .435 .617 r
F P
0 g
s
.58667 .44234 m .58656 .44676 L .58125 .44749 L p .656 .476 .628 r
F P
0 g
s
.56931 .44526 m .57078 .44939 L .56612 .45046 L p .757 .552 .618 r
F P
0 g
s
.56612 .45046 m .56434 .44653 L .56931 .44526 L p .757 .552 .618 r
F P
0 g
s
.50954 .42555 m .5045 .42591 L .50362 .42153 L p .684 .402 .488 r
F P
0 g
s
.49831 .42245 m .50362 .42153 L .5045 .42591 L p .665 .396 .504 r
F P
0 g
s
.60084 .43272 m .59872 .4371 L .59323 .43737 L p .559 .338 .537 r
F P
0 g
s
.59221 .4418 m .59323 .43737 L .59872 .4371 L p .556 .356 .564 r
F P
0 g
s
.47991 .44043 m .47458 .44543 L .47298 .44127 L p .455 .237 .492 r
F P
0 g
s
.47298 .44127 m .4785 .43665 L .47991 .44043 L p .455 .237 .492 r
F P
0 g
s
.54823 .43431 m .55185 .43746 L .54841 .43945 L p .785 .475 .464 r
F P
0 g
s
.54841 .43945 m .54493 .43673 L .54823 .43431 L p .785 .475 .464 r
F P
0 g
s
.62785 .41597 m .62232 .42024 L .61739 .41974 L p .351 .008 .235 r
F P
0 g
s
.61295 .42414 m .61739 .41974 L .62232 .42024 L p .344 .015 .255 r
F P
0 g
s
.57913 .4665 m .57989 .47159 L .57484 .47239 L p .733 .645 .761 r
F P
0 g
s
.58389 .46575 m .58495 .47082 L .57989 .47159 L p .697 .618 .765 r
F P
0 g
s
.57989 .47159 m .57913 .4665 L .58389 .46575 L p .697 .618 .765 r
F P
0 g
s
.4943 .42821 m .48912 .43026 L .48766 .42589 L p .619 .381 .535 r
F P
0 g
s
.48766 .42589 m .49301 .42389 L .4943 .42821 L p .619 .381 .535 r
F P
0 g
s
.74649 .1558 m .74067 .14509 L .7438 .14594 L p .17 .364 .813 r
F P
0 g
s
.7438 .14594 m .75069 .15695 L .74649 .1558 L p .17 .364 .813 r
F P
0 g
s
.73644 .1435 m .73218 .13607 L .73522 .13721 L p .244 .448 .861 r
F P
0 g
s
.73522 .13721 m .74067 .14509 L .73644 .1435 L p .244 .448 .861 r
F P
0 g
s
.5045 .42591 m .49942 .42677 L .49831 .42245 L p .665 .396 .504 r
F P
0 g
s
.49301 .42389 m .49831 .42245 L .49942 .42677 L p .643 .389 .519 r
F P
0 g
s
.67506 .11433 m .68714 .11408 L .69057 .11692 L p .524 .744 .975 r
F P
0 g
s
.6991 .11693 m .69057 .11692 L .68714 .11408 L p .447 .711 .979 r
F P
0 g
s
.69057 .11692 m .6991 .11693 L .70234 .11931 L p .473 .694 .964 r
F P
0 g
s
.47031 .45514 m .46467 .46405 L .4632 .46022 L p .207 .006 .372 r
F P
0 g
s
.4632 .46022 m .46906 .45189 L .47031 .45514 L p .207 .006 .372 r
F P
0 g
s
.48646 .37585 m .48198 .37964 L .47991 .37539 L p .844 .795 .803 r
F P
0 g
s
.47991 .37539 m .48412 .37129 L .48646 .37585 L p .844 .795 .803 r
F P
0 g
s
.49942 .42677 m .4943 .42821 L .49301 .42389 L p .643 .389 .519 r
F P
0 g
s
.65642 .11251 m .67204 .11131 L .67506 .11433 L p .559 .805 .991 r
F P
0 g
s
.68714 .11408 m .67506 .11433 L .67204 .11131 L p .48 .765 .994 r
F P
0 g
s
.76315 .18924 m .75746 .17133 L .76075 .1715 L p .009 .157 .67 r
F P
0 g
s
.76075 .1715 m .76724 .18954 L .76315 .18924 L p .009 .157 .67 r
F P
0 g
s
.5759 .44838 m .5768 .4527 L .57199 .4536 L p .728 .551 .652 r
F P
0 g
s
.57199 .4536 m .57078 .44939 L .5759 .44838 L p .728 .551 .652 r
F P
0 g
s
.5768 .4527 m .5759 .44838 L .58125 .44749 L p .694 .526 .655 r
F P
0 g
s
.45975 .39002 m .45263 .39116 L .45084 .38697 L p .669 .737 .901 r
F P
0 g
s
.44259 .38693 m .45084 .38697 L .45263 .39116 L p .62 .712 .911 r
F P
0 g
s
.57484 .47239 m .57441 .46726 L .57913 .4665 L p .733 .645 .761 r
F P
0 g
s
.57441 .46726 m .57484 .47239 L .57003 .47316 L p .769 .673 .757 r
F P
0 g
s
.12444 .62131 m .08362 .57342 L .0854 .56953 L p .887 .465 .18 r
F P
0 g
s
.06901 .53487 m .0854 .56953 L .08362 .57342 L p .954 .612 .236 r
F P
0 g
s
.0854 .56953 m .06901 .53487 L .06986 .53153 L p .969 .657 .362 r
F P
0 g
s
.5622 .44268 m .56434 .44653 L .56014 .44777 L p .785 .544 .573 r
F P
0 g
s
.56014 .44777 m .5578 .44419 L .5622 .44268 L p .785 .544 .573 r
F P
0 g
s
.58847 .46506 m .58982 .47008 L .58495 .47082 L p .658 .591 .768 r
F P
0 g
s
.58495 .47082 m .58389 .46575 L .58847 .46506 L p .658 .591 .768 r
F P
0 g
s
.72426 .13238 m .72295 .12826 L .72586 .12968 L p .32 .532 .903 r
F P
0 g
s
.72586 .12968 m .72847 .13444 L .72426 .13238 L p .32 .532 .903 r
F P
0 g
s
.58177 .45189 m .58125 .44749 L .58656 .44676 L p .656 .495 .654 r
F P
0 g
s
.58125 .44749 m .58177 .45189 L .5768 .4527 L p .694 .526 .655 r
F P
0 g
s
.07017 .47332 m .06464 .48885 L .06433 .48704 L p .993 .875 .559 r
F P
0 g
s
.06433 .48704 m .06941 .4691 L .07017 .47332 L p .993 .875 .559 r
F P
0 g
s
.71043 .12103 m .70619 .12193 L .70234 .11931 L p .411 .649 .956 r
F P
0 g
s
.70619 .12193 m .71043 .12103 L .71342 .12292 L p .413 .631 .944 r
F P
0 g
s
.64491 .49892 m .66534 .50972 L .66159 .51022 L p .063 .499 .894 r
F P
0 g
s
.66159 .51022 m .64204 .49932 L .64491 .49892 L p .063 .499 .894 r
F P
0 g
s
.40538 .37362 m .38707 .36621 L .3855 .36277 L p .146 .561 .928 r
F P
0 g
s
.36093 .35242 m .3855 .36277 L .38707 .36621 L p .153 .568 .93 r
F P
0 g
s
.6159 .11948 m .63617 .11296 L .63835 .11629 L p .644 .918 .978 r
F P
0 g
s
.65642 .11251 m .63835 .11629 L .63617 .11296 L p .562 .874 .994 r
F P
0 g
s
.49454 .35583 m .4914 .36151 L .48918 .35772 L p .944 .87 .735 r
F P
0 g
s
.48918 .35772 m .49198 .35173 L .49454 .35583 L p .944 .87 .735 r
F P
0 g
s
.61839 .48454 m .62819 .49122 L .62414 .49184 L p .307 .574 .934 r
F P
0 g
s
.62414 .49184 m .6151 .48504 L .61839 .48454 L p .307 .574 .934 r
F P
0 g
s
.49831 .31913 m .49994 .30938 L .50233 .31262 L p .983 .874 .513 r
F P
0 g
s
.50233 .31262 m .50046 .32217 L .49831 .31913 L p .983 .874 .513 r
F P
0 g
s
.55185 .43746 m .55504 .44076 L .55156 .44239 L p .796 .497 .483 r
F P
0 g
s
.55156 .44239 m .54841 .43945 L .55185 .43746 L p .796 .497 .483 r
F P
0 g
s
.57078 .44939 m .57199 .4536 L .56756 .45452 L p .761 .574 .644 r
F P
0 g
s
.56756 .45452 m .56612 .45046 L .57078 .44939 L p .761 .574 .644 r
F P
0 g
s
.6091 .42845 m .60583 .43271 L .60084 .43272 L p .478 .222 .447 r
F P
0 g
s
.59872 .4371 m .60084 .43272 L .60583 .43271 L p .474 .24 .478 r
F P
0 g
s
.6408 .40689 m .64872 .4016 L .65258 .4022 L p .086 0 0 r
F P
0 g
s
.66199 .3963 m .65258 .4022 L .64872 .4016 L p .092 0 0 r
F P
0 g
s
.57838 .4617 m .57913 .4665 L .57441 .46726 L p .732 .619 .732 r
F P
0 g
s
.58304 .46096 m .58389 .46575 L .57913 .4665 L p .697 .593 .736 r
F P
0 g
s
.57913 .4665 m .57838 .4617 L .58304 .46096 L p .697 .593 .736 r
F P
0 g
s
.5768 .4527 m .57762 .45712 L .57299 .45794 L p .73 .573 .678 r
F P
0 g
s
.57299 .45794 m .57199 .4536 L .5768 .4527 L p .73 .573 .678 r
F P
0 g
s
.57762 .45712 m .5768 .4527 L .58177 .45189 L p .695 .547 .681 r
F P
0 g
s
.48198 .37964 m .47714 .38298 L .47527 .37895 L p .818 .791 .826 r
F P
0 g
s
.47527 .37895 m .47991 .37539 L .48198 .37964 L p .818 .791 .826 r
F P
0 g
s
.59221 .4418 m .59152 .44619 L .58656 .44676 L p .612 .435 .617 r
F P
0 g
s
.58665 .45118 m .58656 .44676 L .59152 .44619 L p .612 .456 .646 r
F P
0 g
s
.58656 .44676 m .58665 .45118 L .58177 .45189 L p .656 .495 .654 r
F P
0 g
s
.44259 .38693 m .433 .38571 L .43143 .38203 L p .504 .718 .968 r
F P
0 g
s
.41975 .37879 m .43143 .38203 L .433 .38571 L p .437 .675 .964 r
F P
0 g
s
.58235 .45635 m .58177 .45189 L .58665 .45118 L p .657 .516 .681 r
F P
0 g
s
.58177 .45189 m .58235 .45635 L .57762 .45712 L p .695 .547 .681 r
F P
0 g
s
.57003 .47316 m .56994 .46801 L .57441 .46726 L p .769 .673 .757 r
F P
0 g
s
.56994 .46801 m .57003 .47316 L .56566 .47388 L p .807 .705 .752 r
F P
0 g
s
.56477 .47959 m .56566 .47388 L .57003 .47316 L p .806 .734 .785 r
F P
0 g
s
.56566 .47388 m .56477 .47959 L .56056 .48026 L p .848 .776 .781 r
F P
0 g
s
.55811 .48682 m .56056 .48026 L .56477 .47959 L p .842 .806 .815 r
F P
0 g
s
.48511 .43657 m .47991 .44043 L .4785 .43665 L p .494 .252 .476 r
F P
0 g
s
.4785 .43665 m .48386 .43303 L .48511 .43657 L p .494 .252 .476 r
F P
0 g
s
.56434 .44653 m .56612 .45046 L .5621 .4515 L p .791 .568 .599 r
F P
0 g
s
.5621 .4515 m .56014 .44777 L .56434 .44653 L p .791 .568 .599 r
F P
0 g
s
.46612 .38822 m .45975 .39002 L .45804 .38606 L p .714 .757 .886 r
F P
0 g
s
.45084 .38697 m .45804 .38606 L .45975 .39002 L p .669 .737 .901 r
F P
0 g
s
.69499 .88553 m .7115 .88165 L .71049 .88248 L p .229 0 0 r
F P
0 g
s
.71049 .88248 m .69171 .88819 L .69499 .88553 L p .229 0 0 r
F P
0 g
s
.59269 .46445 m .59427 .46943 L .58982 .47008 L p .613 .56 .772 r
F P
0 g
s
.58982 .47008 m .58847 .46506 L .59269 .46445 L p .613 .56 .772 r
F P
0 g
s
.58755 .46028 m .58847 .46506 L .58389 .46575 L p .658 .564 .738 r
F P
0 g
s
.58389 .46575 m .58304 .46096 L .58755 .46028 L p .658 .564 .738 r
F P
0 g
s
.43985 .70721 m .47442 .81357 L .4741 .81754 L p .764 .447 0 r
F P
0 g
s
.47442 .81357 m .5606 .88498 L .56116 .88851 L p .632 .088 0 r
F P
0 g
s
.56116 .88851 m .4741 .81754 L .47442 .81357 L p .632 .088 0 r
F P
0 g
s
.57441 .46726 m .57379 .46247 L .57838 .4617 L p .732 .619 .732 r
F P
0 g
s
.57379 .46247 m .57441 .46726 L .56994 .46801 L p .768 .647 .728 r
F P
0 g
s
.59872 .4371 m .59706 .44143 L .59221 .4418 L p .556 .356 .564 r
F P
0 g
s
.59152 .44619 m .59221 .4418 L .59706 .44143 L p .555 .377 .596 r
F P
0 g
s
.80042 .76487 m .77271 .82734 L .7691 .82738 L p .001 0 .255 r
F P
0 g
s
.74274 .85991 m .7691 .82738 L .77271 .82734 L p 0 0 .04 r
F P
0 g
s
.7691 .82738 m .74274 .85991 L .74007 .86058 L p .132 0 .155 r
F P
0 g
s
.4593 .47807 m .45215 .49409 L .45117 .49108 L p 0 0 .113 r
F P
0 g
s
.45117 .49108 m .45848 .4757 L .4593 .47807 L p 0 0 .113 r
F P
0 g
s
.59811 .46887 m .60085 .47407 L .59661 .4747 L p .553 .557 .813 r
F P
0 g
s
.59661 .4747 m .59427 .46943 L .59811 .46887 L p .553 .557 .813 r
F P
0 g
s
.57762 .45712 m .57838 .4617 L .57379 .46247 L p .731 .595 .705 r
F P
0 g
s
.57379 .46247 m .57299 .45794 L .57762 .45712 L p .731 .595 .705 r
F P
0 g
s
.57838 .4617 m .57762 .45712 L .58235 .45635 L p .696 .569 .708 r
F P
0 g
s
.58235 .45635 m .58304 .46096 L .57838 .4617 L p .696 .569 .708 r
F P
0 g
s
.57199 .4536 m .57299 .45794 L .56867 .45877 L p .764 .597 .671 r
F P
0 g
s
.56867 .45877 m .56756 .45452 L .57199 .4536 L p .764 .597 .671 r
F P
0 g
s
.62232 .42024 m .61739 .42443 L .61295 .42414 L p .344 .015 .255 r
F P
0 g
s
.6091 .42845 m .61295 .42414 L .61739 .42443 L p .337 .027 .283 r
F P
0 g
s
.45397 .62177 m .43985 .70721 L .4391 .70978 L p .718 .681 .136 r
F P
0 g
s
.4741 .81754 m .4391 .70978 L .43985 .70721 L p .764 .447 0 r
F P
0 g
s
.56056 .48026 m .55811 .48682 L .55419 .48743 L p .887 .864 .811 r
F P
0 g
s
.54943 .49529 m .55419 .48743 L .55811 .48682 L p .872 .892 .845 r
F P
0 g
s
.55504 .44076 m .5578 .44419 L .55436 .44553 L p .807 .522 .506 r
F P
0 g
s
.55436 .44553 m .55156 .44239 L .55504 .44076 L p .807 .522 .506 r
F P
0 g
s
.47714 .38298 m .47188 .38585 L .47013 .38196 L p .788 .783 .848 r
F P
0 g
s
.47013 .38196 m .47527 .37895 L .47714 .38298 L p .788 .783 .848 r
F P
0 g
s
.58665 .45118 m .58696 .45567 L .58235 .45635 L p .657 .516 .681 r
F P
0 g
s
.58304 .46096 m .58235 .45635 L .58696 .45567 L p .658 .54 .709 r
F P
0 g
s
.58696 .45567 m .58755 .46028 L .58304 .46096 L p .658 .54 .709 r
F P
0 g
s
.47188 .38585 m .46612 .38822 L .46443 .38435 L p .753 .772 .868 r
F P
0 g
s
.45804 .38606 m .46443 .38435 L .46612 .38822 L p .714 .757 .886 r
F P
0 g
s
.4914 .36151 m .48793 .36666 L .48602 .36316 L p .927 .877 .767 r
F P
0 g
s
.48602 .36316 m .48918 .35772 L .4914 .36151 L p .927 .877 .767 r
F P
0 g
s
.57299 .45794 m .57379 .46247 L .56947 .46324 L p .767 .621 .699 r
F P
0 g
s
.56994 .46801 m .56947 .46324 L .57379 .46247 L p .768 .647 .728 r
F P
0 g
s
.72477 .87401 m .73644 .8619 L .74007 .86058 L p .121 0 .002 r
F P
0 g
s
.73644 .8619 m .72477 .87401 L .72331 .87464 L p .168 0 .041 r
F P
0 g
s
.56947 .46324 m .56867 .45877 L .57299 .45794 L p .767 .621 .699 r
F P
0 g
s
.46443 .38435 m .47013 .38196 L .47188 .38585 L p .753 .772 .868 r
F P
0 g
s
.59152 .44619 m .59119 .45061 L .58665 .45118 L p .612 .456 .646 r
F P
0 g
s
.58696 .45567 m .58665 .45118 L .59119 .45061 L p .612 .479 .676 r
F P
0 g
s
.49668 .3277 m .49831 .31913 L .50046 .32217 L p .982 .883 .528 r
F P
0 g
s
.50046 .32217 m .49861 .33055 L .49668 .3277 L p .982 .883 .528 r
F P
0 g
s
.72847 .13444 m .72586 .12968 L .72843 .13081 L p .268 .497 .892 r
F P
0 g
s
.72843 .13081 m .73218 .13607 L .72847 .13444 L p .268 .497 .892 r
F P
0 g
s
.70777 .11922 m .70234 .11931 L .6991 .11693 L p .396 .663 .967 r
F P
0 g
s
.70234 .11931 m .70777 .11922 L .71043 .12103 L p .411 .649 .956 r
F P
0 g
s
.60423 .47357 m .60871 .47906 L .60482 .47964 L p .463 .553 .863 r
F P
0 g
s
.60482 .47964 m .60085 .47407 L .60423 .47357 L p .463 .553 .863 r
F P
0 g
s
.56612 .45046 m .56756 .45452 L .56366 .45541 L p .796 .594 .628 r
F P
0 g
s
.56366 .45541 m .5621 .4515 L .56612 .45046 L p .796 .594 .628 r
F P
0 g
s
.53166 .4328 m .52772 .43141 L .52875 .42853 L p .738 .36 .336 r
F P
0 g
s
.52875 .42853 m .53306 .43014 L .53166 .4328 L p .738 .36 .336 r
F P
0 g
s
.52418 .42721 m .52875 .42853 L .52772 .43141 L p .723 .347 .338 r
F P
0 g
s
.52772 .43141 m .52354 .43026 L .52418 .42721 L p .723 .347 .338 r
F P
0 g
s
.51941 .42624 m .52418 .42721 L .52354 .43026 L p .706 .336 .345 r
F P
0 g
s
.49022 .43365 m .48511 .43657 L .48386 .43303 L p .53 .265 .459 r
F P
0 g
s
.48386 .43303 m .48912 .43026 L .49022 .43365 L p .53 .265 .459 r
F P
0 g
s
.08248 .43421 m .06857 .46617 L .06768 .46463 L p .956 .941 .626 r
F P
0 g
s
.06768 .46463 m .0808 .43126 L .08248 .43421 L p .956 .941 .626 r
F P
0 g
s
.53306 .43015 m .53718 .43204 L .53543 .43444 L p .75 .374 .342 r
F P
0 g
s
.53543 .43444 m .53166 .4328 L .53306 .43015 L p .75 .374 .342 r
F P
0 g
s
.35878 .62454 m .28657 .65863 L .28906 .65678 L p 0 0 0 r
F P
0 g
s
.28906 .65678 m .36027 .62323 L .35878 .62454 L p 0 0 0 r
F P
0 g
s
.1995 .65782 m .28906 .65678 L .28657 .65863 L p .116 0 0 r
F P
0 g
s
.59171 .45969 m .59269 .46445 L .58847 .46506 L p .613 .532 .739 r
F P
0 g
s
.58847 .46506 m .58755 .46028 L .59171 .45969 L p .613 .532 .739 r
F P
0 g
s
.47567 .44829 m .47031 .45514 L .46906 .45189 L p .257 .025 .358 r
F P
0 g
s
.46906 .45189 m .47458 .44543 L .47567 .44829 L p .257 .025 .358 r
F P
0 g
s
.52354 .43026 m .51915 .42941 L .51941 .42624 L p .706 .336 .345 r
F P
0 g
s
.51452 .42568 m .51941 .42624 L .51915 .42941 L p .688 .326 .355 r
F P
0 g
s
.63394 .41159 m .6408 .40689 L .64434 .40736 L p .078 0 0 r
F P
0 g
s
.65258 .4022 m .64434 .40736 L .6408 .40689 L p .086 0 0 r
F P
0 g
s
.56947 .46324 m .56994 .46801 L .5659 .46871 L p .807 .676 .72 r
F P
0 g
s
.56566 .47388 m .5659 .46871 L .56994 .46801 L p .807 .705 .752 r
F P
0 g
s
.60583 .43271 m .60312 .43695 L .59872 .4371 L p .474 .24 .478 r
F P
0 g
s
.59706 .44143 m .59872 .4371 L .60312 .43695 L p .471 .263 .514 r
F P
0 g
s
.53718 .43204 m .54116 .43425 L .53912 .43636 L p .766 .392 .347 r
F P
0 g
s
.53912 .43636 m .53543 .43444 L .53718 .43204 L p .766 .392 .347 r
F P
0 g
s
.5578 .44419 m .56014 .44777 L .55678 .44887 L p .818 .551 .534 r
F P
0 g
s
.55678 .44887 m .55436 .44553 L .5578 .44419 L p .818 .551 .534 r
F P
0 g
s
.51915 .42941 m .51459 .42891 L .51452 .42568 L p .688 .326 .355 r
F P
0 g
s
.50954 .42555 m .51452 .42568 L .51459 .42891 L p .667 .316 .369 r
F P
0 g
s
.59119 .45061 m .59124 .45509 L .58696 .45567 L p .612 .479 .676 r
F P
0 g
s
.58755 .46028 m .58696 .45567 L .59124 .45509 L p .612 .504 .707 r
F P
0 g
s
.53808 .50573 m .52634 .51888 L .52349 .51946 L p .775 .989 .754 r
F P
0 g
s
.50567 .5388 m .52349 .51946 L .52634 .51888 L p .779 .989 .753 r
F P
0 g
s
.59706 .44143 m .59588 .44577 L .59152 .44619 L p .555 .377 .596 r
F P
0 g
s
.59119 .45061 m .59152 .44619 L .59588 .44577 L p .554 .402 .629 r
F P
0 g
s
.59124 .45509 m .59171 .45969 L .58755 .46028 L p .612 .504 .707 r
F P
0 g
s
.56756 .45452 m .56867 .45877 L .56484 .45955 L p .801 .621 .658 r
F P
0 g
s
.56484 .45955 m .56366 .45541 L .56756 .45452 L p .801 .621 .658 r
F P
0 g
s
.51459 .42891 m .50989 .42881 L .50954 .42555 L p .667 .316 .369 r
F P
0 g
s
.5045 .42591 m .50954 .42555 L .50989 .42881 L p .645 .307 .385 r
F P
0 g
s
.49525 .43152 m .49022 .43365 L .48912 .43026 L p .562 .277 .44 r
F P
0 g
s
.48912 .43026 m .4943 .42821 L .49525 .43152 L p .562 .277 .44 r
F P
0 g
s
.55419 .48743 m .54943 .49529 L .54612 .49582 L p .9 .96 .823 r
F P
0 g
s
.53808 .50573 m .54612 .49582 L .54943 .49529 L p .871 .975 .848 r
F P
0 g
s
.54116 .43425 m .54493 .43673 L .54266 .43855 L p .783 .414 .358 r
F P
0 g
s
.54266 .43855 m .53912 .43636 L .54116 .43425 L p .783 .414 .358 r
F P
0 g
s
.56867 .45877 m .56947 .46324 L .5656 .46396 L p .804 .648 .689 r
F P
0 g
s
.5659 .46871 m .5656 .46396 L .56947 .46324 L p .807 .676 .72 r
F P
0 g
s
.5659 .46871 m .56566 .47388 L .56193 .47449 L p .851 .744 .744 r
F P
0 g
s
.56056 .48026 m .56193 .47449 L .56566 .47388 L p .848 .776 .781 r
F P
0 g
s
.45084 .38697 m .44259 .38693 L .4412 .38366 L p .573 .761 .967 r
F P
0 g
s
.43143 .38203 m .4412 .38366 L .44259 .38693 L p .504 .718 .968 r
F P
0 g
s
.50989 .42881 m .50509 .42918 L .5045 .42591 L p .645 .307 .385 r
F P
0 g
s
.49942 .42677 m .5045 .42591 L .50509 .42918 L p .62 .298 .403 r
F P
0 g
s
.5656 .46396 m .56484 .45955 L .56867 .45877 L p .804 .648 .689 r
F P
0 g
s
.59634 .46393 m .59811 .46887 L .59427 .46943 L p .554 .523 .775 r
F P
0 g
s
.59427 .46943 m .59269 .46445 L .59634 .46393 L p .554 .523 .775 r
F P
0 g
s
.50021 .43005 m .49525 .43152 L .4943 .42821 L p .593 .288 .422 r
F P
0 g
s
.4943 .42821 m .49942 .42677 L .50021 .43005 L p .593 .288 .422 r
F P
0 g
s
.48793 .36666 m .48412 .37129 L .48245 .36805 L p .905 .881 .801 r
F P
0 g
s
.48245 .36805 m .48602 .36316 L .48793 .36666 L p .905 .881 .801 r
F P
0 g
s
.50509 .42918 m .50021 .43005 L .49942 .42677 L p .62 .298 .403 r
F P
0 g
s
.41975 .37879 m .40538 .37362 L .4041 .37078 L p .182 .591 .941 r
F P
0 g
s
.3855 .36277 m .4041 .37078 L .40538 .37362 L p .146 .561 .928 r
F P
0 g
s
.75746 .17133 m .75069 .15695 L .75322 .15704 L p .005 .211 .723 r
F P
0 g
s
.75322 .15704 m .76075 .1715 L .75746 .17133 L p .005 .211 .723 r
F P
0 g
s
.61739 .42443 m .61307 .42857 L .6091 .42845 L p .337 .027 .283 r
F P
0 g
s
.60583 .43271 m .6091 .42845 L .61307 .42857 L p .332 .045 .319 r
F P
0 g
s
.49861 .33055 m .49665 .33814 L .49493 .33548 L p .981 .894 .551 r
F P
0 g
s
.49493 .33548 m .49668 .32771 L .49861 .33055 L p .981 .894 .551 r
F P
0 g
s
.56014 .44777 m .5621 .4515 L .55881 .45242 L p .828 .581 .566 r
F P
0 g
s
.55881 .45242 m .55678 .44887 L .56014 .44777 L p .828 .581 .566 r
F P
0 g
s
.28657 .65863 m .19622 .65955 L .1995 .65782 L p .116 0 0 r
F P
0 g
s
.12444 .62131 m .1995 .65782 L .19622 .65955 L p .51 0 0 r
F P
0 g
s
.54493 .43673 m .54841 .43945 L .54599 .44099 L p .801 .441 .375 r
F P
0 g
s
.54599 .44099 m .54266 .43855 L .54493 .43673 L p .801 .441 .375 r
F P
0 g
s
.63617 .11296 m .65471 .1098 L .65642 .11251 L p .562 .874 .994 r
F P
0 g
s
.67204 .11131 m .65642 .11251 L .65471 .1098 L p .477 .823 .998 r
F P
0 g
s
.59588 .44577 m .59517 .45015 L .59119 .45061 L p .554 .402 .629 r
F P
0 g
s
.59124 .45509 m .59119 .45061 L .59517 .45015 L p .554 .429 .664 r
F P
0 g
s
.06437 .51308 m .06986 .53153 L .06901 .53487 L p .986 .727 .349 r
F P
0 g
s
.06986 .53153 m .06437 .51308 L .06469 .51117 L p .994 .747 .408 r
F P
0 g
s
.61146 .47864 m .61839 .48454 L .6151 .48504 L p .314 .535 .907 r
F P
0 g
s
.6151 .48504 m .60871 .47906 L .61146 .47864 L p .314 .535 .907 r
F P
0 g
s
.64434 .40736 m .63719 .41194 L .63394 .41159 L p .078 0 0 r
F P
0 g
s
.62785 .41597 m .63394 .41159 L .63718 .41194 L p .077 0 0 r
F P
0 g
s
.40308 .5817 m .35878 .62454 L .36027 .62323 L p .499 .822 .515 r
F P
0 g
s
.36027 .62323 m .40391 .581 L .40308 .5817 L p .499 .822 .515 r
F P
0 g
s
.56193 .47449 m .56056 .48026 L .55723 .48079 L p .898 .831 .771 r
F P
0 g
s
.55419 .48743 m .55723 .48079 L .56056 .48026 L p .887 .864 .811 r
F P
0 g
s
.60312 .43695 m .60097 .44119 L .59706 .44143 L p .471 .263 .514 r
F P
0 g
s
.59588 .44577 m .59706 .44143 L .60097 .44119 L p .469 .29 .554 r
F P
0 g
s
.59533 .4592 m .59634 .46393 L .59269 .46445 L p .554 .49 .738 r
F P
0 g
s
.59269 .46445 m .59171 .45969 L .59533 .4592 L p .554 .49 .738 r
F P
0 g
s
.48086 .44301 m .47567 .44829 L .47458 .44543 L p .309 .044 .34 r
F P
0 g
s
.47458 .44543 m .47991 .44043 L .48086 .44301 L p .309 .044 .34 r
F P
0 g
s
.63044 .4909 m .64491 .49892 L .64204 .49932 L p .062 .491 .892 r
F P
0 g
s
.64204 .49932 m .62819 .49122 L .63044 .4909 L p .062 .491 .892 r
F P
0 g
s
.5656 .46396 m .5659 .46871 L .56246 .46932 L p .851 .711 .708 r
F P
0 g
s
.56193 .47449 m .56246 .46932 L .5659 .46871 L p .851 .744 .744 r
F P
0 g
s
.5621 .4515 m .56366 .45541 L .56044 .4562 L p .837 .613 .6 r
F P
0 g
s
.56044 .4562 m .55881 .45242 L .5621 .4515 L p .837 .613 .6 r
F P
0 g
s
.54841 .43945 m .55156 .44239 L .54907 .44367 L p .82 .473 .399 r
F P
0 g
s
.54907 .44367 m .54599 .44099 L .54841 .43945 L p .82 .473 .399 r
F P
0 g
s
.74067 .14509 m .73522 .13721 L .73747 .1378 L p .14 .386 .839 r
F P
0 g
s
.73747 .1378 m .7438 .14594 L .74067 .14509 L p .14 .386 .839 r
F P
0 g
s
.60119 .46842 m .60423 .47357 L .60085 .47407 L p .467 .512 .821 r
F P
0 g
s
.60085 .47407 m .59811 .46887 L .60119 .46842 L p .467 .512 .821 r
F P
0 g
s
.48412 .37129 m .47991 .37539 L .47843 .37236 L p .877 .882 .834 r
F P
0 g
s
.47843 .37236 m .48245 .36805 L .48412 .37129 L p .877 .882 .834 r
F P
0 g
s
.59517 .45015 m .59497 .45462 L .59124 .45509 L p .554 .429 .664 r
F P
0 g
s
.59171 .45969 m .59124 .45509 L .59497 .45462 L p .554 .458 .701 r
F P
0 g
s
.67204 .11131 m .68489 .11182 L .68714 .11408 L p .48 .765 .994 r
F P
0 g
s
.69663 .11488 m .68714 .11408 L .68489 .11182 L p .398 .72 .988 r
F P
0 g
s
.68714 .11408 m .69663 .11488 L .6991 .11693 L p .447 .711 .979 r
F P
0 g
s
.71659 .12481 m .71752 .12322 L .71966 .12441 L p .318 .572 .931 r
F P
0 g
s
.71966 .12441 m .71981 .12662 L .71659 .12481 L p .318 .572 .931 r
F P
0 g
s
.71752 .12322 m .71659 .12481 L .71342 .12292 L p .332 .591 .939 r
F P
0 g
s
.46537 .46597 m .4593 .47807 L .45848 .4757 L p 0 0 .101 r
F P
0 g
s
.45848 .4757 m .46467 .46405 L .46537 .46597 L p 0 0 .101 r
F P
0 g
s
.59497 .45462 m .59533 .4592 L .59171 .45969 L p .554 .458 .701 r
F P
0 g
s
.45804 .38606 m .45084 .38697 L .44955 .38399 L p .64 .798 .958 r
F P
0 g
s
.4412 .38366 m .44955 .38399 L .45084 .38697 L p .573 .761 .967 r
F P
0 g
s
.06941 .4691 m .06433 .48704 L .06397 .48578 L p .985 .881 .532 r
F P
0 g
s
.06397 .48578 m .06857 .46617 L .06941 .4691 L p .985 .881 .532 r
F P
0 g
s
.71981 .12662 m .71966 .12441 L .72173 .1255 L p .293 .55 .922 r
F P
0 g
s
.72173 .1255 m .72295 .12826 L .71981 .12662 L p .293 .55 .922 r
F P
0 g
s
.49665 .33814 m .49446 .3452 L .49294 .34273 L p .977 .91 .583 r
F P
0 g
s
.49294 .34273 m .49493 .33548 L .49665 .33814 L p .977 .91 .583 r
F P
0 g
s
.71542 .12197 m .71342 .12292 L .71043 .12103 L p .337 .607 .947 r
F P
0 g
s
.71342 .12292 m .71542 .12197 L .71752 .12322 L p .332 .591 .939 r
F P
0 g
s
.56366 .45541 m .56484 .45955 L .56163 .46024 L p .843 .646 .635 r
F P
0 g
s
.56163 .46024 m .56044 .4562 L .56366 .45541 L p .843 .646 .635 r
F P
0 g
s
.73218 .13607 m .72843 .13081 L .73052 .13159 L p .2 .456 .878 r
F P
0 g
s
.73052 .13159 m .73522 .13721 L .73218 .13607 L p .2 .456 .878 r
F P
0 g
s
.56484 .45955 m .5656 .46396 L .56232 .4646 L p .848 .678 .671 r
F P
0 g
s
.56246 .46932 m .56232 .4646 L .5656 .46396 L p .851 .711 .708 r
F P
0 g
s
.70553 .11757 m .6991 .11693 L .69663 .11488 L p .367 .672 .975 r
F P
0 g
s
.6991 .11693 m .70553 .11757 L .70777 .11922 L p .396 .663 .967 r
F P
0 g
s
.56232 .4646 m .56163 .46024 L .56484 .45955 L p .848 .678 .671 r
F P
0 g
s
.4391 .70978 m .45352 .62297 L .45397 .62177 L p .718 .681 .136 r
F P
0 g
s
.48151 .56955 m .45397 .62177 L .45352 .62297 L p 0 0 0 r
F P
0 g
s
.55156 .44239 m .55436 .44553 L .55184 .44659 L p .838 .508 .43 r
F P
0 g
s
.55184 .44659 m .54907 .44367 L .55156 .44239 L p .838 .508 .43 r
F P
0 g
s
.61307 .42857 m .60935 .4327 L .60583 .43271 L p .332 .045 .319 r
F P
0 g
s
.60312 .43695 m .60583 .43271 L .60935 .4327 L p .327 .07 .363 r
F P
0 g
s
.47991 .37539 m .47527 .37895 L .47393 .37609 L p .843 .877 .866 r
F P
0 g
s
.47393 .37609 m .47843 .37236 L .47991 .37539 L p .843 .877 .866 r
F P
0 g
s
.63718 .41194 m .63081 .41622 L .62785 .41597 L p .077 0 0 r
F P
0 g
s
.62232 .42024 m .62785 .41597 L .63081 .41622 L p .068 0 0 r
F P
0 g
s
.60097 .44119 m .59939 .44547 L .59588 .44577 L p .469 .29 .554 r
F P
0 g
s
.59517 .45015 m .59588 .44577 L .59939 .44547 L p .469 .32 .596 r
F P
0 g
s
.69171 .88819 m .71049 .88248 L .70983 .88315 L p .191 0 0 r
F P
0 g
s
.70983 .88315 m .68955 .89032 L .69171 .88819 L p .191 0 0 r
F P
0 g
s
.48595 .43897 m .48086 .44301 L .47991 .44043 L p .36 .063 .318 r
F P
0 g
s
.47991 .44043 m .48511 .43657 L .48595 .43897 L p .36 .063 .318 r
F P
0 g
s
.46443 .38435 m .45804 .38606 L .45682 .38325 L p .701 .828 .943 r
F P
0 g
s
.44955 .38399 m .45682 .38325 L .45804 .38606 L p .64 .798 .958 r
F P
0 g
s
.72295 .12826 m .72173 .1255 L .72366 .12644 L p .259 .524 .912 r
F P
0 g
s
.72366 .12644 m .72586 .12968 L .72295 .12826 L p .259 .524 .912 r
F P
0 g
s
.71345 .12072 m .71043 .12103 L .70777 .11922 L p .333 .619 .955 r
F P
0 g
s
.71043 .12103 m .71345 .12072 L .71542 .12197 L p .337 .607 .947 r
F P
0 g
s
.56246 .46932 m .56193 .47449 L .55899 .47498 L p .904 .794 .728 r
F P
0 g
s
.55723 .48079 m .55899 .47498 L .56193 .47449 L p .898 .831 .771 r
F P
0 g
s
.55436 .44553 m .55678 .44887 L .55428 .44975 L p .855 .547 .466 r
F P
0 g
s
.55428 .44975 m .55184 .44659 L .55436 .44553 L p .855 .547 .466 r
F P
0 g
s
.55723 .48079 m .55419 .48743 L .5515 .48786 L p .928 .935 .786 r
F P
0 g
s
.54612 .49582 m .5515 .48786 L .55419 .48743 L p .9 .96 .823 r
F P
0 g
s
.43143 .38203 m .41975 .37879 L .41869 .37642 L p .25 .647 .963 r
F P
0 g
s
.4041 .37078 m .41869 .37642 L .41975 .37879 L p .182 .591 .941 r
F P
0 g
s
.59927 .46352 m .60119 .46842 L .59811 .46887 L p .468 .47 .776 r
F P
0 g
s
.59811 .46887 m .59634 .46393 L .59927 .46352 L p .468 .47 .776 r
F P
0 g
s
.47527 .37895 m .47013 .38196 L .46888 .37919 L p .803 .867 .896 r
F P
0 g
s
.46888 .37919 m .47393 .37609 L .47527 .37895 L p .803 .867 .896 r
F P
0 g
s
.5606 .88498 m .64176 .89998 L .64245 .90192 L p .388 0 0 r
F P
0 g
s
.64245 .90192 m .56116 .88851 L .5606 .88498 L p .388 0 0 r
F P
0 g
s
.77571 .60549 m .80559 .6821 L .80282 .68045 L p 0 0 .42 r
F P
0 g
s
.80282 .68045 m .77324 .60455 L .77571 .60549 L p 0 0 .42 r
F P
0 g
s
.80042 .76487 m .80282 .68045 L .80559 .6821 L p 0 0 .215 r
F P
0 g
s
.49446 .3452 m .49198 .35173 L .49066 .34945 L p .97 .928 .623 r
F P
0 g
s
.49066 .34945 m .49294 .34273 L .49446 .3452 L p .97 .928 .623 r
F P
0 g
s
.47013 .38196 m .46443 .38435 L .46322 .3816 L p .755 .851 .922 r
F P
0 g
s
.45682 .38325 m .46322 .3816 L .46443 .38435 L p .701 .828 .943 r
F P
0 g
s
.46322 .3816 m .46888 .37919 L .47013 .38196 L p .755 .851 .922 r
F P
0 g
s
.72596 .87357 m .74007 .86058 L .74274 .85991 L p .064 0 0 r
F P
0 g
s
.74007 .86058 m .72596 .87357 L .72477 .87401 L p .121 0 .002 r
F P
0 g
s
.73304 .55518 m .77571 .60549 L .77324 .60455 L p 0 .025 .564 r
F P
0 g
s
.77324 .60455 m .73129 .55477 L .73304 .55518 L p 0 .025 .564 r
F P
0 g
s
.59939 .44547 m .59838 .44982 L .59517 .45015 L p .469 .32 .596 r
F P
0 g
s
.59497 .45462 m .59517 .45015 L .59838 .44982 L p .468 .354 .64 r
F P
0 g
s
.60664 .47321 m .61146 .47864 L .60871 .47906 L p .319 .487 .869 r
F P
0 g
s
.60871 .47906 m .60423 .47357 L .60664 .47321 L p .319 .487 .869 r
F P
0 g
s
.54612 .49582 m .53808 .50573 L .53595 .50611 L p .803 .99 .741 r
F P
0 g
s
.53595 .50611 m .53808 .50573 L p .52885 .51442 L .775 .989 .754 r
F P
0 g
s
.53595 .50611 m .54446 .4961 L .54612 .49582 L p .803 .99 .741 r
F P
0 g
s
.53595 .50611 m .53606 .50613 L p .54189 .49917 L 0 0 0 r
F P
0 g
s
.54446 .4961 m .53595 .50611 L p .54189 .49917 L 0 0 0 r
F P
0 g
s
.52349 .51946 m .53595 .50611 L p .52885 .51442 L .775 .989 .754 r
F P
0 g
s
.49095 .43594 m .48595 .43897 L .48511 .43657 L p .408 .08 .295 r
F P
0 g
s
.48511 .43657 m .49022 .43365 L .49095 .43594 L p .408 .08 .295 r
F P
0 g
s
.55678 .44887 m .55881 .45242 L .55634 .45316 L p .871 .588 .506 r
F P
0 g
s
.55634 .45316 m .55428 .44975 L .55678 .44887 L p .871 .588 .506 r
F P
0 g
s
.60935 .4327 m .60624 .43685 L .60312 .43695 L p .327 .07 .363 r
F P
0 g
s
.60097 .44119 m .60312 .43695 L .60624 .43685 L p .324 .1 .412 r
F P
0 g
s
.59824 .45881 m .59927 .46352 L .59634 .46393 L p .469 .429 .731 r
F P
0 g
s
.59634 .46393 m .59533 .4592 L .59824 .45881 L p .469 .429 .731 r
F P
0 g
s
.4279 .54441 m .40308 .5817 L .40391 .581 L p .617 .823 .42 r
F P
0 g
s
.40391 .581 m .42839 .54411 L .4279 .54441 L p .617 .823 .42 r
F P
0 g
s
.06528 .49989 m .0632 .49999 L .06319 .499 L p .995 .816 .451 r
F P
0 g
s
.06319 .499 m .06523 .49678 L .06528 .49989 L p .995 .816 .451 r
F P
0 g
s
.0632 .49999 m .06528 .49989 L .06525 .50301 L p .995 .809 .443 r
F P
0 g
s
.63081 .41622 m .62501 .42039 L .62232 .42024 L p .068 0 0 r
F P
0 g
s
.61739 .42443 m .62232 .42024 L .62501 .42039 L p .058 0 0 r
F P
0 g
s
.56232 .4646 m .56246 .46932 L .55978 .4698 L p .905 .754 .684 r
F P
0 g
s
.55899 .47498 m .55978 .4698 L .56246 .46932 L p .904 .794 .728 r
F P
0 g
s
.75069 .15695 m .7438 .14594 L .74568 .14598 L p .002 .26 .765 r
F P
0 g
s
.74568 .14598 m .75322 .15704 L .75069 .15695 L p .002 .26 .765 r
F P
0 g
s
.59838 .44982 m .59798 .45425 L .59497 .45462 L p .468 .354 .64 r
F P
0 g
s
.59533 .4592 m .59497 .45462 L .59798 .45425 L p .469 .39 .686 r
F P
0 g
s
.47092 .45676 m .46537 .46597 L .46467 .46405 L p 0 0 .08 r
F P
0 g
s
.46467 .46405 m .47031 .45514 L .47092 .45676 L p 0 0 .08 r
F P
0 g
s
.52706 .43322 m .52311 .43219 L .52354 .43026 L p .674 .212 .147 r
F P
0 g
s
.52354 .43026 m .52772 .43141 L .52706 .43322 L p .674 .212 .147 r
F P
0 g
s
.51915 .42941 m .52354 .43026 L .52311 .43219 L p .649 .192 .153 r
F P
0 g
s
.06319 .50098 m .06525 .50301 L .06514 .50603 L p .994 .801 .429 r
F P
0 g
s
.06525 .50301 m .06319 .50098 L .0632 .49999 L p .995 .809 .443 r
F P
0 g
s
.28245 .33181 m .22509 .33266 L .22276 .33124 L p .146 .686 .83 r
F P
0 g
s
.22509 .33266 m .16301 .35188 L .16032 .3507 L p .391 .851 .84 r
F P
0 g
s
.16032 .3507 m .22276 .33124 L .22509 .33266 L p .391 .851 .84 r
F P
0 g
s
.53078 .43448 m .52706 .43322 L .52772 .43141 L p .698 .234 .146 r
F P
0 g
s
.52772 .43141 m .53166 .4328 L .53078 .43448 L p .698 .234 .146 r
F P
0 g
s
.49587 .43374 m .49095 .43594 L .49022 .43365 L p .452 .097 .271 r
F P
0 g
s
.49022 .43365 m .49525 .43152 L .49587 .43374 L p .452 .097 .271 r
F P
0 g
s
.65471 .1098 m .67075 .1092 L .67204 .11131 L p .477 .823 .998 r
F P
0 g
s
.68489 .11182 m .67204 .11131 L .67075 .1092 L p .393 .767 .992 r
F P
0 g
s
.52311 .43219 m .51895 .43143 L .51915 .42941 L p .649 .192 .153 r
F P
0 g
s
.51459 .42891 m .51915 .42941 L .51895 .43143 L p .623 .174 .164 r
F P
0 g
s
.59798 .45425 m .59824 .45881 L .59533 .4592 L p .469 .39 .686 r
F P
0 g
s
.55881 .45242 m .56044 .4562 L .55798 .45683 L p .884 .63 .549 r
F P
0 g
s
.55798 .45683 m .55634 .45316 L .55881 .45242 L p .884 .63 .549 r
F P
0 g
s
.06523 .49678 m .06319 .499 L .06315 .49805 L p .994 .822 .455 r
F P
0 g
s
.06315 .49805 m .06511 .49382 L .06523 .49678 L p .994 .822 .455 r
F P
0 g
s
.53166 .4328 m .53543 .43444 L .53435 .43596 L p .721 .26 .157 r
F P
0 g
s
.53435 .43596 m .53078 .43448 L .53166 .4328 L p .721 .26 .157 r
F P
0 g
s
.51895 .43143 m .5146 .43099 L .51459 .42891 L p .623 .174 .164 r
F P
0 g
s
.50989 .42881 m .51459 .42891 L .5146 .43099 L p .595 .157 .18 r
F P
0 g
s
.72586 .12968 m .72366 .12644 L .72535 .12718 L p .214 .495 .901 r
F P
0 g
s
.72535 .12718 m .72843 .13081 L .72586 .12968 L p .214 .495 .901 r
F P
0 g
s
.49198 .35173 m .48918 .35772 L .48803 .35561 L p .958 .947 .669 r
F P
0 g
s
.48803 .35561 m .49066 .34945 L .49198 .35173 L p .958 .947 .669 r
F P
0 g
s
.5146 .43099 m .51009 .43093 L .50989 .42881 L p .595 .157 .18 r
F P
0 g
s
.50509 .42918 m .50989 .42881 L .51009 .43093 L p .564 .142 .199 r
F P
0 g
s
.71168 .11952 m .70777 .11922 L .70553 .11757 L p .316 .627 .961 r
F P
0 g
s
.70777 .11922 m .71168 .11952 L .71345 .12072 L p .333 .619 .955 r
F P
0 g
s
.50071 .43223 m .49587 .43374 L .49525 .43152 L p .493 .112 .246 r
F P
0 g
s
.49525 .43152 m .50021 .43005 L .50071 .43223 L p .493 .112 .246 r
F P
0 g
s
.53543 .43444 m .53912 .43636 L .53786 .43772 L p .746 .289 .166 r
F P
0 g
s
.53786 .43772 m .53435 .43596 L .53543 .43444 L p .746 .289 .166 r
F P
0 g
s
.51009 .43093 m .50545 .43133 L .50509 .42918 L p .564 .142 .199 r
F P
0 g
s
.50021 .43005 m .50509 .42918 L .50545 .43133 L p .53 .127 .222 r
F P
0 g
s
.50545 .43133 m .50071 .43223 L .50021 .43005 L p .53 .127 .222 r
F P
0 g
s
.56163 .46024 m .56232 .4646 L .55978 .4651 L p .902 .714 .639 r
F P
0 g
s
.55978 .4698 m .55978 .4651 L .56232 .4646 L p .905 .754 .684 r
F P
0 g
s
.6202 .48428 m .63044 .4909 L .62819 .49122 L p .058 .461 .883 r
F P
0 g
s
.62819 .49122 m .61839 .48454 L .6202 .48428 L p .058 .461 .883 r
F P
0 g
s
.56044 .4562 m .56163 .46024 L .55915 .4608 L p .895 .672 .593 r
F P
0 g
s
.55915 .4608 m .55798 .45683 L .56044 .4562 L p .895 .672 .593 r
F P
0 g
s
.55978 .4651 m .55915 .4608 L .56163 .46024 L p .902 .714 .639 r
F P
0 g
s
.53912 .43636 m .54266 .43855 L .54125 .43973 L p .772 .323 .183 r
F P
0 g
s
.54125 .43973 m .53786 .43772 L .53912 .43636 L p .772 .323 .183 r
F P
0 g
s
.16301 .35188 m .1115 .38915 L .10907 .38845 L p .634 .956 .779 r
F P
0 g
s
.10907 .38845 m .16032 .3507 L .16301 .35188 L p .634 .956 .779 r
F P
0 g
s
.06315 .50194 m .06514 .50603 L .06495 .50879 L p .992 .792 .411 r
F P
0 g
s
.06514 .50603 m .06315 .50194 L .06319 .50098 L p .994 .801 .429 r
F P
0 g
s
.19622 .65955 m .12147 .62227 L .12444 .62131 L p .51 0 0 r
F P
0 g
s
.08362 .57342 m .12444 .62131 L .12147 .62227 L p .774 .291 0 r
F P
0 g
s
.4412 .38366 m .43143 .38203 L .43053 .37999 L p .337 .715 .984 r
F P
0 g
s
.41869 .37642 m .43053 .37999 L .43143 .38203 L p .25 .647 .963 r
F P
0 g
s
.60624 .43685 m .60375 .44102 L .60097 .44119 L p .324 .1 .412 r
F P
0 g
s
.59939 .44547 m .60097 .44119 L .60375 .44102 L p .322 .137 .467 r
F P
0 g
s
.55899 .47498 m .55723 .48079 L .55495 .48115 L p .951 .9 .739 r
F P
0 g
s
.5515 .48786 m .55495 .48115 L .55723 .48079 L p .928 .935 .786 r
F P
0 g
s
.06511 .49382 m .06315 .49805 L .06309 .49719 L p .991 .828 .454 r
F P
0 g
s
.06309 .49719 m .06491 .49114 L .06511 .49382 L p .991 .828 .454 r
F P
0 g
s
.3276 .34089 m .28245 .33181 L .28074 .33049 L p 0 .527 .784 r
F P
0 g
s
.22276 .33124 m .28074 .33049 L .28245 .33181 L p .146 .686 .83 r
F P
0 g
s
.54266 .43855 m .54599 .44099 L .54447 .442 L p .801 .363 .207 r
F P
0 g
s
.54447 .442 m .54125 .43973 L .54266 .43855 L p .801 .363 .207 r
F P
0 g
s
.60338 .4681 m .60664 .47321 L .60423 .47357 L p .321 .434 .821 r
F P
0 g
s
.60423 .47357 m .60119 .46842 L .60338 .4681 L p .321 .434 .821 r
F P
0 g
s
.62501 .42039 m .6198 .42449 L .61739 .42443 L p .058 0 0 r
F P
0 g
s
.61307 .42857 m .61739 .42443 L .6198 .42449 L p .048 0 0 r
F P
0 g
s
.69493 .52646 m .73304 .55518 L .73129 .55477 L p 0 .175 .638 r
F P
0 g
s
.73129 .55477 m .69379 .52631 L .69493 .52646 L p 0 .175 .638 r
F P
0 g
s
.48918 .35772 m .48602 .36316 L .48501 .36122 L p .94 .964 .72 r
F P
0 g
s
.48501 .36122 m .48803 .35561 L .48918 .35772 L p .94 .964 .72 r
F P
0 g
s
.54599 .44099 m .54907 .44367 L .54748 .44453 L p .83 .409 .24 r
F P
0 g
s
.54748 .44453 m .54447 .442 L .54599 .44099 L p .83 .409 .24 r
F P
0 g
s
.73522 .13721 m .73052 .13159 L .73207 .13199 L p .111 .405 .856 r
F P
0 g
s
.73207 .13199 m .73747 .1378 L .73522 .13721 L p .111 .405 .856 r
F P
0 g
s
.73964 .3275 m .75234 .3072 L .75421 .30577 L p 0 0 0 r
F P
0 g
s
.75234 .3072 m .76265 .28431 L .76456 .28274 L p 0 0 0 r
F P
0 g
s
.76456 .28274 m .75421 .30577 L .75234 .3072 L p 0 0 0 r
F P
0 g
s
.68489 .11182 m .69502 .11325 L .69663 .11488 L p .398 .72 .988 r
F P
0 g
s
.70382 .11615 m .69663 .11488 L .69502 .11325 L p .317 .671 .976 r
F P
0 g
s
.69663 .11488 m .70382 .11615 L .70553 .11757 L p .367 .672 .975 r
F P
0 g
s
.72566 .34487 m .73964 .3275 L .7414 .32624 L p 0 0 0 r
F P
0 g
s
.75421 .30577 m .7414 .32624 L .73964 .3275 L p 0 0 0 r
F P
0 g
s
.4762 .4497 m .47092 .45676 L .47031 .45514 L p 0 0 .053 r
F P
0 g
s
.47031 .45514 m .47567 .44829 L .4762 .4497 L p 0 0 .053 r
F P
0 g
s
.76265 .28431 m .76959 .25971 L .77145 .25806 L p 0 0 0 r
F P
0 g
s
.77145 .25806 m .76456 .28274 L .76265 .28431 L p 0 0 0 r
F P
0 g
s
.50567 .5388 m .48151 .56955 L .48138 .57005 L p 0 0 0 r
F P
0 g
s
.45352 .62297 m .48138 .57005 L .48151 .56955 L p 0 0 0 r
F P
0 g
s
.60375 .44102 m .60188 .44526 L .59939 .44547 L p .322 .137 .467 r
F P
0 g
s
.59838 .44982 m .59939 .44547 L .60188 .44526 L p .321 .178 .526 r
F P
0 g
s
.53037 .19798 m .54244 .17787 L .54214 .18017 L p .703 .868 .463 r
F P
0 g
s
.54214 .18017 m .53016 .20012 L .53037 .19798 L p .703 .868 .463 r
F P
0 g
s
.55722 .16104 m .54214 .18017 L .54244 .17787 L p .677 .904 .562 r
F P
0 g
s
.80559 .6821 m .80257 .76677 L .80042 .76487 L p 0 0 .215 r
F P
0 g
s
.77271 .82734 m .80042 .76487 L .80257 .76677 L p 0 0 .017 r
F P
0 g
s
.52123 .21791 m .53037 .19798 L .53016 .20012 L p .717 .825 .372 r
F P
0 g
s
.53016 .20012 m .52108 .21984 L .52123 .21791 L p .717 .825 .372 r
F P
0 g
s
.54907 .44367 m .55184 .44659 L .55022 .44731 L p .86 .461 .282 r
F P
0 g
s
.55022 .44731 m .54748 .44453 L .54907 .44367 L p .86 .461 .282 r
F P
0 g
s
.71138 .35938 m .72566 .34487 L .72726 .34377 L p 0 0 0 r
F P
0 g
s
.7414 .32624 m .72726 .34377 L .72566 .34487 L p 0 0 0 r
F P
0 g
s
.54244 .17787 m .55762 .15865 L .55722 .16104 L p .677 .904 .562 r
F P
0 g
s
.57513 .1439 m .55722 .16104 L .55762 .15865 L p .637 .927 .66 r
F P
0 g
s
.06309 .50281 m .06495 .50879 L .06469 .51117 L p .988 .782 .389 r
F P
0 g
s
.06495 .50879 m .06309 .50281 L .06315 .50194 L p .992 .792 .411 r
F P
0 g
s
.5515 .48786 m .54612 .49582 L .54446 .4961 L p .85 .987 .715 r
F P
0 g
s
.55978 .4698 m .55899 .47498 L .55699 .47531 L p .964 .856 .685 r
F P
0 g
s
.55495 .48115 m .55699 .47531 L .55899 .47498 L p .951 .9 .739 r
F P
0 g
s
.44955 .38399 m .4412 .38366 L .44041 .38186 L p .434 .785 .997 r
F P
0 g
s
.43053 .37999 m .44041 .38186 L .4412 .38366 L p .337 .715 .984 r
F P
0 g
s
.06491 .49114 m .06309 .49719 L .063 .49645 L p .988 .831 .448 r
F P
0 g
s
.063 .49645 m .06464 .48885 L .06491 .49114 L p .988 .831 .448 r
F P
0 g
s
.51453 .23689 m .52123 .21791 L .52108 .21984 L p .724 .783 .294 r
F P
0 g
s
.52108 .21984 m .51444 .23861 L .51453 .23689 L p .724 .783 .294 r
F P
0 g
s
.48602 .36316 m .48245 .36805 L .48156 .36625 L p .914 .977 .774 r
F P
0 g
s
.48156 .36625 m .48501 .36122 L .48602 .36316 L p .914 .977 .774 r
F P
0 g
s
.60135 .46322 m .60338 .4681 L .60119 .46842 L p .322 .38 .766 r
F P
0 g
s
.60119 .46842 m .59927 .46352 L .60135 .46322 L p .322 .38 .766 r
F P
0 g
s
.76959 .25971 m .77254 .23474 L .77425 .23307 L p 0 0 .11 r
F P
0 g
s
.77425 .23307 m .77145 .25806 L .76959 .25971 L p 0 0 .11 r
F P
0 g
s
.72843 .13081 m .72535 .12718 L .72673 .12769 L p .156 .46 .887 r
F P
0 g
s
.72673 .12769 m .73052 .13159 L .72843 .13081 L p .156 .46 .887 r
F P
0 g
s
.7102 .11843 m .70553 .11757 L .70382 .11615 L p .287 .629 .963 r
F P
0 g
s
.70553 .11757 m .7102 .11843 L .71168 .11952 L p .316 .627 .961 r
F P
0 g
s
.6198 .42449 m .61522 .42857 L .61307 .42857 L p .048 0 0 r
F P
0 g
s
.60935 .4327 m .61307 .42857 L .61522 .42857 L p .038 0 .043 r
F P
0 g
s
.4424 .5156 m .4279 .54441 L .42839 .54411 L p .667 .803 .353 r
F P
0 g
s
.42839 .54411 m .44271 .51552 L .4424 .5156 L p .667 .803 .353 r
F P
0 g
s
.55184 .44659 m .55428 .44975 L .55264 .45035 L p .888 .517 .33 r
F P
0 g
s
.55264 .45035 m .55022 .44731 L .55184 .44659 L p .888 .517 .33 r
F P
0 g
s
.71752 .12322 m .71808 .12227 L .71942 .12302 L p .246 .551 .93 r
F P
0 g
s
.71942 .12302 m .71966 .12441 L .71752 .12322 L p .246 .551 .93 r
F P
0 g
s
.71808 .12227 m .71752 .12322 L .71542 .12197 L p .257 .566 .936 r
F P
0 g
s
.6975 .37134 m .71138 .35938 L .71279 .35843 L p 0 0 0 r
F P
0 g
s
.72726 .34377 m .71279 .35843 L .71138 .35938 L p 0 0 0 r
F P
0 g
s
.36093 .35242 m .3276 .34089 L .32644 .33982 L p 0 .415 .74 r
F P
0 g
s
.28074 .33049 m .32644 .33982 L .3276 .34089 L p 0 .527 .784 r
F P
0 g
s
.60188 .44526 m .60066 .44958 L .59838 .44982 L p .321 .178 .526 r
F P
0 g
s
.59798 .45425 m .59838 .44982 L .60066 .44958 L p .321 .224 .586 r
F P
0 g
s
.55762 .15865 m .57563 .14152 L .57513 .1439 L p .637 .927 .66 r
F P
0 g
s
.5951 .12982 m .57513 .1439 L .57563 .14152 L p .584 .932 .751 r
F P
0 g
s
.08362 .57342 m .06807 .53664 L .06901 .53487 L p .954 .612 .236 r
F P
0 g
s
.06401 .5144 m .06901 .53487 L .06807 .53664 L p .968 .701 .277 r
F P
0 g
s
.06901 .53487 m .06401 .5144 L .06437 .51308 L p .986 .727 .349 r
F P
0 g
s
.71966 .12441 m .71942 .12302 L .72072 .1237 L p .226 .533 .922 r
F P
0 g
s
.72072 .1237 m .72173 .1255 L .71966 .12441 L p .226 .533 .922 r
F P
0 g
s
.71676 .12148 m .71542 .12197 L .71345 .12072 L p .26 .577 .942 r
F P
0 g
s
.71542 .12197 m .71676 .12148 L .71808 .12227 L p .257 .566 .936 r
F P
0 g
s
.61298 .47841 m .6202 .48428 L .61839 .48454 L p .051 .412 .862 r
F P
0 g
s
.61839 .48454 m .61146 .47864 L .61298 .47841 L p .051 .412 .862 r
F P
0 g
s
.50973 .25446 m .51453 .23689 L .51444 .23861 L p .725 .744 .231 r
F P
0 g
s
.51444 .23861 m .50967 .25596 L .50973 .25446 L p .725 .744 .231 r
F P
0 g
s
.60031 .45853 m .60135 .46322 L .59927 .46352 L p .322 .325 .708 r
F P
0 g
s
.59927 .46352 m .59824 .45881 L .60031 .45853 L p .322 .325 .708 r
F P
0 g
s
.55428 .44975 m .55634 .45316 L .55469 .45366 L p .915 .575 .385 r
F P
0 g
s
.55469 .45366 m .55264 .45035 L .55428 .44975 L p .915 .575 .385 r
F P
0 g
s
.48133 .44428 m .4762 .4497 L .47567 .44829 L p 0 0 .02 r
F P
0 g
s
.47567 .44829 m .48086 .44301 L .48133 .44428 L p 0 0 .02 r
F P
0 g
s
.60066 .44958 m .60011 .45399 L .59798 .45425 L p .321 .224 .586 r
F P
0 g
s
.59824 .45881 m .59798 .45425 L .60011 .45399 L p .322 .273 .647 r
F P
0 g
s
.55978 .4651 m .55978 .4698 L .55795 .47012 L p .969 .807 .627 r
F P
0 g
s
.55699 .47531 m .55795 .47012 L .55978 .4698 L p .964 .856 .685 r
F P
0 g
s
.7438 .14594 m .73747 .1378 L .7388 .13782 L p 0 .304 .797 r
F P
0 g
s
.7388 .13782 m .74568 .14598 L .7438 .14594 L p 0 .304 .797 r
F P
0 g
s
.48245 .36805 m .47843 .37236 L .47764 .37068 L p .879 .983 .828 r
F P
0 g
s
.47764 .37068 m .48156 .36625 L .48245 .36805 L p .879 .983 .828 r
F P
0 g
s
.67075 .1092 m .68394 .11024 L .68489 .11182 L p .393 .767 .992 r
F P
0 g
s
.69502 .11325 m .68489 .11182 L .68394 .11024 L p .314 .709 .979 r
F P
0 g
s
.60011 .45399 m .60031 .45853 L .59824 .45881 L p .322 .273 .647 r
F P
0 g
s
.77254 .23474 m .77154 .2109 L .77303 .20931 L p 0 0 .251 r
F P
0 g
s
.77303 .20931 m .77425 .23307 L .77254 .23474 L p 0 0 .251 r
F P
0 g
s
.6845 .38121 m .6975 .37134 L .69874 .37054 L p 0 0 0 r
F P
0 g
s
.71279 .35843 m .69874 .37054 L .6975 .37134 L p 0 0 0 r
F P
0 g
s
.45682 .38325 m .44955 .38399 L .44884 .38234 L p .53 .849 .998 r
F P
0 g
s
.44041 .38186 m .44884 .38234 L .44955 .38399 L p .434 .785 .997 r
F P
0 g
s
.1115 .38915 m .0808 .43126 L .07912 .43098 L p .809 .969 .66 r
F P
0 g
s
.07912 .43098 m .10907 .38845 L .1115 .38915 L p .809 .969 .66 r
F P
0 g
s
.55634 .45316 m .55798 .45683 L .55633 .45726 L p .937 .635 .443 r
F P
0 g
s
.55633 .45726 m .55469 .45366 L .55634 .45316 L p .937 .635 .443 r
F P
0 g
s
.06857 .46617 m .06397 .48578 L .06359 .48513 L p .968 .877 .49 r
F P
0 g
s
.06359 .48513 m .06768 .46463 L .06857 .46617 L p .968 .877 .49 r
F P
0 g
s
.72173 .1255 m .72072 .1237 L .72193 .12429 L p .198 .512 .913 r
F P
0 g
s
.72193 .12429 m .72366 .12644 L .72173 .1255 L p .198 .512 .913 r
F P
0 g
s
.71552 .1207 m .71345 .12072 L .71168 .11952 L p .254 .585 .946 r
F P
0 g
s
.71345 .12072 m .71552 .1207 L .71676 .12148 L p .26 .577 .942 r
F P
0 g
s
.50628 .2704 m .50973 .25446 L .50967 .25596 L p .724 .714 .184 r
F P
0 g
s
.50967 .25596 m .50624 .2717 L .50628 .2704 L p .724 .714 .184 r
F P
0 g
s
.57563 .14152 m .59568 .12756 L .5951 .12982 L p .584 .932 .751 r
F P
0 g
s
.6159 .11948 m .5951 .12982 L .59568 .12756 L p .519 .916 .825 r
F P
0 g
s
.55915 .4608 m .55978 .4651 L .55805 .46544 L p .965 .752 .566 r
F P
0 g
s
.55795 .47012 m .55805 .46544 L .55978 .4651 L p .969 .807 .627 r
F P
0 g
s
.61522 .42857 m .61126 .43264 L .60935 .4327 L p .038 0 .043 r
F P
0 g
s
.60624 .43685 m .60935 .4327 L .61126 .43264 L p .028 0 .103 r
F P
0 g
s
.55798 .45683 m .55915 .4608 L .55748 .46117 L p .954 .695 .505 r
F P
0 g
s
.55748 .46117 m .55633 .45726 L .55798 .45683 L p .954 .695 .505 r
F P
0 g
s
.55805 .46544 m .55748 .46117 L .55915 .4608 L p .965 .752 .566 r
F P
0 g
s
.47843 .37236 m .47393 .37609 L .47321 .3745 L p .832 .981 .879 r
F P
0 g
s
.47321 .3745 m .47764 .37068 L .47843 .37236 L p .832 .981 .879 r
F P
0 g
s
.66609 .50976 m .69493 .52646 L .69379 .52631 L p 0 .258 .669 r
F P
0 g
s
.69379 .52631 m .66534 .50972 L .66609 .50976 L p 0 .258 .669 r
F P
0 g
s
.71797 .87743 m .71862 .87865 L .71825 .87887 L p .101 0 0 r
F P
0 g
s
.71825 .87887 m .71612 .87853 L .71797 .87743 L p .101 0 0 r
F P
0 g
s
.71862 .87865 m .71797 .87743 L .71983 .87639 L p .096 0 0 r
F P
0 g
s
.68955 .89032 m .70983 .88315 L .70957 .88361 L p .139 0 0 r
F P
0 g
s
.70957 .88361 m .68863 .89182 L .68955 .89032 L p .139 0 0 r
F P
0 g
s
.48636 .44015 m .48133 .44428 L .48086 .44301 L p .06 0 0 r
F P
0 g
s
.48086 .44301 m .48595 .43897 L .48636 .44015 L p .06 0 0 r
F P
0 g
s
.06301 .50356 m .06469 .51117 L .06437 .51308 L p .982 .771 .363 r
F P
0 g
s
.06469 .51117 m .06301 .50356 L .06309 .50281 L p .988 .782 .389 r
F P
0 g
s
.46322 .3816 m .45682 .38325 L .45615 .38169 L p .622 .902 .986 r
F P
0 g
s
.44884 .38234 m .45615 .38169 L .45682 .38325 L p .53 .849 .998 r
F P
0 g
s
.71612 .87853 m .71825 .87887 L .71791 .87909 L p .102 0 0 r
F P
0 g
s
.71791 .87909 m .71438 .87963 L .71612 .87853 L p .102 0 0 r
F P
0 g
s
.67263 .3894 m .6845 .38121 L .68557 .38052 L p 0 0 0 r
F P
0 g
s
.69874 .37054 m .68557 .38052 L .6845 .38121 L p 0 0 0 r
F P
0 g
s
.71899 .87844 m .71983 .87639 L .72164 .87545 L p .088 0 0 r
F P
0 g
s
.71983 .87639 m .71899 .87844 L .71862 .87865 L p .096 0 0 r
F P
0 g
s
.55495 .48115 m .5515 .48786 L .55016 .48807 L p .902 .973 .672 r
F P
0 g
s
.54446 .4961 m .55016 .48807 L .5515 .48786 L p .85 .987 .715 r
F P
0 g
s
.50371 .28467 m .50628 .2704 L .50624 .2717 L p .723 .693 .153 r
F P
0 g
s
.50624 .2717 m .50369 .2858 L .50371 .28467 L p .723 .693 .153 r
F P
0 g
s
.06464 .48885 m .063 .49645 L .0629 .49586 L p .982 .832 .436 r
F P
0 g
s
.0629 .49586 m .06433 .48704 L .06464 .48885 L p .982 .832 .436 r
F P
0 g
s
.47393 .37609 m .46888 .37919 L .46821 .37765 L p .774 .967 .924 r
F P
0 g
s
.46821 .37765 m .47321 .3745 L .47393 .37609 L p .774 .967 .924 r
F P
0 g
s
.46888 .37919 m .46322 .3816 L .46256 .38008 L p .703 .941 .96 r
F P
0 g
s
.45615 .38169 m .46256 .38008 L .46322 .3816 L p .622 .902 .986 r
F P
0 g
s
.46256 .38008 m .46821 .37765 L .46888 .37919 L p .703 .941 .96 r
F P
0 g
s
.77271 .82734 m .74433 .85991 L .74274 .85991 L p 0 0 .04 r
F P
0 g
s
.72684 .87335 m .74274 .85991 L .74433 .85991 L p 0 0 0 r
F P
0 g
s
.74274 .85991 m .72684 .87335 L .72596 .87357 L p .064 0 0 r
F P
0 g
s
.3855 .36277 m .36093 .35242 L .36016 .35161 L p 0 .359 .714 r
F P
0 g
s
.32644 .33982 m .36016 .35161 L .36093 .35242 L p 0 .415 .74 r
F P
0 g
s
.77154 .2109 m .76724 .18954 L .76848 .1881 L p 0 0 .381 r
F P
0 g
s
.76848 .1881 m .77303 .20931 L .77154 .2109 L p 0 0 .381 r
F P
0 g
s
.60795 .47301 m .61298 .47841 L .61146 .47864 L p .043 .346 .823 r
F P
0 g
s
.61146 .47864 m .60664 .47321 L .60795 .47301 L p .043 .346 .823 r
F P
0 g
s
.72366 .12644 m .72193 .12429 L .72299 .12475 L p .161 .488 .902 r
F P
0 g
s
.72299 .12475 m .72535 .12718 L .72366 .12644 L p .161 .488 .902 r
F P
0 g
s
.71441 .11995 m .71168 .11952 L .7102 .11843 L p .239 .589 .947 r
F P
0 g
s
.71168 .11952 m .71441 .11995 L .71552 .1207 L p .254 .585 .946 r
F P
0 g
s
.49131 .43705 m .48636 .44015 L .48595 .43897 L p .127 0 0 r
F P
0 g
s
.48595 .43897 m .49095 .43594 L .49131 .43705 L p .127 0 0 r
F P
0 g
s
.61126 .43264 m .60794 .43675 L .60624 .43685 L p .028 0 .103 r
F P
0 g
s
.60375 .44102 m .60624 .43685 L .60794 .43675 L p .02 0 .174 r
F P
0 g
s
.71438 .87963 m .71791 .87909 L .7176 .87929 L p .098 0 0 r
F P
0 g
s
.7176 .87929 m .71281 .88068 L .71438 .87963 L p .098 0 0 r
F P
0 g
s
.71935 .87825 m .72164 .87545 L .72331 .87464 L p .076 0 0 r
F P
0 g
s
.72164 .87545 m .71935 .87825 L .71899 .87844 L p .088 0 0 r
F P
0 g
s
.59568 .12756 m .61652 .11744 L .6159 .11948 L p .519 .916 .825 r
F P
0 g
s
.63617 .11296 m .6159 .11948 L .61652 .11744 L p .448 .881 .88 r
F P
0 g
s
.45195 .49407 m .4424 .5156 L .44271 .51552 L p .683 .791 .323 r
F P
0 g
s
.44271 .51552 m .45215 .49409 L .45195 .49407 L p .683 .791 .323 r
F P
0 g
s
.66199 .3963 m .67263 .3894 L .67355 .38881 L p 0 0 0 r
F P
0 g
s
.68557 .38052 m .67355 .38881 L .67263 .3894 L p 0 0 0 r
F P
0 g
s
.50168 .29734 m .50371 .28467 L .50369 .2858 L p .722 .681 .137 r
F P
0 g
s
.50369 .2858 m .50168 .29832 L .50168 .29734 L p .722 .681 .137 r
F P
0 g
s
.52349 .51946 m .50567 .5388 L .5057 .53901 L p 0 0 0 r
F P
0 g
s
.48138 .57005 m .5057 .53901 L .50567 .5388 L p 0 0 0 r
F P
0 g
s
.49617 .4348 m .49131 .43705 L .49095 .43594 L p .19 0 0 r
F P
0 g
s
.49095 .43594 m .49587 .43374 L .49617 .4348 L p .19 0 0 r
F P
0 g
s
.73052 .13159 m .72673 .12769 L .72775 .12795 L p .085 .419 .866 r
F P
0 g
s
.72775 .12795 m .73207 .13199 L .73052 .13159 L p .085 .419 .866 r
F P
0 g
s
.69502 .11325 m .70271 .11502 L .70382 .11615 L p .317 .671 .976 r
F P
0 g
s
.70907 .11749 m .70382 .11615 L .70271 .11502 L p .242 .623 .958 r
F P
0 g
s
.70382 .11615 m .70907 .11749 L .7102 .11843 L p .287 .629 .963 r
F P
0 g
s
.52676 .43406 m .52291 .43308 L .52311 .43219 L p .517 0 0 r
F P
0 g
s
.52311 .43219 m .52706 .43322 L .52676 .43406 L p .517 0 0 r
F P
0 g
s
.51895 .43143 m .52311 .43219 L .52291 .43308 L p .481 0 0 r
F P
0 g
s
.52291 .43308 m .51886 .43236 L .51895 .43143 L p .481 0 0 r
F P
0 g
s
.5146 .43099 m .51895 .43143 L .51886 .43236 L p .442 0 0 r
F P
0 g
s
.53037 .43525 m .52676 .43406 L .52706 .43322 L p .553 0 0 r
F P
0 g
s
.52706 .43322 m .53078 .43448 L .53037 .43525 L p .553 0 0 r
F P
0 g
s
.50095 .43327 m .49617 .4348 L .49587 .43374 L p .25 0 0 r
F P
0 g
s
.49587 .43374 m .50071 .43223 L .50095 .43327 L p .25 0 0 r
F P
0 g
s
.51886 .43236 m .51461 .43196 L .5146 .43099 L p .442 0 0 r
F P
0 g
s
.51009 .43093 m .5146 .43099 L .51461 .43196 L p .4 0 0 r
F P
0 g
s
.51461 .43196 m .51019 .43193 L .51009 .43093 L p .4 0 0 r
F P
0 g
s
.50545 .43133 m .51009 .43093 L .51019 .43193 L p .354 0 0 r
F P
0 g
s
.53078 .43448 m .53435 .43596 L .53385 .43667 L p .59 .022 0 r
F P
0 g
s
.53385 .43667 m .53038 .43525 L .53078 .43448 L p .59 .022 0 r
F P
0 g
s
.50563 .43235 m .50095 .43327 L .50071 .43223 L p .304 0 0 r
F P
0 g
s
.50071 .43223 m .50545 .43133 L .50563 .43235 L p .304 0 0 r
F P
0 g
s
.51019 .43193 m .50563 .43235 L .50545 .43133 L p .354 0 0 r
F P
0 g
s
.53435 .43596 m .53786 .43772 L .53727 .43834 L p .627 .065 0 r
F P
0 g
s
.53727 .43834 m .53385 .43667 L .53435 .43596 L p .627 .065 0 r
F P
0 g
s
.60794 .43675 m .60526 .4409 L .60375 .44102 L p .02 0 .174 r
F P
0 g
s
.60188 .44526 m .60375 .44102 L .60526 .4409 L p .015 0 .254 r
F P
0 g
s
.55699 .47531 m .55495 .48115 L .55383 .48132 L p .946 .942 .612 r
F P
0 g
s
.55016 .48807 m .55383 .48132 L .55495 .48115 L p .902 .973 .672 r
F P
0 g
s
.49994 .30854 m .50168 .29734 L .50168 .29832 L p .722 .679 .133 r
F P
0 g
s
.50168 .29832 m .49994 .30938 L .49994 .30854 L p .722 .679 .133 r
F P
0 g
s
.64176 .89998 m .68863 .89182 L .689 .8926 L p .189 0 0 r
F P
0 g
s
.689 .8926 m .64245 .90192 L .64176 .89998 L p .189 0 0 r
F P
0 g
s
.65258 .4022 m .66199 .3963 L .66277 .3958 L p .377 .797 .6 r
F P
0 g
s
.67355 .38881 m .66277 .3958 L .66199 .3963 L p 0 0 0 r
F P
0 g
s
.53786 .43772 m .54125 .43973 L .54059 .44028 L p .667 .115 0 r
F P
0 g
s
.54059 .44028 m .53727 .43834 L .53786 .43772 L p .667 .115 0 r
F P
0 g
s
.71281 .88068 m .7176 .87929 L .71734 .87948 L p .09 0 0 r
F P
0 g
s
.71734 .87948 m .7115 .88165 L .71281 .88068 L p .09 0 0 r
F P
0 g
s
.71968 .87809 m .72331 .87464 L .72477 .87401 L p .06 0 0 r
F P
0 g
s
.72331 .87464 m .71968 .87809 L .71935 .87825 L p .076 0 0 r
F P
0 g
s
.60457 .46791 m .60795 .47301 L .60664 .47321 L p .034 .27 .767 r
F P
0 g
s
.60664 .47321 m .60338 .4681 L .60457 .46791 L p .034 .27 .767 r
F P
0 g
s
.54125 .43973 m .54447 .442 L .54376 .44247 L p .709 .173 0 r
F P
0 g
s
.54376 .44247 m .54059 .44028 L .54125 .43973 L p .709 .173 0 r
F P
0 g
s
.76724 .18954 m .76075 .1715 L .76172 .17027 L p 0 0 .495 r
F P
0 g
s
.76172 .17027 m .76848 .1881 L .76724 .18954 L p 0 0 .495 r
F P
0 g
s
.12147 .62227 m .0817 .57375 L .08362 .57342 L p .774 .291 0 r
F P
0 g
s
.06807 .53664 m .08362 .57342 L .0817 .57375 L p .894 .533 .061 r
F P
0 g
s
.73747 .1378 m .73207 .13199 L .73299 .13199 L p 0 .341 .821 r
F P
0 g
s
.73299 .13199 m .7388 .13782 L .73747 .1378 L p 0 .341 .821 r
F P
0 g
s
.68394 .11024 m .69435 .11212 L .69502 .11325 L p .314 .709 .979 r
F P
0 g
s
.70271 .11502 m .69502 .11325 L .69435 .11212 L p .242 .654 .961 r
F P
0 g
s
.64542 .49891 m .66609 .50976 L .66534 .50972 L p 0 .286 .679 r
F P
0 g
s
.66534 .50972 m .64491 .49892 L .64542 .49891 L p 0 .286 .679 r
F P
0 g
s
.4041 .37078 m .3855 .36277 L .38516 .36235 L p 0 .352 .711 r
F P
0 g
s
.39054 .36466 m .4041 .37078 L .38516 .36235 L 0 .352 .711 r
F
.41869 .37642 m .4041 .37078 L .40395 .37058 L p 0 .384 .725 r
F P
0 g
s
.40395 .37058 m .40374 .3703 L p .40991 .37282 L 0 .384 .725 r
F P
0 g
s
.40991 .37282 m .41869 .37642 L .40395 .37058 L 0 .384 .725 r
F
.43053 .37999 m .41869 .37642 L .41861 .37631 L p 0 .445 .749 r
F P
0 g
s
.41861 .37631 m .41843 .37603 L p .42395 .37783 L 0 .445 .749 r
F P
0 g
s
.42395 .37783 m .43053 .37999 L .41861 .37631 L 0 .445 .749 r
F
.44041 .38186 m .43053 .37999 L .43034 .37967 L p 0 .524 .774 r
F P
0 g
s
.41843 .37603 m .43034 .37967 L .43053 .37999 L p 0 .445 .749 r
F P
0 g
s
.43034 .37967 m .43088 .3811 L p .4363 .38138 L .472 0 0 r
F P
0 g
s
.43034 .37967 m .44027 .38158 L .44041 .38186 L p 0 .524 .774 r
F P
0 g
s
.44027 .38158 m .43034 .37967 L p .4363 .38138 L .472 0 0 r
F P
0 g
s
.40374 .3703 m .41843 .37603 L .41869 .37642 L p 0 .384 .725 r
F P
0 g
s
.41843 .37603 m .419 .37767 L p .42613 .37893 L .516 0 0 r
F P
0 g
s
.43034 .37967 m .41843 .37603 L p .42613 .37893 L .516 0 0 r
F P
0 g
s
.38498 .36214 m .40374 .3703 L .4041 .37078 L p 0 .352 .711 r
F P
0 g
s
.40374 .3703 m .40433 .37221 L p .41495 .37509 L .546 0 0 r
F P
0 g
s
.41843 .37603 m .40374 .3703 L p .41495 .37509 L .546 0 0 r
F P
0 g
s
.38516 .36235 m .38498 .36214 L p .39054 .36466 L 0 .352 .711 r
F P
0 g
s
.36016 .35161 m .38498 .36214 L .3855 .36277 L p 0 .359 .714 r
F P
0 g
s
.72535 .12718 m .72299 .12475 L .72385 .12507 L p .116 .461 .889 r
F P
0 g
s
.72385 .12507 m .72673 .12769 L .72535 .12718 L p .116 .461 .889 r
F P
0 g
s
.61652 .11744 m .63679 .11121 L .63617 .11296 L p .448 .881 .88 r
F P
0 g
s
.65471 .1098 m .63617 .11296 L .63679 .11121 L p .374 .832 .915 r
F P
0 g
s
.71349 .11926 m .7102 .11843 L .70907 .11749 L p .213 .587 .945 r
F P
0 g
s
.7102 .11843 m .71349 .11926 L .71441 .11995 L p .239 .589 .947 r
F P
0 g
s
.54447 .442 m .54748 .44453 L .54673 .44493 L p .755 .238 0 r
F P
0 g
s
.54673 .44493 m .54376 .44247 L .54447 .442 L p .755 .238 0 r
F P
0 g
s
.60526 .4409 m .60324 .44512 L .60188 .44526 L p .015 0 .254 r
F P
0 g
s
.60066 .44958 m .60188 .44526 L .60324 .44512 L p .011 0 .341 r
F P
0 g
s
.4983 .3184 m .49994 .30854 L .49994 .30938 L p .722 .685 .141 r
F P
0 g
s
.49994 .30938 m .49831 .31913 L .4983 .3184 L p .722 .685 .141 r
F P
0 g
s
.64434 .40736 m .65258 .4022 L .65325 .40178 L p .377 .797 .601 r
F P
0 g
s
.66277 .3958 m .65325 .40178 L .65258 .4022 L p .377 .797 .6 r
F P
0 g
s
.0629 .50415 m .06437 .51308 L .06401 .5144 L p .973 .759 .333 r
F P
0 g
s
.06437 .51308 m .0629 .50415 L .06301 .50356 L p .982 .771 .363 r
F P
0 g
s
.55795 .47012 m .55699 .47531 L .556 .47546 L p .977 .893 .538 r
F P
0 g
s
.55383 .48132 m .556 .47546 L .55699 .47531 L p .946 .942 .612 r
F P
0 g
s
.54748 .44453 m .55022 .44731 L .54945 .44764 L p .803 .312 0 r
F P
0 g
s
.54945 .44764 m .54673 .44493 L .54748 .44453 L p .803 .312 0 r
F P
0 g
s
.06433 .48704 m .0629 .49586 L .06279 .49546 L p .973 .83 .418 r
F P
0 g
s
.06279 .49546 m .06397 .48578 L .06433 .48704 L p .973 .83 .418 r
F P
0 g
s
.60248 .46305 m .60457 .46791 L .60338 .4681 L p .025 .188 .696 r
F P
0 g
s
.60338 .4681 m .60135 .46322 L .60248 .46305 L p .025 .188 .696 r
F P
0 g
s
.45916 .47799 m .45195 .49407 L .45215 .49409 L p .682 .792 .326 r
F P
0 g
s
.45215 .49409 m .4593 .47807 L .45916 .47799 L p .682 .792 .326 r
F P
0 g
s
.71808 .12227 m .7184 .12172 L .71919 .12216 L p .178 .527 .921 r
F P
0 g
s
.71919 .12216 m .71942 .12302 L .71808 .12227 L p .178 .527 .921 r
F P
0 g
s
.7184 .12172 m .71808 .12227 L .71676 .12148 L p .186 .538 .926 r
F P
0 g
s
.80257 .76677 m .77386 .82872 L .77271 .82734 L p 0 0 .017 r
F P
0 g
s
.74433 .85991 m .77271 .82734 L .77386 .82872 L p 0 0 0 r
F P
0 g
s
.60324 .44512 m .6019 .44942 L .60066 .44958 L p .011 0 .341 r
F P
0 g
s
.60011 .45399 m .60066 .44958 L .6019 .44942 L p .011 0 .433 r
F P
0 g
s
.71942 .12302 m .71919 .12216 L .71995 .12256 L p .163 .514 .915 r
F P
0 g
s
.71995 .12256 m .72072 .1237 L .71942 .12302 L p .163 .514 .915 r
F P
0 g
s
.71762 .12126 m .71676 .12148 L .71552 .1207 L p .188 .545 .929 r
F P
0 g
s
.71676 .12148 m .71762 .12126 L .7184 .12172 L p .186 .538 .926 r
F P
0 g
s
.55022 .44731 m .55264 .45035 L .55186 .45063 L p .851 .393 .028 r
F P
0 g
s
.55186 .45063 m .54945 .44764 L .55022 .44731 L p .851 .393 .028 r
F P
0 g
s
.49667 .32706 m .4983 .3184 L .49831 .31913 L p .723 .697 .16 r
F P
0 g
s
.49831 .31913 m .49668 .3277 L .49667 .32706 L p .723 .697 .16 r
F P
0 g
s
.49668 .32771 m .49493 .33548 L .49492 .33492 L p .722 .716 .188 r
F P
0 g
s
.49492 .33492 m .49667 .32707 L .49668 .32771 L p .722 .716 .188 r
F P
0 g
s
.49662 .33651 m .49859 .32869 L .49667 .32707 L p 0 0 .282 r
F P
0 g
s
.60144 .45837 m .60248 .46305 L .60135 .46322 L p .018 .106 .614 r
F P
0 g
s
.60135 .46322 m .60031 .45853 L .60144 .45837 L p .018 .106 .614 r
F P
0 g
s
.0808 .43126 m .06768 .46463 L .06678 .46456 L p .901 .921 .531 r
F P
0 g
s
.06678 .46456 m .07912 .43098 L .0808 .43126 L p .901 .921 .531 r
F P
0 g
s
.7115 .88165 m .71734 .87948 L .71714 .87965 L p .078 0 0 r
F P
0 g
s
.71714 .87965 m .71049 .88248 L .7115 .88165 L p .078 0 0 r
F P
0 g
s
.63719 .41194 m .64434 .40736 L .64492 .40699 L p .381 .798 .596 r
F P
0 g
s
.65325 .40178 m .64492 .40699 L .64434 .40736 L p .377 .797 .601 r
F P
0 g
s
.6019 .44942 m .60128 .45383 L .60011 .45399 L p .011 0 .433 r
F P
0 g
s
.60031 .45853 m .60011 .45399 L .60128 .45383 L p .013 .026 .525 r
F P
0 g
s
.55805 .46544 m .55795 .47012 L .55705 .47027 L p .991 .828 .454 r
F P
0 g
s
.556 .47546 m .55705 .47027 L .55795 .47012 L p .977 .893 .538 r
F P
0 g
s
.55264 .45035 m .55469 .45366 L .5539 .45389 L p .897 .481 .102 r
F P
0 g
s
.5539 .45389 m .55186 .45063 L .55264 .45035 L p .897 .481 .102 r
F P
0 g
s
.71997 .87796 m .72477 .87401 L .72596 .87357 L p .042 0 0 r
F P
0 g
s
.72477 .87401 m .71997 .87796 L .71968 .87809 L p .06 0 0 r
F P
0 g
s
.53595 .50611 m .52349 .51946 L .52359 .51953 L p 0 0 0 r
F P
0 g
s
.5057 .53901 m .52359 .51953 L .52349 .51946 L p 0 0 0 r
F P
0 g
s
.60128 .45383 m .60144 .45837 L .60031 .45853 L p .013 .026 .525 r
F P
0 g
s
.72072 .1237 m .71995 .12256 L .72066 .1229 L p .142 .498 .907 r
F P
0 g
s
.72066 .1229 m .72193 .12429 L .72072 .1237 L p .142 .498 .907 r
F P
0 g
s
.7169 .1208 m .71552 .1207 L .71441 .11995 L p .182 .55 .93 r
F P
0 g
s
.71552 .1207 m .7169 .1208 L .71762 .12126 L p .188 .545 .929 r
F P
0 g
s
.55469 .45366 m .55633 .45726 L .55553 .45745 L p .937 .572 .184 r
F P
0 g
s
.55553 .45745 m .5539 .45389 L .55469 .45366 L p .937 .572 .184 r
F P
0 g
s
.55748 .46117 m .55805 .46544 L .55721 .46559 L p .988 .749 .364 r
F P
0 g
s
.55705 .47027 m .55721 .46559 L .55805 .46544 L p .991 .828 .454 r
F P
0 g
s
.76075 .1715 m .75322 .15704 L .75395 .15605 L p 0 .015 .589 r
F P
0 g
s
.75395 .15605 m .76172 .17027 L .76075 .1715 L p 0 .015 .589 r
F P
0 g
s
.55633 .45726 m .55748 .46117 L .55667 .46134 L p .969 .663 .273 r
F P
0 g
s
.55667 .46134 m .55553 .45745 L .55633 .45726 L p .969 .663 .273 r
F P
0 g
s
.55721 .46559 m .55667 .46134 L .55748 .46117 L p .988 .749 .364 r
F P
0 g
s
.63679 .11121 m .65528 .10838 L .65471 .1098 L p .374 .832 .915 r
F P
0 g
s
.67075 .1092 m .65471 .1098 L .65528 .10838 L p .304 .776 .932 r
F P
0 g
s
.64492 .40699 m .63768 .41163 L .63719 .41194 L p .381 .798 .596 r
F P
0 g
s
.63081 .41622 m .63718 .41194 L .63762 .41167 L p 0 0 0 r
F P
0 g
s
.63081 .41622 m .63762 .41167 L .63689 .41215 L 0 0 0 r
F
.63768 .41163 m .63123 .41595 L .63081 .41622 L p F P
0 g
s
.63123 .41595 m .62907 .41517 L p .62578 .4196 L .73 .989 .876 r
F P
0 g
s
.62501 .42039 m .63081 .41622 L .63116 .41599 L p 0 0 0 r
F P
0 g
s
.63116 .41599 m .63123 .41595 L p .63027 .41664 L 0 0 0 r
F P
0 g
s
.62501 .42039 m .63116 .41599 L .63027 .41664 L 0 0 0 r
F
.63123 .41595 m .62537 .42016 L .62501 .42039 L p F P
0 g
s
.62537 .42016 m .62338 .41955 L p .62061 .42358 L .752 .994 .861 r
F P
0 g
s
.6198 .42449 m .62501 .42039 L .62529 .42021 L p 0 0 0 r
F P
0 g
s
.62529 .42021 m .62537 .42016 L p .62428 .421 L 0 0 0 r
F P
0 g
s
.6198 .42449 m .62529 .42021 L .62428 .421 L 0 0 0 r
F
.62537 .42016 m .62011 .4243 L .6198 .42449 L p F P
0 g
s
.62011 .4243 m .61829 .42385 L p .61602 .42753 L .781 .998 .842 r
F P
0 g
s
.61522 .42857 m .6198 .42449 L .62003 .42435 L p 0 0 0 r
F P
0 g
s
.62003 .42435 m .62011 .4243 L p .61896 .4253 L 0 0 0 r
F P
0 g
s
.61522 .42857 m .62003 .42435 L .61896 .4253 L 0 0 0 r
F
.62011 .4243 m .61548 .4284 L .61522 .42857 L p F P
0 g
s
.61548 .4284 m .61384 .42808 L p .61204 .43148 L .815 1 .815 r
F P
0 g
s
.61126 .43264 m .61522 .42857 L .61539 .42846 L p 0 0 0 r
F P
0 g
s
.61539 .42846 m .61548 .4284 L p .61433 .42956 L 0 0 0 r
F P
0 g
s
.61126 .43264 m .61539 .42846 L .61433 .42956 L 0 0 0 r
F
.61548 .4284 m .61149 .43251 L .61126 .43264 L p F P
0 g
s
.61149 .43251 m .61001 .43229 L p .60865 .43545 L .854 .997 .781 r
F P
0 g
s
.60794 .43675 m .61126 .43264 L .6114 .43256 L p 0 0 0 r
F P
0 g
s
.6114 .43256 m .61149 .43251 L p .61039 .43381 L 0 0 0 r
F P
0 g
s
.60794 .43675 m .6114 .43256 L .61039 .43381 L 0 0 0 r
F
.61149 .43251 m .60814 .43663 L .60794 .43675 L p F P
0 g
s
.60814 .43663 m .60682 .4365 L p .60587 .43947 L .894 .987 .736 r
F P
0 g
s
.60526 .4409 m .60794 .43675 L .60814 .43663 L p 0 0 0 r
F P
0 g
s
.60814 .43663 m .60544 .4408 L .60526 .4409 L p 0 0 0 r
F P
0 g
s
.60544 .4408 m .60814 .43663 L p .60587 .43947 L .894 .987 .736 r
F P
0 g
s
.60814 .43663 m .61149 .43251 L p .60865 .43545 L .854 .997 .781 r
F P
0 g
s
.61149 .43251 m .61548 .4284 L p .61204 .43148 L .815 1 .815 r
F P
0 g
s
.61548 .4284 m .62011 .4243 L p .61602 .42753 L .781 .998 .842 r
F P
0 g
s
.62011 .4243 m .62537 .42016 L p .62061 .42358 L .752 .994 .861 r
F P
0 g
s
.62537 .42016 m .63123 .41595 L p .62578 .4196 L .73 .989 .876 r
F P
0 g
s
.63762 .41167 m .63768 .41163 L p .63689 .41215 L 0 0 0 r
F P
0 g
s
.6308 .49087 m .64542 .49891 L .64491 .49892 L p 0 .272 .674 r
F P
0 g
s
.64491 .49892 m .63044 .4909 L .6308 .49087 L p 0 .272 .674 r
F P
0 g
s
.46527 .46588 m .45916 .47799 L .4593 .47807 L p .668 .805 .355 r
F P
0 g
s
.4593 .47807 m .46537 .46597 L .46527 .46588 L p .668 .805 .355 r
F P
0 g
s
.72193 .12429 m .72066 .1229 L .72128 .12318 L p .114 .48 .897 r
F P
0 g
s
.72128 .12318 m .72299 .12475 L .72193 .12429 L p .114 .48 .897 r
F P
0 g
s
.71624 .12035 m .71441 .11995 L .71349 .11926 L p .169 .551 .929 r
F P
0 g
s
.71441 .11995 m .71624 .12035 L .7169 .1208 L p .182 .55 .93 r
F P
0 g
s
.72673 .12769 m .72385 .12507 L .72449 .12523 L p .061 .429 .871 r
F P
0 g
s
.72449 .12523 m .72775 .12795 L .72673 .12769 L p .061 .429 .871 r
F P
0 g
s
.49493 .33548 m .49294 .34273 L .49292 .34225 L p .72 .74 .225 r
F P
0 g
s
.49292 .34225 m .49492 .33492 L .49493 .33548 L p .72 .74 .225 r
F P
0 g
s
.70271 .11502 m .70834 .11674 L .70907 .11749 L p .242 .623 .958 r
F P
0 g
s
.71278 .11867 m .70907 .11749 L .70834 .11674 L p .176 .578 .937 r
F P
0 g
s
.70907 .11749 m .71278 .11867 L .71349 .11926 L p .213 .587 .945 r
F P
0 g
s
.73207 .13199 m .72775 .12795 L .72835 .12795 L p 0 .371 .837 r
F P
0 g
s
.72835 .12795 m .73299 .13199 L .73207 .13199 L p 0 .371 .837 r
F P
0 g
s
.69435 .11212 m .70225 .11424 L .70271 .11502 L p .242 .654 .961 r
F P
0 g
s
.70834 .11674 m .70271 .11502 L .70225 .11424 L p .18 .604 .942 r
F P
0 g
s
.49294 .34273 m .49066 .34945 L .49063 .34903 L p .714 .768 .273 r
F P
0 g
s
.49063 .34903 m .49292 .34225 L .49294 .34273 L p .714 .768 .273 r
F P
0 g
s
.52359 .51953 m .53606 .50613 L .53595 .50611 L p 0 0 0 r
F P
0 g
s
.71049 .88248 m .71714 .87965 L .71702 .87978 L p .063 0 0 r
F P
0 g
s
.71702 .87978 m .70983 .88315 L .71049 .88248 L p .063 0 0 r
F P
0 g
s
.72021 .87788 m .72596 .87357 L .72684 .87335 L p .022 0 0 r
F P
0 g
s
.72596 .87357 m .72021 .87788 L .71997 .87796 L p .042 0 0 r
F P
0 g
s
.75322 .15704 m .74568 .14598 L .74621 .14521 L p 0 .113 .664 r
F P
0 g
s
.74621 .14521 m .75395 .15605 L .75322 .15704 L p 0 .113 .664 r
F P
0 g
s
.47085 .45666 m .46527 .46588 L .46537 .46597 L p .643 .823 .403 r
F P
0 g
s
.46537 .46597 m .47092 .45676 L .47085 .45666 L p .643 .823 .403 r
F P
0 g
s
.65528 .10838 m .67123 .10809 L .67075 .1092 L p .304 .776 .932 r
F P
0 g
s
.68394 .11024 m .67075 .1092 L .67123 .10809 L p .24 .718 .936 r
F P
0 g
s
.72299 .12475 m .72128 .12318 L .72179 .12336 L p .081 .459 .886 r
F P
0 g
s
.72179 .12336 m .72385 .12507 L .72299 .12475 L p .081 .459 .886 r
F P
0 g
s
.7157 .11995 m .71349 .11926 L .71278 .11867 L p .149 .547 .925 r
F P
0 g
s
.71349 .11926 m .7157 .11995 L .71624 .12035 L p .169 .551 .929 r
F P
0 g
s
.49066 .34945 m .48803 .35561 L .488 .35525 L p .703 .799 .33 r
F P
0 g
s
.488 .35525 m .49063 .34903 L .49066 .34945 L p .703 .799 .33 r
F P
0 g
s
.62047 .48424 m .6308 .49087 L .63044 .4909 L p 0 .223 .655 r
F P
0 g
s
.63044 .4909 m .6202 .48428 L .62047 .48424 L p 0 .223 .655 r
F P
0 g
s
.0632 .49999 m .06262 .5 L .06262 .4998 L p .971 .794 .367 r
F P
0 g
s
.06262 .4998 m .06319 .499 L .0632 .49999 L p .971 .794 .367 r
F P
0 g
s
.06262 .5 m .0632 .49999 L .06319 .50098 L p .971 .791 .363 r
F P
0 g
s
.06807 .53664 m .06363 .51509 L .06401 .5144 L p .968 .701 .277 r
F P
0 g
s
.06279 .50456 m .06401 .5144 L .06363 .51509 L p .962 .746 .3 r
F P
0 g
s
.06401 .5144 m .06279 .50456 L .0629 .50415 L p .973 .759 .333 r
F P
0 g
s
.06262 .5002 m .06319 .50098 L .06315 .50194 L p .97 .788 .358 r
F P
0 g
s
.06319 .50098 m .06262 .5002 L .06262 .5 L p .971 .791 .363 r
F P
0 g
s
.06319 .499 m .06262 .4998 L .06261 .49961 L p .97 .796 .368 r
F P
0 g
s
.06261 .49961 m .06315 .49805 L .06319 .499 L p .97 .796 .368 r
F P
0 g
s
.06397 .48578 m .06279 .49546 L .06267 .49525 L p .961 .824 .395 r
F P
0 g
s
.06267 .49525 m .06359 .48513 L .06397 .48578 L p .961 .824 .395 r
F P
0 g
s
.48803 .35561 m .48501 .36122 L .48497 .36089 L p .684 .831 .397 r
F P
0 g
s
.48497 .36089 m .488 .35525 L .48803 .35561 L p .684 .831 .397 r
F P
0 g
s
.06261 .50039 m .06315 .50194 L .06309 .50281 L p .968 .784 .351 r
F P
0 g
s
.06315 .50194 m .06261 .50039 L .06262 .5002 L p .97 .788 .358 r
F P
0 g
s
.06315 .49805 m .06261 .49961 L .0626 .49944 L p .968 .797 .367 r
F P
0 g
s
.0626 .49944 m .06309 .49719 L .06315 .49805 L p .968 .797 .367 r
F P
0 g
s
.7184 .12172 m .71858 .12141 L .719 .12165 L p .119 .503 .907 r
F P
0 g
s
.719 .12165 m .71919 .12216 L .7184 .12172 L p .119 .503 .907 r
F P
0 g
s
.71858 .12141 m .7184 .12172 L .71762 .12126 L p .125 .511 .911 r
F P
0 g
s
.47615 .44959 m .47085 .45666 L .47092 .45676 L p .605 .839 .463 r
F P
0 g
s
.47092 .45676 m .4762 .4497 L .47615 .44959 L p .605 .839 .463 r
F P
0 g
s
.71919 .12216 m .719 .12165 L .71942 .12187 L p .109 .494 .903 r
F P
0 g
s
.71942 .12187 m .71995 .12256 L .71919 .12216 L p .109 .494 .903 r
F P
0 g
s
.71816 .12116 m .71762 .12126 L .7169 .1208 L p .125 .515 .912 r
F P
0 g
s
.71762 .12126 m .71816 .12116 L .71858 .12141 L p .125 .511 .911 r
F P
0 g
s
.55016 .48807 m .54446 .4961 L .54457 .49609 L p 0 0 0 r
F P
0 g
s
.53606 .50613 m .54457 .49609 L .54446 .4961 L p 0 0 0 r
F P
0 g
s
.44884 .38234 m .44041 .38186 L .44027 .38158 L p .051 .613 .792 r
F P
0 g
s
.48501 .36122 m .48156 .36625 L .48152 .36596 L p .654 .858 .47 r
F P
0 g
s
.48152 .36596 m .48497 .36089 L .48501 .36122 L p .654 .858 .47 r
F P
0 g
s
.71995 .12256 m .71942 .12187 L .7198 .12205 L p .094 .483 .897 r
F P
0 g
s
.7198 .12205 m .72066 .1229 L .71995 .12256 L p .094 .483 .897 r
F P
0 g
s
.71776 .12091 m .7169 .1208 L .71624 .12035 L p .121 .518 .912 r
F P
0 g
s
.7169 .1208 m .71776 .12091 L .71816 .12116 L p .125 .515 .912 r
F P
0 g
s
.0817 .57375 m .0671 .53672 L .06807 .53664 L p .894 .533 .061 r
F P
0 g
s
.06363 .51509 m .06807 .53664 L .0671 .53672 L p .935 .666 .193 r
F P
0 g
s
.61319 .47837 m .62047 .48424 L .6202 .48428 L p 0 .143 .618 r
F P
0 g
s
.6202 .48428 m .61298 .47841 L .61319 .47837 L p 0 .143 .618 r
F P
0 g
s
.0626 .50056 m .06309 .50281 L .06301 .50356 L p .966 .78 .343 r
F P
0 g
s
.06309 .50281 m .0626 .50056 L .06261 .50039 L p .968 .784 .351 r
F P
0 g
s
.06309 .49719 m .0626 .49944 L .06258 .4993 L p .966 .797 .364 r
F P
0 g
s
.06258 .4993 m .063 .49645 L .06309 .49719 L p .966 .797 .364 r
F P
0 g
s
.48129 .44417 m .47615 .44959 L .4762 .4497 L p .554 .849 .527 r
F P
0 g
s
.4762 .4497 m .48133 .44428 L .48129 .44417 L p .554 .849 .527 r
F P
0 g
s
.74568 .14598 m .7388 .13782 L .73917 .13726 L p 0 .195 .722 r
F P
0 g
s
.73917 .13726 m .74621 .14521 L .74568 .14598 L p 0 .195 .722 r
F P
0 g
s
.48156 .36625 m .47764 .37068 L .4776 .37042 L p .609 .876 .546 r
F P
0 g
s
.4776 .37042 m .48152 .36596 L .48156 .36625 L p .609 .876 .546 r
F P
0 g
s
.67123 .10809 m .68434 .10941 L .68394 .11024 L p .24 .718 .936 r
F P
0 g
s
.69435 .11212 m .68394 .11024 L .68434 .10941 L p .184 .662 .931 r
F P
0 g
s
.72385 .12507 m .72179 .12336 L .72216 .12346 L p .042 .436 .872 r
F P
0 g
s
.72216 .12346 m .72449 .12523 L .72385 .12507 L p .042 .436 .872 r
F P
0 g
s
.70834 .11674 m .71232 .11821 L .71278 .11867 L p .176 .578 .937 r
F P
0 g
s
.71528 .11961 m .71278 .11867 L .71232 .11821 L p .121 .539 .917 r
F P
0 g
s
.71278 .11867 m .71528 .11961 L .7157 .11995 L p .149 .547 .925 r
F P
0 g
s
.45615 .38169 m .44884 .38234 L .44873 .38209 L p .159 .7 .795 r
F P
0 g
s
.44027 .38158 m .44873 .38209 L .44884 .38234 L p .051 .613 .792 r
F P
0 g
s
.06768 .46463 m .06359 .48513 L .06321 .48512 L p .936 .859 .429 r
F P
0 g
s
.06321 .48512 m .06678 .46456 L .06768 .46463 L p .936 .859 .429 r
F P
0 g
s
.72775 .12795 m .72449 .12523 L .72486 .12523 L p 0 .394 .848 r
F P
0 g
s
.72486 .12523 m .72835 .12795 L .72775 .12795 L p 0 .394 .848 r
F P
0 g
s
.70225 .11424 m .70804 .11623 L .70834 .11674 L p .18 .604 .942 r
F P
0 g
s
.71232 .11821 m .70834 .11674 L .70804 .11623 L p .128 .56 .922 r
F P
0 g
s
.47764 .37068 m .47321 .3745 L .47316 .37426 L p .548 .881 .621 r
F P
0 g
s
.47316 .37426 m .4776 .37042 L .47764 .37068 L p .548 .881 .621 r
F P
0 g
s
.72066 .1229 m .7198 .12205 L .72014 .1222 L p .075 .47 .889 r
F P
0 g
s
.72014 .1222 m .72128 .12318 L .72066 .1229 L p .075 .47 .889 r
F P
0 g
s
.71741 .12067 m .71624 .12035 L .7157 .11995 L p .112 .517 .91 r
F P
0 g
s
.71624 .12035 m .71741 .12067 L .71776 .12091 L p .121 .518 .912 r
F P
0 g
s
.68863 .89182 m .70957 .88361 L .7097 .88385 L p .076 0 0 r
F P
0 g
s
.7097 .88385 m .689 .8926 L .68863 .89182 L p .076 0 0 r
F P
0 g
s
.48633 .44004 m .48129 .44417 L .48133 .44428 L p .492 .847 .59 r
F P
0 g
s
.48133 .44428 m .48636 .44015 L .48633 .44004 L p .492 .847 .59 r
F P
0 g
s
.46256 .38008 m .45615 .38169 L .45606 .38146 L p .27 .775 .779 r
F P
0 g
s
.44873 .38209 m .45606 .38146 L .45615 .38169 L p .159 .7 .795 r
F P
0 g
s
.55383 .48132 m .55016 .48807 L .55026 .48804 L p 0 0 0 r
F P
0 g
s
.54457 .49609 m .55026 .48804 L .55016 .48807 L p 0 0 0 r
F P
0 g
s
.47321 .3745 m .46821 .37765 L .46815 .37742 L p .47 .868 .689 r
F P
0 g
s
.46815 .37742 m .47316 .37426 L .47321 .3745 L p .47 .868 .689 r
F P
0 g
s
.46821 .37765 m .46256 .38008 L .46249 .37985 L p .376 .832 .743 r
F P
0 g
s
.45606 .38146 m .46249 .37985 L .46256 .38008 L p .27 .775 .779 r
F P
0 g
s
.46249 .37985 m .46815 .37742 L .46821 .37765 L p .376 .832 .743 r
F P
0 g
s
.77386 .82872 m .74479 .86058 L .74433 .85991 L p 0 0 0 r
F P
0 g
s
.72735 .87335 m .74433 .85991 L .74479 .86058 L p 0 0 0 r
F P
0 g
s
.74433 .85991 m .72735 .87335 L .72684 .87335 L p 0 0 0 r
F P
0 g
s
.60812 .47297 m .61319 .47837 L .61298 .47841 L p 0 .036 .558 r
F P
0 g
s
.61298 .47841 m .60795 .47301 L .60812 .47297 L p 0 .036 .558 r
F P
0 g
s
.70983 .88315 m .71702 .87978 L .71696 .87987 L p .044 0 0 r
F P
0 g
s
.71696 .87987 m .70957 .88361 L .70983 .88315 L p .044 0 0 r
F P
0 g
s
.06258 .5007 m .06301 .50356 L .0629 .50415 L p .962 .775 .333 r
F P
0 g
s
.06301 .50356 m .06258 .5007 L .0626 .50056 L p .966 .78 .343 r
F P
0 g
s
.49129 .43694 m .48633 .44004 L .48636 .44015 L p .421 .832 .645 r
F P
0 g
s
.48636 .44015 m .49131 .43705 L .49129 .43694 L p .421 .832 .645 r
F P
0 g
s
.063 .49645 m .06258 .4993 L .06256 .49918 L p .962 .796 .359 r
F P
0 g
s
.06256 .49918 m .0629 .49586 L .063 .49645 L p .962 .796 .359 r
F P
0 g
s
.72039 .87783 m .72684 .87335 L .72735 .87335 L p 0 0 0 r
F P
0 g
s
.72684 .87335 m .72039 .87783 L .72021 .87788 L p .022 0 0 r
F P
0 g
s
.49617 .43469 m .49129 .43694 L .49131 .43705 L p .344 .804 .69 r
F P
0 g
s
.49131 .43705 m .49617 .4348 L .49617 .43469 L p .344 .804 .69 r
F P
0 g
s
.50096 .43316 m .49617 .43469 L .49617 .4348 L p .266 .766 .723 r
F P
0 g
s
.49617 .4348 m .50095 .43327 L .50096 .43316 L p .266 .766 .723 r
F P
0 g
s
.52295 .43297 m .51889 .43225 L .51886 .43236 L p 0 .513 .75 r
F P
0 g
s
.51886 .43236 m .52291 .43308 L .52295 .43297 L p 0 .513 .75 r
F P
0 g
s
.51461 .43196 m .51886 .43236 L .51889 .43225 L p 0 .564 .758 r
F P
0 g
s
.52681 .43395 m .52295 .43297 L .52291 .43308 L p 0 .462 .74 r
F P
0 g
s
.52291 .43308 m .52676 .43406 L .52681 .43395 L p 0 .462 .74 r
F P
0 g
s
.51889 .43225 m .51463 .43185 L .51461 .43196 L p 0 .564 .758 r
F P
0 g
s
.51019 .43193 m .51461 .43196 L .51463 .43185 L p .051 .617 .76 r
F P
0 g
s
.53042 .43514 m .52681 .43395 L .52676 .43406 L p 0 .413 .726 r
F P
0 g
s
.52676 .43406 m .53037 .43525 L .53042 .43514 L p 0 .413 .726 r
F P
0 g
s
.50564 .43223 m .50096 .43316 L .50095 .43327 L p .19 .72 .744 r
F P
0 g
s
.50095 .43327 m .50563 .43235 L .50564 .43223 L p .19 .72 .744 r
F P
0 g
s
.51463 .43185 m .51021 .43182 L .51019 .43193 L p .051 .617 .76 r
F P
0 g
s
.50563 .43235 m .51019 .43193 L .51021 .43182 L p .118 .669 .756 r
F P
0 g
s
.51021 .43182 m .50564 .43223 L .50563 .43235 L p .118 .669 .756 r
F P
0 g
s
.53038 .43525 m .53385 .43667 L .53391 .43656 L p 0 .363 .71 r
F P
0 g
s
.53391 .43656 m .53043 .43514 L .53038 .43525 L p 0 .363 .71 r
F P
0 g
s
.72128 .12318 m .72014 .1222 L .72041 .1223 L p .053 .456 .881 r
F P
0 g
s
.72041 .1223 m .72179 .12336 L .72128 .12318 L p .053 .456 .881 r
F P
0 g
s
.71712 .12046 m .7157 .11995 L .71528 .11961 L p .097 .514 .906 r
F P
0 g
s
.7157 .11995 m .71712 .12046 L .71741 .12067 L p .112 .517 .91 r
F P
0 g
s
.60324 .44512 m .60526 .4409 L .60544 .4408 L p 0 0 0 r
F P
0 g
s
.556 .47546 m .55383 .48132 L .55392 .48129 L p 0 0 0 r
F P
0 g
s
.55026 .48804 m .55392 .48129 L .55383 .48132 L p 0 0 0 r
F P
0 g
s
.53385 .43667 m .53727 .43834 L .53733 .43824 L p 0 .311 .691 r
F P
0 g
s
.53733 .43824 m .53391 .43656 L .53385 .43667 L p 0 .311 .691 r
F P
0 g
s
.53727 .43834 m .54059 .44028 L .54066 .44018 L p 0 .254 .667 r
F P
0 g
s
.54066 .44018 m .53733 .43824 L .53727 .43834 L p 0 .254 .667 r
F P
0 g
s
.60472 .46787 m .60812 .47297 L .60795 .47301 L p 0 0 .473 r
F P
0 g
s
.60795 .47301 m .60457 .46791 L .60472 .46787 L p 0 0 .473 r
F P
0 g
s
.54059 .44028 m .54376 .44247 L .54383 .44239 L p 0 .192 .637 r
F P
0 g
s
.54383 .44239 m .54066 .44018 L .54059 .44028 L p 0 .192 .637 r
F P
0 g
s
.7388 .13782 m .73299 .13199 L .73323 .1316 L p 0 .262 .764 r
F P
0 g
s
.73323 .1316 m .73917 .13726 L .7388 .13782 L p 0 .262 .764 r
F P
0 g
s
.68434 .10941 m .69465 .11152 L .69435 .11212 L p .184 .662 .931 r
F P
0 g
s
.70225 .11424 m .69435 .11212 L .69465 .11152 L p .137 .612 .922 r
F P
0 g
s
.60544 .4408 m .6034 .44504 L .60324 .44512 L p 0 0 0 r
F P
0 g
s
.6019 .44942 m .60324 .44512 L .6034 .44504 L p 0 0 0 r
F P
0 g
s
.54376 .44247 m .54673 .44493 L .5468 .44485 L p 0 .124 .601 r
F P
0 g
s
.5468 .44485 m .54383 .44239 L .54376 .44247 L p 0 .124 .601 r
F P
0 g
s
.55705 .47027 m .556 .47546 L .55609 .47543 L p 0 0 0 r
F P
0 g
s
.55392 .48129 m .55609 .47543 L .556 .47546 L p 0 0 0 r
F P
0 g
s
.60262 .463 m .60472 .46787 L .60457 .46791 L p 0 0 .365 r
F P
0 g
s
.60457 .46791 m .60248 .46305 L .60262 .463 L p 0 0 .365 r
F P
0 g
s
.54673 .44493 m .54945 .44764 L .54951 .44757 L p 0 .047 .556 r
F P
0 g
s
.54951 .44757 m .5468 .44485 L .54673 .44493 L p 0 .047 .556 r
F P
0 g
s
.6034 .44504 m .60204 .44935 L .6019 .44942 L p 0 0 0 r
F P
0 g
s
.60128 .45383 m .6019 .44942 L .60204 .44935 L p 0 0 0 r
F P
0 g
s
.54945 .44764 m .55186 .45063 L .55192 .45056 L p 0 0 .5 r
F P
0 g
s
.55192 .45056 m .54951 .44757 L .54945 .44764 L p 0 0 .5 r
F P
0 g
s
.06256 .50082 m .0629 .50415 L .06279 .50456 L p .958 .771 .322 r
F P
0 g
s
.0629 .50415 m .06256 .50082 L .06258 .5007 L p .962 .775 .333 r
F P
0 g
s
.0629 .49586 m .06256 .49918 L .06254 .4991 L p .958 .794 .351 r
F P
0 g
s
.06254 .4991 m .06279 .49546 L .0629 .49586 L p .958 .794 .351 r
F P
0 g
s
.60157 .45831 m .60262 .463 L .60248 .46305 L p 0 0 .24 r
F P
0 g
s
.60248 .46305 m .60144 .45837 L .60157 .45831 L p 0 0 .24 r
F P
0 g
s
.71858 .12141 m .71867 .12125 L .71888 .12136 L p .073 .483 .893 r
F P
0 g
s
.71888 .12136 m .719 .12165 L .71858 .12141 L p .073 .483 .893 r
F P
0 g
s
.71867 .12125 m .71858 .12141 L .71816 .12116 L p .076 .487 .895 r
F P
0 g
s
.60204 .44935 m .60141 .45377 L .60128 .45383 L p 0 0 0 r
F P
0 g
s
.60144 .45837 m .60128 .45383 L .60141 .45377 L p 0 0 .107 r
F P
0 g
s
.55721 .46559 m .55705 .47027 L .55713 .47023 L p 0 0 .021 r
F P
0 g
s
.55609 .47543 m .55713 .47023 L .55705 .47027 L p 0 0 0 r
F P
0 g
s
.55186 .45063 m .5539 .45389 L .55397 .45383 L p 0 0 .431 r
F P
0 g
s
.55397 .45383 m .55192 .45056 L .55186 .45063 L p 0 0 .431 r
F P
0 g
s
.60141 .45377 m .60157 .45831 L .60144 .45837 L p 0 0 .107 r
F P
0 g
s
.719 .12165 m .71888 .12136 L .71908 .12147 L p .067 .477 .89 r
F P
0 g
s
.71908 .12147 m .71942 .12187 L .719 .12165 L p .067 .477 .89 r
F P
0 g
s
.71847 .12113 m .71816 .12116 L .71776 .12091 L p .077 .49 .896 r
F P
0 g
s
.71816 .12116 m .71847 .12113 L .71867 .12125 L p .076 .487 .895 r
F P
0 g
s
.72449 .12523 m .72216 .12346 L .72238 .12346 L p 0 .412 .855 r
F P
0 g
s
.72238 .12346 m .72486 .12523 L .72449 .12523 L p 0 .412 .855 r
F P
0 g
s
.70804 .11623 m .71213 .11788 L .71232 .11821 L p .128 .56 .922 r
F P
0 g
s
.71501 .11933 m .71232 .11821 L .71213 .11788 L p .087 .525 .905 r
F P
0 g
s
.71232 .11821 m .71501 .11933 L .71528 .11961 L p .121 .539 .917 r
F P
0 g
s
.5539 .45389 m .55553 .45745 L .5556 .4574 L p 0 0 .348 r
F P
0 g
s
.5556 .4574 m .55397 .45383 L .5539 .45389 L p 0 0 .348 r
F P
0 g
s
.55667 .46134 m .55721 .46559 L .55729 .46555 L p 0 0 .139 r
F P
0 g
s
.55713 .47023 m .55729 .46555 L .55721 .46559 L p 0 0 .021 r
F P
0 g
s
.55553 .45745 m .55667 .46134 L .55674 .46129 L p 0 0 .25 r
F P
0 g
s
.55674 .46129 m .5556 .4574 L .55553 .45745 L p 0 0 .25 r
F P
0 g
s
.72179 .12336 m .72041 .1223 L .72061 .12235 L p .027 .441 .87 r
F P
0 g
s
.72061 .12235 m .72216 .12346 L .72179 .12336 L p .027 .441 .87 r
F P
0 g
s
.71689 .12027 m .71528 .11961 L .71501 .11933 L p .078 .507 .9 r
F P
0 g
s
.71528 .11961 m .71689 .12027 L .71712 .12046 L p .097 .514 .906 r
F P
0 g
s
.55729 .46555 m .55674 .46129 L .55667 .46134 L p 0 0 .139 r
F P
0 g
s
.71942 .12187 m .71908 .12147 L .71926 .12156 L p .057 .47 .886 r
F P
0 g
s
.71926 .12156 m .7198 .12205 L .71942 .12187 L p .057 .47 .886 r
F P
0 g
s
.71828 .12101 m .71776 .12091 L .71741 .12067 L p .074 .491 .895 r
F P
0 g
s
.71776 .12091 m .71828 .12101 L .71847 .12113 L p .077 .49 .896 r
F P
0 g
s
.71862 .87865 m .71874 .87887 L .71872 .87889 L p .021 0 0 r
F P
0 g
s
.71872 .87889 m .71825 .87887 L .71862 .87865 L p .021 0 0 r
F P
0 g
s
.71874 .87887 m .71862 .87865 L .71899 .87844 L p .02 0 0 r
F P
0 g
s
.71825 .87887 m .71872 .87889 L .7187 .8789 L p .021 0 0 r
F P
0 g
s
.7187 .8789 m .71791 .87909 L .71825 .87887 L p .021 0 0 r
F P
0 g
s
.71877 .87886 m .71899 .87844 L .71935 .87825 L p .018 0 0 r
F P
0 g
s
.71899 .87844 m .71877 .87886 L .71874 .87887 L p .02 0 0 r
F P
0 g
s
.7198 .12205 m .71926 .12156 L .71942 .12163 L p .046 .462 .881 r
F P
0 g
s
.71942 .12163 m .72014 .1222 L .7198 .12205 L p .046 .462 .881 r
F P
0 g
s
.71811 .12089 m .71741 .12067 L .71712 .12046 L p .068 .49 .894 r
F P
0 g
s
.71741 .12067 m .71811 .12089 L .71828 .12101 L p .074 .491 .895 r
F P
0 g
s
.73299 .13199 m .72835 .12795 L .72851 .12769 L p 0 .315 .796 r
F P
0 g
s
.72851 .12769 m .73323 .1316 L .73299 .13199 L p 0 .315 .796 r
F P
0 g
s
.71791 .87909 m .7187 .8789 L .71868 .87891 L p .02 0 0 r
F P
0 g
s
.71868 .87891 m .7176 .87929 L .71791 .87909 L p .02 0 0 r
F P
0 g
s
.71879 .87885 m .71935 .87825 L .71968 .87809 L p .016 0 0 r
F P
0 g
s
.71935 .87825 m .71879 .87885 L .71877 .87886 L p .018 0 0 r
F P
0 g
s
.69465 .11152 m .70247 .11383 L .70225 .11424 L p .137 .612 .922 r
F P
0 g
s
.70804 .11623 m .70225 .11424 L .70247 .11383 L p .099 .569 .91 r
F P
0 g
s
.7176 .87929 m .71868 .87891 L .71866 .87892 L p .018 0 0 r
F P
0 g
s
.71866 .87892 m .71734 .87948 L .7176 .87929 L p .018 0 0 r
F P
0 g
s
.71881 .87884 m .71968 .87809 L .71997 .87796 L p .012 0 0 r
F P
0 g
s
.71968 .87809 m .71881 .87884 L .71879 .87885 L p .016 0 0 r
F P
0 g
s
.0671 .53672 m .06323 .5151 L .06363 .51509 L p .935 .666 .193 r
F P
0 g
s
.06267 .50477 m .06363 .51509 L .06323 .5151 L p .946 .732 .265 r
F P
0 g
s
.06363 .51509 m .06267 .50477 L .06279 .50456 L p .962 .746 .3 r
F P
0 g
s
.72014 .1222 m .71942 .12163 L .71956 .12168 L p .032 .453 .875 r
F P
0 g
s
.71956 .12168 m .72041 .1223 L .72014 .1222 L p .032 .453 .875 r
F P
0 g
s
.71797 .12079 m .71712 .12046 L .71689 .12027 L p .059 .488 .891 r
F P
0 g
s
.71712 .12046 m .71797 .12079 L .71811 .12089 L p .068 .49 .894 r
F P
0 g
s
.06359 .48513 m .06267 .49525 L .06254 .49525 L p .946 .813 .365 r
F P
0 g
s
.06254 .49525 m .06321 .48512 L .06359 .48513 L p .946 .813 .365 r
F P
0 g
s
.06254 .5009 m .06279 .50456 L .06267 .50477 L p .954 .766 .311 r
F P
0 g
s
.06279 .50456 m .06254 .5009 L .06256 .50082 L p .958 .771 .322 r
F P
0 g
s
.06279 .49546 m .06254 .4991 L .06252 .49906 L p .954 .792 .343 r
F P
0 g
s
.06252 .49906 m .06267 .49525 L .06279 .49546 L p .954 .792 .343 r
F P
0 g
s
.71734 .87948 m .71866 .87892 L .71865 .87893 L p .016 0 0 r
F P
0 g
s
.71865 .87893 m .71714 .87965 L .71734 .87948 L p .016 0 0 r
F P
0 g
s
.71883 .87883 m .71997 .87796 L .72021 .87788 L p .009 0 0 r
F P
0 g
s
.71997 .87796 m .71883 .87883 L .71881 .87884 L p .012 0 0 r
F P
0 g
s
.72216 .12346 m .72061 .12235 L .72073 .12235 L p 0 .425 .859 r
F P
0 g
s
.72073 .12235 m .72238 .12346 L .72216 .12346 L p 0 .425 .859 r
F P
0 g
s
.71213 .11788 m .71491 .11914 L .71501 .11933 L p .087 .525 .905 r
F P
0 g
s
.71675 .12012 m .71501 .11933 L .71491 .11914 L p .056 .497 .891 r
F P
0 g
s
.71501 .11933 m .71675 .12012 L .71689 .12027 L p .078 .507 .9 r
F P
0 g
s
.72835 .12795 m .72486 .12523 L .72496 .12507 L p 0 .356 .819 r
F P
0 g
s
.72496 .12507 m .72851 .12769 L .72835 .12795 L p 0 .356 .819 r
F P
0 g
s
.70247 .11383 m .70819 .11596 L .70804 .11623 L p .099 .569 .91 r
F P
0 g
s
.71213 .11788 m .70804 .11623 L .70819 .11596 L p .069 .533 .898 r
F P
0 g
s
.72041 .1223 m .71956 .12168 L .71965 .1217 L p .016 .444 .868 r
F P
0 g
s
.71965 .1217 m .72061 .12235 L .72041 .1223 L p .016 .444 .868 r
F P
0 g
s
.71786 .1207 m .71689 .12027 L .71675 .12012 L p .047 .483 .886 r
F P
0 g
s
.71689 .12027 m .71786 .1207 L .71797 .12079 L p .059 .488 .891 r
F P
0 g
s
.71867 .12125 m .71872 .12117 L .7188 .12121 L p .04 .467 .881 r
F P
0 g
s
.7188 .12121 m .71888 .12136 L .71867 .12125 L p .04 .467 .881 r
F P
0 g
s
.71872 .12117 m .71867 .12125 L .71847 .12113 L p .042 .47 .882 r
F P
0 g
s
.71888 .12136 m .7188 .12121 L .71889 .12126 L p .036 .464 .879 r
F P
0 g
s
.71889 .12126 m .71908 .12147 L .71888 .12136 L p .036 .464 .879 r
F P
0 g
s
.71864 .12112 m .71847 .12113 L .71828 .12101 L p .042 .471 .882 r
F P
0 g
s
.71847 .12113 m .71864 .12112 L .71872 .12117 L p .042 .47 .882 r
F P
0 g
s
.70957 .88361 m .71696 .87987 L .71699 .87991 L p .023 0 0 r
F P
0 g
s
.71699 .87991 m .7097 .88385 L .70957 .88361 L p .023 0 0 r
F P
0 g
s
.74479 .86058 m .72749 .87358 L .72735 .87335 L p 0 0 0 r
F P
0 g
s
.72049 .87783 m .72735 .87335 L .72749 .87358 L p 0 0 0 r
F P
0 g
s
.72735 .87335 m .72049 .87783 L .72039 .87783 L p 0 0 0 r
F P
0 g
s
.71908 .12147 m .71889 .12126 L .71896 .12129 L p .031 .46 .877 r
F P
0 g
s
.71896 .12129 m .71926 .12156 L .71908 .12147 L p .031 .46 .877 r
F P
0 g
s
.71856 .12107 m .71828 .12101 L .71811 .12089 L p .04 .472 .882 r
F P
0 g
s
.71828 .12101 m .71856 .12107 L .71864 .12112 L p .042 .471 .882 r
F P
0 g
s
.71714 .87965 m .71865 .87893 L .71864 .87894 L p .013 0 0 r
F P
0 g
s
.71864 .87894 m .71702 .87978 L .71714 .87965 L p .013 0 0 r
F P
0 g
s
.71884 .87882 m .72021 .87788 L .72039 .87783 L p .004 0 0 r
F P
0 g
s
.72021 .87788 m .71884 .87882 L .71883 .87883 L p .009 0 0 r
F P
0 g
s
.06262 .5 m .06251 .5 L .06251 .49999 L p .954 .779 .327 r
F P
0 g
s
.06251 .49999 m .06262 .4998 L .06262 .5 L p .954 .779 .327 r
F P
0 g
s
.06251 .5 m .06262 .5 L .06262 .5002 L p .954 .779 .327 r
F P
0 g
s
.06251 .50001 m .06262 .5002 L .06261 .50039 L p .954 .778 .325 r
F P
0 g
s
.06262 .5002 m .06251 .50001 L .06251 .5 L p .954 .779 .327 r
F P
0 g
s
.06262 .4998 m .06251 .49999 L .06251 .49998 L p .954 .78 .328 r
F P
0 g
s
.06251 .49998 m .06261 .49961 L .06262 .4998 L p .954 .78 .328 r
F P
0 g
s
.71926 .12156 m .71896 .12129 L .71903 .12132 L p .025 .456 .874 r
F P
0 g
s
.71903 .12132 m .71942 .12163 L .71926 .12156 L p .025 .456 .874 r
F P
0 g
s
.71849 .12102 m .71811 .12089 L .71797 .12079 L p .037 .471 .881 r
F P
0 g
s
.71811 .12089 m .71849 .12102 L .71856 .12107 L p .04 .472 .882 r
F P
0 g
s
.06251 .50002 m .06261 .50039 L .0626 .50056 L p .953 .777 .324 r
F P
0 g
s
.06261 .50039 m .06251 .50002 L .06251 .50001 L p .954 .778 .325 r
F P
0 g
s
.06261 .49961 m .06251 .49998 L .06251 .49996 L p .953 .78 .327 r
F P
0 g
s
.06251 .49996 m .0626 .49944 L .06261 .49961 L p .953 .78 .327 r
F P
0 g
s
.72486 .12523 m .72238 .12346 L .72244 .12336 L p 0 .387 .835 r
F P
0 g
s
.72244 .12336 m .72496 .12507 L .72486 .12523 L p 0 .387 .835 r
F P
0 g
s
.70819 .11596 m .71223 .11771 L .71213 .11788 L p .069 .533 .898 r
F P
0 g
s
.71491 .11914 m .71213 .11788 L .71223 .11771 L p .046 .505 .888 r
F P
0 g
s
.06251 .50004 m .0626 .50056 L .06258 .5007 L p .953 .776 .322 r
F P
0 g
s
.0626 .50056 m .06251 .50004 L .06251 .50002 L p .953 .777 .324 r
F P
0 g
s
.0626 .49944 m .06251 .49996 L .06251 .49996 L p .953 .78 .327 r
F P
0 g
s
.06251 .49996 m .06258 .4993 L .0626 .49944 L p .953 .78 .327 r
F P
0 g
s
.71942 .12163 m .71903 .12132 L .71908 .12134 L p .017 .451 .87 r
F P
0 g
s
.71908 .12134 m .71956 .12168 L .71942 .12163 L p .017 .451 .87 r
F P
0 g
s
.71843 .12098 m .71797 .12079 L .71786 .1207 L p .032 .469 .879 r
F P
0 g
s
.71797 .12079 m .71843 .12098 L .71849 .12102 L p .037 .471 .881 r
F P
0 g
s
.72061 .12235 m .71965 .1217 L .71971 .1217 L p 0 .434 .861 r
F P
0 g
s
.71971 .1217 m .72073 .12235 L .72061 .12235 L p 0 .434 .861 r
F P
0 g
s
.71491 .11914 m .71669 .12002 L .71675 .12012 L p .056 .497 .891 r
F P
0 g
s
.71779 .12063 m .71675 .12012 L .71669 .12002 L p .033 .477 .88 r
F P
0 g
s
.71675 .12012 m .71779 .12063 L .71786 .1207 L p .047 .483 .886 r
F P
0 g
s
.06251 .50004 m .06258 .5007 L .06256 .50082 L p .952 .775 .32 r
F P
0 g
s
.06258 .5007 m .06251 .50004 L .06251 .50004 L p .953 .776 .322 r
F P
0 g
s
.06258 .4993 m .06251 .49996 L .0625 .49995 L p .952 .779 .325 r
F P
0 g
s
.0625 .49995 m .06256 .49918 L .06258 .4993 L p .952 .779 .325 r
F P
0 g
s
.71702 .87978 m .71864 .87894 L .71864 .87895 L p .009 0 0 r
F P
0 g
s
.71864 .87895 m .71696 .87987 L .71702 .87978 L p .009 0 0 r
F P
0 g
s
.71885 .87882 m .72039 .87783 L .72049 .87783 L p 0 0 0 r
F P
0 g
s
.72039 .87783 m .71885 .87882 L .71884 .87882 L p .004 0 0 r
F P
0 g
s
.71956 .12168 m .71908 .12134 L .71912 .12135 L p .009 .445 .867 r
F P
0 g
s
.71912 .12135 m .71965 .1217 L .71956 .12168 L p .009 .445 .867 r
F P
0 g
s
.71839 .12094 m .71786 .1207 L .71779 .12063 L p .025 .467 .876 r
F P
0 g
s
.71786 .1207 m .71839 .12094 L .71843 .12098 L p .032 .469 .879 r
F P
0 g
s
.06323 .5151 m .06254 .50477 L .06267 .50477 L p .946 .732 .265 r
F P
0 g
s
.06252 .50094 m .06267 .50477 L .06254 .50477 L p .948 .761 .3 r
F P
0 g
s
.06267 .50477 m .06252 .50094 L .06254 .5009 L p .954 .766 .311 r
F P
0 g
s
.06267 .49525 m .06252 .49906 L .06249 .49906 L p .948 .788 .332 r
F P
0 g
s
.06249 .49906 m .06254 .49525 L .06267 .49525 L p .948 .788 .332 r
F P
0 g
s
.0625 .50005 m .06256 .50082 L .06254 .5009 L p .951 .774 .318 r
F P
0 g
s
.06256 .50082 m .0625 .50005 L .06251 .50004 L p .952 .775 .32 r
F P
0 g
s
.06256 .49918 m .0625 .49995 L .0625 .49994 L p .951 .779 .324 r
F P
0 g
s
.0625 .49994 m .06254 .4991 L .06256 .49918 L p .951 .779 .324 r
F P
0 g
s
.71872 .12117 m .71874 .12113 L .71877 .12115 L p .019 .457 .872 r
F P
0 g
s
.71877 .12115 m .7188 .12121 L .71872 .12117 L p .019 .457 .872 r
F P
0 g
s
.71874 .12113 m .71872 .12117 L .71864 .12112 L p .02 .458 .873 r
F P
0 g
s
.72238 .12346 m .72073 .12235 L .72076 .1223 L p 0 .409 .846 r
F P
0 g
s
.72076 .1223 m .72244 .12336 L .72238 .12346 L p 0 .409 .846 r
F P
0 g
s
.7188 .12121 m .71877 .12115 L .71879 .12116 L p .017 .455 .871 r
F P
0 g
s
.71879 .12116 m .71889 .12126 L .7188 .12121 L p .017 .455 .871 r
F P
0 g
s
.71871 .12111 m .71864 .12112 L .71856 .12107 L p .02 .459 .873 r
F P
0 g
s
.71864 .12112 m .71871 .12111 L .71874 .12113 L p .02 .458 .873 r
F P
0 g
s
.71223 .11771 m .71496 .11904 L .71491 .11914 L p .046 .505 .888 r
F P
0 g
s
.71669 .12002 m .71491 .11914 L .71496 .11904 L p .029 .484 .88 r
F P
0 g
s
.71889 .12126 m .71879 .12116 L .71882 .12117 L p .015 .453 .87 r
F P
0 g
s
.71882 .12117 m .71896 .12129 L .71889 .12126 L p .015 .453 .87 r
F P
0 g
s
.71869 .1211 m .71856 .12107 L .71849 .12102 L p .019 .459 .873 r
F P
0 g
s
.71856 .12107 m .71869 .1211 L .71871 .12111 L p .02 .459 .873 r
F P
0 g
s
.71896 .12129 m .71882 .12117 L .71884 .12118 L p .012 .451 .869 r
F P
0 g
s
.71884 .12118 m .71903 .12132 L .71896 .12129 L p .012 .451 .869 r
F P
0 g
s
.71867 .12108 m .71849 .12102 L .71843 .12098 L p .017 .458 .872 r
F P
0 g
s
.71849 .12102 m .71867 .12108 L .71869 .1211 L p .019 .459 .873 r
F P
0 g
s
.71965 .1217 m .71912 .12135 L .71915 .12135 L p 0 .44 .863 r
F P
0 g
s
.71915 .12135 m .71971 .1217 L .71965 .1217 L p 0 .44 .863 r
F P
0 g
s
.71669 .12002 m .71776 .12058 L .71779 .12063 L p .033 .477 .88 r
F P
0 g
s
.71836 .12091 m .71779 .12063 L .71776 .12058 L p .018 .463 .873 r
F P
0 g
s
.71779 .12063 m .71836 .12091 L .71839 .12094 L p .025 .467 .876 r
F P
0 g
s
.71903 .12132 m .71884 .12118 L .71886 .12119 L p .008 .449 .867 r
F P
0 g
s
.71886 .12119 m .71908 .12134 L .71903 .12132 L p .008 .449 .867 r
F P
0 g
s
.71865 .12107 m .71843 .12098 L .71839 .12094 L p .015 .458 .871 r
F P
0 g
s
.71843 .12098 m .71865 .12107 L .71867 .12108 L p .017 .458 .872 r
F P
0 g
s
.0625 .50006 m .06254 .5009 L .06252 .50094 L p .95 .773 .315 r
F P
0 g
s
.06254 .5009 m .0625 .50006 L .0625 .50005 L p .951 .774 .318 r
F P
0 g
s
.06254 .4991 m .0625 .49994 L .0625 .49994 L p .95 .778 .322 r
F P
0 g
s
.0625 .49994 m .06252 .49906 L .06254 .4991 L p .95 .778 .322 r
F P
0 g
s
.72073 .12235 m .71971 .1217 L .71973 .12168 L p 0 .425 .854 r
F P
0 g
s
.71973 .12168 m .72076 .1223 L .72073 .12235 L p 0 .425 .854 r
F P
0 g
s
.71496 .11904 m .71672 .11997 L .71669 .12002 L p .029 .484 .88 r
F P
0 g
s
.71776 .12058 m .71669 .12002 L .71672 .11997 L p .017 .469 .874 r
F P
0 g
s
.71908 .12134 m .71886 .12119 L .71887 .12119 L p .004 .446 .865 r
F P
0 g
s
.71887 .12119 m .71912 .12135 L .71908 .12134 L p .004 .446 .865 r
F P
0 g
s
.71863 .12106 m .71839 .12094 L .71836 .12091 L p .012 .456 .87 r
F P
0 g
s
.71839 .12094 m .71863 .12106 L .71865 .12107 L p .015 .458 .871 r
F P
0 g
s
.71696 .87987 m .71864 .87895 L .71864 .87895 L p .005 0 0 r
F P
0 g
s
.71864 .87895 m .71699 .87991 L .71696 .87987 L p .005 0 0 r
F P
0 g
s
.72749 .87358 m .72052 .87788 L .72049 .87783 L p 0 0 0 r
F P
0 g
s
.71886 .87882 m .72049 .87783 L .72052 .87788 L p 0 0 0 r
F P
0 g
s
.72049 .87783 m .71886 .87882 L .71885 .87882 L p 0 0 0 r
F P
0 g
s
.71874 .12113 m .71875 .12112 L .71875 .12112 L p .007 .451 .867 r
F P
0 g
s
.71875 .12112 m .71877 .12115 L .71874 .12113 L p .007 .451 .867 r
F P
0 g
s
.71875 .12112 m .71874 .12113 L .71871 .12111 L p .007 .451 .867 r
F P
0 g
s
.71877 .12115 m .71875 .12112 L .71876 .12112 L p .006 .45 .867 r
F P
0 g
s
.71876 .12112 m .71879 .12116 L .71877 .12115 L p .006 .45 .867 r
F P
0 g
s
.71874 .12111 m .71871 .12111 L .71869 .1211 L p .007 .451 .867 r
F P
0 g
s
.71871 .12111 m .71874 .12111 L .71875 .12112 L p .007 .451 .867 r
F P
0 g
s
.71912 .12135 m .71887 .12119 L .71888 .12119 L p 0 .444 .863 r
F P
0 g
s
.71888 .12119 m .71915 .12135 L .71912 .12135 L p 0 .444 .863 r
F P
0 g
s
.71776 .12058 m .71835 .12089 L .71836 .12091 L p .018 .463 .873 r
F P
0 g
s
.71863 .12105 m .71836 .12091 L .71835 .12089 L p .008 .455 .868 r
F P
0 g
s
.71836 .12091 m .71863 .12105 L .71863 .12106 L p .012 .456 .87 r
F P
0 g
s
.71879 .12116 m .71876 .12112 L .71876 .12113 L p .005 .45 .866 r
F P
0 g
s
.71876 .12113 m .71882 .12117 L .71879 .12116 L p .005 .45 .866 r
F P
0 g
s
.71874 .12111 m .71869 .1211 L .71867 .12108 L p .007 .452 .867 r
F P
0 g
s
.71869 .1211 m .71874 .12111 L .71874 .12111 L p .007 .451 .867 r
F P
0 g
s
.71875 .87889 m .71872 .87889 L .71874 .87887 L closepath p .002 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .87887 L .71877 .87886 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .7187 .8789 L .71872 .87889 L closepath p .002 0 0 r
F P
0 g
s
.71875 .87889 m .71877 .87886 L .71879 .87885 L closepath p .001 0 0 r
F P
0 g
s
.71882 .12117 m .71876 .12113 L .71877 .12113 L p .004 .449 .866 r
F P
0 g
s
.71877 .12113 m .71884 .12118 L .71882 .12117 L p .004 .449 .866 r
F P
0 g
s
.71873 .12111 m .71867 .12108 L .71865 .12107 L p .006 .451 .867 r
F P
0 g
s
.71867 .12108 m .71873 .12111 L .71874 .12111 L p .007 .452 .867 r
F P
0 g
s
.71971 .1217 m .71915 .12135 L .71915 .12134 L p 0 .435 .859 r
F P
0 g
s
.71915 .12134 m .71973 .12168 L .71971 .1217 L p 0 .435 .859 r
F P
0 g
s
.71672 .11997 m .71778 .12055 L .71776 .12058 L p .017 .469 .874 r
F P
0 g
s
.71835 .12089 m .71776 .12058 L .71778 .12055 L p .009 .459 .869 r
F P
0 g
s
.71875 .87889 m .71868 .87891 L .7187 .8789 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87885 L .71881 .87884 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71866 .87892 L .71868 .87891 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71881 .87884 L .71883 .87883 L closepath p .001 0 0 r
F P
0 g
s
.06254 .50477 m .06249 .50094 L .06252 .50094 L p .948 .761 .3 r
F P
0 g
s
.0625 .50006 m .06252 .50094 L .06249 .50094 L p .949 .772 .313 r
F P
0 g
s
.06252 .50094 m .0625 .50006 L .0625 .50006 L p .95 .773 .315 r
F P
0 g
s
.06252 .49906 m .0625 .49994 L .0625 .49994 L p .949 .777 .32 r
F P
0 g
s
.0625 .49994 m .06249 .49906 L .06252 .49906 L p .949 .777 .32 r
F P
0 g
s
.71884 .12118 m .71877 .12113 L .71877 .12113 L p .003 .448 .865 r
F P
0 g
s
.71877 .12113 m .71886 .12119 L .71884 .12118 L p .003 .448 .865 r
F P
0 g
s
.71873 .12111 m .71865 .12107 L .71863 .12106 L p .005 .451 .867 r
F P
0 g
s
.71865 .12107 m .71873 .12111 L .71873 .12111 L p .006 .451 .867 r
F P
0 g
s
.71875 .87889 m .71865 .87893 L .71866 .87892 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71883 .87883 L .71884 .87882 L closepath p .001 0 0 r
F P
0 g
s
.71886 .12119 m .71877 .12113 L .71877 .12113 L p .001 .447 .864 r
F P
0 g
s
.71877 .12113 m .71887 .12119 L .71886 .12119 L p .001 .447 .864 r
F P
0 g
s
.71873 .1211 m .71863 .12106 L .71863 .12105 L p .004 .451 .866 r
F P
0 g
s
.71863 .12106 m .71873 .1211 L .71873 .12111 L p .005 .451 .867 r
F P
0 g
s
.71875 .87889 m .71864 .87894 L .71865 .87893 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71884 .87882 L .71885 .87882 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .06251 .49999 L .06251 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .5 L .06251 .50001 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .50001 L .06251 .50002 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .49998 L .06251 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .50002 L .06251 .50004 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .49996 L .06251 .49998 L closepath p .949 .775 .317 r
F P
0 g
s
.71915 .12135 m .71888 .12119 L .71888 .12119 L p 0 .442 .861 r
F P
0 g
s
.71888 .12119 m .71915 .12134 L .71915 .12135 L p 0 .442 .861 r
F P
0 g
s
.71778 .12055 m .71835 .12088 L .71835 .12089 L p .009 .459 .869 r
F P
0 g
s
.71862 .12104 m .71835 .12089 L .71835 .12088 L p .004 .453 .866 r
F P
0 g
s
.71835 .12089 m .71862 .12104 L .71863 .12105 L p .008 .455 .868 r
F P
0 g
s
.0625 .5 m .06251 .50004 L .06251 .50004 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .06251 .49996 L .06251 .49996 L closepath p .949 .775 .317 r
F P
0 g
s
.71887 .12119 m .71877 .12113 L .71877 .12113 L p 0 .446 .864 r
F P
0 g
s
.71877 .12113 m .71888 .12119 L .71887 .12119 L p 0 .446 .864 r
F P
0 g
s
.71873 .1211 m .71863 .12105 L .71862 .12104 L p .003 .45 .866 r
F P
0 g
s
.71863 .12105 m .71873 .1211 L .71873 .1211 L p .004 .451 .866 r
F P
0 g
s
.0625 .5 m .06251 .50004 L .0625 .50005 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .49995 L .06251 .49996 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71864 .87895 L .71864 .87894 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71885 .87882 L .71886 .87882 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50005 L .0625 .50006 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49994 L .0625 .49995 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .12112 m .71875 .12111 L .71875 .12111 L p .002 .448 .865 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L p .002 .448 .865 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71874 .12111 L p .002 .448 .865 r
F P
0 g
s
.71875 .12112 m .71875 .12111 L .71875 .12111 L p .002 .448 .865 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71875 .12112 L p .002 .448 .865 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L p .002 .448 .865 r
F P
0 g
s
.71874 .12111 m .71875 .12111 L .71875 .12111 L p .002 .448 .865 r
F P
0 g
s
.71876 .12112 m .71875 .12111 L .71875 .12111 L p .001 .448 .865 r
F P
0 g
s
.71875 .12111 m .71876 .12113 L .71876 .12112 L p .001 .448 .865 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71873 .12111 L p .002 .448 .865 r
F P
0 g
s
.71874 .12111 m .71875 .12111 L .71875 .12111 L p .002 .448 .865 r
F P
0 g
s
.71876 .12113 m .71875 .12111 L .71875 .12111 L p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12113 L .71876 .12113 L p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .71873 .12111 L .71873 .12111 L p .002 .448 .865 r
F P
0 g
s
.71873 .12111 m .71875 .12111 L .71875 .12111 L p .002 .448 .865 r
F P
0 g
s
.71877 .12113 m .71875 .12111 L .71875 .12111 L p .001 .447 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12113 L .71877 .12113 L p .001 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .12111 L .71873 .1211 L p .001 .448 .865 r
F P
0 g
s
.71873 .12111 m .71875 .12111 L .71875 .12111 L p .002 .448 .865 r
F P
0 g
s
.0625 .5 m .0625 .50006 L .0625 .50006 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .49994 L .0625 .49994 L closepath p .949 .775 .317 r
F P
0 g
s
.71888 .12119 m .71877 .12113 L .71878 .12113 L p 0 .445 .863 r
F P
0 g
s
.71878 .12113 m .71888 .12119 L .71888 .12119 L p 0 .445 .863 r
F P
0 g
s
.71835 .12088 m .71862 .12104 L .71862 .12104 L p .004 .453 .866 r
F P
0 g
s
.71872 .1211 m .71862 .12104 L .71862 .12104 L p .002 .449 .865 r
F P
0 g
s
.71862 .12104 m .71872 .1211 L .71873 .1211 L p .003 .45 .866 r
F P
0 g
s
.71877 .12113 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12113 L .71877 .12113 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .1211 L .71873 .1211 L p .001 .448 .864 r
F P
0 g
s
.71873 .1211 m .71875 .12111 L .71875 .12111 L p .001 .448 .865 r
F P
0 g
s
.71875 .87889 m .71864 .87895 L .71864 .87895 L closepath p 0 0 0 r
F P
0 g
s
.72052 .87788 m .71886 .87882 L .71886 .87882 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71886 .87882 L .71886 .87882 L closepath p 0 0 0 r
F P
0 g
s
.71877 .12113 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12113 L .71877 .12113 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .1211 L .71872 .1211 L p .001 .448 .864 r
F P
0 g
s
.71873 .1211 m .71875 .12111 L .71875 .12111 L p .001 .448 .864 r
F P
0 g
s
.06249 .50094 m .0625 .50006 L .0625 .50006 L p .949 .772 .313 r
F P
0 g
s
.0625 .5 m .0625 .50006 L .0625 .50006 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .49994 L .0625 .49994 L closepath p .949 .775 .317 r
F P
0 g
s
.71877 .12113 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71878 .12113 L .71877 .12113 L p 0 .447 .864 r
F P
0 g
s
.71862 .12104 m .71873 .1211 L .71872 .1211 L p .002 .449 .865 r
F P
0 g
s
.71875 .12111 m .71872 .1211 L .71873 .1211 L p 0 .448 .864 r
F P
0 g
s
.71872 .1211 m .71875 .12111 L .71875 .12111 L p .001 .448 .864 r
F P
0 g
s
.71873 .1211 m .71875 .12111 L .71875 .12111 L p 0 .448 .864 r
F P
0 g
s
.71875 .87889 m .71876 .8789 L .71873 .87891 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71878 .87889 L .71876 .8789 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .7188 .87887 L .71878 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71882 .87886 L .7188 .87887 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71884 .87885 L .71882 .87886 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71885 .87884 L .71884 .87885 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71886 .87883 L .71885 .87884 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71886 .87882 L .71886 .87883 L closepath p 0 0 0 r
F P
0 g
s
.45427 .9351 m
.5 .9375 L
s
.40904 .92794 m
.45427 .9351 L
s
.36481 .91609 m
.40904 .92794 L
s
.32205 .89968 m
.36481 .91609 L
s
.28125 .87889 m
.32205 .89968 L
s
.24284 .85394 m
.28125 .87889 L
s
.20726 .82513 m
.24284 .85394 L
s
.17487 .79274 m
.20726 .82513 L
s
.14606 .75716 m
.17487 .79274 L
s
.12111 .71875 m
.14606 .75716 L
s
.10032 .67795 m
.12111 .71875 L
s
.08391 .63519 m
.10032 .67795 L
s
.07206 .59096 m
.08391 .63519 L
s
.0649 .54573 m
.07206 .59096 L
s
.06332 .51561 m
.0649 .54573 L
s
.06331 .48451 m
.0649 .45427 L
s
.0649 .45427 m
.07206 .40904 L
s
.07206 .40904 m
.08391 .36481 L
s
.10032 .32205 m
.08391 .36481 L
s
.12111 .28125 m
.10032 .32205 L
s
.14606 .24284 m
.12111 .28125 L
s
.17487 .20726 m
.14606 .24284 L
s
.20726 .17487 m
.17487 .20726 L
s
.24284 .14606 m
.20726 .17487 L
s
.28125 .12111 m
.24284 .14606 L
s
.32205 .10032 m
.28125 .12111 L
s
.36481 .08391 m
.32205 .10032 L
s
.40904 .07206 m
.36481 .08391 L
s
.45427 .0649 m
.40904 .07206 L
s
.5 .0625 m
.45427 .0649 L
s
.54573 .9351 m
.5 .9375 L
s
.59096 .92794 m
.54573 .9351 L
s
.63519 .91609 m
.59096 .92794 L
s
.66445 .90486 m
.67795 .89968 L
s
.63519 .91609 m
.66445 .90486 L
s
.6948 .89109 m
.70569 .88554 L
s
.67795 .89968 m
.6948 .89109 L
s
.73111 .87086 m
.74058 .86471 L
s
.74058 .86471 m
.75716 .85394 L
s
.75716 .85394 m
.76408 .84834 L
s
.76408 .84834 m
.79274 .82513 L
s
.79274 .82513 m
.82513 .79274 L
s
.85394 .75716 m
.82513 .79274 L
s
.87889 .71875 m
.85394 .75716 L
s
.89968 .67795 m
.87889 .71875 L
s
.91609 .63519 m
.89968 .67795 L
s
.92794 .59096 m
.91609 .63519 L
s
.9351 .54573 m
.92794 .59096 L
s
.9375 .5 m
.9351 .54573 L
s
.9351 .45427 m
.9375 .5 L
s
.92794 .40904 m
.9351 .45427 L
s
.91609 .36481 m
.92794 .40904 L
s
.89968 .32205 m
.91609 .36481 L
s
.87889 .28125 m
.89968 .32205 L
s
.85394 .24284 m
.87889 .28125 L
s
.82513 .20726 m
.85394 .24284 L
s
.79274 .17487 m
.82513 .20726 L
s
.75716 .14606 m
.79274 .17487 L
s
.71875 .12111 m
.72418 .12464 L
s
.72587 .12574 m
.72633 .12603 L
s
.72633 .12603 m
.72896 .12774 L
s
.72896 .12774 m
.73722 .13311 L
s
.73722 .13311 m
.75716 .14606 L
s
.71297 .11817 m
.71875 .12111 L
s
.71071 .11702 m
.71119 .11726 L
s
.70793 .1156 m
.71071 .11702 L
s
.69925 .11118 m
.70793 .1156 L
s
.67795 .10032 m
.69925 .11118 L
s
.63519 .08391 m
.67795 .10032 L
s
.59096 .07206 m
.63519 .08391 L
s
.54573 .0649 m
.59096 .07206 L
s
.5 .0625 m
.54573 .0649 L
s
.71875 .87889 m .71865 .87895 L .71864 .87895 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71866 .87895 L .71865 .87895 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71867 .87894 L .71866 .87895 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71869 .87894 L .71867 .87894 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71871 .87892 L .71869 .87894 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71873 .87891 L .71871 .87892 L closepath p 0 0 0 r
F P
0 g
s
.70772 .8845 m
.71875 .87889 L
s
.71875 .87889 m
.72914 .87214 L
s
.0625 .5 m .0625 .49994 L .0625 .49994 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49995 L .0625 .49994 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49996 L .0625 .49995 L closepath p .948 .775 .316 r
F P
0 g
s
.0625 .5 m .06249 .49996 L .0625 .49996 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .49998 L .06249 .49996 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .06249 .49999 L .06249 .49998 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m .0625 .50006 L .0625 .50006 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50006 L .0625 .50005 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50005 L .0625 .50004 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m .0625 .50004 L .06249 .50004 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m .06249 .50004 L .06249 .50002 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m .06249 .50002 L .06249 .50001 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m .06249 .50001 L .06249 .5 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m .06249 .5 L .06249 .49999 L closepath p .948 .774 .315 r
F P
0 g
s
.0625 .5 m
.06303 .51013 L
s
.0625 .5 m
.06304 .48969 L
s
.71873 .1211 m .71875 .12111 L .71875 .12111 L p 0 .448 .864 r
F P
0 g
s
.71875 .12111 m .71873 .1211 L .71873 .1211 L p 0 .448 .864 r
F P
0 g
s
.71878 .12113 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71873 .1211 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .1211 L .71873 .1211 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12113 L .71878 .12113 L p 0 .447 .864 r
F P
0 g
s
.71877 .12113 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71873 .1211 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71873 .1211 L .71873 .1211 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71877 .12112 L .71877 .12113 L p 0 .446 .863 r
F P
0 g
s
.71877 .12112 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71874 .1211 m .71875 .12111 L .71875 .12111 L p 0 .447 .863 r
F P
0 g
s
.71875 .12111 m .71873 .1211 L .71874 .1211 L p 0 .447 .863 r
F P
0 g
s
.71875 .12111 m .71877 .12112 L .71877 .12112 L p 0 .446 .863 r
F P
0 g
s
.71877 .12112 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71874 .12111 m .71875 .12111 L .71875 .12111 L p 0 .447 .863 r
F P
0 g
s
.71875 .12111 m .71874 .1211 L .71874 .12111 L p 0 .447 .863 r
F P
0 g
s
.71875 .12111 m .71877 .12112 L .71877 .12112 L p 0 .446 .863 r
F P
0 g
s
.71877 .12112 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71877 .12112 L p 0 .446 .863 r
F P
0 g
s
.71876 .12112 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71876 .12111 L .71876 .12112 L p 0 .446 .863 r
F P
0 g
s
.71876 .12111 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71876 .12111 L p 0 .446 .863 r
F P
0 g
s
.71863 .12104 m .71873 .1211 L .71873 .1211 L p 0 .448 .864 r
F P
0 g
s
.71873 .1211 m .71862 .12104 L .71863 .12104 L p 0 .448 .864 r
F P
0 g
s
.71888 .12119 m .71878 .12113 L .71877 .12113 L p 0 .444 .862 r
F P
0 g
s
.06249 .49906 m .0625 .49994 L .0625 .49994 L p .948 .776 .317 r
F P
0 g
s
.06247 .5009 m .0625 .50006 L .0625 .50006 L p .948 .771 .311 r
F P
0 g
s
.0625 .50006 m .06249 .50094 L .06247 .5009 L p .948 .771 .311 r
F P
0 g
s
.71864 .12104 m .71873 .1211 L .71873 .1211 L p 0 .447 .863 r
F P
0 g
s
.71873 .1211 m .71863 .12104 L .71864 .12104 L p 0 .447 .863 r
F P
0 g
s
.71877 .12113 m .71887 .12118 L .71888 .12119 L p 0 .444 .862 r
F P
0 g
s
.71887 .12118 m .71877 .12113 L .71877 .12112 L p 0 .444 .862 r
F P
0 g
s
.72047 .87797 m .71886 .87883 L .71886 .87882 L p 0 0 0 r
F P
0 g
s
.71886 .87882 m .72052 .87788 L .72047 .87797 L p 0 0 0 r
F P
0 g
s
.71699 .87991 m .71864 .87895 L .71865 .87895 L p 0 0 0 r
F P
0 g
s
.71866 .12105 m .71873 .1211 L .71873 .1211 L p 0 .447 .863 r
F P
0 g
s
.71873 .1211 m .71864 .12104 L .71866 .12105 L p 0 .447 .863 r
F P
0 g
s
.71877 .12112 m .71886 .12117 L .71887 .12118 L p 0 .444 .862 r
F P
0 g
s
.71886 .12117 m .71877 .12112 L .71877 .12112 L p 0 .443 .861 r
F P
0 g
s
.71838 .12088 m .71863 .12104 L .71862 .12104 L p 0 .45 .864 r
F P
0 g
s
.71862 .12104 m .71835 .12088 L .71838 .12088 L p 0 .45 .864 r
F P
0 g
s
.71915 .12134 m .71888 .12119 L .71887 .12118 L p 0 .44 .86 r
F P
0 g
s
.0625 .49994 m .06247 .4991 L .06249 .49906 L p .948 .776 .317 r
F P
0 g
s
.06247 .4991 m .0625 .49994 L .0625 .49995 L p .946 .775 .315 r
F P
0 g
s
.06245 .50082 m .0625 .50005 L .0625 .50006 L p .946 .77 .309 r
F P
0 g
s
.0625 .50006 m .06247 .5009 L .06245 .50082 L p .946 .77 .309 r
F P
0 g
s
.71868 .12106 m .71874 .1211 L .71873 .1211 L p 0 .446 .862 r
F P
0 g
s
.71873 .1211 m .71866 .12105 L .71868 .12106 L p 0 .446 .862 r
F P
0 g
s
.71877 .12112 m .71885 .12116 L .71886 .12117 L p 0 .443 .861 r
F P
0 g
s
.71885 .12116 m .71877 .12112 L .71877 .12112 L p 0 .443 .861 r
F P
0 g
s
.71871 .12107 m .71874 .12111 L .71874 .1211 L p 0 .445 .862 r
F P
0 g
s
.71874 .1211 m .71868 .12106 L .71871 .12107 L p 0 .445 .862 r
F P
0 g
s
.71877 .12112 m .71883 .12114 L .71885 .12116 L p 0 .443 .861 r
F P
0 g
s
.71883 .12114 m .71877 .12112 L .71876 .12112 L p 0 .443 .861 r
F P
0 g
s
.71873 .12108 m .71875 .12111 L .71874 .12111 L p 0 .444 .861 r
F P
0 g
s
.71874 .12111 m .71871 .12107 L .71873 .12108 L p 0 .444 .861 r
F P
0 g
s
.71876 .12112 m .71881 .12113 L .71883 .12114 L p 0 .443 .861 r
F P
0 g
s
.71881 .12113 m .71876 .12112 L .71876 .12111 L p 0 .443 .861 r
F P
0 g
s
.71876 .1211 m .71875 .12111 L .71875 .12111 L p 0 .444 .861 r
F P
0 g
s
.71875 .12111 m .71873 .12108 L .71876 .1211 L p 0 .444 .861 r
F P
0 g
s
.71876 .12111 m .71879 .12111 L .71881 .12113 L p 0 .443 .861 r
F P
0 g
s
.71879 .12111 m .71876 .12111 L .71875 .12111 L p 0 .443 .861 r
F P
0 g
s
.71875 .12111 m .71876 .1211 L .71879 .12111 L p 0 .443 .861 r
F P
0 g
s
.0625 .49995 m .06245 .49918 L .06247 .4991 L p .946 .775 .315 r
F P
0 g
s
.06245 .49918 m .0625 .49995 L .0625 .49996 L p .945 .774 .313 r
F P
0 g
s
.06243 .5007 m .0625 .50004 L .0625 .50005 L p .945 .77 .307 r
F P
0 g
s
.0625 .50005 m .06245 .50082 L .06243 .5007 L p .945 .77 .307 r
F P
0 g
s
.72034 .8781 m .71885 .87884 L .71886 .87883 L p 0 0 0 r
F P
0 g
s
.71886 .87883 m .72047 .87797 L .72034 .8781 L p 0 0 0 r
F P
0 g
s
.71865 .87895 m .71709 .87991 L .71699 .87991 L p 0 0 0 r
F P
0 g
s
.71709 .87991 m .71865 .87895 L .71866 .87895 L p 0 0 0 r
F P
0 g
s
.0625 .49996 m .06243 .4993 L .06245 .49918 L p .945 .774 .313 r
F P
0 g
s
.06243 .4993 m .0625 .49996 L .06249 .49996 L p .944 .773 .31 r
F P
0 g
s
.06241 .50056 m .06249 .50004 L .0625 .50004 L p .944 .769 .306 r
F P
0 g
s
.0625 .50004 m .06243 .5007 L .06241 .50056 L p .944 .769 .306 r
F P
0 g
s
.71842 .12089 m .71864 .12104 L .71863 .12104 L p 0 .448 .863 r
F P
0 g
s
.71863 .12104 m .71838 .12088 L .71842 .12089 L p 0 .448 .863 r
F P
0 g
s
.71887 .12118 m .71914 .12132 L .71915 .12134 L p 0 .44 .86 r
F P
0 g
s
.71914 .12132 m .71887 .12118 L .71886 .12117 L p 0 .438 .858 r
F P
0 g
s
.06249 .49996 m .06241 .49944 L .06243 .4993 L p .944 .773 .31 r
F P
0 g
s
.06241 .49944 m .06249 .49996 L .06249 .49998 L p .944 .772 .308 r
F P
0 g
s
.0624 .50039 m .06249 .50002 L .06249 .50004 L p .944 .769 .305 r
F P
0 g
s
.06249 .50004 m .06241 .50056 L .0624 .50039 L p .944 .769 .305 r
F P
0 g
s
.71783 .12055 m .71838 .12088 L .71835 .12088 L p 0 .454 .865 r
F P
0 g
s
.71835 .12088 m .71778 .12055 L .71783 .12055 L p 0 .454 .865 r
F P
0 g
s
.71973 .12168 m .71915 .12134 L .71914 .12132 L p 0 .431 .855 r
F P
0 g
s
.06249 .49998 m .0624 .49961 L .06241 .49944 L p .944 .772 .308 r
F P
0 g
s
.0624 .49961 m .06249 .49998 L .06249 .49999 L p .943 .771 .307 r
F P
0 g
s
.06239 .5002 m .06249 .50001 L .06249 .50002 L p .943 .769 .305 r
F P
0 g
s
.06249 .50002 m .0624 .50039 L .06239 .5002 L p .943 .769 .305 r
F P
0 g
s
.06249 .49999 m .06239 .4998 L .0624 .49961 L p .943 .771 .307 r
F P
0 g
s
.06239 .4998 m .06249 .49999 L .06249 .5 L p .943 .77 .306 r
F P
0 g
s
.06239 .5 m .06249 .5 L .06249 .50001 L p .943 .77 .305 r
F P
0 g
s
.06249 .50001 m .06239 .5002 L .06239 .5 L p .943 .77 .305 r
F P
0 g
s
.06249 .5 m .06239 .5 L .06239 .4998 L p .943 .77 .306 r
F P
0 g
s
.72014 .87826 m .71884 .87885 L .71885 .87884 L p 0 0 0 r
F P
0 g
s
.71885 .87884 m .72034 .8781 L .72014 .87826 L p 0 0 0 r
F P
0 g
s
.71866 .87895 m .71727 .87987 L .71709 .87991 L p 0 0 0 r
F P
0 g
s
.71727 .87987 m .71866 .87895 L .71867 .87894 L p 0 0 0 r
F P
0 g
s
.71847 .12091 m .71866 .12105 L .71864 .12104 L p 0 .445 .861 r
F P
0 g
s
.71864 .12104 m .71842 .12089 L .71847 .12091 L p 0 .445 .861 r
F P
0 g
s
.71886 .12117 m .71911 .12129 L .71914 .12132 L p 0 .438 .858 r
F P
0 g
s
.71911 .12129 m .71886 .12117 L .71885 .12116 L p 0 .437 .857 r
F P
0 g
s
.71989 .87845 m .71882 .87886 L .71884 .87885 L p 0 0 0 r
F P
0 g
s
.71884 .87885 m .72014 .87826 L .71989 .87845 L p 0 0 0 r
F P
0 g
s
.71867 .87894 m .71751 .87978 L .71727 .87987 L p 0 0 0 r
F P
0 g
s
.71751 .87978 m .71867 .87894 L .71869 .87894 L p 0 0 0 r
F P
0 g
s
.71854 .12094 m .71868 .12106 L .71866 .12105 L p 0 .443 .859 r
F P
0 g
s
.71866 .12105 m .71847 .12091 L .71854 .12094 L p 0 .443 .859 r
F P
0 g
s
.71885 .12116 m .71907 .12126 L .71911 .12129 L p 0 .437 .857 r
F P
0 g
s
.71907 .12126 m .71885 .12116 L .71883 .12114 L p 0 .436 .856 r
F P
0 g
s
.06254 .49525 m .06249 .49906 L .06247 .4991 L p .943 .783 .321 r
F P
0 g
s
.06242 .50456 m .06247 .5009 L .06249 .50094 L p .943 .757 .289 r
F P
0 g
s
.06249 .50094 m .06254 .50477 L .06242 .50456 L p .943 .757 .289 r
F P
0 g
s
.71958 .87866 m .7188 .87887 L .71882 .87886 L p 0 0 0 r
F P
0 g
s
.71882 .87886 m .71989 .87845 L .71958 .87866 L p 0 0 0 r
F P
0 g
s
.71869 .87894 m .7178 .87965 L .71751 .87978 L p 0 0 0 r
F P
0 g
s
.7178 .87965 m .71869 .87894 L .71871 .87892 L p 0 0 0 r
F P
0 g
s
.71924 .87888 m .71878 .87889 L .7188 .87887 L p 0 0 0 r
F P
0 g
s
.7188 .87887 m .71958 .87866 L .71924 .87888 L p 0 0 0 r
F P
0 g
s
.71871 .87892 m .71814 .87949 L .7178 .87965 L p 0 0 0 r
F P
0 g
s
.71814 .87949 m .71871 .87892 L .71873 .87891 L p 0 0 0 r
F P
0 g
s
.71684 .11996 m .71783 .12055 L .71778 .12055 L p 0 .46 .866 r
F P
0 g
s
.71778 .12055 m .71672 .11997 L .71684 .11996 L p 0 .46 .866 r
F P
0 g
s
.72076 .1223 m .71973 .12168 L .7197 .12163 L p 0 .416 .846 r
F P
0 g
s
.71914 .12132 m .7197 .12163 L .71973 .12168 L p 0 .431 .855 r
F P
0 g
s
.71861 .12098 m .71871 .12107 L .71868 .12106 L p 0 .441 .857 r
F P
0 g
s
.71868 .12106 m .71854 .12094 L .71861 .12098 L p 0 .441 .857 r
F P
0 g
s
.71883 .12114 m .71901 .12121 L .71907 .12126 L p 0 .436 .856 r
F P
0 g
s
.71901 .12121 m .71883 .12114 L .71881 .12113 L p 0 .435 .855 r
F P
0 g
s
.71887 .87909 m .71876 .8789 L .71878 .87889 L p 0 0 0 r
F P
0 g
s
.71878 .87889 m .71924 .87888 L .71887 .87909 L p 0 0 0 r
F P
0 g
s
.71873 .87891 m .7185 .8793 L .71814 .87949 L p 0 0 0 r
F P
0 g
s
.7185 .8793 m .71873 .87891 L .71876 .8789 L p 0 0 0 r
F P
0 g
s
.71876 .8789 m .71887 .87909 L .7185 .8793 L p 0 0 0 r
F P
0 g
s
.71869 .12102 m .71873 .12108 L .71871 .12107 L p 0 .439 .856 r
F P
0 g
s
.71871 .12107 m .71861 .12098 L .71869 .12102 L p 0 .439 .856 r
F P
0 g
s
.71881 .12113 m .71894 .12116 L .71901 .12121 L p 0 .435 .855 r
F P
0 g
s
.71894 .12116 m .71881 .12113 L .71879 .12111 L p 0 .435 .854 r
F P
0 g
s
.71793 .12057 m .71842 .12089 L .71838 .12088 L p 0 .449 .861 r
F P
0 g
s
.71838 .12088 m .71783 .12055 L .71793 .12057 L p 0 .449 .861 r
F P
0 g
s
.7197 .12163 m .71914 .12132 L .71911 .12129 L p 0 .427 .851 r
F P
0 g
s
.71878 .12107 m .71876 .1211 L .71873 .12108 L p 0 .437 .855 r
F P
0 g
s
.71873 .12108 m .71869 .12102 L .71878 .12107 L p 0 .437 .855 r
F P
0 g
s
.71879 .12111 m .71886 .12112 L .71894 .12116 L p 0 .435 .854 r
F P
0 g
s
.71886 .12112 m .71879 .12111 L .71876 .1211 L p 0 .436 .855 r
F P
0 g
s
.71876 .1211 m .71878 .12107 L .71886 .12112 L p 0 .436 .855 r
F P
0 g
s
.72725 .87402 m .72047 .87797 L .72052 .87788 L p 0 0 0 r
F P
0 g
s
.72052 .87788 m .72749 .87358 L .72725 .87402 L p 0 0 0 r
F P
0 g
s
.7097 .88385 m .71699 .87991 L .71709 .87991 L p 0 0 0 r
F P
0 g
s
.71806 .12062 m .71847 .12091 L .71842 .12089 L p 0 .443 .856 r
F P
0 g
s
.71842 .12089 m .71793 .12057 L .71806 .12062 L p 0 .443 .856 r
F P
0 g
s
.71911 .12129 m .71963 .12155 L .7197 .12163 L p 0 .427 .851 r
F P
0 g
s
.71963 .12155 m .71911 .12129 L .71907 .12126 L p 0 .424 .848 r
F P
0 g
s
.71518 .11904 m .71684 .11996 L .71672 .11997 L p .001 .469 .866 r
F P
0 g
s
.71672 .11997 m .71496 .11904 L .71518 .11904 L p .001 .469 .866 r
F P
0 g
s
.72244 .12336 m .72076 .1223 L .7207 .1222 L p 0 .394 .833 r
F P
0 g
s
.7197 .12163 m .7207 .1222 L .72076 .1223 L p 0 .416 .846 r
F P
0 g
s
.06247 .4991 m .06242 .49545 L .06254 .49525 L p .943 .783 .321 r
F P
0 g
s
.06242 .49545 m .06247 .4991 L .06245 .49918 L p .937 .778 .31 r
F P
0 g
s
.0623 .50415 m .06245 .50082 L .06247 .5009 L p .937 .753 .279 r
F P
0 g
s
.06247 .5009 m .06242 .50456 L .0623 .50415 L p .937 .753 .279 r
F P
0 g
s
.71822 .12069 m .71854 .12094 L .71847 .12091 L p 0 .438 .852 r
F P
0 g
s
.71847 .12091 m .71806 .12062 L .71822 .12069 L p 0 .438 .852 r
F P
0 g
s
.71907 .12126 m .71952 .12146 L .71963 .12155 L p 0 .424 .848 r
F P
0 g
s
.71952 .12146 m .71907 .12126 L .71901 .12121 L p 0 .422 .845 r
F P
0 g
s
.71704 .12002 m .71793 .12057 L .71783 .12055 L p 0 .45 .857 r
F P
0 g
s
.71783 .12055 m .71684 .11996 L .71704 .12002 L p 0 .45 .857 r
F P
0 g
s
.7207 .1222 m .7197 .12163 L .71963 .12155 L p 0 .409 .839 r
F P
0 g
s
.71841 .12078 m .71861 .12098 L .71854 .12094 L p 0 .433 .849 r
F P
0 g
s
.71854 .12094 m .71822 .12069 L .71841 .12078 L p 0 .433 .849 r
F P
0 g
s
.71901 .12121 m .71938 .12136 L .71952 .12146 L p 0 .422 .845 r
F P
0 g
s
.71938 .12136 m .71901 .12121 L .71894 .12116 L p 0 .421 .843 r
F P
0 g
s
.71861 .12089 m .71869 .12102 L .71861 .12098 L p 0 .428 .846 r
F P
0 g
s
.71861 .12098 m .71841 .12078 L .71861 .12089 L p 0 .428 .846 r
F P
0 g
s
.71894 .12116 m .71921 .12124 L .71938 .12136 L p 0 .421 .843 r
F P
0 g
s
.71921 .12124 m .71894 .12116 L .71886 .12112 L p 0 .421 .842 r
F P
0 g
s
.7126 .11771 m .71518 .11904 L .71496 .11904 L p .001 .481 .866 r
F P
0 g
s
.71496 .11904 m .71223 .11771 L .7126 .11771 L p .001 .481 .866 r
F P
0 g
s
.71881 .121 m .71878 .12107 L .71869 .12102 L p 0 .425 .844 r
F P
0 g
s
.71869 .12102 m .71861 .12089 L .71881 .121 L p 0 .425 .844 r
F P
0 g
s
.71886 .12112 m .71902 .12112 L .71921 .12124 L p 0 .421 .842 r
F P
0 g
s
.71902 .12112 m .71886 .12112 L .71878 .12107 L p 0 .422 .843 r
F P
0 g
s
.72496 .12507 m .72244 .12336 L .72233 .12317 L p 0 .361 .813 r
F P
0 g
s
.7207 .1222 m .72233 .12317 L .72244 .12336 L p 0 .394 .833 r
F P
0 g
s
.71878 .12107 m .71881 .121 L .71902 .12112 L p 0 .422 .843 r
F P
0 g
s
.06245 .49918 m .0623 .49586 L .06242 .49545 L p .937 .778 .31 r
F P
0 g
s
.0623 .49586 m .06245 .49918 L .06243 .4993 L p .932 .772 .298 r
F P
0 g
s
.0622 .50356 m .06243 .5007 L .06245 .50082 L p .932 .75 .271 r
F P
0 g
s
.06245 .50082 m .0623 .50415 L .0622 .50356 L p .932 .75 .271 r
F P
0 g
s
.06321 .48512 m .06254 .49525 L .06242 .49545 L p .928 .799 .331 r
F P
0 g
s
.06284 .51444 m .06242 .50456 L .06254 .50477 L p .928 .716 .23 r
F P
0 g
s
.06254 .50477 m .06323 .5151 L .06284 .51444 L p .928 .716 .23 r
F P
0 g
s
.71731 .12012 m .71806 .12062 L .71793 .12057 L p 0 .439 .849 r
F P
0 g
s
.71793 .12057 m .71704 .12002 L .71731 .12012 L p 0 .439 .849 r
F P
0 g
s
.71963 .12155 m .72056 .12205 L .7207 .1222 L p 0 .409 .839 r
F P
0 g
s
.72056 .12205 m .71963 .12155 L .71952 .12146 L p 0 .402 .832 r
F P
0 g
s
.72663 .87466 m .72034 .8781 L .72047 .87797 L p 0 0 0 r
F P
0 g
s
.72047 .87797 m .72725 .87402 L .72663 .87466 L p 0 0 0 r
F P
0 g
s
.71709 .87991 m .71022 .88385 L .7097 .88385 L p 0 0 0 r
F P
0 g
s
.71022 .88385 m .71709 .87991 L .71727 .87987 L p 0 0 0 r
F P
0 g
s
.06243 .4993 m .0622 .49644 L .0623 .49586 L p .932 .772 .298 r
F P
0 g
s
.0622 .49644 m .06243 .4993 L .06241 .49944 L p .927 .766 .287 r
F P
0 g
s
.06212 .50281 m .06241 .50056 L .06243 .5007 L p .927 .747 .264 r
F P
0 g
s
.06243 .5007 m .0622 .50356 L .06212 .50281 L p .927 .747 .264 r
F P
0 g
s
.71555 .11913 m .71704 .12002 L .71684 .11996 L p 0 .451 .851 r
F P
0 g
s
.71684 .11996 m .71518 .11904 L .71555 .11913 L p 0 .451 .851 r
F P
0 g
s
.72233 .12317 m .7207 .1222 L .72056 .12205 L p 0 .38 .819 r
F P
0 g
s
.71765 .12026 m .71822 .12069 L .71806 .12062 L p 0 .429 .84 r
F P
0 g
s
.71806 .12062 m .71731 .12012 L .71765 .12026 L p 0 .429 .84 r
F P
0 g
s
.71952 .12146 m .72033 .12186 L .72056 .12205 L p 0 .402 .832 r
F P
0 g
s
.72033 .12186 m .71952 .12146 L .71938 .12136 L p 0 .398 .827 r
F P
0 g
s
.06241 .49944 m .06212 .49718 L .0622 .49644 L p .927 .766 .287 r
F P
0 g
s
.06212 .49718 m .06241 .49944 L .0624 .49961 L p .923 .76 .277 r
F P
0 g
s
.06206 .50194 m .0624 .50039 L .06241 .50056 L p .923 .746 .26 r
F P
0 g
s
.06241 .50056 m .06212 .50281 L .06206 .50194 L p .923 .746 .26 r
F P
0 g
s
.70878 .11595 m .7126 .11771 L .71223 .11771 L p .002 .496 .864 r
F P
0 g
s
.71223 .11771 m .70819 .11596 L .70878 .11595 L p .002 .496 .864 r
F P
0 g
s
.72851 .12769 m .72496 .12507 L .72478 .12474 L p 0 .316 .783 r
F P
0 g
s
.72233 .12317 m .72478 .12474 L .72496 .12507 L p 0 .361 .813 r
F P
0 g
s
.0624 .49961 m .06206 .49804 L .06212 .49718 L p .923 .76 .277 r
F P
0 g
s
.06206 .49804 m .0624 .49961 L .06239 .4998 L p .92 .755 .269 r
F P
0 g
s
.06202 .50099 m .06239 .5002 L .0624 .50039 L p .92 .747 .258 r
F P
0 g
s
.0624 .50039 m .06206 .50194 L .06202 .50099 L p .92 .747 .258 r
F P
0 g
s
.71803 .12045 m .71841 .12078 L .71822 .12069 L p 0 .419 .833 r
F P
0 g
s
.71822 .12069 m .71765 .12026 L .71803 .12045 L p 0 .419 .833 r
F P
0 g
s
.71938 .12136 m .72004 .12164 L .72033 .12186 L p 0 .398 .827 r
F P
0 g
s
.72004 .12164 m .71938 .12136 L .71921 .12124 L p 0 .396 .823 r
F P
0 g
s
.06239 .4998 m .06202 .49899 L .06206 .49804 L p .92 .755 .269 r
F P
0 g
s
.06202 .49899 m .06239 .4998 L .06239 .5 L p .918 .751 .263 r
F P
0 g
s
.062 .49999 m .06239 .5 L .06239 .5002 L p .918 .748 .259 r
F P
0 g
s
.06239 .5002 m .06202 .50099 L .062 .49999 L p .918 .748 .259 r
F P
0 g
s
.06239 .5 m .062 .49999 L .06202 .49899 L p .918 .751 .263 r
F P
0 g
s
.72565 .87548 m .72014 .87826 L .72034 .8781 L p 0 0 0 r
F P
0 g
s
.72034 .8781 m .72663 .87466 L .72565 .87548 L p 0 0 0 r
F P
0 g
s
.71727 .87987 m .71112 .88362 L .71022 .88385 L p 0 0 0 r
F P
0 g
s
.71112 .88362 m .71727 .87987 L .71751 .87978 L p 0 0 0 r
F P
0 g
s
.71844 .12067 m .71861 .12089 L .71841 .12078 L p 0 .41 .827 r
F P
0 g
s
.71841 .12078 m .71803 .12045 L .71844 .12067 L p 0 .41 .827 r
F P
0 g
s
.71921 .12124 m .71968 .1214 L .72004 .12164 L p 0 .396 .823 r
F P
0 g
s
.71968 .1214 m .71921 .12124 L .71902 .12112 L p 0 .396 .821 r
F P
0 g
s
.74409 .86191 m .72725 .87402 L .72749 .87358 L p 0 0 0 r
F P
0 g
s
.72749 .87358 m .74479 .86058 L .74409 .86191 L p 0 0 0 r
F P
0 g
s
.689 .8926 m .7097 .88385 L .71022 .88385 L p .002 0 0 r
F P
0 g
s
.71887 .1209 m .71881 .121 L .71861 .12089 L p 0 .403 .823 r
F P
0 g
s
.71861 .12089 m .71844 .12067 L .71887 .1209 L p 0 .403 .823 r
F P
0 g
s
.71902 .12112 m .71929 .12115 L .71968 .1214 L p 0 .396 .821 r
F P
0 g
s
.71929 .12115 m .71902 .12112 L .71881 .121 L p 0 .398 .821 r
F P
0 g
s
.71881 .121 m .71887 .1209 L .71929 .12115 L p 0 .398 .821 r
F P
0 g
s
.71606 .11932 m .71731 .12012 L .71704 .12002 L p 0 .432 .835 r
F P
0 g
s
.71704 .12002 m .71555 .11913 L .71606 .11932 L p 0 .432 .835 r
F P
0 g
s
.72056 .12205 m .72207 .1229 L .72233 .12317 L p 0 .38 .819 r
F P
0 g
s
.72207 .1229 m .72056 .12205 L .72033 .12186 L p 0 .368 .807 r
F P
0 g
s
.70335 .11381 m .70878 .11595 L .70819 .11596 L p .003 .516 .859 r
F P
0 g
s
.70819 .11596 m .70247 .11383 L .70335 .11381 L p .003 .516 .859 r
F P
0 g
s
.73323 .1316 m .72851 .12769 L .72822 .12718 L p 0 .253 .741 r
F P
0 g
s
.72478 .12474 m .72822 .12718 L .72851 .12769 L p 0 .316 .783 r
F P
0 g
s
.71323 .11787 m .71555 .11913 L .71518 .11904 L p 0 .452 .84 r
F P
0 g
s
.71518 .11904 m .7126 .11771 L .71323 .11787 L p 0 .452 .84 r
F P
0 g
s
.72478 .12474 m .72233 .12317 L .72207 .1229 L p 0 .338 .789 r
F P
0 g
s
.72437 .87642 m .71989 .87845 L .72014 .87826 L p 0 0 0 r
F P
0 g
s
.72014 .87826 m .72565 .87548 L .72437 .87642 L p 0 0 0 r
F P
0 g
s
.71751 .87978 m .71234 .88317 L .71112 .88362 L p 0 0 0 r
F P
0 g
s
.71234 .88317 m .71751 .87978 L .7178 .87965 L p 0 0 0 r
F P
0 g
s
.06242 .49545 m .06283 .48574 L .06321 .48512 L p .928 .799 .331 r
F P
0 g
s
.06283 .48574 m .06242 .49545 L .0623 .49586 L p .907 .78 .294 r
F P
0 g
s
.06247 .51313 m .0623 .50415 L .06242 .50456 L p .907 .701 .197 r
F P
0 g
s
.06242 .50456 m .06284 .51444 L .06247 .51313 L p .907 .701 .197 r
F P
0 g
s
.06678 .46456 m .06321 .48512 L .06283 .48574 L p .887 .823 .349 r
F P
0 g
s
.71668 .11959 m .71765 .12026 L .71731 .12012 L p 0 .413 .82 r
F P
0 g
s
.71731 .12012 m .71606 .11932 L .71668 .11959 L p 0 .413 .82 r
F P
0 g
s
.72033 .12186 m .72165 .12255 L .72207 .1229 L p 0 .368 .807 r
F P
0 g
s
.72165 .12255 m .72033 .12186 L .72004 .12164 L p 0 .36 .796 r
F P
0 g
s
.06614 .5351 m .06284 .51444 L .06323 .5151 L p .883 .62 .1 r
F P
0 g
s
.06323 .5151 m .0671 .53672 L .06614 .5351 L p .883 .62 .1 r
F P
0 g
s
.72283 .87747 m .71958 .87866 L .71989 .87845 L p 0 0 0 r
F P
0 g
s
.71989 .87845 m .72437 .87642 L .72283 .87747 L p 0 0 0 r
F P
0 g
s
.7178 .87965 m .71384 .88251 L .71234 .88317 L p 0 0 0 r
F P
0 g
s
.71384 .88251 m .7178 .87965 L .71814 .87949 L p 0 0 0 r
F P
0 g
s
.69591 .11149 m .70335 .11381 L .70247 .11383 L p .005 .538 .846 r
F P
0 g
s
.70247 .11383 m .69465 .11152 L .69591 .11149 L p .005 .538 .846 r
F P
0 g
s
.7211 .87857 m .71924 .87888 L .71958 .87866 L p 0 0 0 r
F P
0 g
s
.71958 .87866 m .72283 .87747 L .7211 .87857 L p 0 0 0 r
F P
0 g
s
.71814 .87949 m .71554 .88169 L .71384 .88251 L p 0 0 0 r
F P
0 g
s
.71554 .88169 m .71814 .87949 L .7185 .8793 L p 0 0 0 r
F P
0 g
s
.73917 .13726 m .73323 .1316 L .7328 .13082 L p 0 .17 .681 r
F P
0 g
s
.72822 .12718 m .7328 .13082 L .73323 .1316 L p 0 .253 .741 r
F P
0 g
s
.71739 .11994 m .71803 .12045 L .71765 .12026 L p 0 .395 .806 r
F P
0 g
s
.71765 .12026 m .71668 .11959 L .71739 .11994 L p 0 .395 .806 r
F P
0 g
s
.72004 .12164 m .7211 .12215 L .72165 .12255 L p 0 .36 .796 r
F P
0 g
s
.7211 .12215 m .72004 .12164 L .71968 .1214 L p 0 .355 .788 r
F P
0 g
s
.71926 .87967 m .71887 .87909 L .71924 .87888 L p 0 0 0 r
F P
0 g
s
.71924 .87888 m .7211 .87857 L .71926 .87967 L p 0 0 0 r
F P
0 g
s
.7185 .8793 m .71738 .88072 L .71554 .88169 L p 0 0 0 r
F P
0 g
s
.71738 .88072 m .7185 .8793 L .71887 .87909 L p 0 0 0 r
F P
0 g
s
.71887 .87909 m .71926 .87967 L .71738 .88072 L p 0 0 0 r
F P
0 g
s
.71815 .12034 m .71844 .12067 L .71803 .12045 L p 0 .38 .794 r
F P
0 g
s
.71803 .12045 m .71739 .11994 L .71815 .12034 L p 0 .38 .794 r
F P
0 g
s
.71968 .1214 m .72045 .1217 L .7211 .12215 L p 0 .355 .788 r
F P
0 g
s
.72045 .1217 m .71968 .1214 L .71929 .12115 L p 0 .355 .783 r
F P
0 g
s
.5556 .4574 m .55674 .46129 L .55769 .46103 L p 0 .102 .625 r
F P
0 g
s
.55674 .46129 m .55729 .46555 L .55827 .46531 L p 0 .023 .545 r
F P
0 g
s
.55827 .46531 m .55769 .46103 L .55674 .46129 L p 0 .023 .545 r
F P
0 g
s
.71409 .11819 m .71606 .11932 L .71555 .11913 L p 0 .42 .812 r
F P
0 g
s
.71555 .11913 m .71323 .11787 L .71409 .11819 L p 0 .42 .812 r
F P
0 g
s
.72207 .1229 m .72433 .12428 L .72478 .12474 L p 0 .338 .789 r
F P
0 g
s
.72433 .12428 m .72207 .1229 L .72165 .12255 L p 0 .317 .766 r
F P
0 g
s
.55397 .45383 m .5556 .4574 L .55654 .4571 L p 0 .177 .694 r
F P
0 g
s
.55769 .46103 m .55654 .4571 L .5556 .4574 L p 0 .102 .625 r
F P
0 g
s
.55729 .46555 m .55713 .47023 L .55817 .47 L p 0 0 .453 r
F P
0 g
s
.55817 .47 m .55827 .46531 L .55729 .46555 L p 0 0 .453 r
F P
0 g
s
.55192 .45056 m .55397 .45383 L .5549 .45349 L p .015 .246 .751 r
F P
0 g
s
.55654 .4571 m .5549 .45349 L .55397 .45383 L p 0 .177 .694 r
F P
0 g
s
.70978 .1162 m .71323 .11787 L .7126 .11771 L p 0 .451 .822 r
F P
0 g
s
.7126 .11771 m .70878 .11595 L .70978 .1162 L p 0 .451 .822 r
F P
0 g
s
.72822 .12718 m .72478 .12474 L .72433 .12428 L p 0 .276 .743 r
F P
0 g
s
.71894 .12078 m .71887 .1209 L .71844 .12067 L p 0 .367 .786 r
F P
0 g
s
.71844 .12067 m .71815 .12034 L .71894 .12078 L p 0 .367 .786 r
F P
0 g
s
.71929 .12115 m .71972 .12124 L .72045 .1217 L p 0 .355 .783 r
F P
0 g
s
.71972 .12124 m .71929 .12115 L .71887 .1209 L p 0 .359 .782 r
F P
0 g
s
.60051 .45381 m .6007 .45837 L .60157 .45831 L p .993 .796 .42 r
F P
0 g
s
.60157 .45831 m .60141 .45377 L .60051 .45381 L p .993 .796 .42 r
F P
0 g
s
.60262 .463 m .60157 .45831 L .6007 .45837 L p .977 .697 .305 r
F P
0 g
s
.54951 .44757 m .55192 .45056 L .55285 .45016 L p .036 .31 .798 r
F P
0 g
s
.5549 .45349 m .55285 .45016 L .55192 .45056 L p .015 .246 .751 r
F P
0 g
s
.55713 .47023 m .55609 .47543 L .55723 .4752 L p 0 0 .352 r
F P
0 g
s
.55723 .4752 m .55817 .47 L .55713 .47023 L p 0 0 .352 r
F P
0 g
s
.60108 .44937 m .60051 .45381 L .60141 .45377 L p .988 .873 .521 r
F P
0 g
s
.60141 .45377 m .60204 .44935 L .60108 .44937 L p .988 .873 .521 r
F P
0 g
s
.71887 .1209 m .71894 .12078 L .71972 .12124 L p 0 .359 .782 r
F P
0 g
s
.6007 .45837 m .60175 .46308 L .60262 .463 L p .977 .697 .305 r
F P
0 g
s
.60472 .46787 m .60262 .463 L .60175 .46308 L p .938 .577 .18 r
F P
0 g
s
.0623 .49586 m .06247 .48698 L .06283 .48574 L p .907 .78 .294 r
F P
0 g
s
.06247 .48698 m .0623 .49586 L .0622 .49644 L p .886 .758 .255 r
F P
0 g
s
.06215 .51124 m .0622 .50356 L .0623 .50415 L p .884 .687 .167 r
F P
0 g
s
.0623 .50415 m .06247 .51313 L .06215 .51124 L p .884 .687 .167 r
F P
0 g
s
.5468 .44485 m .54951 .44757 L .55042 .4471 L p .06 .368 .836 r
F P
0 g
s
.55285 .45016 m .55042 .4471 L .54951 .44757 L p .036 .31 .798 r
F P
0 g
s
.60234 .44502 m .60108 .44937 L .60204 .44935 L p .966 .928 .608 r
F P
0 g
s
.60204 .44935 m .6034 .44504 L .60234 .44502 L p .966 .928 .608 r
F P
0 g
s
.54383 .44239 m .5468 .44485 L .54768 .44429 L p .086 .421 .868 r
F P
0 g
s
.55042 .4471 m .54768 .44429 L .5468 .44485 L p .06 .368 .836 r
F P
0 g
s
.60175 .46308 m .60382 .46796 L .60472 .46787 L p .938 .577 .18 r
F P
0 g
s
.60812 .47297 m .60472 .46787 L .60382 .46796 L p .876 .444 .053 r
F P
0 g
s
.55609 .47543 m .55392 .48129 L .55522 .48106 L p 0 0 .245 r
F P
0 g
s
.55522 .48106 m .55723 .4752 L .55609 .47543 L p 0 0 .245 r
F P
0 g
s
.54066 .44018 m .54383 .44239 L .54467 .44174 L p .115 .47 .893 r
F P
0 g
s
.54768 .44429 m .54467 .44174 L .54383 .44239 L p .086 .421 .868 r
F P
0 g
s
.60426 .44074 m .60234 .44502 L .6034 .44504 L p .933 .965 .679 r
F P
0 g
s
.6034 .44504 m .60544 .4408 L .60426 .44074 L p .933 .965 .679 r
F P
0 g
s
.68606 .10936 m .69591 .11149 L .69465 .11152 L p .007 .561 .822 r
F P
0 g
s
.69465 .11152 m .68434 .10941 L .68606 .10936 L p .007 .561 .822 r
F P
0 g
s
.74621 .14521 m .73917 .13726 L .73856 .13614 L p 0 .062 .597 r
F P
0 g
s
.7328 .13082 m .73856 .13614 L .73917 .13726 L p 0 .17 .681 r
F P
0 g
s
.53733 .43824 m .54066 .44018 L .54144 .43945 L p .146 .516 .915 r
F P
0 g
s
.54467 .44174 m .54144 .43945 L .54066 .44018 L p .115 .47 .893 r
F P
0 g
s
.60382 .46796 m .60714 .47309 L .60812 .47297 L p .876 .444 .053 r
F P
0 g
s
.61319 .47837 m .60812 .47297 L .60714 .47309 L p .797 .306 0 r
F P
0 g
s
.53391 .43656 m .53733 .43824 L .53804 .43742 L p .179 .559 .933 r
F P
0 g
s
.54144 .43945 m .53804 .43742 L .53733 .43824 L p .146 .516 .915 r
F P
0 g
s
.53043 .43514 m .53391 .43656 L .53452 .43565 L p .214 .6 .949 r
F P
0 g
s
.53804 .43742 m .53452 .43565 L .53391 .43656 L p .179 .559 .933 r
F P
0 g
s
.55392 .48129 m .55026 .48804 L .55179 .48779 L p 0 0 .138 r
F P
0 g
s
.55179 .48779 m .55522 .48106 L .55392 .48129 L p 0 0 .138 r
F P
0 g
s
.60682 .4365 m .60426 .44074 L .60544 .4408 L p .894 .987 .736 r
F P
0 g
s
.71515 .11865 m .71668 .11959 L .71606 .11932 L p 0 .387 .784 r
F P
0 g
s
.71606 .11932 m .71409 .11819 L .71515 .11865 L p 0 .387 .784 r
F P
0 g
s
.72165 .12255 m .72362 .12369 L .72433 .12428 L p 0 .317 .766 r
F P
0 g
s
.72362 .12369 m .72165 .12255 L .7211 .12215 L p 0 .301 .745 r
F P
0 g
s
.53452 .43565 m .53093 .43415 L .53043 .43514 L p .214 .6 .949 r
F P
0 g
s
.52681 .43395 m .53042 .43514 L .53093 .43415 L p .249 .641 .962 r
F P
0 g
s
.51014 .43059 m .50548 .43098 L .50564 .43223 L p .504 .851 .994 r
F P
0 g
s
.50564 .43223 m .51021 .43182 L .51014 .43059 L p .504 .851 .994 r
F P
0 g
s
.50096 .43316 m .50564 .43223 L .50548 .43098 L p .567 .891 .987 r
F P
0 g
s
.51467 .43064 m .51014 .43059 L .51021 .43182 L p .445 .809 .995 r
F P
0 g
s
.51021 .43182 m .51463 .43185 L .51467 .43064 L p .445 .809 .995 r
F P
0 g
s
.50548 .43098 m .50071 .43189 L .50096 .43316 L p .567 .891 .987 r
F P
0 g
s
.49617 .43469 m .50096 .43316 L .50071 .43189 L p .63 .927 .973 r
F P
0 g
s
.53093 .43415 m .5272 .43288 L .52681 .43395 L p .249 .641 .962 r
F P
0 g
s
.52295 .43297 m .52681 .43395 L .5272 .43288 L p .29 .682 .974 r
F P
0 g
s
.51904 .43108 m .51467 .43064 L .51463 .43185 L p .388 .767 .991 r
F P
0 g
s
.51463 .43185 m .51889 .43225 L .51904 .43108 L p .388 .767 .991 r
F P
0 g
s
.5272 .43288 m .52323 .43184 L .52295 .43297 L p .29 .682 .974 r
F P
0 g
s
.51889 .43225 m .52295 .43297 L .52323 .43184 L p .337 .724 .984 r
F P
0 g
s
.52323 .43184 m .51904 .43108 L .51889 .43225 L p .337 .724 .984 r
F P
0 g
s
.50071 .43189 m .49585 .4334 L .49617 .43469 L p .63 .927 .973 r
F P
0 g
s
.49129 .43694 m .49617 .43469 L .49585 .4334 L p .693 .957 .949 r
F P
0 g
s
.49585 .4334 m .4909 .43561 L .49129 .43694 L p .693 .957 .949 r
F P
0 g
s
.48633 .44004 m .49129 .43694 L .4909 .43561 L p .752 .979 .916 r
F P
0 g
s
.74224 .86384 m .72663 .87466 L .72725 .87402 L p 0 0 0 r
F P
0 g
s
.72725 .87402 m .74409 .86191 L .74224 .86384 L p 0 0 0 r
F P
0 g
s
.0622 .49644 m .06216 .48878 L .06247 .48698 L p .886 .758 .255 r
F P
0 g
s
.06216 .48878 m .0622 .49644 L .06212 .49718 L p .864 .735 .218 r
F P
0 g
s
.4909 .43561 m .48587 .43864 L .48633 .44004 L p .752 .979 .916 r
F P
0 g
s
.48129 .44417 m .48633 .44004 L .48587 .43864 L p .805 .993 .874 r
F P
0 g
s
.61001 .43229 m .60682 .4365 L .60814 .43663 L p .854 .997 .781 r
F P
0 g
s
.06188 .50885 m .06212 .50281 L .0622 .50356 L p .863 .675 .144 r
F P
0 g
s
.0622 .50356 m .06215 .51124 L .06188 .50885 L p .863 .675 .144 r
F P
0 g
s
.71022 .88385 m .69066 .89262 L .689 .8926 L p .002 0 0 r
F P
0 g
s
.69066 .89262 m .71022 .88385 L .71112 .88362 L p 0 0 0 r
F P
0 g
s
.60714 .47309 m .61208 .47853 L .61319 .47837 L p .797 .306 0 r
F P
0 g
s
.62047 .48424 m .61319 .47837 L .61208 .47853 L p .712 .178 0 r
F P
0 g
s
.77248 .83149 m .74409 .86191 L .74479 .86058 L p 0 0 0 r
F P
0 g
s
.74479 .86058 m .77386 .82872 L .77248 .83149 L p 0 0 0 r
F P
0 g
s
.76856 .83558 m .74224 .86384 L .74409 .86191 L p .53 .827 .497 r
F P
0 g
s
.47316 .37426 m .46815 .37742 L .46871 .37851 L p .136 0 0 r
F P
0 g
s
.46815 .37742 m .46249 .37985 L .46301 .38094 L p .207 0 0 r
F P
0 g
s
.46301 .38094 m .46871 .37851 L .46815 .37742 L p .207 0 0 r
F P
0 g
s
.46249 .37985 m .45606 .38146 L .45657 .38257 L p .28 0 0 r
F P
0 g
s
.45657 .38257 m .46301 .38094 L .46249 .37985 L p .28 0 0 r
F P
0 g
s
.4776 .37042 m .47316 .37426 L .47378 .37538 L p .071 0 .013 r
F P
0 g
s
.46871 .37851 m .47378 .37538 L .47316 .37426 L p .136 0 0 r
F P
0 g
s
.55026 .48804 m .54457 .49609 L .54644 .49579 L p 0 0 .042 r
F P
0 g
s
.54644 .49579 m .55179 .48779 L .55026 .48804 L p 0 0 .042 r
F P
0 g
s
.45606 .38146 m .44873 .38209 L .44924 .38327 L p .351 0 0 r
F P
0 g
s
.44924 .38327 m .45657 .38257 L .45606 .38146 L p .351 0 0 r
F P
0 g
s
.48587 .43864 m .48075 .44268 L .48129 .44417 L p .805 .993 .874 r
F P
0 g
s
.47615 .44959 m .48129 .44417 L .48075 .44268 L p .85 .996 .823 r
F P
0 g
s
.64245 .90192 m .689 .8926 L .69066 .89262 L p .006 0 0 r
F P
0 g
s
.71635 .11923 m .71739 .11994 L .71668 .11959 L p 0 .357 .758 r
F P
0 g
s
.71668 .11959 m .71515 .11865 L .71635 .11923 L p 0 .357 .758 r
F P
0 g
s
.7211 .12215 m .72269 .123 L .72362 .12369 L p 0 .301 .745 r
F P
0 g
s
.72269 .123 m .7211 .12215 L .72045 .1217 L p 0 .292 .728 r
F P
0 g
s
.48152 .36596 m .4776 .37042 L .4783 .3716 L p .013 0 .065 r
F P
0 g
s
.47378 .37538 m .4783 .3716 L .4776 .37042 L p .071 0 .013 r
F P
0 g
s
.61384 .42808 m .61001 .43229 L .61149 .43251 L p .815 1 .815 r
F P
0 g
s
.70486 .11419 m .70978 .1162 L .70878 .11595 L p 0 .446 .789 r
F P
0 g
s
.70878 .11595 m .70335 .11381 L .70486 .11419 L p 0 .446 .789 r
F P
0 g
s
.7328 .13082 m .72822 .12718 L .7275 .12643 L p 0 .191 .674 r
F P
0 g
s
.72433 .12428 m .7275 .12643 L .72822 .12718 L p 0 .276 .743 r
F P
0 g
s
.07912 .43098 m .06678 .46456 L .0659 .46596 L p .782 .837 .373 r
F P
0 g
s
.06283 .48574 m .0659 .46596 L .06678 .46456 L p .887 .823 .349 r
F P
0 g
s
.44873 .38209 m .44027 .38158 L .44079 .38286 L p .416 0 0 r
F P
0 g
s
.44079 .38286 m .44924 .38327 L .44873 .38209 L p .416 0 0 r
F P
0 g
s
.71115 .11671 m .71409 .11819 L .71323 .11787 L p 0 .399 .773 r
F P
0 g
s
.71323 .11787 m .70978 .1162 L .71115 .11671 L p 0 .399 .773 r
F P
0 g
s
.7275 .12643 m .72433 .12428 L .72362 .12369 L p 0 .241 .701 r
F P
0 g
s
.6735 .10803 m .68606 .10936 L .68434 .10941 L p .012 .581 .78 r
F P
0 g
s
.68434 .10941 m .67123 .10809 L .6735 .10803 L p .012 .581 .78 r
F P
0 g
s
.68434 .10941 m .6735 .10803 L .6735 .10803 L .012 .581 .78 r
F
.67746 .10903 m .68906 .11012 L .68606 .10936 L p .238 0 0 r
F P
0 g
s
.6735 .10803 m .6735 .10803 L p .6735 .10803 L .012 .581 .78 r
F P
0 g
s
.48497 .36089 m .48152 .36596 L .48233 .3672 L p 0 0 .114 r
F P
0 g
s
.4783 .3716 m .48233 .3672 L .48152 .36596 L p .013 0 .065 r
F P
0 g
s
.75395 .15605 m .74621 .14521 L .74536 .14367 L p 0 0 .484 r
F P
0 g
s
.73856 .13614 m .74536 .14367 L .74621 .14521 L p 0 .062 .597 r
F P
0 g
s
.48075 .44268 m .47551 .44796 L .47615 .44959 L p .85 .996 .823 r
F P
0 g
s
.47085 .45666 m .47615 .44959 L .47551 .44796 L p .886 .991 .767 r
F P
0 g
s
.06212 .49718 m .06189 .49108 L .06216 .48878 L p .864 .735 .218 r
F P
0 g
s
.06189 .49108 m .06212 .49718 L .06206 .49804 L p .846 .713 .184 r
F P
0 g
s
.06168 .50607 m .06206 .50194 L .06212 .50281 L p .844 .667 .128 r
F P
0 g
s
.06212 .50281 m .06188 .50885 L .06168 .50607 L p .844 .667 .128 r
F P
0 g
s
.61208 .47853 m .61917 .48444 L .62047 .48424 L p .712 .178 0 r
F P
0 g
s
.6308 .49087 m .62047 .48424 L .61917 .48444 L p .635 .073 0 r
F P
0 g
s
.07975 .57048 m .06614 .5351 L .0671 .53672 L p .756 .406 0 r
F P
0 g
s
.0671 .53672 m .0817 .57375 L .07975 .57048 L p .756 .406 0 r
F P
0 g
s
.71766 .11992 m .71815 .12034 L .71739 .11994 L p 0 .33 .736 r
F P
0 g
s
.71739 .11994 m .71635 .11923 L .71766 .11992 L p 0 .33 .736 r
F P
0 g
s
.72045 .1217 m .72157 .12224 L .72269 .123 L p 0 .292 .728 r
F P
0 g
s
.72157 .12224 m .72045 .1217 L .71972 .12124 L p 0 .29 .718 r
F P
0 g
s
.61829 .42385 m .61384 .42808 L .61548 .4284 L p .781 .998 .842 r
F P
0 g
s
.488 .35525 m .48497 .36089 L .48592 .36222 L p 0 0 .158 r
F P
0 g
s
.48233 .3672 m .48592 .36222 L .48497 .36089 L p 0 0 .114 r
F P
0 g
s
.43088 .3811 m .44079 .38286 L .44027 .38158 L p .472 0 0 r
F P
0 g
s
.54457 .49609 m .53606 .50613 L .53842 .50578 L p 0 0 0 r
F P
0 g
s
.53842 .50578 m .54644 .49579 L .54457 .49609 L p 0 0 0 r
F P
0 g
s
.719 .12067 m .71894 .12078 L .71815 .12034 L p 0 .309 .722 r
F P
0 g
s
.71815 .12034 m .71766 .11992 L .719 .12067 L p 0 .309 .722 r
F P
0 g
s
.71972 .12124 m .72033 .12146 L .72157 .12224 L p 0 .29 .718 r
F P
0 g
s
.72033 .12146 m .71972 .12124 L .71894 .12078 L p 0 .295 .716 r
F P
0 g
s
.47551 .44796 m .4701 .45482 L .47085 .45666 L p .886 .991 .767 r
F P
0 g
s
.46527 .46588 m .47085 .45666 L .4701 .45482 L p .912 .979 .71 r
F P
0 g
s
.71894 .12078 m .719 .12067 L .72033 .12146 L p 0 .295 .716 r
F P
0 g
s
.06206 .49804 m .06169 .49377 L .06189 .49108 L p .846 .713 .184 r
F P
0 g
s
.06169 .49377 m .06206 .49804 L .06202 .49899 L p .832 .693 .156 r
F P
0 g
s
.06156 .50304 m .06202 .50099 L .06206 .50194 L p .831 .665 .121 r
F P
0 g
s
.06206 .50194 m .06168 .50607 L .06156 .50304 L p .831 .665 .121 r
F P
0 g
s
.49063 .34903 m .488 .35525 L .4891 .35665 L p 0 0 .198 r
F P
0 g
s
.48592 .36222 m .4891 .35665 L .488 .35525 L p 0 0 .158 r
F P
0 g
s
.62338 .41955 m .61829 .42385 L .62011 .4243 L p .752 .994 .861 r
F P
0 g
s
.0659 .46596 m .06283 .48574 L .06247 .48698 L p .821 .766 .254 r
F P
0 g
s
.419 .37767 m .43088 .3811 L .43034 .37967 L p .516 0 0 r
F P
0 g
s
.06202 .49899 m .06157 .49675 L .06169 .49377 L p .832 .693 .156 r
F P
0 g
s
.06157 .49675 m .06202 .49899 L .062 .49999 L p .824 .678 .135 r
F P
0 g
s
.06153 .49988 m .062 .49999 L .06202 .50099 L p .824 .668 .123 r
F P
0 g
s
.06202 .50099 m .06156 .50304 L .06153 .49988 L p .824 .668 .123 r
F P
0 g
s
.06524 .53186 m .06247 .51313 L .06284 .51444 L p .812 .565 .007 r
F P
0 g
s
.06284 .51444 m .06614 .5351 L .06524 .53186 L p .812 .565 .007 r
F P
0 g
s
.062 .49999 m .06153 .49988 L .06157 .49675 L p .824 .678 .135 r
F P
0 g
s
.61917 .48444 m .62924 .49115 L .6308 .49087 L p .635 .073 0 r
F P
0 g
s
.64542 .49891 m .6308 .49087 L .62924 .49115 L p .581 .005 0 r
F P
0 g
s
.49292 .34225 m .49063 .34903 L .49192 .35051 L p 0 0 .231 r
F P
0 g
s
.4891 .35665 m .49192 .35051 L .49063 .34903 L p 0 0 .198 r
F P
0 g
s
.71284 .11744 m .71515 .11865 L .71409 .11819 L p 0 .346 .722 r
F P
0 g
s
.71409 .11819 m .71115 .11671 L .71284 .11744 L p 0 .346 .722 r
F P
0 g
s
.72362 .12369 m .72637 .12549 L .7275 .12643 L p 0 .241 .701 r
F P
0 g
s
.72637 .12549 m .72362 .12369 L .72269 .123 L p 0 .214 .663 r
F P
0 g
s
.65812 .1083 m .6735 .10803 L .67123 .10809 L p .018 .592 .712 r
F P
0 g
s
.67123 .10809 m .65528 .10838 L .65812 .1083 L p .018 .592 .712 r
F P
0 g
s
.4701 .45482 m .46437 .46374 L .46527 .46588 L p .912 .979 .71 r
F P
0 g
s
.45916 .47799 m .46527 .46588 L .46437 .46374 L p .927 .964 .662 r
F P
0 g
s
.76172 .17027 m .75395 .15605 L .75284 .15402 L p .621 .23 0 r
F P
0 g
s
.74536 .14367 m .75284 .15402 L .75395 .15605 L p 0 0 .484 r
F P
0 g
s
.62907 .41517 m .62338 .41955 L .62537 .42016 L p .73 .989 .876 r
F P
0 g
s
.73931 .8663 m .72565 .87548 L .72663 .87466 L p 0 0 0 r
F P
0 g
s
.72663 .87466 m .74224 .86384 L .73931 .8663 L p 0 0 0 r
F P
0 g
s
.71112 .88362 m .69353 .89188 L .69066 .89262 L p 0 0 0 r
F P
0 g
s
.69353 .89188 m .71112 .88362 L .71234 .88317 L p 0 0 0 r
F P
0 g
s
.53606 .50613 m .52359 .51953 L .52665 .5191 L p 0 0 0 r
F P
0 g
s
.52665 .5191 m .53842 .50578 L .53606 .50613 L p 0 0 0 r
F P
0 g
s
.49492 .33492 m .49292 .34225 L .49441 .34379 L p 0 0 .26 r
F P
0 g
s
.49192 .35051 m .49441 .34379 L .49292 .34225 L p 0 0 .231 r
F P
0 g
s
.40433 .37221 m .419 .37767 L .41843 .37603 L p .546 0 0 r
F P
0 g
s
.69808 .11204 m .70486 .11419 L .70335 .11381 L p 0 .433 .735 r
F P
0 g
s
.70335 .11381 m .69591 .11149 L .69808 .11204 L p 0 .433 .735 r
F P
0 g
s
.73856 .13614 m .7328 .13082 L .73171 .1297 L p 0 .075 .574 r
F P
0 g
s
.7275 .12643 m .73171 .1297 L .7328 .13082 L p 0 .191 .674 r
F P
0 g
s
.63536 .41065 m .62907 .41517 L .63123 .41595 L p .715 .985 .886 r
F P
0 g
s
.63123 .41595 m .63768 .41163 L .63536 .41065 L p .715 .985 .886 r
F P
0 g
s
.70693 .11496 m .71115 .11671 L .70978 .1162 L p 0 .365 .707 r
F P
0 g
s
.70978 .1162 m .70486 .11419 L .70693 .11496 L p 0 .365 .707 r
F P
0 g
s
.49667 .32707 m .49492 .33492 L .49662 .33651 L p 0 0 .282 r
F P
0 g
s
.49441 .34379 m .49662 .33651 L .49492 .33492 L p 0 0 .26 r
F P
0 g
s
.73171 .1297 m .7275 .12643 L .72637 .12549 L p 0 .134 .603 r
F P
0 g
s
.71477 .11838 m .71635 .11923 L .71515 .11865 L p 0 .296 .676 r
F P
0 g
s
.71515 .11865 m .71284 .11744 L .71477 .11838 L p 0 .296 .676 r
F P
0 g
s
.72269 .123 m .72488 .12439 L .72637 .12549 L p 0 .214 .663 r
F P
0 g
s
.72488 .12439 m .72269 .123 L .72157 .12224 L p 0 .196 .631 r
F P
0 g
s
.46437 .46374 m .45805 .47545 L .45916 .47799 L p .927 .964 .662 r
F P
0 g
s
.45195 .49407 m .45916 .47799 L .45805 .47545 L p .935 .953 .631 r
F P
0 g
s
.62924 .49115 m .64352 .49931 L .64542 .49891 L p .581 .005 0 r
F P
0 g
s
.66609 .50976 m .64542 .49891 L .64352 .49931 L p .565 0 0 r
F P
0 g
s
.63768 .41163 m .64492 .40699 L .64246 .40579 L p .706 .983 .89 r
F P
0 g
s
.64246 .40579 m .63537 .41064 L .63768 .41163 L p .706 .983 .89 r
F P
0 g
s
.6402 .11113 m .65812 .1083 L .65528 .10838 L p 0 0 0 r
F P
0 g
s
.65528 .10838 m .63679 .11121 L .6402 .11113 L p 0 0 0 r
F P
0 g
s
.55654 .4571 m .55769 .46103 L .5595 .46056 L p .295 .322 .719 r
F P
0 g
s
.55769 .46103 m .55827 .46531 L .56014 .46489 L p .286 .269 .664 r
F P
0 g
s
.56014 .46489 m .5595 .46056 L .55769 .46103 L p .286 .269 .664 r
F P
0 g
s
.5549 .45349 m .55654 .4571 L .55833 .45657 L p .304 .371 .767 r
F P
0 g
s
.5595 .46056 m .55833 .45657 L .55654 .4571 L p .295 .322 .719 r
F P
0 g
s
.4983 .3184 m .49667 .32706 L .4986 .32868 L p 0 0 .297 r
F P
0 g
s
.76848 .1881 m .76172 .17027 L .76031 .16769 L p .742 .402 0 r
F P
0 g
s
.75284 .15402 m .76031 .16769 L .76172 .17027 L p .621 .23 0 r
F P
0 g
s
.40374 .3703 m .38498 .36214 L .38555 .3644 L p .56 0 0 r
F P
0 g
s
.38555 .3644 m .40433 .37221 L .40374 .3703 L p .56 0 0 r
F P
0 g
s
.55827 .46531 m .55817 .47 L .56016 .4696 L p .276 .212 .602 r
F P
0 g
s
.56016 .4696 m .56014 .46489 L .55827 .46531 L p .276 .212 .602 r
F P
0 g
s
.55285 .45016 m .5549 .45349 L .55669 .45287 L p .313 .417 .808 r
F P
0 g
s
.55833 .45657 m .55669 .45287 L .5549 .45349 L p .304 .371 .767 r
F P
0 g
s
.71685 .11947 m .71766 .11992 L .71635 .11923 L p 0 .253 .639 r
F P
0 g
s
.71635 .11923 m .71477 .11838 L .71685 .11947 L p 0 .253 .639 r
F P
0 g
s
.72157 .12224 m .7231 .12319 L .72488 .12439 L p 0 .196 .631 r
F P
0 g
s
.7231 .12319 m .72157 .12224 L .72033 .12146 L p 0 .191 .611 r
F P
0 g
s
.5986 .45396 m .59886 .45855 L .6007 .45837 L p .962 .777 .606 r
F P
0 g
s
.6007 .45837 m .60051 .45381 L .5986 .45396 L p .962 .777 .606 r
F P
0 g
s
.60175 .46308 m .6007 .45837 L .59886 .45855 L p .956 .714 .53 r
F P
0 g
s
.52359 .51953 m .5057 .53901 L .50979 .53846 L p 0 0 0 r
F P
0 g
s
.50979 .53846 m .52665 .5191 L .52359 .51953 L p 0 0 0 r
F P
0 g
s
.73541 .86919 m .72437 .87642 L .72565 .87548 L p 0 0 0 r
F P
0 g
s
.72565 .87548 m .73931 .8663 L .73541 .86919 L p 0 0 0 r
F P
0 g
s
.55042 .4471 m .55285 .45016 L .55463 .44943 L p .323 .459 .843 r
F P
0 g
s
.55669 .45287 m .55463 .44943 L .55285 .45016 L p .313 .417 .808 r
F P
0 g
s
.55817 .47 m .55723 .4752 L .55941 .47481 L p .264 .151 .532 r
F P
0 g
s
.55941 .47481 m .56016 .4696 L .55817 .47 L p .264 .151 .532 r
F P
0 g
s
.59904 .44948 m .5986 .45396 L .60051 .45381 L p .958 .827 .672 r
F P
0 g
s
.60051 .45381 m .60108 .44937 L .59904 .44948 L p .958 .827 .672 r
F P
0 g
s
.64492 .40699 m .65325 .40178 L .65066 .40031 L p .703 .981 .895 r
F P
0 g
s
.65066 .40031 m .64246 .40579 L .64492 .40699 L p .703 .981 .895 r
F P
0 g
s
.71234 .88317 m .69747 .89042 L .69353 .89188 L p 0 0 0 r
F P
0 g
s
.69747 .89042 m .71234 .88317 L .71384 .88251 L p 0 0 0 r
F P
0 g
s
.0659 .46596 m .07752 .43343 L .07912 .43098 L p .782 .837 .373 r
F P
0 g
s
.10907 .38845 m .07912 .43098 L .07752 .43343 L p 0 0 0 r
F P
0 g
s
.59886 .45855 m .59991 .46328 L .60175 .46308 L p .956 .714 .53 r
F P
0 g
s
.60382 .46796 m .60175 .46308 L .59991 .46328 L p .938 .638 .445 r
F P
0 g
s
.4986 .32868 m .50047 .32002 L .4983 .3184 L p 0 0 .297 r
F P
0 g
s
.49994 .30854 m .4983 .3184 L .50047 .32002 L p 0 0 .309 r
F P
0 g
s
.54768 .44429 m .55042 .4471 L .55219 .44623 L p .335 .498 .872 r
F P
0 g
s
.55463 .44943 m .55219 .44623 L .55042 .4471 L p .323 .459 .843 r
F P
0 g
s
.719 .12067 m .719 .12067 L .71766 .11992 L p .348 0 0 r
F P
0 g
s
.71766 .11992 m .71685 .11947 L .719 .12067 L p .348 0 0 r
F P
0 g
s
.72033 .12146 m .72111 .12193 L .7231 .12319 L p 0 .191 .611 r
F P
0 g
s
.72111 .12193 m .72033 .12146 L .719 .12067 L p .364 0 0 r
F P
0 g
s
.6001 .44508 m .59904 .44948 L .60108 .44937 L p .946 .867 .729 r
F P
0 g
s
.60108 .44937 m .60234 .44502 L .6001 .44508 L p .946 .867 .729 r
F P
0 g
s
.80055 .77078 m .77248 .83149 L .77386 .82872 L p .659 .781 .315 r
F P
0 g
s
.77386 .82872 m .80257 .76677 L .80055 .77078 L p .659 .781 .315 r
F P
0 g
s
.719 .12067 m .719 .12067 L .72111 .12193 L p .364 0 0 r
F P
0 g
s
.45805 .47545 m .45056 .49097 L .45195 .49407 L p .935 .953 .631 r
F P
0 g
s
.4424 .5156 m .45195 .49407 L .45056 .49097 L p .936 .951 .629 r
F P
0 g
s
.59991 .46328 m .60189 .4682 L .60382 .46796 L p .938 .638 .445 r
F P
0 g
s
.60714 .47309 m .60382 .46796 L .60189 .4682 L p .907 .55 .352 r
F P
0 g
s
.06247 .48698 m .06507 .46879 L .0659 .46596 L p .821 .766 .254 r
F P
0 g
s
.06507 .46879 m .06247 .48698 L .06216 .48878 L p .743 .694 .152 r
F P
0 g
s
.54467 .44174 m .54768 .44429 L .54942 .44327 L p .349 .534 .896 r
F P
0 g
s
.55219 .44623 m .54942 .44327 L .54768 .44429 L p .335 .498 .872 r
F P
0 g
s
.55723 .4752 m .55522 .48106 L .55768 .48064 L p .25 .087 .454 r
F P
0 g
s
.55768 .48064 m .55941 .47481 L .55723 .4752 L p .25 .087 .454 r
F P
0 g
s
.06444 .52717 m .06215 .51124 L .06247 .51313 L p .73 .508 0 r
F P
0 g
s
.06247 .51313 m .06524 .53186 L .06444 .52717 L p .73 .508 0 r
F P
0 g
s
.65325 .40178 m .66277 .3958 L .66007 .39404 L p .706 .982 .897 r
F P
0 g
s
.66007 .39404 m .65066 .40031 L .65325 .40178 L p .706 .982 .897 r
F P
0 g
s
.50047 .32002 m .50236 .31015 L .49994 .30854 L p 0 0 .309 r
F P
0 g
s
.50168 .29734 m .49994 .30854 L .50236 .31015 L p 0 0 .316 r
F P
0 g
s
.60177 .44073 m .6001 .44508 L .60234 .44502 L p .927 .896 .777 r
F P
0 g
s
.60234 .44502 m .60426 .44074 L .60177 .44073 L p .927 .896 .777 r
F P
0 g
s
.54144 .43945 m .54467 .44174 L .54634 .44055 L p .365 .568 .915 r
F P
0 g
s
.54942 .44327 m .54634 .44055 L .54467 .44174 L p .349 .534 .896 r
F P
0 g
s
.70949 .11607 m .71284 .11744 L .71115 .11671 L p .305 0 0 r
F P
0 g
s
.71115 .11671 m .70693 .11496 L .70949 .11607 L p .305 0 0 r
F P
0 g
s
.62045 .11738 m .6402 .11113 L .63679 .11121 L p 0 0 0 r
F P
0 g
s
.63679 .11121 m .61652 .11744 L .62045 .11738 L p 0 0 0 r
F P
0 g
s
.72637 .12549 m .72999 .12827 L .73171 .1297 L p 0 .134 .603 r
F P
0 g
s
.72999 .12827 m .72637 .12549 L .72488 .12439 L p .454 0 0 r
F P
0 g
s
.38498 .36214 m .36016 .35161 L .36062 .35426 L p .556 0 0 r
F P
0 g
s
.36062 .35426 m .38555 .3644 L .38498 .36214 L p .556 0 0 r
F P
0 g
s
.64352 .49931 m .66378 .51036 L .66609 .50976 L p .565 0 0 r
F P
0 g
s
.69493 .52646 m .66609 .50976 L .66378 .51036 L p .597 .025 0 r
F P
0 g
s
.68906 .11012 m .69808 .11204 L .69591 .11149 L p .19 0 0 r
F P
0 g
s
.69591 .11149 m .68606 .10936 L .68906 .11012 L p .19 0 0 r
F P
0 g
s
.73171 .1297 m .73697 .13451 L .73856 .13614 L p 0 .075 .574 r
F P
0 g
s
.74536 .14367 m .73856 .13614 L .73697 .13451 L p .563 .072 0 r
F P
0 g
s
.11819 .61674 m .07975 .57048 L .0817 .57375 L p 0 0 .54 r
F P
0 g
s
.0817 .57375 m .12147 .62227 L .11819 .61674 L p 0 0 .54 r
F P
0 g
s
.77303 .20931 m .76848 .1881 L .76676 .18498 L p .843 .569 .027 r
F P
0 g
s
.76031 .16769 m .76676 .18498 L .76848 .1881 L p .742 .402 0 r
F P
0 g
s
.53804 .43742 m .54144 .43945 L .54299 .43807 L p .385 .598 .931 r
F P
0 g
s
.54634 .44055 m .54299 .43807 L .54144 .43945 L p .365 .568 .915 r
F P
0 g
s
.60189 .4682 m .60504 .47337 L .60714 .47309 L p .907 .55 .352 r
F P
0 g
s
.61208 .47853 m .60714 .47309 L .60504 .47337 L p .862 .453 .252 r
F P
0 g
s
.73068 .87241 m .72283 .87747 L .72437 .87642 L p 0 0 0 r
F P
0 g
s
.72437 .87642 m .73541 .86919 L .73068 .87241 L p 0 0 0 r
F P
0 g
s
.71384 .88251 m .70229 .88831 L .69747 .89042 L p 0 0 0 r
F P
0 g
s
.70229 .88831 m .71384 .88251 L .71554 .88169 L p 0 0 0 r
F P
0 g
s
.71738 .88072 m .71358 .8826 L .70774 .88566 L p .341 .79 .639 r
F P
0 g
s
.53452 .43565 m .53804 .43742 L .53944 .43585 L p .406 .627 .943 r
F P
0 g
s
.54299 .43807 m .53944 .43585 L .53804 .43742 L p .385 .598 .931 r
F P
0 g
s
.66277 .3958 m .67355 .38881 L .67073 .38674 L p .717 .984 .894 r
F P
0 g
s
.67073 .38674 m .66007 .39404 L .66277 .3958 L p .717 .984 .894 r
F P
0 g
s
.69066 .89262 m .64642 .90198 L .64245 .90192 L p .006 0 0 r
F P
0 g
s
.56116 .88851 m .64245 .90192 L .64642 .90198 L p 0 .551 .787 r
F P
0 g
s
.50236 .31015 m .50438 .29891 L .50168 .29734 L p 0 0 .316 r
F P
0 g
s
.50371 .28467 m .50168 .29734 L .50438 .29891 L p 0 0 .316 r
F P
0 g
s
.55522 .48106 m .55179 .48779 L .55469 .48732 L p .234 .022 .373 r
F P
0 g
s
.55469 .48732 m .55768 .48064 L .55522 .48106 L p .234 .022 .373 r
F P
0 g
s
.60403 .43639 m .60177 .44073 L .60426 .44074 L p .905 .917 .818 r
F P
0 g
s
.60426 .44074 m .60682 .4365 L .60403 .43639 L p .905 .917 .818 r
F P
0 g
s
.53093 .43415 m .53452 .43565 L .53573 .4339 L p .43 .654 .953 r
F P
0 g
s
.53944 .43585 m .53573 .4339 L .53452 .43565 L p .406 .627 .943 r
F P
0 g
s
.50997 .42822 m .50513 .42859 L .50548 .43098 L p .635 .816 .97 r
F P
0 g
s
.50548 .43098 m .51014 .43059 L .50997 .42822 L p .635 .816 .97 r
F P
0 g
s
.50071 .43189 m .50548 .43098 L .50513 .42859 L p .678 .839 .961 r
F P
0 g
s
.50513 .42859 m .50021 .42948 L .50071 .43189 L p .678 .839 .961 r
F P
0 g
s
.49585 .4334 m .50071 .43189 L .50021 .42948 L p .721 .861 .948 r
F P
0 g
s
.53573 .4339 m .53192 .43224 L .53093 .43415 L p .43 .654 .953 r
F P
0 g
s
.5272 .43288 m .53093 .43415 L .53192 .43223 L p .454 .684 .964 r
F P
0 g
s
.51471 .42831 m .50997 .42822 L .51014 .43059 L p .593 .791 .974 r
F P
0 g
s
.51014 .43059 m .51467 .43064 L .51471 .42831 L p .593 .791 .974 r
F P
0 g
s
.51931 .42881 m .51471 .42831 L .51467 .43064 L p .554 .764 .976 r
F P
0 g
s
.51467 .43064 m .51904 .43108 L .51931 .42881 L p .554 .764 .976 r
F P
0 g
s
.50021 .42948 m .49521 .43095 L .49585 .4334 L p .721 .861 .948 r
F P
0 g
s
.4909 .43561 m .49585 .4334 L .49521 .43095 L p .764 .88 .93 r
F P
0 g
s
.53192 .43223 m .52796 .43083 L .5272 .43288 L p .454 .684 .964 r
F P
0 g
s
.52323 .43184 m .5272 .43288 L .52796 .43083 L p .484 .71 .97 r
F P
0 g
s
.52374 .42967 m .51931 .42881 L .51904 .43108 L p .517 .737 .974 r
F P
0 g
s
.51904 .43108 m .52323 .43184 L .52374 .42967 L p .517 .737 .974 r
F P
0 g
s
.52796 .43083 m .52374 .42967 L .52323 .43184 L p .484 .71 .97 r
F P
0 g
s
.70107 .11314 m .70693 .11496 L .70486 .11419 L p .287 0 0 r
F P
0 g
s
.70486 .11419 m .69808 .11204 L .70107 .11314 L p .287 0 0 r
F P
0 g
s
.73697 .13451 m .73171 .1297 L .72999 .12827 L p .535 .008 0 r
F P
0 g
s
.49521 .43095 m .49013 .43309 L .4909 .43561 L p .764 .88 .93 r
F P
0 g
s
.48587 .43864 m .4909 .43561 L .49013 .43309 L p .805 .896 .907 r
F P
0 g
s
.5057 .53901 m .48138 .57005 L .48694 .56938 L p 0 0 .002 r
F P
0 g
s
.48694 .56938 m .50979 .53846 L .5057 .53901 L p 0 0 .002 r
F P
0 g
s
.50438 .29891 m .5067 .28617 L .50371 .28467 L p 0 0 .316 r
F P
0 g
s
.50628 .2704 m .50371 .28467 L .5067 .28617 L p 0 0 .308 r
F P
0 g
s
.67355 .38881 m .68557 .38052 L .68266 .37811 L p .734 .988 .888 r
F P
0 g
s
.68266 .37811 m .67073 .38674 L .67355 .38881 L p .734 .988 .888 r
F P
0 g
s
.45056 .49097 m .44064 .51173 L .4424 .5156 L p .936 .951 .629 r
F P
0 g
s
.4279 .54441 m .4424 .5156 L .44064 .51173 L p .929 .963 .663 r
F P
0 g
s
.60001 .12758 m .62045 .11738 L .61652 .11744 L p 0 0 0 r
F P
0 g
s
.61652 .11744 m .59568 .12756 L .60001 .12758 L p 0 0 0 r
F P
0 g
s
.72531 .87582 m .7211 .87857 L .72283 .87747 L p .388 .804 .605 r
F P
0 g
s
.72283 .87747 m .73068 .87241 L .72531 .87582 L p .388 .804 .605 r
F P
0 g
s
.71554 .88169 m .70774 .88566 L .70229 .88831 L p 0 0 0 r
F P
0 g
s
.70774 .88566 m .71554 .88169 L .71738 .88072 L p .341 .79 .639 r
F P
0 g
s
.60687 .43205 m .60403 .43639 L .60682 .4365 L p .88 .929 .85 r
F P
0 g
s
.60682 .4365 m .61001 .43229 L .60687 .43205 L p .88 .929 .85 r
F P
0 g
s
.49013 .43309 m .48498 .43601 L .48587 .43864 L p .805 .896 .907 r
F P
0 g
s
.48075 .44268 m .48587 .43864 L .48498 .43601 L p .844 .907 .88 r
F P
0 g
s
.7124 .11748 m .71477 .11838 L .71284 .11744 L p .385 0 0 r
F P
0 g
s
.71284 .11744 m .70949 .11607 L .7124 .11748 L p .385 0 0 r
F P
0 g
s
.72488 .12439 m .72774 .12661 L .72999 .12827 L p .454 0 0 r
F P
0 g
s
.72774 .12661 m .72488 .12439 L .7231 .12319 L p .496 0 0 r
F P
0 g
s
.60504 .47337 m .60968 .47887 L .61208 .47853 L p .862 .453 .252 r
F P
0 g
s
.61917 .48444 m .61208 .47853 L .60968 .47887 L p .808 .353 .155 r
F P
0 g
s
.77425 .23307 m .77303 .20931 L .77101 .2057 L p .912 .714 .215 r
F P
0 g
s
.76676 .18498 m .77101 .2057 L .77303 .20931 L p .843 .569 .027 r
F P
0 g
s
.36016 .35161 m .32644 .33982 L .3266 .3429 L p .524 0 0 r
F P
0 g
s
.3266 .3429 m .36062 .35426 L .36016 .35161 L p .524 0 0 r
F P
0 g
s
.74409 .86191 m .77248 .83149 L .76856 .83558 L p .53 .827 .497 r
F P
0 g
s
.47378 .37538 m .46871 .37851 L .46986 .38089 L p .434 .114 .323 r
F P
0 g
s
.46871 .37851 m .46301 .38094 L .4641 .3833 L p .48 .126 .288 r
F P
0 g
s
.4641 .3833 m .46986 .38089 L .46871 .37851 L p .48 .126 .288 r
F P
0 g
s
.46301 .38094 m .45657 .38257 L .45765 .38498 L p .528 .141 .251 r
F P
0 g
s
.45765 .38498 m .4641 .3833 L .46301 .38094 L p .528 .141 .251 r
F P
0 g
s
.4783 .3716 m .47378 .37538 L .47504 .37784 L p .389 .105 .357 r
F P
0 g
s
.46986 .38089 m .47504 .37784 L .47378 .37538 L p .434 .114 .323 r
F P
0 g
s
.06216 .48878 m .06434 .47296 L .06507 .46879 L p .743 .694 .152 r
F P
0 g
s
.06434 .47296 m .06216 .48878 L .06189 .49108 L p 0 0 0 r
F P
0 g
s
.5067 .28617 m .50957 .2718 L .50628 .2704 L p 0 0 .308 r
F P
0 g
s
.50973 .25446 m .50628 .2704 L .50957 .2718 L p 0 0 .29 r
F P
0 g
s
.55179 .48779 m .54644 .49579 L .54999 .49523 L p .217 0 .292 r
F P
0 g
s
.54999 .49523 m .55469 .48732 L .55179 .48779 L p .217 0 .292 r
F P
0 g
s
.71952 .87926 m .71926 .87967 L .7211 .87857 L p .389 .813 .633 r
F P
0 g
s
.7211 .87857 m .72531 .87582 L .71952 .87926 L p .389 .813 .633 r
F P
0 g
s
.68557 .38052 m .69874 .37054 L .69577 .36776 L p .759 .993 .875 r
F P
0 g
s
.69577 .36776 m .68266 .37811 L .68557 .38052 L p .759 .993 .875 r
F P
0 g
s
.71358 .8826 m .71738 .88072 L .71926 .87967 L p .373 .808 .645 r
F P
0 g
s
.45657 .38257 m .44924 .38327 L .45034 .38582 L p .576 .158 .212 r
F P
0 g
s
.45034 .38582 m .45765 .38498 L .45657 .38257 L p .576 .158 .212 r
F P
0 g
s
.06378 .52125 m .06188 .50885 L .06215 .51124 L p 0 0 .139 r
F P
0 g
s
.06215 .51124 m .06444 .52717 L .06378 .52125 L p 0 0 .139 r
F P
0 g
s
.48498 .43601 m .47972 .43986 L .48075 .44268 L p .844 .907 .88 r
F P
0 g
s
.47551 .44796 m .48075 .44268 L .47972 .43986 L p .879 .915 .847 r
F P
0 g
s
.64642 .90198 m .69066 .89262 L .69353 .89188 L p .199 .725 .738 r
F P
0 g
s
.71926 .87967 m .71952 .87926 L .71358 .8826 L p .373 .808 .645 r
F P
0 g
s
.66378 .51036 m .69221 .52741 L .69493 .52646 L p .597 .025 0 r
F P
0 g
s
.73304 .55518 m .69493 .52646 L .69221 .52741 L p .68 .134 0 r
F P
0 g
s
.48233 .3672 m .4783 .3716 L .47972 .37418 L p .347 .099 .388 r
F P
0 g
s
.47504 .37784 m .47972 .37418 L .4783 .3716 L p .389 .105 .357 r
F P
0 g
s
.55833 .45657 m .5595 .46056 L .56212 .45992 L p .449 .425 .739 r
F P
0 g
s
.5595 .46056 m .56014 .46489 L .56284 .46431 L p .444 .386 .698 r
F P
0 g
s
.56284 .46431 m .56212 .45992 L .5595 .46056 L p .444 .386 .698 r
F P
0 g
s
.55669 .45287 m .55833 .45657 L .56093 .45584 L p .454 .461 .776 r
F P
0 g
s
.56212 .45992 m .56093 .45584 L .55833 .45657 L p .449 .425 .739 r
F P
0 g
s
.61031 .42766 m .60687 .43205 L .61001 .43229 L p .855 .936 .876 r
F P
0 g
s
.61001 .43229 m .61384 .42808 L .61031 .42766 L p .855 .936 .876 r
F P
0 g
s
.56014 .46489 m .56016 .4696 L .563 .46905 L p .437 .343 .652 r
F P
0 g
s
.563 .46905 m .56284 .46431 L .56014 .46489 L p .437 .343 .652 r
F P
0 g
s
.58021 .14166 m .60001 .12758 L .59568 .12756 L p 0 0 0 r
F P
0 g
s
.59568 .12756 m .57563 .14152 L .58021 .14166 L p 0 0 0 r
F P
0 g
s
.50957 .2718 m .51333 .25573 L .50973 .25446 L p 0 0 .29 r
F P
0 g
s
.51453 .23689 m .50973 .25446 L .51333 .25573 L p 0 0 .262 r
F P
0 g
s
.71556 .11914 m .71685 .11947 L .71477 .11838 L p .446 0 0 r
F P
0 g
s
.71477 .11838 m .7124 .11748 L .71556 .11914 L p .446 0 0 r
F P
0 g
s
.7231 .12319 m .72504 .12478 L .72774 .12661 L p .496 0 0 r
F P
0 g
s
.72504 .12478 m .7231 .12319 L .72111 .12193 L p .514 0 0 r
F P
0 g
s
.07752 .43343 m .0659 .46596 L .06507 .46879 L p 0 0 0 r
F P
0 g
s
.55463 .44943 m .55669 .45287 L .55931 .45202 L p .459 .494 .807 r
F P
0 g
s
.56093 .45584 m .55931 .45202 L .55669 .45287 L p .454 .461 .776 r
F P
0 g
s
.16032 .3507 m .10907 .38845 L .10688 .39184 L p 0 0 0 r
F P
0 g
s
.07752 .43343 m .10688 .39184 L .10907 .38845 L p 0 0 0 r
F P
0 g
s
.44924 .38327 m .44079 .38286 L .44195 .38565 L p .62 .176 .174 r
F P
0 g
s
.44195 .38565 m .45034 .38582 L .44924 .38327 L p .62 .176 .174 r
F P
0 g
s
.69874 .37054 m .71279 .35843 L .70978 .35528 L p .789 .998 .854 r
F P
0 g
s
.70978 .35528 m .69577 .36776 L .69874 .37054 L p .789 .998 .854 r
F P
0 g
s
.77145 .25806 m .77425 .23307 L .77195 .2291 L p .945 .827 .383 r
F P
0 g
s
.77101 .2057 m .77195 .2291 L .77425 .23307 L p .912 .714 .215 r
F P
0 g
s
.59578 .45423 m .59614 .45885 L .59886 .45855 L p .894 .724 .664 r
F P
0 g
s
.59886 .45855 m .5986 .45396 L .59578 .45423 L p .894 .724 .664 r
F P
0 g
s
.59991 .46328 m .59886 .45855 L .59614 .45885 L p .891 .68 .61 r
F P
0 g
s
.68606 .10936 m .6735 .10803 L .67746 .10903 L p .238 0 0 r
F P
0 g
s
.48592 .36222 m .48233 .3672 L .48395 .36996 L p .31 .095 .417 r
F P
0 g
s
.47972 .37418 m .48395 .36996 L .48233 .3672 L p .347 .099 .388 r
F P
0 g
s
.75284 .15402 m .74536 .14367 L .74317 .14142 L p .711 .243 0 r
F P
0 g
s
.73697 .13451 m .74317 .14142 L .74536 .14367 L p .563 .072 0 r
F P
0 g
s
.56016 .4696 m .55941 .47481 L .56251 .47426 L p .428 .297 .599 r
F P
0 g
s
.56251 .47426 m .563 .46905 L .56016 .4696 L p .428 .297 .599 r
F P
0 g
s
.59602 .44971 m .59578 .45423 L .5986 .45396 L p .891 .762 .712 r
F P
0 g
s
.5986 .45396 m .59904 .44948 L .59602 .44971 L p .891 .762 .712 r
F P
0 g
s
.47972 .43986 m .47432 .44486 L .47551 .44796 L p .879 .915 .847 r
F P
0 g
s
.4701 .45482 m .47551 .44796 L .47432 .44486 L p .91 .919 .811 r
F P
0 g
s
.55219 .44623 m .55463 .44943 L .55728 .44842 L p .465 .524 .835 r
F P
0 g
s
.55931 .45202 m .55728 .44842 L .55463 .44943 L p .459 .494 .807 r
F P
0 g
s
.59614 .45885 m .59717 .46362 L .59991 .46328 L p .891 .68 .61 r
F P
0 g
s
.60189 .4682 m .59991 .46328 L .59717 .46362 L p .881 .627 .549 r
F P
0 g
s
.51333 .25573 m .51844 .238 L .51453 .23689 L p 0 0 .262 r
F P
0 g
s
.52123 .21791 m .51453 .23689 L .51844 .238 L p 0 0 .221 r
F P
0 g
s
.60968 .47887 m .61634 .48488 L .61917 .48444 L p .808 .353 .155 r
F P
0 g
s
.62924 .49115 m .61917 .48444 L .61634 .48488 L p .753 .263 .069 r
F P
0 g
s
.71881 .12096 m .719 .12067 L .71685 .11947 L p .488 0 0 r
F P
0 g
s
.71685 .11947 m .71556 .11914 L .71881 .12096 L p .488 0 0 r
F P
0 g
s
.72111 .12193 m .72202 .12287 L .72504 .12478 L p .514 0 0 r
F P
0 g
s
.72202 .12287 m .72111 .12193 L .719 .12067 L p .511 0 0 r
F P
0 g
s
.07786 .56376 m .06524 .53186 L .06614 .5351 L p 0 0 .351 r
F P
0 g
s
.06614 .5351 m .07975 .57048 L .07786 .56376 L p 0 0 .351 r
F P
0 g
s
.56228 .15896 m .58021 .14166 L .57563 .14152 L p 0 0 0 r
F P
0 g
s
.57563 .14152 m .55762 .15865 L .56228 .15896 L p 0 0 0 r
F P
0 g
s
.5968 .44525 m .59602 .44971 L .59904 .44948 L p .884 .792 .753 r
F P
0 g
s
.59904 .44948 m .6001 .44508 L .5968 .44525 L p .884 .792 .753 r
F P
0 g
s
.32644 .33982 m .28074 .33049 L .28031 .33397 L p .451 0 0 r
F P
0 g
s
.28031 .33397 m .3266 .3429 L .32644 .33982 L p .451 0 0 r
F P
0 g
s
.71279 .35843 m .72726 .34377 L .72424 .34026 L p .825 1 .823 r
F P
0 g
s
.72424 .34026 m .70978 .35528 L .71279 .35843 L p .825 1 .823 r
F P
0 g
s
.719 .12067 m .71881 .12096 L .72202 .12287 L p .511 0 0 r
F P
0 g
s
.54942 .44327 m .55219 .44623 L .55486 .44502 L p .471 .552 .857 r
F P
0 g
s
.55728 .44842 m .55486 .44502 L .55219 .44623 L p .465 .524 .835 r
F P
0 g
s
.44064 .51173 m .42561 .53953 L .4279 .54441 L p .929 .963 .663 r
F P
0 g
s
.40308 .5817 m .4279 .54441 L .42561 .53953 L p .904 .984 .738 r
F P
0 g
s
.61436 .42319 m .61031 .42766 L .61384 .42808 L p .832 .939 .896 r
F P
0 g
s
.61384 .42808 m .61829 .42385 L .61436 .42319 L p .832 .939 .896 r
F P
0 g
s
.70476 .11475 m .70949 .11607 L .70693 .11496 L p .409 0 0 r
F P
0 g
s
.70693 .11496 m .70107 .11314 L .70476 .11475 L p .409 0 0 r
F P
0 g
s
.72999 .12827 m .73449 .13245 L .73697 .13451 L p .535 .008 0 r
F P
0 g
s
.73449 .13245 m .72999 .12827 L .72774 .12661 L p .611 .068 0 r
F P
0 g
s
.76456 .28274 m .77145 .25806 L .7689 .25388 L p .948 .905 .523 r
F P
0 g
s
.77195 .2291 m .7689 .25388 L .77145 .25806 L p .945 .827 .383 r
F P
0 g
s
.59717 .46362 m .59902 .46858 L .60189 .4682 L p .881 .627 .549 r
F P
0 g
s
.60504 .47337 m .60189 .4682 L .59902 .46858 L p .864 .565 .48 r
F P
0 g
s
.4891 .35665 m .48592 .36222 L .4878 .36517 L p .277 .094 .443 r
F P
0 g
s
.48395 .36996 m .4878 .36517 L .48592 .36222 L p .31 .095 .417 r
F P
0 g
s
.51844 .238 m .52541 .21884 L .52123 .21791 L p 0 0 .221 r
F P
0 g
s
.53037 .19798 m .52123 .21791 L .52541 .21884 L p 0 0 .166 r
F P
0 g
s
.06189 .49108 m .06373 .47832 L .06434 .47296 L p 0 0 0 r
F P
0 g
s
.06373 .47832 m .06189 .49108 L .06169 .49377 L p 0 0 .035 r
F P
0 g
s
.44079 .38286 m .43088 .3811 L .43214 .38424 L p .659 .194 .138 r
F P
0 g
s
.43214 .38424 m .44195 .38565 L .44079 .38286 L p .659 .194 .138 r
F P
0 g
s
.55941 .47481 m .55768 .48064 L .5612 .48005 L p .417 .247 .541 r
F P
0 g
s
.5612 .48005 m .56251 .47426 L .55941 .47481 L p .417 .247 .541 r
F P
0 g
s
.54644 .49579 m .53842 .50578 L .54291 .50508 L p .202 0 .224 r
F P
0 g
s
.54291 .50508 m .54999 .49523 L .54644 .49579 L p .202 0 .224 r
F P
0 g
s
.06329 .51441 m .06168 .50607 L .06188 .50885 L p 0 0 .179 r
F P
0 g
s
.06188 .50885 m .06378 .52125 L .06329 .51441 L p 0 0 .179 r
F P
0 g
s
.54704 .17838 m .56228 .15896 L .55762 .15865 L p 0 0 .004 r
F P
0 g
s
.55762 .15865 m .54244 .17787 L .54704 .17838 L p 0 0 .004 r
F P
0 g
s
.72726 .34377 m .7414 .32624 L .73842 .32241 L p .862 .996 .779 r
F P
0 g
s
.73842 .32241 m .72424 .34026 L .72726 .34377 L p .862 .996 .779 r
F P
0 g
s
.54634 .44055 m .54942 .44327 L .55207 .44183 L p .479 .578 .876 r
F P
0 g
s
.55486 .44502 m .55207 .44183 L .54942 .44327 L p .471 .552 .857 r
F P
0 g
s
.52541 .21884 m .5348 .1987 L .53037 .19798 L p 0 0 .166 r
F P
0 g
s
.54244 .17787 m .53037 .19798 L .5348 .1987 L p 0 0 .094 r
F P
0 g
s
.80304 .68593 m .80055 .77078 L .80257 .76677 L p .88 .74 .229 r
F P
0 g
s
.80257 .76677 m .80559 .6821 L .80304 .68593 L p .88 .74 .229 r
F P
0 g
s
.5348 .1987 m .54704 .17838 L .54244 .17787 L p 0 0 .094 r
F P
0 g
s
.59808 .44082 m .5968 .44525 L .6001 .44508 L p .873 .816 .79 r
F P
0 g
s
.6001 .44508 m .60177 .44073 L .59808 .44082 L p .873 .816 .79 r
F P
0 g
s
.48138 .57005 m .45352 .62297 L .46101 .62223 L p 0 0 .147 r
F P
0 g
s
.46101 .62223 m .48694 .56938 L .48138 .57005 L p 0 0 .147 r
F P
0 g
s
.75421 .30577 m .76456 .28274 L .76182 .27854 L p .93 .955 .634 r
F P
0 g
s
.7689 .25388 m .76182 .27854 L .76456 .28274 L p .948 .905 .523 r
F P
0 g
s
.47432 .44486 m .46869 .45132 L .4701 .45482 L p .91 .919 .811 r
F P
0 g
s
.46437 .46374 m .4701 .45482 L .46869 .45132 L p .934 .918 .774 r
F P
0 g
s
.7414 .32624 m .75421 .30577 L .75132 .30169 L p .899 .983 .717 r
F P
0 g
s
.75132 .30169 m .73842 .32241 L .7414 .32624 L p .899 .983 .717 r
F P
0 g
s
.6932 .11165 m .70107 .11314 L .69808 .11204 L p .369 0 0 r
F P
0 g
s
.69808 .11204 m .68906 .11012 L .6932 .11165 L p .369 0 0 r
F P
0 g
s
.76182 .27854 m .75132 .30169 L .75421 .30577 L p .93 .955 .634 r
F P
0 g
s
.74317 .14142 m .73697 .13451 L .73449 .13245 L p .689 .177 0 r
F P
0 g
s
.54299 .43807 m .54634 .44055 L .54891 .43883 L p .489 .6 .891 r
F P
0 g
s
.55207 .44183 m .54891 .43883 L .54634 .44055 L p .479 .578 .876 r
F P
0 g
s
.49192 .35051 m .4891 .35665 L .49129 .35982 L p .249 .094 .466 r
F P
0 g
s
.4878 .36517 m .49129 .35982 L .4891 .35665 L p .277 .094 .443 r
F P
0 g
s
.69221 .52741 m .73002 .55675 L .73304 .55518 L p .68 .134 0 r
F P
0 g
s
.77571 .60549 m .73304 .55518 L .73002 .55675 L p .797 .315 0 r
F P
0 g
s
.61903 .41862 m .61436 .42319 L .61829 .42385 L p .813 .938 .911 r
F P
0 g
s
.61829 .42385 m .62338 .41955 L .61903 .41862 L p .813 .938 .911 r
F P
0 g
s
.59902 .46858 m .60189 .4738 L .60504 .47337 L p .864 .565 .48 r
F P
0 g
s
.60968 .47887 m .60504 .47337 L .60189 .4738 L p .838 .495 .405 r
F P
0 g
s
.53944 .43585 m .54299 .43807 L .54542 .43604 L p .501 .621 .902 r
F P
0 g
s
.54891 .43883 m .54542 .43604 L .54299 .43807 L p .489 .6 .891 r
F P
0 g
s
.28074 .33049 m .22276 .33124 L .22144 .33501 L p .313 0 0 r
F P
0 g
s
.22144 .33501 m .28031 .33397 L .28074 .33049 L p .313 0 0 r
F P
0 g
s
.06169 .49377 m .06326 .48468 L .06373 .47832 L p 0 0 .035 r
F P
0 g
s
.06326 .48468 m .06169 .49377 L .06157 .49675 L p 0 0 .106 r
F P
0 g
s
.55768 .48064 m .55469 .48732 L .55883 .48665 L p .402 .194 .478 r
F P
0 g
s
.55883 .48665 m .5612 .48005 L .55768 .48064 L p .402 .194 .478 r
F P
0 g
s
.59987 .43636 m .59808 .44082 L .60177 .44073 L p .859 .833 .821 r
F P
0 g
s
.60177 .44073 m .60403 .43639 L .59987 .43636 L p .859 .833 .821 r
F P
0 g
s
.43088 .3811 m .419 .37767 L .42039 .38131 L p .691 .211 .106 r
F P
0 g
s
.42039 .38131 m .43214 .38424 L .43088 .3811 L p .691 .211 .106 r
F P
0 g
s
.1919 .65201 m .11819 .61674 L .12147 .62227 L p .034 .487 .882 r
F P
0 g
s
.12147 .62227 m .19622 .65955 L .1919 .65201 L p .034 .487 .882 r
F P
0 g
s
.06298 .50698 m .06156 .50304 L .06168 .50607 L p 0 0 .195 r
F P
0 g
s
.06168 .50607 m .06329 .51441 L .06298 .50698 L p 0 0 .195 r
F P
0 g
s
.22276 .33124 m .16032 .3507 L .15821 .35452 L p .087 0 0 r
F P
0 g
s
.10688 .39184 m .15821 .35452 L .16032 .3507 L p 0 0 0 r
F P
0 g
s
.53573 .4339 m .53944 .43585 L .54163 .43351 L p .514 .639 .91 r
F P
0 g
s
.54542 .43604 m .54163 .43351 L .53944 .43585 L p .501 .621 .902 r
F P
0 g
s
.56093 .45584 m .56212 .45992 L .56547 .45915 L p .538 .484 .743 r
F P
0 g
s
.56212 .45992 m .56284 .46431 L .56625 .46361 L p .535 .452 .709 r
F P
0 g
s
.56625 .46361 m .56547 .45915 L .56212 .45992 L p .535 .452 .709 r
F P
0 g
s
.55931 .45202 m .56093 .45584 L .5643 .45497 L p .541 .512 .773 r
F P
0 g
s
.56547 .45915 m .5643 .45497 L .56093 .45584 L p .538 .484 .743 r
F P
0 g
s
.61634 .48488 m .62579 .49173 L .62924 .49115 L p .753 .263 .069 r
F P
0 g
s
.64352 .49931 m .62924 .49115 L .62579 .49173 L p .711 .2 .011 r
F P
0 g
s
.56284 .46431 m .563 .46905 L .56658 .46838 L p .53 .418 .671 r
F P
0 g
s
.56658 .46838 m .56625 .46361 L .56284 .46431 L p .53 .418 .671 r
F P
0 g
s
.50455 .42507 m .49941 .42596 L .50021 .42948 L p .705 .774 .906 r
F P
0 g
s
.50021 .42948 m .50513 .42859 L .50455 .42507 L p .705 .774 .906 r
F P
0 g
s
.49521 .43095 m .50021 .42948 L .49941 .42596 L p .737 .788 .894 r
F P
0 g
s
.50964 .4247 m .50455 .42507 L .50513 .42859 L p .674 .759 .915 r
F P
0 g
s
.50513 .42859 m .50997 .42822 L .50964 .4247 L p .674 .759 .915 r
F P
0 g
s
.53192 .43224 m .53573 .4339 L .53761 .43125 L p .53 .655 .916 r
F P
0 g
s
.54163 .43351 m .53761 .43125 L .53573 .4339 L p .514 .639 .91 r
F P
0 g
s
.49941 .42596 m .49423 .4274 L .49521 .43095 L p .737 .788 .894 r
F P
0 g
s
.49013 .43309 m .49521 .43095 L .49423 .4274 L p .768 .801 .88 r
F P
0 g
s
.70898 .1168 m .7124 .11748 L .70949 .11607 L p .504 0 0 r
F P
0 g
s
.70949 .11607 m .70476 .11475 L .70898 .1168 L p .504 0 0 r
F P
0 g
s
.51468 .42481 m .50964 .4247 L .50997 .42822 L p .645 .743 .921 r
F P
0 g
s
.50997 .42822 m .51471 .42831 L .51468 .42481 L p .645 .743 .921 r
F P
0 g
s
.49441 .34379 m .49192 .35051 L .49447 .35389 L p .227 .097 .486 r
F P
0 g
s
.49129 .35982 m .49447 .35389 L .49192 .35051 L p .249 .094 .466 r
F P
0 g
s
.72774 .12661 m .73122 .13004 L .73449 .13245 L p .611 .068 0 r
F P
0 g
s
.73122 .13004 m .72774 .12661 L .72504 .12478 L p .651 .101 0 r
F P
0 g
s
.51964 .42537 m .51468 .42481 L .51471 .42831 L p .616 .727 .925 r
F P
0 g
s
.51471 .42831 m .51931 .42881 L .51964 .42537 L p .616 .727 .925 r
F P
0 g
s
.53761 .43125 m .53345 .42932 L .53192 .43224 L p .53 .655 .916 r
F P
0 g
s
.52796 .43083 m .53192 .43223 L .53345 .42932 L p .547 .677 .924 r
F P
0 g
s
.06157 .49675 m .06298 .49178 L .06326 .48468 L p 0 0 .106 r
F P
0 g
s
.06298 .49178 m .06157 .49675 L .06153 .49988 L p 0 0 .157 r
F P
0 g
s
.55728 .44842 m .55931 .45202 L .56274 .45099 L p .544 .538 .799 r
F P
0 g
s
.5643 .45497 m .56274 .45099 L .55931 .45202 L p .541 .512 .773 r
F P
0 g
s
.59218 .45463 m .59265 .45928 L .59614 .45885 L p .839 .681 .687 r
F P
0 g
s
.59614 .45885 m .59578 .45423 L .59218 .45463 L p .839 .681 .687 r
F P
0 g
s
.59717 .46362 m .59614 .45885 L .59265 .45928 L p .837 .646 .645 r
F P
0 g
s
.52447 .42634 m .51964 .42537 L .51931 .42881 L p .591 .711 .927 r
F P
0 g
s
.51931 .42881 m .52374 .42967 L .52447 .42634 L p .591 .711 .927 r
F P
0 g
s
.66315 .1096 m .67746 .10903 L .6735 .10803 L p .28 0 0 r
F P
0 g
s
.6735 .10803 m .65812 .1083 L .66315 .1096 L p .28 0 0 r
F P
0 g
s
.49423 .4274 m .48899 .42947 L .49013 .43309 L p .768 .801 .88 r
F P
0 g
s
.48498 .43601 m .49013 .43309 L .48899 .42947 L p .799 .812 .862 r
F P
0 g
s
.53345 .42932 m .52909 .42768 L .52796 .43083 L p .547 .677 .924 r
F P
0 g
s
.52374 .42967 m .52796 .43083 L .52909 .42768 L p .567 .694 .926 r
F P
0 g
s
.15821 .35452 m .22144 .33501 L .22276 .33124 L p .087 0 0 r
F P
0 g
s
.06288 .49932 m .06153 .49988 L .06156 .50304 L p 0 0 .187 r
F P
0 g
s
.06156 .50304 m .06298 .50698 L .06288 .49932 L p 0 0 .187 r
F P
0 g
s
.52909 .42768 m .52447 .42634 L .52374 .42967 L p .567 .694 .926 r
F P
0 g
s
.46869 .45132 m .4627 .45967 L .46437 .46374 L p .934 .918 .774 r
F P
0 g
s
.45805 .47545 m .46437 .46374 L .4627 .45967 L p .952 .914 .741 r
F P
0 g
s
.59217 .45007 m .59218 .45463 L .59578 .45423 L p .837 .711 .725 r
F P
0 g
s
.59578 .45423 m .59602 .44971 L .59217 .45007 L p .837 .711 .725 r
F P
0 g
s
.76031 .16769 m .75284 .15402 L .74991 .15102 L p .841 .418 0 r
F P
0 g
s
.74317 .14142 m .74991 .15102 L .75284 .15402 L p .711 .243 0 r
F P
0 g
s
.563 .46905 m .56251 .47426 L .5664 .47358 L p .523 .38 .629 r
F P
0 g
s
.5664 .47358 m .56658 .46838 L .563 .46905 L p .523 .38 .629 r
F P
0 g
s
.62432 .41391 m .61903 .41862 L .62338 .41955 L p .797 .936 .921 r
F P
0 g
s
.62338 .41955 m .62907 .41517 L .62432 .41391 L p .797 .936 .921 r
F P
0 g
s
.06153 .49988 m .06288 .49932 L .06298 .49178 L p 0 0 .157 r
F P
0 g
s
.42561 .53953 m .4001 .57557 L .40308 .5817 L p .904 .984 .738 r
F P
0 g
s
.35878 .62454 m .40308 .5817 L .4001 .57557 L p .84 .995 .843 r
F P
0 g
s
.59265 .45928 m .59366 .46408 L .59717 .46362 L p .837 .646 .645 r
F P
0 g
s
.59902 .46858 m .59717 .46362 L .59366 .46408 L p .83 .605 .597 r
F P
0 g
s
.60216 .43184 m .59987 .43636 L .60403 .43639 L p .843 .846 .846 r
F P
0 g
s
.60403 .43639 m .60687 .43205 L .60216 .43184 L p .843 .846 .846 r
F P
0 g
s
.55486 .44502 m .55728 .44842 L .5608 .44719 L p .546 .561 .821 r
F P
0 g
s
.56274 .45099 m .5608 .44719 L .55728 .44842 L p .544 .538 .799 r
F P
0 g
s
.48899 .42947 m .48367 .43224 L .48498 .43601 L p .799 .812 .862 r
F P
0 g
s
.47972 .43986 m .48498 .43601 L .48367 .43224 L p .829 .822 .842 r
F P
0 g
s
.53842 .50578 m .52665 .5191 L .53254 .51818 L p .192 0 .185 r
F P
0 g
s
.53254 .51818 m .54291 .50508 L .53842 .50578 L p .192 0 .185 r
F P
0 g
s
.60189 .4738 m .60608 .47939 L .60968 .47887 L p .838 .495 .405 r
F P
0 g
s
.61634 .48488 m .60968 .47887 L .60608 .47939 L p .805 .421 .328 r
F P
0 g
s
.59258 .44557 m .59217 .45007 L .59602 .44971 L p .832 .736 .758 r
F P
0 g
s
.59602 .44971 m .5968 .44525 L .59258 .44557 L p .832 .736 .758 r
F P
0 g
s
.73002 .55675 m .77275 .60812 L .77571 .60549 L p .797 .315 0 r
F P
0 g
s
.80559 .6821 m .77571 .60549 L .77275 .60812 L p .897 .542 .068 r
F P
0 g
s
.76217 .84087 m .73931 .8663 L .74224 .86384 L p .659 .933 .656 r
F P
0 g
s
.74224 .86384 m .76856 .83558 L .76217 .84087 L p .659 .933 .656 r
F P
0 g
s
.47504 .37784 m .46986 .38089 L .47154 .38447 L p .554 .299 .483 r
F P
0 g
s
.46986 .38089 m .4641 .3833 L .46571 .38686 L p .589 .308 .458 r
F P
0 g
s
.46571 .38686 m .47154 .38447 L .46986 .38089 L p .589 .308 .458 r
F P
0 g
s
.4641 .3833 m .45765 .38498 L .45924 .38862 L p .624 .318 .431 r
F P
0 g
s
.45924 .38862 m .46571 .38686 L .4641 .3833 L p .624 .318 .431 r
F P
0 g
s
.49662 .33651 m .49441 .34379 L .49736 .34738 L p .21 .1 .503 r
F P
0 g
s
.49447 .35389 m .49736 .34738 L .49441 .34379 L p .227 .097 .486 r
F P
0 g
s
.77275 .60812 m .80304 .68593 L .80559 .6821 L p .897 .542 .068 r
F P
0 g
s
.4741 .81754 m .56116 .88851 L .56846 .8886 L p 0 .363 .829 r
F P
0 g
s
.64642 .90198 m .56846 .8886 L .56116 .88851 L p 0 .551 .787 r
F P
0 g
s
.47972 .37418 m .47504 .37784 L .47686 .38154 L p .522 .291 .506 r
F P
0 g
s
.47154 .38447 m .47686 .38154 L .47504 .37784 L p .554 .299 .483 r
F P
0 g
s
.59366 .46408 m .59532 .46908 L .59902 .46858 L p .83 .605 .597 r
F P
0 g
s
.60189 .4738 m .59902 .46858 L .59532 .46908 L p .819 .557 .543 r
F P
0 g
s
.419 .37767 m .40433 .37221 L .40586 .3765 L p .713 .224 .082 r
F P
0 g
s
.40586 .3765 m .42039 .38131 L .419 .37767 L p .713 .224 .082 r
F P
0 g
s
.55469 .48732 m .54999 .49523 L .55504 .49444 L p .387 .141 .415 r
F P
0 g
s
.55504 .49444 m .55883 .48665 L .55469 .48732 L p .387 .141 .415 r
F P
0 g
s
.55207 .44183 m .55486 .44502 L .55847 .44354 L p .55 .582 .84 r
F P
0 g
s
.5608 .44719 m .55847 .44354 L .55486 .44502 L p .546 .561 .821 r
F P
0 g
s
.56251 .47426 m .5612 .48005 L .5656 .47933 L p .514 .339 .582 r
F P
0 g
s
.5656 .47933 m .5664 .47358 L .56251 .47426 L p .514 .339 .582 r
F P
0 g
s
.71356 .1192 m .71556 .11914 L .7124 .11748 L p .574 0 0 r
F P
0 g
s
.7124 .11748 m .70898 .1168 L .71356 .1192 L p .574 0 0 r
F P
0 g
s
.72504 .12478 m .72731 .12738 L .73122 .13004 L p .651 .101 0 r
F P
0 g
s
.72731 .12738 m .72504 .12478 L .72202 .12287 L p .662 .109 0 r
F P
0 g
s
.45765 .38498 m .45034 .38582 L .45198 .38968 L p .66 .329 .402 r
F P
0 g
s
.45198 .38968 m .45924 .38862 L .45765 .38498 L p .66 .329 .402 r
F P
0 g
s
.48367 .43224 m .47823 .43584 L .47972 .43986 L p .829 .822 .842 r
F P
0 g
s
.47432 .44486 m .47972 .43986 L .47823 .43584 L p .858 .83 .819 r
F P
0 g
s
.69353 .89188 m .65348 .90017 L .64642 .90198 L p .199 .725 .738 r
F P
0 g
s
.65348 .90017 m .69353 .89188 L .69747 .89042 L p .379 .843 .866 r
F P
0 g
s
.59337 .44106 m .59258 .44557 L .5968 .44525 L p .824 .756 .788 r
F P
0 g
s
.5968 .44525 m .59808 .44082 L .59337 .44106 L p .824 .756 .788 r
F P
0 g
s
.63023 .40903 m .62432 .41391 L .62907 .41517 L p .786 .933 .928 r
F P
0 g
s
.62907 .41517 m .63536 .41065 L .63023 .40903 L p .786 .933 .928 r
F P
0 g
s
.48395 .36996 m .47972 .37418 L .48175 .37809 L p .491 .286 .528 r
F P
0 g
s
.47686 .38154 m .48175 .37809 L .47972 .37418 L p .522 .291 .506 r
F P
0 g
s
.60499 .42722 m .60216 .43184 L .60687 .43205 L p .827 .853 .867 r
F P
0 g
s
.60687 .43205 m .61031 .42766 L .60499 .42722 L p .827 .853 .867 r
F P
0 g
s
.54891 .43883 m .55207 .44183 L .55572 .44002 L p .554 .6 .854 r
F P
0 g
s
.55847 .44354 m .55572 .44002 L .55207 .44183 L p .55 .582 .84 r
F P
0 g
s
.45352 .62297 m .4391 .70978 L .4485 .70919 L p 0 0 .366 r
F P
0 g
s
.4485 .70919 m .46101 .62223 L .45352 .62297 L p 0 0 .366 r
F P
0 g
s
.5643 .45497 m .56547 .45915 L .56944 .4583 L p .598 .524 .742 r
F P
0 g
s
.56547 .45915 m .56625 .46361 L .57026 .46283 L p .596 .497 .713 r
F P
0 g
s
.57026 .46283 m .56944 .4583 L .56547 .45915 L p .596 .497 .713 r
F P
0 g
s
.69831 .11388 m .70476 .11475 L .70107 .11314 L p .505 0 0 r
F P
0 g
s
.70107 .11314 m .6932 .11165 L .69831 .11388 L p .505 0 0 r
F P
0 g
s
.56625 .46361 m .56658 .46838 L .57076 .46763 L p .592 .468 .68 r
F P
0 g
s
.57076 .46763 m .57026 .46283 L .56625 .46361 L p .592 .468 .68 r
F P
0 g
s
.73449 .13245 m .73972 .13855 L .74317 .14142 L p .689 .177 0 r
F P
0 g
s
.73972 .13855 m .73449 .13245 L .73122 .13004 L p .754 .241 0 r
F P
0 g
s
.56274 .45099 m .5643 .45497 L .56833 .454 L p .6 .548 .768 r
F P
0 g
s
.56944 .4583 m .56833 .454 L .5643 .45497 L p .598 .524 .742 r
F P
0 g
s
.71827 .12184 m .71881 .12096 L .71556 .11914 L p .621 .055 0 r
F P
0 g
s
.71556 .11914 m .71356 .1192 L .71827 .12184 L p .621 .055 0 r
F P
0 g
s
.49859 .32869 m .49662 .33651 L .50001 .34028 L p .197 .104 .517 r
F P
0 g
s
.49736 .34738 m .50001 .34028 L .49662 .33651 L p .21 .1 .503 r
F P
0 g
s
.72202 .12287 m .72293 .12461 L .72731 .12738 L p .662 .109 0 r
F P
0 g
s
.72293 .12461 m .72202 .12287 L .71881 .12096 L p .651 .093 0 r
F P
0 g
s
.06507 .46879 m .07604 .43857 L .07752 .43343 L p 0 0 0 r
F P
0 g
s
.07604 .43857 m .06507 .46879 L .06434 .47296 L p 0 0 .038 r
F P
0 g
s
.45034 .38582 m .44195 .38565 L .4437 .38987 L p .694 .341 .372 r
F P
0 g
s
.4437 .38987 m .45198 .38968 L .45034 .38582 L p .694 .341 .372 r
F P
0 g
s
.58797 .45516 m .58856 .45982 L .59265 .45928 L p .794 .646 .699 r
F P
0 g
s
.59265 .45928 m .59218 .45463 L .58797 .45516 L p .794 .646 .699 r
F P
0 g
s
.59366 .46408 m .59265 .45928 L .58856 .45982 L p .792 .616 .663 r
F P
0 g
s
.4627 .45967 m .45603 .47057 L .45805 .47545 L p .952 .914 .741 r
F P
0 g
s
.45056 .49097 m .45805 .47545 L .45603 .47057 L p .961 .91 .719 r
F P
0 g
s
.71881 .12096 m .71827 .12184 L .72293 .12461 L p .651 .093 0 r
F P
0 g
s
.68296 .11107 m .6932 .11165 L .68906 .11012 L p .438 0 0 r
F P
0 g
s
.68906 .11012 m .67746 .10903 L .68296 .11107 L p .438 0 0 r
F P
0 g
s
.58769 .45059 m .58797 .45516 L .59218 .45463 L p .793 .672 .731 r
F P
0 g
s
.59218 .45463 m .59217 .45007 L .58769 .45059 L p .793 .672 .731 r
F P
0 g
s
.4878 .36517 m .48395 .36996 L .48627 .37415 L p .464 .282 .548 r
F P
0 g
s
.48175 .37809 m .48627 .37415 L .48395 .36996 L p .491 .286 .528 r
F P
0 g
s
.59532 .46908 m .59782 .47438 L .60189 .4738 L p .819 .557 .543 r
F P
0 g
s
.60608 .47939 m .60189 .4738 L .59782 .47438 L p .801 .503 .483 r
F P
0 g
s
.74991 .15102 m .74317 .14142 L .73972 .13855 L p .821 .35 0 r
F P
0 g
s
.54542 .43604 m .54891 .43883 L .55254 .43663 L p .559 .616 .865 r
F P
0 g
s
.55572 .44002 m .55254 .43663 L .54891 .43883 L p .554 .6 .854 r
F P
0 g
s
.5608 .44719 m .56274 .45099 L .56691 .44987 L p .601 .569 .791 r
F P
0 g
s
.56833 .454 m .56691 .44987 L .56274 .45099 L p .6 .548 .768 r
F P
0 g
s
.56658 .46838 m .5664 .47358 L .57092 .47282 L p .587 .435 .643 r
F P
0 g
s
.57092 .47282 m .57076 .46763 L .56658 .46838 L p .587 .435 .643 r
F P
0 g
s
.62579 .49173 m .63924 .50011 L .64352 .49931 L p .711 .2 .011 r
F P
0 g
s
.66378 .51036 m .64352 .49931 L .63924 .50011 L p .698 .181 0 r
F P
0 g
s
.47823 .43584 m .4726 .44045 L .47432 .44486 L p .858 .83 .819 r
F P
0 g
s
.46869 .45132 m .47432 .44486 L .4726 .44045 L p .884 .836 .793 r
F P
0 g
s
.58856 .45982 m .58952 .46465 L .59366 .46408 L p .792 .616 .663 r
F P
0 g
s
.59532 .46908 m .59366 .46408 L .58952 .46465 L p .787 .582 .623 r
F P
0 g
s
.59453 .43649 m .59337 .44106 L .59808 .44082 L p .814 .772 .813 r
F P
0 g
s
.59808 .44082 m .59987 .43636 L .59453 .43649 L p .814 .772 .813 r
F P
0 g
s
.5612 .48005 m .55883 .48665 L .564 .48583 L p .502 .294 .53 r
F P
0 g
s
.564 .48583 m .5656 .47933 L .5612 .48005 L p .502 .294 .53 r
F P
0 g
s
.4001 .57557 m .35499 .6171 L .35878 .62454 L p .84 .995 .843 r
F P
0 g
s
.28657 .65863 m .35878 .62454 L .35499 .6171 L p .702 .958 .948 r
F P
0 g
s
.63537 .41064 m .64246 .40579 L .63696 .40376 L p .783 .933 .93 r
F P
0 g
s
.63696 .40376 m .63024 .40903 L .63537 .41064 L p .783 .933 .93 r
F P
0 g
s
.60608 .47939 m .61207 .48553 L .61634 .48488 L p .805 .421 .328 r
F P
0 g
s
.62579 .49173 m .61634 .48488 L .61207 .48553 L p .77 .351 .256 r
F P
0 g
s
.07616 .55397 m .06444 .52717 L .06524 .53186 L p 0 0 .484 r
F P
0 g
s
.06524 .53186 m .07786 .56376 L .07616 .55397 L p 0 0 .484 r
F P
0 g
s
.58768 .44607 m .58769 .45059 L .59217 .45007 L p .789 .694 .759 r
F P
0 g
s
.59217 .45007 m .59258 .44557 L .58768 .44607 L p .789 .694 .759 r
F P
0 g
s
.64633 .11275 m .66315 .1096 L .65812 .1083 L p .308 0 0 r
F P
0 g
s
.65812 .1083 m .6402 .11113 L .64633 .11275 L p .308 0 0 r
F P
0 g
s
.54163 .43351 m .54542 .43604 L .5489 .43339 L p .565 .628 .873 r
F P
0 g
s
.55254 .43663 m .5489 .43339 L .54542 .43604 L p .559 .616 .865 r
F P
0 g
s
.28213 .65045 m .1919 .65201 L .19622 .65955 L p .447 .815 .994 r
F P
0 g
s
.19622 .65955 m .28657 .65863 L .28213 .65045 L p .447 .815 .994 r
F P
0 g
s
.55847 .44354 m .5608 .44719 L .56516 .44585 L p .601 .588 .81 r
F P
0 g
s
.56691 .44987 m .56516 .44585 L .5608 .44719 L p .601 .569 .791 r
F P
0 g
s
.50001 .34028 m .50244 .33259 L .49859 .32869 L p .197 .104 .517 r
F P
0 g
s
.50047 .32002 m .4986 .32868 L .50244 .33259 L p .182 .103 .525 r
F P
0 g
s
.60838 .42244 m .60499 .42722 L .61031 .42766 L p .811 .857 .883 r
F P
0 g
s
.61031 .42766 m .61436 .42319 L .60838 .42244 L p .811 .857 .883 r
F P
0 g
s
.76676 .18498 m .76031 .16769 L .75655 .16386 L p .933 .574 .158 r
F P
0 g
s
.74991 .15102 m .75655 .16386 L .76031 .16769 L p .841 .418 0 r
F P
0 g
s
.40433 .37221 m .38555 .3644 L .38721 .36953 L p .723 .23 .069 r
F P
0 g
s
.38721 .36953 m .40586 .3765 L .40433 .37221 L p .723 .23 .069 r
F P
0 g
s
.50367 .42044 m .49829 .42138 L .49941 .42596 L p .709 .721 .858 r
F P
0 g
s
.49941 .42596 m .50455 .42507 L .50367 .42044 L p .709 .721 .858 r
F P
0 g
s
.49423 .4274 m .49941 .42596 L .49829 .42138 L p .734 .73 .848 r
F P
0 g
s
.49129 .35982 m .4878 .36517 L .49049 .36969 L p .439 .28 .567 r
F P
0 g
s
.48627 .37415 m .49049 .36969 L .4878 .36517 L p .464 .282 .548 r
F P
0 g
s
.49829 .42138 m .49291 .42284 L .49423 .4274 L p .734 .73 .848 r
F P
0 g
s
.48899 .42947 m .49423 .4274 L .49291 .42284 L p .759 .74 .835 r
F P
0 g
s
.58952 .46465 m .59096 .4697 L .59532 .46908 L p .787 .582 .623 r
F P
0 g
s
.59782 .47438 m .59532 .46908 L .59096 .4697 L p .778 .542 .577 r
F P
0 g
s
.56833 .454 m .56944 .4583 L .57387 .45743 L p .644 .556 .74 r
F P
0 g
s
.56944 .4583 m .57026 .46283 L .57469 .46201 L p .643 .532 .713 r
F P
0 g
s
.57469 .46201 m .57387 .45743 L .56944 .4583 L p .643 .532 .713 r
F P
0 g
s
.50906 .41999 m .50367 .42044 L .50455 .42507 L p .686 .711 .867 r
F P
0 g
s
.50455 .42507 m .50964 .4247 L .50906 .41999 L p .686 .711 .867 r
F P
0 g
s
.44195 .38565 m .43214 .38424 L .43406 .38901 L p .726 .353 .342 r
F P
0 g
s
.43406 .38901 m .4437 .38987 L .44195 .38565 L p .726 .353 .342 r
F P
0 g
s
.5664 .47358 m .5656 .47933 L .57068 .4785 L p .579 .399 .601 r
F P
0 g
s
.57068 .4785 m .57092 .47282 L .5664 .47358 L p .579 .399 .601 r
F P
0 g
s
.57026 .46283 m .57076 .46763 L .57535 .46685 L p .64 .505 .683 r
F P
0 g
s
.57535 .46685 m .57469 .46201 L .57026 .46283 L p .64 .505 .683 r
F P
0 g
s
.53761 .43125 m .54163 .43351 L .54482 .43036 L p .573 .639 .878 r
F P
0 g
s
.5489 .43339 m .54482 .43036 L .54163 .43351 L p .565 .628 .873 r
F P
0 g
s
.54999 .49523 m .54291 .50508 L .54931 .50407 L p .371 .095 .358 r
F P
0 g
s
.54931 .50407 m .55504 .49444 L .54999 .49523 L p .371 .095 .358 r
F P
0 g
s
.49291 .42284 m .48749 .42485 L .48899 .42947 L p .759 .74 .835 r
F P
0 g
s
.48367 .43224 m .48899 .42947 L .48749 .42485 L p .784 .749 .821 r
F P
0 g
s
.5145 .42005 m .50906 .41999 L .50964 .4247 L p .663 .701 .875 r
F P
0 g
s
.50964 .4247 m .51468 .42481 L .5145 .42005 L p .663 .701 .875 r
F P
0 g
s
.56691 .44987 m .56833 .454 L .57289 .45302 L p .645 .577 .764 r
F P
0 g
s
.57387 .45743 m .57289 .45302 L .56833 .454 L p .644 .556 .74 r
F P
0 g
s
.58336 .45582 m .58406 .46048 L .58856 .45982 L p .755 .616 .705 r
F P
0 g
s
.58856 .45982 m .58797 .45516 L .58336 .45582 L p .755 .616 .705 r
F P
0 g
s
.58952 .46465 m .58856 .45982 L .58406 .46048 L p .753 .589 .673 r
F P
0 g
s
.58789 .44153 m .58768 .44607 L .59258 .44557 L p .784 .712 .784 r
F P
0 g
s
.59258 .44557 m .59337 .44106 L .58789 .44153 L p .784 .712 .784 r
F P
0 g
s
.52665 .5191 m .50979 .53846 L .51774 .5372 L p .195 0 .19 r
F P
0 g
s
.51774 .5372 m .53254 .51818 L .52665 .5191 L p .195 0 .19 r
F P
0 g
s
.58281 .45127 m .58336 .45582 L .58797 .45516 L p .755 .64 .734 r
F P
0 g
s
.58797 .45516 m .58769 .45059 L .58281 .45127 L p .755 .64 .734 r
F P
0 g
s
.51995 .42061 m .5145 .42005 L .51468 .42481 L p .643 .691 .88 r
F P
0 g
s
.51468 .42481 m .51964 .42537 L .51995 .42061 L p .643 .691 .88 r
F P
0 g
s
.55572 .44002 m .55847 .44354 L .56304 .4419 L p .602 .604 .826 r
F P
0 g
s
.56516 .44585 m .56304 .4419 L .55847 .44354 L p .601 .588 .81 r
F P
0 g
s
.53345 .42932 m .53761 .43125 L .54036 .42761 L p .582 .647 .88 r
F P
0 g
s
.54482 .43036 m .54036 .42761 L .53761 .43125 L p .573 .639 .878 r
F P
0 g
s
.59608 .4318 m .59453 .43649 L .59987 .43636 L p .803 .783 .834 r
F P
0 g
s
.59987 .43636 m .60216 .43184 L .59608 .4318 L p .803 .783 .834 r
F P
0 g
s
.57076 .46763 m .57092 .47282 L .57586 .47201 L p .635 .475 .648 r
F P
0 g
s
.57586 .47201 m .57535 .46685 L .57076 .46763 L p .635 .475 .648 r
F P
0 g
s
.64246 .40579 m .65066 .40031 L .6448 .39783 L p .779 .93 .932 r
F P
0 g
s
.6448 .39783 m .63696 .40376 L .64246 .40579 L p .779 .93 .932 r
F P
0 g
s
.52536 .42169 m .51995 .42061 L .51964 .42537 L p .624 .681 .884 r
F P
0 g
s
.51964 .42537 m .52447 .42634 L .52536 .42169 L p .624 .681 .884 r
F P
0 g
s
.4726 .44045 m .4667 .44634 L .46869 .45132 L p .884 .836 .793 r
F P
0 g
s
.4627 .45967 m .46869 .45132 L .4667 .44634 L p .907 .839 .767 r
F P
0 g
s
.58406 .46048 m .58495 .46532 L .58952 .46465 L p .753 .589 .673 r
F P
0 g
s
.59096 .4697 m .58952 .46465 L .58495 .46532 L p .749 .558 .637 r
F P
0 g
s
.35499 .6171 m .28213 .65045 L .28657 .65863 L p .702 .958 .948 r
F P
0 g
s
.54036 .42761 m .53563 .42523 L .53345 .42932 L p .582 .647 .88 r
F P
0 g
s
.52909 .42768 m .53345 .42932 L .53563 .42523 L p .594 .662 .886 r
F P
0 g
s
.10688 .39184 m .07752 .43343 L .07604 .43857 L p 0 0 0 r
F P
0 g
s
.48749 .42485 m .48198 .42747 L .48367 .43224 L p .784 .749 .821 r
F P
0 g
s
.47823 .43584 m .48367 .43224 L .48198 .42747 L p .809 .757 .804 r
F P
0 g
s
.53064 .42325 m .52536 .42169 L .52447 .42634 L p .607 .671 .886 r
F P
0 g
s
.52447 .42634 m .52909 .42768 L .53064 .42325 L p .607 .671 .886 r
F P
0 g
s
.53563 .42523 m .53064 .42325 L .52909 .42768 L p .594 .662 .886 r
F P
0 g
s
.56516 .44585 m .56691 .44987 L .5717 .44873 L p .644 .595 .785 r
F P
0 g
s
.57289 .45302 m .5717 .44873 L .56691 .44987 L p .645 .577 .764 r
F P
0 g
s
.59782 .47438 m .60142 .48008 L .60608 .47939 L p .801 .503 .483 r
F P
0 g
s
.61207 .48553 m .60608 .47939 L .60142 .48008 L p .779 .444 .42 r
F P
0 g
s
.70417 .11673 m .70898 .1168 L .70476 .11475 L p .6 .043 0 r
F P
0 g
s
.70476 .11475 m .69831 .11388 L .70417 .11673 L p .6 .043 0 r
F P
0 g
s
.73122 .13004 m .73516 .13519 L .73972 .13855 L p .754 .241 0 r
F P
0 g
s
.73516 .13519 m .73122 .13004 L .72731 .12738 L p .775 .268 0 r
F P
0 g
s
.50244 .33259 m .5048 .32404 L .50047 .32002 L p .182 .103 .525 r
F P
0 g
s
.50236 .31015 m .50047 .32002 L .5048 .32404 L p .18 .108 .533 r
F P
0 g
s
.58236 .44678 m .58281 .45127 L .58769 .45059 L p .752 .66 .759 r
F P
0 g
s
.58769 .45059 m .58768 .44607 L .58236 .44678 L p .752 .66 .759 r
F P
0 g
s
.47686 .38154 m .47154 .38447 L .47364 .38911 L p .616 .402 .569 r
F P
0 g
s
.47154 .38447 m .46571 .38686 L .46774 .39146 L p .643 .41 .55 r
F P
0 g
s
.46774 .39146 m .47364 .38911 L .47154 .38447 L p .643 .41 .55 r
F P
0 g
s
.57289 .45302 m .57387 .45743 L .57859 .45658 L p .683 .584 .738 r
F P
0 g
s
.57387 .45743 m .57469 .46201 L .57936 .46122 L p .683 .561 .712 r
F P
0 g
s
.57936 .46122 m .57859 .45658 L .57387 .45743 L p .683 .561 .712 r
F P
0 g
s
.75349 .8472 m .73541 .86919 L .73931 .8663 L p .731 .982 .766 r
F P
0 g
s
.73931 .8663 m .76217 .84087 L .75349 .8472 L p .731 .982 .766 r
F P
0 g
s
.57469 .46201 m .57535 .46685 L .58015 .46606 L p .68 .536 .682 r
F P
0 g
s
.58015 .46606 m .57936 .46122 L .57469 .46201 L p .68 .536 .682 r
F P
0 g
s
.49447 .35389 m .49129 .35982 L .49445 .36471 L p .418 .279 .583 r
F P
0 g
s
.49049 .36969 m .49445 .36471 L .49129 .35982 L p .439 .28 .567 r
F P
0 g
s
.46571 .38686 m .45924 .38862 L .46127 .39334 L p .672 .418 .529 r
F P
0 g
s
.46127 .39334 m .46774 .39146 L .46571 .38686 L p .672 .418 .529 r
F P
0 g
s
.57859 .45658 m .57936 .46122 L .58406 .46048 L p .719 .589 .709 r
F P
0 g
s
.58406 .46048 m .58336 .45582 L .57859 .45658 L p .719 .589 .709 r
F P
0 g
s
.58495 .46532 m .58406 .46048 L .57936 .46122 L p .717 .563 .679 r
F P
0 g
s
.57779 .45209 m .57859 .45658 L .58336 .45582 L p .719 .611 .736 r
F P
0 g
s
.58336 .45582 m .58281 .45127 L .57779 .45209 L p .719 .611 .736 r
F P
0 g
s
.48175 .37809 m .47686 .38154 L .47911 .38634 L p .59 .396 .587 r
F P
0 g
s
.47364 .38911 m .47911 .38634 L .47686 .38154 L p .616 .402 .569 r
F P
0 g
s
.55254 .43663 m .55572 .44002 L .56049 .43799 L p .603 .617 .838 r
F P
0 g
s
.56304 .4419 m .56049 .43799 L .55572 .44002 L p .602 .604 .826 r
F P
0 g
s
.55883 .48665 m .55504 .49444 L .56135 .49344 L p .488 .248 .476 r
F P
0 g
s
.56135 .49344 m .564 .48583 L .55883 .48665 L p .488 .248 .476 r
F P
0 g
s
.4391 .70978 m .4741 .81754 L .48382 .81738 L p 0 .093 .625 r
F P
0 g
s
.48382 .81738 m .4485 .70919 L .4391 .70978 L p 0 .093 .625 r
F P
0 g
s
.61237 .41747 m .60838 .42244 L .61436 .42319 L p .797 .858 .895 r
F P
0 g
s
.61436 .42319 m .61903 .41862 L .61237 .41747 L p .797 .858 .895 r
F P
0 g
s
.5717 .44873 m .57289 .45302 L .57779 .45209 L p .683 .604 .761 r
F P
0 g
s
.57859 .45658 m .57779 .45209 L .57289 .45302 L p .683 .584 .738 r
F P
0 g
s
.57936 .46122 m .58015 .46606 L .58495 .46532 L p .717 .563 .679 r
F P
0 g
s
.59096 .4697 m .593 .47508 L .59782 .47438 L p .778 .542 .577 r
F P
0 g
s
.60142 .48008 m .59782 .47438 L .593 .47508 L p .765 .496 .527 r
F P
0 g
s
.45603 .47057 m .44806 .48494 L .45056 .49097 L p .961 .91 .719 r
F P
0 g
s
.44064 .51173 m .45056 .49097 L .44806 .48494 L p .962 .909 .717 r
F P
0 g
s
.79424 .77684 m .76856 .83558 L .77248 .83149 L p .879 .949 .592 r
F P
0 g
s
.77248 .83149 m .80055 .77078 L .79424 .77684 L p .879 .949 .592 r
F P
0 g
s
.58831 .43689 m .58789 .44153 L .59337 .44106 L p .776 .726 .806 r
F P
0 g
s
.59337 .44106 m .59453 .43649 L .58831 .43689 L p .776 .726 .806 r
F P
0 g
s
.57535 .46685 m .57586 .47201 L .581 .4712 L p .676 .507 .649 r
F P
0 g
s
.581 .4712 m .58015 .46606 L .57535 .46685 L p .676 .507 .649 r
F P
0 g
s
.56846 .8886 m .48382 .81738 L .4741 .81754 L p 0 .363 .829 r
F P
0 g
s
.58611 .47042 m .58495 .46532 L .58015 .46606 L p .713 .534 .645 r
F P
0 g
s
.58495 .46532 m .58611 .47042 L .59096 .4697 L p .749 .558 .637 r
F P
0 g
s
.593 .47508 m .59096 .4697 L .58611 .47042 L p .742 .523 .597 r
F P
0 g
s
.69747 .89042 m .66323 .89659 L .65348 .90017 L p .379 .843 .866 r
F P
0 g
s
.66323 .89659 m .69747 .89042 L .70229 .88831 L p .514 .908 .928 r
F P
0 g
s
.45924 .38862 m .45198 .38968 L .4541 .39469 L p .701 .427 .506 r
F P
0 g
s
.4541 .39469 m .46127 .39334 L .45924 .38862 L p .701 .427 .506 r
F P
0 g
s
.56304 .4419 m .56516 .44585 L .57028 .44449 L p .643 .611 .803 r
F P
0 g
s
.5717 .44873 m .57028 .44449 L .56516 .44585 L p .644 .595 .785 r
F P
0 g
s
.48198 .42747 m .47633 .43078 L .47823 .43584 L p .809 .757 .804 r
F P
0 g
s
.4726 .44045 m .47823 .43584 L .47633 .43078 L p .834 .764 .786 r
F P
0 g
s
.5656 .47933 m .564 .48583 L .56996 .48489 L p .569 .359 .556 r
F P
0 g
s
.56996 .48489 m .57068 .4785 L .5656 .47933 L p .569 .359 .556 r
F P
0 g
s
.57092 .47282 m .57068 .4785 L .57622 .47763 L p .628 .441 .61 r
F P
0 g
s
.57622 .47763 m .57586 .47201 L .57092 .47282 L p .628 .441 .61 r
F P
0 g
s
.57694 .44768 m .57779 .45209 L .58281 .45127 L p .717 .63 .76 r
F P
0 g
s
.58281 .45127 m .58236 .44678 L .57694 .44768 L p .717 .63 .76 r
F P
0 g
s
.43214 .38424 m .42039 .38131 L .42254 .38684 L p .753 .363 .315 r
F P
0 g
s
.42254 .38684 m .43406 .38901 L .43214 .38424 L p .753 .363 .315 r
F P
0 g
s
.58196 .44226 m .58236 .44678 L .58768 .44607 L p .748 .676 .781 r
F P
0 g
s
.58768 .44607 m .58789 .44153 L .58196 .44226 L p .748 .676 .781 r
F P
0 g
s
.48627 .37415 m .48175 .37809 L .48425 .38318 L p .566 .392 .604 r
F P
0 g
s
.47911 .38634 m .48425 .38318 L .48175 .37809 L p .59 .396 .587 r
F P
0 g
s
.57779 .45209 m .57694 .44768 L .5717 .44873 L p .683 .604 .761 r
F P
0 g
s
.58015 .46606 m .581 .4712 L .58611 .47042 L p .713 .534 .645 r
F P
0 g
s
.65066 .40031 m .66007 .39404 L .65385 .39104 L p .781 .927 .931 r
F P
0 g
s
.65385 .39104 m .6448 .39783 L .65066 .40031 L p .781 .927 .931 r
F P
0 g
s
.59804 .42691 m .59608 .4318 L .60216 .43184 L p .791 .79 .851 r
F P
0 g
s
.60216 .43184 m .60499 .42722 L .59804 .42691 L p .791 .79 .851 r
F P
0 g
s
.57028 .44449 m .5717 .44873 L .57694 .44768 L p .681 .621 .782 r
F P
0 g
s
.5489 .43339 m .55254 .43663 L .55744 .43409 L p .604 .627 .847 r
F P
0 g
s
.56049 .43799 m .55744 .43409 L .55254 .43663 L p .603 .617 .838 r
F P
0 g
s
.5048 .32404 m .50721 .31424 L .50236 .31015 L p .18 .108 .533 r
F P
0 g
s
.50438 .29891 m .50236 .31015 L .50721 .31424 L p .181 .112 .537 r
F P
0 g
s
.61207 .48553 m .62057 .49258 L .62579 .49173 L p .77 .351 .256 r
F P
0 g
s
.63924 .50011 m .62579 .49173 L .62057 .49258 L p .741 .3 .205 r
F P
0 g
s
.49736 .34738 m .49447 .35389 L .49818 .35916 L p .401 .279 .598 r
F P
0 g
s
.49445 .36471 m .49818 .35916 L .49447 .35389 L p .418 .279 .583 r
F P
0 g
s
.6276 .11936 m .64633 .11275 L .6402 .11113 L p .321 0 0 r
F P
0 g
s
.6402 .11113 m .62045 .11738 L .6276 .11936 L p .321 0 0 r
F P
0 g
s
.38555 .3644 m .36062 .35426 L .36233 .3604 L p .719 .226 .07 r
F P
0 g
s
.36233 .3604 m .38721 .36953 L .38555 .3644 L p .719 .226 .07 r
F P
0 g
s
.63924 .50011 m .65843 .5115 L .66378 .51036 L p .698 .181 0 r
F P
0 g
s
.69221 .52741 m .66378 .51036 L .65843 .5115 L p .726 .22 .028 r
F P
0 g
s
.71054 .12008 m .71356 .1192 L .70898 .1168 L p .667 .134 0 r
F P
0 g
s
.70898 .1168 m .70417 .11673 L .71054 .12008 L p .667 .134 0 r
F P
0 g
s
.06434 .47296 m .07475 .44629 L .07604 .43857 L p 0 0 .038 r
F P
0 g
s
.07475 .44629 m .06434 .47296 L .06373 .47832 L p 0 0 .207 r
F P
0 g
s
.57598 .44327 m .57694 .44768 L .58236 .44678 L p .714 .647 .781 r
F P
0 g
s
.58236 .44678 m .58196 .44226 L .57598 .44327 L p .714 .647 .781 r
F P
0 g
s
.72731 .12738 m .72971 .13149 L .73516 .13519 L p .775 .268 0 r
F P
0 g
s
.72971 .13149 m .72731 .12738 L .72293 .12461 L p .769 .266 .003 r
F P
0 g
s
.58764 .47588 m .58611 .47042 L .581 .4712 L p .706 .5 .608 r
F P
0 g
s
.58611 .47042 m .58764 .47588 L .593 .47508 L p .742 .523 .597 r
F P
0 g
s
.56049 .43799 m .56304 .4419 L .56856 .44025 L p .641 .624 .817 r
F P
0 g
s
.57028 .44449 m .56856 .44025 L .56304 .4419 L p .643 .611 .803 r
F P
0 g
s
.1148 .60502 m .07786 .56376 L .07975 .57048 L p 0 .234 .751 r
F P
0 g
s
.07975 .57048 m .11819 .61674 L .1148 .60502 L p 0 .234 .751 r
F P
0 g
s
.57586 .47201 m .57622 .47763 L .58196 .47674 L p .669 .474 .612 r
F P
0 g
s
.58196 .47674 m .581 .4712 L .57586 .47201 L p .669 .474 .612 r
F P
0 g
s
.45198 .38968 m .4437 .38987 L .44598 .39537 L p .729 .436 .483 r
F P
0 g
s
.44598 .39537 m .4541 .39469 L .45198 .38968 L p .729 .436 .483 r
F P
0 g
s
.57694 .44768 m .57598 .44327 L .57028 .44449 L p .681 .621 .782 r
F P
0 g
s
.77101 .2057 m .76676 .18498 L .76212 .18029 L p .982 .694 .338 r
F P
0 g
s
.75655 .16386 m .76212 .18029 L .76676 .18498 L p .933 .574 .158 r
F P
0 g
s
.67018 .11223 m .68296 .11107 L .67746 .10903 L p .484 0 0 r
F P
0 g
s
.67746 .10903 m .66315 .1096 L .67018 .11223 L p .484 0 0 r
F P
0 g
s
.49678 .41586 m .49123 .41742 L .49291 .42284 L p .725 .684 .809 r
F P
0 g
s
.49291 .42284 m .49829 .42138 L .49678 .41586 L p .725 .684 .809 r
F P
0 g
s
.48749 .42485 m .49291 .42284 L .49123 .41742 L p .747 .691 .798 r
F P
0 g
s
.49049 .36969 m .48627 .37415 L .48913 .37962 L p .544 .388 .62 r
F P
0 g
s
.48425 .38318 m .48913 .37962 L .48627 .37415 L p .566 .392 .604 r
F P
0 g
s
.4667 .44634 m .46034 .45387 L .4627 .45967 L p .907 .839 .767 r
F P
0 g
s
.45603 .47057 m .4627 .45967 L .46034 .45387 L p .924 .841 .743 r
F P
0 g
s
.68978 .11407 m .69831 .11388 L .6932 .11165 L p .571 .032 0 r
F P
0 g
s
.6932 .11165 m .68296 .11107 L .68978 .11407 L p .571 .032 0 r
F P
0 g
s
.50238 .41474 m .49678 .41586 L .49829 .42138 L p .705 .677 .82 r
F P
0 g
s
.49829 .42138 m .50367 .42044 L .50238 .41474 L p .705 .677 .82 r
F P
0 g
s
.73972 .13855 m .7453 .14718 L .74991 .15102 L p .821 .35 0 r
F P
0 g
s
.7453 .14718 m .73972 .13855 L .73516 .13519 L p .853 .397 .088 r
F P
0 g
s
.75655 .16386 m .74991 .15102 L .7453 .14718 L p .908 .5 .161 r
F P
0 g
s
.49123 .41742 m .48564 .41942 L .48749 .42485 L p .747 .691 .798 r
F P
0 g
s
.48198 .42747 m .48749 .42485 L .48564 .41942 L p .769 .698 .785 r
F P
0 g
s
.581 .4712 m .58196 .47674 L .58764 .47588 L p .706 .5 .608 r
F P
0 g
s
.617 .41228 m .61237 .41747 L .61903 .41862 L p .786 .856 .903 r
F P
0 g
s
.61903 .41862 m .62432 .41391 L .617 .41228 L p .786 .856 .903 r
F P
0 g
s
.54482 .43036 m .5489 .43339 L .55377 .4302 L p .607 .633 .852 r
F P
0 g
s
.55744 .43409 m .55377 .4302 L .5489 .43339 L p .604 .627 .847 r
F P
0 g
s
.47633 .43078 m .47044 .43492 L .4726 .44045 L p .834 .764 .786 r
F P
0 g
s
.4667 .44634 m .4726 .44045 L .47044 .43492 L p .857 .771 .766 r
F P
0 g
s
.58893 .43207 m .58831 .43689 L .59453 .43649 L p .767 .736 .824 r
F P
0 g
s
.59453 .43649 m .59608 .4318 L .58893 .43207 L p .767 .736 .824 r
F P
0 g
s
.50808 .41408 m .50238 .41474 L .50367 .42044 L p .686 .67 .829 r
F P
0 g
s
.50367 .42044 m .50906 .41999 L .50808 .41408 L p .686 .67 .829 r
F P
0 g
s
.56856 .44025 m .57028 .44449 L .57598 .44327 L p .678 .635 .799 r
F P
0 g
s
.58159 .43764 m .58196 .44226 L .58789 .44153 L p .742 .69 .801 r
F P
0 g
s
.58789 .44153 m .58831 .43689 L .58159 .43764 L p .742 .69 .801 r
F P
0 g
s
.59587 .48091 m .593 .47508 L .58764 .47588 L p .731 .482 .552 r
F P
0 g
s
.593 .47508 m .59587 .48091 L .60142 .48008 L p .765 .496 .527 r
F P
0 g
s
.56846 .8886 m .64642 .90198 L .65348 .90017 L p .33 .742 .979 r
F P
0 g
s
.54291 .50508 m .53254 .51818 L .54094 .51682 L p .361 .067 .324 r
F P
0 g
s
.54094 .51682 m .54931 .50407 L .54291 .50508 L p .361 .067 .324 r
F P
0 g
s
.07471 .5417 m .06378 .52125 L .06444 .52717 L p 0 0 .548 r
F P
0 g
s
.06444 .52717 m .07616 .55397 L .07471 .5417 L p 0 0 .548 r
F P
0 g
s
.51394 .41391 m .50808 .41408 L .50906 .41999 L p .668 .664 .837 r
F P
0 g
s
.50906 .41999 m .5145 .42005 L .51394 .41391 L p .668 .664 .837 r
F P
0 g
s
.57068 .4785 m .56996 .48489 L .57642 .48388 L p .619 .404 .568 r
F P
0 g
s
.57642 .48388 m .57622 .47763 L .57068 .4785 L p .619 .404 .568 r
F P
0 g
s
.66007 .39404 m .67073 .38674 L .66417 .38319 L p .787 .925 .927 r
F P
0 g
s
.66417 .38319 m .65385 .39104 L .66007 .39404 L p .787 .925 .927 r
F P
0 g
s
.60142 .48008 m .60651 .48639 L .61207 .48553 L p .779 .444 .42 r
F P
0 g
s
.62057 .49258 m .61207 .48553 L .60651 .48639 L p .755 .389 .361 r
F P
0 g
s
.50721 .31424 m .50978 .30305 L .50438 .29891 L p .181 .112 .537 r
F P
0 g
s
.5067 .28617 m .50438 .29891 L .50978 .30305 L p .187 .115 .537 r
F P
0 g
s
.48564 .41942 m .47995 .4219 L .48198 .42747 L p .769 .698 .785 r
F P
0 g
s
.47633 .43078 m .48198 .42747 L .47995 .4219 L p .791 .705 .77 r
F P
0 g
s
.71711 .12376 m .71827 .12184 L .71356 .1192 L p .715 .199 0 r
F P
0 g
s
.71356 .1192 m .71054 .12008 L .71711 .12376 L p .715 .199 0 r
F P
0 g
s
.60651 .48639 m .60142 .48008 L .59587 .48091 L p .749 .447 .473 r
F P
0 g
s
.72293 .12461 m .7236 .12763 L .72971 .13149 L p .769 .266 .003 r
F P
0 g
s
.7236 .12763 m .72293 .12461 L .71827 .12184 L p .748 .243 .015 r
F P
0 g
s
.47911 .38634 m .47364 .38911 L .47603 .39459 L p .654 .472 .625 r
F P
0 g
s
.47364 .38911 m .46774 .39146 L .47007 .39692 L p .677 .478 .609 r
F P
0 g
s
.47007 .39692 m .47603 .39459 L .47364 .38911 L p .677 .478 .609 r
F P
0 g
s
.54036 .42761 m .54482 .43036 L .54942 .42638 L p .609 .637 .853 r
F P
0 g
s
.55377 .4302 m .54942 .42638 L .54482 .43036 L p .607 .633 .852 r
F P
0 g
s
.55744 .43409 m .56049 .43799 L .56645 .43593 L p .64 .634 .828 r
F P
0 g
s
.56856 .44025 m .56645 .43593 L .56049 .43799 L p .641 .624 .817 r
F P
0 g
s
.60049 .42175 m .59804 .42691 L .60499 .42722 L p .779 .793 .864 r
F P
0 g
s
.60499 .42722 m .60838 .42244 L .60049 .42175 L p .779 .793 .864 r
F P
0 g
s
.57598 .44327 m .57485 .43878 L .56856 .44025 L p .678 .635 .799 r
F P
0 g
s
.57485 .43878 m .57598 .44327 L .58196 .44226 L p .71 .66 .798 r
F P
0 g
s
.52001 .4143 m .51394 .41391 L .5145 .42005 L p .652 .659 .843 r
F P
0 g
s
.5145 .42005 m .51995 .42061 L .52001 .4143 L p .652 .659 .843 r
F P
0 g
s
.58196 .44226 m .58159 .43764 L .57485 .43878 L p .71 .66 .798 r
F P
0 g
s
.46774 .39146 m .46127 .39334 L .46365 .39895 L p .701 .485 .592 r
F P
0 g
s
.46365 .39895 m .47007 .39692 L .46774 .39146 L p .701 .485 .592 r
F P
0 g
s
.74277 .85435 m .73068 .87241 L .73541 .86919 L p .76 .996 .837 r
F P
0 g
s
.73541 .86919 m .75349 .8472 L .74277 .85435 L p .76 .996 .837 r
F P
0 g
s
.50001 .34028 m .49736 .34738 L .50169 .35301 L p .387 .281 .61 r
F P
0 g
s
.49818 .35916 m .50169 .35301 L .49736 .34738 L p .401 .279 .598 r
F P
0 g
s
.48425 .38318 m .47911 .38634 L .48165 .39202 L p .632 .466 .64 r
F P
0 g
s
.47603 .39459 m .48165 .39202 L .47911 .38634 L p .654 .472 .625 r
F P
0 g
s
.49445 .36471 m .49049 .36969 L .49381 .37565 L p .525 .387 .635 r
F P
0 g
s
.48913 .37962 m .49381 .37565 L .49049 .36969 L p .544 .388 .62 r
F P
0 g
s
.71827 .12184 m .71711 .12376 L .7236 .12763 L p .748 .243 .015 r
F P
0 g
s
.564 .48583 m .56135 .49344 L .5686 .49229 L p .557 .318 .509 r
F P
0 g
s
.5686 .49229 m .56996 .48489 L .564 .48583 L p .557 .318 .509 r
F P
0 g
s
.42039 .38131 m .40586 .3765 L .40829 .38306 L p .772 .371 .293 r
F P
0 g
s
.40829 .38306 m .42254 .38684 L .42039 .38131 L p .772 .371 .293 r
F P
0 g
s
.52627 .41535 m .52001 .4143 L .51995 .42061 L p .639 .654 .849 r
F P
0 g
s
.51995 .42061 m .52536 .42169 L .52627 .41535 L p .639 .654 .849 r
F P
0 g
s
.55504 .49444 m .54931 .50407 L .5573 .50279 L p .475 .207 .428 r
F P
0 g
s
.5573 .50279 m .56135 .49344 L .55504 .49444 L p .475 .207 .428 r
F P
0 g
s
.53563 .42523 m .54036 .42761 L .54434 .42278 L p .613 .638 .852 r
F P
0 g
s
.54942 .42638 m .54434 .42278 L .54036 .42761 L p .609 .637 .853 r
F P
0 g
s
.4437 .38987 m .43406 .38901 L .43659 .39524 L p .756 .445 .458 r
F P
0 g
s
.43659 .39524 m .44598 .39537 L .4437 .38987 L p .756 .445 .458 r
F P
0 g
s
.56645 .43593 m .56856 .44025 L .57485 .43878 L p .674 .645 .813 r
F P
0 g
s
.58968 .48184 m .58764 .47588 L .58196 .47674 L p .697 .463 .566 r
F P
0 g
s
.58764 .47588 m .58968 .48184 L .59587 .48091 L p .731 .482 .552 r
F P
0 g
s
.70229 .88831 m .67512 .89146 L .66323 .89659 L p .514 .908 .928 r
F P
0 g
s
.67512 .89146 m .70229 .88831 L .70774 .88566 L p .606 .939 .947 r
F P
0 g
s
.57622 .47763 m .57642 .48388 L .5831 .48284 L p .66 .437 .571 r
F P
0 g
s
.5831 .48284 m .58196 .47674 L .57622 .47763 L p .66 .437 .571 r
F P
0 g
s
.46127 .39334 m .4541 .39469 L .4566 .40065 L p .726 .493 .573 r
F P
0 g
s
.4566 .40065 m .46365 .39895 L .46127 .39334 L p .726 .493 .573 r
F P
0 g
s
.53259 .41714 m .52627 .41535 L .52536 .42169 L p .628 .65 .853 r
F P
0 g
s
.52536 .42169 m .53064 .42325 L .53259 .41714 L p .628 .65 .853 r
F P
0 g
s
.47995 .4219 m .47408 .42491 L .47633 .43078 L p .791 .705 .77 r
F P
0 g
s
.47044 .43492 m .47633 .43078 L .47408 .42491 L p .813 .712 .754 r
F P
0 g
s
.54434 .42278 m .53868 .41965 L .53563 .42523 L p .613 .638 .852 r
F P
0 g
s
.53064 .42325 m .53563 .42523 L .53868 .41965 L p .619 .647 .855 r
F P
0 g
s
.48913 .37962 m .48425 .38318 L .48703 .38921 L p .612 .462 .654 r
F P
0 g
s
.48165 .39202 m .48703 .38921 L .48425 .38318 L p .632 .466 .64 r
F P
0 g
s
.53868 .41965 m .53259 .41714 L .53064 .42325 L p .619 .647 .855 r
F P
0 g
s
.58119 .43281 m .58159 .43764 L .58831 .43689 L p .735 .699 .817 r
F P
0 g
s
.58831 .43689 m .58893 .43207 L .58119 .43281 L p .735 .699 .817 r
F P
0 g
s
.50979 .53846 m .48694 .56938 L .49791 .56757 L p .213 0 .255 r
F P
0 g
s
.49791 .56757 m .51774 .5372 L .50979 .53846 L p .213 0 .255 r
F P
0 g
s
.62228 .40685 m .617 .41228 L .62432 .41391 L p .778 .854 .907 r
F P
0 g
s
.62432 .41391 m .63023 .40903 L .62228 .40685 L p .778 .854 .907 r
F P
0 g
s
.58196 .47674 m .5831 .48284 L .58968 .48184 L p .697 .463 .566 r
F P
0 g
s
.58979 .42695 m .58893 .43207 L .59608 .4318 L p .758 .742 .838 r
F P
0 g
s
.59608 .4318 m .59804 .42691 L .58979 .42695 L p .758 .742 .838 r
F P
0 g
s
.50978 .30305 m .51268 .29032 L .5067 .28617 L p .187 .115 .537 r
F P
0 g
s
.50957 .2718 m .5067 .28617 L .51268 .29032 L p .195 .115 .532 r
F P
0 g
s
.49486 .40958 m .48919 .41133 L .49123 .41742 L p .714 .642 .776 r
F P
0 g
s
.49123 .41742 m .49678 .41586 L .49486 .40958 L p .714 .642 .776 r
F P
0 g
s
.48564 .41942 m .49123 .41742 L .48919 .41133 L p .733 .648 .765 r
F P
0 g
s
.44806 .48494 m .4375 .50412 L .44064 .51173 L p .962 .909 .717 r
F P
0 g
s
.42561 .53953 m .44064 .51173 L .4375 .50412 L p .952 .912 .74 r
F P
0 g
s
.47044 .43492 m .46421 .4401 L .4667 .44634 L p .857 .771 .766 r
F P
0 g
s
.46034 .45387 m .4667 .44634 L .46421 .4401 L p .878 .775 .745 r
F P
0 g
s
.67073 .38674 m .68266 .37811 L .67578 .37397 L p .799 .924 .92 r
F P
0 g
s
.67578 .37397 m .66417 .38319 L .67073 .38674 L p .799 .924 .92 r
F P
0 g
s
.55377 .4302 m .55744 .43409 L .56384 .43145 L p .638 .639 .835 r
F P
0 g
s
.56645 .43593 m .56384 .43145 L .55744 .43409 L p .64 .634 .828 r
F P
0 g
s
.48919 .41133 m .48349 .4134 L .48564 .41942 L p .733 .648 .765 r
F P
0 g
s
.47995 .4219 m .48564 .41942 L .48349 .4134 L p .753 .655 .752 r
F P
0 g
s
.50059 .40813 m .49486 .40958 L .49678 .41586 L p .696 .637 .786 r
F P
0 g
s
.49678 .41586 m .50238 .41474 L .50059 .40813 L p .696 .637 .786 r
F P
0 g
s
.60799 .12992 m .6276 .11936 L .62045 .11738 L p .321 0 .075 r
F P
0 g
s
.62045 .11738 m .60001 .12758 L .60799 .12992 L p .321 0 .075 r
F P
0 g
s
.57485 .43878 m .57349 .43412 L .56645 .43593 L p .674 .645 .813 r
F P
0 g
s
.57349 .43412 m .57485 .43878 L .58159 .43764 L p .705 .67 .813 r
F P
0 g
s
.58159 .43764 m .58119 .43281 L .57349 .43412 L p .705 .67 .813 r
F P
0 g
s
.49818 .35916 m .49445 .36471 L .49837 .37123 L p .509 .386 .648 r
F P
0 g
s
.49381 .37565 m .49837 .37123 L .49445 .36471 L p .525 .387 .635 r
F P
0 g
s
.50244 .33259 m .50001 .34028 L .50502 .34623 L p .378 .283 .62 r
F P
0 g
s
.50169 .35301 m .50502 .34623 L .50001 .34028 L p .387 .281 .61 r
F P
0 g
s
.5065 .40703 m .50059 .40813 L .50238 .41474 L p .68 .633 .796 r
F P
0 g
s
.50238 .41474 m .50808 .41408 L .5065 .40703 L p .68 .633 .796 r
F P
0 g
s
.77195 .2291 m .77101 .2057 L .76549 .2002 L p .997 .779 .485 r
F P
0 g
s
.76212 .18029 m .76549 .2002 L .77101 .2057 L p .982 .694 .338 r
F P
0 g
s
.48349 .4134 m .47765 .41577 L .47995 .4219 L p .753 .655 .752 r
F P
0 g
s
.47408 .42491 m .47995 .4219 L .47765 .41577 L p .774 .661 .739 r
F P
0 g
s
.48165 .39202 m .47603 .39459 L .47857 .40067 L p .681 .524 .667 r
F P
0 g
s
.47603 .39459 m .47007 .39692 L .47259 .40298 L p .701 .53 .653 r
F P
0 g
s
.47259 .40298 m .47857 .40067 L .47603 .39459 L p .701 .53 .653 r
F P
0 g
s
.49381 .37565 m .48913 .37962 L .49227 .38615 L p .594 .46 .668 r
F P
0 g
s
.48703 .38921 m .49227 .38615 L .48913 .37962 L p .612 .462 .654 r
F P
0 g
s
.46034 .45387 m .45318 .46359 L .45603 .47057 L p .924 .841 .743 r
F P
0 g
s
.44806 .48494 m .45603 .47057 L .45318 .46359 L p .934 .84 .727 r
F P
0 g
s
.59989 .48741 m .59587 .48091 L .58968 .48184 L p .717 .439 .504 r
F P
0 g
s
.59587 .48091 m .59989 .48741 L .60651 .48639 L p .749 .447 .473 r
F P
0 g
s
.06373 .47832 m .0737 .45637 L .07475 .44629 L p 0 0 .207 r
F P
0 g
s
.0737 .45637 m .06373 .47832 L .06326 .48468 L p 0 0 .332 r
F P
0 g
s
.36062 .35426 m .3266 .3429 L .32813 .35019 L p .696 .207 .082 r
F P
0 g
s
.32813 .35019 m .36233 .3604 L .36062 .35426 L p .696 .207 .082 r
F P
0 g
s
.56384 .43145 m .56645 .43593 L .57349 .43412 L p .67 .653 .824 r
F P
0 g
s
.4541 .39469 m .44598 .39537 L .4487 .40193 L p .751 .501 .553 r
F P
0 g
s
.4487 .40193 m .4566 .40065 L .4541 .39469 L p .751 .501 .553 r
F P
0 g
s
.60349 .41626 m .60049 .42175 L .60838 .42244 L p .769 .793 .873 r
F P
0 g
s
.60838 .42244 m .61237 .41747 L .60349 .41626 L p .769 .793 .873 r
F P
0 g
s
.48703 .38921 m .48165 .39202 L .48428 .3983 L p .661 .519 .68 r
F P
0 g
s
.47857 .40067 m .48428 .3983 L .48165 .39202 L p .681 .524 .667 r
F P
0 g
s
.47007 .39692 m .46365 .39895 L .46624 .4052 L p .723 .536 .638 r
F P
0 g
s
.46624 .4052 m .47259 .40298 L .47007 .39692 L p .723 .536 .638 r
F P
0 g
s
.69762 .11789 m .70417 .11673 L .69831 .11388 L p .657 .159 .054 r
F P
0 g
s
.69831 .11388 m .68978 .11407 L .69762 .11789 L p .657 .159 .054 r
F P
0 g
s
.73516 .13519 m .73919 .14268 L .7453 .14718 L p .853 .397 .088 r
F P
0 g
s
.73919 .14268 m .73516 .13519 L .72971 .13149 L p .847 .405 .168 r
F P
0 g
s
.73038 .86204 m .72531 .87582 L .73068 .87241 L p .762 .992 .882 r
F P
0 g
s
.73068 .87241 m .74277 .85435 L .73038 .86204 L p .762 .992 .882 r
F P
0 g
s
.56996 .48489 m .5686 .49229 L .57645 .49106 L p .608 .365 .524 r
F P
0 g
s
.57645 .49106 m .57642 .48388 L .56996 .48489 L p .608 .365 .524 r
F P
0 g
s
.47408 .42491 m .46792 .42854 L .47044 .43492 L p .813 .712 .754 r
F P
0 g
s
.46421 .4401 m .47044 .43492 L .46792 .42854 L p .834 .718 .737 r
F P
0 g
s
.5127 .40633 m .5065 .40703 L .50808 .41408 L p .665 .629 .804 r
F P
0 g
s
.50808 .41408 m .51394 .41391 L .5127 .40633 L p .665 .629 .804 r
F P
0 g
s
.54942 .42638 m .55377 .4302 L .56054 .42673 L p .636 .641 .838 r
F P
0 g
s
.56384 .43145 m .56054 .42673 L .55377 .4302 L p .638 .639 .835 r
F P
0 g
s
.62057 .49258 m .63271 .50127 L .63924 .50011 L p .741 .3 .205 r
F P
0 g
s
.65843 .5115 m .63924 .50011 L .63271 .50127 L p .733 .286 .19 r
F P
0 g
s
.51268 .29032 m .51613 .27593 L .50957 .2718 L p .195 .115 .532 r
F P
0 g
s
.51333 .25573 m .50957 .2718 L .51613 .27593 L p .206 .112 .521 r
F P
0 g
s
.49252 .40279 m .48684 .40485 L .48919 .41133 L p .7 .603 .745 r
F P
0 g
s
.48919 .41133 m .49486 .40958 L .49252 .40279 L p .7 .603 .745 r
F P
0 g
s
.48349 .4134 m .48919 .41133 L .48684 .40485 L p .718 .609 .733 r
F P
0 g
s
.48684 .40485 m .48109 .40705 L .48349 .4134 L p .718 .609 .733 r
F P
0 g
s
.47765 .41577 m .48349 .4134 L .48109 .40705 L p .737 .614 .721 r
F P
0 g
s
.70774 .88566 m .68849 .88506 L .67512 .89146 L p .606 .939 .947 r
F P
0 g
s
.68849 .88506 m .70774 .88566 L .71358 .8826 L p .67 .957 .945 r
F P
0 g
s
.68266 .37811 m .69577 .36776 L .68858 .36302 L p .815 .923 .908 r
F P
0 g
s
.68858 .36302 m .67578 .37397 L .68266 .37811 L p .815 .923 .908 r
F P
0 g
s
.07359 .52763 m .06329 .51441 L .06378 .52125 L p 0 .037 .567 r
F P
0 g
s
.06378 .52125 m .07471 .5417 L .07359 .52763 L p 0 .037 .567 r
F P
0 g
s
.49227 .38615 m .48703 .38921 L .48986 .39587 L p .643 .516 .693 r
F P
0 g
s
.48428 .3983 m .48986 .39587 L .48703 .38921 L p .661 .519 .68 r
F P
0 g
s
.43406 .38901 m .42254 .38684 L .4254 .3941 L p .779 .453 .435 r
F P
0 g
s
.4254 .3941 m .43659 .39524 L .43406 .38901 L p .779 .453 .435 r
F P
0 g
s
.63024 .40903 m .63696 .40376 L .62842 .40096 L p .778 .853 .907 r
F P
0 g
s
.62842 .40096 m .62229 .40685 L .63024 .40903 L p .778 .853 .907 r
F P
0 g
s
.58075 .42763 m .58119 .43281 L .58893 .43207 L p .727 .705 .829 r
F P
0 g
s
.58893 .43207 m .58979 .42695 L .58075 .42763 L p .727 .705 .829 r
F P
0 g
s
.46365 .39895 m .4566 .40065 L .45936 .40732 L p .745 .543 .621 r
F P
0 g
s
.45936 .40732 m .46624 .4052 L .46365 .39895 L p .745 .543 .621 r
F P
0 g
s
.47765 .41577 m .47158 .41849 L .47408 .42491 L p .774 .661 .739 r
F P
0 g
s
.46792 .42854 m .47408 .42491 L .47158 .41849 L p .794 .668 .724 r
F P
0 g
s
.48428 .3983 m .47857 .40067 L .48109 .40705 L p .701 .568 .702 r
F P
0 g
s
.47857 .40067 m .47259 .40298 L .47516 .40936 L p .721 .574 .689 r
F P
0 g
s
.47516 .40936 m .48109 .40705 L .47857 .40067 L p .721 .574 .689 r
F P
0 g
s
.49825 .40087 m .49252 .40279 L .49486 .40958 L p .683 .599 .756 r
F P
0 g
s
.49486 .40958 m .50059 .40813 L .49825 .40087 L p .683 .599 .756 r
F P
0 g
s
.61374 .4937 m .60651 .48639 L .59989 .48741 L p .73 .401 .423 r
F P
0 g
s
.60651 .48639 m .61374 .4937 L .62057 .49258 L p .755 .389 .361 r
F P
0 g
s
.51937 .40615 m .5127 .40633 L .51394 .41391 L p .653 .628 .812 r
F P
0 g
s
.51394 .41391 m .52001 .4143 L .51937 .40615 L p .653 .628 .812 r
F P
0 g
s
.59093 .42141 m .58979 .42695 L .59804 .42691 L p .748 .744 .848 r
F P
0 g
s
.59804 .42691 m .60049 .42175 L .59093 .42141 L p .748 .744 .848 r
F P
0 g
s
.48986 .39587 m .48428 .3983 L .48684 .40485 L p .683 .563 .714 r
F P
0 g
s
.48109 .40705 m .48684 .40485 L .48428 .3983 L p .701 .568 .702 r
F P
0 g
s
.65494 .11604 m .67018 .11223 L .66315 .1096 L p .505 .034 .071 r
F P
0 g
s
.66315 .1096 m .64633 .11275 L .65494 .11604 L p .505 .034 .071 r
F P
0 g
s
.48109 .40705 m .47516 .40936 L .47765 .41577 L p .737 .614 .721 r
F P
0 g
s
.47158 .41849 m .47765 .41577 L .47516 .40936 L p .757 .62 .708 r
F P
0 g
s
.65843 .5115 m .68557 .52913 L .69221 .52741 L p .726 .22 .028 r
F P
0 g
s
.73002 .55675 m .69221 .52741 L .68557 .52913 L p .792 .321 .114 r
F P
0 g
s
.57349 .43412 m .57179 .42916 L .56384 .43145 L p .67 .653 .824 r
F P
0 g
s
.57179 .42916 m .57349 .43412 L .58119 .43281 L p .699 .676 .824 r
F P
0 g
s
.59245 .48856 m .58968 .48184 L .5831 .48284 L p .684 .423 .521 r
F P
0 g
s
.58968 .48184 m .59245 .48856 L .59989 .48741 L p .717 .439 .504 r
F P
0 g
s
.47259 .40298 m .46624 .4052 L .46893 .41181 L p .741 .58 .675 r
F P
0 g
s
.46893 .41181 m .47516 .40936 L .47259 .40298 L p .741 .58 .675 r
F P
0 g
s
.48684 .40485 m .49252 .40279 L .48986 .39587 L p .683 .563 .714 r
F P
0 g
s
.49837 .37123 m .49381 .37565 L .49746 .38282 L p .578 .458 .68 r
F P
0 g
s
.49227 .38615 m .49746 .38282 L .49381 .37565 L p .594 .46 .668 r
F P
0 g
s
.50502 .34623 m .50817 .3388 L .50244 .33259 L p .378 .283 .62 r
F P
0 g
s
.5048 .32404 m .50244 .33259 L .50818 .33879 L p .364 .281 .627 r
F P
0 g
s
.50169 .35301 m .49818 .35916 L .50283 .36626 L p .496 .386 .659 r
F P
0 g
s
.49837 .37123 m .50283 .36626 L .49818 .35916 L p .509 .386 .648 r
F P
0 g
s
.76212 .18029 m .75655 .16386 L .7506 .15894 L p .95 .611 .338 r
F P
0 g
s
.7453 .14718 m .7506 .15894 L .75655 .16386 L p .908 .5 .161 r
F P
0 g
s
.57642 .48388 m .57645 .49106 L .58453 .4898 L p .649 .399 .528 r
F P
0 g
s
.58453 .4898 m .5831 .48284 L .57642 .48388 L p .649 .399 .528 r
F P
0 g
s
.63271 .50127 m .62057 .49258 L .61374 .4937 L p .735 .348 .318 r
F P
0 g
s
.54434 .42278 m .54942 .42638 L .55626 .42171 L p .635 .638 .836 r
F P
0 g
s
.56054 .42673 m .55626 .42171 L .54942 .42638 L p .636 .641 .838 r
F P
0 g
s
.58119 .43281 m .58075 .42763 L .57179 .42916 L p .699 .676 .824 r
F P
0 g
s
.71681 .86997 m .71952 .87926 L .72531 .87582 L p .745 .982 .912 r
F P
0 g
s
.72531 .87582 m .73038 .86204 L .71681 .86997 L p .745 .982 .912 r
F P
0 g
s
.40586 .3765 m .38721 .36953 L .38994 .37743 L p .781 .374 .281 r
F P
0 g
s
.38994 .37743 m .40829 .38306 L .40586 .3765 L p .781 .374 .281 r
F P
0 g
s
.50415 .39911 m .49825 .40087 L .50059 .40813 L p .668 .596 .765 r
F P
0 g
s
.50059 .40813 m .5065 .40703 L .50415 .39911 L p .668 .596 .765 r
F P
0 g
s
.56054 .42673 m .56384 .43145 L .57179 .42916 L p .666 .656 .83 r
F P
0 g
s
.47516 .40936 m .46893 .41181 L .47158 .41849 L p .757 .62 .708 r
F P
0 g
s
.58877 .14437 m .60799 .12992 L .60001 .12758 L p .314 0 .186 r
F P
0 g
s
.60001 .12758 m .58021 .14166 L .58877 .14437 L p .314 0 .186 r
F P
0 g
s
.56135 .49344 m .5573 .50279 L .56646 .50132 L p .544 .28 .465 r
F P
0 g
s
.56646 .50132 m .5686 .49229 L .56135 .49344 L p .544 .28 .465 r
F P
0 g
s
.48986 .39587 m .4954 .39338 L .49227 .38615 L p .643 .516 .693 r
F P
0 g
s
.4954 .39338 m .48986 .39587 L .49252 .40279 L p .666 .56 .725 r
F P
0 g
s
.5831 .48284 m .58453 .4898 L .59245 .48856 L p .684 .423 .521 r
F P
0 g
s
.49252 .40279 m .49825 .40087 L .4954 .39338 L p .666 .56 .725 r
F P
0 g
s
.71358 .8826 m .70262 .87777 L .68849 .88506 L p .67 .957 .945 r
F P
0 g
s
.70262 .87777 m .71358 .8826 L .71952 .87926 L p .714 .97 .932 r
F P
0 g
s
.52668 .40669 m .51937 .40615 L .52001 .4143 L p .643 .628 .819 r
F P
0 g
s
.52001 .4143 m .52627 .41535 L .52668 .40669 L p .643 .628 .819 r
F P
0 g
s
.49746 .38282 m .49227 .38615 L .4954 .39338 L p .628 .513 .704 r
F P
0 g
s
.46421 .4401 m .45741 .44662 L .46034 .45387 L p .878 .775 .745 r
F P
0 g
s
.45318 .46359 m .46034 .45387 L .45741 .44662 L p .894 .778 .726 r
F P
0 g
s
.51613 .27593 m .52049 .2598 L .51333 .25573 L p .206 .112 .521 r
F P
0 g
s
.51844 .238 m .51333 .25573 L .52049 .2598 L p .22 .106 .504 r
F P
0 g
s
.67892 .1161 m .68978 .11407 L .68296 .11107 L p .604 .129 .099 r
F P
0 g
s
.68296 .11107 m .67018 .11223 L .67892 .1161 L p .604 .129 .099 r
F P
0 g
s
.44598 .39537 m .43659 .39524 L .43963 .4027 L p .775 .508 .533 r
F P
0 g
s
.43963 .4027 m .4487 .40193 L .44598 .39537 L p .775 .508 .533 r
F P
0 g
s
.7506 .15894 m .7453 .14718 L .73919 .14268 L p .903 .516 .278 r
F P
0 g
s
.71952 .87926 m .71681 .86997 L .70262 .87777 L p .714 .97 .932 r
F P
0 g
s
.46624 .4052 m .45936 .40732 L .46225 .41441 L p .762 .587 .66 r
F P
0 g
s
.46225 .41441 m .46893 .41181 L .46624 .4052 L p .762 .587 .66 r
F P
0 g
s
.46515 .42159 m .47158 .41849 L .46893 .41181 L p .778 .627 .693 r
F P
0 g
s
.47158 .41849 m .46515 .42159 L .46792 .42854 L p .794 .668 .724 r
F P
0 g
s
.15821 .35452 m .10688 .39184 L .10498 .39934 L p .153 0 .061 r
F P
0 g
s
.07604 .43857 m .10498 .39934 L .10688 .39184 L p 0 0 0 r
F P
0 g
s
.69577 .36776 m .70978 .35528 L .70234 .34995 L p .835 .922 .891 r
F P
0 g
s
.70234 .34995 m .68858 .36302 L .69577 .36776 L p .835 .922 .891 r
F P
0 g
s
.60714 .41041 m .60349 .41626 L .61237 .41747 L p .76 .791 .878 r
F P
0 g
s
.61237 .41747 m .617 .41228 L .60714 .41041 L p .76 .791 .878 r
F P
0 g
s
.7689 .25388 m .77195 .2291 L .76565 .22294 L p .989 .836 .598 r
F P
0 g
s
.76549 .2002 m .76565 .22294 L .77195 .2291 L p .997 .779 .485 r
F P
0 g
s
.53254 .51818 m .51774 .5372 L .5291 .53529 L p .363 .071 .327 r
F P
0 g
s
.5291 .53529 m .54094 .51682 L .53254 .51818 L p .363 .071 .327 r
F P
0 g
s
.06326 .48468 m .07294 .46852 L .0737 .45637 L p 0 0 .332 r
F P
0 g
s
.07294 .46852 m .06326 .48468 L .06298 .49178 L p 0 0 .422 r
F P
0 g
s
.4566 .40065 m .4487 .40193 L .45173 .4093 L p .768 .55 .604 r
F P
0 g
s
.45173 .4093 m .45936 .40732 L .4566 .40065 L p .768 .55 .604 r
F P
0 g
s
.53868 .41965 m .54434 .42278 L .55055 .41648 L p .633 .631 .831 r
F P
0 g
s
.55626 .42171 m .55055 .41648 L .54434 .42278 L p .635 .638 .836 r
F P
0 g
s
.70614 .12238 m .71054 .12008 L .70417 .11673 L p .715 .249 .14 r
F P
0 g
s
.70417 .11673 m .69762 .11789 L .70614 .12238 L p .715 .249 .14 r
F P
0 g
s
.53476 .40836 m .52668 .40669 L .52627 .41535 L p .637 .629 .826 r
F P
0 g
s
.52627 .41535 m .53259 .41714 L .53476 .40836 L p .637 .629 .826 r
F P
0 g
s
.72971 .13149 m .73187 .13772 L .73919 .14268 L p .847 .405 .168 r
F P
0 g
s
.73187 .13772 m .72971 .13149 L .7236 .12763 L p .825 .391 .206 r
F P
0 g
s
.51039 .39752 m .50415 .39911 L .5065 .40703 L p .655 .595 .775 r
F P
0 g
s
.5065 .40703 m .5127 .40633 L .51039 .39752 L p .655 .595 .775 r
F P
0 g
s
.46132 .43293 m .46792 .42854 L .46515 .42159 L p .815 .674 .708 r
F P
0 g
s
.46792 .42854 m .46132 .43293 L .46421 .4401 L p .834 .718 .737 r
F P
0 g
s
.45741 .44662 m .46421 .4401 L .46132 .43293 L p .854 .724 .719 r
F P
0 g
s
.46893 .41181 m .46225 .41441 L .46515 .42159 L p .778 .627 .693 r
F P
0 g
s
.54931 .50407 m .54094 .51682 L .55139 .5151 L p .465 .182 .398 r
F P
0 g
s
.55139 .5151 m .5573 .50279 L .54931 .50407 L p .465 .182 .398 r
F P
0 g
s
.50104 .39083 m .4954 .39338 L .49825 .40087 L p .651 .557 .736 r
F P
0 g
s
.49825 .40087 m .50415 .39911 L .50104 .39083 L p .651 .557 .736 r
F P
0 g
s
.63696 .40376 m .6448 .39783 L .63568 .39432 L p .775 .85 .907 r
F P
0 g
s
.63568 .39432 m .62842 .40096 L .63696 .40376 L p .775 .85 .907 r
F P
0 g
s
.4954 .39338 m .50104 .39083 L .49746 .38282 L p .628 .513 .704 r
F P
0 g
s
.55055 .41648 m .54315 .41168 L .53868 .41965 L p .633 .631 .831 r
F P
0 g
s
.53259 .41714 m .53868 .41965 L .54314 .41167 L p .633 .632 .831 r
F P
0 g
s
.54314 .41167 m .53476 .40836 L .53259 .41714 L p .633 .632 .831 r
F P
0 g
s
.07284 .51254 m .06298 .50698 L .06329 .51441 L p .007 .052 .558 r
F P
0 g
s
.06329 .51441 m .07359 .52763 L .07284 .51254 L p .007 .052 .558 r
F P
0 g
s
.10498 .39934 m .07604 .43857 L .07475 .44629 L p .047 0 .224 r
F P
0 g
s
.50283 .36626 m .49837 .37123 L .5027 .37917 L p .565 .458 .691 r
F P
0 g
s
.49746 .38282 m .5027 .37917 L .49837 .37123 L p .578 .458 .68 r
F P
0 g
s
.58025 .42189 m .58075 .42763 L .58979 .42695 L p .719 .707 .837 r
F P
0 g
s
.58979 .42695 m .59093 .42141 L .58025 .42189 L p .719 .707 .837 r
F P
0 g
s
.52049 .2598 m .52616 .24198 L .51844 .238 L p .22 .106 .504 r
F P
0 g
s
.52541 .21884 m .51844 .238 L .52616 .24198 L p .235 .096 .479 r
F P
0 g
s
.50818 .33879 m .51129 .33045 L .5048 .32404 L p .364 .281 .627 r
F P
0 g
s
.50721 .31424 m .5048 .32404 L .51129 .33045 L p .363 .284 .632 r
F P
0 g
s
.57179 .42916 m .56959 .42368 L .56054 .42673 L p .666 .656 .83 r
F P
0 g
s
.56959 .42368 m .57179 .42916 L .58075 .42763 L p .692 .678 .831 r
F P
0 g
s
.5027 .37917 m .49746 .38282 L .50104 .39083 L p .614 .512 .715 r
F P
0 g
s
.50502 .34623 m .50169 .35301 L .50722 .36068 L p .486 .388 .669 r
F P
0 g
s
.50283 .36626 m .50722 .36068 L .50169 .35301 L p .496 .386 .659 r
F P
0 g
s
.55626 .42171 m .56054 .42673 L .56959 .42368 L p .661 .654 .833 r
F P
0 g
s
.57113 .16202 m .58877 .14437 L .58021 .14166 L p .301 0 .275 r
F P
0 g
s
.58021 .14166 m .56228 .15896 L .57113 .16202 L p .301 0 .275 r
F P
0 g
s
.59251 .41532 m .59093 .42141 L .60049 .42175 L p .739 .743 .855 r
F P
0 g
s
.60049 .42175 m .60349 .41626 L .59251 .41532 L p .739 .743 .855 r
F P
0 g
s
.60556 .49502 m .59989 .48741 L .59245 .48856 L p .702 .398 .459 r
F P
0 g
s
.59989 .48741 m .60556 .49502 L .61374 .4937 L p .73 .401 .423 r
F P
0 g
s
.70978 .35528 m .72424 .34026 L .71662 .33438 L p .86 .92 .869 r
F P
0 g
s
.71662 .33438 m .70234 .34995 L .70978 .35528 L p .86 .92 .869 r
F P
0 g
s
.3266 .3429 m .28031 .33397 L .28123 .34235 L p .645 .165 .099 r
F P
0 g
s
.28123 .34235 m .32813 .35019 L .3266 .3429 L p .645 .165 .099 r
F P
0 g
s
.4375 .50412 m .42164 .52974 L .42561 .53953 L p .952 .912 .74 r
F P
0 g
s
.4001 .57557 m .42561 .53953 L .42164 .52974 L p .925 .913 .788 r
F P
0 g
s
.51723 .39615 m .51039 .39752 L .5127 .40633 L p .646 .595 .783 r
F P
0 g
s
.5127 .40633 m .51937 .40615 L .51723 .39615 L p .646 .595 .783 r
F P
0 g
s
.45936 .40732 m .45173 .4093 L .45494 .41716 L p .783 .593 .643 r
F P
0 g
s
.45494 .41716 m .46225 .41441 L .45936 .40732 L p .783 .593 .643 r
F P
0 g
s
.71495 .12733 m .71711 .12376 L .71054 .12008 L p .76 .313 .191 r
F P
0 g
s
.71054 .12008 m .70614 .12238 L .71495 .12733 L p .76 .313 .191 r
F P
0 g
s
.45318 .46359 m .44457 .47633 L .44806 .48494 L p .934 .84 .727 r
F P
0 g
s
.4375 .50412 m .44806 .48494 L .44457 .47633 L p .936 .84 .724 r
F P
0 g
s
.58075 .42763 m .58025 .42189 L .56959 .42368 L p .692 .678 .831 r
F P
0 g
s
.06298 .49178 m .07253 .4823 L .07294 .46852 L p 0 0 .422 r
F P
0 g
s
.07253 .4823 m .06298 .49178 L .06288 .49932 L p .022 0 .486 r
F P
0 g
s
.7236 .12763 m .72366 .13253 L .73187 .13772 L p .825 .391 .206 r
F P
0 g
s
.72366 .13253 m .7236 .12763 L .71711 .12376 L p .795 .36 .212 r
F P
0 g
s
.45819 .42516 m .46515 .42159 L .46225 .41441 L p .798 .633 .677 r
F P
0 g
s
.46515 .42159 m .45819 .42516 L .46132 .43293 L p .815 .674 .708 r
F P
0 g
s
.50692 .38816 m .50104 .39083 L .50415 .39911 L p .639 .557 .746 r
F P
0 g
s
.50415 .39911 m .51039 .39752 L .50692 .38816 L p .639 .557 .746 r
F P
0 g
s
.42254 .38684 m .40829 .38306 L .41156 .39172 L p .796 .459 .417 r
F P
0 g
s
.41156 .39172 m .4254 .3941 L .42254 .38684 L p .796 .459 .417 r
F P
0 g
s
.5686 .49229 m .56646 .50132 L .57633 .49973 L p .596 .329 .483 r
F P
0 g
s
.57633 .49973 m .57645 .49106 L .5686 .49229 L p .596 .329 .483 r
F P
0 g
s
.78367 .78484 m .76217 .84087 L .76856 .83558 L p .935 .967 .736 r
F P
0 g
s
.76856 .83558 m .79424 .77684 L .78367 .78484 L p .935 .967 .736 r
F P
0 g
s
.76182 .27854 m .7689 .25388 L .76195 .2473 L p .969 .872 .684 r
F P
0 g
s
.76565 .22294 m .76195 .2473 L .7689 .25388 L p .989 .836 .598 r
F P
0 g
s
.07249 .49719 m .06288 .49932 L .06298 .50698 L p .031 .038 .531 r
F P
0 g
s
.06298 .50698 m .07284 .51254 L .07249 .49719 L p .031 .038 .531 r
F P
0 g
s
.52616 .24198 m .53364 .22266 L .52541 .21884 L p .235 .096 .479 r
F P
0 g
s
.5348 .1987 m .52541 .21884 L .53364 .22266 L p .252 .081 .445 r
F P
0 g
s
.50104 .39083 m .50692 .38816 L .5027 .37917 L p .614 .512 .715 r
F P
0 g
s
.71711 .12376 m .71495 .12733 L .72366 .13253 L p .795 .36 .212 r
F P
0 g
s
.46225 .41441 m .45494 .41716 L .45819 .42516 L p .798 .633 .677 r
F P
0 g
s
.06288 .49932 m .07249 .49719 L .07253 .4823 L p .022 0 .486 r
F P
0 g
s
.61153 .40419 m .60714 .41041 L .617 .41228 L p .754 .788 .881 r
F P
0 g
s
.617 .41228 m .62228 .40685 L .61153 .40419 L p .754 .788 .881 r
F P
0 g
s
.4487 .40193 m .43963 .4027 L .44304 .41111 L p .789 .557 .586 r
F P
0 g
s
.44304 .41111 m .45173 .4093 L .4487 .40193 L p .789 .557 .586 r
F P
0 g
s
.5559 .18175 m .57113 .16202 L .56228 .15896 L p .286 .034 .346 r
F P
0 g
s
.56228 .15896 m .54704 .17838 L .5559 .18175 L p .286 .034 .346 r
F P
0 g
s
.72424 .34026 m .73842 .32241 L .73071 .31607 L p .887 .916 .839 r
F P
0 g
s
.73071 .31607 m .71662 .33438 L .72424 .34026 L p .887 .916 .839 r
F P
0 g
s
.43659 .39524 m .4254 .3941 L .42886 .40283 L p .795 .515 .513 r
F P
0 g
s
.42886 .40283 m .43963 .4027 L .43659 .39524 L p .795 .515 .513 r
F P
0 g
s
.53364 .22266 m .54343 .20233 L .5348 .1987 L p .252 .081 .445 r
F P
0 g
s
.54704 .17838 m .5348 .1987 L .54343 .20233 L p .269 .061 .401 r
F P
0 g
s
.6448 .39783 m .65385 .39104 L .64418 .38679 L p .775 .846 .905 r
F P
0 g
s
.64418 .38679 m .63568 .39432 L .6448 .39783 L p .775 .846 .905 r
F P
0 g
s
.52509 .39505 m .51723 .39615 L .51937 .40615 L p .639 .599 .792 r
F P
0 g
s
.51937 .40615 m .52668 .40669 L .52509 .39505 L p .639 .599 .792 r
F P
0 g
s
.48694 .56938 m .46101 .62223 L .47604 .61958 L p .245 .033 .381 r
F P
0 g
s
.47604 .61958 m .49791 .56757 L .48694 .56938 L p .245 .033 .381 r
F P
0 g
s
.45405 .4383 m .46132 .43293 L .45819 .42516 L p .834 .679 .691 r
F P
0 g
s
.46132 .43293 m .45405 .4383 L .45741 .44662 L p .854 .724 .719 r
F P
0 g
s
.54343 .20233 m .5559 .18175 L .54704 .17838 L p .269 .061 .401 r
F P
0 g
s
.79501 .69193 m .79424 .77684 L .80055 .77078 L p .999 .84 .525 r
F P
0 g
s
.80055 .77078 m .80304 .68593 L .79501 .69193 L p .999 .84 .525 r
F P
0 g
s
.50722 .36068 m .50283 .36626 L .50806 .37507 L p .555 .459 .701 r
F P
0 g
s
.5027 .37917 m .50806 .37507 L .50283 .36626 L p .565 .458 .691 r
F P
0 g
s
.59633 .49651 m .59245 .48856 L .58453 .4898 L p .671 .385 .479 r
F P
0 g
s
.59245 .48856 m .59633 .49651 L .60556 .49502 L p .702 .398 .459 r
F P
0 g
s
.51129 .33045 m .5145 .3208 L .50721 .31424 L p .363 .284 .632 r
F P
0 g
s
.50978 .30305 m .50721 .31424 L .5145 .3208 L p .365 .288 .635 r
F P
0 g
s
.55055 .41648 m .55626 .42171 L .56664 .41736 L p .655 .647 .83 r
F P
0 g
s
.56959 .42368 m .56664 .41736 L .55626 .42171 L p .661 .654 .833 r
F P
0 g
s
.50806 .37507 m .5027 .37917 L .50692 .38816 L p .604 .513 .725 r
F P
0 g
s
.75132 .30169 m .76182 .27854 L .75442 .2718 L p .944 .894 .75 r
F P
0 g
s
.76195 .2473 m .75442 .2718 L .76182 .27854 L p .969 .872 .684 r
F P
0 g
s
.57645 .49106 m .57633 .49973 L .58645 .49811 L p .636 .363 .487 r
F P
0 g
s
.58645 .49811 m .58453 .4898 L .57645 .49106 L p .636 .363 .487 r
F P
0 g
s
.73842 .32241 m .75132 .30169 L .74368 .29505 L p .915 .908 .8 r
F P
0 g
s
.74368 .29505 m .73071 .31607 L .73842 .32241 L p .915 .908 .8 r
F P
0 g
s
.51321 .3853 m .50692 .38816 L .51039 .39752 L p .63 .558 .755 r
F P
0 g
s
.51039 .39752 m .51723 .39615 L .51321 .3853 L p .63 .558 .755 r
F P
0 g
s
.63772 .12332 m .65494 .11604 L .64633 .11275 L p .509 .101 .203 r
F P
0 g
s
.64633 .11275 m .6276 .11936 L .63772 .12332 L p .509 .101 .203 r
F P
0 g
s
.50817 .3388 m .50502 .34623 L .51153 .35439 L p .478 .39 .677 r
F P
0 g
s
.50722 .36068 m .51153 .35439 L .50502 .34623 L p .486 .388 .669 r
F P
0 g
s
.6241 .50278 m .61374 .4937 L .60556 .49502 L p .715 .367 .386 r
F P
0 g
s
.61374 .4937 m .6241 .50278 L .63271 .50127 L p .735 .348 .318 r
F P
0 g
s
.45741 .44662 m .44967 .45491 L .45318 .46359 L p .894 .778 .726 r
F P
0 g
s
.44457 .47633 m .45318 .46359 L .44967 .45491 L p .905 .78 .713 r
F P
0 g
s
.11152 .5879 m .07616 .55397 L .07786 .56376 L p .173 .341 .792 r
F P
0 g
s
.07786 .56376 m .1148 .60502 L .11152 .5879 L p .173 .341 .792 r
F P
0 g
s
.56664 .41736 m .56959 .42368 L .58025 .42189 L p .684 .675 .835 r
F P
0 g
s
.38721 .36953 m .36233 .3604 L .36528 .36996 L p .777 .371 .282 r
F P
0 g
s
.36528 .36996 m .38994 .37743 L .38721 .36953 L p .777 .371 .282 r
F P
0 g
s
.75442 .2718 m .74368 .29505 L .75132 .30169 L p .944 .894 .75 r
F P
0 g
s
.44967 .45491 m .45741 .44662 L .45405 .4383 L p .87 .727 .702 r
F P
0 g
s
.63271 .50127 m .65015 .51316 L .65843 .5115 L p .733 .286 .19 r
F P
0 g
s
.68557 .52913 m .65843 .5115 L .65015 .51316 L p .753 .32 .222 r
F P
0 g
s
.57977 .41529 m .58025 .42189 L .59093 .42141 L p .711 .704 .842 r
F P
0 g
s
.59093 .42141 m .59251 .41532 L .57977 .41529 L p .711 .704 .842 r
F P
0 g
s
.58453 .4898 m .58645 .49811 L .59633 .49651 L p .671 .385 .479 r
F P
0 g
s
.76549 .2002 m .76212 .18029 L .75474 .17422 L p .959 .687 .475 r
F P
0 g
s
.7506 .15894 m .75474 .17422 L .76212 .18029 L p .95 .611 .338 r
F P
0 g
s
.689 .12105 m .69762 .11789 L .68978 .11407 L p .678 .248 .219 r
F P
0 g
s
.68978 .11407 m .67892 .1161 L .689 .12105 L p .678 .248 .219 r
F P
0 g
s
.50692 .38816 m .51321 .3853 L .50806 .37507 L p .604 .513 .725 r
F P
0 g
s
.59474 .40857 m .59251 .41532 L .60349 .41626 L p .732 .74 .858 r
F P
0 g
s
.60349 .41626 m .60714 .41041 L .59474 .40857 L p .732 .74 .858 r
F P
0 g
s
.73919 .14268 m .74272 .15314 L .7506 .15894 L p .903 .516 .278 r
F P
0 g
s
.74272 .15314 m .73919 .14268 L .73187 .13772 L p .875 .503 .337 r
F P
0 g
s
.45173 .4093 m .44304 .41111 L .44669 .42012 L p .803 .599 .627 r
F P
0 g
s
.44669 .42012 m .45494 .41716 L .45173 .4093 L p .803 .599 .627 r
F P
0 g
s
.53488 .39436 m .52509 .39505 L .52668 .40669 L p .638 .606 .801 r
F P
0 g
s
.52668 .40669 m .53476 .40836 L .53488 .39436 L p .638 .606 .801 r
F P
0 g
s
.68557 .52913 m .72214 .55947 L .73002 .55675 L p .792 .321 .114 r
F P
0 g
s
.77275 .60812 m .73002 .55675 L .72214 .55947 L p .881 .473 .242 r
F P
0 g
s
.45042 .42932 m .45819 .42516 L .45494 .41716 L p .817 .639 .661 r
F P
0 g
s
.45819 .42516 m .45042 .42932 L .45405 .4383 L p .834 .679 .691 r
F P
0 g
s
.58025 .42189 m .57977 .41529 L .56664 .41736 L p .684 .675 .835 r
F P
0 g
s
.65015 .51316 m .63271 .50127 L .6241 .50278 L p .729 .337 .306 r
F P
0 g
s
.5573 .50279 m .55139 .5151 L .56335 .51312 L p .535 .256 .437 r
F P
0 g
s
.56335 .51312 m .56646 .50132 L .5573 .50279 L p .535 .256 .437 r
F P
0 g
s
.54315 .41168 m .55055 .41648 L .56236 .40944 L p .649 .628 .816 r
F P
0 g
s
.56664 .41736 m .56236 .40944 L .55055 .41648 L p .655 .647 .83 r
F P
0 g
s
.65348 .90017 m .58212 .88521 L .56846 .8886 L p .33 .742 .979 r
F P
0 g
s
.58212 .88521 m .65348 .90017 L .66323 .89659 L p .523 .792 .994 r
F P
0 g
s
.45494 .41716 m .44669 .42012 L .45042 .42932 L p .817 .639 .661 r
F P
0 g
s
.62229 .40685 m .62842 .40096 L .61686 .3974 L p .756 .787 .878 r
F P
0 g
s
.61686 .3974 m .61153 .40419 L .62229 .40685 L p .756 .787 .878 r
F P
0 g
s
.18681 .63565 m .1148 .60502 L .11819 .61674 L p .366 .596 .935 r
F P
0 g
s
.11819 .61674 m .1919 .65201 L .18681 .63565 L p .366 .596 .935 r
F P
0 g
s
.65385 .39104 m .66417 .38319 L .65396 .37814 L p .779 .842 .899 r
F P
0 g
s
.65396 .37814 m .64418 .38679 L .65385 .39104 L p .779 .842 .899 r
F P
0 g
s
.28031 .33397 m .22144 .33501 L .22121 .34411 L p .553 .092 .113 r
F P
0 g
s
.22121 .34411 m .28123 .34235 L .28031 .33397 L p .553 .092 .113 r
F P
0 g
s
.5145 .3208 m .5179 .30971 L .50978 .30305 L p .365 .288 .635 r
F P
0 g
s
.51268 .29032 m .50978 .30305 L .5179 .30971 L p .37 .29 .634 r
F P
0 g
s
.55293 .39469 m .53488 .39436 L .53476 .40836 L p .64 .617 .811 r
F P
0 g
s
.53476 .40836 m .54314 .41167 L .55293 .39469 L p .64 .617 .811 r
F P
0 g
s
.52015 .38206 m .51321 .3853 L .51723 .39615 L p .625 .562 .764 r
F P
0 g
s
.51723 .39615 m .52509 .39505 L .52015 .38206 L p .625 .562 .764 r
F P
0 g
s
.6657 .12086 m .67892 .1161 L .67018 .11223 L p .613 .202 .24 r
F P
0 g
s
.67018 .11223 m .65494 .11604 L .6657 .12086 L p .613 .202 .24 r
F P
0 g
s
.51153 .35439 m .50722 .36068 L .51362 .37037 L p .548 .461 .709 r
F P
0 g
s
.50806 .37507 m .51362 .37037 L .50722 .36068 L p .555 .459 .701 r
F P
0 g
s
.51362 .37037 m .50806 .37507 L .51321 .3853 L p .596 .516 .734 r
F P
0 g
s
.56236 .40944 m .55306 .39476 L .54315 .41168 L p .649 .628 .816 r
F P
0 g
s
.22144 .33501 m .15821 .35452 L .15677 .36345 L p .401 0 .106 r
F P
0 g
s
.10498 .39934 m .15677 .36345 L .15821 .35452 L p .153 0 .061 r
F P
0 g
s
.75474 .17422 m .7506 .15894 L .74272 .15314 L p .917 .597 .424 r
F P
0 g
s
.43963 .4027 m .42886 .40283 L .43279 .41272 L p .808 .563 .569 r
F P
0 g
s
.43279 .41272 m .44304 .41111 L .43963 .4027 L p .808 .563 .569 r
F P
0 g
s
.51153 .35439 m .51573 .34733 L .50817 .3388 L p .478 .39 .677 r
F P
0 g
s
.51129 .33045 m .50818 .33879 L .51573 .34732 L p .467 .387 .683 r
F P
0 g
s
.40829 .38306 m .38994 .37743 L .39366 .38791 L p .804 .462 .407 r
F P
0 g
s
.39366 .38791 m .41156 .39172 L .40829 .38306 L p .804 .462 .407 r
F P
0 g
s
.56236 .40944 m .56664 .41736 L .57977 .41529 L p .675 .666 .833 r
F P
0 g
s
.51321 .3853 m .52015 .38206 L .51362 .37037 L p .596 .516 .734 r
F P
0 g
s
.44568 .44496 m .45405 .4383 L .45042 .42932 L p .85 .684 .676 r
F P
0 g
s
.45405 .4383 m .44568 .44496 L .44967 .45491 L p .87 .727 .702 r
F P
0 g
s
.4254 .3941 m .41156 .39172 L .41556 .40219 L p .81 .52 .498 r
F P
0 g
s
.41556 .40219 m .42886 .40283 L .4254 .3941 L p .81 .52 .498 r
F P
0 g
s
.61372 .50457 m .60556 .49502 L .59633 .49651 L p .69 .369 .427 r
F P
0 g
s
.60556 .49502 m .61372 .50457 L .6241 .50278 L p .715 .367 .386 r
F P
0 g
s
.54094 .51682 m .5291 .53529 L .54321 .53284 L p .467 .184 .4 r
F P
0 g
s
.54321 .53284 m .55139 .5151 L .54094 .51682 L p .467 .184 .4 r
F P
0 g
s
.57964 .40741 m .57977 .41529 L .59251 .41532 L p .703 .698 .843 r
F P
0 g
s
.59251 .41532 m .59474 .40857 L .57964 .40741 L p .703 .698 .843 r
F P
0 g
s
.51774 .5372 m .49791 .56757 L .5136 .56474 L p .381 .115 .381 r
F P
0 g
s
.5136 .56474 m .5291 .53529 L .51774 .5372 L p .381 .115 .381 r
F P
0 g
s
.69998 .12686 m .70614 .12238 L .69762 .11789 L p .73 .331 .293 r
F P
0 g
s
.69762 .11789 m .689 .12105 L .69998 .12686 L p .73 .331 .293 r
F P
0 g
s
.59788 .40119 m .59474 .40857 L .60714 .41041 L p .726 .735 .859 r
F P
0 g
s
.60714 .41041 m .61153 .40419 L .59788 .40119 L p .726 .735 .859 r
F P
0 g
s
.15677 .36345 m .22121 .34411 L .22144 .33501 L p .401 0 .106 r
F P
0 g
s
.44457 .47633 m .43316 .49321 L .4375 .50412 L p .936 .84 .724 r
F P
0 g
s
.42164 .52974 m .4375 .50412 L .43316 .49321 L p .925 .838 .74 r
F P
0 g
s
.73187 .13772 m .73325 .14673 L .74272 .15314 L p .875 .503 .337 r
F P
0 g
s
.73325 .14673 m .73187 .13772 L .72366 .13253 L p .842 .476 .361 r
F P
0 g
s
.42164 .52974 m .39514 .56295 L .4001 .57557 L p .925 .913 .788 r
F P
0 g
s
.35499 .6171 m .4001 .57557 L .39514 .56295 L p .869 .902 .853 r
F P
0 g
s
.5179 .30971 m .52164 .29705 L .51268 .29032 L p .37 .29 .634 r
F P
0 g
s
.51613 .27593 m .51268 .29032 L .52164 .29705 L p .378 .291 .63 r
F P
0 g
s
.66417 .38319 m .67578 .37397 L .66504 .3681 L p .786 .838 .891 r
F P
0 g
s
.66504 .3681 m .65396 .37814 L .66417 .38319 L p .786 .838 .891 r
F P
0 g
s
.56646 .50132 m .56335 .51312 L .57617 .51096 L p .587 .305 .455 r
F P
0 g
s
.57617 .51096 m .57633 .49973 L .56646 .50132 L p .587 .305 .455 r
F P
0 g
s
.52793 .37795 m .52015 .38206 L .52509 .39505 L p .625 .57 .772 r
F P
0 g
s
.52509 .39505 m .53488 .39436 L .52793 .37795 L p .625 .57 .772 r
F P
0 g
s
.62842 .40096 m .63568 .39432 L .62339 .38979 L p .753 .782 .877 r
F P
0 g
s
.62339 .38979 m .61686 .3974 L .62842 .40096 L p .753 .782 .877 r
F P
0 g
s
.57977 .41529 m .57964 .40741 L .56236 .40944 L p .675 .666 .833 r
F P
0 g
s
.44304 .41111 m .43279 .41272 L .43703 .42335 L p .82 .605 .611 r
F P
0 g
s
.43703 .42335 m .44669 .42012 L .44304 .41111 L p .82 .605 .611 r
F P
0 g
s
.61939 .13455 m .63772 .12332 L .6276 .11936 L p .502 .152 .306 r
F P
0 g
s
.6276 .11936 m .60799 .12992 L .61939 .13455 L p .502 .152 .306 r
F P
0 g
s
.07475 .44629 m .10347 .41089 L .10498 .39934 L p .047 0 .224 r
F P
0 g
s
.10347 .41089 m .07475 .44629 L .0737 .45637 L p .21 .019 .39 r
F P
0 g
s
.51573 .34733 m .51153 .35439 L .51933 .36484 L p .543 .464 .716 r
F P
0 g
s
.51362 .37037 m .51933 .36484 L .51153 .35439 L p .548 .461 .709 r
F P
0 g
s
.44139 .43427 m .45042 .42932 L .44669 .42012 L p .834 .644 .646 r
F P
0 g
s
.45042 .42932 m .44139 .43427 L .44568 .44496 L p .85 .684 .676 r
F P
0 g
s
.4403 .46561 m .44967 .45491 L .44568 .44496 L p .88 .73 .691 r
F P
0 g
s
.44967 .45491 m .4403 .46561 L .44457 .47633 L p .905 .78 .713 r
F P
0 g
s
.51573 .34732 m .51991 .33923 L .51129 .33045 L p .467 .387 .683 r
F P
0 g
s
.5145 .3208 m .51129 .33045 L .51991 .33923 L p .467 .391 .687 r
F P
0 g
s
.51933 .36484 m .51362 .37037 L .52015 .38206 L p .592 .519 .742 r
F P
0 g
s
.76565 .22294 m .76549 .2002 L .7567 .19304 L p .951 .737 .578 r
F P
0 g
s
.75474 .17422 m .7567 .19304 L .76549 .2002 L p .959 .687 .475 r
F P
0 g
s
.44669 .42012 m .43703 .42335 L .44139 .43427 L p .834 .644 .646 r
F P
0 g
s
.60194 .50659 m .59633 .49651 L .58645 .49811 L p .661 .359 .45 r
F P
0 g
s
.59633 .49651 m .60194 .50659 L .61372 .50457 L p .69 .369 .427 r
F P
0 g
s
.43316 .49321 m .44457 .47633 L .4403 .46561 L p .906 .779 .71 r
F P
0 g
s
.72214 .55947 m .76419 .61244 L .77275 .60812 L p .881 .473 .242 r
F P
0 g
s
.80304 .68593 m .77275 .60812 L .76419 .61244 L p .964 .654 .387 r
F P
0 g
s
.36233 .3604 m .32813 .35019 L .33104 .36164 L p .757 .358 .296 r
F P
0 g
s
.33104 .36164 m .36528 .36996 L .36233 .3604 L p .757 .358 .296 r
F P
0 g
s
.71137 .13327 m .71495 .12733 L .70614 .12238 L p .771 .392 .338 r
F P
0 g
s
.70614 .12238 m .69998 .12686 L .71137 .13327 L p .771 .392 .338 r
F P
0 g
s
.48382 .81738 m .56846 .8886 L .58212 .88521 L p .352 .546 .904 r
F P
0 g
s
.72366 .13253 m .72263 .14 L .73325 .14673 L p .842 .476 .361 r
F P
0 g
s
.72263 .14 m .72366 .13253 L .71495 .12733 L p .808 .44 .36 r
F P
0 g
s
.52015 .38206 m .52793 .37795 L .51933 .36484 L p .592 .519 .742 r
F P
0 g
s
.57633 .49973 m .57617 .51096 L .58924 .50875 L p .627 .338 .459 r
F P
0 g
s
.58924 .50875 m .58645 .49811 L .57633 .49973 L p .627 .338 .459 r
F P
0 g
s
.76419 .61244 m .79501 .69193 L .80304 .68593 L p .964 .654 .387 r
F P
0 g
s
.55306 .39476 m .56236 .40944 L .57964 .40741 L p .659 .646 .826 r
F P
0 g
s
.76893 .79464 m .75349 .8472 L .76217 .84087 L p .92 .934 .8 r
F P
0 g
s
.76217 .84087 m .78367 .78484 L .76893 .79464 L p .92 .934 .8 r
F P
0 g
s
.58645 .49811 m .58924 .50875 L .60194 .50659 L p .661 .359 .45 r
F P
0 g
s
.71495 .12733 m .71137 .13327 L .72263 .14 L p .808 .44 .36 r
F P
0 g
s
.52164 .29705 m .52595 .28269 L .51613 .27593 L p .378 .291 .63 r
F P
0 g
s
.52049 .2598 m .51613 .27593 L .52595 .28269 L p .388 .29 .621 r
F P
0 g
s
.63913 .51529 m .6241 .50278 L .61372 .50457 L p .712 .359 .377 r
F P
0 g
s
.6241 .50278 m .63913 .51529 L .65015 .51316 L p .729 .337 .306 r
F P
0 g
s
.67578 .37397 m .68858 .36302 L .67734 .35634 L p .797 .835 .88 r
F P
0 g
s
.67734 .35634 m .66504 .3681 L .67578 .37397 L p .797 .835 .88 r
F P
0 g
s
.61153 .40419 m .61686 .3974 L .60224 .39307 L p .729 .732 .853 r
F P
0 g
s
.60224 .39307 m .59789 .40118 L .61153 .40419 L p .729 .732 .853 r
F P
0 g
s
.42886 .40283 m .41556 .40219 L .42015 .4141 L p .821 .567 .555 r
F P
0 g
s
.42015 .4141 m .43279 .41272 L .42886 .40283 L p .821 .567 .555 r
F P
0 g
s
.53627 .3721 m .52793 .37795 L .53488 .39436 L p .636 .585 .78 r
F P
0 g
s
.53488 .39436 m .55293 .39469 L .53627 .3721 L p .636 .585 .78 r
F P
0 g
s
.58079 .39802 m .57964 .40741 L .59474 .40857 L p .696 .69 .841 r
F P
0 g
s
.59474 .40857 m .59788 .40119 L .58079 .39802 L p .696 .69 .841 r
F P
0 g
s
.63568 .39432 m .64418 .38679 L .6312 .38124 L p .752 .778 .874 r
F P
0 g
s
.6312 .38124 m .62339 .38979 L .63568 .39432 L p .752 .778 .874 r
F P
0 g
s
.67816 .12703 m .689 .12105 L .67892 .1161 L p .679 .311 .342 r
F P
0 g
s
.67892 .1161 m .6657 .12086 L .67816 .12703 L p .679 .311 .342 r
F P
0 g
s
.65015 .51316 m .67512 .5316 L .68557 .52913 L p .753 .32 .222 r
F P
0 g
s
.72214 .55947 m .68557 .52913 L .67512 .5316 L p .801 .404 .301 r
F P
0 g
s
.51991 .33923 m .52422 .32974 L .5145 .3208 L p .467 .391 .687 r
F P
0 g
s
.5179 .30971 m .5145 .3208 L .52422 .32974 L p .47 .393 .688 r
F P
0 g
s
.74272 .15314 m .74494 .16704 L .75474 .17422 L p .917 .597 .424 r
F P
0 g
s
.74494 .16704 m .74272 .15314 L .73325 .14673 L p .877 .568 .461 r
F P
0 g
s
.46101 .62223 m .4485 .70919 L .46753 .70544 L p .285 .174 .547 r
F P
0 g
s
.46753 .70544 m .47604 .61958 L .46101 .62223 L p .285 .174 .547 r
F P
0 g
s
.51933 .36484 m .52504 .35827 L .51573 .34733 L p .543 .464 .716 r
F P
0 g
s
.51991 .33923 m .51573 .34732 L .52505 .35827 L p .533 .461 .721 r
F P
0 g
s
.10852 .56655 m .07471 .5417 L .07616 .55397 L p .298 .377 .776 r
F P
0 g
s
.07616 .55397 m .11152 .5879 L .10852 .56655 L p .298 .377 .776 r
F P
0 g
s
.65043 .12913 m .6657 .12086 L .65494 .11604 L p .609 .256 .347 r
F P
0 g
s
.65494 .11604 m .63772 .12332 L .65043 .12913 L p .609 .256 .347 r
F P
0 g
s
.52504 .35827 m .51933 .36484 L .52793 .37795 L p .589 .523 .748 r
F P
0 g
s
.43547 .45338 m .44568 .44496 L .44139 .43427 L p .861 .686 .664 r
F P
0 g
s
.44568 .44496 m .43547 .45338 L .4403 .46561 L p .88 .73 .691 r
F P
0 g
s
.57964 .40741 m .58079 .39802 L .55306 .39476 L p .659 .646 .826 r
F P
0 g
s
.6011 .1496 m .61939 .13455 L .60799 .12992 L p .49 .191 .385 r
F P
0 g
s
.60799 .12992 m .58877 .14437 L .6011 .1496 L p .49 .191 .385 r
F P
0 g
s
.7567 .19304 m .75474 .17422 L .74494 .16704 L p .911 .65 .53 r
F P
0 g
s
.38994 .37743 m .36528 .36996 L .36941 .38275 L p .8 .459 .41 r
F P
0 g
s
.36941 .38275 m .39366 .38791 L .38994 .37743 L p .8 .459 .41 r
F P
0 g
s
.55139 .5151 m .54321 .53284 L .55927 .53 L p .536 .256 .437 r
F P
0 g
s
.55927 .53 m .56335 .51312 L .55139 .5151 L p .536 .256 .437 r
F P
0 g
s
.67512 .5316 m .65015 .51316 L .63913 .51529 L p .745 .367 .336 r
F P
0 g
s
.41156 .39172 m .39366 .38791 L .39829 .40068 L p .817 .522 .49 r
F P
0 g
s
.39829 .40068 m .41556 .40219 L .41156 .39172 L p .817 .522 .49 r
F P
0 g
s
.52595 .28269 m .53114 .26658 L .52049 .2598 L p .388 .29 .621 r
F P
0 g
s
.52616 .24198 m .52049 .2598 L .53114 .26658 L p .4 .286 .607 r
F P
0 g
s
.76195 .2473 m .76565 .22294 L .75557 .21485 L p .933 .769 .655 r
F P
0 g
s
.7567 .19304 m .75557 .21485 L .76565 .22294 L p .951 .737 .578 r
F P
0 g
s
.68858 .36302 m .70234 .34995 L .69065 .34249 L p .811 .831 .866 r
F P
0 g
s
.69065 .34249 m .67734 .35634 L .68858 .36302 L p .811 .831 .866 r
F P
0 g
s
.52793 .37795 m .53627 .3721 L .52504 .35827 L p .589 .523 .748 r
F P
0 g
s
.15677 .36345 m .10498 .39934 L .10347 .41089 L p .358 .059 .315 r
F P
0 g
s
.43279 .41272 m .42015 .4141 L .42514 .42698 L p .832 .608 .599 r
F P
0 g
s
.42514 .42698 m .43703 .42335 L .43279 .41272 L p .832 .608 .599 r
F P
0 g
s
.66323 .89659 m .60122 .87859 L .58212 .88521 L p .523 .792 .994 r
F P
0 g
s
.60122 .87859 m .66323 .89659 L .67512 .89146 L p .627 .801 .966 r
F P
0 g
s
.43033 .44028 m .44139 .43427 L .43703 .42335 L p .845 .647 .634 r
F P
0 g
s
.44139 .43427 m .43033 .44028 L .43547 .45338 L p .861 .686 .664 r
F P
0 g
s
.39514 .56295 m .34914 .60135 L .35499 .6171 L p .869 .902 .853 r
F P
0 g
s
.28213 .65045 m .35499 .6171 L .34914 .60135 L p .775 .864 .915 r
F P
0 g
s
.61686 .3974 m .62339 .38979 L .60803 .3841 L p .726 .727 .851 r
F P
0 g
s
.60803 .3841 m .60224 .39307 L .61686 .3974 L p .726 .727 .851 r
F P
0 g
s
.64418 .38679 m .65396 .37814 L .64032 .37156 L p .755 .773 .868 r
F P
0 g
s
.64032 .37156 m .6312 .38124 L .64418 .38679 L p .755 .773 .868 r
F P
0 g
s
.43703 .42335 m .42514 .42698 L .43033 .44028 L p .845 .647 .634 r
F P
0 g
s
.52422 .32974 m .52871 .31875 L .5179 .30971 L p .47 .393 .688 r
F P
0 g
s
.52164 .29705 m .5179 .30971 L .52871 .31875 L p .475 .395 .687 r
F P
0 g
s
.59789 .40118 m .60224 .39307 L .58427 .38759 L p .701 .684 .83 r
F P
0 g
s
.58427 .38759 m .58079 .39801 L .59789 .40118 L p .701 .684 .83 r
F P
0 g
s
.62573 .51784 m .61372 .50457 L .60194 .50659 L p .688 .363 .42 r
F P
0 g
s
.61372 .50457 m .62573 .51784 L .63913 .51529 L p .712 .359 .377 r
F P
0 g
s
.53114 .26658 m .53761 .24872 L .52616 .24198 L p .4 .286 .607 r
F P
0 g
s
.53364 .22266 m .52616 .24198 L .53761 .24872 L p .414 .281 .589 r
F P
0 g
s
.56272 .37848 m .55305 .39463 L .58079 .39801 L p .664 .636 .812 r
F P
0 g
s
.55305 .39463 m .56272 .37848 L .54426 .36384 L p .623 .581 .786 r
F P
0 g
s
.54426 .36384 m .53627 .37209 L .55305 .39463 L p .623 .581 .786 r
F P
0 g
s
.0737 .45637 m .10242 .4263 L .10347 .41089 L p .21 .019 .39 r
F P
0 g
s
.10242 .4263 m .0737 .45637 L .07294 .46852 L p .306 .148 .496 r
F P
0 g
s
.52505 .35827 m .53074 .35036 L .51991 .33923 L p .533 .461 .721 r
F P
0 g
s
.52422 .32974 m .51991 .33923 L .53074 .35036 L p .535 .465 .724 r
F P
0 g
s
.27606 .63272 m .18681 .63565 L .1919 .65201 L p .623 .778 .956 r
F P
0 g
s
.1919 .65201 m .28213 .65045 L .27606 .63272 L p .623 .778 .956 r
F P
0 g
s
.4279 .47965 m .4403 .46561 L .43547 .45338 L p .882 .729 .687 r
F P
0 g
s
.4403 .46561 m .4279 .47965 L .43316 .49321 L p .906 .779 .71 r
F P
0 g
s
.43316 .49321 m .41624 .51566 L .42164 .52974 L p .925 .838 .74 r
F P
0 g
s
.39514 .56295 m .42164 .52974 L .41624 .51566 L p .898 .831 .772 r
F P
0 g
s
.58396 .16777 m .6011 .1496 L .58877 .14437 L p .476 .22 .447 r
F P
0 g
s
.58877 .14437 m .57113 .16202 L .58396 .16777 L p .476 .22 .447 r
F P
0 g
s
.70234 .34995 m .71662 .33438 L .70457 .32623 L p .828 .827 .847 r
F P
0 g
s
.70457 .32623 m .69065 .34249 L .70234 .34995 L p .828 .827 .847 r
F P
0 g
s
.69178 .13429 m .69998 .12686 L .689 .12105 L p .727 .388 .404 r
F P
0 g
s
.689 .12105 m .67816 .12703 L .69178 .13429 L p .727 .388 .404 r
F P
0 g
s
.53074 .35036 m .52505 .35827 L .53627 .37209 L p .58 .52 .752 r
F P
0 g
s
.73325 .14673 m .73316 .15907 L .74494 .16704 L p .877 .568 .461 r
F P
0 g
s
.73316 .15907 m .73325 .14673 L .72263 .14 L p .839 .533 .472 r
F P
0 g
s
.32813 .35019 m .28123 .34235 L .28353 .35566 L p .715 .329 .317 r
F P
0 g
s
.28353 .35566 m .33104 .36164 L .32813 .35019 L p .715 .329 .317 r
F P
0 g
s
.75442 .2718 m .76195 .2473 L .75084 .23856 L p .912 .791 .713 r
F P
0 g
s
.75557 .21485 m .75084 .23856 L .76195 .2473 L p .933 .769 .655 r
F P
0 g
s
.5291 .53529 m .5136 .56474 L .53303 .56107 L p .482 .222 .443 r
F P
0 g
s
.53303 .56107 m .54321 .53284 L .5291 .53529 L p .482 .222 .443 r
F P
0 g
s
.56335 .51312 m .55927 .53 L .57639 .52693 L p .587 .304 .454 r
F P
0 g
s
.57639 .52693 m .57617 .51096 L .56335 .51312 L p .587 .304 .454 r
F P
0 g
s
.53761 .24872 m .54579 .2293 L .53364 .22266 L p .414 .281 .589 r
F P
0 g
s
.54343 .20233 m .53364 .22266 L .54579 .2293 L p .429 .272 .565 r
F P
0 g
s
.41624 .51566 m .43316 .49321 L .4279 .47965 L p .897 .776 .72 r
F P
0 g
s
.58079 .39801 m .58427 .38759 L .56272 .37848 L p .664 .636 .812 r
F P
0 g
s
.75031 .80597 m .74277 .85435 L .75349 .8472 L p .886 .896 .831 r
F P
0 g
s
.75349 .8472 m .76893 .79464 L .75031 .80597 L p .886 .896 .831 r
F P
0 g
s
.41556 .40219 m .39829 .40068 L .40366 .41531 L p .827 .569 .549 r
F P
0 g
s
.40366 .41531 m .42015 .4141 L .41556 .40219 L p .827 .569 .549 r
F P
0 g
s
.56883 .18791 m .58396 .16777 L .57113 .16202 L p .46 .242 .495 r
F P
0 g
s
.57113 .16202 m .5559 .18175 L .56883 .18791 L p .46 .242 .495 r
F P
0 g
s
.71662 .33438 m .73071 .31607 L .71847 .30737 L p .847 .822 .824 r
F P
0 g
s
.71847 .30737 m .70457 .32623 L .71662 .33438 L p .847 .822 .824 r
F P
0 g
s
.49791 .56757 m .47604 .61958 L .49759 .6152 L p .412 .201 .48 r
F P
0 g
s
.49759 .6152 m .5136 .56474 L .49791 .56757 L p .412 .201 .48 r
F P
0 g
s
.53627 .37209 m .54426 .36384 L .53074 .35036 L p .58 .52 .752 r
F P
0 g
s
.61039 .5207 m .60194 .50659 L .58924 .50875 L p .66 .355 .445 r
F P
0 g
s
.60194 .50659 m .61039 .5207 L .62573 .51784 L p .688 .363 .42 r
F P
0 g
s
.54579 .2293 m .5561 .20878 L .54343 .20233 L p .429 .272 .565 r
F P
0 g
s
.5559 .18175 m .54343 .20233 L .5561 .20878 L p .445 .259 .534 r
F P
0 g
s
.52871 .31875 m .53354 .30616 L .52164 .29705 L p .475 .395 .687 r
F P
0 g
s
.52595 .28269 m .52164 .29705 L .53354 .30616 L p .482 .396 .682 r
F P
0 g
s
.65396 .37814 m .66504 .3681 L .65073 .36052 L p .76 .769 .86 r
F P
0 g
s
.65073 .36052 m .64032 .37156 L .65396 .37814 L p .76 .769 .86 r
F P
0 g
s
.6338 .1413 m .65043 .12913 L .63772 .12332 L p .598 .295 .427 r
F P
0 g
s
.63772 .12332 m .61939 .13455 L .6338 .1413 L p .598 .295 .427 r
F P
0 g
s
.5561 .20878 m .56883 .18791 L .5559 .18175 L p .445 .259 .534 r
F P
0 g
s
.10598 .54238 m .07359 .52763 L .07471 .5417 L p .362 .38 .745 r
F P
0 g
s
.07471 .5417 m .10852 .56655 L .10598 .54238 L p .362 .38 .745 r
F P
0 g
s
.70593 .1423 m .71137 .13327 L .69998 .12686 L p .766 .445 .443 r
F P
0 g
s
.69998 .12686 m .69178 .13429 L .70593 .1423 L p .766 .445 .443 r
F P
0 g
s
.34914 .60135 m .27606 .63272 L .28213 .65045 L p .775 .864 .915 r
F P
0 g
s
.62339 .38979 m .6312 .38124 L .61519 .37426 L p .725 .722 .847 r
F P
0 g
s
.61519 .37426 m .60803 .3841 L .62339 .38979 L p .725 .722 .847 r
F P
0 g
s
.72263 .14 m .71994 .15069 L .73316 .15907 L p .839 .533 .472 r
F P
0 g
s
.71994 .15069 m .72263 .14 L .71137 .13327 L p .802 .492 .465 r
F P
0 g
s
.74368 .29505 m .75442 .2718 L .74261 .26274 L p .89 .805 .759 r
F P
0 g
s
.75084 .23856 m .74261 .26274 L .75442 .2718 L p .912 .791 .713 r
F P
0 g
s
.78137 .70006 m .78367 .78484 L .79424 .77684 L p .965 .816 .646 r
F P
0 g
s
.79424 .77684 m .79501 .69193 L .78137 .70006 L p .965 .816 .646 r
F P
0 g
s
.53074 .35036 m .53646 .34087 L .52422 .32974 L p .535 .465 .724 r
F P
0 g
s
.52871 .31875 m .52422 .32974 L .53646 .34087 L p .538 .467 .724 r
F P
0 g
s
.57617 .51096 m .57639 .52693 L .5937 .52378 L p .627 .335 .456 r
F P
0 g
s
.5937 .52378 m .58924 .50875 L .57617 .51096 L p .627 .335 .456 r
F P
0 g
s
.73071 .31607 m .74368 .29505 L .7315 .28602 L p .868 .815 .795 r
F P
0 g
s
.7315 .28602 m .71847 .30737 L .73071 .31607 L p .868 .815 .795 r
F P
0 g
s
.75557 .21485 m .7567 .19304 L .74499 .18451 L p .897 .685 .608 r
F P
0 g
s
.74494 .16704 m .74499 .18451 L .7567 .19304 L p .911 .65 .53 r
F P
0 g
s
.66522 .13656 m .67816 .12703 L .6657 .12086 L p .671 .355 .431 r
F P
0 g
s
.6657 .12086 m .65043 .12913 L .66522 .13656 L p .671 .355 .431 r
F P
0 g
s
.60224 .39307 m .60803 .3841 L .58982 .37677 L p .697 .678 .828 r
F P
0 g
s
.58982 .37677 m .58427 .38759 L .60224 .39307 L p .697 .678 .828 r
F P
0 g
s
.58924 .50875 m .5937 .52378 L .61039 .5207 L p .66 .355 .445 r
F P
0 g
s
.71137 .13327 m .70593 .1423 L .71994 .15069 L p .802 .492 .465 r
F P
0 g
s
.74261 .26274 m .7315 .28602 L .74368 .29505 L p .89 .805 .759 r
F P
0 g
s
.42199 .46424 m .43547 .45338 L .43033 .44028 L p .864 .687 .661 r
F P
0 g
s
.43547 .45338 m .42199 .46424 L .4279 .47965 L p .882 .729 .687 r
F P
0 g
s
.74499 .18451 m .74494 .16704 L .73316 .15907 L p .866 .61 .55 r
F P
0 g
s
.53646 .34087 m .53074 .35036 L .54426 .36384 L p .584 .524 .754 r
F P
0 g
s
.39366 .38791 m .36941 .38275 L .37464 .39845 L p .812 .519 .493 r
F P
0 g
s
.37464 .39845 m .39829 .40068 L .39366 .38791 L p .812 .519 .493 r
F P
0 g
s
.66104 .53477 m .63913 .51529 L .62573 .51784 L p .725 .387 .405 r
F P
0 g
s
.63913 .51529 m .66104 .53477 L .67512 .5316 L p .745 .367 .336 r
F P
0 g
s
.4485 .70919 m .48382 .81738 L .50304 .81305 L p .323 .344 .728 r
F P
0 g
s
.50304 .81305 m .46753 .70544 L .4485 .70919 L p .323 .344 .728 r
F P
0 g
s
.36528 .36996 m .33104 .36164 L .3353 .37711 L p .781 .448 .423 r
F P
0 g
s
.3353 .37711 m .36941 .38275 L .36528 .36996 L p .781 .448 .423 r
F P
0 g
s
.07294 .46852 m .10189 .44524 L .10242 .4263 L p .306 .148 .496 r
F P
0 g
s
.10189 .44524 m .07294 .46852 L .07253 .4823 L p .361 .234 .569 r
F P
0 g
s
.67512 .89146 m .62445 .86923 L .60122 .87859 L p .627 .801 .966 r
F P
0 g
s
.62445 .86923 m .67512 .89146 L .68849 .88506 L p .691 .804 .935 r
F P
0 g
s
.42015 .4141 m .40366 .41531 L .40957 .43125 L p .837 .609 .594 r
F P
0 g
s
.40957 .43125 m .42514 .42698 L .42015 .4141 L p .837 .609 .594 r
F P
0 g
s
.67512 .5316 m .7094 .56332 L .72214 .55947 L p .801 .404 .301 r
F P
0 g
s
.76419 .61244 m .72214 .55947 L .7094 .56332 L p .861 .522 .41 r
F P
0 g
s
.58212 .88521 m .50304 .81305 L .48382 .81738 L p .352 .546 .904 r
F P
0 g
s
.18132 .61171 m .11152 .5879 L .1148 .60502 L p .493 .593 .883 r
F P
0 g
s
.1148 .60502 m .18681 .63565 L .18132 .61171 L p .493 .593 .883 r
F P
0 g
s
.53354 .30616 m .53892 .29187 L .52595 .28269 L p .482 .396 .682 r
F P
0 g
s
.53114 .26658 m .52595 .28269 L .53892 .29187 L p .491 .395 .674 r
F P
0 g
s
.66504 .3681 m .67734 .35634 L .66238 .34779 L p .768 .765 .85 r
F P
0 g
s
.66238 .34779 m .65073 .36052 L .66504 .3681 L p .768 .765 .85 r
F P
0 g
s
.41578 .44782 m .43033 .44028 L .42514 .42698 L p .849 .648 .63 r
F P
0 g
s
.43033 .44028 m .41578 .44782 L .42199 .46424 L p .864 .687 .661 r
F P
0 g
s
.58427 .38759 m .58982 .37677 L .5699 .36662 L p .663 .63 .807 r
F P
0 g
s
.5699 .36662 m .56272 .37848 L .58427 .38759 L p .663 .63 .807 r
F P
0 g
s
.42514 .42698 m .40957 .43125 L .41578 .44782 L p .849 .648 .63 r
F P
0 g
s
.28123 .34235 m .22121 .34411 L .22215 .35859 L p .645 .28 .336 r
F P
0 g
s
.22215 .35859 m .28353 .35566 L .28123 .34235 L p .645 .28 .336 r
F P
0 g
s
.6312 .38124 m .64032 .37156 L .62366 .3634 L p .727 .717 .841 r
F P
0 g
s
.62366 .3634 m .61519 .37426 L .6312 .38124 L p .727 .717 .841 r
F P
0 g
s
.55154 .35371 m .54426 .36384 L .56272 .37848 L p .625 .579 .782 r
F P
0 g
s
.54426 .36384 m .55154 .35371 L .53646 .34087 L p .584 .524 .754 r
F P
0 g
s
.72829 .81847 m .73038 .86204 L .74277 .85435 L p .85 .864 .851 r
F P
0 g
s
.74277 .85435 m .75031 .80597 L .72829 .81847 L p .85 .864 .851 r
F P
0 g
s
.53646 .34087 m .54224 .32983 L .52871 .31875 L p .538 .467 .724 r
F P
0 g
s
.53354 .30616 m .52871 .31875 L .54224 .32983 L p .543 .468 .722 r
F P
0 g
s
.10401 .51686 m .07284 .51254 L .07359 .52763 L p .393 .365 .709 r
F P
0 g
s
.07359 .52763 m .10598 .54238 L .10401 .51686 L p .393 .365 .709 r
F P
0 g
s
.56272 .37848 m .5699 .36662 L .55154 .35371 L p .625 .579 .782 r
F P
0 g
s
.22121 .34411 m .15677 .36345 L .15607 .37752 L p .536 .198 .341 r
F P
0 g
s
.10347 .41089 m .15607 .37752 L .15677 .36345 L p .358 .059 .315 r
F P
0 g
s
.7094 .56332 m .67512 .5316 L .66104 .53477 L p .781 .438 .406 r
F P
0 g
s
.60803 .3841 m .61519 .37426 L .59674 .36555 L p .696 .673 .823 r
F P
0 g
s
.59674 .36555 m .58982 .37677 L .60803 .3841 L p .696 .673 .823 r
F P
0 g
s
.61677 .15719 m .6338 .1413 L .61939 .13455 L p .584 .323 .488 r
F P
0 g
s
.61939 .13455 m .6011 .1496 L .61677 .15719 L p .584 .323 .488 r
F P
0 g
s
.07253 .4823 m .10196 .46718 L .10189 .44524 L p .361 .234 .569 r
F P
0 g
s
.10196 .46718 m .07253 .4823 L .07249 .49719 L p .391 .294 .625 r
F P
0 g
s
.54321 .53284 m .53303 .56107 L .55499 .55679 L p .55 .29 .474 r
F P
0 g
s
.55499 .55679 m .55927 .53 L .54321 .53284 L p .55 .29 .474 r
F P
0 g
s
.54224 .32983 m .53646 .34087 L .55154 .35371 L p .588 .526 .753 r
F P
0 g
s
.40975 .49818 m .4279 .47965 L .42199 .46424 L p .874 .726 .695 r
F P
0 g
s
.4279 .47965 m .40975 .49818 L .41624 .51566 L p .897 .776 .72 r
F P
0 g
s
.68143 .14528 m .69178 .13429 L .67816 .12703 L p .716 .426 .485 r
F P
0 g
s
.67816 .12703 m .66522 .13656 L .68143 .14528 L p .716 .426 .485 r
F P
0 g
s
.53892 .29187 m .54515 .27581 L .53114 .26658 L p .491 .395 .674 r
F P
0 g
s
.53761 .24872 m .53114 .26658 L .54515 .27581 L p .501 .392 .662 r
F P
0 g
s
.75084 .23856 m .75557 .21485 L .74213 .20515 L p .879 .708 .667 r
F P
0 g
s
.74499 .18451 m .74213 .20515 L .75557 .21485 L p .897 .685 .608 r
F P
0 g
s
.73316 .15907 m .73089 .17501 L .74499 .18451 L p .866 .61 .55 r
F P
0 g
s
.73089 .17501 m .73316 .15907 L .71994 .15069 L p .826 .57 .551 r
F P
0 g
s
.68849 .88506 m .65029 .85779 L .62445 .86923 L p .691 .804 .935 r
F P
0 g
s
.65029 .85779 m .68849 .88506 L .70262 .87777 L p .738 .81 .909 r
F P
0 g
s
.67734 .35634 m .69065 .34249 L .67508 .33304 L p .779 .761 .837 r
F P
0 g
s
.67508 .33304 m .66238 .34779 L .67734 .35634 L p .779 .761 .837 r
F P
0 g
s
.41624 .51566 m .38855 .5447 L .39514 .56295 L p .898 .831 .772 r
F P
0 g
s
.34914 .60135 m .39514 .56295 L .38855 .5447 L p .85 .815 .814 r
F P
0 g
s
.10266 .49139 m .07249 .49719 L .07284 .51254 L p .401 .337 .67 r
F P
0 g
s
.07284 .51254 m .10401 .51686 L .10266 .49139 L p .401 .337 .67 r
F P
0 g
s
.07249 .49719 m .10266 .49139 L .10196 .46718 L p .391 .294 .625 r
F P
0 g
s
.15607 .37752 m .10347 .41089 L .10242 .4263 L p .461 .217 .457 r
F P
0 g
s
.15607 .37752 m .22215 .35859 L .22121 .34411 L p .536 .198 .341 r
F P
0 g
s
.64368 .53855 m .62573 .51784 L .61039 .5207 L p .7 .39 .448 r
F P
0 g
s
.62573 .51784 m .64368 .53855 L .66104 .53477 L p .725 .387 .405 r
F P
0 g
s
.39829 .40068 m .37464 .39845 L .38082 .41661 L p .822 .566 .552 r
F P
0 g
s
.38082 .41661 m .40366 .41531 L .39829 .40068 L p .822 .566 .552 r
F P
0 g
s
.70357 .83169 m .71681 .86997 L .73038 .86204 L p .814 .839 .869 r
F P
0 g
s
.73038 .86204 m .72829 .81847 L .70357 .83169 L p .814 .839 .869 r
F P
0 g
s
.65063 .14992 m .66522 .13656 L .65043 .12913 L p .658 .387 .498 r
F P
0 g
s
.65043 .12913 m .6338 .1413 L .65063 .14992 L p .658 .387 .498 r
F P
0 g
s
.54224 .32983 m .54827 .31724 L .53354 .30616 L p .543 .468 .722 r
F P
0 g
s
.53892 .29187 m .53354 .30616 L .54827 .31724 L p .549 .468 .716 r
F P
0 g
s
.64032 .37156 m .65073 .36052 L .63338 .35125 L p .732 .713 .833 r
F P
0 g
s
.63338 .35125 m .62366 .3634 L .64032 .37156 L p .732 .713 .833 r
F P
0 g
s
.38855 .5447 m .41624 .51566 L .40975 .49818 L p .872 .768 .744 r
F P
0 g
s
.58982 .37677 m .59674 .36555 L .57714 .35473 L p .664 .626 .801 r
F P
0 g
s
.57714 .35473 m .5699 .36662 L .58982 .37677 L p .664 .626 .801 r
F P
0 g
s
.74213 .20515 m .74499 .18451 L .73089 .17501 L p .85 .638 .615 r
F P
0 g
s
.55849 .34228 m .55154 .35371 L .5699 .36662 L p .628 .578 .778 r
F P
0 g
s
.55154 .35371 m .55849 .34228 L .54224 .32983 L p .588 .526 .753 r
F P
0 g
s
.54515 .27581 m .55258 .25798 L .53761 .24872 L p .501 .392 .662 r
F P
0 g
s
.54579 .2293 m .53761 .24872 L .55258 .25798 L p .513 .388 .647 r
F P
0 g
s
.70262 .87777 m .67715 .84503 L .65029 .85779 L p .738 .81 .909 r
F P
0 g
s
.67715 .84503 m .70262 .87777 L .71681 .86997 L p .777 .822 .887 r
F P
0 g
s
.69833 .15491 m .70593 .1423 L .69178 .13429 L p .754 .481 .519 r
F P
0 g
s
.69178 .13429 m .68143 .14528 L .69833 .15491 L p .754 .481 .519 r
F P
0 g
s
.71994 .15069 m .71508 .16498 L .73089 .17501 L p .826 .57 .551 r
F P
0 g
s
.71508 .16498 m .71994 .15069 L .70593 .1423 L p .79 .527 .541 r
F P
0 g
s
.50304 .81305 m .58212 .88521 L .60122 .87859 L p .519 .602 .877 r
F P
0 g
s
.60038 .17604 m .61677 .15719 L .6011 .1496 L p .57 .345 .535 r
F P
0 g
s
.6011 .1496 m .58396 .16777 L .60038 .17604 L p .57 .345 .535 r
F P
0 g
s
.71681 .86997 m .70357 .83169 L .67715 .84503 L p .777 .822 .887 r
F P
0 g
s
.69065 .34249 m .70457 .32623 L .68852 .316 L p .792 .756 .82 r
F P
0 g
s
.68852 .316 m .67508 .33304 L .69065 .34249 L p .792 .756 .82 r
F P
0 g
s
.5699 .36662 m .57714 .35473 L .55849 .34228 L p .628 .578 .778 r
F P
0 g
s
.61519 .37426 m .62366 .3634 L .60475 .35355 L p .698 .668 .817 r
F P
0 g
s
.60475 .35355 m .59674 .36555 L .61519 .37426 L p .698 .668 .817 r
F P
0 g
s
.54827 .31724 m .54224 .32983 L .55849 .34228 L p .593 .526 .749 r
F P
0 g
s
.70593 .1423 m .69833 .15491 L .71508 .16498 L p .79 .527 .541 r
F P
0 g
s
.7094 .56332 m .74996 .61841 L .76419 .61244 L p .861 .522 .41 r
F P
0 g
s
.79501 .69193 m .76419 .61244 L .74996 .61841 L p .92 .661 .528 r
F P
0 g
s
.55927 .53 m .55499 .55679 L .57821 .55215 L p .599 .334 .487 r
F P
0 g
s
.57821 .55215 m .57639 .52693 L .55927 .53 L p .599 .334 .487 r
F P
0 g
s
.74261 .26274 m .75084 .23856 L .73602 .228 L p .86 .724 .712 r
F P
0 g
s
.74213 .20515 m .73602 .228 L .75084 .23856 L p .879 .708 .667 r
F P
0 g
s
.33104 .36164 m .28353 .35566 L .28725 .3738 L p .744 .425 .443 r
F P
0 g
s
.28725 .3738 m .3353 .37711 L .33104 .36164 L p .744 .425 .443 r
F P
0 g
s
.40256 .47841 m .42199 .46424 L .41578 .44782 L p .856 .683 .667 r
F P
0 g
s
.42199 .46424 m .40256 .47841 L .40975 .49818 L p .874 .726 .695 r
F P
0 g
s
.74996 .61841 m .78137 .70006 L .79501 .69193 L p .92 .661 .528 r
F P
0 g
s
.36941 .38275 m .3353 .37711 L .34086 .39631 L p .794 .509 .506 r
F P
0 g
s
.34086 .39631 m .37464 .39845 L .36941 .38275 L p .794 .509 .506 r
F P
0 g
s
.55258 .25798 m .56159 .23853 L .54579 .2293 L p .513 .388 .647 r
F P
0 g
s
.5561 .20878 m .54579 .2293 L .56159 .23853 L p .527 .382 .627 r
F P
0 g
s
.5136 .56474 m .49759 .6152 L .52413 .60943 L p .509 .295 .525 r
F P
0 g
s
.52413 .60943 m .53303 .56107 L .5136 .56474 L p .509 .295 .525 r
F P
0 g
s
.62357 .54282 m .61039 .5207 L .5937 .52378 L p .671 .382 .473 r
F P
0 g
s
.61039 .5207 m .62357 .54282 L .64368 .53855 L p .7 .39 .448 r
F P
0 g
s
.40366 .41531 m .38082 .41661 L .38773 .43657 L p .831 .606 .598 r
F P
0 g
s
.38773 .43657 m .40957 .43125 L .40366 .41531 L p .831 .606 .598 r
F P
0 g
s
.54827 .31724 m .55482 .30303 L .53892 .29187 L p .549 .468 .716 r
F P
0 g
s
.54515 .27581 m .53892 .29187 L .55482 .30303 L p .557 .467 .709 r
F P
0 g
s
.58546 .19667 m .60038 .17604 L .58396 .16777 L p .555 .361 .572 r
F P
0 g
s
.58396 .16777 m .56883 .18791 L .58546 .19667 L p .555 .361 .572 r
F P
0 g
s
.70457 .32623 m .71847 .30737 L .70216 .29657 L p .807 .751 .801 r
F P
0 g
s
.70216 .29657 m .68852 .316 L .70457 .32623 L p .807 .751 .801 r
F P
0 g
s
.65073 .36052 m .66238 .34779 L .64429 .33749 L p .739 .709 .823 r
F P
0 g
s
.64429 .33749 m .63338 .35125 L .65073 .36052 L p .739 .709 .823 r
F P
0 g
s
.47604 .61958 m .46753 .70544 L .49475 .69884 L p .449 .314 .605 r
F P
0 g
s
.49475 .69884 m .49759 .6152 L .47604 .61958 L p .449 .314 .605 r
F P
0 g
s
.56159 .23853 m .57249 .21785 L .5561 .20878 L p .527 .382 .627 r
F P
0 g
s
.56883 .18791 m .5561 .20878 L .57249 .21785 L p .54 .373 .603 r
F P
0 g
s
.57639 .52693 m .57821 .55215 L .60143 .54742 L p .638 .364 .486 r
F P
0 g
s
.60143 .54742 m .5937 .52378 L .57639 .52693 L p .638 .364 .486 r
F P
0 g
s
.57249 .21785 m .58546 .19667 L .56883 .18791 L p .54 .373 .603 r
F P
0 g
s
.7315 .28602 m .74261 .26274 L .72683 .25171 L p .841 .736 .748 r
F P
0 g
s
.73602 .228 m .72683 .25171 L .74261 .26274 L p .86 .724 .712 r
F P
0 g
s
.39509 .4575 m .41578 .44782 L .40957 .43125 L p .842 .644 .635 r
F P
0 g
s
.41578 .44782 m .39509 .4575 L .40256 .47841 L p .856 .683 .667 r
F P
0 g
s
.5937 .52378 m .60143 .54742 L .62357 .54282 L p .671 .382 .473 r
F P
0 g
s
.40957 .43125 m .38773 .43657 L .39509 .4575 L p .842 .644 .635 r
F P
0 g
s
.59674 .36555 m .60475 .35355 L .58485 .34207 L p .667 .623 .795 r
F P
0 g
s
.58485 .34207 m .57714 .35473 L .59674 .36555 L p .667 .623 .795 r
F P
0 g
s
.5656 .32959 m .55849 .34228 L .57714 .35473 L p .632 .576 .773 r
F P
0 g
s
.55849 .34228 m .5656 .32959 L .54827 .31724 L p .593 .526 .749 r
F P
0 g
s
.71847 .30737 m .7315 .28602 L .71524 .27493 L p .824 .745 .777 r
F P
0 g
s
.71524 .27493 m .70216 .29657 L .71847 .30737 L p .824 .745 .777 r
F P
0 g
s
.76215 .71022 m .76893 .79464 L .78367 .78484 L p .911 .777 .701 r
F P
0 g
s
.78367 .78484 m .78137 .70006 L .76215 .71022 L p .911 .777 .701 r
F P
0 g
s
.66917 .16003 m .68143 .14528 L .66522 .13656 L p .702 .453 .544 r
F P
0 g
s
.66522 .13656 m .65063 .14992 L .66917 .16003 L p .702 .453 .544 r
F P
0 g
s
.72683 .25171 m .71524 .27493 L .7315 .28602 L p .841 .736 .748 r
F P
0 g
s
.69194 .56822 m .66104 .53477 L .64368 .53855 L p .754 .449 .468 r
F P
0 g
s
.66104 .53477 m .69194 .56822 L .7094 .56332 L p .781 .438 .406 r
F P
0 g
s
.55482 .30303 m .54827 .31724 L .5656 .32959 L p .599 .525 .743 r
F P
0 g
s
.62366 .3634 m .63338 .35125 L .61382 .34038 L p .702 .665 .81 r
F P
0 g
s
.61382 .34038 m .60475 .35355 L .62366 .3634 L p .702 .665 .81 r
F P
0 g
s
.63518 .16684 m .65063 .14992 L .6338 .1413 L p .644 .409 .548 r
F P
0 g
s
.6338 .1413 m .61677 .15719 L .63518 .16684 L p .644 .409 .548 r
F P
0 g
s
.73089 .17501 m .72594 .19429 L .74213 .20515 L p .85 .638 .615 r
F P
0 g
s
.72594 .19429 m .73089 .17501 L .71508 .16498 L p .811 .594 .609 r
F P
0 g
s
.57714 .35473 m .58485 .34207 L .5656 .32959 L p .632 .576 .773 r
F P
0 g
s
.73602 .228 m .74213 .20515 L .72594 .19429 L p .833 .657 .664 r
F P
0 g
s
.55482 .30303 m .56218 .28708 L .54515 .27581 L p .557 .467 .709 r
F P
0 g
s
.55258 .25798 m .54515 .27581 L .56218 .28708 L p .567 .465 .698 r
F P
0 g
s
.1758 .58206 m .10852 .56655 L .11152 .5879 L p .547 .57 .829 r
F P
0 g
s
.11152 .5879 m .18132 .61171 L .1758 .58206 L p .547 .57 .829 r
F P
0 g
s
.66238 .34779 m .67508 .33304 L .65629 .32182 L p .748 .705 .811 r
F P
0 g
s
.65629 .32182 m .64429 .33749 L .66238 .34779 L p .748 .705 .811 r
F P
0 g
s
.38855 .5447 m .34164 .57846 L .34914 .60135 L p .85 .815 .814 r
F P
0 g
s
.27606 .63272 m .34914 .60135 L .34164 .57846 L p .777 .779 .855 r
F P
0 g
s
.74996 .61841 m .7094 .56332 L .69194 .56822 L p .825 .535 .498 r
F P
0 g
s
.38076 .52212 m .40975 .49818 L .40256 .47841 L p .851 .717 .714 r
F P
0 g
s
.40975 .49818 m .38076 .52212 L .38855 .5447 L p .872 .768 .744 r
F P
0 g
s
.10242 .4263 m .15621 .39664 L .15607 .37752 L p .461 .217 .457 r
F P
0 g
s
.15621 .39664 m .10242 .4263 L .10189 .44524 L p .518 .316 .546 r
F P
0 g
s
.2688 .60683 m .18132 .61171 L .18681 .63565 L p .668 .715 .884 r
F P
0 g
s
.18681 .63565 m .27606 .63272 L .2688 .60683 L p .668 .715 .884 r
F P
0 g
s
.68853 .17116 m .69833 .15491 L .68143 .14528 L p .74 .506 .575 r
F P
0 g
s
.68143 .14528 m .66917 .16003 L .68853 .17116 L p .74 .506 .575 r
F P
0 g
s
.37464 .39845 m .34086 .39631 L .34759 .41874 L p .803 .557 .565 r
F P
0 g
s
.34759 .41874 m .38082 .41661 L .37464 .39845 L p .803 .557 .565 r
F P
0 g
s
.71508 .16498 m .70777 .18277 L .72594 .19429 L p .811 .594 .609 r
F P
0 g
s
.70777 .18277 m .71508 .16498 L .69833 .15491 L p .775 .551 .596 r
F P
0 g
s
.60475 .35355 m .61382 .34038 L .5933 .32823 L p .672 .619 .788 r
F P
0 g
s
.5933 .32823 m .58485 .34207 L .60475 .35355 L p .672 .619 .788 r
F P
0 g
s
.57322 .31546 m .5656 .32959 L .58485 .34207 L p .638 .574 .766 r
F P
0 g
s
.5656 .32959 m .57322 .31546 L .55482 .30303 L p .599 .525 .743 r
F P
0 g
s
.56218 .28708 m .55482 .30303 L .57322 .31546 L p .606 .523 .735 r
F P
0 g
s
.28353 .35566 m .22215 .35859 L .22432 .37841 L p .686 .387 .462 r
F P
0 g
s
.22432 .37841 m .28725 .3738 L .28353 .35566 L p .686 .387 .462 r
F P
0 g
s
.63338 .35125 m .64429 .33749 L .62398 .3257 L p .709 .661 .8 r
F P
0 g
s
.62398 .3257 m .61382 .34038 L .63338 .35125 L p .709 .661 .8 r
F P
0 g
s
.56218 .28708 m .57065 .26935 L .55258 .25798 L p .567 .465 .698 r
F P
0 g
s
.56159 .23853 m .55258 .25798 L .57065 .26935 L p .578 .461 .684 r
F P
0 g
s
.69833 .15491 m .68853 .17116 L .70777 .18277 L p .775 .551 .596 r
F P
0 g
s
.61976 .18649 m .63518 .16684 L .61677 .15719 L p .63 .426 .588 r
F P
0 g
s
.61677 .15719 m .60038 .17604 L .61976 .18649 L p .63 .426 .588 r
F P
0 g
s
.67508 .33304 m .68852 .316 L .66916 .30402 L p .759 .7 .796 r
F P
0 g
s
.66916 .30402 m .65629 .32182 L .67508 .33304 L p .759 .7 .796 r
F P
0 g
s
.58485 .34207 m .5933 .32823 L .57322 .31546 L p .638 .574 .766 r
F P
0 g
s
.22215 .35859 m .15607 .37752 L .15621 .39664 L p .6 .324 .471 r
F P
0 g
s
.72683 .25171 m .73602 .228 L .71814 .21609 L p .817 .671 .702 r
F P
0 g
s
.72594 .19429 m .71814 .21609 L .73602 .228 L p .833 .657 .664 r
F P
0 g
s
.34164 .57846 m .38855 .5447 L .38076 .52212 L p .83 .75 .775 r
F P
0 g
s
.53303 .56107 m .52413 .60943 L .55385 .60267 L p .574 .354 .544 r
F P
0 g
s
.55385 .60267 m .55499 .55679 L .53303 .56107 L p .574 .354 .544 r
F P
0 g
s
.65552 .17813 m .66917 .16003 L .65063 .14992 L p .688 .472 .589 r
F P
0 g
s
.65063 .14992 m .63518 .16684 L .65552 .17813 L p .688 .472 .589 r
F P
0 g
s
.3353 .37711 m .28725 .3738 L .29236 .39652 L p .76 .49 .525 r
F P
0 g
s
.29236 .39652 m .34086 .39631 L .3353 .37711 L p .76 .49 .525 r
F P
0 g
s
.57065 .26935 m .58054 .24993 L .56159 .23853 L p .578 .461 .684 r
F P
0 g
s
.57249 .21785 m .56159 .23853 L .58054 .24993 L p .59 .456 .666 r
F P
0 g
s
.67006 .57407 m .64368 .53855 L .62357 .54282 L p .724 .447 .507 r
F P
0 g
s
.64368 .53855 m .67006 .57407 L .69194 .56822 L p .754 .449 .468 r
F P
0 g
s
.71814 .21609 m .72594 .19429 L .70777 .18277 L p .795 .612 .654 r
F P
0 g
s
.34164 .57846 m .2688 .60683 L .27606 .63272 L p .777 .779 .855 r
F P
0 g
s
.60519 .20767 m .61976 .18649 L .60038 .17604 L p .616 .439 .62 r
F P
0 g
s
.60038 .17604 m .58546 .19667 L .60519 .20767 L p .616 .439 .62 r
F P
0 g
s
.68852 .316 m .70216 .29657 L .68248 .28405 L p .771 .695 .779 r
F P
0 g
s
.68248 .28405 m .66916 .30402 L .68852 .316 L p .771 .695 .779 r
F P
0 g
s
.57322 .31546 m .58165 .29971 L .56218 .28708 L p .606 .523 .735 r
F P
0 g
s
.57065 .26935 m .56218 .28708 L .58165 .29971 L p .615 .521 .724 r
F P
0 g
s
.37229 .49672 m .40256 .47841 L .39509 .4575 L p .835 .674 .683 r
F P
0 g
s
.40256 .47841 m .37229 .49672 L .38076 .52212 L p .851 .717 .714 r
F P
0 g
s
.58165 .29971 m .57322 .31546 L .5933 .32823 L p .645 .571 .758 r
F P
0 g
s
.61382 .34038 m .62398 .3257 L .60266 .31287 L p .678 .616 .779 r
F P
0 g
s
.60266 .31287 m .5933 .32823 L .61382 .34038 L p .678 .616 .779 r
F P
0 g
s
.38082 .41661 m .34759 .41874 L .35528 .44366 L p .812 .597 .611 r
F P
0 g
s
.35528 .44366 m .38773 .43657 L .38082 .41661 L p .812 .597 .611 r
F P
0 g
s
.64429 .33749 m .65629 .32182 L .63523 .30921 L p .717 .657 .789 r
F P
0 g
s
.63523 .30921 m .62398 .3257 L .64429 .33749 L p .717 .657 .789 r
F P
0 g
s
.58054 .24993 m .59204 .22915 L .57249 .21785 L p .59 .456 .666 r
F P
0 g
s
.58546 .19667 m .57249 .21785 L .59204 .22915 L p .602 .448 .645 r
F P
0 g
s
.15621 .39664 m .22432 .37841 L .22215 .35859 L p .6 .324 .471 r
F P
0 g
s
.71524 .27493 m .72683 .25171 L .70781 .23917 L p .801 .681 .733 r
F P
0 g
s
.71814 .21609 m .70781 .23917 L .72683 .25171 L p .817 .671 .702 r
F P
0 g
s
.59204 .22915 m .60519 .20767 L .58546 .19667 L p .602 .448 .645 r
F P
0 g
s
.60122 .87859 m .53029 .80491 L .50304 .81305 L p .519 .602 .877 r
F P
0 g
s
.53029 .80491 m .60122 .87859 L .62445 .86923 L p .606 .628 .846 r
F P
0 g
s
.70216 .29657 m .71524 .27493 L .69563 .26219 L p .785 .689 .758 r
F P
0 g
s
.69563 .26219 m .68248 .28405 L .70216 .29657 L p .785 .689 .758 r
F P
0 g
s
.5933 .32823 m .60266 .31287 L .58165 .29971 L p .645 .571 .758 r
F P
0 g
s
.70781 .23917 m .69563 .26219 L .71524 .27493 L p .801 .681 .733 r
F P
0 g
s
.46753 .70544 m .50304 .81305 L .53029 .80491 L p .485 .445 .738 r
F P
0 g
s
.53029 .80491 m .49475 .69884 L .46753 .70544 L p .485 .445 .738 r
F P
0 g
s
.17059 .54887 m .10598 .54238 L .10852 .56655 L p .571 .542 .783 r
F P
0 g
s
.10852 .56655 m .1758 .58206 L .17059 .54887 L p .571 .542 .783 r
F P
0 g
s
.73754 .72221 m .75031 .80597 L .76893 .79464 L p .863 .744 .731 r
F P
0 g
s
.76893 .79464 m .76215 .71022 L .73754 .72221 L p .863 .744 .731 r
F P
0 g
s
.67684 .19051 m .68853 .17116 L .66917 .16003 L p .725 .523 .617 r
F P
0 g
s
.66917 .16003 m .65552 .17813 L .67684 .19051 L p .725 .523 .617 r
F P
0 g
s
.10189 .44524 m .15724 .42056 L .15621 .39664 L p .518 .316 .546 r
F P
0 g
s
.15724 .42056 m .10189 .44524 L .10196 .46718 L p .551 .385 .609 r
F P
0 g
s
.36364 .47007 m .39509 .4575 L .38773 .43657 L p .823 .635 .649 r
F P
0 g
s
.39509 .4575 m .36364 .47007 L .37229 .49672 L p .835 .674 .683 r
F P
0 g
s
.38773 .43657 m .35528 .44366 L .36364 .47007 L p .823 .635 .649 r
F P
0 g
s
.70777 .18277 m .69807 .20338 L .71814 .21609 L p .795 .612 .654 r
F P
0 g
s
.69807 .20338 m .70777 .18277 L .68853 .17116 L p .76 .568 .638 r
F P
0 g
s
.58165 .29971 m .59114 .2822 L .57065 .26935 L p .615 .521 .724 r
F P
0 g
s
.58054 .24993 m .57065 .26935 L .59114 .2822 L p .625 .517 .711 r
F P
0 g
s
.55499 .55679 m .55385 .60267 L .5849 .59535 L p .621 .393 .55 r
F P
0 g
s
.5849 .59535 m .57821 .55215 L .55499 .55679 L p .621 .393 .55 r
F P
0 g
s
.64127 .19866 m .65552 .17813 L .63518 .16684 L p .674 .486 .624 r
F P
0 g
s
.63518 .16684 m .61976 .18649 L .64127 .19866 L p .674 .486 .624 r
F P
0 g
s
.65629 .32182 m .66916 .30402 L .64746 .29074 L p .727 .652 .775 r
F P
0 g
s
.64746 .29074 m .63523 .30921 L .65629 .32182 L p .727 .652 .775 r
F P
0 g
s
.68853 .17116 m .67684 .19051 L .69807 .20338 L p .76 .568 .638 r
F P
0 g
s
.64432 .58071 m .62357 .54282 L .60143 .54742 L p .694 .438 .531 r
F P
0 g
s
.62357 .54282 m .64432 .58071 L .67006 .57407 L p .724 .447 .507 r
F P
0 g
s
.69194 .56822 m .73008 .62598 L .74996 .61841 L p .825 .535 .498 r
F P
0 g
s
.78137 .70006 m .74996 .61841 L .73008 .62598 L p .87 .646 .598 r
F P
0 g
s
.59114 .2822 m .58165 .29971 L .60266 .31287 L p .653 .568 .747 r
F P
0 g
s
.62398 .3257 m .63523 .30921 L .61307 .29576 L p .686 .612 .768 r
F P
0 g
s
.61307 .29576 m .60266 .31287 L .62398 .3257 L p .686 .612 .768 r
F P
0 g
s
.70781 .23917 m .71814 .21609 L .69807 .20338 L p .78 .624 .688 r
F P
0 g
s
.49759 .6152 m .49475 .69884 L .52805 .68993 L p .541 .39 .626 r
F P
0 g
s
.52805 .68993 m .52413 .60943 L .49759 .6152 L p .541 .39 .626 r
F P
0 g
s
.73008 .62598 m .76215 .71022 L .78137 .70006 L p .87 .646 .598 r
F P
0 g
s
.60266 .31287 m .61307 .29576 L .59114 .2822 L p .653 .568 .747 r
F P
0 g
s
.73008 .62598 m .69194 .56822 L .67006 .57407 L p .789 .533 .55 r
F P
0 g
s
.59114 .2822 m .60188 .26293 L .58054 .24993 L p .625 .517 .711 r
F P
0 g
s
.59204 .22915 m .58054 .24993 L .60188 .26293 L p .636 .512 .695 r
F P
0 g
s
.57821 .55215 m .5849 .59535 L .61555 .58791 L p .66 .42 .545 r
F P
0 g
s
.61555 .58791 m .60143 .54742 L .57821 .55215 L p .66 .42 .545 r
F P
0 g
s
.60143 .54742 m .61555 .58791 L .64432 .58071 L p .694 .438 .531 r
F P
0 g
s
.66916 .30402 m .68248 .28405 L .66042 .27034 L p .739 .647 .759 r
F P
0 g
s
.66042 .27034 m .64746 .29074 L .66916 .30402 L p .739 .647 .759 r
F P
0 g
s
.34086 .39631 m .29236 .39652 L .2988 .42334 L p .771 .539 .583 r
F P
0 g
s
.2988 .42334 m .34759 .41874 L .34086 .39631 L p .771 .539 .583 r
F P
0 g
s
.6272 .2204 m .64127 .19866 L .61976 .18649 L p .661 .497 .652 r
F P
0 g
s
.61976 .18649 m .60519 .20767 L .6272 .2204 L p .661 .497 .652 r
F P
0 g
s
.33305 .55019 m .38076 .52212 L .37229 .49672 L p .813 .699 .739 r
F P
0 g
s
.38076 .52212 m .33305 .55019 L .34164 .57846 L p .83 .75 .775 r
F P
0 g
s
.69563 .26219 m .70781 .23917 L .68646 .22569 L p .765 .634 .716 r
F P
0 g
s
.69807 .20338 m .68646 .22569 L .70781 .23917 L p .78 .624 .688 r
F P
0 g
s
.60188 .26293 m .59114 .2822 L .61307 .29576 L p .663 .565 .734 r
F P
0 g
s
.10196 .46718 m .15922 .44876 L .15724 .42056 L p .551 .385 .609 r
F P
0 g
s
.15922 .44876 m .10196 .46718 L .10266 .49139 L p .571 .436 .658 r
F P
0 g
s
.60188 .26293 m .61394 .24214 L .59204 .22915 L p .636 .512 .695 r
F P
0 g
s
.60519 .20767 m .59204 .22915 L .61394 .24214 L p .648 .506 .676 r
F P
0 g
s
.66388 .21196 m .67684 .19051 L .65552 .17813 L p .711 .536 .65 r
F P
0 g
s
.65552 .17813 m .64127 .19866 L .66388 .21196 L p .711 .536 .65 r
F P
0 g
s
.63523 .30921 m .64746 .29074 L .6246 .2768 L p .696 .608 .755 r
F P
0 g
s
.6246 .2768 m .61307 .29576 L .63523 .30921 L p .696 .608 .755 r
F P
0 g
s
.16597 .51433 m .10401 .51686 L .10598 .54238 L p .581 .511 .742 r
F P
0 g
s
.10598 .54238 m .17059 .54887 L .16597 .51433 L p .581 .511 .742 r
F P
0 g
s
.28725 .3738 m .22432 .37841 L .22775 .40335 L p .708 .457 .543 r
F P
0 g
s
.22775 .40335 m .29236 .39652 L .28725 .3738 L p .708 .457 .543 r
F P
0 g
s
.61394 .24214 m .6272 .2204 L .60519 .20767 L p .648 .506 .676 r
F P
0 g
s
.68646 .22569 m .69807 .20338 L .67684 .19051 L p .745 .581 .671 r
F P
0 g
s
.68248 .28405 m .69563 .26219 L .67364 .2484 L p .751 .641 .739 r
F P
0 g
s
.67364 .2484 m .66042 .27034 L .68248 .28405 L p .751 .641 .739 r
F P
0 g
s
.68646 .22569 m .67364 .2484 L .69563 .26219 L p .765 .634 .716 r
F P
0 g
s
.2688 .60683 m .34164 .57846 L .33305 .55019 L p .769 .718 .805 r
F P
0 g
s
.22432 .37841 m .15621 .39664 L .15724 .42056 L p .634 .405 .553 r
F P
0 g
s
.61307 .29576 m .6246 .2768 L .60188 .26293 L p .663 .565 .734 r
F P
0 g
s
.67684 .19051 m .66388 .21196 L .68646 .22569 L p .745 .581 .671 r
F P
0 g
s
.26089 .57487 m .1758 .58206 L .18132 .61171 L p .682 .665 .827 r
F P
0 g
s
.18132 .61171 m .2688 .60683 L .26089 .57487 L p .682 .665 .827 r
F P
0 g
s
.10266 .49139 m .16214 .48042 L .15922 .44876 L p .571 .436 .658 r
F P
0 g
s
.16214 .48042 m .10266 .49139 L .10401 .51686 L p .58 .477 .701 r
F P
0 g
s
.61394 .24214 m .60188 .26293 L .6246 .2768 L p .673 .56 .718 r
F P
0 g
s
.10401 .51686 m .16597 .51433 L .16214 .48042 L p .58 .477 .701 r
F P
0 g
s
.70798 .73574 m .72829 .81847 L .75031 .80597 L p .821 .718 .751 r
F P
0 g
s
.75031 .80597 m .73754 .72221 L .70798 .73574 L p .821 .718 .751 r
F P
0 g
s
.62445 .86923 m .56347 .79365 L .53029 .80491 L p .606 .628 .846 r
F P
0 g
s
.56347 .79365 m .62445 .86923 L .65029 .85779 L p .664 .646 .822 r
F P
0 g
s
.64746 .29074 m .66042 .27034 L .63714 .25612 L p .707 .604 .739 r
F P
0 g
s
.63714 .25612 m .6246 .2768 L .64746 .29074 L p .707 .604 .739 r
F P
0 g
s
.65041 .23422 m .66388 .21196 L .64127 .19866 L p .698 .546 .677 r
F P
0 g
s
.64127 .19866 m .6272 .2204 L .65041 .23422 L p .698 .546 .677 r
F P
0 g
s
.67364 .2484 m .68646 .22569 L .66388 .21196 L p .732 .59 .698 r
F P
0 g
s
.6246 .2768 m .63714 .25612 L .61394 .24214 L p .673 .56 .718 r
F P
0 g
s
.6272 .2204 m .61394 .24214 L .63714 .25612 L p .685 .554 .7 r
F P
0 g
s
.34759 .41874 m .2988 .42334 L .3064 .45346 L p .78 .58 .629 r
F P
0 g
s
.3064 .45346 m .35528 .44366 L .34759 .41874 L p .78 .58 .629 r
F P
0 g
s
.63714 .25612 m .65041 .23422 L .6272 .2204 L p .685 .554 .7 r
F P
0 g
s
.66042 .27034 m .67364 .2484 L .65041 .23422 L p .719 .598 .72 r
F P
0 g
s
.65041 .23422 m .63714 .25612 L .66042 .27034 L p .719 .598 .72 r
F P
0 g
s
.66388 .21196 m .65041 .23422 L .67364 .2484 L p .732 .59 .698 r
F P
0 g
s
.15724 .42056 m .22775 .40335 L .22432 .37841 L p .634 .405 .553 r
F P
0 g
s
.32395 .51859 m .37229 .49672 L .36364 .47007 L p .8 .657 .704 r
F P
0 g
s
.37229 .49672 m .32395 .51859 L .33305 .55019 L p .813 .699 .739 r
F P
0 g
s
.70477 .635 m .67006 .57407 L .64432 .58071 L p .755 .524 .583 r
F P
0 g
s
.67006 .57407 m .70477 .635 L .73008 .62598 L p .789 .533 .55 r
F P
0 g
s
.52413 .60943 m .52805 .68993 L .56499 .67939 L p .602 .437 .631 r
F P
0 g
s
.56499 .67939 m .55385 .60267 L .52413 .60943 L p .602 .437 .631 r
F P
0 g
s
.33305 .55019 m .26089 .57487 L .2688 .60683 L p .769 .718 .805 r
F P
0 g
s
.35528 .44366 m .3064 .45346 L .31491 .48572 L p .79 .618 .669 r
F P
0 g
s
.31491 .48572 m .36364 .47007 L .35528 .44366 L p .79 .618 .669 r
F P
0 g
s
.36364 .47007 m .31491 .48572 L .32395 .51859 L p .8 .657 .704 r
F P
0 g
s
.67431 .75036 m .70357 .83169 L .72829 .81847 L p .783 .696 .768 r
F P
0 g
s
.72829 .81847 m .70798 .73574 L .67431 .75036 L p .783 .696 .768 r
F P
0 g
s
.76215 .71022 m .73008 .62598 L .70477 .635 L p .825 .629 .638 r
F P
0 g
s
.65029 .85779 m .60011 .78017 L .56347 .79365 L p .664 .646 .822 r
F P
0 g
s
.60011 .78017 m .65029 .85779 L .67715 .84503 L p .708 .661 .802 r
F P
0 g
s
.29236 .39652 m .22775 .40335 L .23244 .43295 L p .723 .509 .601 r
F P
0 g
s
.23244 .43295 m .2988 .42334 L .29236 .39652 L p .723 .509 .601 r
F P
0 g
s
.70477 .635 m .73754 .72221 L .76215 .71022 L p .825 .629 .638 r
F P
0 g
s
.49475 .69884 m .53029 .80491 L .56347 .79365 L p .573 .498 .732 r
F P
0 g
s
.56347 .79365 m .52805 .68993 L .49475 .69884 L p .573 .498 .732 r
F P
0 g
s
.22775 .40335 m .15724 .42056 L .15922 .44876 L p .655 .463 .612 r
F P
0 g
s
.26089 .57487 m .33305 .55019 L .32395 .51859 L p .76 .67 .763 r
F P
0 g
s
.63778 .76543 m .67715 .84503 L .70357 .83169 L p .746 .678 .784 r
F P
0 g
s
.70357 .83169 m .67431 .75036 L .63778 .76543 L p .746 .678 .784 r
F P
0 g
s
.67715 .84503 m .63778 .76543 L .60011 .78017 L p .708 .661 .802 r
F P
0 g
s
.67453 .64526 m .64432 .58071 L .61555 .58791 L p .721 .511 .605 r
F P
0 g
s
.64432 .58071 m .67453 .64526 L .70477 .635 L p .755 .524 .583 r
F P
0 g
s
.25286 .53925 m .17059 .54887 L .1758 .58206 L p .685 .623 .78 r
F P
0 g
s
.1758 .58206 m .26089 .57487 L .25286 .53925 L p .685 .623 .78 r
F P
0 g
s
.55385 .60267 m .56499 .67939 L .6031 .66799 L p .648 .47 .628 r
F P
0 g
s
.6031 .66799 m .5849 .59535 L .55385 .60267 L p .648 .47 .628 r
F P
0 g
s
.15922 .44876 m .23244 .43295 L .22775 .40335 L p .655 .463 .612 r
F P
0 g
s
.2988 .42334 m .23244 .43295 L .23831 .46637 L p .733 .552 .647 r
F P
0 g
s
.23831 .46637 m .3064 .45346 L .2988 .42334 L p .733 .552 .647 r
F P
0 g
s
.64021 .65641 m .61555 .58791 L .5849 .59535 L p .687 .493 .62 r
F P
0 g
s
.61555 .58791 m .64021 .65641 L .67453 .64526 L p .721 .511 .605 r
F P
0 g
s
.5849 .59535 m .6031 .66799 L .64021 .65641 L p .687 .493 .62 r
F P
0 g
s
.23244 .43295 m .15922 .44876 L .16214 .48042 L p .669 .509 .659 r
F P
0 g
s
.25286 .53925 m .32395 .51859 L .31491 .48572 L p .751 .629 .725 r
F P
0 g
s
.32395 .51859 m .25286 .53925 L .26089 .57487 L p .76 .67 .763 r
F P
0 g
s
.73754 .72221 m .70477 .635 L .67453 .64526 L p .786 .612 .664 r
F P
0 g
s
.24521 .50237 m .16597 .51433 L .17059 .54887 L p .683 .585 .74 r
F P
0 g
s
.17059 .54887 m .25286 .53925 L .24521 .50237 L p .683 .585 .74 r
F P
0 g
s
.3064 .45346 m .23831 .46637 L .24521 .50237 L p .742 .591 .687 r
F P
0 g
s
.24521 .50237 m .31491 .48572 L .3064 .45346 L p .742 .591 .687 r
F P
0 g
s
.67453 .64526 m .70798 .73574 L .73754 .72221 L p .786 .612 .664 r
F P
0 g
s
.31491 .48572 m .24521 .50237 L .25286 .53925 L p .751 .629 .725 r
F P
0 g
s
.16214 .48042 m .23831 .46637 L .23244 .43295 L p .669 .509 .659 r
F P
0 g
s
.23831 .46637 m .16214 .48042 L .16597 .51433 L p .678 .548 .7 r
F P
0 g
s
.52805 .68993 m .56347 .79365 L .60011 .78017 L p .632 .532 .723 r
F P
0 g
s
.60011 .78017 m .56499 .67939 L .52805 .68993 L p .632 .532 .723 r
F P
0 g
s
.16597 .51433 m .24521 .50237 L .23831 .46637 L p .678 .548 .7 r
F P
0 g
s
.70798 .73574 m .67453 .64526 L .64021 .65641 L p .75 .595 .683 r
F P
0 g
s
.64021 .65641 m .67431 .75036 L .70798 .73574 L p .75 .595 .683 r
F P
0 g
s
.56499 .67939 m .60011 .78017 L .63778 .76543 L p .677 .556 .711 r
F P
0 g
s
.63778 .76543 m .6031 .66799 L .56499 .67939 L p .677 .556 .711 r
F P
0 g
s
.67431 .75036 m .64021 .65641 L .6031 .66799 L p .715 .577 .699 r
F P
0 g
s
.6031 .66799 m .63778 .76543 L .67431 .75036 L p .715 .577 .699 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
      ImageSize->{288, 288},
      ImageMargins->{{0, 0}, {0, 0}},
      ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ROooo`d0002:
oooo001ooooo2P0000goool:0000P?ooo`00NOooo`H0000Qoooo1P0007[oool007Coool50000;Ooo
o`D0001eoooo001aoooo0`0003Ooool30000L_ooo`00KOooo`@0000moooo100006koool006[oool3
0000AOooo`<0001[oooo001Woooo0`0004_oool30000J?ooo`00I?ooo`<0001Aoooo0`0006Goool0
067oool30000Eoooo`<0001Roooo001Noooo0`0005goool30000Goooo`00Foooo`<0001Soooo0`00
05coool005Woool20000JOooo`80001Joooo001Goooo0P0006Soool00`000?ooooooo`02oooo0P00
05Soool005Goool20000G_oooa@0001Goooo001Coooo0P0005goool400000U8000@00002P@PB1000
00:J8AT80000E?ooo`00DOooo`80001Loooo1@00009B000200000X8I<`@00003W3<m0`0000>]?cP7
0000D_ooo`00D?ooo`030000oooooooo05[oool400000U804`<00002PQTc0P0000BK@EP300000je?
E`<00002^UA;00<0002g?b<000001000053oool004koool20000Foooo`@00002DP0C0P0000>09Th2
00001I]1F08000001:]JKP0000000:e?E`8000001;YSI`0000000;YDB`<000000l9@<00000000002
0000Coooo`00COooo`030000oooooooo05[oool4000000=B01<0000000000h0VCP800002VD]]0P00
0003Vd5H0000000000F[FVh200001;YSI`800002aFAF0P000004be`f000000000000C_ooo`00Booo
o`80001Loooo0`00009@02l200000X0VCP800006VD]]0P0000B[FVh200000[M]O08000001;YSI`00
0<AaLLAaL@8000001LETEP00000000000==T=0020000COooo`00BOooo`80001Loooo0`00009@02l2
00000Wd`HP<00005VD]]0P0000:XHgl2000000>[FVh0002gKG`01KM]O0800004a75a00<0003>L5c>
L5`01P0004_oool004Soool00`000?ooooooo`1Koooo0`00009@02l00`0007d`HWd`HP02OC1R00<0
002EDWbEDW`00P000003VD]]0000000000JXHgl200001KM]O0030000`G^4`G^4008000000lAaL@00
0<emM`03000000?GNE`000000000100004Woool004Koool20000GOooo`<000000e00;`0000000003
OC1R0P0000FEDW`00`000:QSOjQSO`05Z6=o00<0002cLh^cLh/00P0000:gKG`00`000<5kQ<5kQ003
`G^400<0003=OGO=OGL00/emM`050000egULegUL0000gh1F008000000oooo`0000000017oooo0015
oooo00<0003oooooool0G?ooo`800002C@160`00009m<6800`0009EBO9EBO004UE9l00@0002TJ8`0
00000004Z6=o00<0002cLh^cLh/00k=cR`800006`G^40`0000;=OGL4000000COP5H0000000000002
oooo00<0003oooooool0A?ooo`00A?ooo`030000oooooooo05coool200000Td0AP040000NCQbNCQb
NCQb0P0000JEDW`00`000:AXS:AXS002Y6R<0P000003Z6=o0000/g>;00FcLh/010000;f1T`000000
00?1Nh@010000<Z6R/Z6R/Z6RP800003eXQh0P000004gh1F0000000000000_ooo`030000oooooooo
04?oool004?oool00`000?ooooooo`1Loooo0P00009=04H00`0007ThLWThLP02NCQb00@0002AF8P0
00000004UE9l00<0002TJ8bTJ8`01:AXS0800006/g>;00@0002mPI>mPI>mPI<2000000?1Nh@0003:
QXX00lZ6RP800002eXQh00<0003PTGH000000`0000?oool00`000?ooooooo`12oooo0012oooo00<0
003oooooool0G?ooo`800002C@1600<0001i>79i>7800WThLP030000TER8TER800:AF8P2000000>E
DW`0002TJ8`01JAXS0030000/7RF/7RF00<00002/g>;00<0002mPI>mPI<01;f1T`030000bXJ:bXJ:
00?:QXX00`000=>AS@00000200000^2AMP@00003oooo00<0003oooooool0@Oooo`00@?ooo`80001N
oooo0`000003C@160000NCQb00Ai>7800`00095HR95HR004TER80P0000FTJ8`00`000;1hU[1hUP04
/7RF0P0000JmPI<010000<J=V000000000?:QXX01@000=>ASM>ASM>AS@000002h95f00@0003ZV6`0
00000004oooo0P00047oool003ooool00`000?ooooooo`1Moooo0P00009925P2000017ThLP030000
TER8TER800BAF8P00`000:5]UZ5]UP0200000ZAXS0030000/7RF/7RF00F`N9H00`000;V5W@000005
_H6C00@00036SIS6SIS6SIP300001=>AS@@000001>ZHK0000000000000Goool00`000?ooooooo`0n
oooo000noooo00<0003oooooool0GOooo`05000000010000B@QH0000009e?Gh2000000=i>780002A
F8P01I5HR0030000XFfFXFfF00>QKIH200002;1hUP030000^HFM^HFM00800002_H6C00<00036SIS6
SIP01<J=V0030000di6=di6=00;CTHd020000=fLS=fLS0000>ZHK0000?>LEP0000Koool00`000?oo
ooooo`0moooo000moooo00<0003oooooool0GOooo`<00002B@QH00<0001e?Gie?Gh00WDmOP800005
TER800<0002QKIJQKIH01:5]UP040000[7bO000000001K1hUP030000^HFM^HFM00>iQId00`000;f1
T`000006aXfH0`000003di6=0000gIb<00;MW8`2000000CZV6`0000000000006oooo00<0003ooooo
ool0??ooo`00??ooo`030000oooooooo05koool200000TT8F0030000MCenMCen009e?Gh00`0008iL
TXiLTP0200000Y5HR0030000XFfFXFfF00BQKIH00`000:alWjalW`02[7bO00D0002`N9J`N9J`N9H0
00001kV5W@800005aXfH00@0003?V9_?V9_?V9/200000mfLS0030000jJJ7000000<00007oooo00<0
003oooooool0>oooo`00>oooo`030000oooooooo05koool01@0000000@0004T8F0000004MCen00<0
002>G9:>G9800hiLTP800007XFfF00<0002/O9n/O9l00jalW`8000000k1hUP000;V5W@05^HFM00<0
0032TJ?2TJ<00P0000?6SIP00`000<nHVlnHV`02ciRK0P0000;MW8`00`000>VVQnVVQ`0400001ooo
o`030000oooooooo03[oool003[oool00`000?ooooooo`1Noooo10000003B@QH0000MCen00=e?Gh0
0`0008iLTXiLTP03SUbB00@0002ML9h000000004XFfF00<0002/O9n/O9l01ZalW`800006^HFM00<0
0032TJ?2TJ<00/:AX`<00005ciRK00<0003IXid000000P0000;YYXL010000?F_N@00000000Soool0
0`000?ooooooo`0ioooo000ioooo00<0003oooooool0G_ooo`030000000H000000943fH300000WDm
OP030000SUbBSUbB00B>G980100009e`WYe`WYe`WP8000000j5]UP000:alW`07[7bO00<0002fRJJf
RJH00P0000>iQId00`000<:AXl:AX`05`Y6S00<0003?V9_?V9/00lnHV`050000fJ>MfJ>MfJ>M0000
00;YYXL00`000?F_N@00000200002?ooo`030000oooooooo03Soool003Soool00`000?ooooooo`1O
oooo00D0000001P000143fH000000g52R0800006SUbB00<0002ML9jML9h019e`WP030000[7bO[7bO
00N/O9l00`000;J9Y[J9YP02]XVV0P000003^HFM0000`Y6S00K2TJ<300000/nHV`030000fJ>MfJ>M
00;IXid3000000GYYXL00000003k/EH000002Oooo`030000oooooooo03Ooool003Ooool00`000?oo
ooooo`1Ooooo00<0000001P000000T@?IP060000LD:8LD:8LD:80000RUnJ0P0000>>G9800`0009e`
WYe`WP04WG2N00@0002YOjH000000006[7bO00<0002fRJJfRJH01KJ9YP030000`Y6S`Y6S00G2TJ<0
10000<^LYl^LYl^LY`<00004fJ>M00<0003U[i_U[i/00`000003nk5F0000oooo00Woool00`000?oo
ooooo`0foooo000foooo00<0003oooooool0H?ooo`800002A0mV00<0001a@XQa@XP00W52R0040000
RUnJRUnJRUnJ0P000003SUbB0000WG2N00FML9h010000:UoYZUoYZUoYP800003[7bO00<0002fRJJf
RJH01KJ9YP040000_YB[000000001L:AX`030000bibWbibW00?;W:L00`000=VSWMVSW@02fJ>M00H0
003U[i_U[i_U[i/0003e[gT200002oooo`030000oooooooo03Goool003Goool00`000?ooooooo`1P
oooo00D0000001P000143fH000001752R0030000RUnJRUnJ00B:GiX00`0009e`WYe`WP04WG2N00<0
002YOjJYOjH01:UoYP8000000jalW`000;J9YP06]XVV00D0002nU:^nU:^nU:/000000l:AX`030000
bibWbibW00C;W:L3000000?IXid0003U[i/00nF_V`@0000<oooo00<0003oooooool0=?ooo`00=?oo
o`030000oooooooo067oool01@00:P00000004@?IP000003LD:800<0002:GiZ:GiX018YOVP040000
VW:U000000000ie`WP030000ZGnVZGnV00NYOjH200001[J9YP030000_YB[_YB[00>nU:/2000000?2
TJ<0003;W:L01<^LY`040000eJRYeJRYeJRY0P0000CU[i/01@000?>lT`000?^aEP00000<oooo00<0
003oooooool0<oooo`00<oooo`030000oooooooo067oool200000T0DL@<00002LD:800<0002:GiZ:
GiX018YOVP040000VW:UVW:UVW:U0P000003WG2N0000ZGnV00NYOjH00`000;:;[K:;[@0200000kJ9
YP030000_YB[_YB[00JnU:/00`000<^LYl^LY`04bibW00<0003EZ:WEZ:T00]FXZ@030000iJnKiJnK
00;U[i/00`000?>lT`00000200003Oooo`030000oooooooo03;oool003;oool00`000?ooooooo`1R
oooo00D002X000105750574000000Ve5T0800006RUnJ00<0002JLZFJLZD019YbY@030000ZGnVZGnV
00NYOjH00`000;:;[K:;[@02/X^]0P000003]XVV0000_YB[00NnU:/300001<^LY`030000eJRYeJRY
00;EZ:T3000000OU[i/0003c_9?c_9<0003oag`000003_ooo`030000oooooooo037oool0037oool0
0`000?ooooooo`1Roooo0P00009057400`0006e5T6e5T002KDF@0`0000>:GiX00`0009YbYIYbY@04
VW:U00@0002UPJd000000006ZGnV00<0002bRjfbRjd01K:;[@030000_YB[_YB[00JnU:/01@000<NO
/<NO/<NO/0000003bibW00<0003EZ:WEZ:T00]FXZ@030000hKFZhKFZ00800002lkbC00<0003oag`0
00003oooo`030000oooooooo033oool0033oool00`000?ooooooo`1Soooo0P00009057401@0006e5
T6e5T6e5T0000003QV6P0P000003RUnJ0000VW:U00FJLZD010000:F1[JF1[JF1[@800003ZGnV00<0
002bRjfbRjd01K:;[@040000^iNb000000001[jDZ`030000ain`ain`00;7Wk0300001MFXZ@050000
hKFZhKFZhKFZ000000;c_9<00`000?o7O000000@oooo00<0003oooooool0;oooo`00;oooo`030000
oooooooo06?oool3000000=05740001]AI000fe5T0030000QV6PQV6P00>6HJ000`0009YbYIYbY@04
VW:U00<0002UPJfUPJd01:F1[@8000000jUoYP000;:;[@06/X^]00@0002kUk:kUk:kUk8200000kjD
Z`030000ain`ain`00G7Wk000`000=FXZMFXZ@02eJRY00<0003Q]J[Q]JX00^6eZP@000000oo7O000
0?ooo`0@oooo00<0003oooooool0;_ooo`00;_ooo`030000oooooooo06Coool00`00>00003`HNP02
00000fe5T0030000QV6PQV6P00B6HJ0300000iYbY@030000YH6]YH6]00NUPJd00`000;:;[K:;[@05
/X^]00<0002kUk:kUk801;^G/P8000000kjDZ`000<NO/006ain`0`0000;EZ:T00`000>6eZ^6eZP02
hKFZ00H0003^a:O^a:L0003oag`0000Boooo00<0003oooooool0;Oooo`00;_ooo`030000oooooooo
06?oool200000c`HNP<000000fe5T00008IQX004QV6P00@0002GM:ZGM:ZGM:X2000000>JLZD0002U
PJd01jF1[@040000[hfc000000001K:;[@030000^iNb^iNb00JkUk800`000<NO/<NO/005ain`00@0
003AZk?AZk?AZk<300001>6eZP030000k/BWk/BW00@0000Aoooo00<0003oooooool0;Oooo`00;Ooo
o`030000oooooooo06Coool200000S`HNP050000JDNFJDNFJDNF000000J6HJ000`0009MdZYMdZP03
UgBZ00<0002UPJfUPJd01jF1[@050000[hfc[hfc[hfc000000>bRjd00`000;^G/[^G/P06^iNb00@0
0033X[L000000005ain`00<0003AZk?AZk<00m6[/`050000hKFZhKFZhKFZ000000?^a:L010000?gF
V@00000001;oool00`000?ooooooo`0/oooo000/oooo00<0003oooooool0I?ooo`030000000h0000
008l67X0100006U7UVU7UVU7UP<00003QV6P00<0002GM:ZGM:X019MdZP<00006YH6]00<0002_SK>_
SK<00jn=/`8000000k:;[@000;^G/P07^iNb00D00033X[O3X[O3X[L000000lNO/0030000dJ^cdJ^c
00CAZk<3000000?Q]JX0003^a:L00^k4Y`040000oMJI000000004oooo`030000oooooooo02_oool0
02_oool00`000?ooooooo`1Uoooo0P0000<l67X0100006U7UVU7UP0000>3HjD2000000>6HJ00002G
M:X019MdZP040000XX>aXX>aXX>a0P0000>UPJd00`000:n=/jn=/`06[hfc00<0002kUk:kUk801[^G
/P030000`j:g`j:g00?3X[L2000000?7Wk00003AZk<01=6[/`040000g;Vfg;Vfg;Vf0P0000;^a:L0
0`000?gFVOgFV@0200005?ooo`030000oooooooo02[oool002[oool00`000?ooooooo`1Voooo00D0
04<00000000l67X000000fU7UP030000Pf>UPf>U00>3HjD00`0009MdZYMdZP04UgBZ00<0002RPk6R
Pk400j:3/@8000000jF1[@000:n=/`06[hfc00@0002hVKP000000006^iNb00<00033X[O3X[L01L>R
]`030000dJ^cdJ^c00CAZk<00`000=bi]]bi]P02g;Vf00@0003^a:O^a:L00002oMJI0P0001Goool0
0`000?ooooooo`0Yoooo000Yoooo00<0003oooooool0Ioooo`0300130000>1^100800003JDNF00<0
0023HjF3HjD00h=SY@<00003UgBZ00<0002RPk6RPk401Z:3/@030000[hfc[hfc00J_SK<010000;RI
^;RI^;RI^0800003^iNb00<00033X[O3X[L01L>R]`030000cJjk000000CAZk<00`000=bi]]bi]P03
g;Vf10000004oMJI0000lM=R00005_ooo`030000oooooooo02Soool002Soool00`000?ooooooo`1X
oooo00@004<0000h6h4h6h4400001H=SY@040000TgJ_TgJ_TgJ_0P000003UgBZ0000XX>a00JRPk40
10000:b?]`00000000F_SK<00`000;RI^;RI^004^9Vh0P000003^iNb0000`j:g00K3X[L00`000<f^
^lf^^`0200000]6[/`030000g;Vfg;Vf00;L^KH02@000>W:]^W:]^W:]P000?gFV@000?7CHP00000G
oooo00<0003oooooool09oooo`00:?ooo`030000oooooooo06Ooool200000SPKP@050000ITVKITVK
ITVK000000F3HjD00`0009=f[i=f[`03TgJ_00<0002RPk6RPk401Z:3/@050000[8ng[8ng[8ng0000
00>_SK<00`000;RI^;RI^007^9Vh00<00033X[O3X[L01L>R]`030000cJjkcJjk00?=[[/200001Mbi
]P040000jLZfjLZfjLZf100001Soool00`000?ooooooo`0Woooo000Woooo00<0003oooooool0J?oo
o`800002>1^100@0001VBI]VBI]VBI/300000X=SY@030000TgJ_TgJ_00BCMZl300001J:3/@030000
[8ng[8ng00>/SkL2000000>_SK<0002hVKP01kRI^0040000`:Bm000000001L>R]`030000cJjkcJjk
00C=[[/00`000=bi]]bi]P03g;Vf00H0003Yb[KYb[KYb[H0003hgjl200006Oooo`030000oooooooo
02Koool002Koool00`000?ooooooo`1Yoooo100000=VBI/01`00081TZH1TZH1TZ@0008=SY@000005
TgJ_00D0002OQ;JOQ;JOQ;H000000j:3/@030000[8ng[8ng00J/SkL00`000;RI^;RI^007^9Vh00D0
0030Y;g0Y;g0Y;d000000l>R]`030000cJjkcJjk00G=[[/300000mbi]P040000jLZfjLZf00000_SO
[`80000Joooo00<0003oooooool09Oooo`009_ooo`030000oooooooo06Woool01000BP0003@LQ@00
00=VBI/00`00081TZH1TZ@02P6BY00<0002CMZnCMZl019=f[`030000WhBfWhBf00:OQ;H2000000>R
Pk40002/SkL01jb?]`<00006^9Vh00<00030Y;g0Y;d00l2T_@8000000l>R]`000<f^^`05cJjk00@0
003G_;oG_;oG_;l300000nW:]P050000n=n_0000l^N5000001[oool00`000?ooooooo`0Uoooo000U
oooo00<0003oooooool0J_ooo`03001:0000=1b500@00005P6BY0`0000>CMZl00`0009n4]Yn4]P05
WhBf00<0002/SkN/SkL01Zb?]`040000]9Zm]9Zm]9Zm0P0000>hVKP00`000<2T_L2T_@06`:Bm0P00
00K=[[/00`000=Nl_mNl_`03ekbo00T0003Yb[KYb[KYb[H0003hgjl0003bihD000006oooo`030000
oooooooo02Coool002Goool00`000?ooooooo`1Yoooo0P00008d78D0100006=:WV=:WP0000B0I:T0
1000095g/Y5g/Y5g/P8000000i=f[`0009n4]P05WhBf00@0002YT;/000000006[8ng00<0002dV[fd
V[d00kBJ_@8000000kRI^0000<2T_@06`:Bm00<00038/<;8/<800P0000?=[[/00`000=Nl_mNl_`03
ekbo00<0003Sc/8000000^W:]P040000n=n_000000007?ooo`030000oooooooo02Coool002Coool0
0`000?ooooooo`1Zoooo0P000003=1b50000HdZN009SBYh300000X1TZ@030000TGNbTGNb00>AMk82
00001Yn4]P040000ZI2kZI2kZI2k0P0000>/SkL00`000;BJ_KBJ_@06]9Zm00<00030Y;g0Y;d01/2T
_@030000b;32b;3200;8/<82000000?=[[/0003G_;l01=Nl_`030000hlk2hlk200800002n=n_0P00
01goool00`000?ooooooo`0Soooo000Soooo00<0003oooooool0Joooo`04001>0000000000000V=:
WP040000OFF/OFF/OFF/0P0000JAMk80100009f5^@00000000>OQ;H00`000:V@^jV@^`04ZI2k0P00
0003[8ng0000]9Zm00JdV[d010000;fU`P00000000G0Y;d00`000<R``/R``P05b;3200<0003G_;oG
_;l00mNl_`030000hlk2hlk200;Sc/83000000?bihD0003oool07Oooo`030000oooooooo02;oool0
02?oool00`000?ooooooo`1[oooo00@004h0000a7HP00002HdZN00<0001mIJamIJ`00WeU[0030000
TGNbTGNb00>AMk800`0009f5^If5^@02WHFi0P000003WhBf0000ZI2k00NYT;/00`000;BJ_KBJ_@06
]9Zm00D0002mYL:mYL:mYL8000000l2T_@030000b;32b;3200G8/<800`000=:naP000004ekbo00<0
003Sc/;Sc/800^?>`P050000lNBo0000l^N5000001koool00`000?ooooooo`0Roooo000Roooo00<0
003oooooool0Joooo`040000001>0000<Af80`0000EmIJ`300000i5g/P030000WHFiWHFi00BMQKT0
0`000:V@^jV@^`06ZI2k00@0002bVl4000000005]9Zm00<0002mYL:mYL800kfU`P8000000l2T_@00
0<R``P06b;3200@0003B_/KB_/H00002ekbo00<0003Sc/;Sc/800^?>`P050000lNBolNBo0000l^N5
023oool00`000?ooooooo`0Qoooo000Roooo00<0003oooooool0Joooo`800002<Af800@0001PBZ40
00000003OFF/00@0002>MkF>MkF>MkD300001if5^@<00005ZI2k00<0002bVl6bVl400[:K`@050000
]9Zm]9Zm]9Zm000000RmYL800`000<R``/R``P05b;3200<0003B_/KB_/H00]:naP030000ekbo0000
00CSc/801@000?7T_`000>kdXP00000Poooo00<0003oooooool08Oooo`008Oooo`030000oooooooo
06coool01000D00000000000009PBZ401P0007]U[P00000007eU[00000F>MkD00`0009f5^If5^@04
WHFi00D0002WTKnWTKnWTKl000001:V@^`030000/Y_1/Y_100>bVl42000000>dV[d0002mYL801kfU
`P<00005b;3200<0003B_/KB_/H00m:naP800003hlk200H0003ai;oai;l0003^m:80000Qoooo00<0
003oooooool08?ooo`008Oooo`030000oooooooo06coool01000D00002lMR@00009PBZ401@0007]U
[W]U[W]U[P000006SWNe0P0000FMQKT00`000:NA_jNA_`02Yi6o0P000003ZI2k0000/Y_100NbVl40
0`000;fU`[fU`P06_JG200D00035/LO5/LO5/LL000000lR``P030000d[k6d[k600CB_/H02P000=k@
b`0000000>?>`P000?7T_`000>kdXP0002;oool00`000?ooooooo`0Poooo000Poooo00<0003ooooo
ool0K?ooo`800002;af90`0000AkIJh300000hig]@030000VhFlVhFl00800002WHFi00<0002WTKnW
TKl01JNA_`030000/Y_1/Y_100JbVl4010000;ZVaP00000000JmYL800`000<FaalFaa`02aK770P00
0003b;320000d[k600CB_/H00`000=k@bmk@b`02g]3;00H0003ai;oai;l0003^m:80000Soooo00<0
003oooooool07oooo`008?ooo`030000oooooooo06coool400000Ui:XP800003NfF^00<0002<MkN<
MkL00P000003SWNe0000VhFl00>KQK`00`0009f5^@000006Yi6o00@0002_W<@000000006/Y_100@0
002jY/JjY/JjY/H200000kfU`P030000aK77aK7700G5/LL00`000=:na]:naP04d[k600X0003Nd<_N
d<_Nd</0003Zj<`0003ai;o^m:80000Toooo00<0003oooooool07oooo`007oooo`030000oooooooo
06goool2000000H^78T0001NBZ9NBZ80001iIJl300001Hag]`030000VhFlVhFl00BKQK`200001ZNA
_`040000[ic4[ic4[ic40P0000>bVl400`000;ZVa[ZVaP04^ZK60P000003_JG20000aK7700G5/LL0
10000<k0c@00000000?B_/H00`000=k@bmk@b`02g]3;00H0003Zj<cZj<`0003^m:80000Uoooo00<0
003oooooool07_ooo`007oooo`030000oooooooo06goool2000000@^78T0000000000004NFF_00<0
002<MkN<MkL00hag]`800005VhFl00@0002UT/8000000003Yi6o00<0002_W<B_W<@01:nLa0800000
0k:K`@000;ZVaP07^ZK600<00035/LO5/LL01<Faa`030000c/3=c/3=00;>`<d2000000?B_/H0003N
d</00]k@b`060000j^S<j^S<0000i_^g00009_ooo`030000oooooooo01koool001koool00`000?oo
ooooo`1^oooo0P000004;Qb90000GDVR000017UU[`800003S7Ng00<0002IQ[jIQ[h00P0000:KQK`0
0`000:FB`ZFB`P02YI;20P000003Yi6o0000[ic400N_W<@00`000;ZVa[ZVaP06^ZK600@00032/l/0
00000004aK7700<0003>`<g>`<d01<k0c@050000g]3;g]3;g]3;000000?Zj<`20000:?ooo`030000
oooooooo01goool001koool00`000?ooooooo`1^oooo00<004l0000000000Ue9XP800002NFF_00@0
002;MkR;MkP00002S7Ng00<0002IQ[jIQ[h00YV6_P030000VhFl000000JUT/800`000:nLa:nLa006
[ic400@0002gZ<T000000005^ZK600<00032/l_2/l/00/:cb`8000000lFaa`000<k0c@05c/3=00H0
003Hd]800000003Nd</00002j^S<00<0003VnkL00000:?ooo`030000oooooooo01goool001goool0
0`000?ooooooo`1_oooo00<004l^6hP000000Ue9XP050000N6B`0000NFF_000000>;MkP200001YV6
_P030000YI;2YI;200FUT/8300001ZnLa0050000]jS9]jS9]jS9000000BjY/H00`000<:cbl:cb`04
`[?;00<0003>`<g>`<d01<k0c@030000f=;Bf=;B00;Hd]801P000>[Xc>[Xc0000>Kk]`0002[oool0
0`000?ooooooo`0Loooo000Moooo00<0003oooooool0Koooo`030000;Q^8000000800003N6B`00<0
002;MkR;MkP00h]g^0030000VHJnVHJn00BIQ[h300001:FB`P040000[Ig7[Ig7[Ig70P0000>_W<@0
0`000;NXbKNXb@03]jS90P000003^ZK60000`[?;00G2/l/010000<[1d@00000000C>`<d020000=SB
d]SBd]SBdP000>?ZeP000>[Xc080000[oooo00<0003oooooool07?ooo`007?ooo`030000oooooooo
073oool200000Ua8X@040000N6B`N6B`N6B`0`0000:;MkP0100009N6_`00000000>IQ[h01@000:>B
a:>Ba:>Ba0000003YI;200<0002]WLN]WLL00jfMa`8000000jnLa0000;NXb@06]jS900<00032/l_2
/l/01<:cb`030000b/7Ab/7A00;:`M42000000?>`<d0003Hd]800]SBdP070000hn[Fhn[Fhn[F0000
i_^g000002coool00`000?ooooooo`0Koooo000Loooo00<0003oooooool0Koooo`@000000ea8X@00
0000000200000hUg^@030000RgNh000000>GQ[l2000000>IQ[h0002ST/@00j>Ba0<00008[Ig700<0
002gZ<VgZ<T01KNXb@040000_kC?000000001<:cb`030000b/7Ab/7A00C:`M400`000=SBd]SBdP02
f=;B00H0003Sj]KSj]H0003Lo/L0000]oooo00<0003oooooool06oooo`006oooo`030000oooooooo
02[oool;0000>oooo`<000000ee7X00007MT[`02MfB_00<00029MkV9MkT00XUg^@030000UhJoUhJo
00BGQ[l00`000:>Ba:>Ba005Xi;40P0000J]WLL010000;FYc000000000BgZ<T00`000;ndckndc`02
_kC?0P000003`[?;0000b/7A00G:`M401P000=?Cf00000000=SBdP0000;Sj]H00`000=cna`00000_
oooo00<0003oooooool06_ooo`006oooo`030000oooooooo023ooolI0000=oooo`040000<QZ40000
GDNP0P00009gI:l200000XUg^@030000UXK0000000FGQ[l200001J>Ba0030000[9k9[9k900800004
[Ig700@0002eZLbeZLbeZL`2000000>gZ<T0002o]<l01[ndc`030000b/7Ab/7A00C:`M400`000=?C
f=?Cf002dm?H00@0003Sj]KSj]KSj]H20000<?ooo`030000oooooooo01[oool001_oool00`000?oo
ooooo`0Loooo0P00008F000:000028dG70030000YBXIYBXI00P0000coooo00@0000b6X@000000002
Mf>^0P0000:8MkT00`0008Ug^@000002UXK00P0000:GQ[l00`000:6CaJ6Ca@0200000j>Ba0030000
[9k9[9k900:/W/T2000000>]WLL0002eZL`01KFYc0800006_kC?00@00037`]H000000004b/7A00/0
003CdmSCdmSCdmP0003Ljmh0003Sj]H0003Lo/L00000<?ooo`030000oooooooo01[oool001[oool0
0`000?ooooooo`0Joooo0P0000045P000000000000000VH06`030000SALLSALL00j=5a`00`000:DZ
6JDZ6@04YBXI1000009c00030000;_ooo`04=AV00000H4RN00000gMS[P050000R7NiR7NiR7Ni0000
00FFQ/000`0009N6_`000004XI?500<0002ST/@000001jbNb@030000]JW<]JW<00BeZL`00`000;fe
d[fedP0200001;ndc`040000al;Fal;Fal;F0P000003b/7A0000dm?H00;CdmP01`000=c[g]c[g]c[
gP000=cna`00000boooo00<0003oooooool06Oooo`006_ooo`030000oooooooo01Ooool6000016H0
6aH00007YBXI200002[oool0100003DIP0000618WP<000000gMS[P0000000002R7Ni0P0000FFQ/00
0`000:6CaJ6Ca@04XI?50P0000J/W/T010000;>Zc`00000000BeZL`00`000;fed[fedP02_KGB0P00
0003_kC?0000al;F00G7`]H00`000=?Cf=?Cf002dm?H00H0003LjmkLjmh0003Com80000coooo00<0
003oooooool06Oooo`006_ooo`030000oooooooo01?oool600001FH06`<000000hTbE`000:E7EP0?
YDMF00@0002gE56gE56gE54700000ZDZ6@030000/S@D000000H0000Woooo00@j67`0001SAi`00003
NV>]00<00028M[R8M[P00P0000:EQ/4200000YJ6`0040000X9?7000000000j6Ca@030000ZYo;ZYo;
00800004[9k900@0002cZ/ncZ/ncZ/l2000000>eZL`0002m]M801[fedP030000al;Fal;F00C7`]H0
1P000<oDg@0000000=?Cf00000;Ljmh00`000=?odP00000doooo00<0003oooooool06Oooo`006Ooo
o`030000oooooooo01;oool500001FH06`<00004RC9G00<0002UAeJUAeH03ZE7EP030000]eAA]eAA
00RgE54500000k8d50<000000hH000000000000Soooo00@0000j67`0001SAi`2000000AjHjd0002;
M[L00002R7Jh00<0002EQ/6EQ/400YF6`@030000UXK0000000>PTlL2000000>QTlD0002ZWl/00jZO
b`8000000jbNb@000;>Zc`05/j[?00<0002m]M:m]M801KfedP040000a<?I000000000lO2eP030000
cmCMcmCM00;?e=d2000000CLjmh0003Com80000foooo00<0003oooooool06?ooo`006Oooo`030000
oooooooo013oool300001FH06`@00007RC9G00<0002UAeJUAeH03jE7EP030000]eAA]eAA00ZgE540
0`000<5KB`00000200001;8d50@0000Qoooo00@00380001VAiT00002O6>[00P0002;M[N;M[L00028
M[P0002DQL000004UHK100<0002PTlNPTlL01:2Ca`800006ZYo;00<0002cZ/ncZ/l01;>Zc`040000
^kKE000000001;fedP030000a<?Ia<?I00;4`mT00`000<O2eP000004cmCM00D0003Ek>CEk>@0003C
om800P0003Koool00`000?ooooooo`0Hoooo000Ioooo00<0003oooooool03oooo`0300009`0?0000
00=V01/300002XTbEa/00006]eAA00@00031Fd_1Fd_1Fd/3000000>b=1@0002h>A40100001ooool2
000000AVAiT00000001lHj/200000X]f]`050000U8G0U8G0U8G0000000:EQ/400`0009nDb0000005
X9?700@0002YX<d000000003ZYo;00@0002bZm4000000004/j[?00@0002k]]Fk]]Fk]]D2000000>m
]M800034`mT01LC3f@030000cmCMcmCM00;?e=d01@000=G/i=G/i0000<WofP020000=oooo`030000
oooooooo01Soool001Soool00`000?ooooooo`0?oooo00@0000W00l0001V01/300002XTbE`<00000
0iUBN0000:mSMP0@[f=f00<0002nK76nK7401Ki/L@P00005`E];0`0000:h>A42000000>>0000003o
ool06oooo`040000AQQaJdNE00000WiRZ0050000S7JeS7Je0000RgJg00800003U8G000<0002EQ/40
00000YnDb0800002X9?700<0002YX<fYX<d00ZVPc@8000000jZOb`000;:[d@02/Z_A0P000003/j[?
0000^kKE00Fk]]D200001<C3f@8000001LcEh@0000000<oDg@000002eNcT00@00039omX00000000i
oooo00<0003oooooool05oooo`006?ooo`030000oooooooo00goool200000RL03`80000:RC9G0`00
00BIDWP00`000:mSMZmSMP0?[f=f00<0002nK76nK7402ki/L@030000ag9/000000800003`E];00<0
0036GTP000000P0000:h>A4300006_ooo`08CaQZ00000000PV:U0000OV:XSWFc00000Xaf]@030000
UXFo000000BDQL000`0009nDb9nDb003WiC800<0002PTlL000001ZVPc@030000/Z_A/Z_A00BbZm42
00001K^fe@030000`/CL`/CL008000000lC3f@000<cEh@04c=GQ0P000003eNcT0000bOoJ0080000j
oooo00<0003oooooool05oooo`006?ooo`030000oooooooo00coool2000000@W00l0001K3e000007
RC9G100000NIDWP00`000:mSMZmSMP0@[f=f00<0002nK76nK7402[i/L@030000ag9/ag9/00;7LV`3
000000?1Fd/00036GTP00/INB0<000001;Tj4@000000000001Ooool3000000N6Hj800022HZD0002>
MK<0002<M[D00P0000:FQKl01P0009B5`000000009nDb@0000FOU<P200001ZVPc@<00003/Z_A00<0
002j]mNj]mL00P0000:k]]D00`000<;4g<;4g003`/CL00<0003<eN7<eN400/cEh@800002d>cX00<0
0039omX00000??ooo`030000oooooooo01Ooool001Ooool00`000?ooooooo`0<oooo00@0000W00lW
00l00002F`m@00<00029<UN9<UL00XTbE`<0000<VE9h00<0002_HgJ_HgH03jmSMP030000_Vaa_Vaa
00^nK7400`000<MbK<MbK004ag9/0`0000C6GTP300000[Tj4@<0000Boooo0`000003MTR<0000QV>R
00<000000hie/`0000000002UhBm00@0002FQKnFQKl00004WiC90P0000:OU<P00`000:VQcZVQcP02
00000jVPc@040000/ZcB/ZcB/ZcB0P000003/Z_A0000^[OG00>j]mL300001<;4g0060000bMKT0000
0000c=GQ00000]3/j08000000l;ng`000?ooo`0moooo00<0003oooooool05_ooo`005oooo`030000
oooooooo00[oool200000RL03`060000F`m@F`m@F`m@0000RC9G0`0000nIDWP00`000:mSMZmSMP06
[f=f4@0000JnK7400`000<MbK<MbK006ag9/1@000003aUi80000aem7008000000kTj4@000;Hi5004
00003Oooo`0;0000HaYK0000ODV70000Rf>N0000TgF^0000T7F`000000:HQ;/01`0009N4_@0009J5
_`000::Ea`000005WiC900<0002OU<P000001:VQcP8000000jVPc@000;:/dP04/ZcB0P0000Bj]mL0
0`000<75g/75gP02000000?2a=`00039e^@00lWFi08000000m3/j0000<;ng`020000?oooo`030000
oooooooo01Koool001Ooool00`000?ooooooo`09oooo0P0000039`0?0000000000AK3e02000049UB
N0/00009]GB;00<00032OHK2OHH01L9mQP`00003ag9/00<0003<MFS<MFP00/aeJ0T000000kHi5000
0000000300002?ooo`T0000029=e[P00000009Z3^@0009R4^`0009N4_@800002XYG700<0002OU<VO
U<T019nDb@800006ZJ7>0P0000Bb[=800`000;Vhf;Vhf00200000[Zge`030000`LGN`LGN00;1aMh2
00000/WFi0800002c>c[00<00032o]l00000@Oooo`030000oooooooo01Koool001Koool00`000?oo
ooooo`09oooo00@0000W00lW00l00004F`m@00<0001f=g@000003IUBN0@00002XVN=00<0002eM8^e
M8/03kEdR`030000`Wf6`Wf600_2OHH00`000<^2PL^2P@03bh:11P0000?<MFP010000<efJ<efJ<ef
J18000003gXPB@0008e<N`0009MUUP0009afY`0009QeZ`0009f3]`0009Z3^@0009R4^`02000000>O
TLD0002RULL00Z:Ea`030000WiC9WiC900:OU<T00`000:VRcjVRc`0200000jVQcP030000/ZgC/ZgC
00800002/ZcB00<0002i^=Ri^=P00[Vhf0800004`LGN00<00037enK7enH00`000005c>c[00000000
^ocS000004?oool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool01oooo`8000000bL03`00
00000003F`m@0P00009f=g@00`0009UBN9UBN007VE9h100000JRIhd00`000;EdRkEdR`0?]GB;00<0
0032OHK2OHH02l9mQP030000bh:1bh:100O;PX400`000<n4OP000002000000?<MFP0003=MVP00lef
J0040000bgEZ000000000/1LD100000019afY`000000000000:MPkL01IZ3^@00000009n?``000002
Wi7500D0002RULNRULNRULL000000inDb@030000ZJ;?ZJ;?00:YX/l2000000>YXLh0002b[M<00k:]
d`@00002^KSH0P000005`<OO00000000`LGN000000?7enH01@000<W/kLW/k@000;_lh`020000A?oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`06oooo0P0000039`0?0000F`m@00=K3e00
0`0007HgM7HgM002MSMd00<0002IDWRIDWP00iUBN0@0000:XVN=00<0002eM8^eM8/04;EdR`030000
`Wf6`Wf600_2OHH00`000<^2PL^2P@06bh:100<0003?Q7k?Q7h00/n4OPD00002cGIX00<0003;MF[;
MFX03@000009Y6R<0000YgRO0000XGNS0000Y8Ba0000X8>d00<000001:6>`@0009n?``0000:OTLD0
0`000::Eaj:Ea`02XYG700<0002OU<T000001jVRc`<00003/ZgC00@0002i^]Vi^]Vi^]T300001<37
g`800002amOV00H00039k>g9k>d0002gnn@00016oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo00Goool0100002L03bL03`0000=K3e0200001GHgM0030000VE9h000000<0000?XVN=00<0
002eM8^eM8/03kEdR`030000`Wf6`Wf600_2OHH00`000<^2PL^2P@07bh:100<0003?Q7k?Q7h00ln4
OP030000dHEmdHEm00H00002ag=_00L00031LGG1LGD0002jKg/0002cKH401@000005YgRO00000000
0000Y8Ba00<000001j>>_P000:6>`J6>`@0009n?``000002Wi751::Ea`030000WiC9000000NYX/l0
0`000;>_e;>_e00400001;Vjf@060000`<SP00000000`<OO00000/KHi`<000001<W/k@0000000000
04Ooool00`000?ooooooo`0Eoooo000Eoooo00<0003oooooool01Oooo`@00002F`m@0P0000Mf=g@2
00004j9WS@030000]GB;]GB;00^eM8/H00001<^2P@030000chAnchAn00??Q7h00`000=65OM65O@02
dHEm00<0003?QGo?QGl02P000003^GjB0000/gbG00<000001Jj6ZP00000000000:Z?^@0200000Z>>
_Q400003ZJ;?00<0002c[mBc[m@00k>_e0060000^[_J00000000^K[I00001<38h0800002a]SW00<0
0037kNh000000P0004[oool00`000?ooooooo`0Doooo000Eoooo00<0003oooooool01Oooo`800003
F`m@00<0001f=gAf=g@01GHgM0030000Q52;000001BRIhd00`000;EdRkEdR`02]GB;2@0000BiPYT0
0`000<F9ULF9U@0;aHVE00<0003=SY3=SY000lf>T0h00002dHEm00@0003?QGo?QGl00002bh>300<0
0036PXP000000/20S@D000001k>7Y`00000000000:j@]P000:Z?^@05000000BUV<P0002SVLX00002
Xi_=00L0002SWLnSWLnSWLl0002VX=0000000jRUd`H00002/joD00<0002j^mZj^mX00[ZkfP<00002
`<SP00<00036fNS6fNP01P0004_oool00`000?ooooooo`0Doooo000Eoooo00<0003oooooool01?oo
o`<000000e/?D00000000006MSMd0P0000:4D8/00`000:9WSJ9WS@0@XVN=1`0000fiPYT00`000<F9
ULF9U@0<aHVE00<0003=SY3=SY001/f>T0030000dY2=dY2=00CBT8d00`000=>AS=>AS00=000000?4
S9X0002nRih00`000004^9:`00000000[Y2f0`000004ZiS30000YiS600000ZFHb0050000XiW:0000
Xi_=000000>SWLl00`000:JPd0000006Z:GC00<0002b/=Nb/=L01@0000:j^mX00`000<79h<79h005
000000C7k^h000000000001=oooo00<0003oooooool05?ooo`005?ooo`030000oooooooo00Coool5
00001gHgM0030000Q52;Q52;00:4D8/00`000:9WSJ9WS@0<XVN=100000:WMY`00`000;V2VKV2V@0@
^H:I00<00035RIG5RID02lF9U@030000cHj@cHj@00O=SY000`000=:@SM:@S@03dY2=00<0003CTHcC
TH`00]>AS0050000dY6>dY6>dY6>000000;>T94010000<V>UP000<B<VP@000000kfD[0000;RB/003
000000BcV[h00000002[V<<:00000Z>Mc`050000YZ3@YZ3@YZ3@000000>XYM<500000[:`e`030000
^KcK^KcK00H000000lOJj0000<S^kP030000D?ooo`030000oooooooo01?oool001Coool00`000?oo
ooooo`04oooo0`0000Mf=g@200001XA@R`030000XVN=XVN=00NRIhd400001ZMfW0030000^H:I^H:I
012iPYT00`000<F9ULF9U@0;aHVE00<0003=SY3=SY001lf>T0030000dY2=dY2=00CBT8d00`000=>A
S=>AS002di6<00H0003BTHkBTHkBTHh0003>T944000000G8Uj@00033UZP0002mU:`00P000004_9fh
00000000/iZn0`000009[Z;;0000ZZ7=0000Yj3?0000Y:3A0000Xj7C008000000j>Mc`000:JPd003
YZ3@0`0000:/Z]D00`000;>bek>be`0700000/79h@030000am[X0000008000000kCkh`000?ooo`1@
oooo00<0003oooooool04oooo`005?ooo`030000oooooooo00?oool400001GHgM0800008Q52;00<0
002RIhfRIhd00j9WS@@0000:YgJL00<0002iPYViPYT04;V2V@030000aHVEaHVE00_5RID00`000<f>
T<f>T008cHj@00<0003BT8gBT8d00m:@S@030000di6<di6<00P000001M6JW0000<fIX0000<RGY004
000000?1W[D0002lWKP00`000004]ZC600000000[Z;;1`000003Xj7C0000XZ7D00800002YZ3@0`00
00B/Z]D01@000;>bek>bek>be`000003^kgK00<00032b^0000000`000004bNk]000000000000D_oo
o`030000oooooooo01?oool001Coool00`000?ooooooo`02oooo0P000003300i=@AS000000Af=g@0
0`0008A@RhA@R`08Q52;00<0002RIhd000000`0000jWMY`00`000;V2VKV2V@0@^H:I00<00035RIG5
RID03<F9U@030000cHj@cHj@00;=SY0>00000]JKV0050000e9^Ie9^Ie9^I000000?AVY`3000000G<
XZd00037X;400031W[D00`000003^jG30000000000@000001J^YeP000:JXe`000:>Wf@03000000>R
XM@0002RXM@00P0000>WYM@?000000?9fnL0000000000P0005Coool00`000?ooooooo`0Coooo000D
oooo00@0003oooooooooool2000000@<03T0000e16<00002MSMd0P0000Z4D8/300004jMfW0030000
^H:I^H:I012iPYT00`000<F9ULF9U@04aHVE300000G?V9`00`000=BKVMBKV@03e9^I00<0003FViSF
ViP00mJKV0060000e9^Ie9^Ie9^I0000dIZL0P000004dJ>Y0000c::]c::]0`000003aZVm00000000
008000000kV_c`0000000006000000BSYmVPY]X0002NYMX2000000BRXM@00000002WYM@300000jn/
e@030000][CG000000800002_KkJ00@00034bml0003<fnD30000E_ooo`030000oooooooo01?oool0
01?oool00`000?ooooooo`02oooo00<0000<03T000000SD4H`<0000:Q52;0P000003SF:K0000YgJL
01>WMY`00`000;V2VKV2V@0=^H:I2P0000O7U:400`000<nHW<nHW008ciRL00<0003DViWDViT00mBK
V@030000eY^HeY^H00;FViP00`000=BKVMBKV@03000000CEY:D0003AXjWAXjT3000000G;ZkT00000
00000034//P00`000003^k[I0000000000P0000019jUfP0009bSfP0000:RXmH010000:VWeJVWeJVW
e@D000000kRdeP000;nnf@080000F?ooo`030000oooooooo01;oool001?oool01`000?oooooooooo
o`0000`0>@000003=@AS00<00024D8^4D8/028A@R`800003SF:K00<0002WMYbWMY`04ZMfW0030000
^H:I^H:I00NiPYT600000k^=Y@030000aiBQaiBQ00c7U:400`000<nHW<nHW007ciRL00<0003DViWD
ViT00mBKV@040000eY^HeY^HeY^H10000003f:FR0000eJBU00;EY:D300000]2/]@030000d;K10000
00<000000l:me@0000000009000000JHZN8000000000002KXmX00002XZCF0P000003ZZOD0000/JgD
00d0001Ioooo00<0003oooooool04_ooo`004oooo`030000oooooooo0080000010`0>@0003D4HcD4
H`800007Q52;0`0000F=HY/00`000:MfW:MfW00BYgJL00@0002iPYViPYViPYT600002K^=Y@030000
aiBQaiBQ00c7U:400`000<nHW<nHW007ciRL00<0003DViWDViT00mBKV@@00002fJFQ00H0003HYJ;H
YJ;HYJ80003EY:D2000000?E[K00003@[;D00P000003d;K10000cl7=00h000001hb]k000000009:S
h00009^RfP000002Xj?E10000004/ZgB0000^[CD^[CD1P000003f^oP0000oooo05Woool00`000?oo
ooooo`0Boooo000Coooo00H0003oooooool0000<03T00002=@AS00<0001>9Gh000001HA@R`800008
SF:K00<0002WMYbWMY`04:MfW0H0000@^hfU00<00037U:77U:402lNDX@030000ciRLciRL00S?V9`0
0`000=BKV@000002000000?GY:80003IYJ400mVUX@040000f:FRf:FRf:FR0P000003fJn]0000eJf`
00800002eKNl0P000003cl7=0000c<oL00H00002oooo1P000009Pj?X0000T:3O0000VZ3H0000Xj;C
0000ZjOB00L000001<BldP0000000=OHf080001Koooo00<0003oooooool04_ooo`004oooo`050000
oooo0000300i0000008e16<0100004hUOThUOP0000>4D8/200002XeRV`030000YgJLYgJL00^WMY`5
00000Z^2Z0030000^hfU^hfU016kSJD00`000<NDXLNDX@0;aiBQ00<0003?V9c?V9`01/nHW0@00005
ejBR00<0003IYJ7IYJ400]VUX@@00003fJn]00@0003J^KP0003E]k`800002oooo`8000001H2NiP00
08nMg@0009ZMeP03000000>/YM00000000002@0005coool00`000?ooooooo`0Boooo000Coooo00@0
003oool000000002=@AS00H0001>9Gi>9Gi>9Gh00024D8/2000038eRV`030000YgJLYgJL00FWMY`6
00001j^2Z0030000^hfU^hfU016kSJD00`000<NDXLNDX@0<aiBQ00<0003?V9c?V9`01@0000;BXZH0
0`000=NTX]NTXP04ejBR00@0003IYJ7IYJ7IYJ4200000mb_Z@@00002f[Vh00@0003KaL@0003Ke=43
00003oooo`80000017ZCh000000009ZJd`@000000kFXc000000000060000GOooo`030000oooooooo
01;oool001;oool00`000?ooo`000002000000<e16<0001>9Gh00dhUOP80000>SF:K00<0002WMYbW
MY`01@0000j[PZP00`000;^=YK^=Y@0@^hfU00<00037U:77U:402/NDX@D00008dZ:V00<0003GY:;G
Y:801=NTXP<000000mf_Z@000=b_Z@02g:nY00@0003N^[?N^[?N^[<4000000CRe//000000000000A
oooo0P000004N8gK00000000VIK?10000003]ZG70000000000D0001Noooo00<0003oooooool04Ooo
o`004_ooo`060000oooo00000000=@AS000014hUOP80000>SF:K100001>[PZP00`000;^=YK^=Y@0A
^hfU00<00037U:77U:401<NDX@D00002bYj[00<0003BXZKBXZH02=:RYP030000ejBRejBR00?GY:82
00000mf_Z@060000g:nYg:nY0000hKZ`00000]jj/`040000h<Jn0000h]K;0`0001?oool4000000>I
TLX0000000001@000004bK72000000000000Goooo`030000oooooooo017oool001;oool00`000?oo
o`002@0200000dhUOP8000000e`kT@0008eRV`0:SF:K0`000003TVnX0000Zh:X01B[PZP00`000;^=
YK^=Y@0A^hfU00<00037U:77U:40100000S:WZ/00`000=:RY]:RYP07dZ:V00@0003GY:;GY:;GY:82
000000?K[ZX0003M[jT00mf_Z@800002hKZ`00D0003N^[<00000003Pa[h0100001Goool5000000>U
Tl<0000000001`0005ooool00`000?ooooooo`0Aoooo000Boooo100000=>9Gh01@0005`kTE`kTE`k
T@000009SF:K0P0000BBKjP00`000:^2Z:^2Z00CZh:X00<0002kSJFkSJD03[^=Y@H0000<bYj[00<0
003BXZKBXZH02=:RYP<00004fjjZ00D0003M[jWM[jWM[jT000001>6j/0030000i<Nii<Ni00<00000
0n;ma0000?ooo`0Doooo20000003^9bl0000000000@0001Ooooo00<0003oooooool04Oooo`004_oo
o`8000001@00=00004hUOThUOP000004G3^A00<0002=HY^=HY/018eRV`<00006TVnX00<0002[PZR[
PZP05:^2Z0030000^hfU^hfU00NkSJD600000kfG[`030000bYj[bYj[00g:WZ/00`000=:RY]:RYP06
dZ:V0P0000KK[ZX01P000=f_ZMf_Z@000>6j[`0000;Q^[02000000CTakT00000003_jlH200005ooo
o`h0001Ooooo00<0003oooooool04Oooo`004_ooo`H00005G3^A00@0002=HY^=HY^=HY/300002I9_
Z0030000Zh:XZh:X01B[PZP010000;^=YK^=YK^=Y@H0000:_IN_00<0003:WZ_:WZ/03<ZNZ`030000
dZ:VdZ:V00?BXZH3000000?E[:h0003K[ZX01]^^ZP800002hKZ_00<0003Q^[0000000^O7]P<00000
0no[aP000?ooo`0Goooo2P000004bYfY000000000000Goooo`030000oooooooo017oool001;oool4
00001e`kT@040000SF:K000000003I9_Z0030000Zh:XZh:X016[PZP600004;fG[`030000bYj[bYj[
00g:WZ/00`000=:RYP00000200001MF/[P030000fjjZfjjZ00CK[ZX00`000>6j[n6j[`02hKZ_00@0
003WakKWakKWakH2000000?cjKd0003oool06?ooo`h0001Ooooo00<0003oooooool04Oooo`004_oo
o`<00007G3^A0`0000nBKjP00`000:^2Z:^2Z00;Zh:X1P0000:]S;<00`000;fG[kfG[`0A_IN_00<0
003:WZ_:WZ/03<ZNZ`<00008eJb^00<0003K[Z[K[ZX00]^^ZP<00003hKZ_0P0000;WakH500006Ooo
o`D000001J9iY@00000000000;n>X`050000G_ooo`030000oooooooo017oool001;oool300001E`k
T@8000000fA;W`00099_Z00?TVnX00<0002[PZR[PZP01Z^2Z0D00008[Hbc00<0002mUjnmUjl04[fG
[`030000bYj[bYj[00S:WZ/3000000?<Z;@0003E[:h02=F/[P050000fjjZfjjZfjjZ000000;O^K40
10000>6j[n6j[`0000;WakD2000000C_ekX0003cjKd0000Joooo00<005X0000000002@000004dHj;
000000000000GOooo`030000oooooooo017oool001;oool300000e`kT@800003I4^O00<0002BKjRB
KjP03Y9_Z0030000Zh:XZh:X00H0000>[Hbc00<0002mUjnmUjl04KfG[`030000bYj[bYj[00G:WZ/3
00001<bX]0030000eJb^eJb^00SE[:h300001=ni/@800003ilNe00<0003_ek[_ekX00`0001[oool5
000000>PL9`000000000200005goool00`000?ooooooo`0Aoooo000Aoooo10000003G3^A00000000
00ETBil00`00099_Z99_Z00<TVnX1@0001B]S;<00`000;fG[kfG[`0A_IN_00<0003:WZ_:WZ/00lZN
Z`800008c:Rd00<0003E[:kE[:h01mF/[P030000gkVagkVa00CO^K4010000>O7]NO7]NO7]@800000
1>oG^P000?KX^00001_oool7000000JXKi800000002kNhd00033OXH50000G?ooo`030000oooooooo
013oool0017oool2000000<006`0000000001fA;W`030000TVnXTVnX00RBKjP400000YAj/`030000
[Hbc[Hbc01B]S;<00`000;fG[kfG[`0B_IN_00<0003:WZ/000000P0000[<Z;@00`000=F/[]F/[P05
eJb^0`0000GO^K4200000nO7]@030000kmNi000000<0000Joooo0P000003IS5jP4^7000000T00000
0kmbN@0000000002000000>f;@00003oool0FOooo`030000oooooooo013oool0017oool4000026A;
W`030000TVnXTVnX00BBKjP400001YAj/`030000[Hbc[Hbc01B]S;<00`000;fG[kfG[`0@_IN_1000
00g<Z;@00`000=F/[]F/[P03eJb^0P0000?I]kH01@000=ni/Mni/Mni/@000002iLJh00<0003WakD0
00000^oG^@030000m^Rh000001_oool6000000NKGHH0002VIXL0002_K8D0002gL8402P0005Soool0
0`000?ooooooo`0@oooo000Aoooo100000QTBil00`00099_Z99_Z00400002YAj/`030000[Hbc[Hbc
01B]S;<00`000;fG[kfG[`0<_IN_100000;0XKT00`000<bX]<bX]00<c:Rd00@0003E[:kE[:kE[:h2
00001MVg]P040000gkVagkVa00000nG6^0060000ilNe0000kmNi0000m^Rg0P0001[oool2000000AS
96X00000002>DH88000000BcIGD0002jIVbjIV`4000000?0@a4000000000Eoooo`030000oooooooo
013oool0017oool2000000<507`0001TBil00fA;W`L0000>U7Zc00<0002]S;>]S;<05:f</`030000
_IN__IN_00RmUjl400001/2Q^@030000c:Rdc:Rd00g<Z;@300002=Vg]P800005iLJh00H0003_ekW_
ekT0003fj;L0000Koooo1`000004V5Ak0000XUal00000Z]RNP050000/fEe/fEe0000^VI/00T0001E
oooo00<0003oooooool04?ooo`004Oooo`P00004IUJ[00<0002DN[>DN[<03YAj/`030000[Hbc[Hbc
01F]S;<00`000;fG[kfG[`03_IN_100000_0XKT00`000<bX]<bX]00;c:Rd0P0000[I]kH00`000>G6
^>G6^003iLJh0P000003kmNi0000m^Rg0080000Joooo0`000008NCA]0000RdMgRdMg0000V5Ak0000
XUal200000:gGF800`000;aID@0000050000E?ooo`030000oooooooo013oool0017oool2000000<7
2HL0001VEZ/01fIFZ`030000U7ZcU7Zc00nDN[<00`000:f</jf</`0D[Hbc00<0002mUjl000000`00
00o0XKT00`000<bX]<bX]009c:Rd0P000003d;:m0000fKNf00SI]kH200001>G6^0030000k=Jmk=Jm
008000000oKX]`000?ooo`0Ioooo0P000003GQQK0000NCA]00L000001J1FM@000:UKLjUKL`000002
/5i]0P0000:gGF800`000;aID@0000060000D_ooo`030000oooooooo013oool0017oool2000000<7
2HL0001VEZ/01fIFZ`030000U7ZcU7Zc00nDN[<00`000:f</jf</`0A[Hbc1@0001?0XKT00`000<bX
]<bX]007c:Rd0P0000C@/[d00`000=Vg]]Vg]P05fKNf00@0003Oa;kOa;h00003iLJh00D0003/e[g/
e[d0003fj;L00P0001Woool7000000F8@Fl0002FCWBFCW@000000Z1FM@060000ZE]cZE]cZE]c0000
/5i]1P0000:jETh00`000;]9<00000040000D?ooo`030000oooooooo013oool0017oool2000000<7
2HL0001VEZ/01fIFZ`030000U7ZcU7Zc00nDN[<00`000:f</jf</`09[Hbc200000>^UKd00`000<2Q
^L2Q^@0B`:6i00<0003<Z;C<Z;@01<bX]0<00006d;:m00<0003I]kKI]kH00mVg]P800003glBn00@0
003Ua[SUa[P00003k=Jm00@0003fj;L00000000Hoooo0P00009L4E800`0007L^I@000002R45_00@0
002FCWBFCW@00003X5Ie00<0002YFg<000000P0000>`G6/00`000;IKH;IKH002000000BjETh00000
002kBC050000C_ooo`030000oooooooo013oool0017oool4000026IFZ`030000U7ZcU7Zc00nDN[<0
10000:f</jf</jf</`P0000;[YFm00<00030XKW0XKT04l2Q^@040000c:Rdc:Rdc:Rd0P0000[@/[d0
1@000=Vg]]Vg]]Vg]P000006glBn0P0000?/e[d010000??Y_@00000001Soool3000000AL4E80001g
;VD00002R45_00<0002FCW@000001`0000:XFW401@000;1LJk1LJk1LJ`000004]U]P00D0002jETjj
ETh0002kBC001@0004goool00`000?ooooooo`0@oooo000Aoooo0P0000030@f>0000000000<00004
IUJ[00<0002DN[>DN[<01YAj/`d0000D[YFm00<00030XKW0XKT04/2Q^@040000c:Rd000000003=2b
_@040000fKNffKNf00001mo4_P030000k=Jmk=Jm00;/e[d010000??Y_@00000001Ooool00lKm`@00
00000002G15B1`0000:FCG@01@000:1EM:1EM:1EM0000003Z5Ya00<0002`G6^`G6/00[1LJ`030000
]U]P]U]P00H00002`54h1@0004_oool00`000?ooooooo`0@oooo000Aoooo100000ATGKD=00002IB2
_@030000[YFm[YFm01F^UKd00`000<2Q^L2Q^@0A`:6i0`0000o@/[d200001mo4_P800003k=Jm00@0
003cjKd00000000Hoooo1`0000>9@Fl01@0009I=M9I=M9I=M0000003X5Ed00<0002XFW6XFW400ZQJ
L@030000/5a[/5a[00@00003^F=W00<0002nGEJnGEH00P0000;0DCP50000BOooo`030000oooooooo
013oool0017oool4000026AM]@030000U8:mU8:m00nDP[d00`000:jE_JjE_@0E[YFm00<00030XKW0
XKT03L2Q^@@000000l:[``000=2b_@0?d;:m00<0003Oa;kOa;h01Mo4_P040000iMC5iMC500000^cF
_@040000lnVm000000005oooo`800002G19C00@0001g;fIg;fH00003RD5_00D0002FCGBFCGBFCG@0
00001:1EM0030000Z5YaZ5Ya00@00003/f=b00<0002iHfNiHfL00[USI`050000_UeF_UeF_UeF0000
00?0DCP010000;Th1`00000004Soool00`000?ooooooo`0@oooo000Boooo00@000002I4000000007
I5fe00<0002DP[fDP[d03iB2_@030000[YFm[YFm01F^UKd00`000<2Q^L2Q^@0:`:6i0`0000K2Zl<0
0`000=2b_M2b_@0;d;:m0`0000KOa;h020000>GDaNGDaNGDa@000>cF_@000??Y_@80000Goooo00D0
000a0300001L4U<000000WL_IP050000RD5_RD5_RD5_000000BFCG@00`000:1EM:1EM00500000Z]Q
N@030000/f=b/f=b00>cHg800`000;USIkUSI`02^F=W00D0002nGEJnGEJnGEH000000l1A>0D00015
oooo00<0003oooooool04Oooo`004_ooo`8000000`09T@0000000006I5fe00<0002DP[fDP[d03iB2
_@030000[YFm[YFm01F^UKd00`000<2Q^L2Q^@07`:6i0`0000W2Zl<00`000=2b_M2b_@09d;:m0P00
00?D_lH00`000=o4_]o4_P02glBn00<0003Ue<GUe<D00nGDa@8000000o?Y_@000000000Foooo0`00
009L4U<0100007L_IWL_IP0000>9@Fl00`0009I=M9I=M00500000Z=MO0030000Zf5iZf5i00>[HGT0
0`000;=SL[=SLP02/f=b00<0002iHfNiHfL00kUSI`040000_UeF_UeF_UeF0P0000;0DCP50000A?oo
o`030000oooooooo017oool001;oool2000000<02I40001LHKh00P0000ETGKD00`0009B2_IB2_@0>
U8:m00<0002^UKf^UKd05ZjE_@030000`:6i`:6i00;0XKT400003<:[``030000d;:md;:m00O@/[d2
00001MBoaP030000glBnglBn00;Oa;h00`000>GDaNGDa@03iMC500@0003cjKd00000000Foooo0`00
009L4U<;00000YUEO0030000XeelXeel00>SGG`00`000:]QNJ]QN@02Zf5i00<0002cHg:cHg800k=S
LP030000^F=W^F=W00>iHfL00`000;iME[iMEP0400000/eWC@030000bU8M000000800012oooo00<0
003oooooool04Oooo`004_ooo`@00003G66n0P0000=TGKD00`0009B2_IB2_@0?U8:m00<0002^UKf^
UKd05JjE_@030000`:6i00000080000A`Z_300<0003@/[g@/[d01M2b_@030000e;o6e;o600GD_lH0
1@000=o4_]o4_]o4_P000005iMC50P000003lnVm0000000001Goool2000000<a0300000000000P00
009k>7400`0008a:NHa:N@02S4Yi00<0002IEGbIEG`00YUEO0030000XeelXeel00>SGG`00`000:]Q
NJ]QN@03Zf5i00<0002cHg:cHg800k=SLP040000^F=W^F=W^F=W100000?7L6L010000<eWCLeWCLeW
C@8000000lYB7@0000000011oooo00<0003oooooool04Oooo`004_ooo`@00005G66n0P000003I5fe
0000U8:m012DP[d00`000:jE_JjE_@0A[YFm1P0001C2Zl<00`000=2b_M2b_@03d;:m0P0000SD_lH0
10000=o4_]o4_P0000GUe<D00`000>cYbNcYb@0200005Oooo`D000001F4MH@0007/hLG/hL@000005
S4Yi00<0002IEGbIEG`00YUEO0030000XeelXeel00>SGG`00`000:]QNJ]QN@03Zf5i00@0002cHg:c
Hg:cHg8600000l5bM`030000ag1Wag1W00;7L6L00`000<eWCLeWC@02cFM=00@0003:DQd000000010
oooo00<0003oooooool04Oooo`004_ooo`@00007G66n1P0000fDP[d00`000:jE_JjE_@09[YFm2000
00B_WlL00`000<:[`l:[``0C`Z_300@0003@/[g@/[g@/[d200002mBoaP800005iMC500<0003/jLW/
jLT00`0001Coool2000000Df0440001Q7F5Q7F4000000g/hL@030000S4YiS4Yi00><BWT00`0009UE
O9UEO002VEEl00<0002SGGbSGG`00j=MO0030000Zf5iZf5i00>[HGT400001;UbP@030000`G9g`G9g
00?1LWL00`000<M`IlM`I`02ag1W00<0003=Idg=Idd00/eWC@030000bU8M00000080000noooo00<0
003oooooool04Oooo`004_ooo`H00006G66n00<0002BR/RBR/P00Y::b0T00004U8:m00@0002^UKf^
UKf^UKd800003:nOa`030000`Z_3`Z_301C2Zl<300003MBoaP030000iMC5iMC500?Ue<D010000>cY
bNcYbNcYb@80000Doooo0P00008f04401000064MHF4MH@0000=k>7400`0008a:NHa:N@02S4Yi00<0
002IEGbIEG`00iUEO0030000XeelXeel00BSGG`00`000:]QN@00000200000[5`Q`030000^G:1^G:1
00BiLX400`000<5bMl5bM`03`G9g00<00037L6O7L6L00/M`I`800003cFM=00<0003:DQg:DQd00P00
03goool00`000?ooooooo`0Aoooo000Boooo00@0003oool000000002C63600<0001LHKiLHKh00eaQ
_P030000TX[8TX[800^BR/P800005JnOa`030000`Z_3`Z_301;2Zl<200003]BoaP800005iMC500<0
003/jLW/jLT00P0001Goool2000000Df0440001Q7F5Q7F4000000g/hL@030000S4YiS4Yi00><BWT0
0`0009UEO9UEO003VEEl00@0002SGGbSGGbSGG`500001K5`Q`030000^G:1^G:100BiLX400`000<5b
Ml5bM`04`G9g00<00037L6O7L6L00lM`I`050000cFM=cFM=cFM=000000;:DQd20000??ooo`030000
oooooooo017oool001;oool010000?ooo`00000000=<H<H200000eaQ_P030000TX[8TX[800nBR/P0
0`000:nOajnOa`0F[io700<00032Zl?2Zl<03l:[``<000000lBgcP000=BoaP0;e;o60P0000;Id=00
1@000>GDaNGDaNGDa@000002k>W900<0003Wnk`000005?ooo`8000000cH0@@00064MH@02HAeQ00D0
001k>75k>75k>74000001Ha:N@030000VEElVEEl00L00003Z6^;00<0002aL8NaL8L01K5`Q`030000
^G:1^G:100BiLX400`000<5bMl5bM`03`G9g00<00037L6O7L6L01<M`I`040000cFM=cFM=cFM=0P00
00;:DQd20000>_ooo`030000oooooooo017oool001;oool00`000?ooo`000002000014aPaP050000
G66nG66nG66n0000012BR/P00`000:nOajnOa`0F[io700<00032Zl?2Zl<03<:[``<00005a;O>00<0
003D_lKD_lH02=BoaP030000fM3@fM3@00;Id=0010000>GDaNGDa@0000;/jLT00`000>Ok_000000D
oooo0P000003=P110000HAeQ009Q7F400`0007/hLG/hL@02NcQa00<0002<BWV<BWT00Xa:N@@00003
WVB<00<0002XJh^XJh/01JQ[R`030000/G27/G2700BaL8L00`000;UbPKUbP@05^G:100<00031LWO1
LWL00l5bM`030000ag1Wag1W00C7L6L00`000<eWCLeWC@02cFM=00<0003:DQd000000P0003Woool0
0`000?ooooooo`0Aoooo000Coooo00<0003oool000000P0000A<H<H0100005aQ_UaQ_P00016BR/P0
0`000:nOajnOa`0E[io700<00032Zl?2Zl<02L:[``<00008a;O>00<0003D_lKD_lH01mBoaP030000
fM3@fM3@00CId=0200000ncYb@80000Doooo0P00008f04401@00064MHF4MHF4MH@000003NcQa00<0
002<BWT000000`000003TUZ;0000WVB<00BNI8`00`000:Q[RjQ[R`05Z6^;00<0002aL8NaL8L01K5`
Q`030000^G:1^G:100FiLX400`000<5bMl5bM`03`G9g00<00037L6O7L6L01<M`I`030000cFM=cFM=
00<00002hGTm0P0003Ooool00`000?ooooooo`0Boooo000Coooo00H0003oool00000000/ElX00004
C6360`00016BR/P00`000:nOajnOa`0E[io700<00032Zl?2Zl<01/:[``<0000;a;O>00<0003D_lKD
_lH01MBoaP800007fM3@00L0003/jLW/jLW/jLT0003Wnk`000005?ooo`8000000cH0@@00064MH@02
HAeQ00<0001k>75k>740100000FBFX/00`0009iTS9iTS003WVB<00<0002XJh^XJh/01JQ[R`030000
/G27/G2700FaL8L00`000;UbPKUbP@06^G:100<00031LWO1LWL00l5bM`030000ag1Wag1W00?7L6L3
00000mb5J0030000hGTmhGTm0080000foooo00<0003oooooool04_ooo`004oooo`030000oooooooo
008000000baGbP0004aPaP04C6360P00012BR/P00`000:nOajnOa`0F[io700<00032Zl?2Zl<00/:[
``<0000?a;O>00<0003D_lKD_lH00mBoaP030000fM3@fM3@00KId=0200000^cYb@030000io^l0000
01Coool;00000X9;QP030000TUZ;TUZ;00BBFX/00`0009iTS9iTS004WVB<00<0002XJh^XJh/01JQ[
R`030000/G27/G2700FaL8L00`000;UbPKUbP@05^G:100<00031LWO1LWL01<5bM`030000ag1Wag1W
00800002dhQo00<0003LQFSLQFP00]b5J0050000hGTm0000c500000003Goool00`000?ooooooo`0B
oooo000Coooo00L0003oooooool00000>l00000/ElX00P0000=<H<H00`0008bAe0000003000039::
b0030000[io7[io701J_WlL00`000<:[``00000200004/BgcP030000e;o6e;o600;D_lH00`000=W@
d=W@d006fM3@00<0003Ni]X000000^cYb@03io^l0000oooo01?oool3000000<n265Y<gYY<gX00fTc
NP030000PT^6PT^600:2BhH00`00099JRi9JR`04TUZ;00<0002NI8bNI8`019iTS0030000Z6^;Z6^;
00FXJh/00`000;5`Qk5`Q`05/G2700<0002iLX6iLX401[UbP@040000`G9g`G9g`G9g1@0000CCR7l0
0`000=b5J=b5J002g8EX00<0003QNCgQNCd00P0003Goool00`000?ooooooo`0Boooo000Coooo00@0
003oooooooooool200000baGbP040000C636C63600001HbAe0@00008TX[800<0002_WlN_WlL04ZnO
a`H0000Ea;O>00<0003D_lKD_lH00P0000OId=0200000mkVfP8000000nOk_?ooooooo`0Boooo00D0
000002Dn264n2640000016TcNP030000PT^6PT^600>2BhH00`00099JRi9JR`04TUZ;00<0002NI8bN
I8`019iTS0030000Z6^;Z6^;00JXJh/00`000;5`Qk5`Q`05/G2700<0002iLX6iLX401;UbP@D00004
bHR<00<0003CR7oCR7l00m>8O`030000g8EXg8EX00;LQFP00`000>5i?N5i?@020000=?ooo`030000
oooooooo01;oool001?oool00`000?ooooooo`02oooo0P0000</ElX00`0004aPaP000009S97D1000
00FBR/P00`000:nOajnOa`09[io7200000B^Z]<00`000<Bgc/BgcP0Ea;O>0P0000SId=000`000=kV
f]kVfP03g^KJ00<0003Wnk`000005?ooo`800002?PQQ00<0001Y<gYY<gX00VTcNP030000PT^6PT^6
00:2BhH00`00099JRi9JR`05TUZ;00<0002NI8bNI8`019iTS0030000Z6^;Z6^;00JXJh/00`000;5`
Qk5`Q`05/G2700<0002iLX6iLX40100000?1QYD00`000<V8S<V8S003bHR<00<0003CR7oCR7l01=>8
O`030000g8EXg8EX00;LQFP00`000>5i?N5i?@020000<oooo`030000oooooooo01;oool001Coool0
1`000?ooooooooooo`00000k`0000003;5O:00<0001<H<H0000038bAe0@000000i::b0000:nOa`02
[io7200000f^Z]<00`000<Bgc/BgcP0Ca;O>0P0000SId=000`000=kVf]kVfP03g^KJ00<0003Go]L0
00005?ooo`050000000U0000?PQQ000000EY<gX00`00089;QX9;QP02PT^600<0002BFX^BFX/0199J
R`030000WVB<WVB<00FNI8`00`000:Q[RjQ[R`06Z6^;00<0002aL8NaL8L01;5`Q`@00007`HJE00<0
0039R8c9R8`01<V8S0030000dhQodhQo00CCR7l00`000=b5J=b5J002g8EX00<0003QNCgQNCd00P00
037oool00`000?ooooooo`0Coooo000Doooo00<0003oooooool00_ooo`03000003_0000000</ElX2
000048bAe0D0000E[Z[C00<00034]lk4]lh04LBgcP8000000lK7fP000=W@d006fM3@00<0003Ni][N
i]X00mkVfP030000eokG000001Goool200000Sh8H@030000JC=jJC=j009Y<gX00`00089;QX9;QP03
PT^600<0002BFX^BFX/0199JR`030000WVB<WVB<00FNI8`00`000:Q[RjQ[R`07Z6^;00<0002aL8L0
00000`0000:hPYX00`000<66UL66U@07`HJE00<00039R8c9R8`01<V8S0030000dhQodhQo00?CR7l0
0`000=b5J=b5J003g8EX00D0003QNCd0003<D0000000<?ooo`030000oooooooo01?oool001Coool0
0`000?ooooooo`03oooo00<00000>l0000000baGbP80000@S97D00<0002^Z]>^Z]<05ZjZd`030000
a;O>a;O>00k4]lh300001<K7fP030000fM3@fM3@00?Id=000`000=kVf]kVfP03g^KJ00<0003Go]L0
00005Oooo`030000000U0000008n26400`0006TcNVTcNP02JC=j00<00022BhJ2BhH00h9;QP030000
TUZ;TUZ;00BBFX/00`0009iTS9iTS006WVB<00<0002XJh^XJh/01:Q[R`@00007^8:J00<00031QYG1
QYD01/66U@030000bHR<bHR<00C9R8`00`000=>8Om>8O`04dhQo00<0003LQFSLQFP00]b5J0060000
hGTmhGTm0000c5000000;oooo`030000oooooooo01?oool001Coool00`000?ooooooo`04oooo00<0
0000>l0000000RaGbP030000OYOR00000080000=S97D00<0002^Z]>^Z]<05ZjZd`030000a;O>a;O>
00_4]lh300001lK7fP040000fM3@fM3@fM3@0P0000GNi]X00`000=One`00000Foooo0P00008n2640
0`0006TcNVTcNP03JC=j00<00022BhJ2BhH00h9;QP030000TUZ;TUZ;00BBFX/00`0009iTS9iTS006
WVB<00<0002XJh^XJh/0100000:_OYh00`000;R2V[R2VP06^8:J00<00031QYG1QYD01l66U@030000
bHR<bHR<00C9R8`00`000=>8Om>8O`04dhQo00<0003LQFSLQFP00]b5J0060000hGTmhGTm0000c500
0000;_ooo`030000oooooooo01?oool001Coool00`000?ooooooo`04oooo00<00000>l0000000RaG
bP030000OYOROYOR009nUn8300002hbAe0030000[Z[C[Z[C01J^Z]<00`000<Bgc/BgcP08a;O>0P00
00[6amX010000=W@d=W@d00000KNi]X00`000=One`00000Foooo00<0000002D000000Sh8H@030000
JC=jJC=j009Y<gX00`00089;QX9;QP04PT^600<0002BFX^BFX/0199JR`030000WVB<WVB<00BNI8`5
00001jmnWP030000^8:J^8:J00JhPYX00`000<66UL66U@06`HJE00<00039R8c9R8`01LV8S0030000
dhQodhQo00CCR7l00`000=b5J=b5J002g8EX00D0003QNCgQNCd0003<D000;_ooo`030000oooooooo
01?oool001Goool00`000?ooooooo`04oooo00D00000>l00000/ElX000001gjGhP<00008S97D00<0
002^Z]>^Z]<05ZjZd`030000a;O>a;O>00G4]lh300003LK7fP800005g^KJ0P000003eokG0000oooo
01Koool200000Sh8H@030000JC=jJC=j00=Y<gX00`00089;QX9;QP03PT^600<0002BFX^BFX/01I9J
R`030000WVB<WVB<00@00002YGRP00<0002_OYj_OYh01jmnWP030000^8:J^8:J00JhPYX00`000<66
UL66U@07`HJE00<00039R8c9R8`01<V8S0030000dhQodhQo00CCR7l00`000=b5J=b5J003g8EX00D0
003QNCgQNCd0003<D000;?ooo`030000oooooooo01Coool001Goool00`000?ooooooo`05oooo00@0
0000>l000000000:OYOR0P0000J<TM@00`000:jZdjjZd`0F[Z[C00<00034]lk4]lh00/BgcP<0000?
a/OJ0P0000GNi]X010000=OnemOne`0001Ooool00`0000009@000002?PQQ00<0001Y<gYY<gX00VTc
NP030000PT^6PT^600B2BhH00`00099JRi9JR`03TUZ;1@0000NUN:000`000:mnWZmnWP06[gjN00<0
002hPYZhPYX01kR2VP030000`HJE`HJE00K1QYD00`000<V8S<V8S005bHR<00<0003CR7oCR7l01=>8
O`030000g8EXg8EX00?LQFP00`000>5i?@000002c500:oooo`030000oooooooo01Coool001Goool0
0`000?ooooooo`06oooo00@00000>l000000000;OYOR0`0000><TM@00`000:jZdjjZd`0G[Z[C00@0
0034]lh00000000@a/OJ0P000003a]gZ0000g^KJ00?Ni]X010000=OnemOne`0001Soool200000ch8
H@030000JC=jJC=j009Y<gX00`00089;QX9;QP04PT^600<0002BFX/000000`0000:JKj400`000:Eh
X:EhX007YGRP00<0002_OYj_OYh01jmnWP030000^8:J^8:J00JhPYX00`000<66UL66U@07`HJE00<0
0039R8c9R8`01LV8S0030000dhQodhQo00CCR7l00`000=b5J=b5J002g8EX00H0003QNCgQNCd0003<
D000000Zoooo00<0003oooooool05?ooo`005_ooo`030000oooooooo00Koool2000000=MV>l00000
000037jGhP<000000hbAe0000:jZd`0;[Z[C3P000136amX200000lKMjP050000g^KJg^KJg^KJ0000
00;Go]L00`000?ooooooo`0Foooo00<0000002D000000Sh8H@030000JC=jJC=j00=Y<gX00`00089;
QX9;QP02PT^6100000JJKj400`000:EhX:EhX007YGRP00<0002_OYj_OYh01jmnWP030000^8:J^8:J
00NhPYX00`000<66UL66U@07`HJE00<00039R8c9R8`01LV8S0030000dhQodhQo00CCR7l00`000=b5
J=b5J002g8EX00<0003QNCd000000P0002Woool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01_ooo`800003GIS_0P0000enUn8>00003:^ghP030000a/OJa/OJ00c6amX300001/KMjP030000
g^KJ000000;Go]L00`000?ooooooo`0Goooo0P0000<n26400`0006TcNVTcNP02JC=j00<00022BhH0
00000`0000::Hj000`0009Y_XIY_X@06VVnQ00<0002UN:2UN:001ZEhX0030000[gjN[gjN00N_OYh0
0`000;R2V[R2VP07^8:J00<00031QYG1QYD01l66U@030000bHR<bHR<00G9R8`00`000=>8Om>8O`04
dhQo00<0003LQFSLQFP00]b5J08000001?JWH`000>F:4@0002Soool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool01oooo`800004GIS_0`0000]nUn800`000:^ghZ^ghP0GZkOR00<00036am[6
amX02LK7fP800009a]gZ0P0000;Go]L00`000?ooooooo`0Goooo00<0000002D000000Sh8H@030000
JC=jJC=j00D00006RV>P00<0002JKj6JKj401YY_X@030000YGRPYGRP00NUN:000`000:mnWZmnWP07
[gjN00<0002hPYZhPYX01kR2VP030000`HJE`HJE00O1QYD00`000<V8S<V8S005bHR<00<0003CR7oC
R7l01=>8O`060000g8EX00000000jjV700000_JWH`80000Xoooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo00Soool200001UfHk`800009OYOR00<0002[]n:[]n805j^ghP030000a/OJa/OJ
00O6amX200002/KMjP800002eokG00<0003oooooool06?ooo`8000000ch8H@000000000300000g9@
VP030000RV>PRV>P00F:Hj000`0009Y_XIY_X@06VVnQ00<0002UN:2UN:001jEhX0030000[gjN[gjN
00N_OYh00`000;R2V[R2VP07^8:J00<00031QYG1QYD01l66U@030000bHR<bHR<00K9R8`00`000=>8
Om>8O`03dhQo0P0000C[ZHL01@000?JWH`000>F:4@00000Woooo00<0003oooooool05Oooo`005ooo
o`030000oooooooo00Soool300001UfHk`800007OYOR00<0002[]n:[]n805j^ghP030000a/OJa/OJ
00C6amX300002/KMjP8000001;?elP000=One`0001[oool400000TP/S0030000LU2JLU2J00=bD9X0
0`0008YSX8YSX005RV>P00<0002JKj6JKj401YY_X@030000YGRPYGRP00NUN:000`000:mnWZmnWP07
[gjN00<0002hPYZhPYX02;R2VP030000`HJE`HJE00O1QYD00`000<V8S<V8S005bHR<00<0003CR7oC
R7l00`000003gZFI0000jjV700?[ZHL00`000?JWHoJWH`0200009_ooo`030000oooooooo01Koool0
01Ooool00`000?ooooooo`0:oooo0`0000IMV>l300001GjGhP030000ZkORZkOR01J[]n800`000<K7
f/K7fP02a/OJ0P0000_6gNX200000k?elP80000Koooo0P00G@050000B2b<B2b<B2b<000000EbD9X0
0`0008YSX8YSX005RV>P00<0002JKj6JKj401YY_X@030000YGRPYGRP00RUN:000`000:mnWZmnWP07
[gjN00<0002hPYZhPYX01kR2VP030000`HJE`HJE00O1QYD00`000<V8S<V8S005bHR<0`0000GNYIT0
0`000>^YQn^YQ`02jjV700@0003fYf<00000000Voooo00<0003oooooool05_ooo`005oooo`030000
oooooooo00coool300001efHk`800003OYOR00<0002[]n:[]n805j^ghP040000a/OJ000000002/KM
jP<00003/oGb0P0001goool2001M00D00018;8a8;8a8;8`000001G9@VP030000RV>PRV>P00F:Hj00
0`0009Y_XIY_X@06VVnQ00<0002UN:2UN:002:EhX0030000[gjN[gjN00N_OYh00`000;R2V[R2VP08
^8:J00<00031QYG1QYD01l66U@030000bHR<bHR<00;9R8`2000000?CXJ<0003NYIT01MjUV@030000
jjV7jjV700;[ZHL01@000?JWH`000>F:4@00000Uoooo00<0003oooooool05_ooo`006?ooo`030000
oooooooo00goool300001efHk`8000000gjGhP000:^ghP0;ZkOR3`0000[6gNX200001;?elP80000O
oooo0P00G@050000B2b<B2b<B2b<000000EbD9X00`0008YSX8YSX005RV>P00<0002JKj6JKj401iY_
X@030000YGRPYGRP00NUN:000`000:mnWZmnWP08[gjN00<0002hPYZhPYX01kR2VP030000`HJE`HJE
00O1QYD00`000<V8S<V8S00200001=>QX`030000gZFIgZFI00CNYIT01@000>^YQn^YQn^YQ`000002
mZMS0P0002Coool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool03oooo`@00006GIS_3P00
00fOao@00`000<KMj/KMjP07a]gZ0P0000BcmO8200008?ooo`030000001M000000A8;8`00`00079@
VW9@VP03LU2J00<0002:Hj2:Hj001HYSX0030000VVnQVVnQ00NJKj400`000:EhX:EhX007YGRP00<0
002_OYj_OYh02:mnWP030000^8:J^8:J00RhPYX00`000<66UL66U@06`HJE0`0000KCXJ<00`000=jU
VMjUV@04gZFI00<0003[ZHO[ZHL00^^YQ`050000mZMS0000iHXA000002?oool00`000?ooooooo`0G
oooo000Hoooo00<0003oooooool04Oooo`@00005GIS_00<0002OaoBOao@05io7m0030000a]gZa]gZ
00C6gNX300001;?elP80000Roooo00<0000005d0000014P/S0030000LU2JLU2J00=bD9X00`0008YS
X8YSX005RV>P00<0002JKj6JKj401iY_X@030000YGRPYGRP00RUN:000`000:mnWZmnWP07[gjN00<0
002hPYZhPYX02;R2VP030000`HJE`HJE00?1QYD3000000?9W:T0003CXJ<01]>QX`030000gZFIgZFI
00CNYIT00`000>^YQn^YQ`02jjV700<0003fYf?fYf<00P0002?oool00`000?ooooooo`0Goooo000I
oooo00<0003oooooool04_ooo`@00004GIS_00<0002OaoBOao@05io7m0040000a]gZa]gZa]gZ0P00
00FcmO8200009?ooo`030000001M000000=8;8`00`00079@VW9@VP04LU2J00<0002:Hj2:Hj001HYS
X0030000VVnQVVnQ00NJKj400`000:EhX:EhX008YGRP00<0002_OYj_OYh02:mnWP030000^8:J^8:J
00RhPYX00`000<66U@00000200001LVLZ@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@04gZFI00<0
003[ZHO[ZHL00^^YQ`040000mZMS000000008_ooo`030000oooooooo01Soool001Woool00`000?oo
ooooo`0Doooo1000009MV>l00`0009o7m9o7m00GWlOd00@00036gNX000000005/oGb0P0002Koool0
0`000000G@000003B2b<00<0001bD9YbD9X0179@VP030000RV>PRV>P00F:Hj000`0009Y_XIY_X@07
VVnQ00<0002UN:2UN:002:EhX0030000[gjN[gjN00R_OYh00`000;R2V[R2VP07^8:J0`0000S9W:T0
0`000=>QXm>QX`05dj6S00<0003NYIWNYIT01=jUV@030000jjV7jjV700;[ZHL01@000?JWH`000>F:
4@00000Qoooo00<0003oooooool06?ooo`006Oooo`030000oooooooo01Koool4000000=MV>l0002O
ao@02io7m0h00005/oGb0P0002Soool00`000000G@000003B2b<00<0001bD9YbD9X0179@VP030000
RV>PRV>P00F:Hj000`0009Y_XIY_X@08VVnQ00<0002UN:2UN:002:EhX0030000[gjN[gjN00N_OYh0
0`000;R2V[R2VP03^8:J10000003_iR^0000bIbY00S9W:T00`000=>QXm>QX`06dj6S00<0003NYIWN
YIT01=jUV@050000jjV7jjV7jjV7000000;fYf<200008Oooo`030000oooooooo01Soool001[oool0
0`000?ooooooo`0Goooo400000ebd?h00`000;?el[?elP02/oGb00<0003oooooool0:?ooo`030000
001M000000=8;8`00`00079@VW9@VP04LU2J00<0002:Hj2:Hj001XYSX0030000VVnQVVnQ00NJKj40
0`000:EhX:EhX008YGRP00<0002_OYj_OYh02:mnWP030000^8:J000000800006_iR^00<00039W:W9
W:T01lVLZ@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@04gZFI00<0003[ZHO[ZHL00^^YQ`050000
mZMS0000iHXA000001ooool00`000?ooooooo`0Ioooo000Joooo00<0003oooooool06Oooo`80000I
L]3n00@0002cmO:cmO80000[oooo00<0000005d0000014P/S0030000LU2JLU2J00AbD9X00`0008YS
X8YSX006RV>P00<0002JKj6JKj401iY_X@030000YGRPYGRP00RUN:000`000:mnWZmnWP07[gjN0`00
00VoV:h00`000<VLZLVLZ@07bIbY00<0003CXJ?CXJ<01M>QX`030000gZFIgZFI00CNYIT00`000>^Y
Qn^YQ`02jjV700<0003fYf?fYf<00P0001ooool00`000?ooooooo`0Ioooo000Joooo00<0003ooooo
ool06ooooa/0000]oooo00<0000005d0000014P/S0030000LU2JLU2J00=bD9X00`0008YSX8YSX007
RV>P00<0002JKj6JKj401iY_X@030000YGRPYGRP00RUN:000`000:mnWZmnWP03[gjN10000003]i>b
0000_iR^00ZoV:h00`000<VLZLVLZ@07bIbY00<0003CXJ?CXJ<01M>QX`030000gZFIgZFI00CNYIT0
1@000>^YQn^YQn^YQ`000002mZMS00<0003URQ4000007_ooo`030000oooooooo01Woool001_oool0
0`000?ooooooo`1Roooo00<0000005d0000014P/S0030000LU2JLU2J00=bD9X00`0008YSX8YSX007
RV>P00<0002JKj6JKj401iY_X@030000YGRPYGRP00VUN:000`000:mnWP00000200001[NC/P030000
_iR^_iR^00RoV:h00`000<VLZLVLZ@07bIbY00<0003CXJ?CXJ<01M>QX`030000gZFIgZFI00CNYIT0
0`000>^YQn^YQ`02jjV700<0003fYf?fYf<00P0001goool00`000?ooooooo`0Joooo000Koooo00<0
003oooooool0H_ooo`030000001M000000A8;8`00`00079@VW9@VP03LU2J00<0002:Hj2:Hj001hYS
X0030000VVnQVVnQ00NJKj400`000:EhX:EhX008YGRP0`0000VgTk800`000;nH[[nH[P08_iR^00<0
0039W:W9W:T01lVLZ@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@04gZFI00<0003[ZHO[ZHL00^^Y
Q`050000mZMSmZMS0000iHXA01goool00`000?ooooooo`0Joooo000Koooo00<0003oooooool0H_oo
o`030000001M000000A8;8`00`00079@VW9@VP03LU2J00<0002:Hj2:Hj001hYSX0030000VVnQVVnQ
00RJKj400`000:EhX:EhX003YGRP10000003[Hjf0000]i>b00VgTk800`000;nH[[nH[P09_iR^00<0
0039W:W9W:T01lVLZ@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@04gZFI00<0003[ZHO[ZHL00^^Y
Q`050000mZMS0000iHXA000001coool00`000?ooooooo`0Joooo000Loooo00<0003oooooool0HOoo
o`030000001M000000A8;8`00`00079@VW9@VP03LU2J00<0002:Hj2:Hj001hYSX0030000VVnQVVnQ
00RJKj400`000:EhX000000300001Zf>]P030000]i>b]i>b00RgTk800`000;nH[[nH[P08_iR^00<0
0039W:W9W:T01lVLZ@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@04gZFI00<0003[ZHO[ZHL00^^Y
Q`050000mZMSmZMS0000iHXA01_oool00`000?ooooooo`0Koooo000Loooo00<0003oooooool0H?oo
o`030000001M000000E8;8`00`00079@VW9@VP03LU2J00<0002:Hj2:Hj001hYSX0030000VVnQVVnQ
00NJKj4300002Zf>]P030000]i>b]i>b00RgTk800`000;nH[[nH[P08_iR^00<00039W:W9W:T01lVL
Z@030000dj6Sdj6S00KCXJ<00`000=jUVMjUV@04gZFI00D0003[ZHO[ZHO[ZHL000000_JWH`030000
iHXA000001[oool00`000?ooooooo`0Koooo000Loooo00<0003oooooool0H?ooo`030000001M0000
00E8;8`00`00079@VW9@VP03LU2J00<0002:Hj2:Hj001hYSX0030000VVnQVVnQ00BJKj43000000>Q
R;T0002]S[H02Zf>]P030000]i>b]i>b00VgTk800`000;nH[[nH[P08_iR^00<00039W:W9W:T01lVL
Z@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@04gZFI00<0003[ZHO[ZHL00^^YQ`030000mZMSmZMS
0080000Joooo00<0003oooooool06oooo`007Oooo`030000oooooooo05ooool00`000000G@000004
B2b<00<0001bD9YbD9X0179@VP030000RV>PRV>P00N:Hj000`0009Y_XIY_X@02VVnQ0P0000FQR;T0
0`000:f>]Zf>]P09[Hjf00<0002gTk:gTk802;NC/P030000_iR^_iR^00RoV:h00`000<VLZLVLZ@07
bIbY00<0003CXJ?CXJ<01M>QX`030000gZFIgZFI00CNYIT00`000>^YQn^YQ`02jjV700<0003fYf?f
Yf<00P0001Woool00`000?ooooooo`0Loooo000Moooo00<0003oooooool0Goooo`030000001M0000
00A8;8`00`00079@VW9@VP04LU2J00<0002:Hj2:Hj001hYSX0030000VVnQ000000800007XHRi00<0
002]S[J]S[H02Jf>]P030000]i>b]i>b00RgTk800`000;nH[[nH[P09_iR^00<00039W:W9W:T01/VL
Z@030000dj6Sdj6S00KCXJ<00`000=jUVMjUV@04gZFI00<0003[ZHO[ZHL00^^YQ`@0000Ioooo00<0
003oooooool07?ooo`007_ooo`030000oooooooo05koool00`000000G@000004B2b<00<0001bD9Yb
D9X0179@VP030000RV>PRV>P00F:Hj0400002Z68^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P09
]i>b00<0002oV:joV:h02;nH[P030000bIbYbIbY00O9W:T00`000=>QXm>QX`05dj6S00<0003NYIWN
YIT01=jUV@040000jjV7jjV7jjV70P000003omN60000000001Soool00`000?ooooooo`0Moooo000N
oooo00<0003oooooool0G_ooo`030000001M000000A8;8`00`00079@VW9@VP04LU2J00<0002:Hj2:
Hj001@0000:BOk/00`000:68^J68^@0:XHRi00<0002]S[J]S[H02Jf>]P030000]i>b]i>b00RgTk80
0`000;nH[[nH[P08_iR^00<00039W:W9W:T01lVLZ@030000dj6Sdj6S00GCXJ<00`000=jUVMjUV@05
gZFI0`000003mm2U0000omN60080000Hoooo00<0003oooooool07Oooo`007oooo`030000oooooooo
05coool00`000000G@000005B2b<00<0001bD9YbD9X00g9@VP@00008TWnk00<0002QR;VQR;T02J68
^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P08]i>b00<0002oV:joV:h02KnH[P030000bIbYbIbY
00K9W:T00`000=>QXm>QX`06dj6S00<0003NYIWNYIT00mjUV@800003mm2U00@0003oehH00000000G
oooo00<0003oooooool07_ooo`007oooo`030000oooooooo05coool00`000000G@000005B2b<00<0
001bD9X000000`000003O76l0000TWnk00VBOk/00`000:68^J68^@09XHRi00<0002]S[J]S[H02Zf>
]P030000]i>b]i>b00RgTk800`000;nH[[nH[P08_iR^00<00039W:W9W:T01lVLZ@030000dj6Sdj6S
00GCXJ<010000=jUVMjUVMjUV@8000000nW6/`000?O@Y@02mm2U00@0003oehH00000000Goooo00<0
003oooooool07_ooo`008?ooo`030000oooooooo05_oool00`000000G@000002B2b<1@0000IlLK`0
0`00099o^i9o^`07TWnk00<0002QR;VQR;T02Z68^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P08
]i>b00<0002oV:joV:h02KnH[P030000bIbYbIbY00K9W:T00`000=>QXm>QX`06dj6S0`0000?Ya[<0
1P000?O@YOO@YOO@Y@000?oGQP80000Foooo00<0003oooooool07oooo`008?ooo`030000oooooooo
05_oool500000e9H^P030000O76lO76l00ElLK`00`00099o^i9o^`08TWnk00<0002QR;VQR;T02J68
^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P09]i>b00<0002oV:joV:h02;nH[P030000bIbYbIbY
00O9W:T00`000=>QXm>QX`05dj6S00<0003Ya[?Ya[<00nW6/`060000mm2Umm2Umm2U0000omN60P00
01Koool00`000?ooooooo`0Ooooo000Qoooo00<0003oooooool0F_ooo`03000001NO000000IBF;X0
0`0007aa_7aa_004O76l00<0002BOk^BOk/0299o^`030000XHRiXHRi00VQR;T00`000:f>]Zf>]P0:
[Hjf00<0002gTk:gTk802;NC/P030000_iR^_iR^00RoV:h00`000<VLZLVLZ@07bIbY00<0003CXJ?C
XJ<00m>QX`<00005jLJc00H0003gd:Ggd:Ggd:D0003oehH200005Oooo`030000oooooooo023oool0
027oool00`000?ooooooo`1Koooo0P0GW`030000DURjDURj00=BF;X00`0007aa_7aa_005O76l00<0
002BOk^BOk/01i9o^`030000XHRiXHRi00ZQR;T00`000:f>]Zf>]P09[Hjf00<0002gTk:gTk802;NC
/P030000_iR^_iR^00VoV:h00`000<VLZLVLZ@06bIbY00@0003CXJ?CXJ?CXJ<200000]bn^`030000
jLJcjLJc00?Ya[<01P000?O@YOO@YOO@Y@000?oGQP80000Eoooo00<0003oooooool08?ooo`008_oo
o`030000oooooooo05[oool00`00000GW`000005DURj00<0001lLKalLK`01Gaa_0030000TWnkTWnk
00RBOk/00`000:68^J68^@09XHRi00<0002]S[J]S[H02Jf>]P030000]i>b]i>b00VgTk800`000;nH
[[nH[P08_iR^00<00039W:W9W:T01lVLZ@<00004g;jk00<0003Ya[?Ya[<00nW6/`060000mm2Umm2U
mm2U0000omN60P0001Coool00`000?ooooooo`0Qoooo000Soooo00<0003oooooool0FOooo`030000
01NO000000IBF;X00`0007aa_7aa_004O76l00<0002BOk^BOk/0299o^`030000XHRiXHRi00VQR;T0
0`000:f>]Zf>]P0:[Hjf00<0002gTk:gTk802;NC/P030000_iR^_iR^00RoV:h00`000<VLZLVLZ@06
bIbY0P0000KL_[/00`000>W6/nW6/`03jLJc00H0003gd:Ggd:Ggd:D0003oehH200004oooo`030000
oooooooo02;oool002?oool00`000?ooooooo`1Joooo0P0GW`030000DURjDURj00=BF;X00`0007aa
_7aa_005O76l00<0002BOk^BOk/01i9o^`030000XHRiXHRi00ZQR;T00`000:f>]Zf>]P09[Hjf00<0
002gTk:gTk802;NC/P030000_iR^_iR^00VoV:h00`000<VLZLVLZ@03bIbY0P000003d[O00000g;jk
00GL_[/00`000>W6/nW6/`03jLJc00L0003gd:Ggd:Ggd:D0003oehH000005?ooo`030000oooooooo
02;oool002Coool00`000?ooooooo`1Ioooo00<000005il000001E9H^P030000O76lO76l00ElLK`0
0`00099o^i9o^`08TWnk00<0002QR;VQR;T02J68^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P09
]i>b00<0002oV:joV:h02;nH[P040000bIbYbIbYbIbY0P0000?B]l000`000=bn^mbn^`04g;jk00<0
003Ya[?Ya[<00nW6/`040000mm2Umm2Umm2U0`0001?oool00`000?ooooooo`0Soooo000Uoooo00<0
003oooooool0F?ooo`03000001NO000000IBF;X00`0007aa_7aa_005O76l00<0002BOk^BOk/01i9o
^`030000XHRiXHRi00ZQR;T00`000:f>]Zf>]P09[Hjf00<0002gTk:gTk802;NC/P030000_iR^_iR^
00VoV:h300001M:g`0030000g;jkg;jk00GL_[/00`000>W6/nW6/`02jLJc00@0003gd:Ggd:Ggd:D3
00004_ooo`030000oooooooo02Coool002Goool00`000?ooooooo`1Ioooo00<000005il000001E9H
^P030000O76lO76l00ElLK`00`00099o^i9o^`07TWnk00<0002QR;VQR;T02Z68^@030000[Hjf[Hjf
00V]S[H00`000;NC/[NC/P09]i>b00<0002oV:joV:h01knH[P800008d[O000<0003L_[_L_[/01=bn
^`030000jLJcjLJc00;Ya[<01@000?O@YOO@Y@000?oGQP0200004_ooo`030000oooooooo02Coool0
02Koool00`000?ooooooo`1Hoooo00<000005il000001E9H^P030000O76lO76l00ElLK`00`00099o
^i9o^`08TWnk00<0002QR;VQR;T02J68^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P09]i>b00<0
002oV:joV:h01KnH[P8000000lRba0000=:g`007d[O000<0003L_[_L_[/01=bn^`030000jLJcjLJc
00;Ya[<01@000?O@YOO@Y@000?oGQP0200004Oooo`030000oooooooo02Goool002Koool00`000?oo
ooooo`1Hoooo00<000005il000001U9H^P030000O76lO76l00ElLK`00`00099o^i9o^`07TWnk00<0
002QR;VQR;T02Z68^@030000[Hjf[Hjf00V]S[H00`000;NC/[NC/P08]i>b00<0002oV:joV:h00[nH
[P<00004b;;400<0003B]l3B]l001M:g`0030000g;jkg;jk00CL_[/00`000>W6/nW6/`02jLJc00D0
003gd:Ggd:D0003oehH00P00017oool00`000?ooooooo`0Uoooo000Woooo00<0003oooooool0F?oo
o`03000001NO000000EBF;X00`0007aa_7aa_005O76l00<0002BOk^BOk/0299o^`030000XHRiXHRi
00VQR;T00`000:f>]Zf>]P09[Hjf00<0002gTk:gTk802KNC/P040000_iR^000000001lRba0030000
d[O0d[O000GB]l000`000=bn^mbn^`04g;jk00<0003Ya[?Ya[<00^W6/`050000mm2Umm2U0000omN6
0080000@oooo00<0003oooooool09_ooo`00:?ooo`030000oooooooo05Ooool00`00000GW`000005
DURj00<0001lLKalLK`01Gaa_0030000TWnkTWnk00RBOk/00`000:68^J68^@09XHRi00<0002]S[J]
S[H02Zf>]P030000]i>b]i>b00NgTk8300002LRba0030000d[O0d[O000GB]l000`000=bn^mbn^`04
g;jk00<0003Ya[?Ya[<00^W6/`050000mm2Umm2U0000omN60080000?oooo00<0003oooooool09ooo
o`00:?ooo`030000oooooooo05Ooool00`00000GW`000006DURj00<0001lLKalLK`01Gaa_0030000
TWnkTWnk00NBOk/00`000:68^J68^@0:XHRi00<0002]S[J]S[H02Jf>]P030000]i>b]i>b00FgTk82
000000>n[LP00038//@02LRba0030000d[O0d[O000GB]l000`000=bn^mbn^`04g;jk00<0003Ya[?Y
a[<00^W6/`050000mm2Umm2U0000omN60080000?oooo00<0003oooooool09oooo`00:Oooo`030000
oooooooo05Ooool00`00000GW`000005DURj00<0001lLKalLK`01Gaa_0030000TWnkTWnk00RBOk/0
0`000:68^J68^@09XHRi00<0002]S[J]S[H02Jf>]P030000]i>b]i>b00:gTk8300001;j]b0030000
b;;4b;;400S8//@00`000=:g`=:g`005d[O000<0003L_[_L_[/00mbn^`030000jLJcjLJc00;Ya[<0
1@000?O@YOO@Y@000?oGQP0200003_ooo`030000oooooooo02Soool002[oool00`000?ooooooo`1F
oooo00<000005il000001E9H^P030000O76lO76l00ElLK`00`00099o^i9o^`08TWnk00<0002QR;VQ
R;T02J68^@030000[Hjf[Hjf00Z]S[H010000;NC/P00000000Nn[LP00`000<Rba<Rba008b;;400<0
003B]l3B]l001M:g`0030000g;jkg;jk00?L_[/00`000>W6/nW6/`02jLJc00D0003gd:Ggd:D0003o
ehH00P0000goool00`000?ooooooo`0Yoooo000[oooo00<0003oooooool0EOooo`03000001NO0000
00EBF;X00`0007aa_7aa_006O76l00<0002BOk^BOk/01i9o^`030000XHRiXHRi00ZQR;T00`000:f>
]Zf>]P08[Hjf0`0000Vn[LP00`000<Rba<Rba008b;;400<0003B]l3B]l001M:g`0030000g;jkg;jk
00?L_[/00`000>W6/nW6/`02jLJc00D0003gd:Ggd:D0003oehH00P0000coool00`000?ooooooo`0Z
oooo000/oooo00<0003oooooool0E?ooo`03000001NO000000IBF;X00`0007aa_7aa_005O76l00<0
002BOk^BOk/0299o^`030000XHRiXHRi00VQR;T00`000:f>]Zf>]P05[Hjf0`000003]JW=0000_Zg8
00Zn[LP00`000<Rba<Rba007b;;400<0003B]l3B]l001M:g`0030000g;jkg;jk00?L_[/00`000>W6
/nW6/`02jLJc00D0003gd:Ggd:D0003oehH00P0000_oool00`000?ooooooo`0[oooo000]oooo00<0
003oooooool0E?ooo`03000001NO000000EBF;X00`0007aa_7aa_005O76l00<0002BOk^BOk/0299o
^`030000XHRiXHRi00VQR;T00`000:f>]Zf>]P03[Hjf0P0000FeZLd00`000;j]b;j]b008_Zg800<0
0038//C8//@02<Rba0030000d[O0d[O000CB]l000`000=bn^mbn^`03g;jk00<0003Ya[?Ya[<00^W6
/`030000mm2Umm2U00@0000:oooo00<0003oooooool0;?ooo`00;Oooo`030000oooooooo05Coool0
0`00000GW`000005DURj00<0001lLKalLK`01Waa_0030000TWnkTWnk00NBOk/00`000:68^J68^@0:
XHRi00<0002]S[H000000P0000NeZLd00`000;j]b;j]b008_Zg800<00038//C8//@02<Rba0030000
d[O0d[O000CB]l000`000=bn^mbn^`04g;jk00D0003Ya[?Ya[?Ya[<000000_O@Y@030000hO:G0000
00_oool00`000?ooooooo`0/oooo000^oooo00<0003oooooool0Doooo`03000001NO000000IBF;X0
0`0007aa_7aa_005O76l00<0002BOk^BOk/0299o^`030000XHRiXHRi00RQR;T300002kFYc@030000
_Zg8_Zg800Rn[LP00`000<Rba<Rba007b;;400<0003B]l3B]l001M:g`0030000g;jkg;jk00?L_[/0
1P000>W6/nW6/nW6/`000?O@Y@@0000:oooo00<0003oooooool0;Oooo`00;oooo`030000oooooooo
05?oool00`00000GW`000005DURj00<0001lLKalLK`01Waa_0030000TWnkTWnk00NBOk/00`000:68
^J68^@05XHRi0`0000:YYM800`000;FYcKFYc@09]JW=00<0002n[LRn[LP02;j]b0030000b;;4b;;4
00O8//@00`000=:g`=:g`005d[O000<0003L_[_L_[/00mbn^`040000jLJcjLJcjLJc0`000003hO:G
0000oooo00Woool00`000?ooooooo`0^oooo000`oooo00<0003oooooool0D_ooo`03000001NO0000
00EBF;X00`0007aa_7aa_006O76l00<0002BOk^BOk/01i9o^`030000XHRiXHRi00>QR;T200001JVU
dP030000]JW=]JW=00ZeZLd00`000;j]b;j]b007_Zg800<00038//C8//@02<Rba0030000d[O0d[O0
00CB]l000`000=bn^mbn^`03g;jk00H0003Ya[?Ya[?Ya[<0003_mk`300002Oooo`030000oooooooo
02ooool0037oool00`000?ooooooo`1Aoooo00<000005il000001U9H^P030000O76lO76l00ElLK`0
0`00099o^i9o^`08TWnk00<0002QR;T000000P0000RYYM800`000;FYcKFYc@09]JW=00<0002n[LRn
[LP02;j]b0030000b;;4b;;400O8//@00`000=:g`=:g`004d[O000<0003L_[_L_[/00mbn^`030000
jLJc000000<000000n7bU`000?ooo`08oooo00<0003oooooool0<?ooo`00<_ooo`030000oooooooo
057oool00`00000GW`000005DURj00<0001lLKalLK`01Waa_0030000TWnkTWnk00JBOk/300002jVU
dP030000]JW=]JW=00ZeZLd00`000;j]b;j]b007_Zg800<00038//C8//@01lRba0030000d[O0d[O0
00CB]l000`000=bn^mbn^`03g;jk0P000003jno<0000koNl00<00008oooo00<0003oooooool0<Ooo
o`00<oooo`030000oooooooo053oool00`00000GW`000005DURj00<0001lLKalLK`01Waa_0030000
TWnkTWnk00BBOk/200000Y^Pf0030000ZJGBZJGB00ZYYM800`000;FYcKFYc@09]JW=00<0002n[LRn
[LP02;j]b0030000b;;4b;;400K8//@00`000=:g`=:g`004d[O000<0003L_[_L_[/00mbn^`050000
jno<jno<0000koNl00800008oooo00<0003oooooool0<_ooo`00=?ooo`030000oooooooo04ooool0
0`00000GW`000006DURj00<0001lLKalLK`01Gaa_0030000TWnkTWnk00:BOk/200001I^Pf0030000
ZJGBZJGB00ZYYM800`000;FYcKFYc@09]JW=00<0002n[LRn[LP01kj]b0030000b;;4b;;400O8//@0
0`000=:g`=:g`004d[O000<0003L_[_L_[/00`0000;[kl`400001oooo`030000oooooooo03?oool0
03Goool00`000?ooooooo`1?oooo00<000005il000001E9H^P030000O76lO76l00IlLK`01000099o
^`00000000NKX=P00`000:VUdZVUdP0:ZJGB00<0002eZLfeZLd02KFYc@030000_Zg8_Zg800Nn[LP0
0`000<Rba<Rba007b;;400<0003B]l3B]l001=:g`0<000001^;Ue0000>__c>__c0000>og_0800007
oooo00<0003oooooool0=?ooo`00=_ooo`030000oooooooo04koool00`00000GW`000005DURj00<0
001lLKalLK`017aa_0@0000:Vj3H00<0002YYM:YYM802ZVUdP030000]JW=]JW=00VeZLd00`000;j]
b;j]b007_Zg800<00038//C8//@01/Rba0030000d[O0d[O000?B]l0200000n;Ue0030000jno<jno<
00@00006oooo00<0003oooooool0=Oooo`00=oooo`030000oooooooo04goool00`00000GW`000006
DURj00<0001lLK`000000`0000>4V^000`0009^Pf9^Pf009Vj3H00<0002YYM:YYM802JVUdP030000
]JW=]JW=00VeZLd00`000;j]b;j]b007_Zg800<00038//C8//@01/Rba0040000d[O0d[O0d[O00P00
0003fMgI0000h^GD00;RiM@010000>__c0000>og_0800006oooo00<0003oooooool0=_ooo`00>?oo
o`030000oooooooo04goool00`00000GW`000002DURj1@0000R4V^000`0009^Pf9^Pf009Vj3H00<0
002YYM:YYM802JVUdP030000]JW=]JW=00VeZLd00`000;j]b;j]b006_Zg800<00038//C8//@01lRb
a0<00003fMgI00H0003RiMCRiMCRiM@0003[kl`400001Oooo`030000oooooooo03Ooool003Woool0
0`000?ooooooo`1<oooo1@0000AJRnL00`0008BJh8BJh007Q9[P00<0002KX=RKX=P02I^Pf0030000
ZJGBZJGB00VYYM800`000;FYcKFYc@08]JW=00<0002n[LRn[LP01kj]b0030000b;;4b;;400G8//@2
00001MWMf@040000h^GDh^GD00000^__c0<00005oooo00<0003oooooool0>?ooo`00>_ooo`030000
oooooooo04coool00`00001Le0000006FX_W00<00024V^24V^001hBJh0030000Vj3HVj3H00VKX=P0
0`000:VUdZVUdP08ZJGB00<0002eZLfeZLd02KFYc@030000_Zg8_Zg800Jn[LP00`000<Rba<Rba003
b;;40P000003d=KN0000fMgI00?IgMT020000>;Ue>;Ue>;Ue0000>__c0000>og_0800004oooo00<0
003oooooool0>Oooo`00>oooo`030000oooooooo04coool00`00001Le0000006FX_W00<00024V^24
V^001hBJh0030000Vj3HVj3H00RKX=P00`000:VUdZVUdP09ZJGB00<0002eZLfeZLd02;FYc@030000
_Zg8_Zg800Jn[LP010000<Rba<Rba<Rba0800003d=KN00<0003IgMWIgMT00]WMf@060000h^GDh^GD
h^GD0000jno<0`0000Coool00`000?ooooooo`0joooo000loooo00<0003oooooool0COooo`0305cD
0000000000EJRnL00`0008BJh8BJh007Q9[P00<0002KX=RKX=P029^Pf0030000ZJGBZJGB00VYYM80
0`000;FYcKFYc@08]JW=00<0002n[LRn[LP01[j]b0<00005d=KN00<0003IgMWIgMT00]WMf@060000
h^GDh^GDh^GD0000jno<0`0000?oool00`000?ooooooo`0koooo000moooo00<0003oooooool0COoo
o`03000005cD000000EJRnL2000028BJh0030000Vj3HVj3H00RKX=P00`000:VUdZVUdP08ZJGB00<0
002eZLfeZLd02;FYc@030000_Zg8_Zg800Jn[LP00`000=3Fg]3FgP05d=KN00<0003IgMWIgMT00]WM
f@050000h^GDh^GD0000jno<00<00003oooo00<0003oooooool0??ooo`00?_ooo`030000oooooooo
04goool00`00001Le0000006FX_W00<00024V^24V^001XBJh0030000Vj3HVj3H00RKX=P00`000:VU
dZVUdP08ZJGB00<0002eZLfeZLd02;FYc@030000_Zg8_Zg800>n[LP300001m3FgP030000fMgIfMgI
00;IgMT01@000>;Ue>;Ue0000>__c00200000_ooo`80000ooooo000ooooo0P0004koool00`00001L
e0000006FX_W00<00024V^24V^001XBJh0030000Vj3HVj3H00RKX=P00`000:VUdZVUdP07ZJGB00<0
002eZLfeZLd02;FYc@040000_Zg8_Zg8_Zg80P0000?6d^<00`000=3Fg]3FgP04d=KN00<0003IgMWI
gMT00]WMf@030000h^GDh^GD00<00002oooo00<0003oooooool0?oooo`00@Oooo`030000oooooooo
04goool00`1Le00005Z;i`05FX_W00<00024V^24V^001XBJh0030000Vj3HVj3H00NKX=P00`000:VU
dZVUdP08ZJGB00<0002eZLfeZLd02;FYc@<00005a];S00<0003@e]k@e]h01=3FgP030000fMgIfMgI
00;IgMT00`000>;Ue>;Ue00200000_ooo`030000oooooooo043oool004;oool00`000?ooooooo`1=
oooo0`0000EJRnL00`0008BJh8BJh005Q9[P00<0002KX=RKX=P029^Pf0030000ZJGBZJGB00RYYM80
0`000;FYcKFYc@06]JW=0P0000O6d^<00`000=3Fg]3FgP04d=KN00D0003IgMWIgMWIgMT000000^;U
e0800002oooo00<0003oooooool0@Oooo`00@oooo`030000oooooooo04goool00`00001Le0000005
FX_W00<00024V^24V^001HBJh0030000Vj3HVj3H00RKX=P00`000:VUdZVUdP07ZJGB00<0002eZLfe
ZLd01;FYc@800002_<oX00<00036d^?6d^<01LKBh`030000d=KNd=KN00?@e]h01@000=WMfMWMfMWM
f@000002h^GD0P000003oooo0000oooo04?oool004Coool00`000?ooooooo`1=oooo00<00000G=@0
00001EZ;i`030000Q9[PQ9[P00F4V^000`0009^Pf9^Pf008Vj3H00<0002YYM:YYM801jVUdP040000
]JW=]JW=]JW=0P0000FlcnP00`000<KBhlKBh`04a];S00<0003@e]k@e]h00m3FgP040000fMgIfMgI
fMgI10000003oooo0000oooo04Coool004Goool00`000?ooooooo`1>oooo0P0000EJRnL00`0008BJ
h8BJh005Q9[P00<0002KX=RKX=P029^Pf0030000ZJGBZJGB00JYYM8010000;FYc@00000000NlcnP0
0`000<KBhlKBh`05a];S00<0003@e]k@e]h00]3FgP030000fMgIfMgI00@000000oooo`000?ooo`15
oooo0016oooo0P0004ooool200001EZ;i`030000Q9[PQ9[P00F4V^000`0009^Pf9^Pf008Vj3H00<0
002YYM:YYM801JVUdP80000:_<oX00<00036d^?6d^<01<KBh`030000d=KNd=KN00;@e]h4000000C2
o]H0000000000017oooo0018oooo00<0003oooooool0COooo`<00004FX_W00<00024V^24V^001HBJ
h0030000Vj3HVj3H00NKX=P00`000:VUdZVUdP03ZJGB0P0000:`cNl200002Kc?j0030000a];Sa];S
00?6d^<010000=3Fg]3Fg]3FgP8000000l?mh@000<;neP020000BOooo`00BOooo`80001>oooo00<0
0000G=@0000015Z;i`030000Q9[PQ9[P00F4V^000`0009^Pf9^Pf007Vj3H00<0002YYM:YYM800P00
00J`cNl00`000;c?j;c?j007_<oX00<00036d^?6d^<00lKBh`<000000kkkj@000<?mh@020000Booo
o`00Boooo`80001>oooo0P0000AJRnL200001XBJh0030000Vj3HVj3H00JKX=P300002K3=k`030000
_<oX_<oX00JlcnP00`000<KBhlKBh`02a];S0P0000>nnnT30000C?ooo`00COooo`030000oooooooo
04coool200001EZ;i`030000Q9[PQ9[P00B4V^000`0009^Pf9^Pf003Vj3H0P0000>PcOL200002;3=
k`800007_<oX00H00036d^<00000002fn>h00002___Y0P0004koool004koool20000COooo`800005
FX_W00<00024V^24V^0018BJh0030000Vj3HVj3H00800007X<gg0P0000R`cNl00`000;c?j;c?j005
_<oX00<0002fn>jfn>h00[KhkP<0001?oooo001@oooo0P0004coool3000015Z;i`030000Q9[PQ9[P
00>4V^0300002j3=m`<00006/<g_00<0002lcnRlcnP00[c?j08000001:_dl@0000000;KhkP80001A
oooo001Boooo0P0004coool2000015Z;i`030000Q9[PQ9[P00800003QL[n100000ZPcOL200001K3=
k`8000000kc?j0000:_dl@04ZoCa0P0005;oool005Coool20000Boooo`800002FX_W100000V5b_h4
00002:3=m`800003/<g_2@0005Coool005Koool20000Boooo`800005E;gj1@0000N5b_h300001j3=
m`D0000018?Xk@000000000005Ooool005Soool20000COooo`@00004E;gj1@0000F5b_h400000Z3=
m`8000000h?Xk@00000000030000FOooo`00F_ooo`80001Coooo10000003E;gj0000000000<00004
QL[n200005_oool005coool20000F?ooo`L00003oooo0`0005goool005koool30000G?ooo`<0001P
oooo001Qoooo0`0005Koool30000Hoooo`00I?ooo`<0001Aoooo0P0006Koool006Ooool30000Booo
o`<0001Xoooo001Zoooo0`0004Goool30000Joooo`00KOooo`@0000moooo100006koool0077oool3
0000=oooo`<0001boooo001doooo1@0002goool50000MOooo`00NOooo`H0000Qoooo1P0007[oool0
07ooool:00003Oooo`X00020oooo0029oooo3@0008[oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
      ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}]}], "Input",
  Editable->False,
  CellDingbat->None,
  Background->GrayLevel[1]],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\(\[CapitalDelta]0 = 0.4;\),
        FontColor->RGBColor[0.862745, 0.0784314, 0]], 
      StyleBox["             ",
        FontColor->RGBColor[0.862745, 0.0784314, 0]]}], "\[IndentingNewLine]",
   
    StyleBox[\(\(\[CapitalDelta]1 = 0.42;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(\[CapitalDelta]8 = 0.44;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
    StyleBox[\(\(kembed = 0;\)\(\ \ \)\),
      FontColor->RGBColor[0.862745, 0.0784314, 0]], "\[IndentingNewLine]", 
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61473 .67126 m .64381 .73079 L .61424 .74577 L p .716 .587 .709 r
F P
0 g
s
.64379 .65795 m .67294 .71662 L .64381 .73079 L p .684 .573 .724 r
F P
0 g
s
.64381 .73079 m .61473 .67126 L .64379 .65795 L p .684 .573 .724 r
F P
0 g
s
.64381 .73079 m .67387 .79132 L .64883 .80489 L p .685 .515 .65 r
F P
0 g
s
.64883 .80489 m .61424 .74577 L .64381 .73079 L p .685 .515 .65 r
F P
0 g
s
.67387 .79132 m .64381 .73079 L .67294 .71662 L p .654 .502 .665 r
F P
0 g
s
.61424 .74577 m .58519 .68525 L .61473 .67126 L p .716 .587 .709 r
F P
0 g
s
.58519 .68525 m .61424 .74577 L .58538 .76102 L p .748 .599 .692 r
F P
0 g
s
.61424 .74577 m .64883 .80489 L .62456 .81871 L p .715 .524 .631 r
F P
0 g
s
.62456 .81871 m .58538 .76102 L .61424 .74577 L p .715 .524 .631 r
F P
0 g
s
.5924 .62467 m .61473 .67126 L .58519 .68525 L p .738 .646 .757 r
F P
0 g
s
.6183 .61336 m .64379 .65795 L .61473 .67126 L p .704 .631 .772 r
F P
0 g
s
.61473 .67126 m .5924 .62467 L .6183 .61336 L p .704 .631 .772 r
F P
0 g
s
.58519 .68525 m .56611 .63645 L .5924 .62467 L p .738 .646 .757 r
F P
0 g
s
.56611 .63645 m .58519 .68525 L .55631 .69937 L p .771 .662 .742 r
F P
0 g
s
.58538 .76102 m .55631 .69937 L .58519 .68525 L p .748 .599 .692 r
F P
0 g
s
.6713 .64578 m .70058 .70376 L .67294 .71662 L p .648 .557 .738 r
F P
0 g
s
.67294 .71662 m .64379 .65795 L .6713 .64578 L p .648 .557 .738 r
F P
0 g
s
.69868 .77853 m .67294 .71662 L .70058 .70376 L p .618 .484 .677 r
F P
0 g
s
.67294 .71662 m .69868 .77853 L .67387 .79132 L p .654 .502 .665 r
F P
0 g
s
.64284 .60293 m .6713 .64578 L .64379 .65795 L p .669 .617 .788 r
F P
0 g
s
.64379 .65795 m .6183 .61336 L .64284 .60293 L p .669 .617 .788 r
F P
0 g
s
.55631 .69937 m .58538 .76102 L .55845 .7759 L p .781 .612 .671 r
F P
0 g
s
.58538 .76102 m .62456 .81871 L .60208 .83223 L p .744 .53 .605 r
F P
0 g
s
.60208 .83223 m .55845 .7759 L .58538 .76102 L p .744 .53 .605 r
F P
0 g
s
.55631 .69937 m .54046 .64824 L .56611 .63645 L p .771 .662 .742 r
F P
0 g
s
.54046 .64824 m .55631 .69937 L .52932 .71305 L p .807 .68 .725 r
F P
0 g
s
.55845 .7759 m .52932 .71305 L .55631 .69937 L p .781 .612 .671 r
F P
0 g
s
.27442 .48238 m .22485 .48736 L .22183 .45813 L p .703 .601 .739 r
F P
0 g
s
.27791 .51213 m .22747 .5176 L .22485 .48736 L p .7 .57 .704 r
F P
0 g
s
.22485 .48736 m .27442 .48238 L .27791 .51213 L p .7 .57 .704 r
F P
0 g
s
.22485 .48736 m .17286 .4921 L .17087 .4653 L p .75 .635 .733 r
F P
0 g
s
.17087 .4653 m .22183 .45813 L .22485 .48736 L p .75 .635 .733 r
F P
0 g
s
.17286 .4921 m .22485 .48736 L .22747 .5176 L p .747 .605 .699 r
F P
0 g
s
.28096 .5417 m .22957 .54767 L .22747 .5176 L p .695 .536 .667 r
F P
0 g
s
.22747 .5176 m .27791 .51213 L .28096 .5417 L p .695 .536 .667 r
F P
0 g
s
.17437 .51975 m .22747 .5176 L .22957 .54767 L p .745 .573 .662 r
F P
0 g
s
.22747 .5176 m .17437 .51975 L .17286 .4921 L p .747 .605 .699 r
F P
0 g
s
.31553 .4778 m .27442 .48238 L .27064 .45359 L p .659 .57 .743 r
F P
0 g
s
.31941 .50503 m .27791 .51213 L .27442 .48238 L p .656 .537 .708 r
F P
0 g
s
.27442 .48238 m .31553 .4778 L .31941 .50503 L p .656 .537 .708 r
F P
0 g
s
.22183 .45813 m .27064 .45359 L .27442 .48238 L p .703 .601 .739 r
F P
0 g
s
.32293 .53198 m .28096 .5417 L .27791 .51213 L p .648 .501 .67 r
F P
0 g
s
.27791 .51213 m .31941 .50503 L .32293 .53198 L p .648 .501 .67 r
F P
0 g
s
.69633 .63514 m .72577 .69263 L .70058 .70376 L p .605 .538 .752 r
F P
0 g
s
.70058 .70376 m .6713 .64578 L .69633 .63514 L p .605 .538 .752 r
F P
0 g
s
.72232 .76697 m .70058 .70376 L .72577 .69263 L p .575 .46 .685 r
F P
0 g
s
.70058 .70376 m .72232 .76697 L .69868 .77853 L p .618 .484 .677 r
F P
0 g
s
.66515 .59374 m .69633 .63514 L .6713 .64578 L p .627 .602 .806 r
F P
0 g
s
.6713 .64578 m .64284 .60293 L .66515 .59374 L p .627 .602 .806 r
F P
0 g
s
.27064 .45359 m .22183 .45813 L .21853 .43094 L p .704 .632 .774 r
F P
0 g
s
.22183 .45813 m .17087 .4653 L .16849 .44031 L p .752 .667 .767 r
F P
0 g
s
.16849 .44031 m .21853 .43094 L .22183 .45813 L p .752 .667 .767 r
F P
0 g
s
.57724 .59226 m .5924 .62467 L .56611 .63645 L p .752 .695 .797 r
F P
0 g
s
.59896 .58309 m .6183 .61336 L .5924 .62467 L p .718 .68 .812 r
F P
0 g
s
.5924 .62467 m .57724 .59226 L .59896 .58309 L p .718 .68 .812 r
F P
0 g
s
.27064 .45359 m .31145 .45138 L .31553 .4778 L p .659 .57 .743 r
F P
0 g
s
.31145 .45138 m .27064 .45359 L .26673 .42678 L p .659 .6 .778 r
F P
0 g
s
.21853 .43094 m .26673 .42678 L .27064 .45359 L p .704 .632 .774 r
F P
0 g
s
.2834 .56978 m .231 .57626 L .22957 .54767 L p .687 .495 .622 r
F P
0 g
s
.22957 .54767 m .28096 .5417 L .2834 .56978 L p .687 .495 .622 r
F P
0 g
s
.17531 .54716 m .22957 .54767 L .231 .57626 L p .741 .538 .619 r
F P
0 g
s
.22957 .54767 m .17531 .54716 L .17437 .51975 L p .745 .573 .662 r
F P
0 g
s
.56611 .63645 m .55524 .60174 L .57724 .59226 L p .752 .695 .797 r
F P
0 g
s
.55524 .60174 m .56611 .63645 L .54046 .64824 L p .786 .713 .783 r
F P
0 g
s
.67387 .79132 m .69682 .83679 L .67925 .84679 L p .639 .422 .573 r
F P
0 g
s
.67925 .84679 m .64883 .80489 L .67387 .79132 L p .639 .422 .573 r
F P
0 g
s
.69682 .83679 m .67387 .79132 L .69868 .77853 L p .609 .41 .587 r
F P
0 g
s
.32593 .55746 m .2834 .56978 L .28096 .5417 L p .635 .457 .625 r
F P
0 g
s
.28096 .5417 m .32293 .53198 L .32593 .55746 L p .635 .457 .625 r
F P
0 g
s
.64883 .80489 m .67925 .84679 L .66237 .85694 L p .664 .427 .552 r
F P
0 g
s
.66237 .85694 m .62456 .81871 L .64883 .80489 L p .664 .427 .552 r
F P
0 g
s
.52932 .71305 m .55845 .7759 L .53472 .78975 L p .819 .626 .642 r
F P
0 g
s
.55845 .7759 m .60208 .83223 L .58246 .84484 L p .774 .531 .568 r
F P
0 g
s
.58246 .84484 m .53472 .78975 L .55845 .7759 L p .774 .531 .568 r
F P
0 g
s
.61958 .57457 m .64284 .60293 L .6183 .61336 L p .683 .667 .828 r
F P
0 g
s
.6183 .61336 m .59896 .58309 L .61958 .57457 L p .683 .667 .828 r
F P
0 g
s
.17286 .4921 m .12781 .49582 L .12674 .4741 L p .8 .673 .723 r
F P
0 g
s
.12674 .4741 m .17087 .4653 L .17286 .4921 L p .8 .673 .723 r
F P
0 g
s
.12781 .49582 m .17286 .4921 L .17437 .51975 L p .798 .644 .69 r
F P
0 g
s
.52932 .71305 m .51654 .65954 L .54046 .64824 L p .807 .68 .725 r
F P
0 g
s
.51654 .65954 m .52932 .71305 L .50547 .72569 L p .848 .703 .703 r
F P
0 g
s
.53472 .78975 m .50547 .72569 L .52932 .71305 L p .819 .626 .642 r
F P
0 g
s
.71435 .82734 m .69868 .77853 L .72232 .76697 L p .574 .391 .595 r
F P
0 g
s
.69868 .77853 m .71435 .82734 L .69682 .83679 L p .609 .41 .587 r
F P
0 g
s
.12841 .51809 m .17437 .51975 L .17531 .54716 L p .798 .615 .654 r
F P
0 g
s
.17437 .51975 m .12841 .51809 L .12781 .49582 L p .798 .644 .69 r
F P
0 g
s
.34712 .4739 m .31553 .4778 L .31145 .45138 L p .62 .541 .745 r
F P
0 g
s
.35098 .49777 m .31941 .50503 L .31553 .4778 L p .616 .509 .709 r
F P
0 g
s
.31553 .4778 m .34712 .4739 L .35098 .49777 L p .616 .509 .709 r
F P
0 g
s
.35454 .52129 m .32293 .53198 L .31941 .50503 L p .606 .47 .671 r
F P
0 g
s
.31941 .50503 m .35098 .49777 L .35454 .52129 L p .606 .47 .671 r
F P
0 g
s
.54046 .64824 m .53385 .61115 L .55524 .60174 L p .786 .713 .783 r
F P
0 g
s
.53385 .61115 m .54046 .64824 L .51654 .65954 L p .822 .736 .769 r
F P
0 g
s
.26673 .42678 m .21853 .43094 L .21509 .40664 L p .702 .665 .811 r
F P
0 g
s
.21853 .43094 m .16849 .44031 L .16581 .41796 L p .754 .701 .802 r
F P
0 g
s
.16581 .41796 m .21509 .40664 L .21853 .43094 L p .754 .701 .802 r
F P
0 g
s
.62456 .81871 m .66237 .85694 L .64693 .86682 L p .686 .424 .521 r
F P
0 g
s
.64693 .86682 m .60208 .83223 L .62456 .81871 L p .686 .424 .521 r
F P
0 g
s
.17087 .4653 m .12674 .4741 L .12525 .45376 L p .804 .704 .755 r
F P
0 g
s
.12525 .45376 m .16849 .44031 L .17087 .4653 L p .804 .704 .755 r
F P
0 g
s
.26673 .42678 m .30735 .42671 L .31145 .45138 L p .659 .6 .778 r
F P
0 g
s
.30735 .42671 m .26673 .42678 L .26283 .40281 L p .653 .631 .815 r
F P
0 g
s
.21509 .40664 m .26283 .40281 L .26673 .42678 L p .702 .665 .811 r
F P
0 g
s
.31145 .45138 m .34312 .45063 L .34712 .4739 L p .62 .541 .745 r
F P
0 g
s
.34312 .45063 m .31145 .45138 L .30735 .42671 L p .618 .571 .78 r
F P
0 g
s
.61855 .28409 m .63552 .25693 L .65789 .27065 L p .702 .559 .69 r
F P
0 g
s
.59704 .27018 m .61362 .24297 L .63552 .25693 L p .732 .6 .709 r
F P
0 g
s
.63552 .25693 m .61855 .28409 L .59704 .27018 L p .732 .6 .709 r
F P
0 g
s
.63552 .25693 m .65358 .22785 L .67531 .24092 L p .685 .568 .718 r
F P
0 g
s
.67531 .24092 m .65789 .27065 L .63552 .25693 L p .685 .568 .718 r
F P
0 g
s
.65358 .22785 m .63552 .25693 L .61362 .24297 L p .714 .608 .736 r
F P
0 g
s
.231 .57626 m .17561 .57314 L .17531 .54716 L p .741 .538 .619 r
F P
0 g
s
.12849 .54001 m .17531 .54716 L .17561 .57314 L p .799 .585 .612 r
F P
0 g
s
.17531 .54716 m .12849 .54001 L .12841 .51809 L p .798 .615 .654 r
F P
0 g
s
.71805 .62639 m .7477 .68359 L .72577 .69263 L p .549 .511 .766 r
F P
0 g
s
.72577 .69263 m .69633 .63514 L .71805 .62639 L p .549 .511 .766 r
F P
0 g
s
.74396 .75704 m .72577 .69263 L .7477 .68359 L p .517 .424 .689 r
F P
0 g
s
.72577 .69263 m .74396 .75704 L .72232 .76697 L p .575 .46 .685 r
F P
0 g
s
.2851 .595 m .23168 .60197 L .231 .57626 L p .673 .444 .565 r
F P
0 g
s
.231 .57626 m .2834 .56978 L .2851 .595 L p .673 .444 .565 r
F P
0 g
s
.17561 .57314 m .231 .57626 L .23168 .60197 L p .736 .494 .562 r
F P
0 g
s
.65789 .27065 m .6405 .29776 L .61855 .28409 L p .702 .559 .69 r
F P
0 g
s
.6405 .29776 m .65789 .27065 L .67985 .28356 L p .668 .516 .668 r
F P
0 g
s
.65789 .27065 m .67531 .24092 L .69665 .25318 L p .651 .525 .697 r
F P
0 g
s
.69665 .25318 m .67985 .28356 L .65789 .27065 L p .651 .525 .697 r
F P
0 g
s
.35764 .5434 m .32593 .55746 L .32293 .53198 L p .587 .422 .625 r
F P
0 g
s
.32293 .53198 m .35454 .52129 L .35764 .5434 L p .587 .422 .625 r
F P
0 g
s
.60355 .30791 m .61855 .28409 L .6405 .29776 L p .715 .551 .665 r
F P
0 g
s
.58315 .29457 m .59704 .27018 L .61855 .28409 L p .746 .592 .684 r
F P
0 g
s
.61855 .28409 m .60355 .30791 L .58315 .29457 L p .746 .592 .684 r
F P
0 g
s
.63833 .56702 m .66515 .59374 L .64284 .60293 L p .641 .655 .848 r
F P
0 g
s
.64284 .60293 m .61958 .57457 L .63833 .56702 L p .641 .655 .848 r
F P
0 g
s
.68446 .5861 m .71805 .62639 L .69633 .63514 L p .572 .583 .826 r
F P
0 g
s
.69633 .63514 m .66515 .59374 L .68446 .5861 L p .572 .583 .826 r
F P
0 g
s
.57682 .25661 m .59305 .2293 L .61362 .24297 L p .762 .64 .727 r
F P
0 g
s
.61362 .24297 m .59704 .27018 L .57682 .25661 L p .762 .64 .727 r
F P
0 g
s
.63233 .21449 m .61362 .24297 L .59305 .2293 L p .743 .648 .754 r
F P
0 g
s
.61362 .24297 m .63233 .21449 L .65358 .22785 L p .714 .608 .736 r
F P
0 g
s
.73117 .81881 m .72232 .76697 L .74396 .75704 L p .529 .36 .596 r
F P
0 g
s
.72232 .76697 m .73117 .81881 L .71435 .82734 L p .574 .391 .595 r
F P
0 g
s
.32823 .58024 m .2851 .595 L .2834 .56978 L p .612 .398 .566 r
F P
0 g
s
.2834 .56978 m .32593 .55746 L .32823 .58024 L p .612 .398 .566 r
F P
0 g
s
.6405 .29776 m .62435 .32105 L .60355 .30791 L p .715 .551 .665 r
F P
0 g
s
.62435 .32105 m .6405 .29776 L .66201 .31066 L p .682 .506 .642 r
F P
0 g
s
.67985 .28356 m .66201 .31066 L .6405 .29776 L p .668 .516 .668 r
F P
0 g
s
.65358 .22785 m .67121 .19929 L .69106 .21101 L p .664 .576 .747 r
F P
0 g
s
.69106 .21101 m .67531 .24092 L .65358 .22785 L p .664 .576 .747 r
F P
0 g
s
.67121 .19929 m .65358 .22785 L .63233 .21449 L p .693 .615 .765 r
F P
0 g
s
.56396 .28155 m .57682 .25661 L .59704 .27018 L p .777 .632 .701 r
F P
0 g
s
.59704 .27018 m .58315 .29457 L .56396 .28155 L p .777 .632 .701 r
F P
0 g
s
.67531 .24092 m .69106 .21101 L .71055 .22195 L p .63 .535 .728 r
F P
0 g
s
.71055 .22195 m .69665 .25318 L .67531 .24092 L p .63 .535 .728 r
F P
0 g
s
.59305 .2293 m .61238 .20138 L .63233 .21449 L p .743 .648 .754 r
F P
0 g
s
.6518 .18727 m .63233 .21449 L .61238 .20138 L p .72 .655 .783 r
F P
0 g
s
.63233 .21449 m .6518 .18727 L .67121 .19929 L p .693 .615 .765 r
F P
0 g
s
.59076 .32808 m .60355 .30791 L .62435 .32105 L p .727 .543 .643 r
F P
0 g
s
.57183 .31558 m .58315 .29457 L .60355 .30791 L p .757 .584 .662 r
F P
0 g
s
.60355 .30791 m .59076 .32808 L .57183 .31558 L p .757 .584 .662 r
F P
0 g
s
.16849 .44031 m .12525 .45376 L .12342 .43551 L p .809 .739 .787 r
F P
0 g
s
.12342 .43551 m .16581 .41796 L .16849 .44031 L p .809 .739 .787 r
F P
0 g
s
.66201 .31066 m .67985 .28356 L .70047 .29511 L p .629 .465 .641 r
F P
0 g
s
.67985 .28356 m .69665 .25318 L .71671 .26411 L p .611 .476 .673 r
F P
0 g
s
.71671 .26411 m .70047 .29511 L .67985 .28356 L p .611 .476 .673 r
F P
0 g
s
.30735 .42671 m .33916 .42883 L .34312 .45063 L p .618 .571 .78 r
F P
0 g
s
.33916 .42883 m .30735 .42671 L .30336 .40462 L p .609 .6 .817 r
F P
0 g
s
.26283 .40281 m .30336 .40462 L .30735 .42671 L p .653 .631 .815 r
F P
0 g
s
.51654 .65954 m .514 .62008 L .53385 .61115 L p .822 .736 .769 r
F P
0 g
s
.514 .62008 m .51654 .65954 L .49548 .66985 L p .864 .766 .752 r
F P
0 g
s
.50547 .72569 m .49548 .66985 L .51654 .65954 L p .848 .703 .703 r
F P
0 g
s
.62435 .32105 m .61003 .34038 L .59076 .32808 L p .727 .543 .643 r
F P
0 g
s
.61003 .34038 m .62435 .32105 L .64469 .33344 L p .694 .498 .618 r
F P
0 g
s
.66201 .31066 m .64469 .33344 L .62435 .32105 L p .682 .506 .642 r
F P
0 g
s
.37084 .47064 m .34712 .4739 L .34312 .45063 L p .587 .519 .745 r
F P
0 g
s
.37444 .49116 m .35098 .49777 L .34712 .4739 L p .582 .485 .709 r
F P
0 g
s
.34712 .4739 m .37084 .47064 L .37444 .49116 L p .582 .485 .709 r
F P
0 g
s
.56723 .57027 m .57724 .59226 L .55524 .60174 L p .76 .731 .826 r
F P
0 g
s
.58501 .56293 m .59896 .58309 L .57724 .59226 L p .727 .716 .84 r
F P
0 g
s
.57724 .59226 m .56723 .57027 L .58501 .56293 L p .727 .716 .84 r
F P
0 g
s
.64469 .33344 m .66201 .31066 L .68217 .32223 L p .644 .454 .611 r
F P
0 g
s
.70047 .29511 m .68217 .32223 L .66201 .31066 L p .629 .465 .641 r
F P
0 g
s
.60208 .83223 m .64693 .86682 L .63362 .876 L p .706 .411 .475 r
F P
0 g
s
.63362 .876 m .58246 .84484 L .60208 .83223 L p .706 .411 .475 r
F P
0 g
s
.37778 .51128 m .35454 .52129 L .35098 .49777 L p .57 .445 .671 r
F P
0 g
s
.35098 .49777 m .37444 .49116 L .37778 .51128 L p .57 .445 .671 r
F P
0 g
s
.55402 .30339 m .56396 .28155 L .58315 .29457 L p .788 .625 .678 r
F P
0 g
s
.58315 .29457 m .57183 .31558 L .55402 .30339 L p .788 .625 .678 r
F P
0 g
s
.55866 .24389 m .57458 .21646 L .59305 .2293 L p .793 .684 .743 r
F P
0 g
s
.59305 .2293 m .57682 .25661 L .55866 .24389 L p .793 .684 .743 r
F P
0 g
s
.61238 .20138 m .59305 .2293 L .57458 .21646 L p .773 .691 .773 r
F P
0 g
s
.55524 .60174 m .54927 .57781 L .56723 .57027 L p .76 .731 .826 r
F P
0 g
s
.54927 .57781 m .55524 .60174 L .53385 .61115 L p .794 .751 .814 r
F P
0 g
s
.69665 .25318 m .71055 .22195 L .72886 .23164 L p .589 .488 .707 r
F P
0 g
s
.72886 .23164 m .71671 .26411 L .69665 .25318 L p .589 .488 .707 r
F P
0 g
s
.50547 .72569 m .53472 .78975 L .51544 .80189 L p .864 .639 .597 r
F P
0 g
s
.53472 .78975 m .58246 .84484 L .56671 .85592 L p .807 .524 .51 r
F P
0 g
s
.56671 .85592 m .51544 .80189 L .53472 .78975 L p .807 .524 .51 r
F P
0 g
s
.23168 .60197 m .17522 .5964 L .17561 .57314 L p .736 .494 .562 r
F P
0 g
s
.12803 .56063 m .17561 .57314 L .17522 .5964 L p .801 .549 .557 r
F P
0 g
s
.17561 .57314 m .12803 .56063 L .12849 .54001 L p .799 .585 .612 r
F P
0 g
s
.26283 .40281 m .21509 .40664 L .21163 .38597 L p .696 .703 .852 r
F P
0 g
s
.21509 .40664 m .16581 .41796 L .16295 .39893 L p .755 .742 .841 r
F P
0 g
s
.16295 .39893 m .21163 .38597 L .21509 .40664 L p .755 .742 .841 r
F P
0 g
s
.5467 .26939 m .55866 .24389 L .57682 .25661 L p .81 .676 .716 r
F P
0 g
s
.57682 .25661 m .56396 .28155 L .5467 .26939 L p .81 .676 .716 r
F P
0 g
s
.36011 .56305 m .32823 .58024 L .32593 .55746 L p .556 .357 .566 r
F P
0 g
s
.32593 .55746 m .35764 .5434 L .36011 .56305 L p .556 .357 .566 r
F P
0 g
s
.34312 .45063 m .36714 .45055 L .37084 .47064 L p .587 .519 .745 r
F P
0 g
s
.36714 .45055 m .34312 .45063 L .33916 .42883 L p .584 .548 .78 r
F P
0 g
s
.60192 .55608 m .61958 .57457 L .59896 .58309 L p .691 .704 .857 r
F P
0 g
s
.59896 .58309 m .58501 .56293 L .60192 .55608 L p .691 .704 .857 r
F P
0 g
s
.49548 .66985 m .50547 .72569 L .48602 .73663 L p .898 .733 .669 r
F P
0 g
s
.51544 .80189 m .48602 .73663 L .50547 .72569 L p .864 .639 .597 r
F P
0 g
s
.30336 .40462 m .26283 .40281 L .25907 .38242 L p .64 .664 .857 r
F P
0 g
s
.21163 .38597 m .25907 .38242 L .26283 .40281 L p .696 .703 .852 r
F P
0 g
s
.67121 .19929 m .68667 .1741 L .70358 .18392 L p .638 .585 .778 r
F P
0 g
s
.70358 .18392 m .69106 .21101 L .67121 .19929 L p .638 .585 .778 r
F P
0 g
s
.68667 .1741 m .67121 .19929 L .6518 .18727 L p .667 .622 .795 r
F P
0 g
s
.57458 .21646 m .59448 .18902 L .61238 .20138 L p .773 .691 .773 r
F P
0 g
s
.63358 .17542 m .61238 .20138 L .59448 .18902 L p .747 .697 .804 r
F P
0 g
s
.61238 .20138 m .63358 .17542 L .6518 .18727 L p .72 .655 .783 r
F P
0 g
s
.65454 .56069 m .68446 .5861 L .66515 .59374 L p .586 .641 .872 r
F P
0 g
s
.66515 .59374 m .63833 .56702 L .65454 .56069 L p .586 .641 .872 r
F P
0 g
s
.69106 .21101 m .70358 .18392 L .72016 .19303 L p .605 .545 .761 r
F P
0 g
s
.72016 .19303 m .71055 .22195 L .69106 .21101 L p .605 .545 .761 r
F P
0 g
s
.57999 .34493 m .59076 .32808 L .61003 .34038 L p .735 .536 .624 r
F P
0 g
s
.56265 .33338 m .57183 .31558 L .59076 .32808 L p .766 .578 .644 r
F P
0 g
s
.59076 .32808 m .57999 .34493 L .56265 .33338 L p .766 .578 .644 r
F P
0 g
s
.64469 .33344 m .62886 .35197 L .61003 .34038 L p .694 .498 .618 r
F P
0 g
s
.62886 .35197 m .64469 .33344 L .66372 .34456 L p .655 .444 .585 r
F P
0 g
s
.68217 .32223 m .66372 .34456 L .64469 .33344 L p .644 .454 .611 r
F P
0 g
s
.38072 .5301 m .35764 .5434 L .35454 .52129 L p .548 .394 .625 r
F P
0 g
s
.35454 .52129 m .37778 .51128 L .38072 .5301 L p .548 .394 .625 r
F P
0 g
s
.67013 .16399 m .6518 .18727 L .63358 .17542 L p .692 .66 .814 r
F P
0 g
s
.6518 .18727 m .67013 .16399 L .68667 .1741 L p .667 .622 .795 r
F P
0 g
s
.7477 .68359 m .76285 .74907 L .74396 .75704 L p .517 .424 .689 r
F P
0 g
s
.74664 .81151 m .74396 .75704 L .76285 .74907 L p .47 .315 .588 r
F P
0 g
s
.74396 .75704 m .74664 .81151 L .73117 .81881 L p .529 .36 .596 r
F P
0 g
s
.53385 .61115 m .53188 .58524 L .54927 .57781 L p .794 .751 .814 r
F P
0 g
s
.53188 .58524 m .53385 .61115 L .514 .62008 L p .83 .777 .802 r
F P
0 g
s
.61003 .34038 m .59764 .35626 L .57999 .34493 L p .735 .536 .624 r
F P
0 g
s
.59764 .35626 m .61003 .34038 L .62886 .35197 L p .702 .49 .598 r
F P
0 g
s
.12781 .49582 m .09618 .49815 L .09569 .48268 L p .855 .714 .706 r
F P
0 g
s
.09569 .48268 m .12674 .4741 L .12781 .49582 L p .855 .714 .706 r
F P
0 g
s
.09618 .49815 m .12781 .49582 L .12841 .51809 L p .854 .688 .676 r
F P
0 g
s
.538 .29201 m .5467 .26939 L .56396 .28155 L p .822 .668 .691 r
F P
0 g
s
.56396 .28155 m .55402 .30339 L .538 .29201 L p .822 .668 .691 r
F P
0 g
s
.54632 .32211 m .55402 .30339 L .57183 .31558 L p .797 .619 .659 r
F P
0 g
s
.57183 .31558 m .56265 .33338 L .54632 .32211 L p .797 .619 .659 r
F P
0 g
s
.0963 .5139 m .12841 .51809 L .12849 .54001 L p .855 .663 .641 r
F P
0 g
s
.12841 .51809 m .0963 .5139 L .09618 .49815 L p .854 .688 .676 r
F P
0 g
s
.28594 .61596 m .23153 .62337 L .23168 .60197 L p .648 .368 .481 r
F P
0 g
s
.23168 .60197 m .2851 .595 L .28594 .61596 L p .648 .368 .481 r
F P
0 g
s
.17522 .5964 m .23168 .60197 L .23153 .62337 L p .726 .432 .481 r
F P
0 g
s
.68217 .32223 m .70047 .29511 L .71885 .30479 L p .577 .399 .603 r
F P
0 g
s
.70047 .29511 m .71671 .26411 L .73461 .27321 L p .558 .414 .641 r
F P
0 g
s
.73461 .27321 m .71885 .30479 L .70047 .29511 L p .558 .414 .641 r
F P
0 g
s
.61731 .54997 m .63833 .56702 L .61958 .57457 L p .649 .694 .878 r
F P
0 g
s
.61958 .57457 m .60192 .55608 L .61731 .54997 L p .649 .694 .878 r
F P
0 g
s
.3297 .59908 m .28594 .61596 L .2851 .595 L p .571 .309 .48 r
F P
0 g
s
.2851 .595 m .32823 .58024 L .3297 .59908 L p .571 .309 .48 r
F P
0 g
s
.73573 .61981 m .76563 .67694 L .7477 .68359 L p .468 .471 .778 r
F P
0 g
s
.7477 .68359 m .71805 .62639 L .73573 .61981 L p .468 .471 .778 r
F P
0 g
s
.76285 .74907 m .7477 .68359 L .76563 .67694 L p .433 .369 .686 r
F P
0 g
s
.16581 .41796 m .12342 .43551 L .12132 .41995 L p .815 .782 .822 r
F P
0 g
s
.12132 .41995 m .16295 .39893 L .16581 .41796 L p .815 .782 .822 r
F P
0 g
s
.12674 .4741 m .09569 .48268 L .09486 .4681 L p .859 .744 .735 r
F P
0 g
s
.09486 .4681 m .12525 .45376 L .12674 .4741 L p .859 .744 .735 r
F P
0 g
s
.33916 .42883 m .36349 .43166 L .36714 .45055 L p .584 .548 .78 r
F P
0 g
s
.36349 .43166 m .33916 .42883 L .33536 .40926 L p .573 .575 .816 r
F P
0 g
s
.30336 .40462 m .33536 .40926 L .33916 .42883 L p .609 .6 .817 r
F P
0 g
s
.71055 .22195 m .72016 .19303 L .73571 .20104 L p .563 .5 .743 r
F P
0 g
s
.73571 .20104 m .72886 .23164 L .71055 .22195 L p .563 .5 .743 r
F P
0 g
s
.66372 .34456 m .68217 .32223 L .7001 .33196 L p .593 .385 .568 r
F P
0 g
s
.71885 .30479 m .7001 .33196 L .68217 .32223 L p .577 .399 .603 r
F P
0 g
s
.33536 .40926 m .30336 .40462 L .29964 .38579 L p .589 .628 .858 r
F P
0 g
s
.25907 .38242 m .29964 .38579 L .30336 .40462 L p .64 .664 .857 r
F P
0 g
s
.70011 .58026 m .73573 .61981 L .71805 .62639 L p .492 .555 .848 r
F P
0 g
s
.71805 .62639 m .68446 .5861 L .70011 .58026 L p .492 .555 .848 r
F P
0 g
s
.54322 .23253 m .5589 .20494 L .57458 .21646 L p .828 .734 .76 r
F P
0 g
s
.57458 .21646 m .55866 .24389 L .54322 .23253 L p .828 .734 .76 r
F P
0 g
s
.59448 .18902 m .57458 .21646 L .5589 .20494 L p .805 .741 .793 r
F P
0 g
s
.71671 .26411 m .72886 .23164 L .7452 .23964 L p .535 .429 .681 r
F P
0 g
s
.7452 .23964 m .73461 .27321 L .71671 .26411 L p .535 .429 .681 r
F P
0 g
s
.59448 .18902 m .61726 .16421 L .63358 .17542 L p .747 .697 .804 r
F P
0 g
s
.65461 .15399 m .63358 .17542 L .61726 .16421 L p .715 .702 .836 r
F P
0 g
s
.63358 .17542 m .65461 .15399 L .67013 .16399 L p .692 .66 .814 r
F P
0 g
s
.62886 .35197 m .61485 .36692 L .59764 .35626 L p .702 .49 .598 r
F P
0 g
s
.61485 .36692 m .62886 .35197 L .64641 .36236 L p .664 .435 .562 r
F P
0 g
s
.66372 .34456 m .64641 .36236 L .62886 .35197 L p .655 .444 .585 r
F P
0 g
s
.09603 .52927 m .12849 .54001 L .12803 .56063 L p .86 .637 .6 r
F P
0 g
s
.12849 .54001 m .09603 .52927 L .0963 .5139 L p .855 .663 .641 r
F P
0 g
s
.38891 .46789 m .37084 .47064 L .36714 .45055 L p .565 .503 .744 r
F P
0 g
s
.39215 .48545 m .37444 .49116 L .37084 .47064 L p .56 .469 .709 r
F P
0 g
s
.37084 .47064 m .38891 .46789 L .39215 .48545 L p .56 .469 .709 r
F P
0 g
s
.57091 .35903 m .57999 .34493 L .59764 .35626 L p .741 .531 .61 r
F P
0 g
s
.55508 .34843 m .56265 .33338 L .57999 .34493 L p .771 .573 .63 r
F P
0 g
s
.57999 .34493 m .57091 .35903 L .55508 .34843 L p .771 .573 .63 r
F P
0 g
s
.53204 .25856 m .54322 .23253 L .55866 .24389 L p .847 .725 .729 r
F P
0 g
s
.55866 .24389 m .5467 .26939 L .53204 .25856 L p .847 .725 .729 r
F P
0 g
s
.53164 .3116 m .538 .29201 L .55402 .30339 L p .832 .661 .671 r
F P
0 g
s
.55402 .30339 m .54632 .32211 L .53164 .3116 L p .832 .661 .671 r
F P
0 g
s
.39517 .50259 m .37778 .51128 L .37444 .49116 L p .545 .428 .67 r
F P
0 g
s
.37444 .49116 m .39215 .48545 L .39517 .50259 L p .545 .428 .67 r
F P
0 g
s
.38311 .54672 m .36011 .56305 L .35764 .5434 L p .509 .323 .564 r
F P
0 g
s
.35764 .5434 m .38072 .5301 L .38311 .54672 L p .509 .323 .564 r
F P
0 g
s
.5589 .20494 m .57932 .17788 L .59448 .18902 L p .805 .741 .793 r
F P
0 g
s
.61726 .16421 m .59448 .18902 L .57932 .17788 L p .775 .747 .828 r
F P
0 g
s
.59764 .35626 m .58701 .3694 L .57091 .35903 L p .741 .531 .61 r
F P
0 g
s
.58701 .3694 m .59764 .35626 L .61485 .36692 L p .708 .484 .582 r
F P
0 g
s
.49548 .66985 m .4966 .62814 L .514 .62008 L p .864 .766 .752 r
F P
0 g
s
.4966 .62814 m .49548 .66985 L .47834 .67866 L p .914 .806 .726 r
F P
0 g
s
.48602 .73663 m .47834 .67866 L .49548 .66985 L p .898 .733 .669 r
F P
0 g
s
.69682 .83679 m .70978 .86204 L .69944 .86808 L p .564 .293 .463 r
F P
0 g
s
.69944 .86808 m .67925 .84679 L .69682 .83679 L p .564 .293 .463 r
F P
0 g
s
.70978 .86204 m .69682 .83679 L .71435 .82734 L p .538 .282 .476 r
F P
0 g
s
.64641 .36236 m .66372 .34456 L .68059 .35393 L p .606 .373 .537 r
F P
0 g
s
.7001 .33196 m .68059 .35393 L .66372 .34456 L p .593 .385 .568 r
F P
0 g
s
.54019 .33806 m .54632 .32211 L .56265 .33338 L p .803 .613 .645 r
F P
0 g
s
.56265 .33338 m .55508 .34843 L .54019 .33806 L p .803 .613 .645 r
F P
0 g
s
.58246 .84484 m .63362 .876 L .62312 .88403 L p .72 .38 .403 r
F P
0 g
s
.62312 .88403 m .56671 .85592 L .58246 .84484 L p .72 .38 .403 r
F P
0 g
s
.36714 .45055 m .38557 .45063 L .38891 .46789 L p .565 .503 .744 r
F P
0 g
s
.38557 .45063 m .36714 .45055 L .36349 .43166 L p .562 .532 .779 r
F P
0 g
s
.514 .62008 m .5158 .59225 L .53188 .58524 L p .83 .777 .802 r
F P
0 g
s
.5158 .59225 m .514 .62008 L .4966 .62814 L p .871 .811 .788 r
F P
0 g
s
.67925 .84679 m .69944 .86808 L .6896 .87418 L p .583 .292 .44 r
F P
0 g
s
.6896 .87418 m .66237 .85694 L .67925 .84679 L p .583 .292 .44 r
F P
0 g
s
.12525 .45376 m .09486 .4681 L .09372 .45497 L p .867 .779 .762 r
F P
0 g
s
.09372 .45497 m .12342 .43551 L .12525 .45376 L p .867 .779 .762 r
F P
0 g
s
.23153 .62337 m .17412 .61569 L .17522 .5964 L p .726 .432 .481 r
F P
0 g
s
.12703 .57895 m .17522 .5964 L .17412 .61569 L p .803 .502 .48 r
F P
0 g
s
.17522 .5964 m .12703 .57895 L .12803 .56063 L p .801 .549 .557 r
F P
0 g
s
.72018 .85631 m .71435 .82734 L .73117 .81881 L p .504 .261 .479 r
F P
0 g
s
.71435 .82734 m .72018 .85631 L .70978 .86204 L p .538 .282 .476 r
F P
0 g
s
.52439 .28191 m .53204 .25856 L .5467 .26939 L p .861 .716 .7 r
F P
0 g
s
.5467 .26939 m .538 .29201 L .52439 .28191 L p .861 .716 .7 r
F P
0 g
s
.68667 .1741 m .69875 .15432 L .71213 .16198 L p .606 .592 .811 r
F P
0 g
s
.71213 .16198 m .70358 .18392 L .68667 .1741 L p .606 .592 .811 r
F P
0 g
s
.69875 .15432 m .68667 .1741 L .67013 .16399 L p .633 .628 .828 r
F P
0 g
s
.36183 .57919 m .3297 .59908 L .32823 .58024 L p .5 .257 .478 r
F P
0 g
s
.32823 .58024 m .36011 .56305 L .36183 .57919 L p .5 .257 .478 r
F P
0 g
s
.56042 .55483 m .56723 .57027 L .54927 .57781 L p .764 .754 .844 r
F P
0 g
s
.57493 .54894 m .58501 .56293 L .56723 .57027 L p .73 .738 .857 r
F P
0 g
s
.56723 .57027 m .56042 .55483 L .57493 .54894 L p .73 .738 .857 r
F P
0 g
s
.39782 .51854 m .38072 .5301 L .37778 .51128 L p .52 .374 .624 r
F P
0 g
s
.37778 .51128 m .39517 .50259 L .39782 .51854 L p .52 .374 .624 r
F P
0 g
s
.70358 .18392 m .71213 .16198 L .72523 .16906 L p .572 .555 .796 r
F P
0 g
s
.72523 .16906 m .72016 .19303 L .70358 .18392 L p .572 .555 .796 r
F P
0 g
s
.25907 .38242 m .21163 .38597 L .20825 .36953 L p .681 .747 .902 r
F P
0 g
s
.21163 .38597 m .16295 .39893 L .16001 .38381 L p .751 .793 .887 r
F P
0 g
s
.16001 .38381 m .20825 .36953 L .21163 .38597 L p .751 .793 .887 r
F P
0 g
s
.54927 .57781 m .5458 .56087 L .56042 .55483 L p .764 .754 .844 r
F P
0 g
s
.5458 .56087 m .54927 .57781 L .53188 .58524 L p .797 .774 .832 r
F P
0 g
s
.68565 .14639 m .67013 .16399 L .65461 .15399 L p .656 .664 .846 r
F P
0 g
s
.67013 .16399 m .68565 .14639 L .69875 .15432 L p .633 .628 .828 r
F P
0 g
s
.61485 .36692 m .60268 .37911 L .58701 .3694 L p .708 .484 .582 r
F P
0 g
s
.60268 .37911 m .61485 .36692 L .63087 .37645 L p .67 .428 .545 r
F P
0 g
s
.64641 .36236 m .63087 .37645 L .61485 .36692 L p .664 .435 .562 r
F P
0 g
s
.72886 .23164 m .73571 .20104 L .74957 .20759 L p .507 .445 .722 r
F P
0 g
s
.74957 .20759 m .7452 .23964 L .72886 .23164 L p .507 .445 .722 r
F P
0 g
s
.29964 .38579 m .25907 .38242 L .25558 .36618 L p .612 .7 .907 r
F P
0 g
s
.20825 .36953 m .25558 .36618 L .25907 .38242 L p .681 .747 .902 r
F P
0 g
s
.63061 .54483 m .65454 .56069 L .63833 .56702 L p .595 .684 .904 r
F P
0 g
s
.63833 .56702 m .61731 .54997 L .63061 .54483 L p .595 .684 .904 r
F P
0 g
s
.58875 .54341 m .60192 .55608 L .58501 .56293 L p .695 .726 .874 r
F P
0 g
s
.58501 .56293 m .57493 .54894 L .58875 .54341 L p .695 .726 .874 r
F P
0 g
s
.33536 .40926 m .36002 .41466 L .36349 .43166 L p .573 .575 .816 r
F P
0 g
s
.36002 .41466 m .33536 .40926 L .33188 .39256 L p .549 .599 .857 r
F P
0 g
s
.29964 .38579 m .33188 .39256 L .33536 .40926 L p .589 .628 .858 r
F P
0 g
s
.66237 .85694 m .6896 .87418 L .68068 .88009 L p .596 .279 .404 r
F P
0 g
s
.68068 .88009 m .64693 .86682 L .66237 .85694 L p .596 .279 .404 r
F P
0 g
s
.52682 .32839 m .53164 .3116 L .54632 .32211 L p .838 .655 .656 r
F P
0 g
s
.54632 .32211 m .54019 .33806 L .52682 .32839 L p .838 .655 .656 r
F P
0 g
s
.66763 .55581 m .70011 .58026 L .68446 .5861 L p .507 .623 .9 r
F P
0 g
s
.68446 .5861 m .65454 .56069 L .66763 .55581 L p .507 .623 .9 r
F P
0 g
s
.09537 .54359 m .12803 .56063 L .12703 .57895 L p .867 .61 .547 r
F P
0 g
s
.12803 .56063 m .09537 .54359 L .09603 .52927 L p .86 .637 .6 r
F P
0 g
s
.56314 .371 m .57091 .35903 L .58701 .3694 L p .744 .527 .6 r
F P
0 g
s
.54868 .36127 m .55508 .34843 L .57091 .35903 L p .775 .569 .621 r
F P
0 g
s
.57091 .35903 m .56314 .371 L .54868 .36127 L p .775 .569 .621 r
F P
0 g
s
.63087 .37645 m .64641 .36236 L .66193 .37111 L p .615 .362 .511 r
F P
0 g
s
.68059 .35393 m .66193 .37111 L .64641 .36236 L p .606 .373 .537 r
F P
0 g
s
.76563 .67694 m .77834 .74333 L .76285 .74907 L p .433 .369 .686 r
F P
0 g
s
.76017 .8057 m .76285 .74907 L .77834 .74333 L p .384 .245 .565 r
F P
0 g
s
.76285 .74907 m .76017 .8057 L .74664 .81151 L p .47 .315 .588 r
F P
0 g
s
.36349 .43166 m .38229 .43436 L .38557 .45063 L p .562 .532 .779 r
F P
0 g
s
.38229 .43436 m .36349 .43166 L .36002 .41466 L p .55 .558 .815 r
F P
0 g
s
.57932 .17788 m .60346 .15407 L .61726 .16421 L p .775 .747 .828 r
F P
0 g
s
.64072 .14449 m .61726 .16421 L .60346 .15407 L p .737 .749 .862 r
F P
0 g
s
.61726 .16421 m .64072 .14449 L .65461 .15399 L p .715 .702 .836 r
F P
0 g
s
.58701 .3694 m .57785 .38047 L .56314 .371 L p .744 .527 .6 r
F P
0 g
s
.57785 .38047 m .58701 .3694 L .60268 .37911 L p .711 .48 .572 r
F P
0 g
s
.5351 .35172 m .54019 .33806 L .55508 .34843 L p .806 .61 .637 r
F P
0 g
s
.55508 .34843 m .54868 .36127 L .5351 .35172 L p .806 .61 .637 r
F P
0 g
s
.7302 .85112 m .73117 .81881 L .74664 .81151 L p .459 .225 .471 r
F P
0 g
s
.73117 .81881 m .7302 .85112 L .72018 .85631 L p .504 .261 .479 r
F P
0 g
s
.51918 .30228 m .52439 .28191 L .538 .29201 L p .871 .708 .677 r
F P
0 g
s
.538 .29201 m .53164 .3116 L .51918 .30228 L p .871 .708 .677 r
F P
0 g
s
.7001 .33196 m .71885 .30479 L .73413 .31214 L p .501 .304 .545 r
F P
0 g
s
.71885 .30479 m .73461 .27321 L .74951 .28005 L p .48 .325 .593 r
F P
0 g
s
.74951 .28005 m .73413 .31214 L .71885 .30479 L p .48 .325 .593 r
F P
0 g
s
.72016 .19303 m .72523 .16906 L .7375 .17524 L p .53 .513 .781 r
F P
0 g
s
.7375 .17524 m .73571 .20104 L .72016 .19303 L p .53 .513 .781 r
F P
0 g
s
.53188 .58524 m .53169 .56678 L .5458 .56087 L p .797 .774 .832 r
F P
0 g
s
.53169 .56678 m .53188 .58524 L .5158 .59225 L p .833 .802 .821 r
F P
0 g
s
.48602 .73663 m .51544 .80189 L .50174 .81166 L p .918 .649 .514 r
F P
0 g
s
.51544 .80189 m .56671 .85592 L .55573 .8649 L p .84 .498 .406 r
F P
0 g
s
.55573 .8649 m .50174 .81166 L .51544 .80189 L p .84 .498 .406 r
F P
0 g
s
.67335 .13851 m .65461 .15399 L .64072 .14449 L p .674 .703 .869 r
F P
0 g
s
.65461 .15399 m .67335 .13851 L .68565 .14639 L p .656 .664 .846 r
F P
0 g
s
.68059 .35393 m .7001 .33196 L .71495 .33942 L p .519 .286 .501 r
F P
0 g
s
.73413 .31214 m .71495 .33942 L .7001 .33196 L p .501 .304 .545 r
F P
0 g
s
.40312 .46552 m .38891 .46789 L .38557 .45063 L p .555 .495 .744 r
F P
0 g
s
.406 .48062 m .39215 .48545 L .38891 .46789 L p .549 .461 .708 r
F P
0 g
s
.38891 .46789 m .40312 .46552 L .406 .48062 L p .549 .461 .708 r
F P
0 g
s
.16295 .39893 m .12132 .41995 L .11902 .4076 L p .822 .835 .859 r
F P
0 g
s
.11902 .4076 m .16001 .38381 L .16295 .39893 L p .822 .835 .859 r
F P
0 g
s
.47834 .67866 m .48602 .73663 L .4721 .74529 L p .959 .769 .604 r
F P
0 g
s
.50174 .81166 m .4721 .74529 L .48602 .73663 L p .918 .649 .514 r
F P
0 g
s
.60134 .53847 m .61731 .54997 L .60192 .55608 L p .652 .717 .895 r
F P
0 g
s
.60192 .55608 m .58875 .54341 L .60134 .53847 L p .652 .717 .895 r
F P
0 g
s
.33188 .39256 m .29964 .38579 L .29629 .3708 L p .55 .656 .906 r
F P
0 g
s
.25558 .36618 m .29629 .3708 L .29964 .38579 L p .612 .7 .907 r
F P
0 g
s
.73461 .27321 m .7452 .23964 L .7588 .24557 L p .454 .346 .642 r
F P
0 g
s
.7588 .24557 m .74951 .28005 L .73461 .27321 L p .454 .346 .642 r
F P
0 g
s
.40867 .4953 m .39517 .50259 L .39215 .48545 L p .533 .419 .669 r
F P
0 g
s
.39215 .48545 m .406 .48062 L .40867 .4953 L p .533 .419 .669 r
F P
0 g
s
.12342 .43551 m .09372 .45497 L .09232 .44376 L p .877 .82 .789 r
F P
0 g
s
.09232 .44376 m .12132 .41995 L .12342 .43551 L p .877 .82 .789 r
F P
0 g
s
.4 .53254 m .38311 .54672 L .38072 .5301 L p .476 .3 .563 r
F P
0 g
s
.38072 .5301 m .39782 .51854 L .4 .53254 L p .476 .3 .563 r
F P
0 g
s
.5311 .22297 m .54661 .19519 L .5589 .20494 L p .87 .796 .775 r
F P
0 g
s
.5589 .20494 m .54322 .23253 L .5311 .22297 L p .87 .796 .775 r
F P
0 g
s
.57932 .17788 m .5589 .20494 L .54661 .19519 L p .841 .804 .816 r
F P
0 g
s
.60268 .37911 m .59216 .38929 L .57785 .38047 L p .711 .48 .572 r
F P
0 g
s
.59216 .38929 m .60268 .37911 L .61723 .38776 L p .673 .423 .534 r
F P
0 g
s
.63087 .37645 m .61723 .38776 L .60268 .37911 L p .67 .428 .545 r
F P
0 g
s
.38557 .45063 m .40016 .45063 L .40312 .46552 L p .555 .495 .744 r
F P
0 g
s
.40016 .45063 m .38557 .45063 L .38229 .43436 L p .553 .525 .778 r
F P
0 g
s
.5205 .2495 m .5311 .22297 L .54322 .23253 L p .892 .786 .737 r
F P
0 g
s
.54322 .23253 m .53204 .25856 L .5205 .2495 L p .892 .786 .737 r
F P
0 g
s
.38483 .56027 m .36183 .57919 L .36011 .56305 L p .441 .215 .474 r
F P
0 g
s
.36011 .56305 m .38311 .54672 L .38483 .56027 L p .441 .215 .474 r
F P
0 g
s
.52292 .3428 m .52682 .32839 L .54019 .33806 L p .841 .652 .647 r
F P
0 g
s
.54019 .33806 m .5351 .35172 L .52292 .3428 L p .841 .652 .647 r
F P
0 g
s
.61723 .38776 m .63087 .37645 L .64497 .38446 L p .622 .353 .49 r
F P
0 g
s
.66193 .37111 m .64497 .38446 L .63087 .37645 L p .615 .362 .511 r
F P
0 g
s
.55637 .38136 m .56314 .371 L .57785 .38047 L p .745 .525 .596 r
F P
0 g
s
.54309 .37238 m .54868 .36127 L .56314 .371 L p .776 .567 .617 r
F P
0 g
s
.56314 .371 m .55637 .38136 L .54309 .37238 L p .776 .567 .617 r
F P
0 g
s
.66193 .37111 m .68059 .35393 L .69451 .36114 L p .533 .269 .461 r
F P
0 g
s
.71495 .33942 m .69451 .36114 L .68059 .35393 L p .519 .286 .501 r
F P
0 g
s
.54661 .19519 m .56746 .1684 L .57932 .17788 L p .841 .804 .816 r
F P
0 g
s
.60346 .15407 m .57932 .17788 L .56746 .1684 L p .803 .808 .855 r
F P
0 g
s
.64693 .86682 m .68068 .88009 L .67309 .88554 L p .6 .251 .35 r
F P
0 g
s
.67309 .88554 m .63362 .876 L .64693 .86682 L p .6 .251 .35 r
F P
0 g
s
.4966 .62814 m .50177 .5985 L .5158 .59225 L p .871 .811 .788 r
F P
0 g
s
.50177 .5985 m .4966 .62814 L .48251 .63492 L p .917 .857 .766 r
F P
0 g
s
.47834 .67866 m .48251 .63492 L .4966 .62814 L p .914 .806 .726 r
F P
0 g
s
.28581 .63136 m .23051 .63913 L .23153 .62337 L p .594 .239 .337 r
F P
0 g
s
.23153 .62337 m .28594 .61596 L .28581 .63136 L p .594 .239 .337 r
F P
0 g
s
.17412 .61569 m .23153 .62337 L .23051 .63913 L p .7 .331 .345 r
F P
0 g
s
.51548 .31982 m .51918 .30228 L .53164 .3116 L p .878 .702 .66 r
F P
0 g
s
.53164 .3116 m .52682 .32839 L .51548 .31982 L p .878 .702 .66 r
F P
0 g
s
.57785 .38047 m .56991 .39004 L .55637 .38136 L p .745 .525 .596 r
F P
0 g
s
.56991 .39004 m .57785 .38047 L .59216 .38929 L p .712 .477 .568 r
F P
0 g
s
.41102 .50889 m .39782 .51854 L .39517 .50259 L p .505 .364 .622 r
F P
0 g
s
.39517 .50259 m .40867 .4953 L .41102 .50889 L p .505 .364 .622 r
F P
0 g
s
.53063 .36353 m .5351 .35172 L .54868 .36127 L p .807 .608 .633 r
F P
0 g
s
.54868 .36127 m .54309 .37238 L .53063 .36353 L p .807 .608 .633 r
F P
0 g
s
.33022 .61283 m .28581 .63136 L .28594 .61596 L p .487 .156 .33 r
F P
0 g
s
.28594 .61596 m .3297 .59908 L .33022 .61283 L p .487 .156 .33 r
F P
0 g
s
.36002 .41466 m .37918 .41967 L .38229 .43436 L p .55 .558 .815 r
F P
0 g
s
.37918 .41967 m .36002 .41466 L .35687 .40014 L p .523 .58 .855 r
F P
0 g
s
.33188 .39256 m .35687 .40014 L .36002 .41466 L p .549 .599 .857 r
F P
0 g
s
.51368 .2735 m .5205 .2495 L .53204 .25856 L p .908 .775 .702 r
F P
0 g
s
.53204 .25856 m .52439 .28191 L .51368 .2735 L p .908 .775 .702 r
F P
0 g
s
.5158 .59225 m .5187 .57233 L .53169 .56678 L p .833 .802 .821 r
F P
0 g
s
.5187 .57233 m .5158 .59225 L .50177 .5985 L p .872 .838 .809 r
F P
0 g
s
.73571 .20104 m .7375 .17524 L .74839 .18025 L p .472 .461 .765 r
F P
0 g
s
.74839 .18025 m .74957 .20759 L .73571 .20104 L p .472 .461 .765 r
F P
0 g
s
.73945 .84668 m .74664 .81151 L .76017 .8057 L p .399 .172 .449 r
F P
0 g
s
.74664 .81151 m .73945 .84668 L .7302 .85112 L p .459 .225 .471 r
F P
0 g
s
.74876 .61562 m .77895 .67288 L .76563 .67694 L p .331 .398 .781 r
F P
0 g
s
.76563 .67694 m .73573 .61981 L .74876 .61562 L p .331 .398 .781 r
F P
0 g
s
.77834 .74333 m .76563 .67694 L .77895 .67288 L p .295 .272 .663 r
F P
0 g
s
.38229 .43436 m .39723 .43656 L .40016 .45063 L p .553 .525 .778 r
F P
0 g
s
.39723 .43656 m .38229 .43436 L .37918 .41967 L p .54 .551 .814 r
F P
0 g
s
.7452 .23964 m .74957 .20759 L .76108 .21238 L p .424 .369 .692 r
F P
0 g
s
.76108 .21238 m .7588 .24557 L .7452 .23964 L p .424 .369 .692 r
F P
0 g
s
.71154 .57644 m .74876 .61562 L .73573 .61981 L p .357 .503 .867 r
F P
0 g
s
.73573 .61981 m .70011 .58026 L .71154 .57644 L p .357 .503 .867 r
F P
0 g
s
.5555 .54333 m .56042 .55483 L .5458 .56087 L p .765 .762 .85 r
F P
0 g
s
.56744 .53853 m .57493 .54894 L .56042 .55483 L p .732 .746 .863 r
F P
0 g
s
.56042 .55483 m .5555 .54333 L .56744 .53853 L p .732 .746 .863 r
F P
0 g
s
.60346 .15407 m .629 .13587 L .64072 .14449 L p .737 .749 .862 r
F P
0 g
s
.66235 .13102 m .64072 .14449 L .629 .13587 L p .689 .747 .896 r
F P
0 g
s
.64072 .14449 m .66235 .13102 L .67335 .13851 L p .674 .703 .869 r
F P
0 g
s
.09618 .49815 m .0779 .49932 L .07769 .48957 L p .913 .759 .676 r
F P
0 g
s
.07769 .48957 m .09569 .48268 L .09618 .49815 L p .913 .759 .676 r
F P
0 g
s
.0779 .49932 m .09618 .49815 L .0963 .5139 L p .912 .735 .649 r
F P
0 g
s
.17412 .61569 m .1255 .59399 L .12703 .57895 L p .803 .502 .48 r
F P
0 g
s
.09434 .55619 m .12703 .57895 L .1255 .59399 L p .877 .576 .474 r
F P
0 g
s
.12703 .57895 m .09434 .55619 L .09537 .54359 L p .867 .61 .547 r
F P
0 g
s
.6413 .54084 m .66763 .55581 L .65454 .56069 L p .515 .67 .933 r
F P
0 g
s
.65454 .56069 m .63061 .54483 L .6413 .54084 L p .515 .67 .933 r
F P
0 g
s
.07786 .50918 m .0963 .5139 L .09603 .52927 L p .915 .714 .617 r
F P
0 g
s
.0963 .5139 m .07786 .50918 L .0779 .49932 L p .912 .735 .649 r
F P
0 g
s
.64497 .38446 m .66193 .37111 L .67468 .37785 L p .543 .255 .428 r
F P
0 g
s
.69451 .36114 m .67468 .37785 L .66193 .37111 L p .533 .269 .461 r
F P
0 g
s
.5458 .56087 m .5435 .54823 L .5555 .54333 L p .765 .762 .85 r
F P
0 g
s
.5435 .54823 m .5458 .56087 L .53169 .56678 L p .799 .783 .838 r
F P
0 g
s
.59216 .38929 m .58306 .39804 L .56991 .39004 L p .712 .477 .568 r
F P
0 g
s
.58306 .39804 m .59216 .38929 L .60541 .39709 L p .674 .42 .528 r
F P
0 g
s
.61723 .38776 m .60541 .39709 L .59216 .38929 L p .673 .423 .534 r
F P
0 g
s
.61221 .53429 m .63061 .54483 L .61731 .54997 L p .598 .708 .921 r
F P
0 g
s
.61731 .54997 m .60134 .53847 L .61221 .53429 L p .598 .708 .921 r
F P
0 g
s
.35687 .40014 m .33188 .39256 L .32882 .37927 L p .5 .62 .902 r
F P
0 g
s
.29629 .3708 m .32882 .37927 L .33188 .39256 L p .55 .656 .906 r
F P
0 g
s
.69875 .15432 m .70718 .14043 L .71704 .14602 L p .563 .598 .846 r
F P
0 g
s
.71704 .14602 m .71213 .16198 L .69875 .15432 L p .563 .598 .846 r
F P
0 g
s
.70718 .14043 m .69875 .15432 L .68565 .14639 L p .589 .631 .861 r
F P
0 g
s
.51952 .35524 m .52292 .3428 L .5351 .35172 L p .842 .65 .644 r
F P
0 g
s
.5351 .35172 m .53063 .36353 L .51952 .35524 L p .842 .65 .644 r
F P
0 g
s
.48251 .63492 m .47834 .67866 L .46609 .68547 L p .97 .857 .673 r
F P
0 g
s
.4721 .74529 m .46609 .68547 L .47834 .67866 L p .959 .769 .604 r
F P
0 g
s
.57883 .53402 m .58875 .54341 L .57493 .54894 L p .696 .734 .88 r
F P
0 g
s
.57493 .54894 m .56744 .53853 L .57883 .53402 L p .696 .734 .88 r
F P
0 g
s
.56746 .1684 m .59271 .1454 L .60346 .15407 L p .803 .808 .855 r
F P
0 g
s
.629 .13587 m .60346 .15407 L .59271 .1454 L p .756 .807 .894 r
F P
0 g
s
.60541 .39709 m .61723 .38776 L .63 .395 L p .625 .347 .477 r
F P
0 g
s
.64497 .38446 m .63 .395 L .61723 .38776 L p .622 .353 .49 r
F P
0 g
s
.55035 .39054 m .55637 .38136 L .56991 .39004 L p .744 .524 .596 r
F P
0 g
s
.53803 .38218 m .54309 .37238 L .55637 .38136 L p .775 .567 .618 r
F P
0 g
s
.55637 .38136 m .55035 .39054 L .53803 .38218 L p .775 .567 .618 r
F P
0 g
s
.09569 .48268 m .07769 .48957 L .07724 .48033 L p .917 .785 .7 r
F P
0 g
s
.07724 .48033 m .09486 .4681 L .09569 .48268 L p .917 .785 .7 r
F P
0 g
s
.71213 .16198 m .71704 .14602 L .72666 .15116 L p .53 .563 .833 r
F P
0 g
s
.72666 .15116 m .72523 .16906 L .71213 .16198 L p .53 .563 .833 r
F P
0 g
s
.41477 .46344 m .40312 .46552 L .40016 .45063 L p .557 .496 .743 r
F P
0 g
s
.41731 .47656 m .406 .48062 L .40312 .46552 L p .549 .461 .707 r
F P
0 g
s
.40312 .46552 m .41477 .46344 L .41731 .47656 L p .549 .461 .707 r
F P
0 g
s
.56671 .85592 m .62312 .88403 L .61598 .89052 L p .721 .317 .281 r
F P
0 g
s
.61598 .89052 m .55573 .8649 L .56671 .85592 L p .721 .317 .281 r
F P
0 g
s
.69752 .13462 m .68565 .14639 L .67335 .13851 L p .608 .665 .879 r
F P
0 g
s
.68565 .14639 m .69752 .13462 L .70718 .14043 L p .589 .631 .861 r
F P
0 g
s
.51262 .3349 m .51548 .31982 L .52682 .32839 L p .881 .698 .65 r
F P
0 g
s
.52682 .32839 m .52292 .3428 L .51262 .3349 L p .881 .698 .65 r
F P
0 g
s
.23051 .63913 m .17233 .62983 L .17412 .61569 L p .7 .331 .345 r
F P
0 g
s
.1255 .59399 m .17412 .61569 L .17233 .62983 L p .799 .428 .353 r
F P
0 g
s
.50938 .29455 m .51368 .2735 L .52439 .28191 L p .919 .764 .673 r
F P
0 g
s
.52439 .28191 m .51918 .30228 L .50938 .29455 L p .919 .764 .673 r
F P
0 g
s
.41965 .48926 m .40867 .4953 L .406 .48062 L p .533 .418 .668 r
F P
0 g
s
.406 .48062 m .41731 .47656 L .41965 .48926 L p .533 .418 .668 r
F P
0 g
s
.56991 .39004 m .56293 .39853 L .55035 .39054 L p .744 .524 .596 r
F P
0 g
s
.56293 .39853 m .56991 .39004 L .58306 .39804 L p .711 .476 .567 r
F P
0 g
s
.52652 .37388 m .53063 .36353 L .54309 .37238 L p .806 .608 .635 r
F P
0 g
s
.54309 .37238 m .53803 .38218 L .52652 .37388 L p .806 .608 .635 r
F P
0 g
s
.36269 .59087 m .33022 .61283 L .3297 .59908 L p .388 .084 .323 r
F P
0 g
s
.3297 .59908 m .36183 .57919 L .36269 .59087 L p .388 .084 .323 r
F P
0 g
s
.41294 .52077 m .4 .53254 L .39782 .51854 L p .458 .287 .561 r
F P
0 g
s
.39782 .51854 m .41102 .50889 L .41294 .52077 L p .458 .287 .561 r
F P
0 g
s
.40016 .45063 m .41214 .45046 L .41477 .46344 L p .557 .496 .743 r
F P
0 g
s
.41214 .45046 m .40016 .45063 L .39723 .43656 L p .556 .526 .777 r
F P
0 g
s
.07757 .51873 m .09603 .52927 L .09537 .54359 L p .921 .694 .578 r
F P
0 g
s
.09603 .52927 m .07757 .51873 L .07786 .50918 L p .915 .714 .617 r
F P
0 g
s
.53169 .56678 m .53195 .55302 L .5435 .54823 L p .799 .783 .838 r
F P
0 g
s
.53195 .55302 m .53169 .56678 L .5187 .57233 L p .834 .811 .828 r
F P
0 g
s
.40159 .5439 m .38483 .56027 L .38311 .54672 L p .399 .186 .471 r
F P
0 g
s
.38311 .54672 m .4 .53254 L .40159 .5439 L p .399 .186 .471 r
F P
0 g
s
.12132 .41995 m .09232 .44376 L .09072 .43487 L p .889 .87 .814 r
F P
0 g
s
.09072 .43487 m .11902 .4076 L .12132 .41995 L p .889 .87 .814 r
F P
0 g
s
.25558 .36618 m .20825 .36953 L .20508 .3578 L p .641 .801 .959 r
F P
0 g
s
.20825 .36953 m .16001 .38381 L .15707 .37307 L p .734 .858 .939 r
F P
0 g
s
.15707 .37307 m .20508 .3578 L .20825 .36953 L p .734 .858 .939 r
F P
0 g
s
.58922 .52997 m .60134 .53847 L .58875 .54341 L p .654 .724 .901 r
F P
0 g
s
.58875 .54341 m .57883 .53402 L .58922 .52997 L p .654 .724 .901 r
F P
0 g
s
.72523 .16906 m .72666 .15116 L .73566 .15562 L p .487 .524 .821 r
F P
0 g
s
.73566 .15562 m .7375 .17524 L .72523 .16906 L p .487 .524 .821 r
F P
0 g
s
.09486 .4681 m .07724 .48033 L .07658 .47198 L p .925 .816 .72 r
F P
0 g
s
.07658 .47198 m .09372 .45497 L .09486 .4681 L p .925 .816 .72 r
F P
0 g
s
.29629 .3708 m .25558 .36618 L .25247 .35459 L p .549 .738 .963 r
F P
0 g
s
.20508 .3578 m .25247 .35459 L .25558 .36618 L p .641 .801 .959 r
F P
0 g
s
.63 .395 m .64497 .38446 L .65651 .39062 L p .549 .244 .402 r
F P
0 g
s
.67468 .37785 m .65651 .39062 L .64497 .38446 L p .543 .255 .428 r
F P
0 g
s
.4217 .50098 m .41102 .50889 L .40867 .4953 L p .504 .362 .621 r
F P
0 g
s
.40867 .4953 m .41965 .48926 L .4217 .50098 L p .504 .362 .621 r
F P
0 g
s
.68845 .12884 m .67335 .13851 L .66235 .13102 L p .621 .7 .901 r
F P
0 g
s
.67335 .13851 m .68845 .12884 L .69752 .13462 L p .608 .665 .879 r
F P
0 g
s
.63362 .876 m .67309 .88554 L .66719 .89027 L p .591 .199 .268 r
F P
0 g
s
.66719 .89027 m .62312 .88403 L .63362 .876 L p .591 .199 .268 r
F P
0 g
s
.6771 .55256 m .71154 .57644 L .70011 .58026 L p .373 .585 .925 r
F P
0 g
s
.70011 .58026 m .66763 .55581 L .6771 .55256 L p .373 .585 .925 r
F P
0 g
s
.37918 .41967 m .39446 .42383 L .39723 .43656 L p .54 .551 .814 r
F P
0 g
s
.39446 .42383 m .37918 .41967 L .37638 .40711 L p .513 .573 .853 r
F P
0 g
s
.35687 .40014 m .37638 .40711 L .37918 .41967 L p .523 .58 .855 r
F P
0 g
s
.58306 .39804 m .57515 .40582 L .56293 .39853 L p .711 .476 .567 r
F P
0 g
s
.57515 .40582 m .58306 .39804 L .59521 .40506 L p .673 .418 .528 r
F P
0 g
s
.60541 .39709 m .59521 .40506 L .58306 .39804 L p .674 .42 .528 r
F P
0 g
s
.51631 .36609 m .51952 .35524 L .53063 .36353 L p .84 .651 .646 r
F P
0 g
s
.53063 .36353 m .52652 .37388 L .51631 .36609 L p .84 .651 .646 r
F P
0 g
s
.77895 .67288 m .78987 .74003 L .77834 .74333 L p .295 .272 .663 r
F P
0 g
s
.77127 .8016 m .77834 .74333 L .78987 .74003 L p .249 .128 .513 r
F P
0 g
s
.77834 .74333 m .77127 .8016 L .76017 .8057 L p .384 .245 .565 r
F P
0 g
s
.54488 .39886 m .55035 .39054 L .56293 .39853 L p .741 .524 .6 r
F P
0 g
s
.5333 .39098 m .53803 .38218 L .55035 .39054 L p .772 .567 .622 r
F P
0 g
s
.55035 .39054 m .54488 .39886 L .5333 .39098 L p .772 .567 .622 r
F P
0 g
s
.59521 .40506 m .60541 .39709 L .617 .40359 L p .625 .344 .471 r
F P
0 g
s
.63 .395 m .617 .40359 L .60541 .39709 L p .625 .347 .477 r
F P
0 g
s
.50659 .31275 m .50938 .29455 L .51918 .30228 L p .926 .756 .652 r
F P
0 g
s
.51918 .30228 m .51548 .31982 L .50659 .31275 L p .926 .756 .652 r
F P
0 g
s
.39723 .43656 m .40952 .43816 L .41214 .45046 L p .556 .526 .777 r
F P
0 g
s
.40952 .43816 m .39723 .43656 L .39446 .42383 L p .545 .553 .814 r
F P
0 g
s
.71495 .33942 m .73413 .31214 L .74554 .3168 L p .369 .146 .439 r
F P
0 g
s
.73413 .31214 m .74951 .28005 L .76068 .28427 L p .345 .178 .506 r
F P
0 g
s
.76068 .28427 m .74554 .3168 L .73413 .31214 L p .345 .178 .506 r
F P
0 g
s
.51014 .34791 m .51262 .3349 L .52292 .3428 L p .882 .697 .648 r
F P
0 g
s
.52292 .3428 m .51952 .35524 L .51014 .34791 L p .882 .697 .648 r
F P
0 g
s
.56293 .39853 m .55675 .4063 L .54488 .39886 L p .741 .524 .6 r
F P
0 g
s
.55675 .4063 m .56293 .39853 L .57515 .40582 L p .708 .476 .571 r
F P
0 g
s
.52256 .38307 m .52652 .37388 L .53803 .38218 L p .803 .609 .64 r
F P
0 g
s
.53803 .38218 m .5333 .39098 L .52256 .38307 L p .803 .609 .64 r
F P
0 g
s
.50177 .5985 m .50741 .57724 L .5187 .57233 L p .872 .838 .809 r
F P
0 g
s
.50741 .57724 m .50177 .5985 L .49048 .6037 L p .915 .886 .789 r
F P
0 g
s
.48251 .63492 m .49048 .6037 L .50177 .5985 L p .917 .857 .766 r
F P
0 g
s
.74957 .20759 m .74839 .18025 L .75741 .18385 L p .387 .392 .743 r
F P
0 g
s
.75741 .18385 m .76108 .21238 L .74957 .20759 L p .387 .392 .743 r
F P
0 g
s
.37638 .40711 m .35687 .40014 L .35416 .38857 L p .469 .597 .897 r
F P
0 g
s
.32882 .37927 m .35416 .38857 L .35687 .40014 L p .5 .62 .902 r
F P
0 g
s
.69451 .36114 m .71495 .33942 L .726 .34422 L p .388 .118 .377 r
F P
0 g
s
.74554 .3168 m .726 .34422 L .71495 .33942 L p .369 .146 .439 r
F P
0 g
s
.74756 .84317 m .76017 .8057 L .77127 .8016 L p .315 .091 .407 r
F P
0 g
s
.76017 .8057 m .74756 .84317 L .73945 .84668 L p .399 .172 .449 r
F P
0 g
s
.74951 .28005 m .7588 .24557 L .769 .24912 L p .318 .213 .574 r
F P
0 g
s
.769 .24912 m .76068 .28427 L .74951 .28005 L p .318 .213 .574 r
F P
0 g
s
.16001 .38381 m .11902 .4076 L .11661 .39887 L p .822 .903 .897 r
F P
0 g
s
.11661 .39887 m .15707 .37307 L .16001 .38381 L p .822 .903 .897 r
F P
0 g
s
.42469 .46156 m .41477 .46344 L .41214 .45046 L p .567 .502 .742 r
F P
0 g
s
.42693 .47314 m .41731 .47656 L .41477 .46344 L p .559 .466 .706 r
F P
0 g
s
.41477 .46344 m .42469 .46156 L .42693 .47314 L p .559 .466 .706 r
F P
0 g
s
.07704 .52755 m .09537 .54359 L .09434 .55619 L p .93 .674 .528 r
F P
0 g
s
.09537 .54359 m .07704 .52755 L .07757 .51873 L p .921 .694 .578 r
F P
0 g
s
.32882 .37927 m .29629 .3708 L .29344 .36011 L p .466 .677 .956 r
F P
0 g
s
.25247 .35459 m .29344 .36011 L .29629 .3708 L p .549 .738 .963 r
F P
0 g
s
.5187 .57233 m .52134 .55749 L .53195 .55302 L p .834 .811 .828 r
F P
0 g
s
.52134 .55749 m .5187 .57233 L .50741 .57724 L p .873 .848 .817 r
F P
0 g
s
.59271 .1454 m .61991 .12847 L .629 .13587 L p .756 .807 .894 r
F P
0 g
s
.65308 .1242 m .629 .13587 L .61991 .12847 L p .696 .798 .928 r
F P
0 g
s
.629 .13587 m .65308 .1242 L .66235 .13102 L p .689 .747 .896 r
F P
0 g
s
.52274 .21559 m .53817 .1876 L .54661 .19519 L p .917 .878 .782 r
F P
0 g
s
.54661 .19519 m .5311 .22297 L .52274 .21559 L p .917 .878 .782 r
F P
0 g
s
.56746 .1684 m .54661 .19519 L .53817 .1876 L p .879 .887 .835 r
F P
0 g
s
.38578 .57 m .36269 .59087 L .36183 .57919 L p .307 .029 .318 r
F P
0 g
s
.36183 .57919 m .38483 .56027 L .38578 .57 L p .307 .029 .318 r
F P
0 g
s
.42898 .48431 m .41965 .48926 L .41731 .47656 L p .542 .423 .667 r
F P
0 g
s
.41731 .47656 m .42693 .47314 L .42898 .48431 L p .542 .423 .667 r
F P
0 g
s
.5517 .53421 m .5555 .54333 L .5435 .54823 L p .765 .758 .846 r
F P
0 g
s
.56168 .53022 m .56744 .53853 L .5555 .54333 L p .732 .741 .859 r
F P
0 g
s
.5555 .54333 m .5517 .53421 L .56168 .53022 L p .732 .741 .859 r
F P
0 g
s
.51254 .24257 m .52274 .21559 L .5311 .22297 L p .944 .863 .729 r
F P
0 g
s
.5311 .22297 m .5205 .2495 L .51254 .24257 L p .944 .863 .729 r
F P
0 g
s
.62093 .53104 m .6413 .54084 L .63061 .54483 L p .519 .697 .95 r
F P
0 g
s
.63061 .54483 m .61221 .53429 L .62093 .53104 L p .519 .697 .95 r
F P
0 g
s
.41214 .45046 m .42234 .45008 L .42469 .46156 L p .567 .502 .742 r
F P
0 g
s
.42234 .45008 m .41214 .45046 L .40952 .43816 L p .568 .533 .777 r
F P
0 g
s
.617 .40359 m .63 .395 L .64041 .40056 L p .553 .236 .386 r
F P
0 g
s
.65651 .39062 m .64041 .40056 L .63 .395 L p .549 .244 .402 r
F P
0 g
s
.7375 .17524 m .73566 .15562 L .74362 .15921 L p .428 .477 .808 r
F P
0 g
s
.74362 .15921 m .74839 .18025 L .7375 .17524 L p .428 .477 .808 r
F P
0 g
s
.5435 .54823 m .54169 .53828 L .5517 .53421 L p .765 .758 .846 r
F P
0 g
s
.54169 .53828 m .5435 .54823 L .53195 .55302 L p .799 .779 .835 r
F P
0 g
s
.67468 .37785 m .69451 .36114 L .7048 .36583 L p .404 .094 .322 r
F P
0 g
s
.726 .34422 m .7048 .36583 L .69451 .36114 L p .388 .118 .377 r
F P
0 g
s
.57515 .40582 m .56826 .41294 L .55675 .4063 L p .708 .476 .571 r
F P
0 g
s
.56826 .41294 m .57515 .40582 L .58641 .41213 L p .67 .418 .532 r
F P
0 g
s
.59521 .40506 m .58641 .41213 L .57515 .40582 L p .673 .418 .528 r
F P
0 g
s
.49048 .6037 m .48251 .63492 L .47251 .64006 L p .962 .912 .718 r
F P
0 g
s
.46609 .68547 m .47251 .64006 L .48251 .63492 L p .97 .857 .673 r
F P
0 g
s
.42337 .51118 m .41294 .52077 L .41102 .50889 L p .456 .285 .559 r
F P
0 g
s
.41102 .50889 m .4217 .50098 L .42337 .51118 L p .456 .285 .559 r
F P
0 g
s
.59818 .52655 m .61221 .53429 L .60134 .53847 L p .599 .716 .926 r
F P
0 g
s
.60134 .53847 m .58922 .52997 L .59818 .52655 L p .599 .716 .926 r
F P
0 g
s
.53817 .1876 m .55938 .16095 L .56746 .1684 L p .879 .887 .835 r
F P
0 g
s
.59271 .1454 m .56746 .1684 L .55938 .16095 L p .829 .888 .885 r
F P
0 g
s
.51311 .37563 m .51631 .36609 L .52652 .37388 L p .837 .653 .653 r
F P
0 g
s
.52652 .37388 m .52256 .38307 L .51311 .37563 L p .837 .653 .653 r
F P
0 g
s
.53979 .4066 m .54488 .39886 L .55675 .4063 L p .737 .525 .606 r
F P
0 g
s
.52873 .39902 m .5333 .39098 L .54488 .39886 L p .768 .569 .629 r
F P
0 g
s
.54488 .39886 m .53979 .4066 L .52873 .39902 L p .768 .569 .629 r
F P
0 g
s
.57121 .52647 m .57883 .53402 L .56744 .53853 L p .696 .728 .875 r
F P
0 g
s
.56744 .53853 m .56168 .53022 L .57121 .52647 L p .696 .728 .875 r
F P
0 g
s
.09372 .45497 m .07658 .47198 L .07574 .46484 L p .935 .852 .736 r
F P
0 g
s
.07574 .46484 m .09232 .44376 L .09372 .45497 L p .935 .852 .736 r
F P
0 g
s
.68033 .12333 m .66235 .13102 L .65308 .1242 L p .627 .738 .927 r
F P
0 g
s
.66235 .13102 m .68033 .12333 L .68845 .12884 L p .621 .7 .901 r
F P
0 g
s
.50456 .3284 m .50659 .31275 L .51548 .31982 L p .929 .751 .641 r
F P
0 g
s
.51548 .31982 m .51262 .3349 L .50456 .3284 L p .929 .751 .641 r
F P
0 g
s
.58641 .41213 m .59521 .40506 L .6058 .41087 L p .624 .342 .47 r
F P
0 g
s
.617 .40359 m .6058 .41087 L .59521 .40506 L p .625 .344 .471 r
F P
0 g
s
.41436 .53034 m .40159 .5439 L .4 .53254 L p .376 .17 .469 r
F P
0 g
s
.4 .53254 m .41294 .52077 L .41436 .53034 L p .376 .17 .469 r
F P
0 g
s
.51861 .39134 m .52256 .38307 L .5333 .39098 L p .799 .611 .648 r
F P
0 g
s
.5333 .39098 m .52873 .39902 L .51861 .39134 L p .799 .611 .648 r
F P
0 g
s
.55675 .4063 m .5512 .41358 L .53979 .4066 L p .737 .525 .606 r
F P
0 g
s
.5512 .41358 m .55675 .4063 L .56826 .41294 L p .704 .477 .577 r
F P
0 g
s
.50774 .3592 m .51014 .34791 L .51952 .35524 L p .88 .698 .652 r
F P
0 g
s
.51952 .35524 m .51631 .36609 L .50774 .3592 L p .88 .698 .652 r
F P
0 g
s
.43075 .49457 m .4217 .50098 L .41965 .48926 L p .513 .367 .62 r
F P
0 g
s
.41965 .48926 m .42898 .48431 L .43075 .49457 L p .513 .367 .62 r
F P
0 g
s
.50629 .26712 m .51254 .24257 L .5205 .2495 L p .962 .846 .681 r
F P
0 g
s
.5205 .2495 m .51368 .2735 L .50629 .26712 L p .962 .846 .681 r
F P
0 g
s
.39446 .42383 m .40705 .42702 L .40952 .43816 L p .545 .553 .814 r
F P
0 g
s
.40705 .42702 m .39446 .42383 L .39198 .41293 L p .519 .576 .853 r
F P
0 g
s
.37638 .40711 m .39198 .41293 L .39446 .42383 L p .513 .573 .853 r
F P
0 g
s
.70978 .86204 m .71556 .87304 L .7104 .87609 L p .446 .111 .303 r
F P
0 g
s
.7104 .87609 m .69944 .86808 L .70978 .86204 L p .446 .111 .303 r
F P
0 g
s
.71556 .87304 m .70978 .86204 L .72018 .85631 L p .426 .103 .313 r
F P
0 g
s
.7588 .24557 m .76108 .21238 L .7697 .21514 L p .287 .25 .641 r
F P
0 g
s
.7697 .21514 m .769 .24912 L .7588 .24557 L p .287 .25 .641 r
F P
0 g
s
.17233 .62983 m .12351 .6049 L .1255 .59399 L p .799 .428 .353 r
F P
0 g
s
.09297 .56642 m .1255 .59399 L .12351 .6049 L p .885 .526 .36 r
F P
0 g
s
.1255 .59399 m .09297 .56642 L .09434 .55619 L p .877 .576 .474 r
F P
0 g
s
.53195 .55302 m .53208 .54224 L .54169 .53828 L p .799 .779 .835 r
F P
0 g
s
.53208 .54224 m .53195 .55302 L .52134 .55749 L p .834 .807 .825 r
F P
0 g
s
.40952 .43816 m .41999 .43917 L .42234 .45008 L p .568 .533 .777 r
F P
0 g
s
.41999 .43917 m .40952 .43816 L .40705 .42702 L p .559 .562 .813 r
F P
0 g
s
.69944 .86808 m .7104 .87609 L .70551 .87916 L p .458 .106 .28 r
F P
0 g
s
.70551 .87916 m .6896 .87418 L .69944 .86808 L p .458 .106 .28 r
F P
0 g
s
.649 .53816 m .6771 .55256 L .66763 .55581 L p .382 .639 .957 r
F P
0 g
s
.66763 .55581 m .6413 .54084 L .649 .53816 L p .382 .639 .957 r
F P
0 g
s
.72078 .87014 m .72018 .85631 L .7302 .85112 L p .396 .082 .311 r
F P
0 g
s
.72018 .85631 m .72078 .87014 L .71556 .87304 L p .426 .103 .313 r
F P
0 g
s
.57991 .52311 m .58922 .52997 L .57883 .53402 L p .654 .718 .896 r
F P
0 g
s
.57883 .53402 m .57121 .52647 L .57991 .52311 L p .654 .718 .896 r
F P
0 g
s
.65651 .39062 m .67468 .37785 L .68404 .38226 L p .415 .074 .276 r
F P
0 g
s
.7048 .36583 m .68404 .38226 L .67468 .37785 L p .404 .094 .322 r
F P
0 g
s
.35416 .38857 m .32882 .37927 L .32631 .36981 L p .401 .627 .945 r
F P
0 g
s
.29344 .36011 m .32631 .36981 L .32882 .37927 L p .466 .677 .956 r
F P
0 g
s
.39198 .41293 m .37638 .40711 L .37399 .39712 L p .459 .589 .895 r
F P
0 g
s
.35416 .38857 m .37399 .39712 L .37638 .40711 L p .469 .597 .897 r
F P
0 g
s
.53496 .41399 m .53979 .4066 L .5512 .41358 L p .732 .526 .613 r
F P
0 g
s
.52419 .40651 m .52873 .39902 L .53979 .4066 L p .763 .57 .637 r
F P
0 g
s
.53979 .4066 m .53496 .41399 L .52419 .40651 L p .763 .57 .637 r
F P
0 g
s
.43342 .45985 m .42469 .46156 L .42234 .45008 L p .584 .512 .74 r
F P
0 g
s
.43541 .47025 m .42693 .47314 L .42469 .46156 L p .575 .476 .704 r
F P
0 g
s
.42469 .46156 m .43342 .45985 L .43541 .47025 L p .575 .476 .704 r
F P
0 g
s
.55938 .16095 m .58545 .13854 L .59271 .1454 L p .829 .888 .885 r
F P
0 g
s
.61991 .12847 m .59271 .1454 L .58545 .13854 L p .765 .879 .929 r
F P
0 g
s
.50981 .38409 m .51311 .37563 L .52256 .38307 L p .832 .655 .663 r
F P
0 g
s
.52256 .38307 m .51861 .39134 L .50981 .38409 L p .832 .655 .663 r
F P
0 g
s
.56826 .41294 m .56224 .41964 L .5512 .41358 L p .704 .477 .577 r
F P
0 g
s
.56224 .41964 m .56826 .41294 L .57883 .41859 L p .665 .419 .539 r
F P
0 g
s
.58641 .41213 m .57883 .41859 L .56826 .41294 L p .67 .418 .532 r
F P
0 g
s
.6058 .41087 m .617 .40359 L .62641 .40856 L p .553 .232 .378 r
F P
0 g
s
.64041 .40056 m .62641 .40856 L .617 .40359 L p .553 .236 .386 r
F P
0 g
s
.70718 .14043 m .7125 .13162 L .71927 .13544 L p .507 .6 .881 r
F P
0 g
s
.71927 .13544 m .71704 .14602 L .70718 .14043 L p .507 .6 .881 r
F P
0 g
s
.7125 .13162 m .70718 .14043 L .69752 .13462 L p .53 .63 .894 r
F P
0 g
s
.4372 .48024 m .42898 .48431 L .42693 .47314 L p .558 .432 .665 r
F P
0 g
s
.42693 .47314 m .43541 .47025 L .4372 .48024 L p .558 .432 .665 r
F P
0 g
s
.51454 .39884 m .51861 .39134 L .52873 .39902 L p .793 .613 .657 r
F P
0 g
s
.52873 .39902 m .52419 .40651 L .51454 .39884 L p .793 .613 .657 r
F P
0 g
s
.50262 .28874 m .50629 .26712 L .51368 .2735 L p .973 .83 .641 r
F P
0 g
s
.51368 .2735 m .50938 .29455 L .50262 .28874 L p .973 .83 .641 r
F P
0 g
s
.5512 .41358 m .54618 .42061 L .53496 .41399 L p .732 .526 .613 r
F P
0 g
s
.54618 .42061 m .5512 .41358 L .56224 .41964 L p .699 .478 .585 r
F P
0 g
s
.50282 .34189 m .50456 .3284 L .51262 .3349 L p .929 .75 .638 r
F P
0 g
s
.51262 .3349 m .51014 .34791 L .50282 .34189 L p .929 .75 .638 r
F P
0 g
s
.57883 .41859 m .58641 .41213 L .59618 .41729 L p .62 .342 .475 r
F P
0 g
s
.6058 .41087 m .59618 .41729 L .58641 .41213 L p .624 .342 .47 r
F P
0 g
s
.42234 .45008 m .43131 .4495 L .43342 .45985 L p .584 .512 .74 r
F P
0 g
s
.43131 .4495 m .42234 .45008 L .41999 .43917 L p .586 .545 .775 r
F P
0 g
s
.4721 .74529 m .50174 .81166 L .49455 .81846 L p .958 .622 .319 r
F P
0 g
s
.50174 .81166 m .55573 .8649 L .55023 .87125 L p .848 .412 .185 r
F P
0 g
s
.55023 .87125 m .49455 .81846 L .50174 .81166 L p .848 .412 .185 r
F P
0 g
s
.71704 .14602 m .71927 .13544 L .72587 .13893 L p .475 .568 .869 r
F P
0 g
s
.72587 .13893 m .72666 .15116 L .71704 .14602 L p .475 .568 .869 r
F P
0 g
s
.50525 .36907 m .50774 .3592 L .51631 .36609 L p .876 .7 .661 r
F P
0 g
s
.51631 .36609 m .51311 .37563 L .50525 .36907 L p .876 .7 .661 r
F P
0 g
s
.70585 .12764 m .69752 .13462 L .68845 .12884 L p .545 .659 .911 r
F P
0 g
s
.69752 .13462 m .70585 .12764 L .7125 .13162 L p .53 .63 .894 r
F P
0 g
s
.6896 .87418 m .70551 .87916 L .70112 .88212 L p .459 .086 .243 r
F P
0 g
s
.70112 .88212 m .68068 .88009 L .6896 .87418 L p .459 .086 .243 r
F P
0 g
s
.40252 .55198 m .38578 .57 L .38483 .56027 L p .25 0 .313 r
F P
0 g
s
.38483 .56027 m .40159 .5439 L .40252 .55198 L p .25 0 .313 r
F P
0 g
s
.46609 .68547 m .4721 .74529 L .46464 .75113 L p .997 .783 .437 r
F P
0 g
s
.49455 .81846 m .46464 .75113 L .4721 .74529 L p .958 .622 .319 r
F P
0 g
s
.07629 .53524 m .09434 .55619 L .09297 .56642 L p .941 .65 .46 r
F P
0 g
s
.09434 .55619 m .07629 .53524 L .07704 .52755 L p .93 .674 .528 r
F P
0 g
s
.72582 .8675 m .7302 .85112 L .73945 .84668 L p .354 .046 .296 r
F P
0 g
s
.7302 .85112 m .72582 .8675 L .72078 .87014 L p .396 .082 .311 r
F P
0 g
s
.50741 .57724 m .51216 .56143 L .52134 .55749 L p .873 .848 .817 r
F P
0 g
s
.51216 .56143 m .50741 .57724 L .49837 .58129 L p .913 .896 .797 r
F P
0 g
s
.49048 .6037 m .49837 .58129 L .50741 .57724 L p .915 .886 .789 r
F P
0 g
s
.43218 .50346 m .42337 .51118 L .4217 .50098 L p .466 .29 .558 r
F P
0 g
s
.4217 .50098 m .43075 .49457 L .43218 .50346 L p .466 .29 .558 r
F P
0 g
s
.54858 .52657 m .5517 .53421 L .54169 .53828 L p .764 .744 .835 r
F P
0 g
s
.55709 .52318 m .56168 .53022 L .5517 .53421 L p .73 .727 .848 r
F P
0 g
s
.5517 .53421 m .54858 .52657 L .55709 .52318 L p .73 .727 .848 r
F P
0 g
s
.11902 .4076 m .09072 .43487 L .08899 .42862 L p .897 .93 .831 r
F P
0 g
s
.08899 .42862 m .11661 .39887 L .11902 .4076 L p .897 .93 .831 r
F P
0 g
s
.64041 .40056 m .65651 .39062 L .66493 .39468 L p .422 .06 .242 r
F P
0 g
s
.68404 .38226 m .66493 .39468 L .65651 .39062 L p .415 .074 .276 r
F P
0 g
s
.52134 .55749 m .52328 .54593 L .53208 .54224 L p .834 .807 .825 r
F P
0 g
s
.52328 .54593 m .52134 .55749 L .51216 .56143 L p .873 .844 .813 r
F P
0 g
s
.43871 .48939 m .43075 .49457 L .42898 .48431 L p .53 .377 .618 r
F P
0 g
s
.42898 .48431 m .4372 .48024 L .43871 .48939 L p .53 .377 .618 r
F P
0 g
s
.53025 .42123 m .53496 .41399 L .54618 .42061 L p .726 .527 .621 r
F P
0 g
s
.51951 .4136 m .52419 .40651 L .53496 .41399 L p .757 .571 .646 r
F P
0 g
s
.53496 .41399 m .53025 .42123 L .51951 .4136 L p .757 .571 .646 r
F P
0 g
s
.62312 .88403 m .66719 .89027 L .66327 .89407 L p .558 .11 .143 r
F P
0 g
s
.66327 .89407 m .61598 .89052 L .62312 .88403 L p .558 .11 .143 r
F P
0 g
s
.74839 .18025 m .74362 .15921 L .7502 .16175 L p .344 .415 .791 r
F P
0 g
s
.7502 .16175 m .75741 .18385 L .74839 .18025 L p .344 .415 .791 r
F P
0 g
s
.42461 .51936 m .41436 .53034 L .41294 .52077 L p .372 .167 .467 r
F P
0 g
s
.41294 .52077 m .42337 .51118 L .42461 .51936 L p .372 .167 .467 r
F P
0 g
s
.54169 .53828 m .54006 .53002 L .54858 .52657 L p .764 .744 .835 r
F P
0 g
s
.54006 .53002 m .54169 .53828 L .53208 .54224 L p .797 .766 .824 r
F P
0 g
s
.50632 .39164 m .50981 .38409 L .51861 .39134 L p .826 .658 .675 r
F P
0 g
s
.51861 .39134 m .51454 .39884 L .50632 .39164 L p .826 .658 .675 r
F P
0 g
s
.40705 .42702 m .41775 .42929 L .41999 .43917 L p .559 .562 .813 r
F P
0 g
s
.41775 .42929 m .40705 .42702 L .40483 .41748 L p .537 .588 .853 r
F P
0 g
s
.39198 .41293 m .40483 .41748 L .40705 .42702 L p .519 .576 .853 r
F P
0 g
s
.72666 .15116 m .72587 .13893 L .73202 .14195 L p .432 .532 .859 r
F P
0 g
s
.73202 .14195 m .73566 .15562 L .72666 .15116 L p .432 .532 .859 r
F P
0 g
s
.56224 .41964 m .557 .4261 L .54618 .42061 L p .699 .478 .585 r
F P
0 g
s
.557 .4261 m .56224 .41964 L .5723 .42466 L p .659 .421 .548 r
F P
0 g
s
.57883 .41859 m .5723 .42466 L .56224 .41964 L p .665 .419 .539 r
F P
0 g
s
.56523 .52 m .57121 .52647 L .56168 .53022 L p .694 .714 .864 r
F P
0 g
s
.56168 .53022 m .55709 .52318 L .56523 .52 L p .694 .714 .864 r
F P
0 g
s
.28469 .64012 m .22862 .64813 L .23051 .63913 L p .444 0 .032 r
F P
0 g
s
.23051 .63913 m .28581 .63136 L .28469 .64012 L p .444 0 .032 r
F P
0 g
s
.17233 .62983 m .23051 .63913 L .22862 .64813 L p .613 .123 .066 r
F P
0 g
s
.60536 .52389 m .62093 .53104 L .61221 .53429 L p .52 .704 .955 r
F P
0 g
s
.61221 .53429 m .59818 .52655 L .60536 .52389 L p .52 .704 .955 r
F P
0 g
s
.41999 .43917 m .42916 .43966 L .43131 .4495 L p .586 .545 .775 r
F P
0 g
s
.42916 .43966 m .41999 .43917 L .41775 .42929 L p .58 .575 .812 r
F P
0 g
s
.51025 .40569 m .51454 .39884 L .52419 .40651 L p .787 .615 .668 r
F P
0 g
s
.52419 .40651 m .51951 .4136 L .51025 .40569 L p .787 .615 .668 r
F P
0 g
s
.69961 .12368 m .68845 .12884 L .68033 .12333 L p .552 .689 .93 r
F P
0 g
s
.68845 .12884 m .69961 .12368 L .70585 .12764 L p .545 .659 .911 r
F P
0 g
s
.58742 .52026 m .59818 .52655 L .58922 .52997 L p .599 .709 .921 r
F P
0 g
s
.58922 .52997 m .57991 .52311 L .58742 .52026 L p .599 .709 .921 r
F P
0 g
s
.54618 .42061 m .54165 .42759 L .53025 .42123 L p .726 .527 .621 r
F P
0 g
s
.54165 .42759 m .54618 .42061 L .557 .4261 L p .692 .479 .593 r
F P
0 g
s
.61991 .12847 m .64593 .11833 L .65308 .1242 L p .696 .798 .928 r
F P
0 g
s
.67351 .1183 m .65308 .1242 L .64593 .11833 L p .621 .779 .957 r
F P
0 g
s
.65308 .1242 m .67351 .1183 L .68033 .12333 L p .627 .738 .927 r
F P
0 g
s
.59618 .41729 m .6058 .41087 L .61435 .41528 L p .551 .23 .378 r
F P
0 g
s
.62641 .40856 m .61435 .41528 L .6058 .41087 L p .553 .232 .378 r
F P
0 g
s
.32974 .62055 m .28469 .64012 L .28581 .63136 L p .274 0 .012 r
F P
0 g
s
.28581 .63136 m .33022 .61283 L .32974 .62055 L p .274 0 .012 r
F P
0 g
s
.09232 .44376 m .07574 .46484 L .07474 .45918 L p .946 .892 .744 r
F P
0 g
s
.07474 .45918 m .09072 .43487 L .09232 .44376 L p .946 .892 .744 r
F P
0 g
s
.50045 .30746 m .50262 .28874 L .50938 .29455 L p .979 .817 .613 r
F P
0 g
s
.50938 .29455 m .50659 .31275 L .50045 .30746 L p .979 .817 .613 r
F P
0 g
s
.44135 .45827 m .43342 .45985 L .43131 .4495 L p .604 .524 .737 r
F P
0 g
s
.44312 .4678 m .43541 .47025 L .43342 .45985 L p .594 .487 .702 r
F P
0 g
s
.43342 .45985 m .44135 .45827 L .44312 .4678 L p .594 .487 .702 r
F P
0 g
s
.49837 .58129 m .49048 .6037 L .48252 .60758 L p .949 .94 .742 r
F P
0 g
s
.47251 .64006 m .48252 .60758 L .49048 .6037 L p .962 .912 .718 r
F P
0 g
s
.50108 .35357 m .50282 .34189 L .51014 .34791 L p .927 .752 .644 r
F P
0 g
s
.51014 .34791 m .50774 .3592 L .50108 .35357 L p .927 .752 .644 r
F P
0 g
s
.5723 .42466 m .57883 .41859 L .58794 .42315 L p .615 .344 .484 r
F P
0 g
s
.59618 .41729 m .58794 .42315 L .57883 .41859 L p .62 .342 .475 r
F P
0 g
s
.50256 .37773 m .50525 .36907 L .51311 .37563 L p .87 .704 .673 r
F P
0 g
s
.51311 .37563 m .50981 .38409 L .50256 .37773 L p .87 .704 .673 r
F P
0 g
s
.76108 .21238 m .75741 .18385 L .76414 .18586 L p .253 .288 .705 r
F P
0 g
s
.76414 .18586 m .7697 .21514 L .76108 .21238 L p .253 .288 .705 r
F P
0 g
s
.44466 .47693 m .4372 .48024 L .43541 .47025 L p .577 .444 .663 r
F P
0 g
s
.43541 .47025 m .44312 .4678 L .44466 .47693 L p .577 .444 .663 r
F P
0 g
s
.37399 .39712 m .35416 .38857 L .35198 .38036 L p .362 .596 .936 r
F P
0 g
s
.32631 .36981 m .35198 .38036 L .35416 .38857 L p .401 .627 .945 r
F P
0 g
s
.75665 .614 m .78714 .67161 L .77895 .67288 L p .058 .239 .734 r
F P
0 g
s
.77895 .67288 m .74876 .61562 L .75665 .614 L p .058 .239 .734 r
F P
0 g
s
.78987 .74003 m .77895 .67288 L .78714 .67161 L p .033 .081 .58 r
F P
0 g
s
.43131 .4495 m .43941 .44875 L .44135 .45827 L p .604 .524 .737 r
F P
0 g
s
.43941 .44875 m .43131 .4495 L .42916 .43966 L p .608 .558 .772 r
F P
0 g
s
.40483 .41748 m .39198 .41293 L .38988 .40426 L p .467 .594 .896 r
F P
0 g
s
.37399 .39712 m .38988 .40426 L .39198 .41293 L p .459 .589 .895 r
F P
0 g
s
.78987 .74003 m .77952 .79936 L .77127 .8016 L p .249 .128 .513 r
F P
0 g
s
.7542 .84072 m .77127 .8016 L .77952 .79936 L p .191 0 .33 r
F P
0 g
s
.77127 .8016 m .7542 .84072 L .74756 .84317 L p .315 .091 .407 r
F P
0 g
s
.0779 .49932 m .06886 .49979 L .06877 .49434 L p .966 .799 .624 r
F P
0 g
s
.06877 .49434 m .07769 .48957 L .0779 .49932 L p .966 .799 .624 r
F P
0 g
s
.06886 .49979 m .0779 .49932 L .07786 .50918 L p .966 .78 .602 r
F P
0 g
s
.68068 .88009 m .70112 .88212 L .69741 .88483 L p .448 .049 .188 r
F P
0 g
s
.69741 .88483 m .67309 .88554 L .68068 .88009 L p .448 .049 .188 r
F P
0 g
s
.53208 .54224 m .5319 .53339 L .54006 .53002 L p .797 .766 .824 r
F P
0 g
s
.5319 .53339 m .53208 .54224 L .52328 .54593 L p .833 .793 .813 r
F P
0 g
s
.71831 .57479 m .75665 .614 L .74876 .61562 L p .087 .377 .84 r
F P
0 g
s
.74876 .61562 m .71154 .57644 L .71831 .57479 L p .087 .377 .84 r
F P
0 g
s
.5255 .42862 m .53025 .42123 L .54165 .42759 L p .72 .527 .629 r
F P
0 g
s
.51448 .42037 m .51951 .4136 L .53025 .42123 L p .751 .572 .654 r
F P
0 g
s
.53025 .42123 m .5255 .42862 L .51448 .42037 L p .751 .572 .654 r
F P
0 g
s
.58545 .13854 m .61383 .12259 L .61991 .12847 L p .765 .879 .929 r
F P
0 g
s
.64593 .11833 m .61991 .12847 L .61383 .12259 L p .686 .857 .964 r
F P
0 g
s
.57267 .51714 m .57991 .52311 L .57121 .52647 L p .652 .702 .883 r
F P
0 g
s
.57121 .52647 m .56523 .52 L .57267 .51714 L p .652 .702 .883 r
F P
0 g
s
.06881 .50528 m .07786 .50918 L .07757 .51873 L p .968 .763 .574 r
F P
0 g
s
.07786 .50918 m .06881 .50528 L .06886 .49979 L p .966 .78 .602 r
F P
0 g
s
.50258 .39837 m .50632 .39164 L .51454 .39884 L p .818 .661 .688 r
F P
0 g
s
.51454 .39884 m .51025 .40569 L .50258 .39837 L p .818 .661 .688 r
F P
0 g
s
.73049 .86525 m .73945 .84668 L .74756 .84317 L p .299 0 .265 r
F P
0 g
s
.73945 .84668 m .73049 .86525 L .72582 .8675 L p .354 .046 .296 r
F P
0 g
s
.50564 .41191 m .51025 .40569 L .51951 .4136 L p .78 .617 .679 r
F P
0 g
s
.51951 .4136 m .51448 .42037 L .50564 .41191 L p .78 .617 .679 r
F P
0 g
s
.07769 .48957 m .06877 .49434 L .06854 .48916 L p .969 .82 .641 r
F P
0 g
s
.06854 .48916 m .07724 .48033 L .07769 .48957 L p .969 .82 .641 r
F P
0 g
s
.47251 .64006 m .46609 .68547 L .45953 .68989 L p .982 .882 .524 r
F P
0 g
s
.46464 .75113 m .45953 .68989 L .46609 .68547 L p .997 .783 .437 r
F P
0 g
s
.557 .4261 m .55249 .43246 L .54165 .42759 L p .692 .479 .593 r
F P
0 g
s
.55249 .43246 m .557 .4261 L .56673 .4305 L p .653 .423 .559 r
F P
0 g
s
.5723 .42466 m .56673 .4305 L .557 .4261 L p .659 .421 .548 r
F P
0 g
s
.62717 .52884 m .649 .53816 L .6413 .54084 L p .386 .668 .971 r
F P
0 g
s
.6413 .54084 m .62093 .53104 L .62717 .52884 L p .386 .668 .971 r
F P
0 g
s
.62641 .40856 m .64041 .40056 L .64796 .40422 L p .426 .05 .22 r
F P
0 g
s
.66493 .39468 m .64796 .40422 L .64041 .40056 L p .422 .06 .242 r
F P
0 g
s
.54165 .42759 m .53764 .43473 L .5255 .42862 L p .72 .527 .629 r
F P
0 g
s
.53764 .43473 m .54165 .42759 L .55249 .43246 L p .686 .479 .602 r
F P
0 g
s
.55573 .8649 m .61598 .89052 L .61264 .89512 L p .678 .179 .054 r
F P
0 g
s
.61264 .89512 m .55023 .87125 L .55573 .8649 L p .678 .179 .054 r
F P
0 g
s
.43992 .49728 m .43218 .50346 L .43075 .49457 L p .485 .302 .557 r
F P
0 g
s
.43075 .49457 m .43871 .48939 L .43992 .49728 L p .485 .302 .557 r
F P
0 g
s
.22862 .64813 m .16991 .63784 L .17233 .62983 L p .613 .123 .066 r
F P
0 g
s
.12351 .6049 m .17233 .62983 L .16991 .63784 L p .76 .283 .111 r
F P
0 g
s
.44593 .48525 m .43871 .48939 L .4372 .48024 L p .551 .39 .616 r
F P
0 g
s
.4372 .48024 m .44466 .47693 L .44593 .48525 L p .551 .39 .616 r
F P
0 g
s
.3626 .59733 m .32974 .62055 L .33022 .61283 L p .126 0 .002 r
F P
0 g
s
.33022 .61283 m .36269 .59087 L .3626 .59733 L p .126 0 .002 r
F P
0 g
s
.41521 .53712 m .40252 .55198 L .40159 .5439 L p .22 0 .31 r
F P
0 g
s
.40159 .5439 m .41436 .53034 L .41521 .53712 L p .22 0 .31 r
F P
0 g
s
.73566 .15562 m .73202 .14195 L .73746 .14437 L p .374 .489 .848 r
F P
0 g
s
.73746 .14437 m .74362 .15921 L .73566 .15562 L p .374 .489 .848 r
F P
0 g
s
.49901 .32358 m .50045 .30746 L .50659 .31275 L p .981 .81 .598 r
F P
0 g
s
.50659 .31275 m .50456 .3284 L .49901 .32358 L p .981 .81 .598 r
F P
0 g
s
.49963 .38537 m .50256 .37773 L .50981 .38409 L p .863 .708 .688 r
F P
0 g
s
.50981 .38409 m .50632 .39164 L .49963 .38537 L p .863 .708 .688 r
F P
0 g
s
.58794 .42315 m .59618 .41729 L .60403 .42118 L p .546 .231 .384 r
F P
0 g
s
.61435 .41528 m .60403 .42118 L .59618 .41729 L p .551 .23 .378 r
F P
0 g
s
.42916 .43966 m .43741 .43968 L .43941 .44875 L p .608 .558 .772 r
F P
0 g
s
.43741 .43968 m .42916 .43966 L .4271 .43073 L p .605 .59 .809 r
F P
0 g
s
.41775 .42929 m .4271 .43073 L .42916 .43966 L p .58 .575 .812 r
F P
0 g
s
.56673 .4305 m .5723 .42466 L .58091 .42864 L p .608 .347 .496 r
F P
0 g
s
.58794 .42315 m .58091 .42864 L .5723 .42466 L p .615 .344 .484 r
F P
0 g
s
.49917 .36372 m .50108 .35357 L .50774 .3592 L p .923 .756 .657 r
F P
0 g
s
.50774 .3592 m .50525 .36907 L .49917 .36372 L p .923 .756 .657 r
F P
0 g
s
.4271 .43073 m .41775 .42929 L .41573 .42081 L p .563 .604 .853 r
F P
0 g
s
.40483 .41748 m .41573 .42081 L .41775 .42929 L p .537 .588 .853 r
F P
0 g
s
.4487 .45679 m .44135 .45827 L .43941 .44875 L p .625 .536 .734 r
F P
0 g
s
.45029 .46574 m .44312 .4678 L .44135 .45827 L p .614 .499 .699 r
F P
0 g
s
.44135 .45827 m .4487 .45679 L .45029 .46574 L p .614 .499 .699 r
F P
0 g
s
.69402 .11989 m .68033 .12333 L .67351 .1183 L p .549 .718 .952 r
F P
0 g
s
.68033 .12333 m .69402 .11989 L .69961 .12368 L p .552 .689 .93 r
F P
0 g
s
.06862 .51056 m .07757 .51873 L .07704 .52755 L p .972 .747 .539 r
F P
0 g
s
.07757 .51873 m .06862 .51056 L .06881 .50528 L p .968 .763 .574 r
F P
0 g
s
.52042 .43668 m .5255 .42862 L .53764 .43473 L p .713 .526 .634 r
F P
0 g
s
.50878 .42676 m .51448 .42037 L .5255 .42862 L p .744 .573 .662 r
F P
0 g
s
.5255 .42862 m .52042 .43668 L .50878 .42676 L p .744 .573 .662 r
F P
0 g
s
.54589 .51989 m .54858 .52657 L .54006 .53002 L p .761 .725 .819 r
F P
0 g
s
.55332 .51693 m .55709 .52318 L .54858 .52657 L p .727 .707 .832 r
F P
0 g
s
.54858 .52657 m .54589 .51989 L .55332 .51693 L p .727 .707 .832 r
F P
0 g
s
.43323 .51055 m .42461 .51936 L .42337 .51118 L p .384 .173 .466 r
F P
0 g
s
.42337 .51118 m .43218 .50346 L .43323 .51055 L p .384 .173 .466 r
F P
0 g
s
.4516 .47427 m .44466 .47693 L .44312 .4678 L p .598 .456 .66 r
F P
0 g
s
.44312 .4678 m .45029 .46574 L .4516 .47427 L p .598 .456 .66 r
F P
0 g
s
.49857 .40434 m .50258 .39837 L .51025 .40569 L p .809 .663 .701 r
F P
0 g
s
.51025 .40569 m .50564 .41191 L .49857 .40434 L p .809 .663 .701 r
F P
0 g
s
.43941 .44875 m .4469 .44784 L .4487 .45679 L p .625 .536 .734 r
F P
0 g
s
.4469 .44784 m .43941 .44875 L .43741 .43968 L p .63 .571 .769 r
F P
0 g
s
.50067 .41744 m .50564 .41191 L .51448 .42037 L p .772 .619 .69 r
F P
0 g
s
.51448 .42037 m .50878 .42676 L .50067 .41744 L p .772 .619 .69 r
F P
0 g
s
.07724 .48033 m .06854 .48916 L .06819 .48445 L p .973 .843 .652 r
F P
0 g
s
.06819 .48445 m .07658 .47198 L .07724 .48033 L p .973 .843 .652 r
F P
0 g
s
.54006 .53002 m .53846 .52291 L .54589 .51989 L p .761 .725 .819 r
F P
0 g
s
.53846 .52291 m .54006 .53002 L .5319 .53339 L p .795 .746 .807 r
F P
0 g
s
.25247 .35459 m .20508 .3578 L .20221 .35118 L p .526 .842 .999 r
F P
0 g
s
.20508 .3578 m .15707 .37307 L .15424 .36706 L p .665 .924 .974 r
F P
0 g
s
.15424 .36706 m .20221 .35118 L .20508 .3578 L p .665 .924 .974 r
F P
0 g
s
.56045 .51416 m .56523 .52 L .55709 .52318 L p .691 .693 .847 r
F P
0 g
s
.55709 .52318 m .55332 .51693 L .56045 .51416 L p .691 .693 .847 r
F P
0 g
s
.51216 .56143 m .51569 .54917 L .52328 .54593 L p .873 .844 .813 r
F P
0 g
s
.51569 .54917 m .51216 .56143 L .50484 .56466 L p .914 .892 .794 r
F P
0 g
s
.49837 .58129 m .50484 .56466 L .51216 .56143 L p .913 .896 .797 r
F P
0 g
s
.55249 .43246 m .54874 .43879 L .53764 .43473 L p .686 .479 .602 r
F P
0 g
s
.54874 .43879 m .55249 .43246 L .56202 .43617 L p .645 .425 .57 r
F P
0 g
s
.56673 .4305 m .56202 .43617 L .55249 .43246 L p .653 .423 .559 r
F P
0 g
s
.53764 .43473 m .53438 .44226 L .52042 .43668 L p .713 .526 .634 r
F P
0 g
s
.53438 .44226 m .53764 .43473 L .54874 .43879 L p .678 .479 .61 r
F P
0 g
s
.52328 .54593 m .52445 .53652 L .5319 .53339 L p .833 .793 .813 r
F P
0 g
s
.52445 .53652 m .52328 .54593 L .51569 .54917 L p .873 .83 .801 r
F P
0 g
s
.29344 .36011 m .25247 .35459 L .24985 .34804 L p .388 .745 .992 r
F P
0 g
s
.20221 .35118 m .24985 .34804 L .25247 .35459 L p .526 .842 .999 r
F P
0 g
s
.68259 .55106 m .71831 .57479 L .71154 .57644 L p .112 .48 .898 r
F P
0 g
s
.71154 .57644 m .6771 .55256 L .68259 .55106 L p .112 .48 .898 r
F P
0 g
s
.41573 .42081 m .40483 .41748 L .40296 .40988 L p .491 .61 .898 r
F P
0 g
s
.38988 .40426 m .40296 .40988 L .40483 .41748 L p .467 .594 .896 r
F P
0 g
s
.38988 .40426 m .37399 .39712 L .37212 .39003 L p .349 .585 .932 r
F P
0 g
s
.35198 .38036 m .37212 .39003 L .37399 .39712 L p .362 .596 .936 r
F P
0 g
s
.57909 .51473 m .58742 .52026 L .57991 .52311 L p .598 .691 .907 r
F P
0 g
s
.57991 .52311 m .57267 .51714 L .57909 .51473 L p .598 .691 .907 r
F P
0 g
s
.78714 .67161 m .797 .73931 L .78987 .74003 L p .033 .081 .58 r
F P
0 g
s
.77952 .79936 m .78987 .74003 L .797 .73931 L p .014 0 .392 r
F P
0 g
s
.61435 .41528 m .62641 .40856 L .63319 .41183 L p .426 .044 .21 r
F P
0 g
s
.64796 .40422 m .63319 .41183 L .62641 .40856 L p .426 .05 .22 r
F P
0 g
s
.49643 .3921 m .49963 .38537 L .50632 .39164 L p .854 .712 .705 r
F P
0 g
s
.50632 .39164 m .50258 .39837 L .49643 .3921 L p .854 .712 .705 r
F P
0 g
s
.59343 .51804 m .60536 .52389 L .59818 .52655 L p .52 .696 .949 r
F P
0 g
s
.59818 .52655 m .58742 .52026 L .59343 .51804 L p .52 .696 .949 r
F P
0 g
s
.726 .34422 m .74554 .3168 L .75248 .31848 L p .088 0 .202 r
F P
0 g
s
.74554 .3168 m .76068 .28427 L .76751 .28562 L p .067 0 .31 r
F P
0 g
s
.76751 .28562 m .75248 .31848 L .74554 .3168 L p .067 0 .31 r
F P
0 g
s
.51286 .4491 m .52042 .43668 L .53438 .44226 L p .704 .52 .637 r
F P
0 g
s
.50212 .43227 m .50878 .42676 L .52042 .43668 L p .739 .573 .668 r
F P
0 g
s
.52042 .43668 m .51286 .4491 L .50212 .43227 L p .739 .573 .668 r
F P
0 g
s
.56202 .43617 m .56673 .4305 L .57495 .4339 L p .601 .35 .509 r
F P
0 g
s
.58091 .42864 m .57495 .4339 L .56673 .4305 L p .608 .347 .496 r
F P
0 g
s
.45567 .45543 m .4487 .45679 L .4469 .44784 L p .645 .547 .73 r
F P
0 g
s
.45709 .46403 m .45029 .46574 L .4487 .45679 L p .634 .51 .694 r
F P
0 g
s
.4487 .45679 m .45567 .45543 L .45709 .46403 L p .634 .51 .694 r
F P
0 g
s
.45264 .48198 m .44593 .48525 L .44466 .47693 L p .574 .403 .613 r
F P
0 g
s
.44466 .47693 m .4516 .47427 L .45264 .48198 L p .574 .403 .613 r
F P
0 g
s
.49536 .42216 m .50067 .41744 L .50878 .42676 L p .763 .621 .701 r
F P
0 g
s
.50878 .42676 m .50212 .43227 L .49536 .42216 L p .763 .621 .701 r
F P
0 g
s
.49431 .40957 m .49857 .40434 L .50564 .41191 L p .8 .665 .714 r
F P
0 g
s
.50564 .41191 m .50067 .41744 L .49431 .40957 L p .8 .665 .714 r
F P
0 g
s
.4978 .33746 m .49901 .32358 L .50456 .3284 L p .981 .808 .595 r
F P
0 g
s
.50456 .3284 m .50282 .34189 L .4978 .33746 L p .981 .808 .595 r
F P
0 g
s
.43741 .43968 m .44499 .43929 L .4469 .44784 L p .63 .571 .769 r
F P
0 g
s
.44499 .43929 m .43741 .43968 L .43546 .43144 L p .631 .605 .806 r
F P
0 g
s
.4271 .43073 m .43546 .43144 L .43741 .43968 L p .605 .59 .809 r
F P
0 g
s
.58091 .42864 m .58794 .42315 L .59522 .42655 L p .54 .233 .396 r
F P
0 g
s
.60403 .42118 m .59522 .42655 L .58794 .42315 L p .546 .231 .384 r
F P
0 g
s
.497 .37258 m .49917 .36372 L .50525 .36907 L p .917 .762 .674 r
F P
0 g
s
.50525 .36907 m .50256 .37773 L .497 .37258 L p .917 .762 .674 r
F P
0 g
s
.7048 .36583 m .726 .34422 L .73265 .34609 L p .11 0 .105 r
F P
0 g
s
.75248 .31848 m .73265 .34609 L .726 .34422 L p .088 0 .202 r
F P
0 g
s
.44692 .49238 m .43992 .49728 L .43871 .48939 L p .509 .316 .554 r
F P
0 g
s
.43871 .48939 m .44593 .48525 L .44692 .49238 L p .509 .316 .554 r
F P
0 g
s
.5319 .53339 m .53137 .52586 L .53846 .52291 L p .795 .746 .807 r
F P
0 g
s
.53137 .52586 m .5319 .53339 L .52445 .53652 L p .832 .773 .796 r
F P
0 g
s
.12351 .6049 m .09132 .57373 L .09297 .56642 L p .885 .526 .36 r
F P
0 g
s
.07534 .54142 m .09297 .56642 L .09132 .57373 L p .948 .616 .361 r
F P
0 g
s
.09297 .56642 m .07534 .54142 L .07629 .53524 L p .941 .65 .46 r
F P
0 g
s
.4469 .44784 m .45396 .44678 L .45567 .45543 L p .645 .547 .73 r
F P
0 g
s
.45396 .44678 m .4469 .44784 L .44499 .43929 L p .652 .583 .764 r
F P
0 g
s
.76068 .28427 m .769 .24912 L .77525 .25008 L p .047 0 .42 r
F P
0 g
s
.77525 .25008 m .76751 .28562 L .76068 .28427 L p .047 0 .42 r
F P
0 g
s
.56697 .51169 m .57267 .51714 L .56523 .52 L p .649 .679 .865 r
F P
0 g
s
.56523 .52 m .56045 .51416 L .56697 .51169 L p .649 .679 .865 r
F P
0 g
s
.45818 .47216 m .4516 .47427 L .45029 .46574 L p .619 .468 .656 r
F P
0 g
s
.45029 .46574 m .45709 .46403 L .45818 .47216 L p .619 .468 .656 r
F P
0 g
s
.67309 .88554 m .69741 .88483 L .69455 .88717 L p .422 0 .111 r
F P
0 g
s
.69455 .88717 m .66719 .89027 L .67309 .88554 L p .422 0 .111 r
F P
0 g
s
.43546 .43144 m .4271 .43073 L .42523 .42307 L p .593 .623 .851 r
F P
0 g
s
.41573 .42081 m .42523 .42307 L .4271 .43073 L p .563 .604 .853 r
F P
0 g
s
.50484 .56466 m .49837 .58129 L .49203 .58427 L p .943 .949 .75 r
F P
0 g
s
.48252 .60758 m .49203 .58427 L .49837 .58129 L p .949 .94 .742 r
F P
0 g
s
.0683 .51541 m .07704 .52755 L .07629 .53524 L p .978 .73 .494 r
F P
0 g
s
.07704 .52755 m .0683 .51541 L .06862 .51056 L p .972 .747 .539 r
F P
0 g
s
.53438 .44226 m .53245 .45012 L .51286 .4491 L p .704 .52 .637 r
F P
0 g
s
.53245 .45012 m .53438 .44226 L .54582 .4451 L p .67 .478 .617 r
F P
0 g
s
.54874 .43879 m .54582 .4451 L .53438 .44226 L p .678 .479 .61 r
F P
0 g
s
.54582 .4451 m .54874 .43879 L .55814 .44173 L p .638 .427 .581 r
F P
0 g
s
.56202 .43617 m .55814 .44173 L .54874 .43879 L p .645 .425 .57 r
F P
0 g
s
.15707 .37307 m .11661 .39887 L .11418 .39408 L p .787 .975 .912 r
F P
0 g
s
.11418 .39408 m .15424 .36706 L .15707 .37307 L p .787 .975 .912 r
F P
0 g
s
.3859 .57529 m .3626 .59733 L .36269 .59087 L p .014 0 0 r
F P
0 g
s
.36269 .59087 m .38578 .57 L .3859 .57529 L p .014 0 0 r
F P
0 g
s
.51852 .21071 m .53397 .18247 L .53817 .1876 L p .938 .964 .735 r
F P
0 g
s
.53817 .1876 m .52274 .21559 L .51852 .21071 L p .938 .964 .735 r
F P
0 g
s
.55938 .16095 m .53817 .1876 L .53397 .18247 L p .889 .981 .817 r
F P
0 g
s
.32631 .36981 m .29344 .36011 L .29119 .35409 L p .269 .65 .967 r
F P
0 g
s
.24985 .34804 m .29119 .35409 L .29344 .36011 L p .388 .745 .992 r
F P
0 g
s
.73459 .86346 m .74756 .84317 L .7542 .84072 L p .225 0 .214 r
F P
0 g
s
.74756 .84317 m .73459 .86346 L .73049 .86525 L p .299 0 .265 r
F P
0 g
s
.49297 .39801 m .49643 .3921 L .50258 .39837 L p .843 .715 .721 r
F P
0 g
s
.50258 .39837 m .49857 .40434 L .49297 .39801 L p .843 .715 .721 r
F P
0 g
s
.50849 .23807 m .51852 .21071 L .52274 .21559 L p .967 .936 .652 r
F P
0 g
s
.52274 .21559 m .51254 .24257 L .50849 .23807 L p .967 .936 .652 r
F P
0 g
s
.75741 .18385 m .7502 .16175 L .75508 .16313 L p .215 .327 .763 r
F P
0 g
s
.75508 .16313 m .76414 .18586 L .75741 .18385 L p .215 .327 .763 r
F P
0 g
s
.42535 .52511 m .41521 .53712 L .41436 .53034 L p .215 0 .307 r
F P
0 g
s
.41436 .53034 m .42461 .51936 L .42535 .52511 L p .215 0 .307 r
F P
0 g
s
.49478 .43629 m .50211 .43227 L .51276 .44916 L p .732 .571 .673 r
F P
0 g
s
.50211 .43227 m .49478 .43629 L .48972 .42611 L p .756 .619 .707 r
F P
0 g
s
.48972 .42611 m .49536 .42216 L .50211 .43227 L p .756 .619 .707 r
F P
0 g
s
.68404 .38226 m .7048 .36583 L .71092 .36776 L p .129 0 .022 r
F P
0 g
s
.73265 .34609 m .71092 .36776 L .7048 .36583 L p .11 0 .105 r
F P
0 g
s
.48985 .41407 m .49431 .40957 L .50067 .41744 L p .789 .666 .727 r
F P
0 g
s
.50067 .41744 m .49536 .42216 L .48985 .41407 L p .789 .666 .727 r
F P
0 g
s
.07658 .47198 m .06819 .48445 L .06773 .48042 L p .979 .868 .656 r
F P
0 g
s
.06773 .48042 m .07574 .46484 L .07658 .47198 L p .979 .868 .656 r
F P
0 g
s
.48252 .60758 m .47251 .64006 L .46719 .64327 L p .944 .93 .577 r
F P
0 g
s
.45953 .68989 m .46719 .64327 L .47251 .64006 L p .982 .882 .524 r
F P
0 g
s
.4624 .45416 m .45567 .45543 L .45396 .44678 L p .664 .557 .724 r
F P
0 g
s
.46366 .46263 m .45709 .46403 L .45567 .45543 L p .653 .52 .689 r
F P
0 g
s
.45567 .45543 m .4624 .45416 L .46366 .46263 L p .653 .52 .689 r
F P
0 g
s
.44079 .50355 m .43323 .51055 L .43218 .50346 L p .407 .186 .464 r
F P
0 g
s
.43218 .50346 m .43992 .49728 L .44079 .50355 L p .407 .186 .464 r
F P
0 g
s
.53397 .18247 m .55543 .15585 L .55938 .16095 L p .889 .981 .817 r
F P
0 g
s
.58545 .13854 m .55938 .16095 L .55543 .15585 L p .82 .979 .89 r
F P
0 g
s
.7125 .13162 m .71557 .12649 L .71991 .12893 L p .434 .594 .91 r
F P
0 g
s
.71991 .12893 m .71927 .13544 L .7125 .13162 L p .434 .594 .91 r
F P
0 g
s
.71557 .12649 m .7125 .13162 L .70585 .12764 L p .454 .62 .922 r
F P
0 g
s
.54347 .51386 m .54589 .51989 L .53846 .52291 L p .757 .702 .8 r
F P
0 g
s
.55015 .51121 m .55332 .51693 L .54589 .51989 L p .723 .685 .812 r
F P
0 g
s
.54589 .51989 m .54347 .51386 L .55015 .51121 L p .723 .685 .812 r
F P
0 g
s
.61047 .52207 m .62717 .52884 L .62093 .53104 L p .387 .676 .974 r
F P
0 g
s
.62093 .53104 m .60536 .52389 L .61047 .52207 L p .387 .676 .974 r
F P
0 g
s
.55814 .44173 m .56202 .43617 L .56994 .43899 L p .593 .355 .524 r
F P
0 g
s
.57495 .4339 m .56994 .43899 L .56202 .43617 L p .601 .35 .509 r
F P
0 g
s
.74362 .15921 m .73746 .14437 L .74193 .14606 L p .292 .435 .834 r
F P
0 g
s
.74193 .14606 m .7502 .16175 L .74362 .15921 L p .292 .435 .834 r
F P
0 g
s
.45396 .44678 m .46074 .4456 L .4624 .45416 L p .664 .557 .724 r
F P
0 g
s
.46074 .4456 m .45396 .44678 L .45207 .43853 L p .673 .594 .758 r
F P
0 g
s
.44499 .43929 m .45207 .43853 L .45396 .44678 L p .652 .583 .764 r
F P
0 g
s
.45207 .43853 m .44499 .43929 L .44308 .43153 L p .656 .619 .801 r
F P
0 g
s
.43546 .43144 m .44308 .43153 L .44499 .43929 L p .631 .605 .806 r
F P
0 g
s
.61383 .12259 m .64119 .11366 L .64593 .11833 L p .686 .857 .964 r
F P
0 g
s
.66827 .11398 m .64593 .11833 L .64119 .11366 L p .592 .82 .986 r
F P
0 g
s
.64593 .11833 m .66827 .11398 L .67351 .1183 L p .621 .779 .957 r
F P
0 g
s
.60403 .42118 m .61435 .41528 L .62048 .41818 L p .422 .042 .21 r
F P
0 g
s
.63319 .41183 m .62048 .41818 L .61435 .41528 L p .426 .044 .21 r
F P
0 g
s
.45896 .47946 m .45264 .48198 L .4516 .47427 L p .597 .417 .609 r
F P
0 g
s
.4516 .47427 m .45818 .47216 L .45896 .47946 L p .597 .417 .609 r
F P
0 g
s
.49453 .38034 m .497 .37258 L .50256 .37773 L p .908 .768 .694 r
F P
0 g
s
.50256 .37773 m .49963 .38537 L .49453 .38034 L p .908 .768 .694 r
F P
0 g
s
.09072 .43487 m .07474 .45918 L .07364 .45522 L p .952 .934 .738 r
F P
0 g
s
.07364 .45522 m .08899 .42862 L .09072 .43487 L p .952 .934 .738 r
F P
0 g
s
.71927 .13544 m .71991 .12893 L .72413 .13116 L p .405 .566 .9 r
F P
0 g
s
.72413 .13116 m .72587 .13893 L .71927 .13544 L p .405 .566 .9 r
F P
0 g
s
.53846 .52291 m .53683 .51658 L .54347 .51386 L p .757 .702 .8 r
F P
0 g
s
.53683 .51658 m .53846 .52291 L .53137 .52586 L p .791 .723 .788 r
F P
0 g
s
.4645 .47058 m .45818 .47216 L .45709 .46403 L p .638 .479 .651 r
F P
0 g
s
.45709 .46403 m .46366 .46263 L .4645 .47058 L p .638 .479 .651 r
F P
0 g
s
.71131 .12395 m .70585 .12764 L .69961 .12368 L p .465 .644 .935 r
F P
0 g
s
.70585 .12764 m .71131 .12395 L .71557 .12649 L p .454 .62 .922 r
F P
0 g
s
.55656 .50873 m .56045 .51416 L .55332 .51693 L p .687 .669 .826 r
F P
0 g
s
.55332 .51693 m .55015 .51121 L .55656 .50873 L p .687 .669 .826 r
F P
0 g
s
.57495 .4339 m .58091 .42864 L .58773 .43159 L p .533 .238 .412 r
F P
0 g
s
.59522 .42655 m .58773 .43159 L .58091 .42864 L p .54 .233 .396 r
F P
0 g
s
.51276 .44916 m .49851 .44948 L .49478 .43629 L p .732 .571 .673 r
F P
0 g
s
.49851 .44948 m .51276 .44916 L .50409 .46445 L p .72 .545 .652 r
F P
0 g
s
.51286 .44921 m .51966 .46091 L .5102 .46838 L p .71 .533 .647 r
F P
0 g
s
.5102 .46838 m .50409 .46445 L .51286 .44921 L p .71 .533 .647 r
F P
0 g
s
.51966 .46091 m .51286 .44921 L .53245 .45012 L p .704 .534 .654 r
F P
0 g
s
.68934 .11643 m .67351 .1183 L .66827 .11398 L p .53 .747 .975 r
F P
0 g
s
.67351 .1183 m .68934 .11643 L .69402 .11989 L p .549 .718 .952 r
F P
0 g
s
.42523 .42307 m .41573 .42081 L .41404 .41407 L p .524 .632 .899 r
F P
0 g
s
.40296 .40988 m .41404 .41407 L .41573 .42081 L p .491 .61 .898 r
F P
0 g
s
.49652 .34944 m .4978 .33746 L .50282 .34189 L p .98 .812 .605 r
F P
0 g
s
.50282 .34189 m .50108 .35357 L .49652 .34944 L p .98 .812 .605 r
F P
0 g
s
.5025 .26306 m .50849 .23807 L .51254 .24257 L p .982 .902 .576 r
F P
0 g
s
.51254 .24257 m .50629 .26712 L .5025 .26306 L p .982 .902 .576 r
F P
0 g
s
.48751 .43904 m .49478 .43629 L .49851 .44948 L p .73 .579 .686 r
F P
0 g
s
.49478 .43629 m .48751 .43904 L .48378 .42938 L p .748 .619 .716 r
F P
0 g
s
.48378 .42938 m .48972 .42611 L .49478 .43629 L p .748 .619 .716 r
F P
0 g
s
.54582 .4451 m .54381 .45126 L .53245 .45012 L p .67 .478 .617 r
F P
0 g
s
.54381 .45126 m .54582 .4451 L .55507 .44715 L p .631 .43 .593 r
F P
0 g
s
.55814 .44173 m .55507 .44715 L .54582 .4451 L p .638 .427 .581 r
F P
0 g
s
.53223 .4577 m .53245 .45012 L .54381 .45126 L p .67 .493 .637 r
F P
0 g
s
.53245 .45012 m .53223 .4577 L .51966 .46091 L p .704 .534 .654 r
F P
0 g
s
.49536 .42216 m .48972 .42611 L .48511 .41797 L p .78 .664 .736 r
F P
0 g
s
.48511 .41797 m .48985 .41407 L .49536 .42216 L p .78 .664 .736 r
F P
0 g
s
.46903 .45298 m .4624 .45416 L .46074 .4456 L p .682 .566 .718 r
F P
0 g
s
.47012 .46156 m .46366 .46263 L .4624 .45416 L p .67 .529 .684 r
F P
0 g
s
.4624 .45416 m .46903 .45298 L .47012 .46156 L p .67 .529 .684 r
F P
0 g
s
.769 .24912 m .7697 .21514 L .77497 .21573 L p .03 .033 .526 r
F P
0 g
s
.77497 .21573 m .77525 .25008 L .769 .24912 L p .03 .033 .526 r
F P
0 g
s
.4534 .48855 m .44692 .49238 L .44593 .48525 L p .535 .332 .551 r
F P
0 g
s
.44593 .48525 m .45264 .48198 L .4534 .48855 L p .535 .332 .551 r
F P
0 g
s
.16991 .63784 m .12113 .61097 L .12351 .6049 L p .76 .283 .111 r
F P
0 g
s
.09132 .57373 m .12351 .6049 L .12113 .61097 L p .869 .434 .162 r
F P
0 g
s
.48927 .40315 m .49297 .39801 L .49857 .40434 L p .832 .717 .738 r
F P
0 g
s
.49857 .40434 m .49431 .40957 L .48927 .40315 L p .832 .717 .738 r
F P
0 g
s
.40296 .40988 m .38988 .40426 L .38825 .39813 L p .361 .594 .935 r
F P
0 g
s
.37212 .39003 m .38825 .39813 L .38988 .40426 L p .349 .585 .932 r
F P
0 g
s
.44308 .43153 m .43546 .43144 L .43368 .42439 L p .624 .642 .847 r
F P
0 g
s
.42523 .42307 m .43368 .42439 L .43546 .43144 L p .593 .623 .851 r
F P
0 g
s
.52445 .53652 m .52492 .5286 L .53137 .52586 L p .832 .773 .796 r
F P
0 g
s
.52492 .5286 m .52445 .53652 L .51804 .53926 L p .873 .808 .783 r
F P
0 g
s
.51569 .54917 m .51804 .53926 L .52445 .53652 L p .873 .83 .801 r
F P
0 g
s
.46074 .4456 m .46735 .44428 L .46903 .45298 L p .682 .566 .718 r
F P
0 g
s
.46735 .44428 m .46074 .4456 L .45878 .43744 L p .692 .603 .751 r
F P
0 g
s
.45207 .43853 m .45878 .43744 L .46074 .4456 L p .673 .594 .758 r
F P
0 g
s
.50409 .46445 m .49705 .46192 L .49851 .44948 L p .72 .545 .652 r
F P
0 g
s
.49851 .44948 m .48996 .45013 L .48751 .43904 L p .73 .579 .686 r
F P
0 g
s
.48996 .45013 m .49851 .44948 L .49705 .46192 L p .718 .547 .658 r
F P
0 g
s
.51804 .53926 m .51569 .54917 L .50965 .5518 L p .917 .877 .781 r
F P
0 g
s
.50484 .56466 m .50965 .5518 L .51569 .54917 L p .914 .892 .794 r
F P
0 g
s
.66493 .39468 m .68404 .38226 L .68954 .38414 L p .144 0 0 r
F P
0 g
s
.71092 .36776 m .68954 .38414 L .68404 .38226 L p .129 0 .022 r
F P
0 g
s
.57259 .5096 m .57909 .51473 L .57267 .51714 L p .595 .666 .888 r
F P
0 g
s
.57267 .51714 m .56697 .51169 L .57259 .5096 L p .595 .666 .888 r
F P
0 g
s
.48059 .4411 m .48751 .43904 L .48996 .45013 L p .722 .58 .695 r
F P
0 g
s
.48751 .43904 m .48059 .4411 L .4777 .43205 L p .737 .618 .726 r
F P
0 g
s
.4777 .43205 m .48378 .42938 L .48751 .43904 L p .737 .618 .726 r
F P
0 g
s
.65337 .53688 m .68259 .55106 L .6771 .55256 L p .13 .545 .921 r
F P
0 g
s
.6771 .55256 m .649 .53816 L .65337 .53688 L p .13 .545 .921 r
F P
0 g
s
.47066 .46948 m .4645 .47058 L .46366 .46263 L p .657 .49 .646 r
F P
0 g
s
.46366 .46263 m .47012 .46156 L .47066 .46948 L p .657 .49 .646 r
F P
0 g
s
.45878 .43744 m .45207 .43853 L .45014 .43106 L p .68 .631 .794 r
F P
0 g
s
.44308 .43153 m .45014 .43106 L .45207 .43853 L p .656 .619 .801 r
F P
0 g
s
.47569 .45191 m .46903 .45298 L .46735 .44428 L p .698 .573 .711 r
F P
0 g
s
.47657 .46083 m .47012 .46156 L .46903 .45298 L p .686 .537 .678 r
F P
0 g
s
.46903 .45298 m .47569 .45191 L .47657 .46083 L p .686 .537 .678 r
F P
0 g
s
.72587 .13893 m .72413 .13116 L .72807 .13307 L p .364 .534 .89 r
F P
0 g
s
.72807 .13307 m .73202 .14195 L .72587 .13893 L p .364 .534 .89 r
F P
0 g
s
.53137 .52586 m .53051 .51925 L .53683 .51658 L p .791 .723 .788 r
F P
0 g
s
.53051 .51925 m .53137 .52586 L .52492 .5286 L p .828 .748 .775 r
F P
0 g
s
.49705 .46192 m .48994 .46077 L .48996 .45013 L p .718 .547 .658 r
F P
0 g
s
.48996 .45013 m .48257 .45095 L .48059 .4411 L p .722 .58 .695 r
F P
0 g
s
.48257 .45095 m .48996 .45013 L .48994 .46077 L p .71 .546 .665 r
F P
0 g
s
.46735 .44428 m .47392 .4428 L .47569 .45191 L p .698 .573 .711 r
F P
0 g
s
.47392 .4428 m .46735 .44428 L .46524 .43601 L p .709 .61 .744 r
F P
0 g
s
.45878 .43744 m .46524 .43601 L .46735 .44428 L p .692 .603 .751 r
F P
0 g
s
.48972 .42611 m .48378 .42938 L .48001 .42138 L p .768 .663 .747 r
F P
0 g
s
.48001 .42138 m .48511 .41797 L .48972 .42611 L p .768 .663 .747 r
F P
0 g
s
.35198 .38036 m .32631 .36981 L .32444 .36451 L p .182 .575 .938 r
F P
0 g
s
.29119 .35409 m .32444 .36451 L .32631 .36981 L p .269 .65 .967 r
F P
0 g
s
.55507 .44715 m .55814 .44173 L .5658 .44393 L p .585 .36 .54 r
F P
0 g
s
.56994 .43899 m .5658 .44393 L .55814 .44173 L p .593 .355 .524 r
F P
0 g
s
.7073 .1214 m .69961 .12368 L .69402 .11989 L p .465 .667 .95 r
F P
0 g
s
.69961 .12368 m .7073 .1214 L .71131 .12395 L p .465 .644 .935 r
F P
0 g
s
.55543 .15585 m .58199 .13378 L .58545 .13854 L p .82 .979 .89 r
F P
0 g
s
.61383 .12259 m .58545 .13854 L .58199 .13378 L p .732 .955 .946 r
F P
0 g
s
.56243 .50653 m .56697 .51169 L .56045 .51416 L p .645 .653 .843 r
F P
0 g
s
.56045 .51416 m .55656 .50873 L .56243 .50653 L p .645 .653 .843 r
F P
0 g
s
.47392 .4428 m .48059 .4411 L .48257 .45095 L p .711 .578 .704 r
F P
0 g
s
.48059 .4411 m .47392 .4428 L .47153 .43423 L p .724 .615 .735 r
F P
0 g
s
.47153 .43423 m .4777 .43205 L .48059 .4411 L p .724 .615 .735 r
F P
0 g
s
.465 .47762 m .45896 .47946 L .45818 .47216 L p .619 .43 .605 r
F P
0 g
s
.45818 .47216 m .4645 .47058 L .465 .47762 L p .619 .43 .605 r
F P
0 g
s
.58422 .51285 m .59343 .51804 L .58742 .52026 L p .519 .676 .936 r
F P
0 g
s
.58742 .52026 m .57909 .51473 L .58422 .51285 L p .519 .676 .936 r
F P
0 g
s
.48257 .45095 m .47569 .45191 L .47392 .4428 L p .711 .578 .704 r
F P
0 g
s
.48314 .46052 m .47657 .46083 L .47569 .45191 L p .699 .542 .671 r
F P
0 g
s
.47569 .45191 m .48257 .45095 L .48314 .46052 L p .699 .542 .671 r
F P
0 g
s
.48994 .46077 m .48314 .46052 L .48257 .45095 L p .71 .546 .665 r
F P
0 g
s
.46524 .43601 m .47153 .43423 L .47392 .4428 L p .709 .61 .744 r
F P
0 g
s
.49178 .38713 m .49453 .38034 L .49963 .38537 L p .898 .774 .716 r
F P
0 g
s
.49963 .38537 m .49643 .3921 L .49178 .38713 L p .898 .774 .716 r
F P
0 g
s
.48539 .40759 m .48927 .40315 L .49431 .40957 L p .819 .718 .754 r
F P
0 g
s
.49431 .40957 m .48985 .41407 L .48539 .40759 L p .819 .718 .754 r
F P
0 g
s
.49915 .28511 m .5025 .26306 L .50629 .26712 L p .987 .87 .516 r
F P
0 g
s
.50629 .26712 m .50262 .28874 L .49915 .28511 L p .987 .87 .516 r
F P
0 g
s
.55507 .44715 m .55275 .45237 L .54381 .45126 L p .631 .43 .593 r
F P
0 g
s
.54266 .45727 m .54381 .45126 L .55275 .45238 L p .63 .448 .617 r
F P
0 g
s
.54381 .45126 m .54266 .45727 L .53223 .4577 L p .67 .493 .637 r
F P
0 g
s
.47671 .46889 m .47066 .46948 L .47012 .46156 L p .673 .499 .641 r
F P
0 g
s
.47012 .46156 m .47657 .46083 L .47671 .46889 L p .673 .499 .641 r
F P
0 g
s
.56994 .43899 m .57495 .4339 L .58139 .43639 L p .524 .244 .431 r
F P
0 g
s
.58773 .43159 m .58139 .43639 L .57495 .4339 L p .533 .238 .412 r
F P
0 g
s
.59522 .42655 m .60403 .42118 L .60962 .42372 L p .417 .044 .22 r
F P
0 g
s
.62048 .41818 m .60962 .42372 L .60403 .42118 L p .422 .042 .21 r
F P
0 g
s
.5331 .46444 m .53223 .4577 L .54266 .45727 L p .665 .495 .645 r
F P
0 g
s
.53223 .4577 m .5331 .46444 L .52329 .46768 L p .695 .523 .651 r
F P
0 g
s
.52329 .46768 m .51966 .46091 L .53223 .4577 L p .695 .523 .651 r
F P
0 g
s
.46524 .43601 m .45878 .43744 L .45674 .43008 L p .702 .642 .786 r
F P
0 g
s
.45014 .43106 m .45674 .43008 L .45878 .43744 L p .68 .631 .794 r
F P
0 g
s
.44762 .49802 m .44079 .50355 L .43992 .49728 L p .436 .204 .462 r
F P
0 g
s
.43992 .49728 m .44692 .49238 L .44762 .49802 L p .436 .204 .462 r
F P
0 g
s
.54125 .50829 m .54347 .51386 L .53683 .51658 L p .752 .678 .779 r
F P
0 g
s
.54741 .50583 m .55015 .51121 L .54347 .51386 L p .719 .661 .792 r
F P
0 g
s
.54347 .51386 m .54125 .50829 L .54741 .50583 L p .719 .661 .792 r
F P
0 g
s
.48378 .42938 m .4777 .43205 L .47461 .42428 L p .754 .66 .758 r
F P
0 g
s
.47461 .42428 m .48001 .42138 L .48378 .42938 L p .754 .66 .758 r
F P
0 g
s
.40273 .55632 m .3859 .57529 L .38578 .57 L p 0 0 .001 r
F P
0 g
s
.38578 .57 m .40252 .55198 L .40273 .55632 L p 0 0 .001 r
F P
0 g
s
.51966 .46091 m .52329 .46768 L .51501 .47291 L p .712 .531 .643 r
F P
0 g
s
.51501 .47291 m .5102 .46838 L .51966 .46091 L p .712 .531 .643 r
F P
0 g
s
.49502 .35983 m .49652 .34944 L .50108 .35357 L p .976 .82 .624 r
F P
0 g
s
.50108 .35357 m .49917 .36372 L .49502 .35983 L p .976 .82 .624 r
F P
0 g
s
.45014 .43106 m .44308 .43153 L .44133 .42489 L p .654 .659 .842 r
F P
0 g
s
.43368 .42439 m .44133 .42489 L .44308 .43153 L p .624 .642 .847 r
F P
0 g
s
.43387 .51552 m .42535 .52511 L .42461 .51936 L p .229 0 .305 r
F P
0 g
s
.42461 .51936 m .43323 .51055 L .43387 .51552 L p .229 0 .305 r
F P
0 g
s
.06785 .51961 m .07629 .53524 L .07534 .54142 L p .982 .712 .435 r
F P
0 g
s
.07629 .53524 m .06785 .51961 L .0683 .51541 L p .978 .73 .494 r
F P
0 g
s
.45949 .48564 m .4534 .48855 L .45264 .48198 L p .562 .348 .547 r
F P
0 g
s
.45264 .48198 m .45896 .47946 L .45949 .48564 L p .562 .348 .547 r
F P
0 g
s
.48269 .46883 m .47671 .46889 L .47657 .46083 L p .688 .506 .636 r
F P
0 g
s
.47657 .46083 m .48314 .46052 L .48269 .46883 L p .688 .506 .636 r
F P
0 g
s
.43368 .42439 m .42523 .42307 L .42366 .41698 L p .563 .657 .9 r
F P
0 g
s
.41404 .41407 m .42366 .41698 L .42523 .42307 L p .524 .632 .899 r
F P
0 g
s
.53683 .51658 m .53513 .51082 L .54125 .50829 L p .752 .678 .779 r
F P
0 g
s
.53513 .51082 m .53683 .51658 L .53051 .51925 L p .786 .698 .767 r
F P
0 g
s
.55336 .50356 m .55656 .50873 L .55015 .51121 L p .683 .644 .805 r
F P
0 g
s
.55015 .51121 m .54741 .50583 L .55336 .50356 L p .683 .644 .805 r
F P
0 g
s
.4777 .43205 m .47153 .43423 L .46894 .42669 L p .739 .656 .768 r
F P
0 g
s
.46894 .42669 m .47461 .42428 L .4777 .43205 L p .739 .656 .768 r
F P
0 g
s
.47153 .43423 m .46524 .43601 L .46299 .42862 L p .721 .65 .778 r
F P
0 g
s
.45674 .43008 m .46299 .42862 L .46524 .43601 L p .702 .642 .786 r
F P
0 g
s
.47081 .47639 m .465 .47762 L .4645 .47058 L p .639 .442 .6 r
F P
0 g
s
.4645 .47058 m .47066 .46948 L .47081 .47639 L p .639 .442 .6 r
F P
0 g
s
.46299 .42862 m .46894 .42669 L .47153 .43423 L p .721 .65 .778 r
F P
0 g
s
.4886 .46939 m .48269 .46883 L .48314 .46052 L p .701 .513 .631 r
F P
0 g
s
.48314 .46052 m .48994 .46077 L .4886 .46939 L p .701 .513 .631 r
F P
0 g
s
.48985 .41407 m .48511 .41797 L .48124 .41148 L p .806 .716 .765 r
F P
0 g
s
.48124 .41148 m .48539 .40759 L .48985 .41407 L p .806 .716 .765 r
F P
0 g
s
.50965 .5518 m .50484 .56466 L .49972 .567 L p .946 .945 .747 r
F P
0 g
s
.49203 .58427 m .49972 .567 L .50484 .56466 L p .943 .949 .75 r
F P
0 g
s
.49435 .47063 m .4886 .46939 L .48994 .46077 L p .71 .518 .627 r
F P
0 g
s
.48994 .46077 m .49705 .46192 L .49435 .47063 L p .71 .518 .627 r
F P
0 g
s
.11661 .39887 m .08899 .42862 L .08718 .42526 L p .88 .987 .816 r
F P
0 g
s
.08718 .42526 m .11418 .39408 L .11661 .39887 L p .88 .987 .816 r
F P
0 g
s
.61598 .89052 m .66327 .89407 L .66154 .89675 L p .478 0 0 r
F P
0 g
s
.66154 .89675 m .61264 .89512 L .61598 .89052 L p .478 0 0 r
F P
0 g
s
.64796 .40422 m .66493 .39468 L .66981 .39644 L p .154 0 0 r
F P
0 g
s
.68954 .38414 m .66981 .39644 L .66493 .39468 L p .144 0 0 r
F P
0 g
s
.55275 .45237 m .55507 .44715 L .56246 .44873 L p .578 .366 .557 r
F P
0 g
s
.5658 .44393 m .56246 .44873 L .55507 .44715 L p .585 .36 .54 r
F P
0 g
s
.49973 .47257 m .49435 .47063 L .49705 .46192 L p .717 .522 .625 r
F P
0 g
s
.49705 .46192 m .50409 .46445 L .49973 .47257 L p .717 .522 .625 r
F P
0 g
s
.48874 .39306 m .49178 .38713 L .49643 .3921 L p .885 .778 .739 r
F P
0 g
s
.49643 .3921 m .49297 .39801 L .48874 .39306 L p .885 .778 .739 r
F P
0 g
s
.07574 .46484 m .06773 .48042 L .06717 .47723 L p .983 .892 .65 r
F P
0 g
s
.06717 .47723 m .07474 .45918 L .07574 .46484 L p .983 .892 .65 r
F P
0 g
s
.50409 .46445 m .5102 .46838 L .50466 .47518 L p .717 .521 .624 r
F P
0 g
s
.50466 .47518 m .49973 .47257 L .50409 .46445 L p .717 .521 .624 r
F P
0 g
s
.55275 .45238 m .55108 .45751 L .54266 .45727 L p .63 .448 .617 r
F P
0 g
s
.54224 .4631 m .54266 .45727 L .55108 .45751 L p .626 .454 .63 r
F P
0 g
s
.54266 .45727 m .54224 .4631 L .5331 .46444 L p .665 .495 .645 r
F P
0 g
s
.41404 .41407 m .40296 .40988 L .40153 .40452 L p .393 .618 .941 r
F P
0 g
s
.38825 .39813 m .40153 .40452 L .40296 .40988 L p .361 .594 .935 r
F P
0 g
s
.53441 .4704 m .5331 .46444 L .54224 .4631 L p .661 .5 .655 r
F P
0 g
s
.5331 .46444 m .53441 .4704 L .52618 .47339 L p .691 .524 .656 r
F P
0 g
s
.52618 .47339 m .52329 .46768 L .5331 .46444 L p .691 .524 .656 r
F P
0 g
s
.45674 .43008 m .45014 .43106 L .44834 .42468 L p .683 .674 .835 r
F P
0 g
s
.44133 .42489 m .44834 .42468 L .45014 .43106 L p .654 .659 .842 r
F P
0 g
s
.52329 .46768 m .52618 .47339 L .51883 .47749 L p .713 .535 .648 r
F P
0 g
s
.51883 .47749 m .51501 .47291 L .52329 .46768 L p .713 .535 .648 r
F P
0 g
s
.59769 .51653 m .61047 .52207 L .60536 .52389 L p .387 .667 .97 r
F P
0 g
s
.60536 .52389 m .59343 .51804 L .59769 .51653 L p .387 .667 .97 r
F P
0 g
s
.47643 .47574 m .47081 .47639 L .47066 .46948 L p .659 .454 .596 r
F P
0 g
s
.47066 .46948 m .47671 .46889 L .47643 .47574 L p .659 .454 .596 r
F P
0 g
s
.73202 .14195 m .72807 .13307 L .73153 .1346 L p .308 .497 .88 r
F P
0 g
s
.73153 .1346 m .73746 .14437 L .73202 .14195 L p .308 .497 .88 r
F P
0 g
s
.48511 .41797 m .48001 .42138 L .4767 .41494 L p .791 .714 .779 r
F P
0 g
s
.4767 .41494 m .48124 .41148 L .48511 .41797 L p .791 .714 .779 r
F P
0 g
s
.49731 .30422 m .49915 .28511 L .50262 .28874 L p .988 .847 .474 r
F P
0 g
s
.50262 .28874 m .50045 .30746 L .49731 .30422 L p .988 .847 .474 r
F P
0 g
s
.5658 .44393 m .56994 .43899 L .57608 .44103 L p .515 .251 .452 r
F P
0 g
s
.58139 .43639 m .57608 .44103 L .56994 .43899 L p .524 .244 .431 r
F P
0 g
s
.52492 .5286 m .52478 .52174 L .53051 .51925 L p .828 .748 .775 r
F P
0 g
s
.52478 .52174 m .52492 .5286 L .51938 .531 L p .87 .781 .76 r
F P
0 g
s
.51804 .53926 m .51938 .531 L .52492 .5286 L p .873 .808 .783 r
F P
0 g
s
.49203 .58427 m .48252 .60758 L .47833 .60992 L p .912 .949 .603 r
F P
0 g
s
.46719 .64327 m .47833 .60992 L .48252 .60758 L p .944 .93 .577 r
F P
0 g
s
.53051 .51925 m .52934 .51333 L .53513 .51082 L p .786 .698 .767 r
F P
0 g
s
.52934 .51333 m .53051 .51925 L .52478 .52174 L p .823 .721 .753 r
F P
0 g
s
.70372 .11897 m .69402 .11989 L .68934 .11643 L p .454 .687 .965 r
F P
0 g
s
.69402 .11989 m .70372 .11897 L .7073 .1214 L p .465 .667 .95 r
F P
0 g
s
.5588 .50157 m .56243 .50653 L .55656 .50873 L p .641 .626 .82 r
F P
0 g
s
.55656 .50873 m .55336 .50356 L .5588 .50157 L p .641 .626 .82 r
F P
0 g
s
.5675 .50469 m .57259 .5096 L .56697 .51169 L p .591 .636 .864 r
F P
0 g
s
.56697 .51169 m .56243 .50653 L .5675 .50469 L p .591 .636 .864 r
F P
0 g
s
.7697 .21514 m .76414 .18586 L .76824 .18616 L p .017 .112 .621 r
F P
0 g
s
.76824 .18616 m .77497 .21573 L .7697 .21514 L p .017 .112 .621 r
F P
0 g
s
.58773 .43159 m .59522 .42655 L .60037 .42877 L p .409 .048 .237 r
F P
0 g
s
.60962 .42372 m .60037 .42877 L .59522 .42655 L p .417 .044 .22 r
F P
0 g
s
.46526 .4835 m .45949 .48564 L .45896 .47946 L p .589 .364 .543 r
F P
0 g
s
.45896 .47946 m .465 .47762 L .46526 .4835 L p .589 .364 .543 r
F P
0 g
s
.5102 .46838 m .51501 .47291 L .5091 .47835 L p .723 .527 .625 r
F P
0 g
s
.5091 .47835 m .50466 .47518 L .5102 .46838 L p .723 .527 .625 r
F P
0 g
s
.53914 .50304 m .54125 .50829 L .53513 .51082 L p .747 .655 .758 r
F P
0 g
s
.54501 .50069 m .54741 .50583 L .54125 .50829 L p .714 .637 .771 r
F P
0 g
s
.54125 .50829 m .53914 .50304 L .54501 .50069 L p .714 .637 .771 r
F P
0 g
s
.49322 .36887 m .49502 .35983 L .49917 .36372 L p .97 .831 .649 r
F P
0 g
s
.49917 .36372 m .497 .37258 L .49322 .36887 L p .97 .831 .649 r
F P
0 g
s
.37212 .39003 m .35198 .38036 L .35043 .3758 L p .131 .53 .917 r
F P
0 g
s
.32444 .36451 m .35043 .3758 L .35198 .38036 L p .182 .575 .938 r
F P
0 g
s
.66719 .89027 m .69455 .88717 L .69269 .88904 L p .372 0 .005 r
F P
0 g
s
.69269 .88904 m .66327 .89407 L .66719 .89027 L p .372 0 .005 r
F P
0 g
s
.45392 .49372 m .44762 .49802 L .44692 .49238 L p .469 .223 .458 r
F P
0 g
s
.44692 .49238 m .4534 .48855 L .45392 .49372 L p .469 .223 .458 r
F P
0 g
s
.48186 .47565 m .47643 .47574 L .47671 .46889 L p .676 .465 .592 r
F P
0 g
s
.47671 .46889 m .48269 .46883 L .48186 .47565 L p .676 .465 .592 r
F P
0 g
s
.797 .73931 m .78457 .79908 L .77952 .79936 L p .014 0 .392 r
F P
0 g
s
.7591 .83943 m .77952 .79936 L .78457 .79908 L p .004 0 .196 r
F P
0 g
s
.77952 .79936 m .7591 .83943 L .7542 .84072 L p .191 0 .33 r
F P
0 g
s
.48001 .42138 m .47461 .42428 L .47179 .41793 L p .774 .71 .792 r
F P
0 g
s
.47179 .41793 m .4767 .41494 L .48001 .42138 L p .774 .71 .792 r
F P
0 g
s
.46299 .42862 m .45674 .43008 L .45482 .42383 L p .709 .686 .826 r
F P
0 g
s
.44834 .42468 m .45482 .42383 L .45674 .43008 L p .683 .674 .835 r
F P
0 g
s
.51938 .531 m .51804 .53926 L .51296 .54149 L p .92 .854 .761 r
F P
0 g
s
.50965 .5518 m .51296 .54149 L .51804 .53926 L p .917 .877 .781 r
F P
0 g
s
.48547 .3982 m .48874 .39306 L .49297 .39801 L p .871 .782 .76 r
F P
0 g
s
.49297 .39801 m .48927 .40315 L .48547 .3982 L p .871 .782 .76 r
F P
0 g
s
.56246 .44873 m .55983 .45335 L .55275 .45237 L p .578 .366 .557 r
F P
0 g
s
.55108 .45751 m .55275 .45238 L .55983 .45335 L p .577 .386 .586 r
F P
0 g
s
.44133 .42489 m .43368 .42439 L .43218 .41878 L p .602 .682 .897 r
F P
0 g
s
.42366 .41698 m .43218 .41878 L .43368 .42439 L p .563 .657 .9 r
F P
0 g
s
.55069 .49856 m .55336 .50356 L .54741 .50583 L p .678 .619 .783 r
F P
0 g
s
.54741 .50583 m .54501 .50069 L .55069 .49856 L p .678 .619 .783 r
F P
0 g
s
.53513 .51082 m .53334 .50549 L .53914 .50304 L p .747 .655 .758 r
F P
0 g
s
.53334 .50549 m .53513 .51082 L .52934 .51333 L p .78 .673 .745 r
F P
0 g
s
.58199 .13378 m .61102 .11848 L .61383 .12259 L p .732 .955 .946 r
F P
0 g
s
.64119 .11366 m .61383 .12259 L .61102 .11848 L p .628 .909 .983 r
F P
0 g
s
.55108 .45751 m .54999 .46265 L .54224 .4631 L p .626 .454 .63 r
F P
0 g
s
.54239 .46865 m .54224 .4631 L .54999 .46265 L p .622 .463 .645 r
F P
0 g
s
.54224 .4631 m .54239 .46865 L .53441 .4704 L p .661 .5 .655 r
F P
0 g
s
.71556 .87304 m .71775 .87709 L .71561 .87836 L p .29 0 .105 r
F P
0 g
s
.71561 .87836 m .7104 .87609 L .71556 .87304 L p .29 0 .105 r
F P
0 g
s
.71775 .87709 m .71556 .87304 L .72078 .87014 L p .277 0 .112 r
F P
0 g
s
.57709 .50797 m .58422 .51285 L .57909 .51473 L p .516 .647 .916 r
F P
0 g
s
.57909 .51473 m .57259 .5096 L .57709 .50797 L p .516 .647 .916 r
F P
0 g
s
.48708 .47613 m .48186 .47565 L .48269 .46883 L p .692 .476 .589 r
F P
0 g
s
.48269 .46883 m .4886 .46939 L .48708 .47613 L p .692 .476 .589 r
F P
0 g
s
.52618 .47339 m .52866 .47858 L .522 .48201 L p .715 .544 .657 r
F P
0 g
s
.522 .48201 m .51883 .47749 L .52618 .47339 L p .715 .544 .657 r
F P
0 g
s
.52866 .47858 m .52618 .47339 L .53441 .4704 L p .69 .531 .666 r
F P
0 g
s
.47461 .42428 m .46894 .42669 L .46651 .42042 L p .755 .705 .805 r
F P
0 g
s
.46651 .42042 m .47179 .41793 L .47461 .42428 L p .755 .705 .805 r
F P
0 g
s
.53588 .47584 m .53441 .4704 L .54239 .46865 L p .66 .508 .667 r
F P
0 g
s
.53441 .4704 m .53588 .47584 L .52866 .47858 L p .69 .531 .666 r
F P
0 g
s
.46894 .42669 m .46299 .42862 L .46087 .4224 L p .733 .697 .816 r
F P
0 g
s
.45482 .42383 m .46087 .4224 L .46299 .42862 L p .709 .686 .826 r
F P
0 g
s
.51501 .47291 m .51883 .47749 L .51299 .48189 L p .73 .537 .63 r
F P
0 g
s
.51299 .48189 m .5091 .47835 L .51501 .47291 L p .73 .537 .63 r
F P
0 g
s
.46087 .4224 m .46651 .42042 L .46894 .42669 L p .733 .697 .816 r
F P
0 g
s
.73794 .86223 m .7542 .84072 L .7591 .83943 L p .127 0 .136 r
F P
0 g
s
.7542 .84072 m .73794 .86223 L .73459 .86346 L p .225 0 .214 r
F P
0 g
s
.63319 .41183 m .64796 .40422 L .65227 .40583 L p .159 0 0 r
F P
0 g
s
.66981 .39644 m .65227 .40583 L .64796 .40422 L p .154 0 0 r
F P
0 g
s
.63067 .52778 m .65337 .53688 L .649 .53816 L p .141 .578 .928 r
F P
0 g
s
.649 .53816 m .62717 .52884 L .63067 .52778 L p .141 .578 .928 r
F P
0 g
s
.7104 .87609 m .71561 .87836 L .71359 .87964 L p .294 0 .087 r
F P
0 g
s
.71359 .87964 m .70551 .87916 L .7104 .87609 L p .294 0 .087 r
F P
0 g
s
.49201 .47714 m .48708 .47613 L .4886 .46939 L p .706 .486 .587 r
F P
0 g
s
.4886 .46939 m .49435 .47063 L .49201 .47714 L p .706 .486 .587 r
F P
0 g
s
.44132 .50792 m .43387 .51552 L .43323 .51055 L p .258 0 .303 r
F P
0 g
s
.43323 .51055 m .44079 .50355 L .44132 .50792 L p .258 0 .303 r
F P
0 g
s
.71991 .87588 m .72078 .87014 L .72582 .8675 L p .255 0 .108 r
F P
0 g
s
.72078 .87014 m .71991 .87588 L .71775 .87709 L p .277 0 .112 r
F P
0 g
s
.47076 .48207 m .46526 .4835 L .465 .47762 L p .614 .38 .539 r
F P
0 g
s
.465 .47762 m .47081 .47639 L .47076 .48207 L p .614 .38 .539 r
F P
0 g
s
.56246 .44873 m .5658 .44393 L .57167 .44553 L p .506 .259 .474 r
F P
0 g
s
.57608 .44103 m .57167 .44553 L .5658 .44393 L p .515 .251 .452 r
F P
0 g
s
.41545 .54071 m .40273 .55632 L .40252 .55198 L p 0 0 .001 r
F P
0 g
s
.40252 .55198 m .41521 .53712 L .41545 .54071 L p 0 0 .001 r
F P
0 g
s
.53709 .49801 m .53914 .50304 L .53334 .50549 L p .741 .632 .738 r
F P
0 g
s
.54287 .49571 m .54501 .50069 L .53914 .50304 L p .708 .615 .75 r
F P
0 g
s
.53914 .50304 m .53709 .49801 L .54287 .49571 L p .708 .615 .75 r
F P
0 g
s
.7502 .16175 m .74193 .14606 L .74524 .14696 L p .174 .362 .81 r
F P
0 g
s
.74524 .14696 m .75508 .16313 L .7502 .16175 L p .174 .362 .81 r
F P
0 g
s
.48199 .40263 m .48547 .3982 L .48927 .40315 L p .854 .783 .781 r
F P
0 g
s
.48927 .40315 m .48539 .40759 L .48199 .40263 L p .854 .783 .781 r
F P
0 g
s
.49658 .47864 m .49201 .47714 L .49435 .47063 L p .718 .496 .588 r
F P
0 g
s
.49435 .47063 m .49973 .47257 L .49658 .47864 L p .718 .496 .588 r
F P
0 g
s
.49616 .32067 m .49731 .30422 L .50045 .30746 L p .988 .834 .452 r
F P
0 g
s
.50045 .30746 m .49901 .32358 L .49616 .32067 L p .988 .834 .452 r
F P
0 g
s
.49109 .37675 m .49322 .36887 L .497 .37258 L p .961 .842 .679 r
F P
0 g
s
.497 .37258 m .49453 .38034 L .49109 .37675 L p .961 .842 .679 r
F P
0 g
s
.52866 .47858 m .53092 .48352 L .52475 .48651 L p .719 .557 .669 r
F P
0 g
s
.52475 .48651 m .522 .48201 L .52866 .47858 L p .719 .557 .669 r
F P
0 g
s
.53092 .48352 m .52866 .47858 L .53588 .47584 L p .692 .542 .678 r
F P
0 g
s
.55591 .49671 m .5588 .50157 L .55336 .50356 L p .636 .599 .795 r
F P
0 g
s
.55336 .50356 m .55069 .49856 L .55591 .49671 L p .636 .599 .795 r
F P
0 g
s
.55983 .45335 m .55779 .45793 L .55108 .45751 L p .577 .386 .586 r
F P
0 g
s
.54999 .46265 m .55108 .45751 L .55779 .45793 L p .572 .397 .606 r
F P
0 g
s
.52934 .51333 m .52788 .50793 L .53334 .50549 L p .78 .673 .745 r
F P
0 g
s
.52788 .50793 m .52934 .51333 L .52411 .51567 L p .816 .694 .73 r
F P
0 g
s
.52478 .52174 m .52411 .51567 L .52934 .51333 L p .823 .721 .753 r
F P
0 g
s
.54848 .49366 m .55069 .49856 L .54501 .50069 L p .673 .595 .761 r
F P
0 g
s
.54501 .50069 m .54287 .49571 L .54848 .49366 L p .673 .595 .761 r
F P
0 g
s
.51883 .47749 m .522 .48201 L .51637 .48568 L p .737 .549 .64 r
F P
0 g
s
.51637 .48568 m .51299 .48189 L .51883 .47749 L p .737 .549 .64 r
F P
0 g
s
.54239 .46865 m .54297 .47393 L .53588 .47584 L p .66 .508 .667 r
F P
0 g
s
.53746 .48097 m .53588 .47584 L .54297 .47393 L p .66 .52 .683 r
F P
0 g
s
.53588 .47584 m .53746 .48097 L .53092 .48352 L p .692 .542 .678 r
F P
0 g
s
.64119 .11366 m .66482 .11053 L .66827 .11398 L p .592 .82 .986 r
F P
0 g
s
.68575 .11346 m .66827 .11398 L .66482 .11053 L p .487 .769 .994 r
F P
0 g
s
.66827 .11398 m .68575 .11346 L .68934 .11643 L p .53 .747 .975 r
F P
0 g
s
.58139 .43639 m .58773 .43159 L .59252 .43348 L p .4 .054 .259 r
F P
0 g
s
.60037 .42877 m .59252 .43348 L .58773 .43159 L p .409 .048 .237 r
F P
0 g
s
.53334 .50549 m .53144 .50046 L .53709 .49801 L p .741 .632 .738 r
F P
0 g
s
.53144 .50046 m .53334 .50549 L .52788 .50793 L p .774 .649 .724 r
F P
0 g
s
.42366 .41698 m .41404 .41407 L .41276 .40931 L p .438 .65 .949 r
F P
0 g
s
.40153 .40452 m .41276 .40931 L .41404 .41407 L p .393 .618 .941 r
F P
0 g
s
.44834 .42468 m .44133 .42489 L .43984 .41963 L p .641 .705 .892 r
F P
0 g
s
.43218 .41878 m .43984 .41963 L .44133 .42489 L p .602 .682 .897 r
F P
0 g
s
.54999 .46265 m .54943 .46772 L .54239 .46865 L p .622 .463 .645 r
F P
0 g
s
.54297 .47393 m .54239 .46865 L .54943 .46772 L p .62 .474 .662 r
F P
0 g
s
.49973 .47257 m .50466 .47518 L .50085 .48062 L p .723 .503 .591 r
F P
0 g
s
.50085 .48062 m .49659 .47865 L .49973 .47257 L p .723 .503 .591 r
F P
0 g
s
.52411 .51567 m .52478 .52174 L .51988 .52391 L p .865 .751 .735 r
F P
0 g
s
.51938 .531 m .51988 .52391 L .52478 .52174 L p .87 .781 .76 r
F P
0 g
s
.45981 .49045 m .45392 .49372 L .4534 .48855 L p .503 .244 .455 r
F P
0 g
s
.4534 .48855 m .45949 .48564 L .45981 .49045 L p .503 .244 .455 r
F P
0 g
s
.56351 .4999 m .5675 .50469 L .56243 .50653 L p .586 .605 .838 r
F P
0 g
s
.56243 .50653 m .5588 .50157 L .56351 .4999 L p .586 .605 .838 r
F P
0 g
s
.47601 .48127 m .47076 .48207 L .47081 .47639 L p .638 .396 .535 r
F P
0 g
s
.47081 .47639 m .47643 .47574 L .47601 .48127 L p .638 .396 .535 r
F P
0 g
s
.53507 .49314 m .53709 .49801 L .53144 .50046 L p .735 .61 .719 r
F P
0 g
s
.54092 .49082 m .54287 .49571 L .53709 .49801 L p .703 .593 .73 r
F P
0 g
s
.53709 .49801 m .53507 .49314 L .54092 .49082 L p .703 .593 .73 r
F P
0 g
s
.70551 .87916 m .71359 .87964 L .71178 .88086 L p .289 0 .058 r
F P
0 g
s
.71178 .88086 m .70112 .88212 L .70551 .87916 L p .289 0 .058 r
F P
0 g
s
.53092 .48352 m .53303 .48834 L .52718 .49104 L p .724 .572 .683 r
F P
0 g
s
.52718 .49104 m .52475 .48651 L .53092 .48352 L p .724 .572 .683 r
F P
0 g
s
.53303 .48834 m .53092 .48352 L .53746 .48097 L p .695 .557 .694 r
F P
0 g
s
.06886 .49979 m .0649 .49995 L .06486 .49728 L p .997 .821 .548 r
F P
0 g
s
.06486 .49728 m .06877 .49434 L .06886 .49979 L p .997 .821 .548 r
F P
0 g
s
.0649 .49995 m .06886 .49979 L .06881 .50528 L p .997 .807 .532 r
F P
0 g
s
.48539 .40759 m .48124 .41148 L .47822 .40654 L p .838 .781 .797 r
F P
0 g
s
.47822 .40654 m .48199 .40264 L .48539 .40759 L p .838 .781 .797 r
F P
0 g
s
.72202 .87478 m .72582 .8675 L .73049 .86525 L p .223 0 .093 r
F P
0 g
s
.72582 .8675 m .72202 .87478 L .71991 .87588 L p .255 0 .108 r
F P
0 g
s
.50466 .47518 m .5091 .47835 L .50486 .48306 L p .735 .515 .595 r
F P
0 g
s
.50486 .48306 m .50085 .48062 L .50466 .47518 L p .735 .515 .595 r
F P
0 g
s
.51296 .54149 m .50965 .5518 L .50545 .55371 L p .955 .932 .733 r
F P
0 g
s
.49972 .567 m .50545 .55371 L .50965 .5518 L p .946 .945 .747 r
F P
0 g
s
.522 .48201 m .52475 .48651 L .51931 .48967 L p .744 .565 .652 r
F P
0 g
s
.51931 .48967 m .51637 .48568 L .522 .48201 L p .744 .565 .652 r
F P
0 g
s
.54297 .47393 m .54389 .479 L .53746 .48097 L p .66 .52 .683 r
F P
0 g
s
.53913 .48593 m .53746 .48097 L .54389 .479 L p .661 .535 .7 r
F P
0 g
s
.53746 .48097 m .53913 .48593 L .53303 .48834 L p .695 .557 .694 r
F P
0 g
s
.54663 .48881 m .54848 .49366 L .54287 .49571 L p .668 .573 .739 r
F P
0 g
s
.54287 .49571 m .54092 .49082 L .54663 .48881 L p .668 .573 .739 r
F P
0 g
s
.55983 .45335 m .56246 .44873 L .56806 .4499 L p .498 .27 .498 r
F P
0 g
s
.57167 .44553 m .56806 .4499 L .56246 .44873 L p .506 .259 .474 r
F P
0 g
s
.53303 .48834 m .53507 .49314 L .5294 .49567 L p .729 .59 .7 r
F P
0 g
s
.53913 .48593 m .54092 .49082 L .53507 .49314 L p .699 .574 .711 r
F P
0 g
s
.53507 .49314 m .53303 .48834 L .53913 .48593 L p .699 .574 .711 r
F P
0 g
s
.53144 .50046 m .5294 .49567 L .53507 .49314 L p .735 .61 .719 r
F P
0 g
s
.06487 .50263 m .06881 .50528 L .06862 .51056 L p .997 .794 .51 r
F P
0 g
s
.06881 .50528 m .06487 .50263 L .0649 .49995 L p .997 .807 .532 r
F P
0 g
s
.5294 .49567 m .52718 .49104 L .53303 .48834 L p .729 .59 .7 r
F P
0 g
s
.5294 .49567 m .53144 .50046 L .52616 .50293 L p .767 .626 .704 r
F P
0 g
s
.52788 .50793 m .52616 .50293 L .53144 .50046 L p .774 .649 .724 r
F P
0 g
s
.06877 .49434 m .06486 .49728 L .06475 .49473 L p .997 .834 .558 r
F P
0 g
s
.06475 .49473 m .06854 .48916 L .06877 .49434 L p .997 .834 .558 r
F P
0 g
s
.54943 .46772 m .54937 .47269 L .54297 .47393 L p .62 .474 .662 r
F P
0 g
s
.54389 .479 m .54297 .47393 L .54937 .47269 L p .619 .489 .681 r
F P
0 g
s
.48101 .48104 m .47601 .48127 L .47643 .47574 L p .66 .411 .533 r
F P
0 g
s
.47643 .47574 m .48186 .47565 L .48101 .48104 L p .66 .411 .533 r
F P
0 g
s
.54389 .479 m .54511 .48394 L .53913 .48593 L p .661 .535 .7 r
F P
0 g
s
.54092 .49082 m .53913 .48593 L .54511 .48394 L p .664 .553 .719 r
F P
0 g
s
.55779 .45793 m .55626 .46257 L .54999 .46265 L p .572 .397 .606 r
F P
0 g
s
.54943 .46772 m .54999 .46265 L .55626 .46257 L p .568 .41 .626 r
F P
0 g
s
.54511 .48394 m .54663 .48881 L .54092 .49082 L p .664 .553 .719 r
F P
0 g
s
.62048 .41818 m .63319 .41183 L .63702 .41328 L p .16 0 0 r
F P
0 g
s
.65227 .40583 m .63702 .41328 L .63319 .41183 L p .159 0 0 r
F P
0 g
s
.55363 .49192 m .55591 .49671 L .55069 .49856 L p .631 .573 .771 r
F P
0 g
s
.55069 .49856 m .54848 .49366 L .55363 .49192 L p .631 .573 .771 r
F P
0 g
s
.38825 .39813 m .37212 .39003 L .37083 .38612 L p .116 .515 .911 r
F P
0 g
s
.35043 .3758 m .37083 .38612 L .37212 .39003 L p .131 .53 .917 r
F P
0 g
s
.45482 .42383 m .44834 .42468 L .44681 .41964 L p .678 .725 .885 r
F P
0 g
s
.43984 .41963 m .44681 .41964 L .44834 .42468 L p .641 .705 .892 r
F P
0 g
s
.58786 .51156 m .59769 .51653 L .59343 .51804 L p .386 .645 .959 r
F P
0 g
s
.59343 .51804 m .58422 .51285 L .58786 .51156 L p .386 .645 .959 r
F P
0 g
s
.52475 .48651 m .52718 .49104 L .5219 .49386 L p .752 .584 .668 r
F P
0 g
s
.5219 .49386 m .51931 .48967 L .52475 .48651 L p .752 .584 .668 r
F P
0 g
s
.5091 .47835 m .51299 .48189 L .50853 .48592 L p .747 .531 .602 r
F P
0 g
s
.50853 .48592 m .50486 .48306 L .5091 .47835 L p .747 .531 .602 r
F P
0 g
s
.52616 .50293 m .52788 .50793 L .523 .51022 L p .809 .667 .707 r
F P
0 g
s
.52411 .51567 m .523 .51022 L .52788 .50793 L p .816 .694 .73 r
F P
0 g
s
.73746 .14437 m .73153 .1346 L .73437 .13566 L p .234 .451 .866 r
F P
0 g
s
.73437 .13566 m .74193 .14606 L .73746 .14437 L p .234 .451 .866 r
F P
0 g
s
.51988 .52391 m .51938 .531 L .51501 .53294 L p .92 .823 .735 r
F P
0 g
s
.51296 .54149 m .51501 .53294 L .51938 .531 L p .92 .854 .761 r
F P
0 g
s
.48864 .38362 m .49109 .37675 L .49453 .38034 L p .95 .852 .711 r
F P
0 g
s
.49453 .38034 m .49178 .38713 L .48864 .38362 L p .95 .852 .711 r
F P
0 g
s
.48124 .41148 m .4767 .41494 L .47406 .41002 L p .818 .778 .815 r
F P
0 g
s
.47406 .41002 m .47822 .40654 L .48124 .41148 L p .818 .778 .815 r
F P
0 g
s
.52718 .49104 m .5294 .49567 L .52417 .49826 L p .759 .604 .685 r
F P
0 g
s
.52616 .50293 m .52417 .49826 L .5294 .49567 L p .767 .626 .704 r
F P
0 g
s
.52417 .49826 m .5219 .49386 L .52718 .49104 L p .759 .604 .685 r
F P
0 g
s
.70071 .11676 m .68934 .11643 L .68575 .11346 L p .427 .702 .979 r
F P
0 g
s
.68934 .11643 m .70071 .11676 L .70372 .11897 L p .454 .687 .965 r
F P
0 g
s
.57155 .50326 m .57709 .50797 L .57259 .5096 L p .512 .613 .889 r
F P
0 g
s
.57259 .5096 m .5675 .50469 L .57155 .50326 L p .512 .613 .889 r
F P
0 g
s
.49522 .33482 m .49616 .32067 L .49901 .32358 L p .988 .832 .45 r
F P
0 g
s
.49901 .32358 m .4978 .33746 L .49522 .33482 L p .988 .832 .45 r
F P
0 g
s
.44803 .50193 m .44132 .50792 L .44079 .50355 L p .297 .012 .3 r
F P
0 g
s
.44079 .50355 m .44762 .49802 L .44803 .50193 L p .297 .012 .3 r
F P
0 g
s
.57608 .44103 m .58139 .43639 L .58589 .43799 L p .39 .063 .286 r
F P
0 g
s
.59252 .43348 m .58589 .43799 L .58139 .43639 L p .4 .054 .259 r
F P
0 g
s
.48573 .48133 m .48101 .48104 L .48186 .47565 L p .681 .427 .531 r
F P
0 g
s
.48186 .47565 m .48708 .47613 L .48573 .48133 L p .681 .427 .531 r
F P
0 g
s
.12113 .61097 m .08947 .57771 L .09132 .57373 L p .869 .434 .162 r
F P
0 g
s
.07424 .54578 m .09132 .57373 L .08947 .57771 L p .935 .559 .212 r
F P
0 g
s
.09132 .57373 m .07424 .54578 L .07534 .54142 L p .948 .616 .361 r
F P
0 g
s
.46536 .48805 m .45981 .49045 L .45949 .48564 L p .537 .265 .451 r
F P
0 g
s
.45949 .48564 m .46526 .4835 L .46536 .48805 L p .537 .265 .451 r
F P
0 g
s
.54937 .47269 m .54977 .47757 L .54389 .479 L p .619 .489 .681 r
F P
0 g
s
.54511 .48394 m .54389 .479 L .54977 .47757 L p .62 .506 .702 r
F P
0 g
s
.51299 .48189 m .51637 .48568 L .51184 .48914 L p .758 .549 .613 r
F P
0 g
s
.51184 .48914 m .50853 .48592 L .51299 .48189 L p .758 .549 .613 r
F P
0 g
s
.0673 .52296 m .07534 .54142 L .07424 .54578 L p .981 .688 .356 r
F P
0 g
s
.07534 .54142 m .0673 .52296 L .06785 .51961 L p .982 .712 .435 r
F P
0 g
s
.4767 .41494 m .47179 .41793 L .46949 .41305 L p .796 .773 .832 r
F P
0 g
s
.46949 .41305 m .47406 .41002 L .4767 .41494 L p .796 .773 .832 r
F P
0 g
s
.55188 .48716 m .55363 .49192 L .54848 .49366 L p .626 .549 .747 r
F P
0 g
s
.54848 .49366 m .54663 .48881 L .55188 .48716 L p .626 .549 .747 r
F P
0 g
s
.46087 .4224 m .45482 .42383 L .4532 .41892 L p .712 .742 .875 r
F P
0 g
s
.44681 .41964 m .4532 .41892 L .45482 .42383 L p .678 .725 .885 r
F P
0 g
s
.49972 .567 m .49203 .58427 L .48872 .58601 L p .898 .955 .612 r
F P
0 g
s
.47833 .60992 m .48872 .58601 L .49203 .58427 L p .912 .949 .603 r
F P
0 g
s
.06477 .5052 m .06862 .51056 L .0683 .51541 L p .997 .781 .481 r
F P
0 g
s
.06862 .51056 m .06477 .5052 L .06487 .50263 L p .997 .794 .51 r
F P
0 g
s
.56042 .49519 m .56351 .4999 L .5588 .50157 L p .581 .574 .81 r
F P
0 g
s
.5588 .50157 m .55591 .49671 L .56042 .49519 L p .581 .574 .81 r
F P
0 g
s
.43218 .41878 m .42366 .41698 L .42248 .41269 L p .491 .687 .954 r
F P
0 g
s
.41276 .40931 m .42248 .41269 L .42366 .41698 L p .438 .65 .949 r
F P
0 g
s
.523 .51022 m .52411 .51567 L .51967 .51772 L p .858 .72 .708 r
F P
0 g
s
.51988 .52391 m .51967 .51772 L .52411 .51567 L p .865 .751 .735 r
F P
0 g
s
.56806 .4499 m .56518 .45412 L .55983 .45335 L p .498 .27 .498 r
F P
0 g
s
.55779 .45793 m .55983 .45335 L .56518 .45412 L p .498 .295 .535 r
F P
0 g
s
.49016 .4821 m .48573 .48133 L .48708 .47613 L p .7 .443 .532 r
F P
0 g
s
.48708 .47613 m .49201 .47714 L .49016 .4821 L p .7 .443 .532 r
F P
0 g
s
.52417 .49826 m .52616 .50293 L .52149 .50526 L p .8 .641 .685 r
F P
0 g
s
.523 .51022 m .52149 .50526 L .52616 .50293 L p .809 .667 .707 r
F P
0 g
s
.54977 .47757 m .5506 .48239 L .54511 .48394 L p .62 .506 .702 r
F P
0 g
s
.54663 .48881 m .54511 .48394 L .5506 .48239 L p .623 .526 .724 r
F P
0 g
s
.71557 .12649 m .71722 .12371 L .7198 .12516 L p .346 .579 .928 r
F P
0 g
s
.7198 .12516 m .71991 .12893 L .71557 .12649 L p .346 .579 .928 r
F P
0 g
s
.71722 .12371 m .71557 .12649 L .71131 .12395 L p .362 .599 .938 r
F P
0 g
s
.55626 .46257 m .55524 .46724 L .54943 .46772 L p .568 .41 .626 r
F P
0 g
s
.54937 .47269 m .54943 .46772 L .55524 .46724 L p .566 .425 .649 r
F P
0 g
s
.06854 .48916 m .06475 .49473 L .06459 .49242 L p .997 .848 .561 r
F P
0 g
s
.06459 .49242 m .06819 .48445 L .06854 .48916 L p .997 .848 .561 r
F P
0 g
s
.5506 .48239 m .55188 .48716 L .54663 .48881 L p .623 .526 .724 r
F P
0 g
s
.47179 .41793 m .46651 .42042 L .4645 .41557 L p .771 .766 .848 r
F P
0 g
s
.4645 .41557 m .46949 .41305 L .47179 .41793 L p .771 .766 .848 r
F P
0 g
s
.51637 .48568 m .51931 .48967 L .51479 .49269 L p .769 .569 .627 r
F P
0 g
s
.51479 .49269 m .51184 .48914 L .51637 .48568 L p .769 .569 .627 r
F P
0 g
s
.46651 .42042 m .46087 .4224 L .45908 .41754 L p .743 .755 .862 r
F P
0 g
s
.4532 .41892 m .45908 .41754 L .46087 .4224 L p .712 .742 .875 r
F P
0 g
s
.42559 .52814 m .41545 .54071 L .41521 .53712 L p 0 0 0 r
F P
0 g
s
.41521 .53712 m .42535 .52511 L .42559 .52814 L p 0 0 0 r
F P
0 g
s
.45908 .41754 m .4645 .41557 L .46651 .42042 L p .743 .755 .862 r
F P
0 g
s
.76414 .18586 m .75508 .16313 L .75803 .16327 L p .008 .187 .7 r
F P
0 g
s
.75803 .16327 m .76824 .18616 L .76414 .18586 L p .008 .187 .7 r
F P
0 g
s
.70112 .88212 m .71178 .88086 L .71026 .88198 L p .273 0 .016 r
F P
0 g
s
.71026 .88198 m .69741 .88483 L .70112 .88212 L p .273 0 .016 r
F P
0 g
s
.71991 .12893 m .7198 .12516 L .72231 .12648 L p .32 .555 .919 r
F P
0 g
s
.72231 .12648 m .72413 .13116 L .71991 .12893 L p .32 .555 .919 r
F P
0 g
s
.71469 .1222 m .71131 .12395 L .7073 .1214 L p .368 .617 .947 r
F P
0 g
s
.71131 .12395 m .71469 .1222 L .71722 .12371 L p .362 .599 .938 r
F P
0 g
s
.49424 .48328 m .49016 .4821 L .49201 .47714 L p .718 .46 .534 r
F P
0 g
s
.49201 .47714 m .49658 .47864 L .49424 .48328 L p .718 .46 .534 r
F P
0 g
s
.48589 .38959 m .48864 .38362 L .49178 .38713 L p .935 .861 .743 r
F P
0 g
s
.49178 .38713 m .48874 .39306 L .48589 .38959 L p .935 .861 .743 r
F P
0 g
s
.5219 .49386 m .52417 .49826 L .51961 .50073 L p .79 .615 .664 r
F P
0 g
s
.52149 .50526 m .51961 .50073 L .52417 .49826 L p .8 .641 .685 r
F P
0 g
s
.51931 .48967 m .5219 .49386 L .51737 .49654 L p .78 .591 .644 r
F P
0 g
s
.51737 .49654 m .51479 .49269 L .51931 .48967 L p .78 .591 .644 r
F P
0 g
s
.07474 .45918 m .06717 .47723 L .06655 .47501 L p .981 .913 .627 r
F P
0 g
s
.06655 .47501 m .07364 .45522 L .07474 .45918 L p .981 .913 .627 r
F P
0 g
s
.72396 .87384 m .73049 .86525 L .73459 .86346 L p .183 0 .065 r
F P
0 g
s
.73049 .86525 m .72396 .87384 L .72202 .87478 L p .223 0 .093 r
F P
0 g
s
.51961 .50073 m .51737 .49654 L .5219 .49386 L p .79 .615 .664 r
F P
0 g
s
.6133 .52118 m .63067 .52778 L .62717 .52884 L p .145 .587 .929 r
F P
0 g
s
.62717 .52884 m .61047 .52207 L .6133 .52118 L p .145 .587 .929 r
F P
0 g
s
.47061 .48642 m .46536 .48805 L .46526 .4835 L p .57 .287 .447 r
F P
0 g
s
.46526 .4835 m .47076 .48207 L .47061 .48642 L p .57 .287 .447 r
F P
0 g
s
.61102 .11848 m .63907 .11039 L .64119 .11366 L p .628 .909 .983 r
F P
0 g
s
.66482 .11053 m .64119 .11366 L .63907 .11039 L p .514 .846 .997 r
F P
0 g
s
.60962 .42372 m .62048 .41818 L .62391 .41947 L p .156 0 0 r
F P
0 g
s
.62391 .41947 m .62048 .41818 L p .63637 .41347 L .16 0 0 r
F P
0 g
s
.61271 .42486 m .60962 .42372 L p .62229 .41995 L .156 0 0 r
F P
0 g
s
.62391 .41947 m .61271 .42486 L p .62229 .41995 L .156 0 0 r
F P
0 g
s
.60037 .42877 m .60962 .42372 L .61271 .42486 L p .148 0 0 r
F P
0 g
s
.60319 .42975 m .60037 .42877 L p .61072 .42549 L .148 0 0 r
F P
0 g
s
.61271 .42486 m .60319 .42975 L p .61072 .42549 L .148 0 0 r
F P
0 g
s
.59252 .43348 m .60037 .42877 L .60319 .42975 L p .137 0 0 r
F P
0 g
s
.59512 .43433 m .59252 .43348 L p .60115 .43047 L .137 0 0 r
F P
0 g
s
.60319 .42975 m .59512 .43433 L p .60115 .43047 L .137 0 0 r
F P
0 g
s
.58589 .43799 m .59252 .43348 L .59512 .43433 L p .123 0 0 r
F P
0 g
s
.59512 .43433 m .5883 .43869 L .58589 .43799 L p .123 0 0 r
F P
0 g
s
.59512 .43433 m .59543 .43412 L p .58954 .4379 L .385 .8 .599 r
F P
0 g
s
.5883 .43869 m .59512 .43433 L p .58954 .4379 L .385 .8 .599 r
F P
0 g
s
.60319 .42975 m .60356 .4295 L p .59633 .43363 L .357 .794 .623 r
F P
0 g
s
.59512 .43433 m .60319 .42975 L p .59633 .43363 L .357 .794 .623 r
F P
0 g
s
.61271 .42486 m .61316 .42456 L p .60418 .42924 L .336 .787 .641 r
F P
0 g
s
.60319 .42975 m .61271 .42486 L p .60418 .42924 L .336 .787 .641 r
F P
0 g
s
.62391 .41947 m .62446 .41911 L p .61309 .42468 L .322 .783 .652 r
F P
0 g
s
.61271 .42486 m .62391 .41947 L p .61309 .42468 L .322 .783 .652 r
F P
0 g
s
.63702 .41328 m .62391 .41947 L p .63637 .41347 L .16 0 0 r
F P
0 g
s
.49659 .47865 m .50085 .48062 L .49809 .48486 L p .73 .474 .541 r
F P
0 g
s
.49809 .48486 m .49425 .48328 L .49659 .47865 L p .73 .474 .541 r
F P
0 g
s
.55524 .46724 m .55475 .47191 L .54937 .47269 L p .566 .425 .649 r
F P
0 g
s
.54977 .47757 m .54937 .47269 L .55475 .47191 L p .565 .444 .673 r
F P
0 g
s
.08899 .42862 m .07364 .45522 L .07247 .45313 L p .938 .965 .698 r
F P
0 g
s
.07247 .45313 m .08718 .42526 L .08899 .42862 L p .938 .965 .698 r
F P
0 g
s
.57167 .44553 m .57608 .44103 L .58032 .44233 L p .379 .074 .317 r
F P
0 g
s
.58589 .43799 m .58032 .44233 L .57608 .44103 L p .39 .063 .286 r
F P
0 g
s
.55809 .49052 m .56042 .49519 L .55591 .49671 L p .576 .544 .782 r
F P
0 g
s
.55591 .49671 m .55363 .49192 L .55809 .49052 L p .576 .544 .782 r
F P
0 g
s
.56518 .45412 m .56286 .45832 L .55779 .45793 L p .498 .295 .535 r
F P
0 g
s
.55626 .46257 m .55779 .45793 L .56286 .45832 L p .492 .31 .562 r
F P
0 g
s
.49419 .34702 m .49522 .33482 L .4978 .33746 L p .988 .841 .465 r
F P
0 g
s
.4978 .33746 m .49652 .34944 L .49419 .34702 L p .988 .841 .465 r
F P
0 g
s
.52149 .50526 m .523 .51022 L .51888 .51223 L p .849 .688 .682 r
F P
0 g
s
.51967 .51772 m .51888 .51223 L .523 .51022 L p .858 .72 .708 r
F P
0 g
s
.50085 .48062 m .50486 .48306 L .50176 .48687 L p .747 .494 .548 r
F P
0 g
s
.50176 .48687 m .49809 .48486 L .50085 .48062 L p .747 .494 .548 r
F P
0 g
s
.51967 .51772 m .51988 .52391 L .51602 .52567 L p .916 .789 .706 r
F P
0 g
s
.51501 .53294 m .51602 .52567 L .51988 .52391 L p .92 .823 .735 r
F P
0 g
s
.45421 .49729 m .44803 .50193 L .44762 .49802 L p .341 .037 .296 r
F P
0 g
s
.44762 .49802 m .45392 .49372 L .45421 .49729 L p .341 .037 .296 r
F P
0 g
s
.56727 .49862 m .57155 .50326 L .5675 .50469 L p .507 .576 .859 r
F P
0 g
s
.5675 .50469 m .56351 .4999 L .56727 .49862 L p .507 .576 .859 r
F P
0 g
s
.51501 .53294 m .51296 .54149 L .50943 .54308 L p .964 .908 .711 r
F P
0 g
s
.50545 .55371 m .50943 .54308 L .51296 .54149 L p .955 .932 .733 r
F P
0 g
s
.72413 .13116 m .72231 .12648 L .72464 .12761 L p .284 .528 .91 r
F P
0 g
s
.72464 .12761 m .72807 .13307 L .72413 .13116 L p .284 .528 .91 r
F P
0 g
s
.40153 .40452 m .38825 .39813 L .38717 .39476 L p .132 .529 .917 r
F P
0 g
s
.37083 .38612 m .38717 .39476 L .38825 .39813 L p .116 .515 .911 r
F P
0 g
s
.43984 .41963 m .43218 .41878 L .43106 .41484 L p .546 .724 .957 r
F P
0 g
s
.42248 .41269 m .43106 .41484 L .43218 .41878 L p .491 .687 .954 r
F P
0 g
s
.48289 .39477 m .48589 .38959 L .48874 .39306 L p .917 .867 .775 r
F P
0 g
s
.48874 .39306 m .48547 .3982 L .48289 .39477 L p .917 .867 .775 r
F P
0 g
s
.7123 .12069 m .7073 .1214 L .70372 .11897 L p .364 .632 .956 r
F P
0 g
s
.7073 .1214 m .7123 .12069 L .71469 .1222 L p .368 .617 .947 r
F P
0 g
s
.55475 .47191 m .55477 .47658 L .54977 .47757 L p .565 .444 .673 r
F P
0 g
s
.5506 .48239 m .54977 .47757 L .55477 .47658 L p .566 .465 .699 r
F P
0 g
s
.47559 .48544 m .47061 .48642 L .47076 .48207 L p .602 .309 .444 r
F P
0 g
s
.47076 .48207 m .47601 .48127 L .47559 .48544 L p .602 .309 .444 r
F P
0 g
s
.55641 .48587 m .55809 .49052 L .55363 .49192 L p .572 .515 .753 r
F P
0 g
s
.55363 .49192 m .55188 .48716 L .55641 .48587 L p .572 .515 .753 r
F P
0 g
s
.50486 .48306 m .50853 .48592 L .5052 .48929 L p .764 .516 .558 r
F P
0 g
s
.5052 .48929 m .50176 .48687 L .50486 .48306 L p .764 .516 .558 r
F P
0 g
s
.0646 .50755 m .0683 .51541 L .06785 .51961 L p .997 .768 .445 r
F P
0 g
s
.0683 .51541 m .0646 .50755 L .06477 .5052 L p .997 .781 .481 r
F P
0 g
s
.58026 .50686 m .58786 .51156 L .58422 .51285 L p .382 .611 .94 r
F P
0 g
s
.58422 .51285 m .57709 .50797 L .58026 .50686 L p .382 .611 .94 r
F P
0 g
s
.55477 .47658 m .55532 .48123 L .5506 .48239 L p .566 .465 .699 r
F P
0 g
s
.55188 .48716 m .5506 .48239 L .55532 .48123 L p .568 .489 .726 r
F P
0 g
s
.55532 .48123 m .55641 .48587 L .55188 .48716 L p .568 .489 .726 r
F P
0 g
s
.06819 .48445 m .06459 .49242 L .06436 .49043 L p .997 .86 .556 r
F P
0 g
s
.06436 .49043 m .06773 .48042 L .06819 .48445 L p .997 .86 .556 r
F P
0 g
s
.51961 .50073 m .52149 .50526 L .51758 .50732 L p .838 .657 .657 r
F P
0 g
s
.51888 .51223 m .51758 .50732 L .52149 .50526 L p .849 .688 .682 r
F P
0 g
s
.56286 .45832 m .56103 .46262 L .55626 .46257 L p .492 .31 .562 r
F P
0 g
s
.55524 .46724 m .55626 .46257 L .56103 .46262 L p .488 .328 .591 r
F P
0 g
s
.50853 .48592 m .51184 .48914 L .50835 .49211 L p .781 .54 .572 r
F P
0 g
s
.50835 .49211 m .5052 .48929 L .50853 .48592 L p .781 .54 .572 r
F P
0 g
s
.56806 .4499 m .57167 .44553 L .57569 .44655 L p .368 .087 .349 r
F P
0 g
s
.58032 .44233 m .57569 .44655 L .57167 .44553 L p .379 .074 .317 r
F P
0 g
s
.48028 .48504 m .47559 .48544 L .47601 .48127 L p .632 .331 .442 r
F P
0 g
s
.47601 .48127 m .48101 .48104 L .48028 .48504 L p .632 .331 .442 r
F P
0 g
s
.47967 .39922 m .48289 .39477 L .48547 .3982 L p .896 .871 .804 r
F P
0 g
s
.48547 .3982 m .48199 .40263 L .47967 .39922 L p .896 .871 .804 r
F P
0 g
s
.51184 .48914 m .51479 .49269 L .5112 .49532 L p .797 .567 .589 r
F P
0 g
s
.5112 .49532 m .50835 .49211 L .51184 .48914 L p .797 .567 .589 r
F P
0 g
s
.51737 .49654 m .51961 .50073 L .51584 .5029 L p .826 .626 .632 r
F P
0 g
s
.51758 .50732 m .51584 .5029 L .51961 .50073 L p .838 .657 .657 r
F P
0 g
s
.4929 .35758 m .49419 .34702 L .49652 .34944 L p .988 .857 .493 r
F P
0 g
s
.49652 .34944 m .49502 .35983 L .4929 .35758 L p .988 .857 .493 r
F P
0 g
s
.51479 .49269 m .51737 .49654 L .5137 .49891 L p .812 .596 .61 r
F P
0 g
s
.5137 .49891 m .5112 .49532 L .51479 .49269 L p .812 .596 .61 r
F P
0 g
s
.44681 .41964 m .43984 .41963 L .43874 .41594 L p .6 .758 .954 r
F P
0 g
s
.43106 .41484 m .43874 .41594 L .43984 .41963 L p .546 .724 .957 r
F P
0 g
s
.43408 .51811 m .42559 .52814 L .42535 .52511 L p 0 0 0 r
F P
0 g
s
.42535 .52511 m .43387 .51552 L .43408 .51811 L p 0 0 0 r
F P
0 g
s
.51584 .5029 m .5137 .49891 L .51737 .49654 L p .826 .626 .632 r
F P
0 g
s
.56403 .49403 m .56727 .49862 L .56351 .4999 L p .501 .538 .826 r
F P
0 g
s
.56351 .4999 m .56042 .49519 L .56403 .49403 L p .501 .538 .826 r
F P
0 g
s
.45997 .49375 m .45421 .49729 L .45392 .49372 L p .387 .064 .291 r
F P
0 g
s
.45392 .49372 m .45981 .49045 L .45997 .49375 L p .387 .064 .291 r
F P
0 g
s
.51888 .51223 m .51967 .51772 L .51619 .51938 L p .909 .752 .675 r
F P
0 g
s
.51602 .52567 m .51619 .51938 L .51967 .51772 L p .916 .789 .706 r
F P
0 g
s
.48468 .48516 m .48028 .48504 L .48101 .48104 L p .661 .354 .442 r
F P
0 g
s
.48101 .48104 m .48573 .48133 L .48468 .48516 L p .661 .354 .442 r
F P
0 g
s
.56103 .46262 m .55972 .467 L .55524 .46724 L p .488 .328 .591 r
F P
0 g
s
.55475 .47191 m .55524 .46724 L .55972 .467 L p .485 .35 .621 r
F P
0 g
s
.50545 .55371 m .49972 .567 L .49708 .56835 L p .903 .952 .608 r
F P
0 g
s
.49708 .56835 m .49972 .567 L p .48994 .5839 L .898 .955 .612 r
F P
0 g
s
.50329 .55477 m .50545 .55371 L p .49957 .56399 L .903 .952 .608 r
F P
0 g
s
.49708 .56835 m .50329 .55477 L p .49957 .56399 L .903 .952 .608 r
F P
0 g
s
.50943 .54308 m .50545 .55371 L .50329 .55477 L p .922 .943 .592 r
F P
0 g
s
.50764 .54396 m .50943 .54308 L p .50557 .55044 L .922 .943 .592 r
F P
0 g
s
.50329 .55477 m .50764 .54396 L p .50557 .55044 L .922 .943 .592 r
F P
0 g
s
.51198 .53432 m .50943 .54308 L .50764 .54396 L p .946 .925 .566 r
F P
0 g
s
.51044 .53508 m .51198 .53432 L p .50937 .54012 L .946 .925 .566 r
F P
0 g
s
.50764 .54396 m .51044 .53508 L p .50937 .54012 L .946 .925 .566 r
F P
0 g
s
.51336 .52692 m .51198 .53432 L .51044 .53508 L p .97 .895 .528 r
F P
0 g
s
.51044 .53508 m .51201 .52759 L .51336 .52692 L p .97 .895 .528 r
F P
0 g
s
.51044 .53508 m .51046 .53516 L p .51144 .53038 L 0 0 0 r
F P
0 g
s
.51201 .52759 m .51044 .53508 L p .51144 .53038 L 0 0 0 r
F P
0 g
s
.50764 .54396 m .50766 .54408 L p .50951 .53808 L 0 0 0 r
F P
0 g
s
.51044 .53508 m .50764 .54396 L p .50951 .53808 L 0 0 0 r
F P
0 g
s
.50329 .55477 m .5033 .55495 L p .50652 .54678 L 0 0 0 r
F P
0 g
s
.50764 .54396 m .50329 .55477 L p .50652 .54678 L 0 0 0 r
F P
0 g
s
.49708 .56835 m .49707 .56861 L p .50275 .55599 L 0 0 0 r
F P
0 g
s
.50329 .55477 m .49708 .56835 L p .50275 .55599 L 0 0 0 r
F P
0 g
s
.48872 .58601 m .49708 .56835 L p .48994 .5839 L .898 .955 .612 r
F P
0 g
s
.48199 .40264 m .47822 .40654 L .47615 .40315 L p .874 .869 .83 r
F P
0 g
s
.47615 .40315 m .47967 .39922 L .48199 .40264 L p .874 .869 .83 r
F P
0 g
s
.69741 .88483 m .71026 .88198 L .7091 .88294 L p .246 0 0 r
F P
0 g
s
.7091 .88294 m .69455 .88717 L .69741 .88483 L p .246 0 0 r
F P
0 g
s
.72807 .13307 m .72464 .12761 L .72669 .12851 L p .236 .496 .899 r
F P
0 g
s
.72669 .12851 m .73153 .1346 L .72807 .13307 L p .236 .496 .899 r
F P
0 g
s
.71017 .11924 m .70372 .11897 L .70071 .11676 L p .348 .642 .964 r
F P
0 g
s
.70372 .11897 m .71017 .11924 L .7123 .12069 L p .364 .632 .956 r
F P
0 g
s
.48878 .48573 m .48468 .48516 L .48573 .48133 L p .688 .378 .445 r
F P
0 g
s
.48573 .48133 m .49016 .4821 L .48878 .48573 L p .688 .378 .445 r
F P
0 g
s
.56518 .45412 m .56806 .4499 L .57189 .45065 L p .358 .103 .384 r
F P
0 g
s
.57569 .44655 m .57189 .45065 L .56806 .4499 L p .368 .087 .349 r
F P
0 g
s
.72567 .87309 m .73459 .86346 L .73794 .86223 L p .132 0 .023 r
F P
0 g
s
.73459 .86346 m .72567 .87309 L .72396 .87384 L p .183 0 .065 r
F P
0 g
s
.41276 .40931 m .40153 .40452 L .40061 .40159 L p .173 .565 .934 r
F P
0 g
s
.38717 .39476 m .40061 .40159 L .40153 .40452 L p .132 .529 .917 r
F P
0 g
s
.4532 .41892 m .44681 .41964 L .44568 .41612 L p .652 .789 .947 r
F P
0 g
s
.43874 .41594 m .44568 .41612 L .44681 .41964 L p .6 .758 .954 r
F P
0 g
s
.74193 .14606 m .73437 .13566 L .73646 .13622 L p .133 .392 .844 r
F P
0 g
s
.73646 .13622 m .74524 .14696 L .74193 .14606 L p .133 .392 .844 r
F P
0 g
s
.60003 .51578 m .6133 .52118 L .61047 .52207 L p .142 .576 .928 r
F P
0 g
s
.61047 .52207 m .59769 .51653 L .60003 .51578 L p .142 .576 .928 r
F P
0 g
s
.51602 .52567 m .51501 .53294 L .51198 .53432 L p .972 .876 .681 r
F P
0 g
s
.50943 .54308 m .51198 .53432 L .51501 .53294 L p .964 .908 .711 r
F P
0 g
s
.47822 .40654 m .47406 .41002 L .47222 .40665 L p .848 .866 .856 r
F P
0 g
s
.47222 .40665 m .47615 .40315 L .47822 .40654 L p .848 .866 .856 r
F P
0 g
s
.55972 .467 m .55894 .47143 L .55475 .47191 L p .485 .35 .621 r
F P
0 g
s
.55477 .47658 m .55475 .47191 L .55894 .47143 L p .484 .374 .653 r
F P
0 g
s
.49256 .48668 m .48878 .48573 L .49016 .4821 L p .714 .403 .45 r
F P
0 g
s
.49016 .4821 m .49424 .48328 L .49256 .48668 L p .714 .403 .45 r
F P
0 g
s
.56165 .48947 m .56403 .49403 L .56042 .49519 L p .495 .501 .792 r
F P
0 g
s
.56042 .49519 m .55809 .49052 L .56165 .48947 L p .495 .501 .792 r
F P
0 g
s
.66482 .11053 m .6834 .11109 L .68575 .11346 L p .487 .769 .994 r
F P
0 g
s
.69841 .11485 m .68575 .11346 L .6834 .11109 L p .377 .707 .986 r
F P
0 g
s
.68575 .11346 m .69841 .11485 L .70071 .11676 L p .427 .702 .979 r
F P
0 g
s
.57441 .50228 m .58026 .50686 L .57709 .50797 L p .377 .569 .913 r
F P
0 g
s
.57709 .50797 m .57155 .50326 L .57441 .50228 L p .377 .569 .913 r
F P
0 g
s
.49129 .36675 m .4929 .35758 L .49502 .35983 L p .987 .879 .533 r
F P
0 g
s
.49502 .35983 m .49322 .36887 L .49129 .36675 L p .987 .879 .533 r
F P
0 g
s
.51758 .50732 m .51888 .51223 L .51566 .51386 L p .899 .713 .643 r
F P
0 g
s
.51619 .51938 m .51566 .51386 L .51888 .51223 L p .909 .752 .675 r
F P
0 g
s
.46537 .49115 m .45997 .49375 L .45981 .49045 L p .434 .093 .287 r
F P
0 g
s
.45981 .49045 m .46536 .48805 L .46537 .49115 L p .434 .093 .287 r
F P
0 g
s
.66327 .89407 m .69269 .88904 L .6919 .89035 L p .291 0 0 r
F P
0 g
s
.6919 .89035 m .66154 .89675 L .66327 .89407 L p .291 0 0 r
F P
0 g
s
.46464 .75113 m .49455 .81846 L .49449 .82183 L p .746 .378 0 r
F P
0 g
s
.49455 .81846 m .55023 .87125 L .55068 .87457 L p .653 .128 0 r
F P
0 g
s
.55068 .87457 m .49449 .82183 L .49455 .81846 L p .653 .128 0 r
F P
0 g
s
.49425 .48328 m .49809 .48486 L .49613 .48801 L p .735 .427 .46 r
F P
0 g
s
.49613 .48801 m .49256 .48668 L .49425 .48328 L p .735 .427 .46 r
F P
0 g
s
.47406 .41002 m .46949 .41305 L .46786 .40969 L p .817 .86 .88 r
F P
0 g
s
.46786 .40969 m .47222 .40665 L .47406 .41002 L p .817 .86 .88 r
F P
0 g
s
.45908 .41754 m .4532 .41892 L .45201 .4155 L p .7 .814 .936 r
F P
0 g
s
.44568 .41612 m .45201 .4155 L .4532 .41892 L p .652 .789 .947 r
F P
0 g
s
.45953 .68989 m .46464 .75113 L .46428 .75374 L p .749 .564 0 r
F P
0 g
s
.49449 .82183 m .46428 .75374 L .46464 .75113 L p .746 .378 0 r
F P
0 g
s
.55894 .47143 m .55871 .47591 L .55477 .47658 L p .484 .374 .653 r
F P
0 g
s
.55532 .48123 m .55477 .47658 L .55871 .47591 L p .484 .402 .687 r
F P
0 g
s
.57189 .45065 m .56882 .45462 L .56518 .45412 L p .358 .103 .384 r
F P
0 g
s
.56286 .45832 m .56518 .45412 L .56881 .45462 L p .358 .135 .434 r
F P
0 g
s
.06438 .50958 m .06785 .51961 L .0673 .52296 L p .994 .752 .4 r
F P
0 g
s
.06785 .51961 m .06438 .50958 L .0646 .50755 L p .997 .768 .445 r
F P
0 g
s
.56002 .48493 m .56165 .48947 L .55809 .49052 L p .49 .465 .757 r
F P
0 g
s
.55809 .49052 m .55641 .48587 L .56002 .48493 L p .49 .465 .757 r
F P
0 g
s
.46949 .41305 m .4645 .41557 L .46305 .41222 L p .782 .849 .901 r
F P
0 g
s
.46305 .41222 m .46786 .40969 L .46949 .41305 L p .782 .849 .901 r
F P
0 g
s
.4645 .41557 m .45908 .41754 L .45778 .41417 L p .743 .834 .92 r
F P
0 g
s
.45201 .4155 m .45778 .41417 L .45908 .41754 L p .7 .814 .936 r
F P
0 g
s
.49809 .48486 m .50176 .48687 L .49956 .48974 L p .759 .455 .471 r
F P
0 g
s
.49956 .48974 m .49613 .48801 L .49809 .48486 L p .759 .455 .471 r
F P
0 g
s
.45778 .41417 m .46305 .41222 L .4645 .41557 L p .743 .834 .92 r
F P
0 g
s
.55871 .47591 m .55905 .48041 L .55532 .48123 L p .484 .402 .687 r
F P
0 g
s
.55641 .48587 m .55532 .48123 L .55905 .48041 L p .487 .432 .722 r
F P
0 g
s
.78457 .79908 m .76207 .83936 L .7591 .83943 L p .004 0 .196 r
F P
0 g
s
.7404 .86159 m .7591 .83943 L .76207 .83936 L p 0 0 .024 r
F P
0 g
s
.7591 .83943 m .7404 .86159 L .73794 .86223 L p .127 0 .136 r
F P
0 g
s
.55905 .48041 m .56002 .48493 L .55641 .48587 L p .487 .432 .722 r
F P
0 g
s
.4415 .51017 m .43408 .51811 L .43387 .51552 L p 0 0 0 r
F P
0 g
s
.43387 .51552 m .44132 .50792 L .4415 .51017 L p 0 0 0 r
F P
0 g
s
.06773 .48042 m .06436 .49043 L .06409 .48886 L p .993 .87 .542 r
F P
0 g
s
.06409 .48886 m .06717 .47723 L .06773 .48042 L p .993 .87 .542 r
F P
0 g
s
.51584 .5029 m .51758 .50732 L .51455 .50898 L p .885 .674 .611 r
F P
0 g
s
.51566 .51386 m .51455 .50898 L .51758 .50732 L p .899 .713 .643 r
F P
0 g
s
.50176 .48687 m .5052 .48929 L .5028 .49188 L p .783 .487 .486 r
F P
0 g
s
.5028 .49188 m .49956 .48974 L .50176 .48687 L p .783 .487 .486 r
F P
0 g
s
.75508 .16313 m .74524 .14696 L .74722 .14701 L p .003 .256 .761 r
F P
0 g
s
.74722 .14701 m .75803 .16327 L .75508 .16313 L p .003 .256 .761 r
F P
0 g
s
.28261 .64148 m .22595 .64959 L .22862 .64813 L p 0 0 0 r
F P
0 g
s
.22862 .64813 m .28469 .64012 L .28261 .64148 L p 0 0 0 r
F P
0 g
s
.16991 .63784 m .22862 .64813 L .22595 .64959 L p .273 0 0 r
F P
0 g
s
.47046 .48935 m .46537 .49115 L .46536 .48805 L p .48 .123 .282 r
F P
0 g
s
.46536 .48805 m .47061 .48642 L .47046 .48935 L p .48 .123 .282 r
F P
0 g
s
.5052 .48929 m .50835 .49211 L .5058 .49443 L p .807 .521 .504 r
F P
0 g
s
.5058 .49443 m .5028 .49188 L .5052 .48929 L p .807 .521 .504 r
F P
0 g
s
.48933 .37473 m .49129 .36675 L .49322 .36887 L p .982 .902 .579 r
F P
0 g
s
.49322 .36887 m .49109 .37675 L .48933 .37473 L p .982 .902 .579 r
F P
0 g
s
.32824 .62161 m .28261 .64148 L .28469 .64012 L p 0 0 0 r
F P
0 g
s
.28469 .64012 m .32974 .62055 L .32824 .62161 L p 0 0 0 r
F P
0 g
s
.63907 .11039 m .66333 .10812 L .66482 .11053 L p .514 .846 .997 r
F P
0 g
s
.6834 .11109 m .66482 .11053 L .66333 .10812 L p .401 .772 .993 r
F P
0 g
s
.5137 .49891 m .51584 .5029 L .51295 .50465 L p .869 .634 .581 r
F P
0 g
s
.51455 .50898 m .51295 .50465 L .51584 .5029 L p .885 .674 .611 r
F P
0 g
s
.42248 .41269 m .41276 .40931 L .41195 .40672 L p .233 .616 .955 r
F P
0 g
s
.40061 .40159 m .41195 .40672 L .41276 .40931 L p .173 .565 .934 r
F P
0 g
s
.56881 .45462 m .56631 .4586 L .56286 .45832 L p .358 .135 .434 r
F P
0 g
s
.56103 .46262 m .56286 .45832 L .56631 .4586 L p .351 .158 .473 r
F P
0 g
s
.50835 .49211 m .5112 .49532 L .50853 .4974 L p .83 .557 .527 r
F P
0 g
s
.50853 .4974 m .5058 .49443 L .50835 .49211 L p .83 .557 .527 r
F P
0 g
s
.51619 .51938 m .51602 .52567 L .51336 .52692 L p .973 .836 .646 r
F P
0 g
s
.51198 .53432 m .51336 .52692 L .51602 .52567 L p .972 .876 .681 r
F P
0 g
s
.5112 .49532 m .5137 .49891 L .51093 .5008 L p .85 .595 .552 r
F P
0 g
s
.51295 .50465 m .51093 .5008 L .5137 .49891 L p .869 .634 .581 r
F P
0 g
s
.56992 .49775 m .57441 .50228 L .57155 .50326 L p .37 .522 .878 r
F P
0 g
s
.57155 .50326 m .56727 .49862 L .56992 .49775 L p .37 .522 .878 r
F P
0 g
s
.51093 .5008 m .50853 .4974 L .5112 .49532 L p .85 .595 .552 r
F P
0 g
s
.75901 .61505 m .78982 .67321 L .78714 .67161 L p 0 0 .463 r
F P
0 g
s
.78714 .67161 m .75665 .614 L .75901 .61505 L p 0 0 .463 r
F P
0 g
s
.797 .73931 m .78714 .67161 L .78982 .67321 L p 0 0 .298 r
F P
0 g
s
.73153 .1346 m .72669 .12851 L .72837 .12913 L p .173 .459 .884 r
F P
0 g
s
.72837 .12913 m .73437 .13566 L .73153 .1346 L p .173 .459 .884 r
F P
0 g
s
.47525 .48823 m .47046 .48935 L .47061 .48642 L p .525 .154 .28 r
F P
0 g
s
.47061 .48642 m .47559 .48544 L .47525 .48823 L p .525 .154 .28 r
F P
0 g
s
.70838 .11793 m .70071 .11676 L .69841 .11485 L p .318 .647 .968 r
F P
0 g
s
.70071 .11676 m .70838 .11793 L .71017 .11924 L p .348 .642 .964 r
F P
0 g
s
.72008 .5754 m .75901 .61505 L .75665 .614 L p 0 .06 .575 r
F P
0 g
s
.75665 .614 m .71831 .57479 L .72008 .5754 L p 0 .06 .575 r
F P
0 g
s
.46719 .64327 m .45953 .68989 L .45916 .69161 L p .705 .669 .122 r
F P
0 g
s
.46428 .75374 m .45916 .69161 L .45953 .68989 L p .749 .564 0 r
F P
0 g
s
.58984 .51092 m .60003 .51578 L .59769 .51653 L p .134 .55 .923 r
F P
0 g
s
.59769 .51653 m .58786 .51156 L .58984 .51092 L p .134 .55 .923 r
F P
0 g
s
.56631 .4586 m .56429 .46268 L .56103 .46262 L p .351 .158 .473 r
F P
0 g
s
.55972 .467 m .56103 .46262 L .56429 .46268 L p .345 .184 .515 r
F P
0 g
s
.48704 .38166 m .48933 .37473 L .49109 .37675 L p .973 .926 .63 r
F P
0 g
s
.49109 .37675 m .48864 .38362 L .48704 .38166 L p .973 .926 .63 r
F P
0 g
s
.55023 .87125 m .61264 .89512 L .61333 .89756 L p .483 0 0 r
F P
0 g
s
.61333 .89756 m .55068 .87457 L .55023 .87125 L p .483 0 0 r
F P
0 g
s
.22595 .64959 m .16698 .63907 L .16991 .63784 L p .273 0 0 r
F P
0 g
s
.12113 .61097 m .16991 .63784 L .16698 .63907 L p .545 0 0 r
F P
0 g
s
.44817 .50394 m .4415 .51017 L .44132 .50792 L p 0 0 0 r
F P
0 g
s
.44132 .50792 m .44803 .50193 L .44817 .50394 L p 0 0 0 r
F P
0 g
s
.36155 .59807 m .32824 .62161 L .32974 .62055 L p 0 0 0 r
F P
0 g
s
.32974 .62055 m .3626 .59733 L .36155 .59807 L p 0 0 0 r
F P
0 g
s
.47975 .4877 m .47525 .48823 L .47559 .48544 L p .569 .187 .279 r
F P
0 g
s
.47559 .48544 m .48028 .48504 L .47975 .4877 L p .569 .187 .279 r
F P
0 g
s
.58032 .44233 m .58589 .43799 L .5883 .43869 L p .107 0 0 r
F P
0 g
s
.08947 .57771 m .07303 .54811 L .07424 .54578 L p .935 .559 .212 r
F P
0 g
s
.06667 .52531 m .07424 .54578 L .07303 .54811 L p .964 .651 .252 r
F P
0 g
s
.07424 .54578 m .06667 .52531 L .0673 .52296 L p .981 .688 .356 r
F P
0 g
s
.56656 .49325 m .56992 .49775 L .56727 .49862 L p .363 .473 .838 r
F P
0 g
s
.56727 .49862 m .56403 .49403 L .56656 .49325 L p .363 .473 .838 r
F P
0 g
s
.43106 .41484 m .42248 .41269 L .42176 .41036 L p .305 .675 .975 r
F P
0 g
s
.41195 .40672 m .42176 .41036 L .42248 .41269 L p .233 .616 .955 r
F P
0 g
s
.51566 .51386 m .51619 .51938 L .51379 .52055 L p .969 .79 .606 r
F P
0 g
s
.51336 .52692 m .51379 .52055 L .51619 .51938 L p .973 .836 .646 r
F P
0 g
s
.56429 .46268 m .56278 .46687 L .55972 .467 L p .345 .184 .515 r
F P
0 g
s
.55894 .47143 m .55972 .467 L .56278 .46687 L p .341 .215 .559 r
F P
0 g
s
.48396 .48769 m .47975 .4877 L .48028 .48504 L p .611 .222 .281 r
F P
0 g
s
.48028 .48504 m .48468 .48516 L .48396 .48769 L p .611 .222 .281 r
F P
0 g
s
.69455 .88717 m .7091 .88294 L .70834 .8837 L p .205 0 0 r
F P
0 g
s
.70834 .8837 m .69269 .88904 L .69455 .88717 L p .205 0 0 r
F P
0 g
s
.48444 .38769 m .48704 .38166 L .48864 .38362 L p .959 .947 .682 r
F P
0 g
s
.48864 .38362 m .48589 .38959 L .48444 .38769 L p .959 .947 .682 r
F P
0 g
s
.24985 .34804 m .20221 .35118 L .19975 .34995 L p .18 .712 .827 r
F P
0 g
s
.20221 .35118 m .15424 .36706 L .15162 .36605 L p .4 .855 .832 r
F P
0 g
s
.15162 .36605 m .19975 .34995 L .20221 .35118 L p .4 .855 .832 r
F P
0 g
s
.07364 .45522 m .06655 .47501 L .06589 .47386 L p .964 .92 .579 r
F P
0 g
s
.06589 .47386 m .07247 .45313 L .07364 .45522 L p .964 .92 .579 r
F P
0 g
s
.72707 .87258 m .73794 .86223 L .7404 .86159 L p .07 0 0 r
F P
0 g
s
.73794 .86223 m .72707 .87258 L .72567 .87309 L p .132 0 .023 r
F P
0 g
s
.71722 .12371 m .71806 .12229 L .71946 .12308 L p .25 .552 .93 r
F P
0 g
s
.71946 .12308 m .7198 .12516 L .71722 .12371 L p .25 .552 .93 r
F P
0 g
s
.71806 .12229 m .71722 .12371 L .71469 .1222 L p .261 .567 .937 r
F P
0 g
s
.29119 .35409 m .24985 .34804 L .2478 .34679 L p 0 .558 .785 r
F P
0 g
s
.19975 .34995 m .2478 .34679 L .24985 .34804 L p .18 .712 .827 r
F P
0 g
s
.68383 .55141 m .72008 .5754 L .71831 .57479 L p 0 .2 .635 r
F P
0 g
s
.71831 .57479 m .68259 .55106 L .68383 .55141 L p 0 .2 .635 r
F P
0 g
s
.48786 .48812 m .48396 .48769 L .48468 .48516 L p .651 .258 .286 r
F P
0 g
s
.48468 .48516 m .48878 .48573 L .48786 .48812 L p .651 .258 .286 r
F P
0 g
s
.56278 .46687 m .56182 .47114 L .55894 .47143 L p .341 .215 .559 r
F P
0 g
s
.55871 .47591 m .55894 .47143 L .56182 .47114 L p .34 .249 .605 r
F P
0 g
s
.78982 .67321 m .79938 .74123 L .797 .73931 L p 0 0 .298 r
F P
0 g
s
.78457 .79908 m .797 .73931 L .79938 .74123 L p 0 0 .119 r
F P
0 g
s
.57569 .44655 m .58032 .44233 L .58258 .44291 L p .091 0 .023 r
F P
0 g
s
.5883 .43869 m .58258 .44291 L .58032 .44233 L p .107 0 0 r
F P
0 g
s
.56414 .48877 m .56656 .49325 L .56403 .49403 L p .355 .424 .794 r
F P
0 g
s
.56403 .49403 m .56165 .48947 L .56414 .48877 L p .355 .424 .794 r
F P
0 g
s
.7198 .12516 m .71946 .12308 L .72082 .1238 L p .23 .534 .922 r
F P
0 g
s
.72082 .1238 m .72231 .12648 L .7198 .12516 L p .23 .534 .922 r
F P
0 g
s
.71668 .12147 m .71469 .1222 L .7123 .12069 L p .264 .579 .942 r
F P
0 g
s
.71469 .1222 m .71668 .12147 L .71806 .12229 L p .261 .567 .937 r
F P
0 g
s
.73265 .34609 m .75248 .31848 L .75449 .31703 L p 0 0 0 r
F P
0 g
s
.75248 .31848 m .76751 .28562 L .76957 .28397 L p 0 0 0 r
F P
0 g
s
.76957 .28397 m .75449 .31703 L .75248 .31848 L p 0 0 0 r
F P
0 g
s
.51455 .50898 m .51566 .51386 L .51346 .51501 L p .959 .74 .565 r
F P
0 g
s
.51379 .52055 m .51346 .51501 L .51566 .51386 L p .969 .79 .606 r
F P
0 g
s
.49146 .48892 m .48786 .48812 L .48878 .48573 L p .69 .296 .295 r
F P
0 g
s
.48878 .48573 m .49256 .48668 L .49146 .48892 L p .69 .296 .295 r
F P
0 g
s
.4543 .49911 m .44817 .50394 L .44803 .50193 L p .056 0 0 r
F P
0 g
s
.44803 .50193 m .45421 .49729 L .4543 .49911 L p .056 0 0 r
F P
0 g
s
.71092 .36776 m .73265 .34609 L .73447 .34488 L p 0 0 0 r
F P
0 g
s
.75449 .31703 m .73447 .34488 L .73265 .34609 L p 0 0 0 r
F P
0 g
s
.43874 .41594 m .43106 .41484 L .43039 .41271 L p .384 .737 .991 r
F P
0 g
s
.42176 .41036 m .43039 .41271 L .43106 .41484 L p .305 .675 .975 r
F P
0 g
s
.48157 .3929 m .48444 .38769 L .48589 .38959 L p .939 .963 .734 r
F P
0 g
s
.48589 .38959 m .48289 .39477 L .48157 .3929 L p .939 .963 .734 r
F P
0 g
s
.56182 .47114 m .56143 .47549 L .55871 .47591 L p .34 .249 .605 r
F P
0 g
s
.55905 .48041 m .55871 .47591 L .56143 .47549 L p .341 .288 .652 r
F P
0 g
s
.76751 .28562 m .77525 .25008 L .77717 .24833 L p 0 0 .026 r
F P
0 g
s
.77717 .24833 m .76957 .28397 L .76751 .28562 L p 0 0 .026 r
F P
0 g
s
.06411 .51119 m .0673 .52296 L .06667 .52531 L p .985 .734 .346 r
F P
0 g
s
.0673 .52296 m .06411 .51119 L .06438 .50958 L p .994 .752 .4 r
F P
0 g
s
.56253 .48431 m .56414 .48877 L .56165 .48947 L p .349 .376 .748 r
F P
0 g
s
.56165 .48947 m .56002 .48493 L .56253 .48431 L p .349 .376 .748 r
F P
0 g
s
.49256 .48668 m .49613 .48801 L .49486 .49009 L p .724 .335 .312 r
F P
0 g
s
.49486 .49009 m .49146 .48892 L .49256 .48668 L p .724 .335 .312 r
F P
0 g
s
.58198 .5063 m .58984 .51092 L .58786 .51156 L p .121 .508 .909 r
F P
0 g
s
.58786 .51156 m .58026 .50686 L .58198 .5063 L p .121 .508 .909 r
F P
0 g
s
.38516 .57578 m .36155 .59807 L .3626 .59733 L p .505 .832 .533 r
F P
0 g
s
.3626 .59733 m .3859 .57529 L .38516 .57578 L p .505 .832 .533 r
F P
0 g
s
.15424 .36706 m .11418 .39408 L .1118 .39343 L p .609 .948 .785 r
F P
0 g
s
.1118 .39343 m .15162 .36605 L .15424 .36706 L p .609 .948 .785 r
F P
0 g
s
.56143 .47549 m .56165 .47988 L .55905 .48041 L p .341 .288 .652 r
F P
0 g
s
.56002 .48493 m .55905 .48041 L .56165 .47988 L p .344 .33 .7 r
F P
0 g
s
.51866 .20856 m .53423 .18008 L .53397 .18247 L p .713 .856 .434 r
F P
0 g
s
.53397 .18247 m .51852 .21071 L .51866 .20856 L p .713 .856 .434 r
F P
0 g
s
.55543 .15585 m .53397 .18247 L .53423 .18008 L p .677 .909 .573 r
F P
0 g
s
.56165 .47988 m .56253 .48431 L .56002 .48493 L p .344 .33 .7 r
F P
0 g
s
.32444 .36451 m .29119 .35409 L .28962 .35299 L p 0 .427 .734 r
F P
0 g
s
.2478 .34679 m .28962 .35299 L .29119 .35409 L p 0 .558 .785 r
F P
0 g
s
.06717 .47723 m .06409 .48886 L .06378 .48777 L p .985 .874 .516 r
F P
0 g
s
.06378 .48777 m .06655 .47501 L .06717 .47723 L p .985 .874 .516 r
F P
0 g
s
.72231 .12648 m .72082 .1238 L .72209 .12441 L p .202 .513 .913 r
F P
0 g
s
.72209 .12441 m .72464 .12761 L .72231 .12648 L p .202 .513 .913 r
F P
0 g
s
.71538 .12065 m .7123 .12069 L .71017 .11924 L p .258 .587 .946 r
F P
0 g
s
.7123 .12069 m .71538 .12065 L .71668 .12147 L p .264 .579 .942 r
F P
0 g
s
.49613 .48801 m .49956 .48974 L .49813 .49165 L p .761 .377 .328 r
F P
0 g
s
.49813 .49165 m .49486 .49009 L .49613 .48801 L p .761 .377 .328 r
F P
0 g
s
.51295 .50465 m .51455 .50898 L .5125 .51015 L p .942 .688 .523 r
F P
0 g
s
.51346 .51501 m .5125 .51015 L .51455 .50898 L p .959 .74 .565 r
F P
0 g
s
.50855 .23623 m .51866 .20856 L .51852 .21071 L p .727 .792 .308 r
F P
0 g
s
.51852 .21071 m .50849 .23807 L .50855 .23623 L p .727 .792 .308 r
F P
0 g
s
.0649 .49995 m .06331 .49999 L .0633 .49889 L p .996 .817 .46 r
F P
0 g
s
.0633 .49889 m .06486 .49728 L .0649 .49995 L p .996 .817 .46 r
F P
0 g
s
.06331 .49999 m .0649 .49995 L .06487 .50263 L p .996 .81 .45 r
F P
0 g
s
.68954 .38414 m .71092 .36776 L .71248 .36678 L p 0 0 0 r
F P
0 g
s
.73447 .34488 m .71248 .36678 L .71092 .36776 L p 0 0 0 r
F P
0 g
s
.45916 .69161 m .46695 .64433 L .46719 .64327 L p .705 .669 .122 r
F P
0 g
s
.47833 .60992 m .46719 .64327 L .46695 .64433 L p 0 0 0 r
F P
0 g
s
.57189 .45065 m .57569 .44655 L .57782 .447 L p .074 0 .07 r
F P
0 g
s
.58258 .44291 m .57782 .447 L .57569 .44655 L p .091 0 .023 r
F P
0 g
s
.47847 .39738 m .48157 .3929 L .48289 .39477 L p .914 .974 .783 r
F P
0 g
s
.48289 .39477 m .47967 .39922 L .47847 .39738 L p .914 .974 .783 r
F P
0 g
s
.53423 .18008 m .55584 .15333 L .55543 .15585 L p .677 .909 .573 r
F P
0 g
s
.58199 .13378 m .55543 .15585 L .55584 .15333 L p .616 .933 .707 r
F P
0 g
s
.49956 .48974 m .5028 .49188 L .50124 .49362 L p .797 .423 .349 r
F P
0 g
s
.50124 .49362 m .49813 .49165 L .49956 .48974 L p .797 .423 .349 r
F P
0 g
s
.0633 .50109 m .06487 .50263 L .06477 .5052 L p .995 .801 .436 r
F P
0 g
s
.06487 .50263 m .0633 .50109 L .06331 .49999 L p .996 .81 .45 r
F P
0 g
s
.06486 .49728 m .0633 .49889 L .06325 .49784 L p .995 .824 .464 r
F P
0 g
s
.06325 .49784 m .06475 .49473 L .06486 .49728 L p .995 .824 .464 r
F P
0 g
s
.44568 .41612 m .43874 .41594 L .43809 .41395 L p .465 .796 .999 r
F P
0 g
s
.43039 .41271 m .43809 .41395 L .43874 .41594 L p .384 .737 .991 r
F P
0 g
s
.51093 .5008 m .51295 .50465 L .51101 .50587 L p .921 .634 .482 r
F P
0 g
s
.5125 .51015 m .51101 .50587 L .51295 .50465 L p .942 .688 .523 r
F P
0 g
s
.5028 .49188 m .5058 .49443 L .50413 .49601 L p .832 .473 .376 r
F P
0 g
s
.50413 .49601 m .50124 .49362 L .5028 .49188 L p .832 .473 .376 r
F P
0 g
s
.45999 .49543 m .4543 .49911 L .45421 .49729 L p .118 0 0 r
F P
0 g
s
.45421 .49729 m .45997 .49375 L .45999 .49543 L p .118 0 0 r
F P
0 g
s
.50252 .26152 m .50855 .23623 L .50849 .23807 L p .729 .729 .207 r
F P
0 g
s
.50849 .23807 m .5025 .26306 L .50252 .26152 L p .729 .729 .207 r
F P
0 g
s
.5058 .49443 m .50853 .4974 L .50676 .49884 L p .865 .525 .407 r
F P
0 g
s
.50676 .49884 m .50413 .49601 L .5058 .49443 L p .865 .525 .407 r
F P
0 g
s
.50853 .4974 m .51093 .5008 L .50907 .50211 L p .895 .579 .443 r
F P
0 g
s
.51101 .50587 m .50907 .50211 L .51093 .5008 L p .921 .634 .482 r
F P
0 g
s
.16698 .63907 m .11848 .61174 L .12113 .61097 L p .545 0 0 r
F P
0 g
s
.08947 .57771 m .12113 .61097 L .11848 .61174 L p .743 .241 0 r
F P
0 g
s
.77525 .25008 m .77497 .21573 L .77658 .21406 L p 0 0 .224 r
F P
0 g
s
.77658 .21406 m .77717 .24833 L .77525 .25008 L p 0 0 .224 r
F P
0 g
s
.50907 .50211 m .50676 .49884 L .50853 .4974 L p .895 .579 .443 r
F P
0 g
s
.47967 .39922 m .47615 .40315 L .47507 .40133 L p .884 .979 .828 r
F P
0 g
s
.47507 .40133 m .47847 .39738 L .47967 .39922 L p .884 .979 .828 r
F P
0 g
s
.73437 .13566 m .72837 .12913 L .7296 .12945 L p .095 .414 .863 r
F P
0 g
s
.7296 .12945 m .73646 .13622 L .73437 .13566 L p .095 .414 .863 r
F P
0 g
s
.71775 .87709 m .71848 .87842 L .7178 .87882 L p .142 0 0 r
F P
0 g
s
.7178 .87882 m .71561 .87836 L .71775 .87709 L p .142 0 0 r
F P
0 g
s
.71848 .87842 m .71775 .87709 L .71991 .87588 L p .136 0 0 r
F P
0 g
s
.6834 .11109 m .69692 .11334 L .69841 .11485 L p .377 .707 .986 r
F P
0 g
s
.70702 .11679 m .69841 .11485 L .69692 .11334 L p .271 .642 .965 r
F P
0 g
s
.69841 .11485 m .70702 .11679 L .70838 .11793 L p .318 .647 .968 r
F P
0 g
s
.56882 .45462 m .57189 .45065 L .5739 .45097 L p .059 0 .122 r
F P
0 g
s
.57782 .447 m .5739 .45097 L .57189 .45065 L p .074 0 .07 r
F P
0 g
s
.66981 .39644 m .68954 .38414 L .69083 .38335 L p 0 0 0 r
F P
0 g
s
.71248 .36678 m .69083 .38335 L .68954 .38414 L p 0 0 0 r
F P
0 g
s
.06326 .50215 m .06477 .5052 L .0646 .50755 L p .993 .792 .417 r
F P
0 g
s
.06477 .5052 m .06326 .50215 L .0633 .50109 L p .995 .801 .436 r
F P
0 g
s
.65421 .53709 m .68383 .55141 L .68259 .55106 L p 0 .29 .663 r
F P
0 g
s
.68259 .55106 m .65337 .53688 L .65421 .53709 L p 0 .29 .663 r
F P
0 g
s
.45201 .4155 m .44568 .41612 L .44504 .41422 L p .544 .848 .998 r
F P
0 g
s
.43809 .41395 m .44504 .41422 L .44568 .41612 L p .465 .796 .999 r
F P
0 g
s
.06475 .49473 m .06325 .49784 L .06318 .49688 L p .993 .83 .463 r
F P
0 g
s
.06318 .49688 m .06459 .49242 L .06475 .49473 L p .993 .83 .463 r
F P
0 g
s
.71561 .87836 m .7178 .87882 L .71716 .87923 L p .143 0 0 r
F P
0 g
s
.71716 .87923 m .71359 .87964 L .71561 .87836 L p .143 0 0 r
F P
0 g
s
.74524 .14696 m .73646 .13622 L .73771 .13623 L p 0 .314 .804 r
F P
0 g
s
.73771 .13623 m .74722 .14701 L .74524 .14696 L p 0 .314 .804 r
F P
0 g
s
.71917 .87803 m .71991 .87588 L .72202 .87478 L p .124 0 0 r
F P
0 g
s
.71991 .87588 m .71917 .87803 L .71848 .87842 L p .136 0 0 r
F P
0 g
s
.47615 .40315 m .47222 .40665 L .47125 .40485 L p .846 .978 .87 r
F P
0 g
s
.47125 .40485 m .47507 .40133 L .47615 .40315 L p .846 .978 .87 r
F P
0 g
s
.35043 .3758 m .32444 .36451 L .32327 .36361 L p 0 .334 .691 r
F P
0 g
s
.28962 .35299 m .32327 .36361 L .32444 .36451 L p 0 .427 .734 r
F P
0 g
s
.55584 .15333 m .58254 .13134 L .58199 .13378 L p .616 .933 .707 r
F P
0 g
s
.61102 .11848 m .58199 .13378 L .58254 .13134 L p .531 .92 .817 r
F P
0 g
s
.72464 .12761 m .72209 .12441 L .7232 .1249 L p .164 .489 .902 r
F P
0 g
s
.7232 .1249 m .72669 .12851 L .72464 .12761 L p .164 .489 .902 r
F P
0 g
s
.66333 .10812 m .68241 .10944 L .6834 .11109 L p .401 .772 .993 r
F P
0 g
s
.69692 .11334 m .6834 .11109 L .68241 .10944 L p .295 .694 .975 r
F P
0 g
s
.71422 .11987 m .71017 .11924 L .70838 .11793 L p .243 .591 .948 r
F P
0 g
s
.71017 .11924 m .71422 .11987 L .71538 .12065 L p .258 .587 .946 r
F P
0 g
s
.57594 .50178 m .58198 .5063 L .58026 .50686 L p .105 .454 .885 r
F P
0 g
s
.58026 .50686 m .57441 .50228 L .57594 .50178 L p .105 .454 .885 r
F P
0 g
s
.49915 .28383 m .50252 .26152 L .5025 .26306 L p .725 .679 .132 r
F P
0 g
s
.5025 .26306 m .49915 .28511 L .49915 .28383 L p .725 .679 .132 r
F P
0 g
s
.46533 .49271 m .45999 .49543 L .45997 .49375 L p .185 0 0 r
F P
0 g
s
.45997 .49375 m .46537 .49115 L .46533 .49271 L p .185 0 0 r
F P
0 g
s
.47222 .40665 m .46786 .40969 L .46699 .4079 L p .801 .97 .909 r
F P
0 g
s
.46699 .4079 m .47125 .40485 L .47222 .40665 L p .801 .97 .909 r
F P
0 g
s
.45778 .41417 m .45201 .4155 L .45133 .41366 L p .619 .893 .988 r
F P
0 g
s
.44504 .41422 m .45133 .41366 L .45201 .4155 L p .544 .848 .998 r
F P
0 g
s
.4022 .55663 m .38516 .57578 L .3859 .57529 L p .557 .838 .498 r
F P
0 g
s
.3859 .57529 m .40273 .55632 L .4022 .55663 L p .557 .838 .498 r
F P
0 g
s
.5739 .45097 m .57072 .45483 L .56882 .45462 L p .059 0 .122 r
F P
0 g
s
.56631 .4586 m .56881 .45462 L .57072 .45484 L p .054 0 .19 r
F P
0 g
s
.46786 .40969 m .46305 .41222 L .46227 .41042 L p .748 .953 .942 r
F P
0 g
s
.46227 .41042 m .46699 .4079 L .46786 .40969 L p .748 .953 .942 r
F P
0 g
s
.46305 .41222 m .45778 .41417 L .45706 .41237 L p .687 .928 .969 r
F P
0 g
s
.45133 .41366 m .45706 .41237 L .45778 .41417 L p .619 .893 .988 r
F P
0 g
s
.71359 .87964 m .71716 .87923 L .71659 .87962 L p .138 0 0 r
F P
0 g
s
.71659 .87962 m .71178 .88086 L .71359 .87964 L p .138 0 0 r
F P
0 g
s
.71984 .87768 m .72202 .87478 L .72396 .87384 L p .107 0 0 r
F P
0 g
s
.72202 .87478 m .71984 .87768 L .71917 .87803 L p .124 0 0 r
F P
0 g
s
.45706 .41237 m .46227 .41042 L .46305 .41222 L p .687 .928 .969 r
F P
0 g
s
.61264 .89512 m .66154 .89675 L .66212 .89816 L p .305 0 0 r
F P
0 g
s
.66212 .89816 m .61333 .89756 L .61264 .89512 L p .305 0 0 r
F P
0 g
s
.69083 .38335 m .67085 .3958 L .66981 .39644 L p 0 0 0 r
F P
0 g
s
.65227 .40583 m .66981 .39644 L .67085 .3958 L p .343 .789 .632 r
F P
0 g
s
.11418 .39408 m .08718 .42526 L .08536 .42493 L p .768 .973 .695 r
F P
0 g
s
.08536 .42493 m .1118 .39343 L .11418 .39408 L p .768 .973 .695 r
F P
0 g
s
.47035 .49082 m .46533 .49271 L .46537 .49115 L p .252 0 0 r
F P
0 g
s
.46537 .49115 m .47046 .48935 L .47035 .49082 L p .252 0 0 r
F P
0 g
s
.06319 .50311 m .0646 .50755 L .06438 .50958 L p .989 .782 .393 r
F P
0 g
s
.0646 .50755 m .06319 .50311 L .06326 .50215 L p .993 .792 .417 r
F P
0 g
s
.06459 .49242 m .06318 .49688 L .06309 .49606 L p .989 .834 .457 r
F P
0 g
s
.06309 .49606 m .06436 .49043 L .06459 .49242 L p .989 .834 .457 r
F P
0 g
s
.49729 .30317 m .49915 .28383 L .49915 .28511 L p .721 .644 .085 r
F P
0 g
s
.49915 .28511 m .49731 .30422 L .49729 .30317 L p .721 .644 .085 r
F P
0 g
s
.48872 .58601 m .47833 .60992 L .4782 .61057 L p 0 0 0 r
F P
0 g
s
.46695 .64433 m .4782 .61057 L .47833 .60992 L p 0 0 0 r
F P
0 g
s
.57072 .45484 m .56811 .4587 L .56631 .4586 L p .054 0 .19 r
F P
0 g
s
.56429 .46268 m .56631 .4586 L .56811 .4587 L p .042 0 .25 r
F P
0 g
s
.51379 .52055 m .51336 .52692 L .51201 .52759 L p .987 .852 .481 r
F P
0 g
s
.77497 .21573 m .76824 .18616 L .76947 .18472 L p 0 0 .403 r
F P
0 g
s
.76947 .18472 m .77658 .21406 L .77497 .21573 L p 0 0 .403 r
F P
0 g
s
.57134 .49731 m .57594 .50178 L .57441 .50228 L p .088 .391 .849 r
F P
0 g
s
.57441 .50228 m .56992 .49775 L .57134 .49731 L p .088 .391 .849 r
F P
0 g
s
.37083 .38612 m .35043 .3758 L .34957 .37509 L p 0 .282 .665 r
F P
0 g
s
.32327 .36361 m .34957 .37509 L .35043 .3758 L p 0 .334 .691 r
F P
0 g
s
.79938 .74123 m .7862 .8008 L .78457 .79908 L p 0 0 .119 r
F P
0 g
s
.76207 .83936 m .78457 .79908 L .7862 .8008 L p 0 0 0 r
F P
0 g
s
.47506 .48962 m .47035 .49082 L .47046 .48935 L p .32 0 0 r
F P
0 g
s
.47046 .48935 m .47525 .48823 L .47506 .48962 L p .32 0 0 r
F P
0 g
s
.58254 .13134 m .61164 .11633 L .61102 .11848 L p .531 .92 .817 r
F P
0 g
s
.63907 .11039 m .61102 .11848 L .61164 .11633 L p .433 .872 .89 r
F P
0 g
s
.71178 .88086 m .71659 .87962 L .71611 .87997 L p .128 0 0 r
F P
0 g
s
.71611 .87997 m .71026 .88198 L .71178 .88086 L p .128 0 0 r
F P
0 g
s
.72046 .87738 m .72396 .87384 L .72567 .87309 L p .086 0 0 r
F P
0 g
s
.72396 .87384 m .72046 .87738 L .71984 .87768 L p .107 0 0 r
F P
0 g
s
.56811 .4587 m .56599 .46269 L .56429 .46268 L p .042 0 .25 r
F P
0 g
s
.56278 .46687 m .56429 .46268 L .56599 .46269 L p .033 0 .315 r
F P
0 g
s
.63702 .41328 m .65227 .40583 L .65312 .40531 L p .325 .784 .65 r
F P
0 g
s
.67085 .3958 m .65312 .40531 L .65227 .40583 L p .343 .789 .632 r
F P
0 g
s
.63125 .5279 m .65421 .53709 L .65337 .53688 L p 0 .336 .675 r
F P
0 g
s
.65337 .53688 m .63067 .52778 L .63125 .5279 L p 0 .336 .675 r
F P
0 g
s
.72669 .12851 m .7232 .1249 L .72411 .12523 L p .118 .461 .889 r
F P
0 g
s
.72411 .12523 m .72837 .12913 L .72669 .12851 L p .118 .461 .889 r
F P
0 g
s
.71325 .11915 m .70838 .11793 L .70702 .11679 L p .217 .589 .946 r
F P
0 g
s
.70838 .11793 m .71325 .11915 L .71422 .11987 L p .243 .591 .948 r
F P
0 g
s
.41506 .5409 m .4022 .55663 L .40273 .55632 L p .579 .838 .479 r
F P
0 g
s
.40273 .55632 m .41545 .54071 L .41506 .5409 L p .579 .838 .479 r
F P
0 g
s
.47947 .48903 m .47506 .48962 L .47525 .48823 L p .388 0 0 r
F P
0 g
s
.47525 .48823 m .47975 .4877 L .47947 .48903 L p .388 0 0 r
F P
0 g
s
.49615 .3198 m .49729 .30317 L .49731 .30422 L p .718 .626 .062 r
F P
0 g
s
.49731 .30422 m .49616 .32067 L .49615 .3198 L p .718 .626 .062 r
F P
0 g
s
.56791 .49285 m .57134 .49731 L .56992 .49775 L p .07 .32 .801 r
F P
0 g
s
.56992 .49775 m .56656 .49325 L .56791 .49285 L p .07 .32 .801 r
F P
0 g
s
.51346 .51501 m .51379 .52055 L .51258 .52118 L p .994 .797 .425 r
F P
0 g
s
.51201 .52759 m .51258 .52118 L .51379 .52055 L p .987 .852 .481 r
F P
0 g
s
.56599 .46269 m .56439 .46679 L .56278 .46687 L p .033 0 .315 r
F P
0 g
s
.56182 .47114 m .56278 .46687 L .56439 .46679 L p .026 0 .384 r
F P
0 g
s
.69269 .88904 m .70834 .8837 L .70804 .88424 L p .151 0 0 r
F P
0 g
s
.70804 .88424 m .6919 .89035 L .69269 .88904 L p .151 0 0 r
F P
0 g
s
.48358 .48894 m .47947 .48903 L .47975 .4877 L p .454 0 0 r
F P
0 g
s
.47975 .4877 m .48396 .48769 L .48358 .48894 L p .454 0 0 r
F P
0 g
s
.76207 .83936 m .74187 .86158 L .7404 .86159 L p 0 0 .024 r
F P
0 g
s
.72809 .87231 m .7404 .86159 L .74187 .86158 L p 0 0 0 r
F P
0 g
s
.7404 .86159 m .72809 .87231 L .72707 .87258 L p .07 0 0 r
F P
0 g
s
.06309 .50394 m .06438 .50958 L .06411 .51119 L p .983 .77 .366 r
F P
0 g
s
.06438 .50958 m .06309 .50394 L .06319 .50311 L p .989 .782 .393 r
F P
0 g
s
.56439 .46679 m .56334 .47099 L .56182 .47114 L p .026 0 .384 r
F P
0 g
s
.56143 .47549 m .56182 .47114 L .56334 .47099 L p .023 0 .457 r
F P
0 g
s
.62391 .41947 m .63702 .41328 L .6377 .41285 L p .318 .782 .655 r
F P
0 g
s
.65312 .40531 m .6377 .41285 L .63702 .41328 L p .325 .784 .65 r
F P
0 g
s
.56547 .48841 m .56791 .49285 L .56656 .49325 L p .054 .247 .742 r
F P
0 g
s
.56656 .49325 m .56414 .48877 L .56547 .48841 L p .054 .247 .742 r
F P
0 g
s
.38717 .39476 m .37083 .38612 L .37027 .38562 L p 0 .266 .657 r
F P
0 g
s
.3721 .38659 m .38717 .39476 L .37027 .38562 L 0 .266 .657 r
F
.40061 .40159 m .38717 .39476 L .38682 .39444 L p 0 .28 .664 r
F P
0 g
s
.38682 .39444 m .38669 .39431 L p .39007 .39608 L 0 .28 .664 r
F P
0 g
s
.39007 .39608 m .40061 .40159 L .38682 .39444 L 0 .28 .664 r
F
.41195 .40672 m .40061 .40159 L .40038 .40137 L p 0 .319 .682 r
F P
0 g
s
.40038 .40137 m .40024 .40122 L p .40382 .40291 L 0 .319 .682 r
F P
0 g
s
.40382 .40291 m .41195 .40672 L .40038 .40137 L 0 .319 .682 r
F
.42176 .41036 m .41195 .40672 L .41179 .40656 L p 0 .376 .707 r
F P
0 g
s
.41179 .40656 m .41167 .40642 L p .41504 .40774 L 0 .376 .707 r
F P
0 g
s
.41504 .40774 m .42176 .41036 L .41179 .40656 L 0 .376 .707 r
F
.43039 .41271 m .42176 .41036 L .42164 .41023 L p 0 .447 .733 r
F P
0 g
s
.42164 .41023 m .42153 .4101 L p .42459 .411 L 0 .447 .733 r
F P
0 g
s
.42459 .411 m .43039 .41271 L .42164 .41023 L 0 .447 .733 r
F
.43809 .41395 m .43039 .41271 L .43029 .41259 L p 0 .526 .756 r
F P
0 g
s
.43029 .41259 m .4302 .41248 L p .43292 .41299 L 0 .526 .756 r
F P
0 g
s
.43292 .41299 m .43809 .41395 L .43029 .41259 L 0 .526 .756 r
F
.44504 .41422 m .43809 .41395 L .43801 .41384 L p .039 .606 .771 r
F P
0 g
s
.43801 .41384 m .43794 .41374 L p .44034 .4139 L .039 .606 .771 r
F P
0 g
s
.44034 .4139 m .44504 .41422 L .43801 .41384 L .039 .606 .771 r
F
.45133 .41366 m .44504 .41422 L .44491 .41403 L p .134 .682 .773 r
F P
0 g
s
.43794 .41374 m .44491 .41403 L .44504 .41422 L p .039 .606 .771 r
F P
0 g
s
.44491 .41403 m .44532 .41555 L p .44931 .41415 L .401 0 0 r
F P
0 g
s
.44491 .41403 m .45123 .41348 L .45133 .41366 L p .134 .682 .773 r
F P
0 g
s
.45123 .41348 m .44491 .41403 L p .44931 .41415 L .401 0 0 r
F P
0 g
s
.4302 .41248 m .43794 .41374 L .43809 .41395 L p 0 .526 .756 r
F P
0 g
s
.43794 .41374 m .4383 .41533 L p .44274 .41446 L .46 0 0 r
F P
0 g
s
.44491 .41403 m .43794 .41374 L p .44274 .41446 L .46 0 0 r
F P
0 g
s
.42153 .4101 m .4302 .41248 L .43039 .41271 L p 0 .447 .733 r
F P
0 g
s
.4302 .41248 m .43052 .41418 L p .43552 .41388 L .513 0 0 r
F P
0 g
s
.43794 .41374 m .4302 .41248 L p .43552 .41388 L .513 0 0 r
F P
0 g
s
.41167 .40642 m .42153 .4101 L .42176 .41036 L p 0 .376 .707 r
F P
0 g
s
.42153 .4101 m .42181 .41194 L p .42759 .41231 L .56 0 0 r
F P
0 g
s
.4302 .41248 m .42153 .4101 L p .42759 .41231 L .56 0 0 r
F P
0 g
s
.40024 .40122 m .41167 .40642 L .41195 .40672 L p 0 .319 .682 r
F P
0 g
s
.41167 .40642 m .41192 .40843 L p .41885 .40964 L .597 .035 0 r
F P
0 g
s
.42153 .4101 m .41167 .40642 L p .41885 .40964 L .597 .035 0 r
F P
0 g
s
.38669 .39431 m .40024 .40122 L .40061 .40159 L p 0 .28 .664 r
F P
0 g
s
.40024 .40122 m .40045 .40347 L p .40925 .40579 L .625 .065 0 r
F P
0 g
s
.41167 .40642 m .40024 .40122 L p .40925 .40579 L .625 .065 0 r
F P
0 g
s
.3702 .38556 m .38669 .39431 L .38717 .39476 L p 0 .266 .657 r
F P
0 g
s
.38669 .39431 m .38683 .39683 L p .39896 .40081 L .643 .085 0 r
F P
0 g
s
.40024 .40122 m .38669 .39431 L p .39896 .40081 L .643 .085 0 r
F P
0 g
s
.37027 .38562 m .3702 .38556 L p .3721 .38659 L 0 .266 .657 r
F P
0 g
s
.34957 .37509 m .3702 .38556 L .37083 .38612 L p 0 .282 .665 r
F P
0 g
s
.48739 .4893 m .48358 .48894 L .48396 .48769 L p .517 0 0 r
F P
0 g
s
.48396 .48769 m .48786 .48812 L .48739 .4893 L p .517 0 0 r
F P
0 g
s
.06436 .49043 m .06309 .49606 L .06298 .49541 L p .983 .835 .445 r
F P
0 g
s
.06298 .49541 m .06409 .48886 L .06436 .49043 L p .983 .835 .445 r
F P
0 g
s
.5125 .51015 m .51346 .51501 L .51235 .51561 L p .989 .731 .365 r
F P
0 g
s
.51258 .52118 m .51235 .51561 L .51346 .51501 L p .994 .797 .425 r
F P
0 g
s
.4952 .3341 m .49615 .3198 L .49616 .32067 L p .718 .625 .059 r
F P
0 g
s
.49616 .32067 m .49522 .33482 L .4952 .3341 L p .718 .625 .059 r
F P
0 g
s
.11848 .61174 m .08749 .57808 L .08947 .57771 L p .743 .241 0 r
F P
0 g
s
.07303 .54811 m .08947 .57771 L .08749 .57808 L p .859 .452 0 r
F P
0 g
s
.49091 .49003 m .48739 .4893 L .48786 .48812 L p .578 .051 0 r
F P
0 g
s
.48786 .48812 m .49146 .48892 L .49091 .49003 L p .578 .051 0 r
F P
0 g
s
.56334 .47099 m .56287 .47527 L .56143 .47549 L p .023 0 .457 r
F P
0 g
s
.56165 .47988 m .56143 .47549 L .56287 .47527 L p .025 .036 .531 r
F P
0 g
s
.07303 .54811 m .066 .52653 L .06667 .52531 L p .964 .651 .252 r
F P
0 g
s
.0638 .51231 m .06667 .52531 L .066 .52653 L p .968 .71 .281 r
F P
0 g
s
.06667 .52531 m .0638 .51231 L .06411 .51119 L p .985 .734 .346 r
F P
0 g
s
.49708 .56835 m .48872 .58601 L .48867 .58642 L p 0 0 0 r
F P
0 g
s
.4782 .61057 m .48867 .58642 L .48872 .58601 L p 0 0 0 r
F P
0 g
s
.56387 .48399 m .56547 .48841 L .56414 .48877 L p .04 .173 .676 r
F P
0 g
s
.56414 .48877 m .56253 .48431 L .56387 .48399 L p .04 .173 .676 r
F P
0 g
s
.56287 .47527 m .56303 .47961 L .56165 .47988 L p .025 .036 .531 r
F P
0 g
s
.56253 .48431 m .56165 .47988 L .56303 .47961 L p .031 .102 .605 r
F P
0 g
s
.56303 .47961 m .56387 .48399 L .56253 .48431 L p .031 .102 .605 r
F P
0 g
s
.49146 .48892 m .49486 .49009 L .49423 .49112 L p .638 .115 0 r
F P
0 g
s
.49423 .49112 m .49091 .49003 L .49146 .48892 L p .638 .115 0 r
F P
0 g
s
.06655 .47501 m .06378 .48777 L .06346 .48721 L p .968 .87 .476 r
F P
0 g
s
.06346 .48721 m .06589 .47386 L .06655 .47501 L p .968 .87 .476 r
F P
0 g
s
.71026 .88198 m .71611 .87997 L .71574 .88027 L p .112 0 0 r
F P
0 g
s
.71574 .88027 m .7091 .88294 L .71026 .88198 L p .112 0 0 r
F P
0 g
s
.4253 .52825 m .41506 .5409 L .41545 .54071 L p .582 .838 .476 r
F P
0 g
s
.41545 .54071 m .42559 .52814 L .4253 .52825 L p .582 .838 .476 r
F P
0 g
s
.76824 .18616 m .75803 .16327 L .75889 .16214 L p 0 0 .549 r
F P
0 g
s
.75889 .16214 m .76947 .18472 L .76824 .18616 L p 0 0 .549 r
F P
0 g
s
.72101 .87714 m .72567 .87309 L .72707 .87258 L p .06 0 0 r
F P
0 g
s
.72567 .87309 m .72101 .87714 L .72046 .87738 L p .086 0 0 r
F P
0 g
s
.51101 .50587 m .5125 .51015 L .51147 .51075 L p .971 .657 .303 r
F P
0 g
s
.51235 .51561 m .51147 .51075 L .5125 .51015 L p .989 .731 .365 r
F P
0 g
s
.49486 .49009 m .49813 .49165 L .49743 .4926 L p .696 .181 .005 r
F P
0 g
s
.49743 .4926 m .49423 .49112 L .49486 .49009 L p .696 .181 .005 r
F P
0 g
s
.61372 .52126 m .63125 .5279 L .63067 .52778 L p 0 .348 .677 r
F P
0 g
s
.63067 .52778 m .6133 .52118 L .61372 .52126 L p 0 .348 .677 r
F P
0 g
s
.61164 .11633 m .63969 .10866 L .63907 .11039 L p .433 .872 .89 r
F P
0 g
s
.66333 .10812 m .63907 .11039 L .63969 .10866 L p .335 .802 .927 r
F P
0 g
s
.6377 .41285 m .62446 .41911 L .62391 .41947 L p .318 .782 .655 r
F P
0 g
s
.71806 .12229 m .71846 .12161 L .71914 .12199 L p .16 .52 .917 r
F P
0 g
s
.71914 .12199 m .71946 .12308 L .71806 .12229 L p .16 .52 .917 r
F P
0 g
s
.71846 .12161 m .71806 .12229 L .71668 .12147 L p .168 .53 .922 r
F P
0 g
s
.49813 .49165 m .50124 .49362 L .50047 .4945 L p .753 .254 .038 r
F P
0 g
s
.50047 .4945 m .49743 .4926 L .49813 .49165 L p .753 .254 .038 r
F P
0 g
s
.08718 .42526 m .07247 .45313 L .07128 .453 L p .867 .948 .589 r
F P
0 g
s
.07128 .453 m .08536 .42493 L .08718 .42526 L p .867 .948 .589 r
F P
0 g
s
.50907 .50211 m .51101 .50587 L .51003 .5065 L p .943 .578 .241 r
F P
0 g
s
.51147 .51075 m .51003 .5065 L .51101 .50587 L p .971 .657 .303 r
F P
0 g
s
.49417 .34642 m .4952 .3341 L .49522 .33482 L p .72 .636 .075 r
F P
0 g
s
.49522 .33482 m .49419 .34702 L .49417 .34642 L p .72 .636 .075 r
F P
0 g
s
.50124 .49362 m .50413 .49601 L .50331 .49681 L p .808 .331 .079 r
F P
0 g
s
.50331 .49681 m .50047 .4945 L .50124 .49362 L p .808 .331 .079 r
F P
0 g
s
.71946 .12308 m .71914 .12199 L .7198 .12234 L p .147 .508 .912 r
F P
0 g
s
.7198 .12234 m .72082 .1238 L .71946 .12308 L p .147 .508 .912 r
F P
0 g
s
.71779 .12121 m .71668 .12147 L .71538 .12065 L p .169 .537 .924 r
F P
0 g
s
.71668 .12147 m .71779 .12121 L .71846 .12161 L p .168 .53 .922 r
F P
0 g
s
.50676 .49884 m .50907 .50211 L .50815 .50279 L p .905 .495 .181 r
F P
0 g
s
.51003 .5065 m .50815 .50279 L .50907 .50211 L p .943 .578 .241 r
F P
0 g
s
.50413 .49601 m .50676 .49884 L .50588 .49957 L p .859 .412 .127 r
F P
0 g
s
.50588 .49957 m .50331 .49681 L .50413 .49601 L p .859 .412 .127 r
F P
0 g
s
.73646 .13622 m .7296 .12945 L .73033 .12946 L p 0 .36 .832 r
F P
0 g
s
.73033 .12946 m .73771 .13623 L .73646 .13622 L p 0 .36 .832 r
F P
0 g
s
.50815 .50279 m .50588 .49957 L .50676 .49884 L p .905 .495 .181 r
F P
0 g
s
.68241 .10944 m .6963 .11228 L .69692 .11334 L p .295 .694 .975 r
F P
0 g
s
.70614 .11589 m .69692 .11334 L .6963 .11228 L p .203 .623 .949 r
F P
0 g
s
.69692 .11334 m .70614 .11589 L .70702 .11679 L p .271 .642 .965 r
F P
0 g
s
.72837 .12913 m .72411 .12523 L .72477 .1254 L p .063 .429 .871 r
F P
0 g
s
.72477 .1254 m .7296 .12945 L .72837 .12913 L p .063 .429 .871 r
F P
0 g
s
.71251 .11853 m .70702 .11679 L .70614 .11589 L p .18 .58 .938 r
F P
0 g
s
.70702 .11679 m .71251 .11853 L .71325 .11915 L p .217 .589 .946 r
F P
0 g
s
.72082 .1238 m .7198 .12234 L .72041 .12263 L p .127 .494 .904 r
F P
0 g
s
.72041 .12263 m .72209 .12441 L .72082 .1238 L p .127 .494 .904 r
F P
0 g
s
.71717 .12081 m .71538 .12065 L .71422 .11987 L p .164 .54 .925 r
F P
0 g
s
.71538 .12065 m .71717 .12081 L .71779 .12121 L p .169 .537 .924 r
F P
0 g
s
.62446 .41911 m .61316 .42456 L .61271 .42486 L p .322 .783 .652 r
F P
0 g
s
.49287 .35707 m .49417 .34642 L .49419 .34702 L p .721 .659 .105 r
F P
0 g
s
.49419 .34702 m .4929 .35758 L .49287 .35707 L p .721 .659 .105 r
F P
0 g
s
.43386 .51817 m .4253 .52825 L .42559 .52814 L p .57 .838 .488 r
F P
0 g
s
.42559 .52814 m .43408 .51811 L .43386 .51817 L p .57 .838 .488 r
F P
0 g
s
.48867 .58642 m .49707 .56861 L .49708 .56835 L p 0 0 0 r
F P
0 g
s
.06298 .5046 m .06411 .51119 L .0638 .51231 L p .975 .758 .334 r
F P
0 g
s
.06411 .51119 m .06298 .5046 L .06309 .50394 L p .983 .77 .366 r
F P
0 g
s
.06409 .48886 m .06298 .49541 L .06285 .49496 L p .974 .833 .426 r
F P
0 g
s
.06285 .49496 m .06378 .48777 L .06409 .48886 L p .974 .833 .426 r
F P
0 g
s
.60033 .51582 m .61372 .52126 L .6133 .52118 L p 0 .332 .673 r
F P
0 g
s
.6133 .52118 m .60003 .51578 L .60033 .51582 L p 0 .332 .673 r
F P
0 g
s
.61316 .42456 m .60356 .4295 L .60319 .42975 L p .336 .787 .641 r
F P
0 g
s
.72209 .12441 m .72041 .12263 L .72095 .12287 L p .102 .477 .895 r
F P
0 g
s
.72095 .12287 m .7232 .1249 L .72209 .12441 L p .102 .477 .895 r
F P
0 g
s
.49126 .36632 m .49287 .35707 L .4929 .35758 L p .722 .689 .148 r
F P
0 g
s
.4929 .35758 m .49129 .36675 L .49126 .36632 L p .722 .689 .148 r
F P
0 g
s
.7166 .12043 m .71422 .11987 L .71325 .11915 L p .152 .541 .924 r
F P
0 g
s
.71422 .11987 m .7166 .12043 L .71717 .12081 L p .164 .54 .925 r
F P
0 g
s
.66154 .89675 m .6919 .89035 L .69224 .89103 L p .169 0 0 r
F P
0 g
s
.69224 .89103 m .66212 .89816 L .66154 .89675 L p .169 0 0 r
F P
0 g
s
.7091 .88294 m .71574 .88027 L .71551 .88052 L p .09 0 0 r
F P
0 g
s
.71551 .88052 m .70834 .8837 L .7091 .88294 L p .09 0 0 r
F P
0 g
s
.72145 .87698 m .72707 .87258 L .72809 .87231 L p .031 0 0 r
F P
0 g
s
.72707 .87258 m .72145 .87698 L .72101 .87714 L p .06 0 0 r
F P
0 g
s
.7862 .8008 m .76297 .84052 L .76207 .83936 L p 0 0 0 r
F P
0 g
s
.74187 .86158 m .76207 .83936 L .76297 .84052 L p 0 0 0 r
F P
0 g
s
.44132 .51021 m .43386 .51817 L .43408 .51811 L p .545 .839 .512 r
F P
0 g
s
.43408 .51811 m .4415 .51017 L .44132 .51021 L p .545 .839 .512 r
F P
0 g
s
.75803 .16327 m .74722 .14701 L .74778 .14621 L p 0 .104 .658 r
F P
0 g
s
.74778 .14621 m .75889 .16214 L .75803 .16327 L p 0 .104 .658 r
F P
0 g
s
.4893 .37435 m .49126 .36632 L .49129 .36675 L p .719 .724 .201 r
F P
0 g
s
.49129 .36675 m .48933 .37473 L .4893 .37435 L p .719 .724 .201 r
F P
0 g
s
.63969 .10866 m .66386 .10684 L .66333 .10812 L p .335 .802 .927 r
F P
0 g
s
.68241 .10944 m .66333 .10812 L .66386 .10684 L p .245 .723 .936 r
F P
0 g
s
.60356 .4295 m .59543 .43412 L .59512 .43433 L p .357 .794 .623 r
F P
0 g
s
.49707 .56861 m .5033 .55495 L .50329 .55477 L p 0 0 0 r
F P
0 g
s
.59007 .51095 m .60033 .51582 L .60003 .51578 L p 0 .292 .661 r
F P
0 g
s
.60003 .51578 m .58984 .51092 L .59007 .51095 L p 0 .292 .661 r
F P
0 g
s
.06331 .49999 m .06273 .5 L .06272 .49965 L p .978 .8 .386 r
F P
0 g
s
.06272 .49965 m .0633 .49889 L .06331 .49999 L p .978 .8 .386 r
F P
0 g
s
.06273 .5 m .06331 .49999 L .0633 .50109 L p .978 .796 .381 r
F P
0 g
s
.487 .38133 m .4893 .37435 L .48933 .37473 L p .71 .761 .261 r
F P
0 g
s
.48933 .37473 m .48704 .38166 L .487 .38133 L p .71 .761 .261 r
F P
0 g
s
.44803 .50395 m .44132 .51021 L .4415 .51017 L p .508 .837 .543 r
F P
0 g
s
.4415 .51017 m .44817 .50394 L .44803 .50395 L p .508 .837 .543 r
F P
0 g
s
.06272 .50035 m .0633 .50109 L .06326 .50215 L p .977 .792 .374 r
F P
0 g
s
.0633 .50109 m .06272 .50035 L .06273 .5 L p .978 .796 .381 r
F P
0 g
s
.0633 .49889 m .06272 .49965 L .06271 .49932 L p .977 .803 .388 r
F P
0 g
s
.06271 .49932 m .06325 .49784 L .0633 .49889 L p .977 .803 .388 r
F P
0 g
s
.7232 .1249 m .72095 .12287 L .72139 .12303 L p .072 .458 .885 r
F P
0 g
s
.72139 .12303 m .72411 .12523 L .7232 .1249 L p .072 .458 .885 r
F P
0 g
s
.71613 .12009 m .71325 .11915 L .71251 .11853 L p .133 .537 .92 r
F P
0 g
s
.71325 .11915 m .71613 .12009 L .7166 .12043 L p .152 .541 .924 r
F P
0 g
s
.58258 .44291 m .5883 .43869 L .58856 .43851 L p 0 0 0 r
F P
0 g
s
.59543 .43412 m .58856 .43851 L .5883 .43869 L p .385 .8 .599 r
F P
0 g
s
.08749 .57808 m .07178 .54825 L .07303 .54811 L p .859 .452 0 r
F P
0 g
s
.066 .52653 m .07303 .54811 L .07178 .54825 L p .915 .592 .117 r
F P
0 g
s
.4844 .38739 m .487 .38133 L .48704 .38166 L p .695 .796 .326 r
F P
0 g
s
.48704 .38166 m .48444 .38769 L .4844 .38739 L p .695 .796 .326 r
F P
0 g
s
.07247 .45313 m .06589 .47386 L .06521 .47382 L p .917 .9 .493 r
F P
0 g
s
.06521 .47382 m .07128 .453 L .07247 .45313 L p .917 .9 .493 r
F P
0 g
s
.06271 .50068 m .06326 .50215 L .06319 .50311 L p .975 .787 .365 r
F P
0 g
s
.06326 .50215 m .06271 .50068 L .06272 .50035 L p .977 .792 .374 r
F P
0 g
s
.06325 .49784 m .06271 .49932 L .06269 .49901 L p .975 .805 .387 r
F P
0 g
s
.06269 .49901 m .06318 .49688 L .06325 .49784 L p .975 .805 .387 r
F P
0 g
s
.57782 .447 m .58258 .44291 L .58275 .44279 L p 0 0 0 r
F P
0 g
s
.58169 .4437 m .57782 .447 L .58275 .44279 L 0 0 0 r
F
.58281 .44275 m .57802 .44687 L .57782 .447 L p F P
0 g
s
.57802 .44687 m .57625 .44616 L p .57454 .44986 L .833 .998 .832 r
F P
0 g
s
.5739 .45097 m .57782 .447 L .57797 .4469 L p 0 0 0 r
F P
0 g
s
.57797 .4469 m .57802 .44687 L p .57709 .44779 L 0 0 0 r
F P
0 g
s
.57709 .44779 m .5739 .45097 L .57797 .4469 L 0 0 0 r
F
.57802 .44687 m .57407 .45086 L .5739 .45097 L p F P
0 g
s
.57407 .45086 m .57238 .45031 L p .5712 .45379 L .868 .995 .798 r
F P
0 g
s
.57072 .45483 m .5739 .45097 L .57403 .45089 L p 0 0 0 r
F P
0 g
s
.57403 .45089 m .57407 .45086 L p .57331 .45176 L 0 0 0 r
F P
0 g
s
.57331 .45176 m .57072 .45483 L .57403 .45089 L 0 0 0 r
F
.56825 .45862 m .56811 .4587 L p .57022 .45568 L F P
0 g
s
.57087 .45474 m .56825 .45862 L p .57022 .45568 L 0 0 0 r
F P
0 g
s
.56811 .4587 m .57072 .45484 L .57087 .45474 L p 0 0 0 r
F P
0 g
s
.56825 .45862 m .5667 .45835 L p .56626 .46159 L .932 .97 .719 r
F P
0 g
s
.56599 .46269 m .56811 .4587 L .56825 .45862 L p 0 0 0 r
F P
0 g
s
.56825 .45862 m .56611 .46262 L .56599 .46269 L p 0 0 0 r
F P
0 g
s
.56611 .46262 m .56825 .45862 L p .56626 .46159 L .932 .97 .719 r
F P
0 g
s
.56825 .45862 m .57087 .45474 L .57087 .45474 L p .901 .986 .765 r
F P
0 g
s
.57407 .45086 m .57087 .45474 L .57072 .45483 L p 0 0 0 r
F P
0 g
s
.57087 .45474 m .56925 .45434 L p .56847 .45767 L .901 .986 .765 r
F P
0 g
s
.56825 .45862 m .57087 .45474 L .56847 .45767 L .901 .986 .765 r
F
.57087 .45474 m .57407 .45086 L p .5712 .45379 L .868 .995 .798 r
F P
0 g
s
.57407 .45086 m .57802 .44687 L p .57454 .44986 L .833 .998 .832 r
F P
0 g
s
.58275 .44279 m .58281 .44275 L p .58169 .4437 L 0 0 0 r
F P
0 g
s
.58856 .43851 m .58281 .44275 L .58258 .44291 L p 0 0 0 r
F P
0 g
s
.45419 .4991 m .44803 .50395 L .44817 .50394 L p .461 .83 .578 r
F P
0 g
s
.44817 .50394 m .4543 .49911 L .45419 .4991 L p .461 .83 .578 r
F P
0 g
s
.5033 .55495 m .50766 .54408 L .50764 .54396 L p 0 0 0 r
F P
0 g
s
.48152 .39263 m .4844 .38739 L .48444 .38769 L p .673 .826 .394 r
F P
0 g
s
.48444 .38769 m .48157 .3929 L .48152 .39263 L p .673 .826 .394 r
F P
0 g
s
.58217 .50631 m .59007 .51095 L .58984 .51092 L p 0 .229 .638 r
F P
0 g
s
.58984 .51092 m .58198 .5063 L .58217 .50631 L p 0 .229 .638 r
F P
0 g
s
.7296 .12945 m .72477 .1254 L .72517 .1254 L p 0 .393 .847 r
F P
0 g
s
.72517 .1254 m .73033 .12946 L .7296 .12945 L p 0 .393 .847 r
F P
0 g
s
.6963 .11228 m .70577 .11527 L .70614 .11589 L p .203 .623 .949 r
F P
0 g
s
.71203 .11804 m .70614 .11589 L .70577 .11527 L p .131 .562 .923 r
F P
0 g
s
.70614 .11589 m .71203 .11804 L .71251 .11853 L p .18 .58 .938 r
F P
0 g
s
.47842 .39714 m .48152 .39263 L .48157 .3929 L p .641 .85 .461 r
F P
0 g
s
.48157 .3929 m .47847 .39738 L .47842 .39714 L p .641 .85 .461 r
F P
0 g
s
.47847 .39738 m .47507 .40133 L .47501 .4011 L p .6 .865 .526 r
F P
0 g
s
.47501 .4011 m .47842 .39714 L .47847 .39738 L p .6 .865 .526 r
F P
0 g
s
.47599 .4025 m .47953 .39852 L .47842 .39714 L p .054 0 .113 r
F P
0 g
s
.06269 .50099 m .06319 .50311 L .06309 .50394 L p .972 .781 .353 r
F P
0 g
s
.06319 .50311 m .06269 .50099 L .06271 .50068 L p .975 .787 .365 r
F P
0 g
s
.06318 .49688 m .06269 .49901 L .06266 .49875 L p .971 .805 .382 r
F P
0 g
s
.06266 .49875 m .06309 .49606 L .06318 .49688 L p .971 .805 .382 r
F P
0 g
s
.45991 .49542 m .45419 .4991 L .4543 .49911 L p .404 .815 .615 r
F P
0 g
s
.4543 .49911 m .45999 .49543 L .45991 .49542 L p .404 .815 .615 r
F P
0 g
s
.066 .52653 m .06347 .51288 L .0638 .51231 L p .968 .71 .281 r
F P
0 g
s
.06286 .50505 m .0638 .51231 L .06347 .51288 L p .962 .744 .299 r
F P
0 g
s
.0638 .51231 m .06286 .50505 L .06298 .5046 L p .975 .758 .334 r
F P
0 g
s
.74722 .14701 m .73771 .13623 L .73806 .13571 L p 0 .213 .734 r
F P
0 g
s
.73806 .13571 m .74778 .14621 L .74722 .14701 L p 0 .213 .734 r
F P
0 g
s
.50766 .54408 m .51046 .53516 L .51044 .53508 L p 0 0 0 r
F P
0 g
s
.06378 .48777 m .06285 .49496 L .06272 .49473 L p .962 .827 .401 r
F P
0 g
s
.06272 .49473 m .06346 .48721 L .06378 .48777 L p .962 .827 .401 r
F P
0 g
s
.47507 .40133 m .47125 .40485 L .47118 .40464 L p .549 .87 .589 r
F P
0 g
s
.47118 .40464 m .47501 .4011 L .47507 .40133 L p .549 .87 .589 r
F P
0 g
s
.66386 .10684 m .68282 .10856 L .68241 .10944 L p .245 .723 .936 r
F P
0 g
s
.6963 .11228 m .68241 .10944 L .68282 .10856 L p .171 .648 .929 r
F P
0 g
s
.57609 .50179 m .58217 .50631 L .58198 .5063 L p 0 .146 .601 r
F P
0 g
s
.58198 .5063 m .57594 .50178 L .57609 .50179 L p 0 .146 .601 r
F P
0 g
s
.72411 .12523 m .72139 .12303 L .72171 .12311 L p .038 .438 .871 r
F P
0 g
s
.72171 .12311 m .72477 .1254 L .72411 .12523 L p .038 .438 .871 r
F P
0 g
s
.71578 .11979 m .71251 .11853 L .71203 .11804 L p .108 .529 .912 r
F P
0 g
s
.71251 .11853 m .71578 .11979 L .71613 .12009 L p .133 .537 .92 r
F P
0 g
s
.46526 .4927 m .45991 .49542 L .45999 .49543 L p .338 .791 .648 r
F P
0 g
s
.45999 .49543 m .46533 .49271 L .46526 .4927 L p .338 .791 .648 r
F P
0 g
s
.45706 .41237 m .45133 .41366 L .45123 .41348 L p .231 .749 .762 r
F P
0 g
s
.47125 .40485 m .46699 .4079 L .46692 .4077 L p .485 .863 .647 r
F P
0 g
s
.46692 .4077 m .47118 .40464 L .47125 .40485 L p .485 .863 .647 r
F P
0 g
s
.71848 .87842 m .7187 .8788 L .71857 .87888 L p .049 0 0 r
F P
0 g
s
.71857 .87888 m .7178 .87882 L .71848 .87842 L p .049 0 0 r
F P
0 g
s
.7187 .8788 m .71848 .87842 L .71917 .87803 L p .047 0 0 r
F P
0 g
s
.71846 .12161 m .71864 .1213 L .71892 .12145 L p .089 .49 .898 r
F P
0 g
s
.71892 .12145 m .71914 .12199 L .71846 .12161 L p .089 .49 .898 r
F P
0 g
s
.71864 .1213 m .71846 .12161 L .71779 .12121 L p .094 .496 .901 r
F P
0 g
s
.46699 .4079 m .46227 .41042 L .46219 .41023 L p .41 .84 .697 r
F P
0 g
s
.46219 .41023 m .46692 .4077 L .46699 .4079 L p .41 .84 .697 r
F P
0 g
s
.7178 .87882 m .71857 .87888 L .71844 .87896 L p .049 0 0 r
F P
0 g
s
.71844 .87896 m .71716 .87923 L .7178 .87882 L p .049 0 0 r
F P
0 g
s
.70834 .8837 m .71551 .88052 L .71541 .88068 L p .064 0 0 r
F P
0 g
s
.71541 .88068 m .70804 .88424 L .70834 .8837 L p .064 0 0 r
F P
0 g
s
.71884 .87873 m .71917 .87803 L .71984 .87768 L p .043 0 0 r
F P
0 g
s
.71917 .87803 m .71884 .87873 L .7187 .8788 L p .047 0 0 r
F P
0 g
s
.46227 .41042 m .45706 .41237 L .45697 .41218 L p .324 .802 .736 r
F P
0 g
s
.45123 .41348 m .45697 .41218 L .45706 .41237 L p .231 .749 .762 r
F P
0 g
s
.45697 .41218 m .46219 .41023 L .46227 .41042 L p .324 .802 .736 r
F P
0 g
s
.74187 .86158 m .7287 .87231 L .72809 .87231 L p 0 0 0 r
F P
0 g
s
.72178 .8769 m .72809 .87231 L .7287 .87231 L p 0 0 0 r
F P
0 g
s
.72809 .87231 m .72178 .8769 L .72145 .87698 L p .031 0 0 r
F P
0 g
s
.71914 .12199 m .71892 .12145 L .71919 .1216 L p .082 .483 .895 r
F P
0 g
s
.71919 .1216 m .7198 .12234 L .71914 .12199 L p .082 .483 .895 r
F P
0 g
s
.71837 .12113 m .71779 .12121 L .71717 .12081 L p .094 .499 .902 r
F P
0 g
s
.71779 .12121 m .71837 .12113 L .71864 .1213 L p .094 .496 .901 r
F P
0 g
s
.06266 .50125 m .06309 .50394 L .06298 .5046 L p .967 .775 .339 r
F P
0 g
s
.06309 .50394 m .06266 .50125 L .06269 .50099 L p .972 .781 .353 r
F P
0 g
s
.47029 .4908 m .46526 .4927 L .46533 .49271 L p .265 .756 .677 r
F P
0 g
s
.46533 .49271 m .47035 .49082 L .47029 .4908 L p .265 .756 .677 r
F P
0 g
s
.06309 .49606 m .06266 .49875 L .06262 .49854 L p .967 .805 .375 r
F P
0 g
s
.06262 .49854 m .06298 .49541 L .06309 .49606 L p .967 .805 .375 r
F P
0 g
s
.71716 .87923 m .71844 .87896 L .71833 .87904 L p .047 0 0 r
F P
0 g
s
.71833 .87904 m .71659 .87962 L .71716 .87923 L p .047 0 0 r
F P
0 g
s
.71897 .87866 m .71984 .87768 L .72046 .87738 L p .037 0 0 r
F P
0 g
s
.71984 .87768 m .71897 .87866 L .71884 .87873 L p .043 0 0 r
F P
0 g
s
.51258 .52118 m .51201 .52759 L .51203 .52765 L p 0 0 0 r
F P
0 g
s
.51046 .53516 m .51203 .52765 L .51201 .52759 L p 0 0 0 r
F P
0 g
s
.57147 .4973 m .57609 .50179 L .57594 .50178 L p 0 .046 .548 r
F P
0 g
s
.57594 .50178 m .57134 .49731 L .57147 .4973 L p 0 .046 .548 r
F P
0 g
s
.7198 .12234 m .71919 .1216 L .71944 .12172 L p .07 .475 .89 r
F P
0 g
s
.71944 .12172 m .72041 .12263 L .7198 .12234 L p .07 .475 .89 r
F P
0 g
s
.71811 .12097 m .71717 .12081 L .7166 .12043 L p .09 .501 .902 r
F P
0 g
s
.71717 .12081 m .71811 .12097 L .71837 .12113 L p .094 .499 .902 r
F P
0 g
s
.47501 .4896 m .47029 .4908 L .47035 .49082 L p .187 .712 .698 r
F P
0 g
s
.47035 .49082 m .47506 .48962 L .47501 .4896 L p .187 .712 .698 r
F P
0 g
s
.56439 .46679 m .56599 .46269 L .56611 .46262 L p 0 0 0 r
F P
0 g
s
.47943 .48901 m .47501 .4896 L .47506 .48962 L p .106 .658 .712 r
F P
0 g
s
.47506 .48962 m .47947 .48903 L .47943 .48901 L p .106 .658 .712 r
F P
0 g
s
.56803 .49284 m .57147 .4973 L .57134 .49731 L p 0 0 .478 r
F P
0 g
s
.57134 .49731 m .56791 .49285 L .56803 .49284 L p 0 0 .478 r
F P
0 g
s
.51235 .51561 m .51258 .52118 L .51261 .52122 L p 0 0 .039 r
F P
0 g
s
.51203 .52765 m .51261 .52122 L .51258 .52118 L p 0 0 0 r
F P
0 g
s
.71659 .87962 m .71833 .87904 L .71823 .87911 L p .043 0 0 r
F P
0 g
s
.71823 .87911 m .71611 .87997 L .71659 .87962 L p .043 0 0 r
F P
0 g
s
.71909 .8786 m .72046 .87738 L .72101 .87714 L p .029 0 0 r
F P
0 g
s
.72046 .87738 m .71909 .8786 L .71897 .87866 L p .037 0 0 r
F P
0 g
s
.56611 .46262 m .5645 .46673 L .56439 .46679 L p 0 0 0 r
F P
0 g
s
.56334 .47099 m .56439 .46679 L .5645 .46673 L p 0 0 0 r
F P
0 g
s
.6919 .89035 m .70804 .88424 L .70819 .88451 L p .082 0 0 r
F P
0 g
s
.70819 .88451 m .69224 .89103 L .6919 .89035 L p .082 0 0 r
F P
0 g
s
.72041 .12263 m .71944 .12172 L .71966 .12181 L p .056 .465 .884 r
F P
0 g
s
.71966 .12181 m .72095 .12287 L .72041 .12263 L p .056 .465 .884 r
F P
0 g
s
.71788 .12082 m .7166 .12043 L .71613 .12009 L p .083 .5 .9 r
F P
0 g
s
.7166 .12043 m .71788 .12082 L .71811 .12097 L p .09 .501 .902 r
F P
0 g
s
.48355 .48892 m .47943 .48901 L .47947 .48903 L p .024 .596 .716 r
F P
0 g
s
.47947 .48903 m .48358 .48894 L .48355 .48892 L p .024 .596 .716 r
F P
0 g
s
.76297 .84052 m .74229 .8622 L .74187 .86158 L p 0 0 0 r
F P
0 g
s
.7287 .87231 m .74187 .86158 L .74229 .8622 L p 0 0 0 r
F P
0 g
s
.5645 .46673 m .56344 .47094 L .56334 .47099 L p 0 0 0 r
F P
0 g
s
.56287 .47527 m .56334 .47099 L .56344 .47094 L p 0 0 0 r
F P
0 g
s
.56557 .48839 m .56803 .49284 L .56791 .49285 L p 0 0 .391 r
F P
0 g
s
.56791 .49285 m .56547 .48841 L .56557 .48839 L p 0 0 .391 r
F P
0 g
s
.48737 .48928 m .48355 .48892 L .48358 .48894 L p 0 .527 .712 r
F P
0 g
s
.48358 .48894 m .48739 .4893 L .48737 .48928 L p 0 .527 .712 r
F P
0 g
s
.51147 .51075 m .51235 .51561 L .51237 .51564 L p 0 0 .135 r
F P
0 g
s
.51261 .52122 m .51237 .51564 L .51235 .51561 L p 0 0 .039 r
F P
0 g
s
.56344 .47094 m .56297 .47523 L .56287 .47527 L p 0 0 0 r
F P
0 g
s
.56303 .47961 m .56287 .47527 L .56297 .47523 L p 0 0 .077 r
F P
0 g
s
.07178 .54825 m .0653 .52658 L .066 .52653 L p .915 .592 .117 r
F P
0 g
s
.06347 .51288 m .066 .52653 L .0653 .52658 L p .938 .678 .206 r
F P
0 g
s
.49089 .49001 m .48737 .48928 L .48739 .4893 L p 0 .453 .699 r
F P
0 g
s
.48739 .4893 m .49091 .49003 L .49089 .49001 L p 0 .453 .699 r
F P
0 g
s
.56397 .48397 m .56557 .48839 L .56547 .48841 L p 0 0 .292 r
F P
0 g
s
.56547 .48841 m .56387 .48399 L .56397 .48397 L p 0 0 .292 r
F P
0 g
s
.56297 .47523 m .56313 .47957 L .56303 .47961 L p 0 0 .077 r
F P
0 g
s
.56387 .48399 m .56303 .47961 L .56313 .47957 L p 0 0 .186 r
F P
0 g
s
.56313 .47957 m .56397 .48397 L .56387 .48399 L p 0 0 .186 r
F P
0 g
s
.06589 .47386 m .06346 .48721 L .06312 .4872 L p .938 .853 .419 r
F P
0 g
s
.06312 .4872 m .06521 .47382 L .06589 .47386 L p .938 .853 .419 r
F P
0 g
s
.49091 .49003 m .49423 .49112 L .49422 .49111 L p 0 .372 .677 r
F P
0 g
s
.49422 .49111 m .4909 .49001 L .49091 .49003 L p 0 .372 .677 r
F P
0 g
s
.51003 .5065 m .51147 .51075 L .51148 .51077 L p 0 0 .232 r
F P
0 g
s
.51237 .51564 m .51148 .51077 L .51147 .51075 L p 0 0 .135 r
F P
0 g
s
.06262 .50146 m .06298 .5046 L .06286 .50505 L p .962 .769 .325 r
F P
0 g
s
.06298 .5046 m .06262 .50146 L .06266 .50125 L p .967 .775 .339 r
F P
0 g
s
.49423 .49112 m .49743 .4926 L .49742 .49259 L p 0 .285 .646 r
F P
0 g
s
.49742 .49259 m .49422 .49111 L .49423 .49112 L p 0 .285 .646 r
F P
0 g
s
.06298 .49541 m .06262 .49854 L .06258 .4984 L p .962 .802 .366 r
F P
0 g
s
.06258 .4984 m .06285 .49496 L .06298 .49541 L p .962 .802 .366 r
F P
0 g
s
.49743 .4926 m .50047 .4945 L .50047 .49449 L p 0 .189 .604 r
F P
0 g
s
.50047 .49449 m .49742 .49259 L .49743 .4926 L p 0 .189 .604 r
F P
0 g
s
.50815 .50279 m .51003 .5065 L .51005 .50651 L p 0 0 .325 r
F P
0 g
s
.51148 .51077 m .51005 .50651 L .51003 .5065 L p 0 0 .232 r
F P
0 g
s
.71611 .87997 m .71823 .87911 L .71816 .87917 L p .037 0 0 r
F P
0 g
s
.71816 .87917 m .71574 .88027 L .71611 .87997 L p .037 0 0 r
F P
0 g
s
.50047 .4945 m .50331 .49681 L .50331 .49681 L p 0 .085 .551 r
F P
0 g
s
.50331 .49681 m .50047 .49449 L .50047 .4945 L p 0 .085 .551 r
F P
0 g
s
.7192 .87855 m .72101 .87714 L .72145 .87698 L p .02 0 0 r
F P
0 g
s
.72101 .87714 m .7192 .87855 L .71909 .8786 L p .029 0 0 r
F P
0 g
s
.50588 .49957 m .50815 .50279 L .50816 .50279 L p 0 0 .411 r
F P
0 g
s
.51005 .50651 m .50816 .50279 L .50815 .50279 L p 0 0 .325 r
F P
0 g
s
.73771 .13623 m .73033 .12946 L .73053 .12914 L p 0 .295 .785 r
F P
0 g
s
.73053 .12914 m .73806 .13571 L .73771 .13623 L p 0 .295 .785 r
F P
0 g
s
.50331 .49681 m .50588 .49957 L .50589 .49957 L p 0 0 .487 r
F P
0 g
s
.50589 .49957 m .50331 .49681 L .50331 .49681 L p 0 0 .487 r
F P
0 g
s
.50816 .50279 m .50589 .49957 L .50588 .49957 L p 0 0 .411 r
F P
0 g
s
.72095 .12287 m .71966 .12181 L .71984 .12188 L p .039 .454 .877 r
F P
0 g
s
.71984 .12188 m .72139 .12303 L .72095 .12287 L p .039 .454 .877 r
F P
0 g
s
.68282 .10856 m .69658 .11172 L .6963 .11228 L p .171 .648 .929 r
F P
0 g
s
.70577 .11527 m .6963 .11228 L .69658 .11172 L p .113 .585 .915 r
F P
0 g
s
.71769 .12067 m .71613 .12009 L .71578 .11979 L p .072 .497 .896 r
F P
0 g
s
.71613 .12009 m .71769 .12067 L .71788 .12082 L p .083 .5 .9 r
F P
0 g
s
.72477 .1254 m .72171 .12311 L .7219 .12311 L p 0 .416 .856 r
F P
0 g
s
.7219 .12311 m .72517 .1254 L .72477 .1254 L p 0 .416 .856 r
F P
0 g
s
.70577 .11527 m .71184 .1177 L .71203 .11804 L p .131 .562 .923 r
F P
0 g
s
.71555 .11955 m .71203 .11804 L .71184 .1177 L p .077 .516 .901 r
F P
0 g
s
.71203 .11804 m .71555 .11955 L .71578 .11979 L p .108 .529 .912 r
F P
0 g
s
.71574 .88027 m .71816 .87917 L .71811 .87922 L p .03 0 0 r
F P
0 g
s
.71811 .87922 m .71551 .88052 L .71574 .88027 L p .03 0 0 r
F P
0 g
s
.71929 .87852 m .72145 .87698 L .72178 .8769 L p .01 0 0 r
F P
0 g
s
.72145 .87698 m .71929 .87852 L .7192 .87855 L p .02 0 0 r
F P
0 g
s
.72139 .12303 m .71984 .12188 L .71997 .12191 L p .02 .443 .869 r
F P
0 g
s
.71997 .12191 m .72171 .12311 L .72139 .12303 L p .02 .443 .869 r
F P
0 g
s
.71754 .12055 m .71578 .11979 L .71555 .11955 L p .058 .492 .891 r
F P
0 g
s
.71578 .11979 m .71754 .12055 L .71769 .12067 L p .072 .497 .896 r
F P
0 g
s
.06273 .5 m .06254 .5 L .06254 .49993 L p .96 .785 .341 r
F P
0 g
s
.06254 .49993 m .06272 .49965 L .06273 .5 L p .96 .785 .341 r
F P
0 g
s
.06254 .5 m .06273 .5 L .06272 .50035 L p .96 .783 .34 r
F P
0 g
s
.06254 .50007 m .06272 .50035 L .06271 .50068 L p .96 .782 .337 r
F P
0 g
s
.06272 .50035 m .06254 .50007 L .06254 .5 L p .96 .783 .34 r
F P
0 g
s
.06272 .49965 m .06254 .49993 L .06254 .49986 L p .96 .785 .342 r
F P
0 g
s
.06254 .49986 m .06271 .49932 L .06272 .49965 L p .96 .785 .342 r
F P
0 g
s
.06347 .51288 m .06272 .50529 L .06286 .50505 L p .962 .744 .299 r
F P
0 g
s
.06258 .5016 m .06286 .50505 L .06272 .50529 L p .956 .762 .309 r
F P
0 g
s
.06286 .50505 m .06258 .5016 L .06262 .50146 L p .962 .769 .325 r
F P
0 g
s
.06285 .49496 m .06258 .4984 L .06254 .49833 L p .956 .798 .354 r
F P
0 g
s
.06254 .49833 m .06272 .49473 L .06285 .49496 L p .956 .798 .354 r
F P
0 g
s
.06254 .50014 m .06271 .50068 L .06269 .50099 L p .959 .78 .333 r
F P
0 g
s
.06271 .50068 m .06254 .50014 L .06254 .50007 L p .96 .782 .337 r
F P
0 g
s
.06271 .49932 m .06254 .49986 L .06253 .4998 L p .959 .786 .341 r
F P
0 g
s
.06253 .4998 m .06269 .49901 L .06271 .49932 L p .959 .786 .341 r
F P
0 g
s
.71864 .1213 m .71872 .12117 L .71881 .12122 L p .042 .468 .882 r
F P
0 g
s
.71881 .12122 m .71892 .12145 L .71864 .1213 L p .042 .468 .882 r
F P
0 g
s
.71872 .12117 m .71864 .1213 L .71837 .12113 L p .044 .471 .883 r
F P
0 g
s
.71892 .12145 m .71881 .12122 L .71889 .12126 L p .038 .465 .88 r
F P
0 g
s
.71889 .12126 m .71919 .1216 L .71892 .12145 L p .038 .465 .88 r
F P
0 g
s
.71863 .12112 m .71837 .12113 L .71811 .12097 L p .044 .472 .883 r
F P
0 g
s
.71837 .12113 m .71863 .12112 L .71872 .12117 L p .044 .471 .883 r
F P
0 g
s
.73033 .12946 m .72517 .1254 L .72527 .12523 L p 0 .354 .818 r
F P
0 g
s
.72527 .12523 m .73053 .12914 L .73033 .12946 L p 0 .354 .818 r
F P
0 g
s
.69658 .11172 m .70595 .11494 L .70577 .11527 L p .113 .585 .915 r
F P
0 g
s
.71184 .1177 m .70577 .11527 L .70595 .11494 L p .071 .535 .899 r
F P
0 g
s
.71919 .1216 m .71889 .12126 L .71897 .1213 L p .033 .461 .877 r
F P
0 g
s
.71897 .1213 m .71944 .12172 L .71919 .1216 L p .033 .461 .877 r
F P
0 g
s
.71855 .12107 m .71811 .12097 L .71788 .12082 L p .042 .473 .883 r
F P
0 g
s
.71811 .12097 m .71855 .12107 L .71863 .12112 L p .044 .472 .883 r
F P
0 g
s
.06253 .5002 m .06269 .50099 L .06266 .50125 L p .957 .778 .329 r
F P
0 g
s
.06269 .50099 m .06253 .5002 L .06254 .50014 L p .959 .78 .333 r
F P
0 g
s
.06269 .49901 m .06253 .4998 L .06253 .49975 L p .957 .786 .339 r
F P
0 g
s
.06253 .49975 m .06266 .49875 L .06269 .49901 L p .957 .786 .339 r
F P
0 g
s
.0653 .52658 m .06313 .51289 L .06347 .51288 L p .938 .678 .206 r
F P
0 g
s
.06272 .50529 m .06347 .51288 L .06313 .51289 L p .946 .728 .261 r
F P
0 g
s
.06346 .48721 m .06272 .49473 L .06258 .49473 L p .946 .816 .369 r
F P
0 g
s
.06258 .49473 m .06312 .4872 L .06346 .48721 L p .946 .816 .369 r
F P
0 g
s
.70804 .88424 m .71541 .88068 L .71546 .88077 L p .034 0 0 r
F P
0 g
s
.71546 .88077 m .70819 .88451 L .70804 .88424 L p .034 0 0 r
F P
0 g
s
.74229 .8622 m .72886 .87258 L .7287 .87231 L p 0 0 0 r
F P
0 g
s
.72197 .8769 m .7287 .87231 L .72886 .87258 L p 0 0 0 r
F P
0 g
s
.7287 .87231 m .72197 .8769 L .72178 .8769 L p 0 0 0 r
F P
0 g
s
.71944 .12172 m .71897 .1213 L .71904 .12133 L p .026 .456 .874 r
F P
0 g
s
.71904 .12133 m .71966 .12181 L .71944 .12172 L p .026 .456 .874 r
F P
0 g
s
.71848 .12102 m .71788 .12082 L .71769 .12067 L p .038 .472 .881 r
F P
0 g
s
.71788 .12082 m .71848 .12102 L .71855 .12107 L p .042 .473 .883 r
F P
0 g
s
.71551 .88052 m .71811 .87922 L .71809 .87925 L p .021 0 0 r
F P
0 g
s
.71809 .87925 m .71541 .88068 L .71551 .88052 L p .021 0 0 r
F P
0 g
s
.71935 .8785 m .72178 .8769 L .72197 .8769 L p 0 0 0 r
F P
0 g
s
.72178 .8769 m .71935 .8785 L .71929 .87852 L p .01 0 0 r
F P
0 g
s
.72171 .12311 m .71997 .12191 L .72005 .12191 L p 0 .431 .86 r
F P
0 g
s
.72005 .12191 m .7219 .12311 L .72171 .12311 L p 0 .431 .86 r
F P
0 g
s
.71184 .1177 m .71545 .11939 L .71555 .11955 L p .077 .516 .901 r
F P
0 g
s
.71745 .12045 m .71555 .11955 L .71545 .11939 L p .041 .484 .884 r
F P
0 g
s
.71555 .11955 m .71745 .12045 L .71754 .12055 L p .058 .492 .891 r
F P
0 g
s
.06253 .50025 m .06266 .50125 L .06262 .50146 L p .956 .775 .324 r
F P
0 g
s
.06266 .50125 m .06253 .50025 L .06253 .5002 L p .957 .778 .329 r
F P
0 g
s
.06266 .49875 m .06253 .49975 L .06252 .49971 L p .956 .785 .337 r
F P
0 g
s
.06252 .49971 m .06262 .49854 L .06266 .49875 L p .956 .785 .337 r
F P
0 g
s
.71966 .12181 m .71904 .12133 L .7191 .12135 L p .018 .451 .871 r
F P
0 g
s
.7191 .12135 m .71984 .12188 L .71966 .12181 L p .018 .451 .871 r
F P
0 g
s
.71842 .12097 m .71769 .12067 L .71754 .12055 L p .033 .47 .879 r
F P
0 g
s
.71769 .12067 m .71842 .12097 L .71848 .12102 L p .038 .472 .881 r
F P
0 g
s
.06252 .50029 m .06262 .50146 L .06258 .5016 L p .954 .773 .319 r
F P
0 g
s
.06262 .50146 m .06252 .50029 L .06253 .50025 L p .956 .775 .324 r
F P
0 g
s
.06262 .49854 m .06252 .49971 L .06251 .49968 L p .954 .784 .333 r
F P
0 g
s
.06251 .49968 m .06258 .4984 L .06262 .49854 L p .954 .784 .333 r
F P
0 g
s
.72517 .1254 m .7219 .12311 L .72195 .12303 L p 0 .394 .839 r
F P
0 g
s
.72195 .12303 m .72527 .12523 L .72517 .1254 L p 0 .394 .839 r
F P
0 g
s
.70595 .11494 m .71194 .11753 L .71184 .1177 L p .071 .535 .899 r
F P
0 g
s
.71545 .11939 m .71184 .1177 L .71194 .11753 L p .041 .499 .886 r
F P
0 g
s
.71984 .12188 m .7191 .12135 L .71914 .12136 L p .009 .445 .867 r
F P
0 g
s
.71914 .12136 m .71997 .12191 L .71984 .12188 L p .009 .445 .867 r
F P
0 g
s
.71837 .12093 m .71754 .12055 L .71745 .12045 L p .026 .468 .877 r
F P
0 g
s
.71754 .12055 m .71837 .12093 L .71842 .12097 L p .033 .47 .879 r
F P
0 g
s
.7187 .8788 m .71875 .87888 L .71874 .87889 L p .01 0 0 r
F P
0 g
s
.71874 .87889 m .71857 .87888 L .7187 .8788 L p .01 0 0 r
F P
0 g
s
.71875 .87888 m .7187 .8788 L .71884 .87873 L p .01 0 0 r
F P
0 g
s
.71857 .87888 m .71874 .87889 L .71873 .87889 L p .01 0 0 r
F P
0 g
s
.71873 .87889 m .71844 .87896 L .71857 .87888 L p .01 0 0 r
F P
0 g
s
.71876 .87888 m .71884 .87873 L .71897 .87866 L p .009 0 0 r
F P
0 g
s
.71884 .87873 m .71876 .87888 L .71875 .87888 L p .01 0 0 r
F P
0 g
s
.71844 .87896 m .71873 .87889 L .71872 .8789 L p .01 0 0 r
F P
0 g
s
.71872 .8789 m .71833 .87904 L .71844 .87896 L p .01 0 0 r
F P
0 g
s
.71876 .87887 m .71897 .87866 L .71909 .8786 L p .008 0 0 r
F P
0 g
s
.71897 .87866 m .71876 .87887 L .71876 .87888 L p .009 0 0 r
F P
0 g
s
.71833 .87904 m .71872 .8789 L .71872 .8789 L p .009 0 0 r
F P
0 g
s
.71872 .8789 m .71823 .87911 L .71833 .87904 L p .009 0 0 r
F P
0 g
s
.71877 .87887 m .71909 .8786 L .7192 .87855 L p .006 0 0 r
F P
0 g
s
.71909 .8786 m .71877 .87887 L .71876 .87887 L p .008 0 0 r
F P
0 g
s
.06313 .51289 m .06258 .50529 L .06272 .50529 L p .946 .728 .261 r
F P
0 g
s
.06254 .50167 m .06272 .50529 L .06258 .50529 L p .948 .755 .293 r
F P
0 g
s
.06272 .50529 m .06254 .50167 L .06258 .5016 L p .956 .762 .309 r
F P
0 g
s
.06272 .49473 m .06254 .49833 L .0625 .49833 L p .948 .793 .339 r
F P
0 g
s
.0625 .49833 m .06258 .49473 L .06272 .49473 L p .948 .793 .339 r
F P
0 g
s
.06251 .50032 m .06258 .5016 L .06254 .50167 L p .951 .77 .314 r
F P
0 g
s
.06258 .5016 m .06251 .50032 L .06252 .50029 L p .954 .773 .319 r
F P
0 g
s
.06258 .4984 m .06251 .49968 L .06251 .49967 L p .951 .783 .329 r
F P
0 g
s
.06251 .49967 m .06254 .49833 L .06258 .4984 L p .951 .783 .329 r
F P
0 g
s
.71823 .87911 m .71872 .8789 L .71871 .8789 L p .008 0 0 r
F P
0 g
s
.71871 .8789 m .71816 .87917 L .71823 .87911 L p .008 0 0 r
F P
0 g
s
.71878 .87887 m .7192 .87855 L .71929 .87852 L p .004 0 0 r
F P
0 g
s
.7192 .87855 m .71878 .87887 L .71877 .87887 L p .006 0 0 r
F P
0 g
s
.71872 .12117 m .71874 .12112 L .71876 .12113 L p .015 .455 .871 r
F P
0 g
s
.71876 .12113 m .71881 .12122 L .71872 .12117 L p .015 .455 .871 r
F P
0 g
s
.71874 .12112 m .71872 .12117 L .71863 .12112 L p .016 .456 .871 r
F P
0 g
s
.71881 .12122 m .71876 .12113 L .71878 .12114 L p .014 .454 .87 r
F P
0 g
s
.71878 .12114 m .71889 .12126 L .71881 .12122 L p .014 .454 .87 r
F P
0 g
s
.71873 .12111 m .71863 .12112 L .71855 .12107 L p .016 .456 .871 r
F P
0 g
s
.71863 .12112 m .71873 .12111 L .71874 .12112 L p .016 .456 .871 r
F P
0 g
s
.71997 .12191 m .71914 .12136 L .71916 .12136 L p 0 .44 .863 r
F P
0 g
s
.71916 .12136 m .72005 .12191 L .71997 .12191 L p 0 .44 .863 r
F P
0 g
s
.71545 .11939 m .71741 .12039 L .71745 .12045 L p .041 .484 .884 r
F P
0 g
s
.71834 .1209 m .71745 .12045 L .71741 .12039 L p .018 .464 .873 r
F P
0 g
s
.71745 .12045 m .71834 .1209 L .71837 .12093 L p .026 .468 .877 r
F P
0 g
s
.71889 .12126 m .71878 .12114 L .71879 .12115 L p .012 .452 .869 r
F P
0 g
s
.71879 .12115 m .71897 .1213 L .71889 .12126 L p .012 .452 .869 r
F P
0 g
s
.71871 .1211 m .71855 .12107 L .71848 .12102 L p .015 .457 .871 r
F P
0 g
s
.71855 .12107 m .71871 .1211 L .71873 .12111 L p .016 .456 .871 r
F P
0 g
s
.71541 .88068 m .71809 .87925 L .7181 .87927 L p .011 0 0 r
F P
0 g
s
.7181 .87927 m .71546 .88077 L .71541 .88068 L p .011 0 0 r
F P
0 g
s
.72886 .87258 m .72202 .87698 L .72197 .8769 L p 0 0 0 r
F P
0 g
s
.71939 .8785 m .72197 .8769 L .72202 .87698 L p 0 0 0 r
F P
0 g
s
.72197 .8769 m .71939 .8785 L .71935 .8785 L p 0 0 0 r
F P
0 g
s
.71897 .1213 m .71879 .12115 L .71881 .12116 L p .009 .45 .868 r
F P
0 g
s
.71881 .12116 m .71904 .12133 L .71897 .1213 L p .009 .45 .868 r
F P
0 g
s
.7187 .12109 m .71848 .12102 L .71842 .12097 L p .014 .456 .87 r
F P
0 g
s
.71848 .12102 m .7187 .12109 L .71871 .1211 L p .015 .457 .871 r
F P
0 g
s
.7219 .12311 m .72005 .12191 L .72007 .12188 L p 0 .42 .851 r
F P
0 g
s
.72007 .12188 m .72195 .12303 L .7219 .12311 L p 0 .42 .851 r
F P
0 g
s
.71194 .11753 m .7155 .1193 L .71545 .11939 L p .041 .499 .886 r
F P
0 g
s
.71741 .12039 m .71545 .11939 L .7155 .1193 L p .021 .474 .876 r
F P
0 g
s
.71816 .87917 m .71871 .8789 L .71871 .87891 L p .006 0 0 r
F P
0 g
s
.71871 .87891 m .71811 .87922 L .71816 .87917 L p .006 0 0 r
F P
0 g
s
.71878 .87886 m .71929 .87852 L .71935 .8785 L p .002 0 0 r
F P
0 g
s
.71929 .87852 m .71878 .87886 L .71878 .87887 L p .004 0 0 r
F P
0 g
s
.06254 .5 m .0625 .5 L .0625 .5 L p .951 .777 .322 r
F P
0 g
s
.0625 .5 m .06254 .49993 L .06254 .5 L p .951 .777 .322 r
F P
0 g
s
.0625 .5 m .06254 .5 L .06254 .50007 L p .951 .777 .321 r
F P
0 g
s
.0625 .5 m .06254 .50007 L .06254 .50014 L p .951 .776 .321 r
F P
0 g
s
.06254 .50007 m .0625 .5 L .0625 .5 L p .951 .777 .321 r
F P
0 g
s
.06254 .49993 m .0625 .5 L .0625 .49999 L p .951 .777 .322 r
F P
0 g
s
.0625 .49999 m .06254 .49986 L .06254 .49993 L p .951 .777 .322 r
F P
0 g
s
.71904 .12133 m .71881 .12116 L .71882 .12116 L p .006 .449 .866 r
F P
0 g
s
.71882 .12116 m .7191 .12135 L .71904 .12133 L p .006 .449 .866 r
F P
0 g
s
.71868 .12109 m .71842 .12097 L .71837 .12093 L p .012 .456 .87 r
F P
0 g
s
.71842 .12097 m .71868 .12109 L .7187 .12109 L p .014 .456 .87 r
F P
0 g
s
.0625 .50001 m .06254 .50014 L .06253 .5002 L p .951 .776 .32 r
F P
0 g
s
.06254 .50014 m .0625 .50001 L .0625 .5 L p .951 .776 .321 r
F P
0 g
s
.06254 .49986 m .0625 .49999 L .0625 .49999 L p .951 .777 .322 r
F P
0 g
s
.0625 .49999 m .06253 .4998 L .06254 .49986 L p .951 .777 .322 r
F P
0 g
s
.0625 .50001 m .06253 .5002 L .06253 .50025 L p .951 .775 .319 r
F P
0 g
s
.06253 .5002 m .0625 .50001 L .0625 .50001 L p .951 .776 .32 r
F P
0 g
s
.06253 .4998 m .0625 .49999 L .0625 .49998 L p .951 .777 .321 r
F P
0 g
s
.0625 .49998 m .06253 .49975 L .06253 .4998 L p .951 .777 .321 r
F P
0 g
s
.7191 .12135 m .71882 .12116 L .71883 .12116 L p .003 .447 .865 r
F P
0 g
s
.71883 .12116 m .71914 .12136 L .7191 .12135 L p .003 .447 .865 r
F P
0 g
s
.71867 .12108 m .71837 .12093 L .71834 .1209 L p .01 .455 .869 r
F P
0 g
s
.71837 .12093 m .71867 .12108 L .71868 .12109 L p .012 .456 .87 r
F P
0 g
s
.71811 .87922 m .71871 .87891 L .71871 .87891 L p .004 0 0 r
F P
0 g
s
.71871 .87891 m .71809 .87925 L .71811 .87922 L p .004 0 0 r
F P
0 g
s
.71879 .87886 m .71935 .8785 L .71939 .8785 L p 0 0 0 r
F P
0 g
s
.71935 .8785 m .71879 .87886 L .71878 .87886 L p .002 0 0 r
F P
0 g
s
.0625 .50002 m .06253 .50025 L .06252 .50029 L p .95 .775 .318 r
F P
0 g
s
.06253 .50025 m .0625 .50002 L .0625 .50001 L p .951 .775 .319 r
F P
0 g
s
.06253 .49975 m .0625 .49998 L .0625 .49998 L p .95 .777 .321 r
F P
0 g
s
.0625 .49998 m .06252 .49971 L .06253 .49975 L p .95 .777 .321 r
F P
0 g
s
.06258 .50529 m .0625 .50167 L .06254 .50167 L p .948 .755 .293 r
F P
0 g
s
.06251 .50033 m .06254 .50167 L .0625 .50167 L p .949 .768 .308 r
F P
0 g
s
.06254 .50167 m .06251 .50033 L .06251 .50032 L p .951 .77 .314 r
F P
0 g
s
.06254 .49833 m .06251 .49967 L .0625 .49967 L p .949 .781 .324 r
F P
0 g
s
.0625 .49967 m .0625 .49833 L .06254 .49833 L p .949 .781 .324 r
F P
0 g
s
.0625 .50002 m .06252 .50029 L .06251 .50032 L p .95 .774 .317 r
F P
0 g
s
.06252 .50029 m .0625 .50002 L .0625 .50002 L p .95 .775 .318 r
F P
0 g
s
.06252 .49971 m .0625 .49998 L .0625 .49998 L p .95 .777 .32 r
F P
0 g
s
.0625 .49998 m .06251 .49968 L .06252 .49971 L p .95 .777 .32 r
F P
0 g
s
.72005 .12191 m .71916 .12136 L .71917 .12135 L p 0 .435 .858 r
F P
0 g
s
.71917 .12135 m .72007 .12188 L .72005 .12191 L p 0 .435 .858 r
F P
0 g
s
.7155 .1193 m .71743 .12035 L .71741 .12039 L p .021 .474 .876 r
F P
0 g
s
.71833 .12088 m .71741 .12039 L .71743 .12035 L p .01 .459 .869 r
F P
0 g
s
.71741 .12039 m .71833 .12088 L .71834 .1209 L p .018 .464 .873 r
F P
0 g
s
.71914 .12136 m .71883 .12116 L .71883 .12116 L p 0 .445 .863 r
F P
0 g
s
.71883 .12116 m .71916 .12136 L .71914 .12136 L p 0 .445 .863 r
F P
0 g
s
.71867 .12107 m .71834 .1209 L .71833 .12088 L p .007 .453 .867 r
F P
0 g
s
.71834 .1209 m .71867 .12107 L .71867 .12108 L p .01 .455 .869 r
F P
0 g
s
.0625 .50002 m .06251 .50032 L .06251 .50033 L p .949 .774 .316 r
F P
0 g
s
.06251 .50032 m .0625 .50002 L .0625 .50002 L p .95 .774 .317 r
F P
0 g
s
.06251 .49968 m .0625 .49998 L .0625 .49998 L p .949 .776 .319 r
F P
0 g
s
.0625 .49998 m .06251 .49967 L .06251 .49968 L p .949 .776 .319 r
F P
0 g
s
.71874 .12112 m .71875 .12111 L .71875 .12112 L p .004 .449 .866 r
F P
0 g
s
.71875 .12112 m .71876 .12113 L .71874 .12112 L p .004 .449 .866 r
F P
0 g
s
.71875 .12111 m .71874 .12112 L .71873 .12111 L p .004 .449 .866 r
F P
0 g
s
.71876 .12113 m .71875 .12112 L .71875 .12112 L p .003 .449 .865 r
F P
0 g
s
.71875 .12112 m .71878 .12114 L .71876 .12113 L p .003 .449 .865 r
F P
0 g
s
.71875 .12111 m .71873 .12111 L .71871 .1211 L p .004 .449 .866 r
F P
0 g
s
.71873 .12111 m .71875 .12111 L .71875 .12111 L p .004 .449 .866 r
F P
0 g
s
.71878 .12114 m .71875 .12112 L .71875 .12112 L p .003 .448 .865 r
F P
0 g
s
.71875 .12112 m .71879 .12115 L .71878 .12114 L p .003 .448 .865 r
F P
0 g
s
.71875 .12111 m .71871 .1211 L .7187 .12109 L p .004 .449 .866 r
F P
0 g
s
.71871 .1211 m .71875 .12111 L .71875 .12111 L p .004 .449 .866 r
F P
0 g
s
.71809 .87925 m .71871 .87891 L .71871 .87891 L p .002 0 0 r
F P
0 g
s
.71871 .87891 m .7181 .87927 L .71809 .87925 L p .002 0 0 r
F P
0 g
s
.72202 .87698 m .7194 .87852 L .71939 .8785 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .71939 .8785 L .7194 .87852 L p 0 0 0 r
F P
0 g
s
.71939 .8785 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71879 .12115 m .71875 .12112 L .71875 .12112 L p .002 .448 .865 r
F P
0 g
s
.71875 .12112 m .71881 .12116 L .71879 .12115 L p .002 .448 .865 r
F P
0 g
s
.71875 .12111 m .7187 .12109 L .71868 .12109 L p .003 .449 .866 r
F P
0 g
s
.7187 .12109 m .71875 .12111 L .71875 .12111 L p .004 .449 .866 r
F P
0 g
s
.71881 .12116 m .71875 .12112 L .71875 .12112 L p .002 .448 .865 r
F P
0 g
s
.71875 .12112 m .71882 .12116 L .71881 .12116 L p .002 .448 .865 r
F P
0 g
s
.71875 .12111 m .71868 .12109 L .71867 .12108 L p .003 .449 .865 r
F P
0 g
s
.71868 .12109 m .71875 .12111 L .71875 .12111 L p .003 .449 .866 r
F P
0 g
s
.71916 .12136 m .71883 .12116 L .71883 .12116 L p 0 .443 .862 r
F P
0 g
s
.71883 .12116 m .71917 .12135 L .71916 .12136 L p 0 .443 .862 r
F P
0 g
s
.71743 .12035 m .71833 .12087 L .71833 .12088 L p .01 .459 .869 r
F P
0 g
s
.71867 .12107 m .71833 .12088 L .71833 .12087 L p .003 .452 .866 r
F P
0 g
s
.71833 .12088 m .71867 .12107 L .71867 .12107 L p .007 .453 .867 r
F P
0 g
s
.71882 .12116 m .71875 .12112 L .71875 .12112 L p .001 .447 .864 r
F P
0 g
s
.71875 .12112 m .71883 .12116 L .71882 .12116 L p .001 .447 .864 r
F P
0 g
s
.71875 .12111 m .71867 .12108 L .71867 .12107 L p .002 .449 .865 r
F P
0 g
s
.71867 .12108 m .71875 .12111 L .71875 .12111 L p .003 .449 .865 r
F P
0 g
s
.71875 .87889 m .71874 .87889 L .71875 .87888 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71875 .87888 L .71876 .87888 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71873 .87889 L .71874 .87889 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87888 L .71876 .87887 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .8789 L .71873 .87889 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87887 L .71877 .87887 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .8789 L .71872 .8789 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71877 .87887 L .71878 .87887 L closepath p 0 0 0 r
F P
0 g
s
.0625 .50167 m .0625 .50033 L .06251 .50033 L p .949 .768 .308 r
F P
0 g
s
.0625 .50002 m .06251 .50033 L .0625 .50033 L p .949 .773 .315 r
F P
0 g
s
.06251 .50033 m .0625 .50002 L .0625 .50002 L p .949 .774 .316 r
F P
0 g
s
.06251 .49967 m .0625 .49998 L .0625 .49998 L p .949 .776 .318 r
F P
0 g
s
.0625 .49998 m .0625 .49967 L .06251 .49967 L p .949 .776 .318 r
F P
0 g
s
.71875 .87889 m .71871 .8789 L .71872 .8789 L closepath p .001 0 0 r
F P
0 g
s
.71875 .87889 m .71878 .87887 L .71878 .87886 L closepath p 0 0 0 r
F P
0 g
s
.71883 .12116 m .71875 .12112 L .71876 .12112 L p 0 .447 .864 r
F P
0 g
s
.71876 .12112 m .71883 .12116 L .71883 .12116 L p 0 .447 .864 r
F P
0 g
s
.71874 .12111 m .71867 .12107 L .71867 .12107 L p .002 .449 .865 r
F P
0 g
s
.71867 .12107 m .71874 .12111 L .71875 .12111 L p .002 .449 .865 r
F P
0 g
s
.71875 .87889 m .71871 .87891 L .71871 .8789 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71878 .87886 L .71879 .87886 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .50001 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .5 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49999 L closepath p .949 .775 .317 r
F P
0 g
s
.71875 .87889 m .71871 .87891 L .71871 .87891 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87886 L .71879 .87886 L closepath p 0 0 0 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .317 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .317 r
F P
0 g
s
.71883 .12116 m .71876 .12112 L .71876 .12112 L p 0 .446 .863 r
F P
0 g
s
.71876 .12112 m .71883 .12116 L .71883 .12116 L p 0 .446 .863 r
F P
0 g
s
.71833 .12087 m .71867 .12107 L .71867 .12107 L p .003 .452 .866 r
F P
0 g
s
.71874 .12111 m .71867 .12107 L .71867 .12107 L p .001 .448 .864 r
F P
0 g
s
.71867 .12107 m .71874 .12111 L .71874 .12111 L p .002 .449 .865 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71871 .87891 L .71871 .87891 L closepath p 0 0 0 r
F P
0 g
s
.7194 .87852 m .71879 .87886 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87886 L .71879 .87886 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .50033 m .0625 .50002 L .0625 .50002 L p .949 .773 .315 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71867 .12107 m .71874 .12111 L .71874 .12111 L p .001 .448 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71874 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .87889 m .71875 .87889 L .71874 .8789 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71876 .87889 L .71875 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71877 .87888 L .71876 .87889 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71878 .87888 L .71877 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71878 .87887 L .71878 .87888 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87887 L .71878 .87887 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87887 L .71879 .87887 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71879 .87886 L .71879 .87887 L closepath p 0 0 0 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71874 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49998 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49998 L closepath p .949 .775 .316 r
F P
0 g
s
.0625 .5 m .0625 .49999 L .0625 .49999 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .49999 L closepath p .948 .774 .316 r
F P
0 g
s
.71875 .12111 m .71876 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71876 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12112 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12112 L closepath p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71875 .12111 L .71875 .12111 L closepath p 0 .447 .864 r
F P
0 g
s
.45427 .9351 m
.5 .9375 L
s
.40904 .92794 m
.45427 .9351 L
s
.36481 .91609 m
.40904 .92794 L
s
.32205 .89968 m
.36481 .91609 L
s
.28125 .87889 m
.32205 .89968 L
s
.24284 .85394 m
.28125 .87889 L
s
.20726 .82513 m
.24284 .85394 L
s
.17487 .79274 m
.20726 .82513 L
s
.14606 .75716 m
.17487 .79274 L
s
.12111 .71875 m
.14606 .75716 L
s
.10032 .67795 m
.12111 .71875 L
s
.08391 .63519 m
.10032 .67795 L
s
.07206 .59096 m
.08391 .63519 L
s
.0649 .54573 m
.07206 .59096 L
s
.0632 .51332 m
.0649 .54573 L
s
.0632 .48673 m
.0649 .45427 L
s
.0649 .45427 m
.07206 .40904 L
s
.08391 .36481 m
.07206 .40904 L
s
.10032 .32205 m
.08391 .36481 L
s
.12111 .28125 m
.10032 .32205 L
s
.14606 .24284 m
.12111 .28125 L
s
.17487 .20726 m
.14606 .24284 L
s
.20726 .17487 m
.17487 .20726 L
s
.24284 .14606 m
.20726 .17487 L
s
.28125 .12111 m
.24284 .14606 L
s
.32205 .10032 m
.28125 .12111 L
s
.36481 .08391 m
.32205 .10032 L
s
.40904 .07206 m
.36481 .08391 L
s
.45427 .0649 m
.40904 .07206 L
s
.5 .0625 m
.45427 .0649 L
s
.54573 .9351 m
.5 .9375 L
s
.59096 .92794 m
.54573 .9351 L
s
.63519 .91609 m
.59096 .92794 L
s
.67795 .89968 m
.63519 .91609 L
s
.69834 .88929 m
.70576 .88551 L
s
.67795 .89968 m
.69834 .88929 L
s
.73098 .87095 m
.73774 .86655 L
s
.73774 .86655 m
.75716 .85394 L
s
.75716 .85394 m
.79274 .82513 L
s
.79274 .82513 m
.82513 .79274 L
s
.85394 .75716 m
.82513 .79274 L
s
.87889 .71875 m
.85394 .75716 L
s
.89968 .67795 m
.87889 .71875 L
s
.91609 .63519 m
.89968 .67795 L
s
.92794 .59096 m
.91609 .63519 L
s
.9351 .54573 m
.92794 .59096 L
s
.9375 .5 m
.9351 .54573 L
s
.9351 .45427 m
.9375 .5 L
s
.92794 .40904 m
.9351 .45427 L
s
.91609 .36481 m
.92794 .40904 L
s
.89968 .32205 m
.91609 .36481 L
s
.87889 .28125 m
.89968 .32205 L
s
.85394 .24284 m
.87889 .28125 L
s
.82513 .20726 m
.85394 .24284 L
s
.79274 .17487 m
.82513 .20726 L
s
.75716 .14606 m
.79274 .17487 L
s
.71875 .12111 m
.72523 .12532 L
s
.72656 .12618 m
.72801 .12712 L
s
.72801 .12712 m
.73257 .13009 L
s
.73257 .13009 m
.75716 .14606 L
s
.71187 .11761 m
.71875 .12111 L
s
.70894 .11612 m
.71045 .11689 L
s
.69727 .11017 m
.70894 .11612 L
s
.67795 .10032 m
.69727 .11017 L
s
.63519 .08391 m
.67795 .10032 L
s
.59096 .07206 m
.63519 .08391 L
s
.54573 .0649 m
.59096 .07206 L
s
.5 .0625 m
.54573 .0649 L
s
.71875 .87889 m .71871 .87891 L .71871 .87891 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .87891 L .71871 .87891 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71872 .87891 L .71872 .87891 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71873 .8789 L .71872 .87891 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .8789 L .71873 .8789 L closepath p 0 0 0 r
F P
0 g
s
.71875 .87889 m .71874 .8789 L .71874 .8789 L closepath p 0 0 0 r
F P
0 g
s
.70752 .88461 m
.71875 .87889 L
s
.71875 .87889 m
.7293 .87203 L
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50002 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50002 L .0625 .50001 L closepath p .949 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .50001 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .50001 L .0625 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m .0625 .5 L .0625 .5 L closepath p .948 .774 .316 r
F P
0 g
s
.0625 .5 m
.06298 .50911 L
s
.0625 .5 m
.06298 .49083 L
s
.71867 .12107 m .71875 .12111 L .71874 .12111 L p 0 .448 .864 r
F P
0 g
s
.71874 .12111 m .71867 .12107 L .71867 .12107 L p 0 .448 .864 r
F P
0 g
s
.71883 .12116 m .71876 .12112 L .71876 .12112 L p 0 .446 .863 r
F P
0 g
s
.71868 .12107 m .71875 .12111 L .71875 .12111 L p 0 .447 .864 r
F P
0 g
s
.71875 .12111 m .71867 .12107 L .71868 .12107 L p 0 .447 .864 r
F P
0 g
s
.71876 .12112 m .71883 .12116 L .71883 .12116 L p 0 .446 .863 r
F P
0 g
s
.71883 .12116 m .71876 .12112 L .71875 .12112 L p 0 .445 .863 r
F P
0 g
s
.0625 .49967 m .0625 .49998 L .0625 .49998 L p .948 .775 .317 r
F P
0 g
s
.06249 .50032 m .0625 .50002 L .0625 .50002 L p .948 .773 .313 r
F P
0 g
s
.0625 .50002 m .0625 .50033 L .06249 .50032 L p .948 .773 .313 r
F P
0 g
s
.71869 .12107 m .71875 .12111 L .71875 .12111 L p 0 .447 .863 r
F P
0 g
s
.71875 .12111 m .71868 .12107 L .71869 .12107 L p 0 .447 .863 r
F P
0 g
s
.71875 .12112 m .71883 .12115 L .71883 .12116 L p 0 .445 .863 r
F P
0 g
s
.71883 .12115 m .71875 .12112 L .71875 .12112 L p 0 .445 .863 r
F P
0 g
s
.71871 .12108 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71869 .12107 L .71871 .12108 L p 0 .446 .863 r
F P
0 g
s
.71875 .12112 m .71882 .12114 L .71883 .12115 L p 0 .445 .863 r
F P
0 g
s
.71882 .12114 m .71875 .12112 L .71875 .12112 L p 0 .445 .862 r
F P
0 g
s
.71872 .12108 m .71875 .12111 L .71875 .12111 L p 0 .446 .863 r
F P
0 g
s
.71875 .12111 m .71871 .12108 L .71872 .12108 L p 0 .446 .863 r
F P
0 g
s
.71875 .12112 m .7188 .12113 L .71882 .12114 L p 0 .445 .862 r
F P
0 g
s
.7188 .12113 m .71875 .12112 L .71875 .12111 L p 0 .445 .862 r
F P
0 g
s
.71938 .87855 m .71879 .87887 L .71879 .87886 L p 0 0 0 r
F P
0 g
s
.71879 .87886 m .7194 .87852 L .71938 .87855 L p 0 0 0 r
F P
0 g
s
.7181 .87927 m .71871 .87891 L .71871 .87891 L p 0 0 0 r
F P
0 g
s
.71874 .12109 m .71875 .12111 L .71875 .12111 L p 0 .446 .862 r
F P
0 g
s
.71875 .12111 m .71872 .12108 L .71874 .12109 L p 0 .446 .862 r
F P
0 g
s
.71875 .12111 m .71879 .12112 L .7188 .12113 L p 0 .445 .862 r
F P
0 g
s
.71879 .12112 m .71875 .12111 L .71875 .12111 L p 0 .445 .862 r
F P
0 g
s
.71876 .1211 m .71875 .12111 L .71875 .12111 L p 0 .445 .862 r
F P
0 g
s
.71875 .12111 m .71874 .12109 L .71876 .1211 L p 0 .445 .862 r
F P
0 g
s
.71875 .12111 m .71877 .12111 L .71879 .12112 L p 0 .445 .862 r
F P
0 g
s
.71877 .12111 m .71875 .12111 L .71875 .12111 L p 0 .445 .862 r
F P
0 g
s
.71875 .12111 m .71876 .1211 L .71877 .12111 L p 0 .445 .862 r
F P
0 g
s
.0625 .49998 m .06249 .49968 L .0625 .49967 L p .948 .775 .317 r
F P
0 g
s
.06249 .49968 m .0625 .49998 L .0625 .49998 L p .948 .775 .316 r
F P
0 g
s
.06248 .50029 m .0625 .50002 L .0625 .50002 L p .948 .772 .312 r
F P
0 g
s
.0625 .50002 m .06249 .50032 L .06248 .50029 L p .948 .772 .312 r
F P
0 g
s
.71836 .12087 m .71867 .12107 L .71867 .12107 L p 0 .45 .864 r
F P
0 g
s
.71867 .12107 m .71833 .12087 L .71836 .12087 L p 0 .45 .864 r
F P
0 g
s
.71917 .12135 m .71883 .12116 L .71883 .12116 L p 0 .441 .861 r
F P
0 g
s
.0625 .49998 m .06248 .49971 L .06249 .49968 L p .948 .775 .316 r
F P
0 g
s
.06248 .49971 m .0625 .49998 L .0625 .49998 L p .947 .774 .314 r
F P
0 g
s
.06247 .50025 m .0625 .50002 L .0625 .50002 L p .947 .772 .312 r
F P
0 g
s
.0625 .50002 m .06248 .50029 L .06247 .50025 L p .947 .772 .312 r
F P
0 g
s
.0625 .49998 m .06247 .49975 L .06248 .49971 L p .947 .774 .314 r
F P
0 g
s
.06247 .49975 m .0625 .49998 L .0625 .49999 L p .947 .774 .313 r
F P
0 g
s
.06247 .5002 m .0625 .50001 L .0625 .50002 L p .947 .772 .311 r
F P
0 g
s
.0625 .50002 m .06247 .50025 L .06247 .5002 L p .947 .772 .311 r
F P
0 g
s
.71934 .8786 m .71879 .87887 L .71879 .87887 L p 0 0 0 r
F P
0 g
s
.71879 .87887 m .71938 .87855 L .71934 .8786 L p 0 0 0 r
F P
0 g
s
.71871 .87891 m .71814 .87927 L .7181 .87927 L p 0 0 0 r
F P
0 g
s
.71814 .87927 m .71871 .87891 L .71872 .87891 L p 0 0 0 r
F P
0 g
s
.0625 .49999 m .06247 .4998 L .06247 .49975 L p .947 .774 .313 r
F P
0 g
s
.06247 .4998 m .0625 .49999 L .0625 .49999 L p .946 .773 .312 r
F P
0 g
s
.06246 .50014 m .0625 .50001 L .0625 .50001 L p .946 .772 .311 r
F P
0 g
s
.0625 .50001 m .06247 .5002 L .06246 .50014 L p .946 .772 .311 r
F P
0 g
s
.0625 .49999 m .06246 .49986 L .06247 .4998 L p .946 .773 .312 r
F P
0 g
s
.06246 .49986 m .0625 .49999 L .0625 .5 L p .946 .773 .312 r
F P
0 g
s
.06246 .50007 m .0625 .5 L .0625 .50001 L p .946 .772 .31 r
F P
0 g
s
.0625 .50001 m .06246 .50014 L .06246 .50007 L p .946 .772 .31 r
F P
0 g
s
.0625 .5 m .06246 .49993 L .06246 .49986 L p .946 .773 .312 r
F P
0 g
s
.06246 .49993 m .0625 .5 L .0625 .5 L p .946 .772 .311 r
F P
0 g
s
.06246 .5 m .0625 .5 L .0625 .5 L p .946 .772 .311 r
F P
0 g
s
.0625 .5 m .06246 .50007 L .06246 .5 L p .946 .772 .311 r
F P
0 g
s
.0625 .5 m .06246 .5 L .06246 .49993 L p .946 .772 .311 r
F P
0 g
s
.71927 .87866 m .71878 .87887 L .71879 .87887 L p 0 0 0 r
F P
0 g
s
.71879 .87887 m .71934 .8786 L .71927 .87866 L p 0 0 0 r
F P
0 g
s
.71872 .87891 m .71821 .87925 L .71814 .87927 L p 0 0 0 r
F P
0 g
s
.71821 .87925 m .71872 .87891 L .71872 .87891 L p 0 0 0 r
F P
0 g
s
.7184 .12088 m .71868 .12107 L .71867 .12107 L p 0 .448 .863 r
F P
0 g
s
.71867 .12107 m .71836 .12087 L .7184 .12088 L p 0 .448 .863 r
F P
0 g
s
.71883 .12116 m .71916 .12133 L .71917 .12135 L p 0 .441 .861 r
F P
0 g
s
.71916 .12133 m .71883 .12116 L .71883 .12115 L p 0 .44 .859 r
F P
0 g
s
.71917 .87873 m .71878 .87888 L .71878 .87887 L p 0 0 0 r
F P
0 g
s
.71878 .87887 m .71927 .87866 L .71917 .87873 L p 0 0 0 r
F P
0 g
s
.71872 .87891 m .71829 .87922 L .71821 .87925 L p 0 0 0 r
F P
0 g
s
.71829 .87922 m .71872 .87891 L .71873 .8789 L p 0 0 0 r
F P
0 g
s
.0625 .49833 m .0625 .49967 L .06249 .49968 L p .946 .779 .319 r
F P
0 g
s
.06245 .5016 m .06249 .50032 L .0625 .50033 L p .946 .766 .303 r
F P
0 g
s
.0625 .50033 m .0625 .50167 L .06245 .5016 L p .946 .766 .303 r
F P
0 g
s
.71906 .8788 m .71877 .87888 L .71878 .87888 L p 0 0 0 r
F P
0 g
s
.71878 .87888 m .71917 .87873 L .71906 .8788 L p 0 0 0 r
F P
0 g
s
.71873 .8789 m .7184 .87917 L .71829 .87922 L p 0 0 0 r
F P
0 g
s
.7184 .87917 m .71873 .8789 L .71874 .8789 L p 0 0 0 r
F P
0 g
s
.71893 .87889 m .71876 .87889 L .71877 .87888 L p 0 0 0 r
F P
0 g
s
.71877 .87888 m .71906 .8788 L .71893 .87889 L p 0 0 0 r
F P
0 g
s
.71874 .8789 m .71853 .87911 L .7184 .87917 L p 0 0 0 r
F P
0 g
s
.71853 .87911 m .71874 .8789 L .71874 .8789 L p 0 0 0 r
F P
0 g
s
.7188 .87897 m .71875 .87889 L .71876 .87889 L p 0 0 0 r
F P
0 g
s
.71876 .87889 m .71893 .87889 L .7188 .87897 L p 0 0 0 r
F P
0 g
s
.71874 .8789 m .71866 .87904 L .71853 .87911 L p 0 0 0 r
F P
0 g
s
.71866 .87904 m .71874 .8789 L .71875 .87889 L p 0 0 0 r
F P
0 g
s
.71875 .87889 m .7188 .87897 L .71866 .87904 L p 0 0 0 r
F P
0 g
s
.71846 .1209 m .71869 .12107 L .71868 .12107 L p 0 .446 .861 r
F P
0 g
s
.71868 .12107 m .7184 .12088 L .71846 .1209 L p 0 .446 .861 r
F P
0 g
s
.71883 .12115 m .71913 .1213 L .71916 .12133 L p 0 .44 .859 r
F P
0 g
s
.71913 .1213 m .71883 .12115 L .71882 .12114 L p 0 .439 .858 r
F P
0 g
s
.71751 .12035 m .71836 .12087 L .71833 .12087 L p 0 .454 .865 r
F P
0 g
s
.71833 .12087 m .71743 .12035 L .71751 .12035 L p 0 .454 .865 r
F P
0 g
s
.72007 .12188 m .71917 .12135 L .71916 .12133 L p 0 .43 .854 r
F P
0 g
s
.71853 .12093 m .71871 .12108 L .71869 .12107 L p 0 .444 .86 r
F P
0 g
s
.71869 .12107 m .71846 .1209 L .71853 .12093 L p 0 .444 .86 r
F P
0 g
s
.71882 .12114 m .71908 .12126 L .71913 .1213 L p 0 .439 .858 r
F P
0 g
s
.71908 .12126 m .71882 .12114 L .7188 .12113 L p 0 .438 .857 r
F P
0 g
s
.71861 .12097 m .71872 .12108 L .71871 .12108 L p 0 .442 .859 r
F P
0 g
s
.71871 .12108 m .71853 .12093 L .71861 .12097 L p 0 .442 .859 r
F P
0 g
s
.7188 .12113 m .71902 .12122 L .71908 .12126 L p 0 .438 .857 r
F P
0 g
s
.71902 .12122 m .7188 .12113 L .71879 .12112 L p 0 .438 .857 r
F P
0 g
s
.72193 .87715 m .71938 .87855 L .7194 .87852 L p 0 0 0 r
F P
0 g
s
.7194 .87852 m .72202 .87698 L .72193 .87715 L p 0 0 0 r
F P
0 g
s
.71546 .88077 m .7181 .87927 L .71814 .87927 L p 0 0 0 r
F P
0 g
s
.71869 .12101 m .71874 .12109 L .71872 .12108 L p 0 .44 .858 r
F P
0 g
s
.71872 .12108 m .71861 .12097 L .71869 .12101 L p 0 .44 .858 r
F P
0 g
s
.71879 .12112 m .71895 .12117 L .71902 .12122 L p 0 .438 .857 r
F P
0 g
s
.71895 .12117 m .71879 .12112 L .71877 .12111 L p 0 .438 .856 r
F P
0 g
s
.71878 .12106 m .71876 .1211 L .71874 .12109 L p 0 .439 .857 r
F P
0 g
s
.71874 .12109 m .71869 .12101 L .71878 .12106 L p 0 .439 .857 r
F P
0 g
s
.71877 .12111 m .71887 .12112 L .71895 .12117 L p 0 .438 .856 r
F P
0 g
s
.71887 .12112 m .71877 .12111 L .71876 .1211 L p 0 .438 .856 r
F P
0 g
s
.71876 .1211 m .71878 .12106 L .71887 .12112 L p 0 .438 .856 r
F P
0 g
s
.06249 .49968 m .06245 .4984 L .0625 .49833 L p .946 .779 .319 r
F P
0 g
s
.06245 .4984 m .06249 .49968 L .06248 .49971 L p .943 .776 .313 r
F P
0 g
s
.06241 .50146 m .06248 .50029 L .06249 .50032 L p .943 .764 .299 r
F P
0 g
s
.06249 .50032 m .06245 .5016 L .06241 .50146 L p .943 .764 .299 r
F P
0 g
s
.71764 .12038 m .7184 .12088 L .71836 .12087 L p 0 .449 .86 r
F P
0 g
s
.71836 .12087 m .71751 .12035 L .71764 .12038 L p 0 .449 .86 r
F P
0 g
s
.71916 .12133 m .72003 .12181 L .72007 .12188 L p 0 .43 .854 r
F P
0 g
s
.72003 .12181 m .71916 .12133 L .71913 .1213 L p 0 .426 .85 r
F P
0 g
s
.71569 .1193 m .71751 .12035 L .71743 .12035 L p 0 .463 .866 r
F P
0 g
s
.71743 .12035 m .7155 .1193 L .71569 .1193 L p 0 .463 .866 r
F P
0 g
s
.72195 .12303 m .72007 .12188 L .72003 .12181 L p 0 .409 .842 r
F P
0 g
s
.06248 .49971 m .06241 .49854 L .06245 .4984 L p .943 .776 .313 r
F P
0 g
s
.06241 .49854 m .06248 .49971 L .06247 .49975 L p .941 .774 .308 r
F P
0 g
s
.06238 .50125 m .06247 .50025 L .06248 .50029 L p .941 .763 .295 r
F P
0 g
s
.06248 .50029 m .06241 .50146 L .06238 .50125 L p .941 .763 .295 r
F P
0 g
s
.06258 .49473 m .0625 .49833 L .06245 .4984 L p .94 .786 .323 r
F P
0 g
s
.06244 .50506 m .06245 .5016 L .0625 .50167 L p .94 .749 .277 r
F P
0 g
s
.0625 .50167 m .06258 .50529 L .06244 .50506 L p .94 .749 .277 r
F P
0 g
s
.06247 .49975 m .06238 .49875 L .06241 .49854 L p .941 .774 .308 r
F P
0 g
s
.06238 .49875 m .06247 .49975 L .06247 .4998 L p .939 .771 .303 r
F P
0 g
s
.06235 .50099 m .06247 .5002 L .06247 .50025 L p .939 .762 .292 r
F P
0 g
s
.06247 .50025 m .06238 .50125 L .06235 .50099 L p .939 .762 .292 r
F P
0 g
s
.72169 .87739 m .71934 .8786 L .71938 .87855 L p 0 0 0 r
F P
0 g
s
.71938 .87855 m .72193 .87715 L .72169 .87739 L p 0 0 0 r
F P
0 g
s
.71814 .87927 m .71565 .88077 L .71546 .88077 L p 0 0 0 r
F P
0 g
s
.71565 .88077 m .71814 .87927 L .71821 .87925 L p 0 0 0 r
F P
0 g
s
.71782 .12045 m .71846 .1209 L .7184 .12088 L p 0 .443 .856 r
F P
0 g
s
.7184 .12088 m .71764 .12038 L .71782 .12045 L p 0 .443 .856 r
F P
0 g
s
.71913 .1213 m .71994 .12171 L .72003 .12181 L p 0 .426 .85 r
F P
0 g
s
.71994 .12171 m .71913 .1213 L .71908 .12126 L p 0 .423 .847 r
F P
0 g
s
.06247 .4998 m .06235 .49901 L .06238 .49875 L p .939 .771 .303 r
F P
0 g
s
.06235 .49901 m .06247 .4998 L .06246 .49986 L p .937 .768 .298 r
F P
0 g
s
.06233 .50068 m .06246 .50014 L .06247 .5002 L p .937 .762 .29 r
F P
0 g
s
.06247 .5002 m .06235 .50099 L .06233 .50068 L p .937 .762 .29 r
F P
0 g
s
.06246 .49986 m .06233 .49931 L .06235 .49901 L p .937 .768 .298 r
F P
0 g
s
.06233 .49931 m .06246 .49986 L .06246 .49993 L p .936 .766 .294 r
F P
0 g
s
.06231 .50035 m .06246 .50007 L .06246 .50014 L p .936 .762 .289 r
F P
0 g
s
.06246 .50014 m .06233 .50068 L .06231 .50035 L p .936 .762 .289 r
F P
0 g
s
.71804 .12055 m .71853 .12093 L .71846 .1209 L p 0 .437 .852 r
F P
0 g
s
.71846 .1209 m .71782 .12045 L .71804 .12055 L p 0 .437 .852 r
F P
0 g
s
.71908 .12126 m .71979 .12159 L .71994 .12171 L p 0 .423 .847 r
F P
0 g
s
.71979 .12159 m .71908 .12126 L .71902 .12122 L p 0 .42 .844 r
F P
0 g
s
.06246 .49993 m .06231 .49965 L .06233 .49931 L p .936 .766 .294 r
F P
0 g
s
.06231 .49965 m .06246 .49993 L .06246 .5 L p .935 .764 .292 r
F P
0 g
s
.06231 .5 m .06246 .5 L .06246 .50007 L p .935 .763 .29 r
F P
0 g
s
.06246 .50007 m .06231 .50035 L .06231 .5 L p .935 .763 .29 r
F P
0 g
s
.06246 .5 m .06231 .5 L .06231 .49965 L p .935 .764 .292 r
F P
0 g
s
.72133 .87769 m .71927 .87866 L .71934 .8786 L p 0 0 0 r
F P
0 g
s
.71934 .8786 m .72169 .87739 L .72133 .87769 L p 0 0 0 r
F P
0 g
s
.71821 .87925 m .71598 .88069 L .71565 .88077 L p 0 0 0 r
F P
0 g
s
.71598 .88069 m .71821 .87925 L .71829 .87922 L p 0 0 0 r
F P
0 g
s
.71232 .11752 m .71569 .1193 L .7155 .1193 L p .001 .477 .866 r
F P
0 g
s
.7155 .1193 m .71194 .11753 L .71232 .11752 L p .001 .477 .866 r
F P
0 g
s
.72527 .12523 m .72195 .12303 L .72185 .12286 L p 0 .372 .819 r
F P
0 g
s
.72003 .12181 m .72185 .12286 L .72195 .12303 L p 0 .409 .842 r
F P
0 g
s
.71829 .12067 m .71861 .12097 L .71853 .12093 L p 0 .432 .848 r
F P
0 g
s
.71853 .12093 m .71804 .12055 L .71829 .12067 L p 0 .432 .848 r
F P
0 g
s
.71902 .12122 m .7196 .12145 L .71979 .12159 L p 0 .42 .844 r
F P
0 g
s
.7196 .12145 m .71902 .12122 L .71895 .12117 L p 0 .419 .842 r
F P
0 g
s
.72857 .8731 m .72193 .87715 L .72202 .87698 L p 0 0 0 r
F P
0 g
s
.72202 .87698 m .72886 .87258 L .72857 .8731 L p 0 0 0 r
F P
0 g
s
.70819 .88451 m .71546 .88077 L .71565 .88077 L p .001 0 0 r
F P
0 g
s
.71856 .12081 m .71869 .12101 L .71861 .12097 L p 0 .427 .845 r
F P
0 g
s
.71861 .12097 m .71829 .12067 L .71856 .12081 L p 0 .427 .845 r
F P
0 g
s
.71895 .12117 m .71937 .12129 L .7196 .12145 L p 0 .419 .842 r
F P
0 g
s
.71937 .12129 m .71895 .12117 L .71887 .12112 L p 0 .42 .841 r
F P
0 g
s
.71601 .11938 m .71764 .12038 L .71751 .12035 L p 0 .45 .855 r
F P
0 g
s
.71751 .12035 m .71569 .1193 L .71601 .11938 L p 0 .45 .855 r
F P
0 g
s
.72185 .12286 m .72003 .12181 L .71994 .12171 L p 0 .399 .832 r
F P
0 g
s
.71884 .12097 m .71878 .12106 L .71869 .12101 L p 0 .424 .843 r
F P
0 g
s
.71869 .12101 m .71856 .12081 L .71884 .12097 L p 0 .424 .843 r
F P
0 g
s
.71887 .12112 m .71911 .12113 L .71937 .12129 L p 0 .42 .841 r
F P
0 g
s
.71911 .12113 m .71887 .12112 L .71878 .12106 L p 0 .421 .841 r
F P
0 g
s
.71878 .12106 m .71884 .12097 L .71911 .12113 L p 0 .421 .841 r
F P
0 g
s
.72085 .87805 m .71917 .87873 L .71927 .87866 L p 0 0 0 r
F P
0 g
s
.71927 .87866 m .72133 .87769 L .72085 .87805 L p 0 0 0 r
F P
0 g
s
.71829 .87922 m .71643 .88052 L .71598 .88069 L p 0 0 0 r
F P
0 g
s
.71643 .88052 m .71829 .87922 L .7184 .87917 L p 0 0 0 r
F P
0 g
s
.06245 .4984 m .06244 .49496 L .06258 .49473 L p .94 .786 .323 r
F P
0 g
s
.06244 .49496 m .06245 .4984 L .06241 .49854 L p .932 .778 .307 r
F P
0 g
s
.06232 .5046 m .06241 .50146 L .06245 .5016 L p .932 .743 .263 r
F P
0 g
s
.06245 .5016 m .06244 .50506 L .06232 .5046 L p .932 .743 .263 r
F P
0 g
s
.06312 .4872 m .06258 .49473 L .06244 .49496 L p .926 .8 .332 r
F P
0 g
s
.0628 .51233 m .06244 .50506 L .06258 .50529 L p .926 .712 .224 r
F P
0 g
s
.06258 .50529 m .06313 .51289 L .0628 .51233 L p .926 .712 .224 r
F P
0 g
s
.72028 .87843 m .71906 .8788 L .71917 .87873 L p 0 0 0 r
F P
0 g
s
.71917 .87873 m .72085 .87805 L .72028 .87843 L p 0 0 0 r
F P
0 g
s
.7184 .87917 m .71697 .88029 L .71643 .88052 L p 0 0 0 r
F P
0 g
s
.71697 .88029 m .7184 .87917 L .71853 .87911 L p 0 0 0 r
F P
0 g
s
.71964 .87884 m .71893 .87889 L .71906 .8788 L p 0 0 0 r
F P
0 g
s
.71906 .8788 m .72028 .87843 L .71964 .87884 L p 0 0 0 r
F P
0 g
s
.71853 .87911 m .7176 .87998 L .71697 .88029 L p 0 0 0 r
F P
0 g
s
.7176 .87998 m .71853 .87911 L .71866 .87904 L p 0 0 0 r
F P
0 g
s
.71896 .87924 m .7188 .87897 L .71893 .87889 L p 0 0 0 r
F P
0 g
s
.71893 .87889 m .71964 .87884 L .71896 .87924 L p 0 0 0 r
F P
0 g
s
.71866 .87904 m .71827 .87963 L .7176 .87998 L p 0 0 0 r
F P
0 g
s
.71827 .87963 m .71866 .87904 L .7188 .87897 L p 0 0 0 r
F P
0 g
s
.7188 .87897 m .71896 .87924 L .71827 .87963 L p 0 0 0 r
F P
0 g
s
.71644 .11954 m .71782 .12045 L .71764 .12038 L p 0 .437 .844 r
F P
0 g
s
.71764 .12038 m .71601 .11938 L .71644 .11954 L p 0 .437 .844 r
F P
0 g
s
.71994 .12171 m .72162 .12262 L .72185 .12286 L p 0 .399 .832 r
F P
0 g
s
.72162 .12262 m .71994 .12171 L .71979 .12159 L p 0 .391 .824 r
F P
0 g
s
.70666 .11493 m .71232 .11752 L .71194 .11753 L p .002 .497 .864 r
F P
0 g
s
.71194 .11753 m .70595 .11494 L .70666 .11493 L p .002 .497 .864 r
F P
0 g
s
.73053 .12914 m .72527 .12523 L .72508 .12489 L p 0 .313 .781 r
F P
0 g
s
.72185 .12286 m .72508 .12489 L .72527 .12523 L p 0 .372 .819 r
F P
0 g
s
.06241 .49854 m .06232 .4954 L .06244 .49496 L p .932 .778 .307 r
F P
0 g
s
.06232 .4954 m .06241 .49854 L .06238 .49875 L p .923 .77 .29 r
F P
0 g
s
.0622 .50395 m .06238 .50125 L .06241 .50146 L p .923 .738 .251 r
F P
0 g
s
.06241 .50146 m .06232 .5046 L .0622 .50395 L p .923 .738 .251 r
F P
0 g
s
.71698 .11978 m .71804 .12055 L .71782 .12045 L p 0 .423 .834 r
F P
0 g
s
.71782 .12045 m .71644 .11954 L .71698 .11978 L p 0 .423 .834 r
F P
0 g
s
.71979 .12159 m .72126 .12233 L .72162 .12262 L p 0 .391 .824 r
F P
0 g
s
.72126 .12233 m .71979 .12159 L .7196 .12145 L p 0 .385 .817 r
F P
0 g
s
.06238 .49875 m .06221 .49605 L .06232 .4954 L p .923 .77 .29 r
F P
0 g
s
.06221 .49605 m .06238 .49875 L .06235 .49901 L p .916 .761 .274 r
F P
0 g
s
.06211 .50312 m .06235 .50099 L .06238 .50125 L p .916 .735 .241 r
F P
0 g
s
.06238 .50125 m .0622 .50395 L .06211 .50312 L p .916 .735 .241 r
F P
0 g
s
.71298 .11769 m .71601 .11938 L .71569 .1193 L p 0 .452 .844 r
F P
0 g
s
.71569 .1193 m .71232 .11752 L .71298 .11769 L p 0 .452 .844 r
F P
0 g
s
.72508 .12489 m .72185 .12286 L .72162 .12262 L p 0 .351 .799 r
F P
0 g
s
.72785 .87385 m .72169 .87739 L .72193 .87715 L p 0 0 0 r
F P
0 g
s
.72193 .87715 m .72857 .8731 L .72785 .87385 L p 0 0 0 r
F P
0 g
s
.71565 .88077 m .70879 .88452 L .70819 .88451 L p .001 0 0 r
F P
0 g
s
.70879 .88452 m .71565 .88077 L .71598 .88069 L p 0 0 0 r
F P
0 g
s
.71759 .12007 m .71829 .12067 L .71804 .12055 L p 0 .411 .824 r
F P
0 g
s
.71804 .12055 m .71698 .11978 L .71759 .12007 L p 0 .411 .824 r
F P
0 g
s
.7196 .12145 m .72079 .12198 L .72126 .12233 L p 0 .385 .817 r
F P
0 g
s
.72079 .12198 m .7196 .12145 L .71937 .12129 L p 0 .382 .811 r
F P
0 g
s
.74162 .86343 m .72857 .8731 L .72886 .87258 L p 0 0 0 r
F P
0 g
s
.72886 .87258 m .74229 .8622 L .74162 .86343 L p 0 0 0 r
F P
0 g
s
.69224 .89103 m .70819 .88451 L .70879 .88452 L p .002 0 0 r
F P
0 g
s
.06521 .47382 m .06312 .4872 L .06279 .48774 L p .895 .819 .346 r
F P
0 g
s
.06244 .49496 m .06279 .48774 L .06312 .4872 L p .926 .8 .332 r
F P
0 g
s
.06461 .52543 m .0628 .51233 L .06313 .51289 L p .893 .639 .125 r
F P
0 g
s
.06313 .51289 m .0653 .52658 L .06461 .52543 L p .893 .639 .125 r
F P
0 g
s
.06235 .49901 m .06211 .49687 L .06221 .49605 L p .916 .761 .274 r
F P
0 g
s
.06211 .49687 m .06235 .49901 L .06233 .49931 L p .91 .753 .259 r
F P
0 g
s
.06204 .50216 m .06233 .50068 L .06235 .50099 L p .909 .733 .235 r
F P
0 g
s
.06235 .50099 m .06211 .50312 L .06204 .50216 L p .909 .733 .235 r
F P
0 g
s
.71825 .12042 m .71856 .12081 L .71829 .12067 L p 0 .4 .816 r
F P
0 g
s
.71829 .12067 m .71759 .12007 L .71825 .12042 L p 0 .4 .816 r
F P
0 g
s
.71937 .12129 m .72023 .1216 L .72079 .12198 L p 0 .382 .811 r
F P
0 g
s
.72023 .1216 m .71937 .12129 L .71911 .12113 L p 0 .382 .808 r
F P
0 g
s
.69776 .1117 m .70666 .11493 L .70595 .11494 L p .004 .524 .855 r
F P
0 g
s
.70595 .11494 m .69658 .11172 L .69776 .1117 L p .004 .524 .855 r
F P
0 g
s
.73806 .13571 m .73053 .12914 L .73018 .12852 L p 0 .223 .72 r
F P
0 g
s
.72508 .12489 m .73018 .12852 L .73053 .12914 L p 0 .313 .781 r
F P
0 g
s
.71893 .1208 m .71884 .12097 L .71856 .12081 L p 0 .391 .811 r
F P
0 g
s
.71856 .12081 m .71825 .12042 L .71893 .1208 L p 0 .391 .811 r
F P
0 g
s
.71911 .12113 m .7196 .1212 L .72023 .1216 L p 0 .382 .808 r
F P
0 g
s
.7196 .1212 m .71911 .12113 L .71884 .12097 L p 0 .385 .808 r
F P
0 g
s
.71884 .12097 m .71893 .1208 L .7196 .1212 L p 0 .385 .808 r
F P
0 g
s
.06233 .49931 m .06204 .49783 L .06211 .49687 L p .91 .753 .259 r
F P
0 g
s
.06204 .49783 m .06233 .49931 L .06231 .49965 L p .905 .745 .247 r
F P
0 g
s
.062 .5011 m .06231 .50035 L .06233 .50068 L p .905 .733 .232 r
F P
0 g
s
.06233 .50068 m .06204 .50216 L .062 .5011 L p .905 .733 .232 r
F P
0 g
s
.06279 .48774 m .06244 .49496 L .06232 .4954 L p .903 .78 .292 r
F P
0 g
s
.06249 .51123 m .06232 .5046 L .06244 .50506 L p .903 .695 .188 r
F P
0 g
s
.06244 .50506 m .0628 .51233 L .06249 .51123 L p .903 .695 .188 r
F P
0 g
s
.06231 .49965 m .062 .49889 L .06204 .49783 L p .905 .745 .247 r
F P
0 g
s
.062 .49889 m .06231 .49965 L .06231 .5 L p .903 .739 .239 r
F P
0 g
s
.06199 .49999 m .06231 .5 L .06231 .50035 L p .903 .735 .234 r
F P
0 g
s
.06231 .50035 m .062 .5011 L .06199 .49999 L p .903 .735 .234 r
F P
0 g
s
.06231 .5 m .06199 .49999 L .062 .49889 L p .903 .739 .239 r
F P
0 g
s
.71388 .11802 m .71644 .11954 L .71601 .11938 L p 0 .424 .82 r
F P
0 g
s
.71601 .11938 m .71298 .11769 L .71388 .11802 L p 0 .424 .82 r
F P
0 g
s
.72162 .12262 m .72461 .1244 L .72508 .12489 L p 0 .351 .799 r
F P
0 g
s
.72461 .1244 m .72162 .12262 L .72126 .12233 L p 0 .333 .779 r
F P
0 g
s
.72671 .8748 m .72133 .87769 L .72169 .87739 L p 0 0 0 r
F P
0 g
s
.72169 .87739 m .72785 .87385 L .72671 .8748 L p 0 0 0 r
F P
0 g
s
.71598 .88069 m .70982 .88426 L .70879 .88452 L p 0 0 0 r
F P
0 g
s
.70982 .88426 m .71598 .88069 L .71643 .88052 L p 0 0 0 r
F P
0 g
s
.70786 .11523 m .71298 .11769 L .71232 .11752 L p 0 .451 .82 r
F P
0 g
s
.71232 .11752 m .70666 .11493 L .70786 .11523 L p 0 .451 .82 r
F P
0 g
s
.73018 .12852 m .72508 .12489 L .72461 .1244 L p 0 .272 .74 r
F P
0 g
s
.71499 .1185 m .71698 .11978 L .71644 .11954 L p 0 .396 .796 r
F P
0 g
s
.71644 .11954 m .71388 .11802 L .71499 .1185 L p 0 .396 .796 r
F P
0 g
s
.68462 .10852 m .69776 .1117 L .69658 .11172 L p .007 .555 .83 r
F P
0 g
s
.69658 .11172 m .68282 .10856 L .68462 .10852 L p .007 .555 .83 r
F P
0 g
s
.72126 .12233 m .72386 .12378 L .72461 .1244 L p 0 .333 .779 r
F P
0 g
s
.72386 .12378 m .72126 .12233 L .72079 .12198 L p 0 .32 .762 r
F P
0 g
s
.50331 .49681 m .50589 .49957 L .50679 .49883 L p .107 .375 .836 r
F P
0 g
s
.50589 .49957 m .50816 .50279 L .50911 .50212 L p .059 .291 .779 r
F P
0 g
s
.50911 .50212 m .50679 .49883 L .50589 .49957 L p .059 .291 .779 r
F P
0 g
s
.50047 .49449 m .50331 .49681 L .50415 .49599 L p .157 .455 .883 r
F P
0 g
s
.50679 .49883 m .50415 .49599 L .50331 .49681 L p .107 .375 .836 r
F P
0 g
s
.74778 .14621 m .73806 .13571 L .73748 .13466 L p 0 .092 .621 r
F P
0 g
s
.73018 .12852 m .73748 .13466 L .73806 .13571 L p 0 .223 .72 r
F P
0 g
s
.50816 .50279 m .51005 .50651 L .51106 .50589 L p .015 .203 .713 r
F P
0 g
s
.51106 .50589 m .50911 .50212 L .50816 .50279 L p .015 .203 .713 r
F P
0 g
s
.72521 .87591 m .72085 .87805 L .72133 .87769 L p 0 0 0 r
F P
0 g
s
.72133 .87769 m .72671 .8748 L .72521 .87591 L p 0 0 0 r
F P
0 g
s
.49742 .49259 m .50047 .49449 L .50124 .49359 L p .21 .53 .922 r
F P
0 g
s
.50415 .49599 m .50124 .49359 L .50047 .49449 L p .157 .455 .883 r
F P
0 g
s
.71643 .88052 m .71123 .88374 L .70982 .88426 L p 0 0 0 r
F P
0 g
s
.71123 .88374 m .71643 .88052 L .71697 .88029 L p 0 0 0 r
F P
0 g
s
.51005 .50651 m .51148 .51077 L .51256 .51019 L p 0 .114 .639 r
F P
0 g
s
.51256 .51019 m .51106 .50589 L .51005 .50651 L p 0 .114 .639 r
F P
0 g
s
.49422 .49111 m .49742 .49259 L .49812 .49161 L p .264 .599 .951 r
F P
0 g
s
.50124 .49359 m .49812 .49161 L .49742 .49259 L p .21 .53 .922 r
F P
0 g
s
.06232 .4954 m .06249 .48882 L .06279 .48774 L p .903 .78 .292 r
F P
0 g
s
.06249 .48882 m .06232 .4954 L .06221 .49605 L p .879 .756 .25 r
F P
0 g
s
.4909 .49001 m .49422 .49111 L .49483 .49004 L p .318 .662 .973 r
F P
0 g
s
.49812 .49161 m .49483 .49004 L .49422 .49111 L p .264 .599 .951 r
F P
0 g
s
.06221 .50962 m .0622 .50395 L .06232 .5046 L p .878 .679 .155 r
F P
0 g
s
.06232 .5046 m .06249 .51123 L .06221 .50962 L p .878 .679 .155 r
F P
0 g
s
.51148 .51077 m .51237 .51564 L .51353 .51508 L p 0 .026 .557 r
F P
0 g
s
.51353 .51508 m .51256 .51019 L .51148 .51077 L p 0 .026 .557 r
F P
0 g
s
.49483 .49004 m .49142 .48887 L .4909 .49001 L p .318 .662 .973 r
F P
0 g
s
.48737 .48928 m .49089 .49001 L .49142 .48887 L p .371 .722 .988 r
F P
0 g
s
.07128 .453 m .06521 .47382 L .06455 .4749 L p .826 .835 .364 r
F P
0 g
s
.06279 .48774 m .06455 .4749 L .06521 .47382 L p .895 .819 .346 r
F P
0 g
s
.56194 .47978 m .56283 .48424 L .56397 .48397 L p .989 .726 .371 r
F P
0 g
s
.56397 .48397 m .56313 .47957 L .56194 .47978 L p .989 .726 .371 r
F P
0 g
s
.56557 .48839 m .56397 .48397 L .56283 .48424 L p .965 .639 .281 r
F P
0 g
s
.56173 .47537 m .56194 .47978 L .56313 .47957 L p .998 .801 .456 r
F P
0 g
s
.56313 .47957 m .56297 .47523 L .56173 .47537 L p .998 .801 .456 r
F P
0 g
s
.56283 .48424 m .56444 .48872 L .56557 .48839 L p .965 .639 .281 r
F P
0 g
s
.56803 .49284 m .56557 .48839 L .56444 .48872 L p .927 .541 .188 r
F P
0 g
s
.49142 .48887 m .4878 .48806 L .48737 .48928 L p .371 .722 .988 r
F P
0 g
s
.48355 .48892 m .48737 .48928 L .4878 .48806 L p .427 .776 .997 r
F P
0 g
s
.07053 .54618 m .06461 .52543 L .0653 .52658 L p .819 .504 0 r
F P
0 g
s
.0653 .52658 m .07178 .54825 L .07053 .54618 L p .819 .504 0 r
F P
0 g
s
.56213 .471 m .56173 .47537 L .56297 .47523 L p .995 .862 .534 r
F P
0 g
s
.56297 .47523 m .56344 .47094 L .56213 .471 L p .995 .862 .534 r
F P
0 g
s
.51237 .51564 m .51261 .52122 L .51387 .52066 L p 0 0 .47 r
F P
0 g
s
.51387 .52066 m .51353 .51508 L .51237 .51564 L p 0 0 .47 r
F P
0 g
s
.4878 .48806 m .48388 .48763 L .48355 .48892 L p .427 .776 .997 r
F P
0 g
s
.47943 .48901 m .48355 .48892 L .48388 .48763 L p .485 .826 .998 r
F P
0 g
s
.56444 .48872 m .56689 .49322 L .56803 .49284 L p .927 .541 .188 r
F P
0 g
s
.57147 .4973 m .56803 .49284 L .56689 .49322 L p .875 .435 .095 r
F P
0 g
s
.56311 .4667 m .56213 .471 L .56344 .47094 L p .981 .91 .604 r
F P
0 g
s
.56344 .47094 m .5645 .46673 L .56311 .4667 L p .981 .91 .604 r
F P
0 g
s
.76173 .84287 m .74162 .86343 L .74229 .8622 L p 0 0 0 r
F P
0 g
s
.74229 .8622 m .76297 .84052 L .76173 .84287 L p 0 0 0 r
F P
0 g
s
.48388 .48763 m .47965 .48764 L .47943 .48901 L p .485 .826 .998 r
F P
0 g
s
.47501 .4896 m .47943 .48901 L .47965 .48764 L p .543 .872 .993 r
F P
0 g
s
.71625 .11912 m .71759 .12007 L .71698 .11978 L p 0 .37 .774 r
F P
0 g
s
.71698 .11978 m .71499 .1185 L .71625 .11912 L p 0 .37 .774 r
F P
0 g
s
.72079 .12198 m .72289 .12306 L .72386 .12378 L p 0 .32 .762 r
F P
0 g
s
.72289 .12306 m .72079 .12198 L .72023 .1216 L p 0 .312 .748 r
F P
0 g
s
.66212 .89816 m .69224 .89103 L .69369 .89106 L p .006 0 0 r
F P
0 g
s
.70879 .88452 m .69369 .89106 L .69224 .89103 L p .002 0 0 r
F P
0 g
s
.56465 .46248 m .56311 .4667 L .5645 .46673 L p .96 .945 .666 r
F P
0 g
s
.5645 .46673 m .56611 .46262 L .56465 .46248 L p .96 .945 .666 r
F P
0 g
s
.72341 .87713 m .72028 .87843 L .72085 .87805 L p 0 0 0 r
F P
0 g
s
.72085 .87805 m .72521 .87591 L .72341 .87713 L p 0 0 0 r
F P
0 g
s
.71697 .88029 m .71296 .88298 L .71123 .88374 L p 0 0 0 r
F P
0 g
s
.71296 .88298 m .71697 .88029 L .7176 .87998 L p 0 0 0 r
F P
0 g
s
.51261 .52122 m .51203 .52765 L .51344 .52708 L p 0 0 .381 r
F P
0 g
s
.51344 .52708 m .51387 .52066 L .51261 .52122 L p 0 0 .381 r
F P
0 g
s
.56689 .49322 m .57029 .49774 L .57147 .4973 L p .875 .435 .095 r
F P
0 g
s
.57609 .50179 m .57147 .4973 L .57029 .49774 L p .811 .325 .005 r
F P
0 g
s
.47965 .48764 m .47512 .48817 L .47501 .4896 L p .543 .872 .993 r
F P
0 g
s
.47029 .4908 m .47501 .4896 L .47512 .48817 L p .6 .911 .98 r
F P
0 g
s
.5667 .45835 m .56465 .46248 L .56611 .46262 L p .932 .97 .719 r
F P
0 g
s
.47512 .48817 m .47029 .48929 L .47029 .4908 L p .6 .911 .98 r
F P
0 g
s
.46526 .4927 m .47029 .4908 L .47029 .48929 L p .654 .943 .961 r
F P
0 g
s
.71762 .11983 m .71825 .12042 L .71759 .12007 L p 0 .346 .756 r
F P
0 g
s
.71759 .12007 m .71625 .11912 L .71762 .11983 L p 0 .346 .756 r
F P
0 g
s
.72023 .1216 m .72172 .12227 L .72289 .12306 L p 0 .312 .748 r
F P
0 g
s
.72172 .12227 m .72023 .1216 L .7196 .1212 L p 0 .311 .74 r
F P
0 g
s
.57029 .49774 m .57484 .50229 L .57609 .50179 L p .811 .325 .005 r
F P
0 g
s
.58217 .50631 m .57609 .50179 L .57484 .50229 L p .742 .219 0 r
F P
0 g
s
.51203 .52765 m .51046 .53516 L .51206 .53455 L p 0 0 .295 r
F P
0 g
s
.51206 .53455 m .51344 .52708 L .51203 .52765 L p 0 0 .295 r
F P
0 g
s
.72139 .87841 m .71964 .87884 L .72028 .87843 L p 0 0 0 r
F P
0 g
s
.72028 .87843 m .72341 .87713 L .72139 .87841 L p 0 0 0 r
F P
0 g
s
.7176 .87998 m .71493 .88203 L .71296 .88298 L p 0 0 0 r
F P
0 g
s
.71493 .88203 m .7176 .87998 L .71827 .87963 L p 0 0 0 r
F P
0 g
s
.56925 .45434 m .5667 .45835 L .56825 .45862 L p .901 .986 .765 r
F P
0 g
s
.06221 .49605 m .06222 .49039 L .06249 .48882 L p .879 .756 .25 r
F P
0 g
s
.06222 .49039 m .06221 .49605 L .06211 .49687 L p .855 .73 .209 r
F P
0 g
s
.47029 .48929 m .46516 .4911 L .46526 .4927 L p .654 .943 .961 r
F P
0 g
s
.45991 .49542 m .46526 .4927 L .46516 .4911 L p .704 .968 .935 r
F P
0 g
s
.06199 .5076 m .06211 .50312 L .0622 .50395 L p .854 .665 .129 r
F P
0 g
s
.0622 .50395 m .06221 .50962 L .06199 .5076 L p .854 .665 .129 r
F P
0 g
s
.71903 .12062 m .71893 .1208 L .71825 .12042 L p 0 .328 .744 r
F P
0 g
s
.71825 .12042 m .71762 .11983 L .71903 .12062 L p 0 .328 .744 r
F P
0 g
s
.7196 .1212 m .72041 .12145 L .72172 .12227 L p 0 .311 .74 r
F P
0 g
s
.72041 .12145 m .7196 .1212 L .71893 .1208 L p 0 .316 .738 r
F P
0 g
s
.7399 .86522 m .72785 .87385 L .72857 .8731 L p 0 0 0 r
F P
0 g
s
.72857 .8731 m .74162 .86343 L .7399 .86522 L p 0 0 0 r
F P
0 g
s
.46692 .4077 m .46219 .41023 L .46282 .41167 L p .215 0 0 r
F P
0 g
s
.46219 .41023 m .45697 .41218 L .45751 .41363 L p .276 0 0 r
F P
0 g
s
.45751 .41363 m .46282 .41167 L .46219 .41023 L p .276 0 0 r
F P
0 g
s
.45697 .41218 m .45123 .41348 L .4517 .41495 L p .339 0 0 r
F P
0 g
s
.4517 .41495 m .45751 .41363 L .45697 .41218 L p .339 0 0 r
F P
0 g
s
.71924 .87969 m .71896 .87924 L .71964 .87884 L p 0 0 0 r
F P
0 g
s
.71964 .87884 m .72139 .87841 L .71924 .87969 L p 0 0 0 r
F P
0 g
s
.69369 .89106 m .70879 .88452 L .70982 .88426 L p 0 0 0 r
F P
0 g
s
.71827 .87963 m .71706 .88091 L .71493 .88203 L p 0 0 0 r
F P
0 g
s
.71706 .88091 m .71827 .87963 L .71896 .87924 L p 0 0 0 r
F P
0 g
s
.57238 .45031 m .56925 .45434 L .57087 .45474 L p .868 .995 .798 r
F P
0 g
s
.47118 .40464 m .46692 .4077 L .46765 .40912 L p .157 0 .034 r
F P
0 g
s
.46282 .41167 m .46765 .40912 L .46692 .4077 L p .215 0 0 r
F P
0 g
s
.71893 .1208 m .71903 .12062 L .72041 .12145 L p 0 .316 .738 r
F P
0 g
s
.71896 .87924 m .71924 .87969 L .71706 .88091 L p 0 0 0 r
F P
0 g
s
.47501 .4011 m .47118 .40464 L .47204 .40605 L p .102 0 .074 r
F P
0 g
s
.46765 .40912 m .47204 .40605 L .47118 .40464 L p .157 0 .034 r
F P
0 g
s
.44532 .41555 m .4517 .41495 L .45123 .41348 L p .401 0 0 r
F P
0 g
s
.46516 .4911 m .45971 .49371 L .45991 .49542 L p .704 .968 .935 r
F P
0 g
s
.45419 .4991 m .45991 .49542 L .45971 .49371 L p .748 .985 .904 r
F P
0 g
s
.70952 .11584 m .71388 .11802 L .71298 .11769 L p 0 .398 .77 r
F P
0 g
s
.71298 .11769 m .70786 .11523 L .70952 .11584 L p 0 .398 .77 r
F P
0 g
s
.72461 .1244 m .72931 .12761 L .73018 .12852 L p 0 .272 .74 r
F P
0 g
s
.72931 .12761 m .72461 .1244 L .72386 .12378 L p 0 .236 .697 r
F P
0 g
s
.57484 .50229 m .58079 .5069 L .58217 .50631 L p .742 .219 0 r
F P
0 g
s
.59007 .51095 m .58217 .50631 L .58079 .5069 L p .672 .124 0 r
F P
0 g
s
.66642 .10676 m .68462 .10852 L .68282 .10856 L p .013 .583 .776 r
F P
0 g
s
.68282 .10856 m .66386 .10684 L .66642 .10676 L p .013 .583 .776 r
F P
0 g
s
.67092 .10791 m .68774 .1093 L .68462 .10852 L p .241 0 0 r
F P
0 g
s
.47842 .39714 m .47501 .4011 L .47599 .4025 L p .054 0 .113 r
F P
0 g
s
.47204 .40605 m .47599 .4025 L .47501 .4011 L p .102 0 .074 r
F P
0 g
s
.06455 .4749 m .06279 .48774 L .06249 .48882 L p .837 .769 .26 r
F P
0 g
s
.51046 .53516 m .50766 .54408 L .50951 .54342 L p 0 0 .217 r
F P
0 g
s
.50951 .54342 m .51206 .53455 L .51046 .53516 L p 0 0 .217 r
F P
0 g
s
.75889 .16214 m .74778 .14621 L .74689 .14458 L p 0 0 .471 r
F P
0 g
s
.74689 .14458 m .75761 .15979 L .75889 .16214 L p 0 0 .471 r
F P
0 g
s
.75761 .15979 m .76774 .18158 L .76947 .18472 L p .679 .309 0 r
F P
0 g
s
.73748 .13466 m .74689 .14458 L .74778 .14621 L p 0 .092 .621 r
F P
0 g
s
.4383 .41533 m .44532 .41555 L .44491 .41403 L p .46 0 0 r
F P
0 g
s
.57625 .44616 m .57238 .45031 L .57407 .45086 L p .833 .998 .832 r
F P
0 g
s
.06397 .52314 m .06249 .51123 L .0628 .51233 L p .833 .593 .044 r
F P
0 g
s
.0628 .51233 m .06461 .52543 L .06397 .52314 L p .833 .593 .044 r
F P
0 g
s
.48152 .39263 m .47842 .39714 L .47953 .39852 L p .005 0 .15 r
F P
0 g
s
.45971 .49371 m .45388 .49727 L .45419 .4991 L p .748 .985 .904 r
F P
0 g
s
.44803 .50395 m .45419 .4991 L .45388 .49727 L p .786 .995 .87 r
F P
0 g
s
.43052 .41418 m .4383 .41533 L .43794 .41374 L p .513 0 0 r
F P
0 g
s
.06211 .49687 m .06199 .49237 L .06222 .49039 L p .855 .73 .209 r
F P
0 g
s
.06199 .49237 m .06211 .49687 L .06204 .49783 L p .834 .705 .172 r
F P
0 g
s
.06182 .50524 m .06204 .50216 L .06211 .50312 L p .833 .656 .112 r
F P
0 g
s
.06211 .50312 m .06199 .5076 L .06182 .50524 L p .833 .656 .112 r
F P
0 g
s
.47953 .39852 m .48276 .394 L .48152 .39263 L p .005 0 .15 r
F P
0 g
s
.4844 .38739 m .48152 .39263 L .48276 .394 L p 0 0 .189 r
F P
0 g
s
.57802 .44687 m .58281 .44275 L .58097 .44187 L p .796 .997 .861 r
F P
0 g
s
.58097 .44187 m .57625 .44616 L .57802 .44687 L p .796 .997 .861 r
F P
0 g
s
.69978 .11221 m .70786 .11523 L .70666 .11493 L p 0 .442 .771 r
F P
0 g
s
.70666 .11493 m .69776 .1117 L .69978 .11221 L p 0 .442 .771 r
F P
0 g
s
.73748 .13466 m .73018 .12852 L .72931 .12761 L p 0 .148 .639 r
F P
0 g
s
.58079 .5069 m .58853 .51165 L .59007 .51095 L p .672 .124 0 r
F P
0 g
s
.60033 .51582 m .59007 .51095 L .58853 .51165 L p .611 .046 0 r
F P
0 g
s
.48276 .394 m .48578 .38874 L .4844 .38739 L p 0 0 .189 r
F P
0 g
s
.487 .38133 m .4844 .38739 L .48578 .38874 L p 0 0 .228 r
F P
0 g
s
.42181 .41194 m .43052 .41418 L .4302 .41248 L p .56 0 0 r
F P
0 g
s
.50766 .54408 m .5033 .55495 L .5055 .55421 L p 0 0 .155 r
F P
0 g
s
.5055 .55421 m .50951 .54342 L .50766 .54408 L p 0 0 .155 r
F P
0 g
s
.45388 .49727 m .44763 .50195 L .44803 .50395 L p .786 .995 .87 r
F P
0 g
s
.44132 .51021 m .44803 .50395 L .44763 .50195 L p .817 .999 .835 r
F P
0 g
s
.58281 .44275 m .58856 .43851 L .58664 .43744 L p .761 .991 .885 r
F P
0 g
s
.58664 .43744 m .58097 .44187 L .58281 .44275 L p .761 .991 .885 r
F P
0 g
s
.06204 .49783 m .06182 .4947 L .06199 .49237 L p .834 .705 .172 r
F P
0 g
s
.06182 .4947 m .06204 .49783 L .062 .49889 L p .819 .684 .141 r
F P
0 g
s
.06171 .50265 m .062 .5011 L .06204 .50216 L p .818 .653 .104 r
F P
0 g
s
.06204 .50216 m .06182 .50524 L .06171 .50265 L p .818 .653 .104 r
F P
0 g
s
.08536 .42493 m .07128 .453 L .07012 .45485 L p .689 .822 .377 r
F P
0 g
s
.06455 .4749 m .07012 .45485 L .07128 .453 L p .826 .835 .364 r
F P
0 g
s
.48578 .38874 m .48854 .38265 L .487 .38133 L p 0 0 .228 r
F P
0 g
s
.4893 .37435 m .487 .38133 L .48854 .38265 L p 0 0 .264 r
F P
0 g
s
.41192 .40843 m .42181 .41194 L .42153 .4101 L p .597 .035 0 r
F P
0 g
s
.0855 .57478 m .07053 .54618 L .07178 .54825 L p .663 .272 0 r
F P
0 g
s
.07178 .54825 m .08749 .57808 L .0855 .57478 L p .663 .272 0 r
F P
0 g
s
.58856 .43851 m .59543 .43412 L .59341 .43284 L p .727 .983 .904 r
F P
0 g
s
.59341 .43284 m .58664 .43744 L .58856 .43851 L p .727 .983 .904 r
F P
0 g
s
.71156 .11673 m .71499 .1185 L .71388 .11802 L p 0 .343 .718 r
F P
0 g
s
.71388 .11802 m .70952 .11584 L .71156 .11673 L p 0 .343 .718 r
F P
0 g
s
.72386 .12378 m .72793 .12647 L .72931 .12761 L p 0 .236 .697 r
F P
0 g
s
.72793 .12647 m .72386 .12378 L .72289 .12306 L p 0 .208 .657 r
F P
0 g
s
.062 .49889 m .06171 .49726 L .06182 .4947 L p .819 .684 .141 r
F P
0 g
s
.06171 .49726 m .062 .49889 L .06199 .49999 L p .811 .667 .119 r
F P
0 g
s
.06168 .49995 m .06199 .49999 L .062 .5011 L p .81 .657 .106 r
F P
0 g
s
.062 .5011 m .06171 .50265 L .06168 .49995 L p .81 .657 .106 r
F P
0 g
s
.44763 .50195 m .4408 .50799 L .44132 .51021 L p .817 .999 .835 r
F P
0 g
s
.43386 .51817 m .44132 .51021 L .4408 .50799 L p .839 .999 .803 r
F P
0 g
s
.48854 .38265 m .49101 .37565 L .4893 .37435 L p 0 0 .264 r
F P
0 g
s
.49126 .36632 m .4893 .37435 L .49101 .37565 L p 0 0 .297 r
F P
0 g
s
.06199 .49999 m .06168 .49995 L .06171 .49726 L p .811 .667 .119 r
F P
0 g
s
.58853 .51165 m .59857 .51668 L .60033 .51582 L p .611 .046 0 r
F P
0 g
s
.61372 .52126 m .60033 .51582 L .59857 .51668 L p .567 0 0 r
F P
0 g
s
.5033 .55495 m .49707 .56861 L .49972 .56776 L p 0 0 .115 r
F P
0 g
s
.49972 .56776 m .5055 .55421 L .5033 .55495 L p 0 0 .115 r
F P
0 g
s
.40045 .40347 m .41192 .40843 L .41167 .40642 L p .625 .065 0 r
F P
0 g
s
.59543 .43412 m .60356 .4295 L .60144 .42801 L p .698 .974 .918 r
F P
0 g
s
.60144 .42801 m .59341 .43284 L .59543 .43412 L p .698 .974 .918 r
F P
0 g
s
.64306 .10856 m .66642 .10676 L .66386 .10684 L p 0 0 0 r
F P
0 g
s
.66386 .10684 m .63969 .10866 L .64306 .10856 L p 0 0 0 r
F P
0 g
s
.49101 .37565 m .49315 .3676 L .49126 .36632 L p 0 0 .297 r
F P
0 g
s
.49287 .35707 m .49126 .36632 L .49315 .3676 L p 0 0 .326 r
F P
0 g
s
.76947 .18472 m .75889 .16214 L .75761 .15979 L p .679 .309 0 r
F P
0 g
s
.4408 .50799 m .43321 .51568 L .43386 .51817 L p .839 .999 .803 r
F P
0 g
s
.4253 .52825 m .43386 .51817 L .43321 .51568 L p .855 .997 .779 r
F P
0 g
s
.78429 .80447 m .76173 .84287 L .76297 .84052 L p 0 0 0 r
F P
0 g
s
.76297 .84052 m .7862 .8008 L .78429 .80447 L p 0 0 0 r
F P
0 g
s
.73718 .86749 m .72671 .8748 L .72785 .87385 L p 0 0 0 r
F P
0 g
s
.72785 .87385 m .7399 .86522 L .73718 .86749 L p 0 0 0 r
F P
0 g
s
.70982 .88426 m .69619 .89042 L .69369 .89106 L p 0 0 0 r
F P
0 g
s
.69619 .89042 m .70982 .88426 L .71123 .88374 L p 0 0 0 r
F P
0 g
s
.61333 .89756 m .66212 .89816 L .66499 .89824 L p .017 0 0 r
F P
0 g
s
.66499 .89824 m .61811 .89768 L .61333 .89756 L p .017 0 0 r
F P
0 g
s
.61811 .89768 m .55721 .8746 L .55068 .87457 L p 0 .491 .833 r
F P
0 g
s
.69369 .89106 m .66499 .89824 L .66212 .89816 L p .006 0 0 r
F P
0 g
s
.71389 .11786 m .71625 .11912 L .71499 .1185 L p 0 .292 .67 r
F P
0 g
s
.71499 .1185 m .71156 .11673 L .71389 .11786 L p 0 .292 .67 r
F P
0 g
s
.49315 .3676 m .49497 .35834 L .49287 .35707 L p 0 0 .326 r
F P
0 g
s
.49417 .34642 m .49287 .35707 L .49497 .35834 L p 0 0 .349 r
F P
0 g
s
.72289 .12306 m .72613 .12514 L .72793 .12647 L p 0 .208 .657 r
F P
0 g
s
.72613 .12514 m .72289 .12306 L .72172 .12227 L p 0 .19 .624 r
F P
0 g
s
.60356 .4295 m .61316 .42456 L .61092 .42282 L p .676 .966 .929 r
F P
0 g
s
.61092 .42282 m .60144 .42801 L .60356 .4295 L p .676 .966 .929 r
F P
0 g
s
.59857 .51668 m .61168 .52231 L .61372 .52126 L p .567 0 0 r
F P
0 g
s
.63125 .5279 m .61372 .52126 L .61168 .52231 L p .549 0 0 r
F P
0 g
s
.06249 .48882 m .06393 .47706 L .06455 .4749 L p .837 .769 .26 r
F P
0 g
s
.06393 .47706 m .06249 .48882 L .06222 .49039 L p .77 .707 .169 r
F P
0 g
s
.38683 .39683 m .40045 .40347 L .40024 .40122 L p .643 .085 0 r
F P
0 g
s
.0634 .51981 m .06221 .50962 L .06249 .51123 L p .765 .546 0 r
F P
0 g
s
.06249 .51123 m .06397 .52314 L .0634 .51981 L p .765 .546 0 r
F P
0 g
s
.49707 .56861 m .48867 .58642 L .49191 .58545 L p 0 0 .105 r
F P
0 g
s
.49191 .58545 m .49972 .56776 L .49707 .56861 L p 0 0 .105 r
F P
0 g
s
.43321 .51568 m .42449 .52541 L .4253 .52825 L p .855 .997 .779 r
F P
0 g
s
.41506 .5409 m .4253 .52825 L .42449 .52541 L p .862 .995 .766 r
F P
0 g
s
.49497 .35834 m .49648 .34768 L .49417 .34642 L p 0 0 .349 r
F P
0 g
s
.4952 .3341 m .49417 .34642 L .49648 .34768 L p 0 0 .365 r
F P
0 g
s
.61316 .42456 m .62446 .41911 L .62207 .4171 L p .661 .961 .935 r
F P
0 g
s
.62207 .4171 m .61092 .42282 L .61316 .42456 L p .661 .961 .935 r
F P
0 g
s
.7164 .11918 m .71762 .11983 L .71625 .11912 L p 0 .248 .632 r
F P
0 g
s
.71625 .11912 m .71389 .11786 L .7164 .11918 L p 0 .248 .632 r
F P
0 g
s
.72172 .12227 m .72398 .12368 L .72613 .12514 L p 0 .19 .624 r
F P
0 g
s
.72398 .12368 m .72172 .12227 L .72041 .12145 L p 0 .184 .604 r
F P
0 g
s
.70256 .11323 m .70952 .11584 L .70786 .11523 L p 0 .347 .671 r
F P
0 g
s
.70786 .11523 m .69978 .11221 L .70256 .11323 L p 0 .347 .671 r
F P
0 g
s
.72931 .12761 m .736 .13314 L .73748 .13466 L p 0 .148 .639 r
F P
0 g
s
.736 .13314 m .72931 .12761 L .72793 .12647 L p 0 .082 .551 r
F P
0 g
s
.68774 .1093 m .69978 .11221 L .69776 .1117 L p .177 0 0 r
F P
0 g
s
.69776 .1117 m .68462 .10852 L .68774 .1093 L p .177 0 0 r
F P
0 g
s
.38669 .39431 m .3702 .38556 L .37024 .38841 L p .648 .091 0 r
F P
0 g
s
.37024 .38841 m .38683 .39683 L .38669 .39431 L p .648 .091 0 r
F P
0 g
s
.50415 .49599 m .50679 .49883 L .50859 .49738 L p .393 .501 .85 r
F P
0 g
s
.50679 .49883 m .50911 .50212 L .511 .5008 L p .363 .447 .813 r
F P
0 g
s
.511 .5008 m .50859 .49738 L .50679 .49883 L p .363 .447 .813 r
F P
0 g
s
.74689 .14458 m .73748 .13466 L .736 .13314 L p .527 .032 0 r
F P
0 g
s
.50124 .49359 m .50415 .49599 L .50584 .49439 L p .425 .552 .88 r
F P
0 g
s
.50859 .49738 m .50584 .49439 L .50415 .49599 L p .393 .501 .85 r
F P
0 g
s
.50911 .50212 m .51106 .50589 L .51305 .50468 L p .334 .39 .771 r
F P
0 g
s
.51305 .50468 m .511 .5008 L .50911 .50212 L p .334 .39 .771 r
F P
0 g
s
.719 .12063 m .71903 .12062 L .71762 .11983 L p .355 0 0 r
F P
0 g
s
.71762 .11983 m .7164 .11918 L .719 .12063 L p .355 0 0 r
F P
0 g
s
.72041 .12145 m .72156 .12216 L .72398 .12368 L p 0 .184 .604 r
F P
0 g
s
.72156 .12216 m .72041 .12145 L .71903 .12062 L p .372 0 0 r
F P
0 g
s
.49812 .49161 m .50124 .49359 L .50282 .49182 L p .458 .599 .905 r
F P
0 g
s
.50584 .49439 m .50282 .49182 L .50124 .49359 L p .425 .552 .88 r
F P
0 g
s
.49648 .34768 m .49777 .33535 L .4952 .3341 L p 0 0 .365 r
F P
0 g
s
.49615 .3198 m .4952 .3341 L .49777 .33535 L p 0 0 .373 r
F P
0 g
s
.51106 .50589 m .51256 .51019 L .51466 .50905 L p .306 .331 .724 r
F P
0 g
s
.51466 .50905 m .51305 .50468 L .51106 .50589 L p .306 .331 .724 r
F P
0 g
s
.07012 .45485 m .08361 .42769 L .08536 .42493 L p .689 .822 .377 r
F P
0 g
s
.1118 .39343 m .08536 .42493 L .08361 .42769 L p 0 0 0 r
F P
0 g
s
.49483 .49004 m .49812 .49161 L .49955 .48966 L p .492 .643 .924 r
F P
0 g
s
.50282 .49182 m .49955 .48966 L .49812 .49161 L p .458 .599 .905 r
F P
0 g
s
.71903 .12062 m .719 .12063 L .72156 .12216 L p .372 0 0 r
F P
0 g
s
.62446 .41911 m .6377 .41285 L .63515 .41053 L p .658 .959 .937 r
F P
0 g
s
.63515 .41053 m .62207 .4171 L .62446 .41911 L p .658 .959 .937 r
F P
0 g
s
.61573 .11626 m .64306 .10856 L .63969 .10866 L p 0 0 0 r
F P
0 g
s
.63969 .10866 m .61164 .11633 L .61573 .11626 L p 0 0 0 r
F P
0 g
s
.61168 .52231 m .62887 .52923 L .63125 .5279 L p .549 0 0 r
F P
0 g
s
.65421 .53709 m .63125 .5279 L .62887 .52923 L p .562 0 0 r
F P
0 g
s
.49142 .48887 m .49483 .49004 L .4961 .48792 L p .526 .684 .938 r
F P
0 g
s
.49955 .48966 m .4961 .48792 L .49483 .49004 L p .492 .643 .924 r
F P
0 g
s
.51256 .51019 m .51353 .51508 L .51578 .51397 L p .279 .27 .67 r
F P
0 g
s
.51578 .51397 m .51466 .50905 L .51256 .51019 L p .279 .27 .67 r
F P
0 g
s
.73358 .87015 m .72521 .87591 L .72671 .8748 L p 0 0 0 r
F P
0 g
s
.72671 .8748 m .73718 .86749 L .73358 .87015 L p 0 0 0 r
F P
0 g
s
.77658 .21406 m .76947 .18472 L .76774 .18158 L p .829 .542 0 r
F P
0 g
s
.42449 .52541 m .41406 .53762 L .41506 .5409 L p .862 .995 .766 r
F P
0 g
s
.4022 .55663 m .41506 .5409 L .41406 .53762 L p .861 .996 .77 r
F P
0 g
s
.71123 .88374 m .69963 .88916 L .69619 .89042 L p 0 0 0 r
F P
0 g
s
.69963 .88916 m .71123 .88374 L .71296 .88298 L p 0 0 0 r
F P
0 g
s
.07012 .45485 m .06455 .4749 L .06393 .47706 L p .691 .719 .2 r
F P
0 g
s
.4961 .48792 m .49251 .48658 L .49142 .48887 L p .526 .684 .938 r
F P
0 g
s
.4878 .48806 m .49142 .48887 L .4925 .48658 L p .56 .725 .951 r
F P
0 g
s
.5595 .48026 m .56047 .48482 L .56283 .48424 L p .945 .722 .568 r
F P
0 g
s
.56283 .48424 m .56194 .47978 L .5595 .48026 L p .945 .722 .568 r
F P
0 g
s
.56444 .48872 m .56283 .48424 L .56047 .48482 L p .933 .667 .51 r
F P
0 g
s
.55916 .47572 m .5595 .48026 L .56194 .47978 L p .95 .768 .622 r
F P
0 g
s
.56194 .47978 m .56173 .47537 L .55916 .47572 L p .95 .768 .622 r
F P
0 g
s
.56047 .48482 m .56212 .48939 L .56444 .48872 L p .933 .667 .51 r
F P
0 g
s
.56689 .49322 m .56444 .48872 L .56212 .48939 L p .913 .605 .448 r
F P
0 g
s
.48867 .58642 m .4782 .61057 L .48221 .60947 L p 0 0 .132 r
F P
0 g
s
.48221 .60947 m .49191 .58545 L .48867 .58642 L p 0 0 .132 r
F P
0 g
s
.06936 .542 m .06397 .52314 L .06461 .52543 L p 0 0 .198 r
F P
0 g
s
.06461 .52543 m .07053 .54618 L .06936 .542 L p 0 0 .198 r
F P
0 g
s
.55941 .4712 m .55916 .47572 L .56173 .47537 L p .948 .808 .672 r
F P
0 g
s
.56173 .47537 m .56213 .471 L .55941 .4712 L p .948 .808 .672 r
F P
0 g
s
.4925 .48658 m .48869 .48562 L .4878 .48806 L p .56 .725 .951 r
F P
0 g
s
.48388 .48763 m .4878 .48806 L .48869 .48562 L p .597 .76 .957 r
F P
0 g
s
.1157 .60708 m .0855 .57478 L .08749 .57808 L p 0 .067 .596 r
F P
0 g
s
.08749 .57808 m .11848 .61174 L .1157 .60708 L p 0 .067 .596 r
F P
0 g
s
.49777 .33535 m .499 .32105 L .49615 .3198 L p 0 0 .373 r
F P
0 g
s
.49729 .30317 m .49615 .3198 L .499 .32105 L p 0 0 .371 r
F P
0 g
s
.51353 .51508 m .51387 .52066 L .51632 .51955 L p .252 .208 .612 r
F P
0 g
s
.51632 .51955 m .51578 .51397 L .51353 .51508 L p .252 .208 .612 r
F P
0 g
s
.06222 .49039 m .06338 .48023 L .06393 .47706 L p .77 .707 .169 r
F P
0 g
s
.06338 .48023 m .06222 .49039 L .06199 .49237 L p 0 0 0 r
F P
0 g
s
.48869 .48562 m .48456 .48504 L .48388 .48763 L p .597 .76 .957 r
F P
0 g
s
.47965 .48764 m .48388 .48763 L .48456 .48504 L p .635 .794 .959 r
F P
0 g
s
.3702 .38556 m .34957 .37509 L .34945 .37831 L p .639 .08 0 r
F P
0 g
s
.34945 .37831 m .37024 .38841 L .3702 .38556 L p .639 .08 0 r
F P
0 g
s
.56212 .48939 m .56454 .49399 L .56689 .49322 L p .913 .605 .448 r
F P
0 g
s
.57029 .49774 m .56689 .49322 L .56454 .49399 L p .885 .536 .382 r
F P
0 g
s
.6377 .41285 m .65312 .40531 L .65039 .40264 L p .667 .962 .935 r
F P
0 g
s
.65039 .40264 m .63515 .41053 L .6377 .41285 L p .667 .962 .935 r
F P
0 g
s
.56023 .46672 m .55941 .4712 L .56213 .471 L p .94 .839 .716 r
F P
0 g
s
.56213 .471 m .56311 .4667 L .56023 .46672 L p .94 .839 .716 r
F P
0 g
s
.06293 .51561 m .06199 .5076 L .06221 .50962 L p 0 0 .087 r
F P
0 g
s
.06221 .50962 m .0634 .51981 L .06293 .51561 L p 0 0 .087 r
F P
0 g
s
.75839 .84633 m .7399 .86522 L .74162 .86343 L p 0 0 0 r
F P
0 g
s
.74162 .86343 m .76173 .84287 L .75839 .84633 L p 0 0 0 r
F P
0 g
s
.48456 .48504 m .48011 .48492 L .47965 .48764 L p .635 .794 .959 r
F P
0 g
s
.47512 .48817 m .47965 .48764 L .48011 .48492 L p .673 .824 .956 r
F P
0 g
s
.66499 .89824 m .69369 .89106 L .69619 .89042 L p .176 .703 .69 r
F P
0 g
s
.56158 .46228 m .56023 .46672 L .56311 .4667 L p .928 .864 .756 r
F P
0 g
s
.56311 .4667 m .56465 .46248 L .56158 .46228 L p .928 .864 .756 r
F P
0 g
s
.51387 .52066 m .51344 .52708 L .51617 .52592 L p .226 .145 .55 r
F P
0 g
s
.51617 .52592 m .51632 .51955 L .51387 .52066 L p .226 .145 .55 r
F P
0 g
s
.56454 .49399 m .56785 .49861 L .57029 .49774 L p .885 .536 .382 r
F P
0 g
s
.57484 .50229 m .57029 .49774 L .56785 .49861 L p .849 .462 .314 r
F P
0 g
s
.499 .32105 m .50046 .30439 L .49729 .30317 L p 0 0 .371 r
F P
0 g
s
.49915 .28383 m .49729 .30317 L .50046 .30439 L p 0 0 .357 r
F P
0 g
s
.48011 .48492 m .47537 .48531 L .47512 .48817 L p .673 .824 .956 r
F P
0 g
s
.47029 .48929 m .47512 .48817 L .47537 .48531 L p .711 .851 .949 r
F P
0 g
s
.41406 .53762 m .40095 .55282 L .4022 .55663 L p .861 .996 .77 r
F P
0 g
s
.38516 .57578 m .4022 .55663 L .40095 .55282 L p .849 .998 .792 r
F P
0 g
s
.70599 .11472 m .71156 .11673 L .70952 .11584 L p .345 0 0 r
F P
0 g
s
.70952 .11584 m .70256 .11323 L .70599 .11472 L p .345 0 0 r
F P
0 g
s
.72793 .12647 m .73368 .13121 L .736 .13314 L p 0 .082 .551 r
F P
0 g
s
.73368 .13121 m .72793 .12647 L .72613 .12514 L p .516 0 0 r
F P
0 g
s
.62887 .52923 m .65144 .53878 L .65421 .53709 L p .562 0 0 r
F P
0 g
s
.68383 .55141 m .65421 .53709 L .65144 .53878 L p .612 .046 0 r
F P
0 g
s
.65312 .40531 m .67085 .3958 L .66795 .39274 L p .689 .97 .926 r
F P
0 g
s
.66795 .39274 m .65039 .40264 L .65312 .40531 L p .689 .97 .926 r
F P
0 g
s
.56347 .45792 m .56158 .46228 L .56465 .46248 L p .912 .883 .791 r
F P
0 g
s
.56465 .46248 m .5667 .45835 L .56347 .45792 L p .912 .883 .791 r
F P
0 g
s
.72925 .87309 m .72341 .87713 L .72521 .87591 L p .407 .81 .593 r
F P
0 g
s
.72521 .87591 m .73358 .87015 L .72925 .87309 L p .407 .81 .593 r
F P
0 g
s
.71296 .88298 m .70385 .88731 L .69963 .88916 L p 0 0 0 r
F P
0 g
s
.70385 .88731 m .71296 .88298 L .71493 .88203 L p .319 .78 .649 r
F P
0 g
s
.58714 .13138 m .61573 .11626 L .61164 .11633 L p 0 0 0 r
F P
0 g
s
.61164 .11633 m .58254 .13134 L .58714 .13138 L p 0 0 0 r
F P
0 g
s
.47537 .48531 m .47034 .48629 L .47029 .48929 L p .711 .851 .949 r
F P
0 g
s
.46516 .4911 m .47029 .48929 L .47034 .48629 L p .748 .875 .938 r
F P
0 g
s
.79683 .74579 m .78429 .80447 L .7862 .8008 L p .823 .796 .3 r
F P
0 g
s
.7862 .8008 m .79938 .74123 L .79683 .74579 L p .823 .796 .3 r
F P
0 g
s
.34957 .37509 m .32327 .36361 L .32287 .36722 L p .611 .047 0 r
F P
0 g
s
.32287 .36722 m .34945 .37831 L .34957 .37509 L p .611 .047 0 r
F P
0 g
s
.56785 .49861 m .57223 .50329 L .57484 .50229 L p .849 .462 .314 r
F P
0 g
s
.58079 .5069 m .57484 .50229 L .57223 .50329 L p .807 .386 .247 r
F P
0 g
s
.77717 .24833 m .77658 .21406 L .7744 .21017 L p .923 .741 .254 r
F P
0 g
s
.76774 .18158 m .7744 .21017 L .77658 .21406 L p .829 .542 0 r
F P
0 g
s
.51344 .52708 m .51206 .53455 L .51517 .5333 L p .201 .083 .487 r
F P
0 g
s
.51517 .5333 m .51617 .52592 L .51344 .52708 L p .201 .083 .487 r
F P
0 g
s
.56585 .45365 m .56347 .45792 L .5667 .45835 L p .894 .896 .822 r
F P
0 g
s
.5667 .45835 m .56925 .45434 L .56585 .45365 L p .894 .896 .822 r
F P
0 g
s
.4782 .61057 m .46695 .64433 L .4719 .64314 L p 0 0 .202 r
F P
0 g
s
.4719 .64314 m .48221 .60947 L .4782 .61057 L p 0 0 .202 r
F P
0 g
s
.50046 .30439 m .50267 .28501 L .49915 .28383 L p 0 0 .357 r
F P
0 g
s
.50252 .26152 m .49915 .28383 L .50267 .28501 L p 0 0 .328 r
F P
0 g
s
.06199 .49237 m .06292 .48426 L .06338 .48023 L p 0 0 0 r
F P
0 g
s
.06292 .48426 m .06199 .49237 L .06182 .4947 L p 0 0 0 r
F P
0 g
s
.06257 .51071 m .06182 .50524 L .06199 .5076 L p 0 0 .124 r
F P
0 g
s
.06199 .5076 m .06293 .51561 L .06257 .51071 L p 0 0 .124 r
F P
0 g
s
.47034 .48629 m .46502 .48794 L .46516 .4911 L p .748 .875 .938 r
F P
0 g
s
.45971 .49371 m .46516 .4911 L .46502 .48794 L p .783 .895 .923 r
F P
0 g
s
.15162 .36605 m .1118 .39343 L .10957 .39702 L p 0 0 0 r
F P
0 g
s
.08361 .42769 m .10957 .39702 L .1118 .39343 L p 0 0 0 r
F P
0 g
s
.67085 .3958 m .69083 .38335 L .68777 .37988 L p .724 .981 .91 r
F P
0 g
s
.68777 .37988 m .66795 .39274 L .67085 .3958 L p .724 .981 .91 r
F P
0 g
s
.55068 .87457 m .61333 .89756 L .61811 .89768 L p 0 .491 .833 r
F P
0 g
s
.46765 .40912 m .46282 .41167 L .46414 .41471 L p .482 .162 .347 r
F P
0 g
s
.46282 .41167 m .45751 .41363 L .45866 .4167 L p .521 .176 .323 r
F P
0 g
s
.45866 .4167 m .46414 .41471 L .46282 .41167 L p .521 .176 .323 r
F P
0 g
s
.72438 .87617 m .72139 .87841 L .72341 .87713 L p .426 .833 .639 r
F P
0 g
s
.72341 .87713 m .72925 .87309 L .72438 .87617 L p .426 .833 .639 r
F P
0 g
s
.71493 .88203 m .70866 .88498 L .70385 .88731 L p .319 .78 .649 r
F P
0 g
s
.70866 .88498 m .71493 .88203 L .71706 .88091 L p .372 .815 .674 r
F P
0 g
s
.45751 .41363 m .4517 .41495 L .45271 .41807 L p .561 .192 .299 r
F P
0 g
s
.45271 .41807 m .45866 .4167 L .45751 .41363 L p .561 .192 .299 r
F P
0 g
s
.47204 .40605 m .46765 .40912 L .46917 .41216 L p .444 .151 .372 r
F P
0 g
s
.46414 .41471 m .46917 .41216 L .46765 .40912 L p .482 .162 .347 r
F P
0 g
s
.56925 .45434 m .57238 .45031 L .56882 .44934 L p .879 .907 .845 r
F P
0 g
s
.56882 .44934 m .56585 .45364 L .56925 .45434 L p .879 .907 .845 r
F P
0 g
s
.40095 .55282 m .38359 .57134 L .38516 .57578 L p .849 .998 .792 r
F P
0 g
s
.36155 .59807 m .38516 .57578 L .38359 .57134 L p .821 .999 .834 r
F P
0 g
s
.4517 .41495 m .44532 .41555 L .44623 .41876 L p .601 .21 .275 r
F P
0 g
s
.44623 .41876 m .45271 .41807 L .4517 .41495 L p .601 .21 .275 r
F P
0 g
s
.47599 .4025 m .47204 .40605 L .47379 .40908 L p .408 .143 .396 r
F P
0 g
s
.46917 .41216 m .47379 .40908 L .47204 .40605 L p .444 .151 .372 r
F P
0 g
s
.46502 .48794 m .45938 .49035 L .45971 .49371 L p .783 .895 .923 r
F P
0 g
s
.45388 .49727 m .45971 .49371 L .45938 .49035 L p .815 .911 .905 r
F P
0 g
s
.50267 .28501 m .50641 .2626 L .50252 .26152 L p 0 0 .328 r
F P
0 g
s
.50855 .23623 m .50252 .26152 L .50641 .2626 L p 0 0 .282 r
F P
0 g
s
.57223 .50329 m .57791 .50806 L .58079 .5069 L p .807 .386 .247 r
F P
0 g
s
.58853 .51165 m .58079 .5069 L .57791 .50806 L p .762 .312 .183 r
F P
0 g
s
.70991 .11663 m .71389 .11786 L .71156 .11673 L p .433 0 0 r
F P
0 g
s
.71156 .11673 m .70599 .11472 L .70991 .11663 L p .433 0 0 r
F P
0 g
s
.68462 .10852 m .66642 .10676 L .67092 .10791 L p .241 0 0 r
F P
0 g
s
.72613 .12514 m .73063 .12896 L .73368 .13121 L p .516 0 0 r
F P
0 g
s
.73063 .12896 m .72613 .12514 L .72398 .12368 L p .559 0 0 r
F P
0 g
s
.56068 .15356 m .58714 .13138 L .58254 .13134 L p 0 0 0 r
F P
0 g
s
.58254 .13134 m .55584 .15333 L .56068 .15356 L p 0 0 0 r
F P
0 g
s
.32327 .36361 m .28962 .35299 L .2888 .35696 L p .556 0 0 r
F P
0 g
s
.2888 .35696 m .32287 .36722 L .32327 .36361 L p .556 0 0 r
F P
0 g
s
.47953 .39852 m .47599 .4025 L .47799 .40553 L p .375 .136 .419 r
F P
0 g
s
.47379 .40908 m .47799 .40553 L .47599 .4025 L p .408 .143 .396 r
F P
0 g
s
.51206 .53455 m .50951 .54342 L .51312 .54202 L p .178 .027 .426 r
F P
0 g
s
.51312 .54202 m .51517 .5333 L .51206 .53455 L p .178 .027 .426 r
F P
0 g
s
.71916 .87928 m .71924 .87969 L .72139 .87841 L p .426 .841 .668 r
F P
0 g
s
.72139 .87841 m .72438 .87617 L .71916 .87928 L p .426 .841 .668 r
F P
0 g
s
.75761 .15979 m .74689 .14458 L .74457 .1422 L p .726 .262 0 r
F P
0 g
s
.736 .13314 m .74457 .1422 L .74689 .14458 L p .527 .032 0 r
F P
0 g
s
.71706 .88091 m .71385 .88226 L .70866 .88498 L p .372 .815 .674 r
F P
0 g
s
.71385 .88226 m .71706 .88091 L .71924 .87969 L p .408 .835 .68 r
F P
0 g
s
.06182 .4947 m .06257 .48901 L .06292 .48426 L p 0 0 0 r
F P
0 g
s
.06257 .48901 m .06182 .4947 L .06171 .49726 L p 0 0 .064 r
F P
0 g
s
.44532 .41555 m .4383 .41533 L .43914 .41869 L p .639 .23 .252 r
F P
0 g
s
.43914 .41869 m .44623 .41876 L .44532 .41555 L p .639 .23 .252 r
F P
0 g
s
.65144 .53878 m .68068 .55362 L .68383 .55141 L p .612 .046 0 r
F P
0 g
s
.72008 .5754 m .68383 .55141 L .68068 .55362 L p .696 .155 0 r
F P
0 g
s
.06236 .50536 m .06171 .50265 L .06182 .50524 L p 0 0 .141 r
F P
0 g
s
.06182 .50524 m .06257 .51071 L .06236 .50536 L p 0 0 .141 r
F P
0 g
s
.69083 .38335 m .71248 .36678 L .70931 .36288 L p .771 .993 .881 r
F P
0 g
s
.70931 .36288 m .68777 .37988 L .69083 .38335 L p .771 .993 .881 r
F P
0 g
s
.57238 .45031 m .57625 .44616 L .57253 .44488 L p .857 .913 .869 r
F P
0 g
s
.57253 .44488 m .56882 .44934 L .57238 .45031 L p .857 .913 .869 r
F P
0 g
s
.69207 .1109 m .70256 .11323 L .69978 .11221 L p .347 0 0 r
F P
0 g
s
.69978 .11221 m .68774 .1093 L .69207 .1109 L p .347 0 0 r
F P
0 g
s
.71924 .87969 m .71916 .87928 L .71385 .88226 L p .408 .835 .68 r
F P
0 g
s
.74457 .1422 m .736 .13314 L .73368 .13121 L p .652 .133 0 r
F P
0 g
s
.47799 .40553 m .48178 .40153 L .47953 .39852 L p .375 .136 .419 r
F P
0 g
s
.48276 .394 m .47953 .39852 L .48178 .40153 L p .339 .129 .441 r
F P
0 g
s
.50584 .49439 m .50859 .49738 L .5113 .49527 L p .518 .543 .821 r
F P
0 g
s
.50859 .49738 m .511 .5008 L .51383 .4989 L p .497 .505 .796 r
F P
0 g
s
.51383 .4989 m .5113 .49527 L .50859 .49738 L p .497 .505 .796 r
F P
0 g
s
.76957 .28397 m .77717 .24833 L .77458 .24391 L p .951 .879 .475 r
F P
0 g
s
.7744 .21017 m .77458 .24391 L .77717 .24833 L p .923 .741 .254 r
F P
0 g
s
.16367 .63326 m .1157 .60708 L .11848 .61174 L p 0 .43 .848 r
F P
0 g
s
.11848 .61174 m .16698 .63907 L .16367 .63326 L p 0 .43 .848 r
F P
0 g
s
.511 .5008 m .51305 .50468 L .51599 .50293 L p .478 .466 .766 r
F P
0 g
s
.51599 .50293 m .51383 .4989 L .511 .5008 L p .478 .466 .766 r
F P
0 g
s
.50282 .49182 m .50584 .49439 L .50843 .49204 L p .539 .578 .842 r
F P
0 g
s
.5113 .49527 m .50843 .49204 L .50584 .49439 L p .518 .543 .821 r
F P
0 g
s
.50641 .2626 m .51281 .23716 L .50855 .23623 L p 0 0 .282 r
F P
0 g
s
.51866 .20856 m .50855 .23623 L .51281 .23716 L p 0 0 .213 r
F P
0 g
s
.45938 .49035 m .45339 .49365 L .45388 .49727 L p .815 .911 .905 r
F P
0 g
s
.44763 .50195 m .45388 .49727 L .45339 .49365 L p .844 .923 .884 r
F P
0 g
s
.49955 .48966 m .50282 .49182 L .50525 .48919 L p .561 .61 .859 r
F P
0 g
s
.50843 .49204 m .50525 .48919 L .50282 .49182 L p .539 .578 .842 r
F P
0 g
s
.51305 .50468 m .51466 .50905 L .51775 .50739 L p .458 .424 .732 r
F P
0 g
s
.51775 .50739 m .51599 .50293 L .51305 .50468 L p .458 .424 .732 r
F P
0 g
s
.4383 .41533 m .43052 .41418 L .43132 .41775 L p .676 .251 .23 r
F P
0 g
s
.43132 .41775 m .43914 .41869 L .4383 .41533 L p .676 .251 .23 r
F P
0 g
s
.06171 .49726 m .06236 .49426 L .06257 .48901 L p 0 0 .064 r
F P
0 g
s
.06236 .49426 m .06171 .49726 L .06168 .49995 L p 0 0 .109 r
F P
0 g
s
.06228 .49979 m .06168 .49995 L .06171 .50265 L p 0 0 .135 r
F P
0 g
s
.06171 .50265 m .06236 .50536 L .06228 .49979 L p 0 0 .135 r
F P
0 g
s
.4961 .48792 m .49955 .48966 L .50178 .48674 L p .583 .639 .872 r
F P
0 g
s
.50525 .48919 m .50178 .48674 L .49955 .48966 L p .561 .61 .859 r
F P
0 g
s
.53903 .18056 m .56068 .15356 L .55584 .15333 L p 0 0 0 r
F P
0 g
s
.55584 .15333 m .53423 .18008 L .53903 .18056 L p 0 0 0 r
F P
0 g
s
.48178 .40153 m .48529 .39699 L .48276 .394 L p .339 .129 .441 r
F P
0 g
s
.48578 .38874 m .48276 .394 L .48529 .39699 L p .31 .127 .464 r
F P
0 g
s
.57625 .44616 m .58097 .44187 L .57707 .44026 L p .834 .916 .891 r
F P
0 g
s
.57707 .44026 m .57253 .44488 L .57625 .44616 L p .834 .916 .891 r
F P
0 g
s
.46695 .64433 m .45916 .69161 L .46518 .69047 L p 0 0 .319 r
F P
0 g
s
.46518 .69047 m .4719 .64314 L .46695 .64433 L p 0 0 .319 r
F P
0 g
s
.71248 .36678 m .73447 .34488 L .73128 .34058 L p .827 .999 .832 r
F P
0 g
s
.73128 .34058 m .70931 .36288 L .71248 .36678 L p .827 .999 .832 r
F P
0 g
s
.06168 .49995 m .06228 .49979 L .06236 .49426 L p 0 0 .109 r
F P
0 g
s
.51281 .23716 m .52325 .2093 L .51866 .20856 L p 0 0 .213 r
F P
0 g
s
.53423 .18008 m .51866 .20856 L .52325 .2093 L p 0 0 .118 r
F P
0 g
s
.51466 .50905 m .51578 .51397 L .51908 .51236 L p .439 .379 .694 r
F P
0 g
s
.51908 .51236 m .51775 .50739 L .51466 .50905 L p .439 .379 .694 r
F P
0 g
s
.49251 .48658 m .4961 .48792 L .49807 .48471 L p .606 .666 .882 r
F P
0 g
s
.50178 .48674 m .49807 .48471 L .4961 .48792 L p .583 .639 .872 r
F P
0 g
s
.71417 .11886 m .7164 .11918 L .71389 .11786 L p .499 0 0 r
F P
0 g
s
.71389 .11786 m .70991 .11663 L .71417 .11886 L p .499 0 0 r
F P
0 g
s
.72398 .12368 m .72697 .12648 L .73063 .12896 L p .559 0 0 r
F P
0 g
s
.72697 .12648 m .72398 .12368 L .72156 .12216 L p .576 .009 0 r
F P
0 g
s
.06393 .47706 m .06903 .45863 L .07012 .45485 L p .691 .719 .2 r
F P
0 g
s
.06903 .45863 m .06393 .47706 L .06338 .48023 L p 0 0 0 r
F P
0 g
s
.28962 .35299 m .2478 .34679 L .24642 .35104 L p .463 0 0 r
F P
0 g
s
.24642 .35104 m .2888 .35696 L .28962 .35299 L p .463 0 0 r
F P
0 g
s
.55588 .48104 m .55698 .48573 L .56047 .48482 L p .879 .684 .635 r
F P
0 g
s
.56047 .48482 m .5595 .48026 L .55588 .48104 L p .879 .684 .635 r
F P
0 g
s
.56212 .48939 m .56047 .48482 L .55698 .48573 L p .871 .646 .594 r
F P
0 g
s
.52325 .2093 m .53903 .18056 L .53423 .18008 L p 0 0 .118 r
F P
0 g
s
.55534 .47633 m .55588 .48104 L .5595 .48026 L p .882 .717 .673 r
F P
0 g
s
.5595 .48026 m .55916 .47572 L .55534 .47633 L p .882 .717 .673 r
F P
0 g
s
.19975 .34995 m .15162 .36605 L .1493 .37019 L p .103 0 0 r
F P
0 g
s
.10957 .39702 m .1493 .37019 L .15162 .36605 L p 0 0 0 r
F P
0 g
s
.38359 .57134 m .35958 .59292 L .36155 .59807 L p .821 .999 .834 r
F P
0 g
s
.32824 .62161 m .36155 .59807 L .35958 .59292 L p .767 .99 .891 r
F P
0 g
s
.57791 .50806 m .58527 .51301 L .58853 .51165 L p .762 .312 .183 r
F P
0 g
s
.59857 .51668 m .58853 .51165 L .58527 .51301 L p .719 .248 .128 r
F P
0 g
s
.49807 .48471 m .49419 .48311 L .49251 .48658 L p .606 .666 .882 r
F P
0 g
s
.48869 .48562 m .4925 .48658 L .49418 .48311 L p .631 .697 .892 r
F P
0 g
s
.55698 .48573 m .55869 .49043 L .56212 .48939 L p .871 .646 .594 r
F P
0 g
s
.56454 .49399 m .56212 .48939 L .55869 .49043 L p .859 .602 .55 r
F P
0 g
s
.06831 .5359 m .0634 .51981 L .06397 .52314 L p 0 0 .324 r
F P
0 g
s
.06397 .52314 m .06936 .542 L .06831 .5359 L p 0 0 .324 r
F P
0 g
s
.75449 .31703 m .76957 .28397 L .76667 .27931 L p .931 .957 .64 r
F P
0 g
s
.77458 .24391 m .76667 .27931 L .76957 .28397 L p .951 .879 .475 r
F P
0 g
s
.55534 .47161 m .55534 .47633 L .55916 .47572 L p .88 .745 .708 r
F P
0 g
s
.55916 .47572 m .55941 .4712 L .55534 .47161 L p .88 .745 .708 r
F P
0 g
s
.48529 .39699 m .4886 .39171 L .48578 .38874 L p .31 .127 .464 r
F P
0 g
s
.48854 .38265 m .48578 .38874 L .4886 .39171 L p .282 .128 .487 r
F P
0 g
s
.43052 .41418 m .42181 .41194 L .42259 .41582 L p .709 .272 .21 r
F P
0 g
s
.42259 .41582 m .43132 .41775 L .43052 .41418 L p .709 .272 .21 r
F P
0 g
s
.50951 .54342 m .5055 .55421 L .5098 .55259 L p .158 0 .375 r
F P
0 g
s
.5098 .55259 m .51312 .54202 L .50951 .54342 L p .158 0 .375 r
F P
0 g
s
.73447 .34488 m .75449 .31703 L .75138 .31244 L p .884 .991 .756 r
F P
0 g
s
.75138 .31244 m .73128 .34058 L .73447 .34488 L p .884 .991 .756 r
F P
0 g
s
.45339 .49365 m .44695 .498 L .44763 .50195 L p .844 .923 .884 r
F P
0 g
s
.4408 .50799 m .44763 .50195 L .44695 .498 L p .868 .931 .863 r
F P
0 g
s
.49418 .48311 m .49005 .48191 L .48869 .48562 L p .631 .697 .892 r
F P
0 g
s
.48456 .48504 m .48869 .48562 L .49005 .48191 L p .656 .721 .896 r
F P
0 g
s
.51578 .51397 m .51632 .51955 L .5199 .51793 L p .419 .333 .652 r
F P
0 g
s
.5199 .51793 m .51908 .51236 L .51578 .51397 L p .419 .333 .652 r
F P
0 g
s
.76667 .27931 m .75138 .31244 L .75449 .31703 L p .931 .957 .64 r
F P
0 g
s
.71856 .12132 m .719 .12063 L .7164 .11918 L p .544 0 0 r
F P
0 g
s
.7164 .11918 m .71417 .11886 L .71856 .12132 L p .544 0 0 r
F P
0 g
s
.72156 .12216 m .72289 .1239 L .72697 .12648 L p .576 .009 0 r
F P
0 g
s
.72289 .1239 m .72156 .12216 L .719 .12063 L p .57 0 0 r
F P
0 g
s
.55869 .49043 m .56107 .49514 L .56454 .49399 L p .859 .602 .55 r
F P
0 g
s
.56785 .49861 m .56454 .49399 L .56107 .49514 L p .841 .554 .503 r
F P
0 g
s
.58097 .44187 m .58664 .43744 L .58256 .43548 L p .811 .915 .909 r
F P
0 g
s
.58256 .43548 m .57707 .44026 L .58097 .44187 L p .811 .915 .909 r
F P
0 g
s
.78673 .67771 m .79683 .74579 L .79938 .74123 L p .93 .688 .204 r
F P
0 g
s
.79938 .74123 m .78982 .67321 L .78673 .67771 L p .93 .688 .204 r
F P
0 g
s
.55587 .46686 m .55534 .47161 L .55941 .4712 L p .876 .768 .739 r
F P
0 g
s
.55941 .4712 m .56023 .46672 L .55587 .46686 L p .876 .768 .739 r
F P
0 g
s
.49005 .48191 m .48557 .48113 L .48456 .48504 L p .656 .721 .896 r
F P
0 g
s
.48011 .48492 m .48456 .48504 L .48557 .48113 L p .683 .743 .897 r
F P
0 g
s
.68068 .55362 m .71668 .5783 L .72008 .5754 L p .696 .155 0 r
F P
0 g
s
.75901 .61505 m .72008 .5754 L .71668 .5783 L p .802 .311 0 r
F P
0 g
s
.2478 .34679 m .19975 .34995 L .19778 .35428 L p .316 0 0 r
F P
0 g
s
.19778 .35428 m .24642 .35104 L .2478 .34679 L p .316 0 0 r
F P
0 g
s
.719 .12063 m .71856 .12132 L .72289 .1239 L p .57 0 0 r
F P
0 g
s
.75305 .85078 m .73718 .86749 L .7399 .86522 L p .624 .916 .641 r
F P
0 g
s
.7399 .86522 m .75839 .84633 L .75305 .85078 L p .624 .916 .641 r
F P
0 g
s
.08361 .42769 m .07012 .45485 L .06903 .45863 L p 0 0 0 r
F P
0 g
s
.1493 .37019 m .19778 .35428 L .19975 .34995 L p .103 0 0 r
F P
0 g
s
.4886 .39171 m .49167 .38561 L .48854 .38265 L p .282 .128 .487 r
F P
0 g
s
.49101 .37565 m .48854 .38265 L .49167 .38561 L p .257 .129 .508 r
F P
0 g
s
.69619 .89042 m .67005 .89695 L .66499 .89824 L p .176 .703 .69 r
F P
0 g
s
.67005 .89695 m .69619 .89042 L .69963 .88916 L p .344 .823 .819 r
F P
0 g
s
.48557 .48113 m .48079 .48082 L .48011 .48492 L p .683 .743 .897 r
F P
0 g
s
.47537 .48531 m .48011 .48492 L .48079 .48082 L p .71 .765 .895 r
F P
0 g
s
.55694 .46211 m .55587 .46686 L .56023 .46672 L p .868 .786 .768 r
F P
0 g
s
.56023 .46672 m .56158 .46228 L .55694 .46211 L p .868 .786 .768 r
F P
0 g
s
.51632 .51955 m .51617 .52592 L .52013 .52422 L p .398 .285 .607 r
F P
0 g
s
.52013 .52422 m .5199 .51793 L .51632 .51955 L p .398 .285 .607 r
F P
0 g
s
.42181 .41194 m .41192 .40843 L .41269 .41272 L p .736 .291 .193 r
F P
0 g
s
.41269 .41272 m .42259 .41582 L .42181 .41194 L p .736 .291 .193 r
F P
0 g
s
.56107 .49514 m .56424 .4999 L .56785 .49861 L p .841 .554 .503 r
F P
0 g
s
.57223 .50329 m .56785 .49861 L .56424 .4999 L p .819 .501 .453 r
F P
0 g
s
.08358 .56795 m .06936 .542 L .07053 .54618 L p 0 0 .52 r
F P
0 g
s
.07053 .54618 m .0855 .57478 L .08358 .56795 L p 0 0 .52 r
F P
0 g
s
.58664 .43744 m .59341 .43284 L .58911 .43051 L p .789 .913 .924 r
F P
0 g
s
.58911 .43051 m .58256 .43548 L .58664 .43744 L p .789 .913 .924 r
F P
0 g
s
.48079 .48082 m .47572 .48104 L .47537 .48531 L p .71 .765 .895 r
F P
0 g
s
.47034 .48629 m .47537 .48531 L .47572 .48104 L p .737 .784 .89 r
F P
0 g
s
.35958 .59292 m .32579 .61577 L .32824 .62161 L p .767 .99 .891 r
F P
0 g
s
.28261 .64148 m .32824 .62161 L .32579 .61577 L p .673 .955 .949 r
F P
0 g
s
.44695 .498 m .43994 .5036 L .4408 .50799 L p .868 .931 .863 r
F P
0 g
s
.43321 .51568 m .4408 .50799 L .43994 .5036 L p .888 .937 .843 r
F P
0 g
s
.22261 .64321 m .16367 .63326 L .16698 .63907 L p .287 .706 .971 r
F P
0 g
s
.16698 .63907 m .22595 .64959 L .22261 .64321 L p .287 .706 .971 r
F P
0 g
s
.49449 .82183 m .55068 .87457 L .55721 .8746 L p 0 .313 .801 r
F P
0 g
s
.49167 .38561 m .49445 .3786 L .49101 .37565 L p .257 .129 .508 r
F P
0 g
s
.49315 .3676 m .49101 .37565 L .49445 .3786 L p .234 .132 .528 r
F P
0 g
s
.55854 .45738 m .55694 .46211 L .56158 .46228 L p .858 .8 .793 r
F P
0 g
s
.56158 .46228 m .56347 .45792 L .55854 .45738 L p .858 .8 .793 r
F P
0 g
s
.58527 .51301 m .5948 .51831 L .59857 .51668 L p .719 .248 .128 r
F P
0 g
s
.61168 .52231 m .59857 .51668 L .5948 .51831 L p .687 .201 .089 r
F P
0 g
s
.45916 .69161 m .46428 .75374 L .47124 .75289 L p 0 0 .476 r
F P
0 g
s
.47124 .75289 m .46518 .69047 L .45916 .69161 L p 0 0 .476 r
F P
0 g
s
.71668 .5783 m .75561 .6188 L .75901 .61505 L p .802 .311 0 r
F P
0 g
s
.78982 .67321 m .75901 .61505 L .75561 .6188 L p .898 .501 .077 r
F P
0 g
s
.69742 .11323 m .70599 .11472 L .70256 .11323 L p .481 0 0 r
F P
0 g
s
.70256 .11323 m .69207 .1109 L .69742 .11323 L p .481 0 0 r
F P
0 g
s
.47572 .48104 m .47039 .48185 L .47034 .48629 L p .737 .784 .89 r
F P
0 g
s
.46502 .48794 m .47034 .48629 L .47039 .48185 L p .765 .801 .882 r
F P
0 g
s
.73368 .13121 m .74093 .13917 L .74457 .1422 L p .652 .133 0 r
F P
0 g
s
.74093 .13917 m .73368 .13121 L .73063 .12896 L p .721 .198 0 r
F P
0 g
s
.75561 .6188 m .78673 .67771 L .78982 .67321 L p .898 .501 .077 r
F P
0 g
s
.5055 .55421 m .49972 .56776 L .50493 .56585 L p .146 0 .34 r
F P
0 g
s
.50493 .56585 m .5098 .55259 L .5055 .55421 L p .146 0 .34 r
F P
0 g
s
.50843 .49204 m .5113 .49527 L .51496 .4926 L p .586 .562 .794 r
F P
0 g
s
.5113 .49527 m .51383 .4989 L .51757 .4965 L p .571 .534 .775 r
F P
0 g
s
.51757 .4965 m .51496 .4926 L .5113 .49527 L p .571 .534 .775 r
F P
0 g
s
.56424 .4999 m .56836 .50475 L .57223 .50329 L p .819 .501 .453 r
F P
0 g
s
.57791 .50806 m .57223 .50329 L .56836 .50475 L p .792 .446 .401 r
F P
0 g
s
.51383 .4989 m .51599 .50293 L .51984 .50073 L p .557 .504 .752 r
F P
0 g
s
.51984 .50073 m .51757 .4965 L .51383 .4989 L p .557 .504 .752 r
F P
0 g
s
.51617 .52592 m .51517 .5333 L .51967 .53145 L p .377 .237 .56 r
F P
0 g
s
.51967 .53145 m .52013 .52422 L .51617 .52592 L p .377 .237 .56 r
F P
0 g
s
.50525 .48919 m .50843 .49204 L .51198 .48902 L p .6 .587 .81 r
F P
0 g
s
.51496 .4926 m .51198 .48902 L .50843 .49204 L p .586 .562 .794 r
F P
0 g
s
.56066 .4527 m .55854 .45738 L .56347 .45792 L p .846 .81 .815 r
F P
0 g
s
.56347 .45792 m .56585 .45365 L .56066 .4527 L p .846 .81 .815 r
F P
0 g
s
.41192 .40843 m .40045 .40347 L .40122 .40827 L p .757 .306 .179 r
F P
0 g
s
.40122 .40827 m .41269 .41272 L .41192 .40843 L p .757 .306 .179 r
F P
0 g
s
.59341 .43284 m .60144 .42801 L .59687 .42528 L p .769 .909 .936 r
F P
0 g
s
.59687 .42528 m .58911 .43051 L .59341 .43284 L p .769 .909 .936 r
F P
0 g
s
.51599 .50293 m .51775 .50739 L .52175 .50533 L p .543 .472 .726 r
F P
0 g
s
.52175 .50533 m .51984 .50073 L .51599 .50293 L p .543 .472 .726 r
F P
0 g
s
.64907 .11014 m .67092 .10791 L .66642 .10676 L p .292 0 0 r
F P
0 g
s
.66642 .10676 m .64306 .10856 L .64907 .11014 L p .292 0 0 r
F P
0 g
s
.32579 .61577 m .27964 .63515 L .28261 .64148 L p .673 .955 .949 r
F P
0 g
s
.22595 .64959 m .28261 .64148 L .27964 .63515 L p .52 .871 .988 r
F P
0 g
s
.49445 .3786 m .49695 .37057 L .49315 .3676 L p .234 .132 .528 r
F P
0 g
s
.49497 .35834 m .49315 .3676 L .49695 .37057 L p .214 .135 .545 r
F P
0 g
s
.50178 .48674 m .50525 .48919 L .50864 .48575 L p .615 .61 .823 r
F P
0 g
s
.51198 .48902 m .50864 .48575 L .50525 .48919 L p .6 .587 .81 r
F P
0 g
s
.47039 .48185 m .46479 .48329 L .46502 .48794 L p .765 .801 .882 r
F P
0 g
s
.45938 .49035 m .46502 .48794 L .46479 .48329 L p .791 .817 .872 r
F P
0 g
s
.27964 .63515 m .22261 .64321 L .22595 .64959 L p .52 .871 .988 r
F P
0 g
s
.76774 .18158 m .75761 .15979 L .75422 .15632 L p .889 .494 .05 r
F P
0 g
s
.74457 .1422 m .75422 .15632 L .75761 .15979 L p .726 .262 0 r
F P
0 g
s
.49807 .48471 m .50178 .48674 L .50492 .48285 L p .63 .63 .832 r
F P
0 g
s
.50864 .48575 m .50492 .48285 L .50178 .48674 L p .615 .61 .823 r
F P
0 g
s
.51775 .50739 m .51908 .51236 L .5233 .51035 L p .529 .438 .696 r
F P
0 g
s
.5233 .51035 m .52175 .50533 L .51775 .50739 L p .529 .438 .696 r
F P
0 g
s
.06338 .48023 m .06807 .4642 L .06903 .45863 L p 0 0 0 r
F P
0 g
s
.06807 .4642 m .06338 .48023 L .06292 .48426 L p 0 0 .123 r
F P
0 g
s
.43994 .5036 m .43214 .51073 L .43321 .51568 L p .888 .937 .843 r
F P
0 g
s
.42449 .52541 m .43321 .51568 L .43214 .51073 L p .901 .939 .826 r
F P
0 g
s
.55122 .48217 m .55252 .487 L .55698 .48573 L p .826 .652 .666 r
F P
0 g
s
.55698 .48573 m .55588 .48104 L .55122 .48217 L p .826 .652 .666 r
F P
0 g
s
.55869 .49043 m .55698 .48573 L .55252 .487 L p .821 .622 .634 r
F P
0 g
s
.77883 .81 m .75839 .84633 L .76173 .84287 L p .806 .945 .593 r
F P
0 g
s
.76173 .84287 m .78429 .80447 L .77883 .81 L p .806 .945 .593 r
F P
0 g
s
.55039 .47729 m .55122 .48217 L .55588 .48104 L p .829 .677 .695 r
F P
0 g
s
.55588 .48104 m .55534 .47633 L .55039 .47729 L p .829 .677 .695 r
F P
0 g
s
.46917 .41216 m .46414 .41471 L .46605 .41934 L p .585 .331 .498 r
F P
0 g
s
.46414 .41471 m .45866 .4167 L .46033 .42134 L p .613 .341 .481 r
F P
0 g
s
.46033 .42134 m .46605 .41934 L .46414 .41471 L p .613 .341 .481 r
F P
0 g
s
.49419 .48311 m .49807 .48471 L .50086 .48037 L p .646 .648 .838 r
F P
0 g
s
.50492 .48285 m .50086 .48037 L .49807 .48471 L p .63 .63 .832 r
F P
0 g
s
.45866 .4167 m .45271 .41807 L .45419 .42276 L p .642 .352 .464 r
F P
0 g
s
.45419 .42276 m .46033 .42134 L .45866 .4167 L p .642 .352 .464 r
F P
0 g
s
.47379 .40908 m .46917 .41216 L .4714 .4168 L p .559 .323 .515 r
F P
0 g
s
.46605 .41934 m .4714 .4168 L .46917 .41216 L p .585 .331 .498 r
F P
0 g
s
.55252 .487 m .5543 .49182 L .55869 .49043 L p .821 .622 .634 r
F P
0 g
s
.56107 .49514 m .55869 .49043 L .5543 .49182 L p .811 .588 .6 r
F P
0 g
s
.06744 .52818 m .06293 .51561 L .0634 .51981 L p 0 0 .404 r
F P
0 g
s
.0634 .51981 m .06831 .5359 L .06744 .52818 L p 0 0 .404 r
F P
0 g
s
.56585 .45364 m .56882 .44934 L .56339 .44796 L p .838 .819 .83 r
F P
0 g
s
.56339 .44796 m .56066 .4527 L .56585 .45364 L p .838 .819 .83 r
F P
0 g
s
.55002 .47233 m .55039 .47729 L .55534 .47633 L p .828 .699 .721 r
F P
0 g
s
.55534 .47633 m .55534 .47161 L .55002 .47233 L p .828 .699 .721 r
F P
0 g
s
.46428 .75374 m .49449 .82183 L .50179 .82147 L p 0 .11 .652 r
F P
0 g
s
.50179 .82147 m .47124 .75289 L .46428 .75374 L p 0 .11 .652 r
F P
0 g
s
.45271 .41807 m .44623 .41876 L .44758 .42358 L p .671 .365 .446 r
F P
0 g
s
.44758 .42358 m .45419 .42276 L .45271 .41807 L p .671 .365 .446 r
F P
0 g
s
.47799 .40553 m .47379 .40908 L .47637 .41374 L p .533 .317 .532 r
F P
0 g
s
.4714 .4168 m .47637 .41374 L .47379 .40908 L p .559 .323 .515 r
F P
0 g
s
.50086 .48037 m .49654 .47836 L .49419 .48311 L p .646 .648 .838 r
F P
0 g
s
.49005 .48191 m .49418 .48311 L .49654 .47836 L p .665 .671 .846 r
F P
0 g
s
.55721 .8746 m .50179 .82147 L .49449 .82183 L p 0 .313 .801 r
F P
0 g
s
.61811 .89768 m .66499 .89824 L .67005 .89695 L p .283 .764 .924 r
F P
0 g
s
.46479 .48329 m .45891 .48543 L .45938 .49035 L p .791 .817 .872 r
F P
0 g
s
.45339 .49365 m .45938 .49035 L .45891 .48543 L p .816 .83 .86 r
F P
0 g
s
.51908 .51236 m .5199 .51793 L .52445 .51589 L p .513 .401 .663 r
F P
0 g
s
.52445 .51589 m .5233 .51035 L .51908 .51236 L p .513 .401 .663 r
F P
0 g
s
.49695 .37057 m .49915 .36136 L .49497 .35834 L p .214 .135 .545 r
F P
0 g
s
.49648 .34768 m .49497 .35834 L .49915 .36136 L p .199 .138 .559 r
F P
0 g
s
.60144 .42801 m .61092 .42282 L .60603 .41966 L p .753 .905 .944 r
F P
0 g
s
.60603 .41966 m .59687 .42528 L .60144 .42801 L p .753 .905 .944 r
F P
0 g
s
.56836 .50475 m .57364 .50974 L .57791 .50806 L p .792 .446 .401 r
F P
0 g
s
.58527 .51301 m .57791 .50806 L .57364 .50974 L p .762 .39 .351 r
F P
0 g
s
.67718 .11024 m .69207 .1109 L .68774 .1093 L p .442 0 0 r
F P
0 g
s
.68774 .1093 m .67092 .10791 L .67718 .11024 L p .442 0 0 r
F P
0 g
s
.5543 .49182 m .55664 .49667 L .56107 .49514 L p .811 .588 .6 r
F P
0 g
s
.56424 .4999 m .56107 .49514 L .55664 .49667 L p .799 .551 .563 r
F P
0 g
s
.49654 .47836 m .4919 .47684 L .49005 .48191 L p .665 .671 .846 r
F P
0 g
s
.48557 .48113 m .49005 .48191 L .4919 .47684 L p .683 .688 .848 r
F P
0 g
s
.55011 .46727 m .55002 .47233 L .55534 .47161 L p .825 .716 .745 r
F P
0 g
s
.55534 .47161 m .55587 .46686 L .55011 .46727 L p .825 .716 .745 r
F P
0 g
s
.48178 .40153 m .47799 .40553 L .48096 .41019 L p .509 .312 .548 r
F P
0 g
s
.47637 .41374 m .48096 .41019 L .47799 .40553 L p .533 .317 .532 r
F P
0 g
s
.51517 .5333 m .51312 .54202 L .51835 .53993 L p .357 .191 .514 r
F P
0 g
s
.51835 .53993 m .51967 .53145 L .51517 .5333 L p .357 .191 .514 r
F P
0 g
s
.5948 .51831 m .60723 .52431 L .61168 .52231 L p .687 .201 .089 r
F P
0 g
s
.62887 .52923 m .61168 .52231 L .60723 .52431 L p .673 .181 .073 r
F P
0 g
s
.75422 .15632 m .74457 .1422 L .74093 .13917 L p .832 .367 0 r
F P
0 g
s
.44623 .41876 m .43914 .41869 L .44041 .42372 L p .7 .378 .429 r
F P
0 g
s
.44041 .42372 m .44758 .42358 L .44623 .41876 L p .7 .378 .429 r
F P
0 g
s
.40045 .40347 m .38683 .39683 L .3876 .40228 L p .771 .316 .17 r
F P
0 g
s
.3876 .40228 m .40122 .40827 L .40045 .40347 L p .771 .316 .17 r
F P
0 g
s
.74591 .85603 m .73358 .87015 L .73718 .86749 L p .698 .97 .751 r
F P
0 g
s
.73718 .86749 m .75305 .85078 L .74591 .85603 L p .698 .97 .751 r
F P
0 g
s
.56882 .44934 m .57253 .44488 L .56687 .44302 L p .824 .824 .849 r
F P
0 g
s
.56687 .44302 m .56339 .44796 L .56882 .44934 L p .824 .824 .849 r
F P
0 g
s
.4919 .47684 m .4869 .4758 L .48557 .48113 L p .683 .688 .848 r
F P
0 g
s
.48079 .48082 m .48557 .48113 L .4869 .4758 L p .702 .704 .848 r
F P
0 g
s
.70356 .11622 m .70991 .11663 L .70599 .11472 L p .579 .009 0 r
F P
0 g
s
.70599 .11472 m .69742 .11323 L .70356 .11622 L p .579 .009 0 r
F P
0 g
s
.73063 .12896 m .73612 .13563 L .74093 .13917 L p .721 .198 0 r
F P
0 g
s
.73612 .13563 m .73063 .12896 L .72697 .12648 L p .748 .227 0 r
F P
0 g
s
.69963 .88916 m .67705 .89437 L .67005 .89695 L p .344 .823 .819 r
F P
0 g
s
.67705 .89437 m .69963 .88916 L .70385 .88731 L p .477 .895 .892 r
F P
0 g
s
.48096 .41019 m .48517 .40618 L .48178 .40153 L p .509 .312 .548 r
F P
0 g
s
.48529 .39699 m .48178 .40153 L .48517 .40618 L p .483 .305 .564 r
F P
0 g
s
.49972 .56776 m .49191 .58545 L .49833 .58314 L p .143 0 .331 r
F P
0 g
s
.49833 .58314 m .50493 .56585 L .49972 .56776 L p .143 0 .331 r
F P
0 g
s
.55072 .4621 m .55011 .46727 L .55587 .46686 L p .819 .73 .766 r
F P
0 g
s
.55587 .46686 m .55694 .46211 L .55072 .4621 L p .819 .73 .766 r
F P
0 g
s
.4869 .4758 m .4816 .47531 L .48079 .48082 L p .702 .704 .848 r
F P
0 g
s
.47572 .48104 m .48079 .48082 L .4816 .47531 L p .723 .718 .846 r
F P
0 g
s
.5199 .51793 m .52013 .52422 L .52516 .52207 L p .497 .362 .628 r
F P
0 g
s
.52516 .52207 m .52445 .51589 L .5199 .51793 L p .497 .362 .628 r
F P
0 g
s
.45891 .48543 m .45268 .48838 L .45339 .49365 L p .816 .83 .86 r
F P
0 g
s
.44695 .498 m .45339 .49365 L .45268 .48838 L p .839 .841 .847 r
F P
0 g
s
.55664 .49667 m .55963 .50159 L .56424 .4999 L p .799 .551 .563 r
F P
0 g
s
.56836 .50475 m .56424 .4999 L .55963 .50159 L p .782 .51 .524 r
F P
0 g
s
.51496 .4926 m .51757 .4965 L .52219 .49378 L p .621 .553 .757 r
F P
0 g
s
.51757 .4965 m .51984 .50073 L .5245 .49824 L p .61 .529 .738 r
F P
0 g
s
.5245 .49824 m .52219 .49378 L .51757 .4965 L p .61 .529 .738 r
F P
0 g
s
.43214 .51073 m .42318 .51973 L .42449 .52541 L p .901 .939 .826 r
F P
0 g
s
.41406 .53762 m .42449 .52541 L .42318 .51973 L p .907 .939 .818 r
F P
0 g
s
.43914 .41869 m .43132 .41775 L .43255 .4231 L p .728 .393 .412 r
F P
0 g
s
.43255 .4231 m .44041 .42372 L .43914 .41869 L p .728 .393 .412 r
F P
0 g
s
.51198 .48902 m .51496 .4926 L .51957 .48953 L p .63 .575 .773 r
F P
0 g
s
.52219 .49378 m .51957 .48953 L .51496 .4926 L p .621 .553 .757 r
F P
0 g
s
.49915 .36136 m .5011 .35077 L .49648 .34768 L p .199 .138 .559 r
F P
0 g
s
.49777 .33535 m .49648 .34768 L .5011 .35077 L p .188 .14 .569 r
F P
0 g
s
.51984 .50073 m .52175 .50533 L .52652 .50297 L p .6 .503 .716 r
F P
0 g
s
.52652 .50297 m .5245 .49824 L .51984 .50073 L p .6 .503 .716 r
F P
0 g
s
.50864 .48575 m .51198 .48902 L .51659 .48549 L p .64 .594 .786 r
F P
0 g
s
.51957 .48953 m .51659 .48549 L .51198 .48902 L p .63 .575 .773 r
F P
0 g
s
.61092 .42282 m .62207 .4171 L .61681 .41346 L p .743 .902 .949 r
F P
0 g
s
.61681 .41346 m .60603 .41966 L .61092 .42282 L p .743 .902 .949 r
F P
0 g
s
.48517 .40618 m .4891 .4016 L .48529 .39699 L p .483 .305 .564 r
F P
0 g
s
.4886 .39171 m .48529 .39699 L .4891 .4016 L p .462 .304 .58 r
F P
0 g
s
.4816 .47531 m .47608 .47538 L .47572 .48104 L p .723 .718 .846 r
F P
0 g
s
.47039 .48185 m .47572 .48104 L .47608 .47538 L p .744 .732 .841 r
F P
0 g
s
.57253 .44488 m .57707 .44026 L .57117 .43791 L p .808 .827 .865 r
F P
0 g
s
.57117 .43791 m .56687 .44302 L .57253 .44488 L p .808 .827 .865 r
F P
0 g
s
.50492 .48285 m .50864 .48575 L .51317 .48163 L p .65 .61 .795 r
F P
0 g
s
.51659 .48549 m .51317 .48163 L .50864 .48575 L p .64 .594 .786 r
F P
0 g
s
.55189 .45684 m .55072 .4621 L .55694 .46211 L p .812 .74 .785 r
F P
0 g
s
.55694 .46211 m .55854 .45738 L .55189 .45684 L p .812 .74 .785 r
F P
0 g
s
.52175 .50533 m .5233 .51035 L .52829 .50804 L p .588 .474 .691 r
F P
0 g
s
.52829 .50804 m .52652 .50297 L .52175 .50533 L p .588 .474 .691 r
F P
0 g
s
.06292 .48426 m .06727 .47136 L .06807 .4642 L p 0 0 .123 r
F P
0 g
s
.06727 .47136 m .06292 .48426 L .06257 .48901 L p 0 0 .243 r
F P
0 g
s
.54573 .48372 m .54727 .48865 L .55252 .487 L p .785 .625 .683 r
F P
0 g
s
.55252 .487 m .55122 .48217 L .54573 .48372 L p .785 .625 .683 r
F P
0 g
s
.5543 .49182 m .55252 .487 L .54727 .48865 L p .78 .601 .657 r
F P
0 g
s
.54451 .47871 m .54573 .48372 L .55122 .48217 L p .787 .646 .707 r
F P
0 g
s
.55122 .48217 m .55039 .47729 L .54451 .47871 L p .787 .646 .707 r
F P
0 g
s
.57364 .50974 m .58041 .51498 L .58527 .51301 L p .762 .39 .351 r
F P
0 g
s
.5948 .51831 m .58527 .51301 L .58041 .51498 L p .733 .341 .306 r
F P
0 g
s
.06678 .51921 m .06257 .51071 L .06293 .51561 L p 0 0 .442 r
F P
0 g
s
.06293 .51561 m .06744 .52818 L .06678 .51921 L p 0 0 .442 r
F P
0 g
s
.50086 .48037 m .50492 .48285 L .50924 .47803 L p .66 .623 .802 r
F P
0 g
s
.51317 .48163 m .50924 .47803 L .50492 .48285 L p .65 .61 .795 r
F P
0 g
s
.54727 .48865 m .54916 .49357 L .5543 .49182 L p .78 .601 .657 r
F P
0 g
s
.55664 .49667 m .5543 .49182 L .54916 .49357 L p .772 .573 .629 r
F P
0 g
s
.47608 .47538 m .47036 .47602 L .47039 .48185 L p .744 .732 .841 r
F P
0 g
s
.46479 .48329 m .47039 .48185 L .47036 .47602 L p .765 .745 .835 r
F P
0 g
s
.54361 .47354 m .54451 .47871 L .55039 .47729 L p .787 .664 .728 r
F P
0 g
s
.55039 .47729 m .55002 .47233 L .54361 .47354 L p .787 .664 .728 r
F P
0 g
s
.71023 .11972 m .71417 .11886 L .70991 .11663 L p .647 .099 0 r
F P
0 g
s
.70991 .11663 m .70356 .11622 L .71023 .11972 L p .647 .099 0 r
F P
0 g
s
.4891 .4016 m .49285 .39627 L .4886 .39171 L p .462 .304 .58 r
F P
0 g
s
.49167 .38561 m .4886 .39171 L .49285 .39627 L p .442 .303 .596 r
F P
0 g
s
.43132 .41775 m .42259 .41582 L .42382 .42162 L p .753 .407 .396 r
F P
0 g
s
.42382 .42162 m .43255 .4231 L .43132 .41775 L p .753 .407 .396 r
F P
0 g
s
.38683 .39683 m .37024 .38841 L .37096 .39464 L p .775 .319 .166 r
F P
0 g
s
.37096 .39464 m .3876 .40228 L .38683 .39683 L p .775 .319 .166 r
F P
0 g
s
.72697 .12648 m .73038 .13173 L .73612 .13563 L p .748 .227 0 r
F P
0 g
s
.73038 .13173 m .72697 .12648 L .72289 .1239 L p .747 .229 0 r
F P
0 g
s
.51312 .54202 m .5098 .55259 L .51601 .55016 L p .34 .152 .474 r
F P
0 g
s
.51601 .55016 m .51835 .53993 L .51312 .54202 L p .34 .152 .474 r
F P
0 g
s
.55963 .50159 m .56339 .50663 L .56836 .50475 L p .782 .51 .524 r
F P
0 g
s
.57364 .50974 m .56836 .50475 L .56339 .50663 L p .763 .466 .483 r
F P
0 g
s
.45268 .48838 m .44601 .49225 L .44695 .498 L p .839 .841 .847 r
F P
0 g
s
.43994 .5036 m .44695 .498 L .44601 .49225 L p .86 .85 .832 r
F P
0 g
s
.52013 .52422 m .51967 .53145 L .52536 .5291 L p .48 .323 .59 r
F P
0 g
s
.52536 .5291 m .52516 .52207 L .52013 .52422 L p .48 .323 .59 r
F P
0 g
s
.49654 .47836 m .50086 .48037 L .50473 .4748 L p .67 .634 .805 r
F P
0 g
s
.50924 .47803 m .50473 .4748 L .50086 .48037 L p .66 .623 .802 r
F P
0 g
s
.5233 .51035 m .52445 .51589 L .5298 .51354 L p .576 .443 .663 r
F P
0 g
s
.5298 .51354 m .52829 .50804 L .5233 .51035 L p .576 .443 .663 r
F P
0 g
s
.5011 .35077 m .50288 .33855 L .49777 .33535 L p .188 .14 .569 r
F P
0 g
s
.499 .32105 m .49777 .33535 L .50288 .33855 L p .182 .141 .574 r
F P
0 g
s
.55365 .45157 m .55189 .45684 L .55854 .45738 L p .803 .747 .801 r
F P
0 g
s
.55854 .45738 m .56066 .4527 L .55365 .45157 L p .803 .747 .801 r
F P
0 g
s
.54916 .49357 m .55144 .49854 L .55664 .49667 L p .772 .573 .629 r
F P
0 g
s
.55963 .50159 m .55664 .49667 L .55144 .49854 L p .761 .541 .599 r
F P
0 g
s
.57707 .44026 m .58256 .43548 L .57639 .43263 L p .792 .828 .88 r
F P
0 g
s
.57639 .43263 m .57117 .43791 L .57707 .44026 L p .792 .828 .88 r
F P
0 g
s
.10957 .39702 m .08361 .42769 L .08199 .43348 L p 0 0 .012 r
F P
0 g
s
.06903 .45863 m .08199 .43348 L .08361 .42769 L p 0 0 0 r
F P
0 g
s
.54306 .46816 m .54361 .47354 L .55002 .47233 L p .785 .678 .746 r
F P
0 g
s
.55002 .47233 m .55011 .46727 L .54306 .46816 L p .785 .678 .746 r
F P
0 g
s
.50473 .4748 m .49973 .47214 L .49654 .47836 L p .67 .634 .805 r
F P
0 g
s
.4919 .47684 m .49654 .47836 L .49972 .47214 L p .683 .651 .811 r
F P
0 g
s
.62207 .4171 m .63515 .41053 L .62944 .40637 L p .74 .901 .95 r
F P
0 g
s
.62944 .40637 m .61681 .41346 L .62207 .4171 L p .74 .901 .95 r
F P
0 g
s
.62319 .11832 m .64907 .11014 L .64306 .10856 L p .316 0 0 r
F P
0 g
s
.64306 .10856 m .61573 .11626 L .62319 .11832 L p .316 0 0 r
F P
0 g
s
.47036 .47602 m .46443 .47726 L .46479 .48329 L p .765 .745 .835 r
F P
0 g
s
.45891 .48543 m .46479 .48329 L .46443 .47726 L p .786 .757 .827 r
F P
0 g
s
.60723 .52431 m .62356 .53172 L .62887 .52923 L p .673 .181 .073 r
F P
0 g
s
.65144 .53878 m .62887 .52923 L .62356 .53172 L p .684 .196 .084 r
F P
0 g
s
.51957 .48953 m .52219 .49378 L .52758 .49092 L p .658 .569 .743 r
F P
0 g
s
.52219 .49378 m .5245 .49824 L .52982 .49561 L p .651 .549 .726 r
F P
0 g
s
.52982 .49561 m .52758 .49092 L .52219 .49378 L p .651 .549 .726 r
F P
0 g
s
.73725 .86187 m .72925 .87309 L .73358 .87015 L p .73 .99 .824 r
F P
0 g
s
.73358 .87015 m .74591 .85603 L .73725 .86187 L p .73 .99 .824 r
F P
0 g
s
.08199 .43348 m .06903 .45863 L .06807 .4642 L p 0 0 .144 r
F P
0 g
s
.51659 .48549 m .51957 .48953 L .52511 .48631 L p .665 .586 .758 r
F P
0 g
s
.52758 .49092 m .52511 .48631 L .51957 .48953 L p .658 .569 .743 r
F P
0 g
s
.5245 .49824 m .52652 .50297 L .53191 .50047 L p .642 .526 .706 r
F P
0 g
s
.53191 .50047 m .52982 .49561 L .5245 .49824 L p .642 .526 .706 r
F P
0 g
s
.49285 .39627 m .49636 .39014 L .49167 .38561 L p .442 .303 .596 r
F P
0 g
s
.49445 .3786 m .49167 .38561 L .49636 .39014 L p .423 .304 .612 r
F P
0 g
s
.49972 .47214 m .49426 .47016 L .4919 .47684 L p .683 .651 .811 r
F P
0 g
s
.4869 .4758 m .4919 .47684 L .49426 .47016 L p .696 .661 .811 r
F P
0 g
s
.71713 .12359 m .71856 .12132 L .71417 .11886 L p .695 .164 0 r
F P
0 g
s
.71417 .11886 m .71023 .11972 L .71713 .12359 L p .695 .164 0 r
F P
0 g
s
.72289 .1239 m .72395 .12766 L .73038 .13173 L p .747 .229 0 r
F P
0 g
s
.72395 .12766 m .72289 .1239 L .71856 .12132 L p .728 .207 0 r
F P
0 g
s
.70385 .88731 m .68568 .89061 L .67705 .89437 L p .477 .895 .892 r
F P
0 g
s
.68568 .89061 m .70385 .88731 L .70866 .88498 L p .573 .935 .923 r
F P
0 g
s
.7744 .21017 m .76774 .18158 L .76311 .17686 L p .976 .677 .311 r
F P
0 g
s
.75422 .15632 m .76311 .17686 L .76774 .18158 L p .889 .494 .05 r
F P
0 g
s
.4714 .4168 m .46605 .41934 L .46842 .42548 L p .638 .427 .58 r
F P
0 g
s
.46605 .41934 m .46033 .42134 L .46238 .42743 L p .659 .434 .567 r
F P
0 g
s
.46238 .42743 m .46842 .42548 L .46605 .41934 L p .659 .434 .567 r
F P
0 g
s
.42318 .51973 m .41247 .53101 L .41406 .53762 L p .907 .939 .818 r
F P
0 g
s
.40095 .55282 m .41406 .53762 L .41247 .53101 L p .906 .938 .82 r
F P
0 g
s
.46033 .42134 m .45419 .42276 L .45601 .42889 L p .682 .443 .554 r
F P
0 g
s
.45601 .42889 m .46238 .42743 L .46033 .42134 L p .682 .443 .554 r
F P
0 g
s
.51317 .48163 m .51659 .48549 L .52234 .48174 L p .67 .601 .769 r
F P
0 g
s
.52511 .48631 m .52234 .48174 L .51659 .48549 L p .665 .586 .758 r
F P
0 g
s
.47637 .41374 m .4714 .4168 L .47419 .42302 L p .618 .421 .593 r
F P
0 g
s
.46842 .42548 m .47419 .42302 L .4714 .4168 L p .638 .427 .58 r
F P
0 g
s
.53971 .48572 m .54153 .49068 L .54727 .48865 L p .749 .603 .695 r
F P
0 g
s
.54727 .48865 m .54573 .48372 L .53971 .48572 L p .749 .603 .695 r
F P
0 g
s
.54916 .49357 m .54727 .48865 L .54153 .49068 L p .744 .581 .673 r
F P
0 g
s
.06257 .48901 m .06668 .47984 L .06727 .47136 L p 0 0 .243 r
F P
0 g
s
.06668 .47984 m .06257 .48901 L .06236 .49426 L p 0 0 .331 r
F P
0 g
s
.54295 .46248 m .54306 .46816 L .55011 .46727 L p .78 .689 .763 r
F P
0 g
s
.55011 .46727 m .55072 .4621 L .54295 .46248 L p .78 .689 .763 r
F P
0 g
s
.71856 .12132 m .71713 .12359 L .72395 .12766 L p .728 .207 0 r
F P
0 g
s
.53802 .48069 m .53971 .48572 L .54573 .48372 L p .752 .622 .715 r
F P
0 g
s
.54573 .48372 m .54451 .47871 L .53802 .48069 L p .752 .622 .715 r
F P
0 g
s
.52652 .50297 m .52829 .50804 L .53386 .50557 L p .633 .501 .684 r
F P
0 g
s
.53386 .50557 m .53191 .50047 L .52652 .50297 L p .633 .501 .684 r
F P
0 g
s
.49426 .47016 m .48842 .46889 L .4869 .4758 L p .696 .661 .811 r
F P
0 g
s
.4816 .47531 m .4869 .4758 L .48842 .46889 L p .711 .671 .81 r
F P
0 g
s
.56066 .4527 m .56339 .44796 L .55608 .44618 L p .799 .754 .811 r
F P
0 g
s
.55608 .44618 m .55365 .45156 L .56066 .4527 L p .799 .754 .811 r
F P
0 g
s
.52445 .51589 m .52516 .52207 L .53104 .51959 L p .562 .41 .633 r
F P
0 g
s
.53104 .51959 m .5298 .51354 L .52445 .51589 L p .562 .41 .633 r
F P
0 g
s
.42259 .41582 m .41269 .41272 L .41395 .41914 L p .776 .42 .381 r
F P
0 g
s
.41395 .41914 m .42382 .42162 L .42259 .41582 L p .776 .42 .381 r
F P
0 g
s
.55144 .49854 m .5542 .50362 L .55963 .50159 L p .761 .541 .599 r
F P
0 g
s
.56339 .50663 m .55963 .50159 L .5542 .50362 L p .748 .507 .566 r
F P
0 g
s
.06636 .50943 m .06236 .50536 L .06257 .51071 L p 0 0 .449 r
F P
0 g
s
.06257 .51071 m .06678 .51921 L .06636 .50943 L p 0 0 .449 r
F P
0 g
s
.49191 .58545 m .48221 .60947 L .49021 .60666 L p .152 0 .355 r
F P
0 g
s
.49021 .60666 m .49833 .58314 L .49191 .58545 L p .152 0 .355 r
F P
0 g
s
.45419 .42276 m .44758 .42358 L .44925 .42983 L p .704 .452 .541 r
F P
0 g
s
.44925 .42983 m .45601 .42889 L .45419 .42276 L p .704 .452 .541 r
F P
0 g
s
.54153 .49068 m .54351 .49565 L .54916 .49357 L p .744 .581 .673 r
F P
0 g
s
.55144 .49854 m .54916 .49357 L .54351 .49565 L p .737 .556 .649 r
F P
0 g
s
.48096 .41019 m .47637 .41374 L .47967 .42004 L p .598 .416 .606 r
F P
0 g
s
.47419 .42302 m .47967 .42004 L .47637 .41374 L p .618 .421 .593 r
F P
0 g
s
.08183 .55792 m .06831 .5359 L .06936 .542 L p 0 .085 .636 r
F P
0 g
s
.06936 .542 m .08358 .56795 L .08183 .55792 L p 0 .085 .636 r
F P
0 g
s
.50924 .47803 m .51317 .48163 L .51912 .47713 L p .676 .612 .776 r
F P
0 g
s
.52234 .48174 m .51912 .47713 L .51317 .48163 L p .67 .601 .769 r
F P
0 g
s
.53645 .47546 m .53802 .48069 L .54451 .47871 L p .753 .637 .733 r
F P
0 g
s
.54451 .47871 m .54361 .47354 L .53645 .47546 L p .753 .637 .733 r
F P
0 g
s
.46443 .47726 m .45825 .47911 L .45891 .48543 L p .786 .757 .827 r
F P
0 g
s
.45268 .48838 m .45891 .48543 L .45825 .47911 L p .807 .768 .817 r
F P
0 g
s
.11293 .59715 m .08358 .56795 L .0855 .57478 L p .002 .298 .793 r
F P
0 g
s
.0855 .57478 m .1157 .60708 L .11293 .59715 L p .002 .298 .793 r
F P
0 g
s
.48842 .46889 m .4824 .46831 L .4816 .47531 L p .711 .671 .81 r
F P
0 g
s
.47608 .47538 m .4816 .47531 L .4824 .46831 L p .727 .681 .806 r
F P
0 g
s
.58256 .43548 m .58911 .43051 L .58262 .42713 L p .777 .828 .892 r
F P
0 g
s
.58262 .42713 m .57639 .43263 L .58256 .43548 L p .777 .828 .892 r
F P
0 g
s
.44601 .49225 m .43876 .49723 L .43994 .5036 L p .86 .85 .832 r
F P
0 g
s
.43214 .51073 m .43994 .5036 L .43876 .49723 L p .876 .857 .819 r
F P
0 g
s
.50288 .33855 m .50467 .32438 L .499 .32105 L p .182 .141 .574 r
F P
0 g
s
.50046 .30439 m .499 .32105 L .50467 .32438 L p .183 .14 .572 r
F P
0 g
s
.56339 .50663 m .56814 .51189 L .57364 .50974 L p .763 .466 .483 r
F P
0 g
s
.58041 .51498 m .57364 .50974 L .56814 .51189 L p .741 .422 .442 r
F P
0 g
s
.68496 .11366 m .69742 .11323 L .69207 .1109 L p .574 .041 0 r
F P
0 g
s
.69207 .1109 m .67718 .11024 L .68496 .11366 L p .574 .041 0 r
F P
0 g
s
.52511 .48631 m .52758 .49092 L .53353 .48816 L p .69 .584 .732 r
F P
0 g
s
.52758 .49092 m .52982 .49561 L .5356 .49304 L p .685 .566 .715 r
F P
0 g
s
.5356 .49304 m .53353 .48816 L .52758 .49092 L p .685 .566 .715 r
F P
0 g
s
.52982 .49561 m .53191 .50047 L .53766 .49798 L p .678 .545 .696 r
F P
0 g
s
.53766 .49798 m .5356 .49304 L .52982 .49561 L p .678 .545 .696 r
F P
0 g
s
.48517 .40618 m .48096 .41019 L .48485 .41652 L p .58 .412 .619 r
F P
0 g
s
.47967 .42004 m .48485 .41652 L .48096 .41019 L p .598 .416 .606 r
F P
0 g
s
.49636 .39014 m .49962 .38312 L .49445 .3786 L p .423 .304 .612 r
F P
0 g
s
.49695 .37057 m .49445 .3786 L .49962 .38312 L p .406 .304 .626 r
F P
0 g
s
.51967 .53145 m .51835 .53993 L .52495 .53727 L p .463 .285 .553 r
F P
0 g
s
.52495 .53727 m .52536 .5291 L .51967 .53145 L p .463 .285 .553 r
F P
0 g
s
.74093 .13917 m .74887 .15187 L .75422 .15632 L p .832 .367 0 r
F P
0 g
s
.74887 .15187 m .74093 .13917 L .73612 .13563 L p .86 .411 .11 r
F P
0 g
s
.52829 .50804 m .5298 .51354 L .53573 .51101 L p .622 .473 .658 r
F P
0 g
s
.53573 .51101 m .53386 .50557 L .52829 .50804 L p .622 .473 .658 r
F P
0 g
s
.50473 .4748 m .50924 .47803 L .51526 .47246 L p .681 .619 .78 r
F P
0 g
s
.51912 .47713 m .51526 .47246 L .50924 .47803 L p .676 .612 .776 r
F P
0 g
s
.52234 .48174 m .52511 .48631 L .53139 .48327 L p .694 .6 .746 r
F P
0 g
s
.53353 .48816 m .53139 .48327 L .52511 .48631 L p .69 .584 .732 r
F P
0 g
s
.58041 .51498 m .58914 .52067 L .5948 .51831 L p .733 .341 .306 r
F P
0 g
s
.60723 .52431 m .5948 .51831 L .58914 .52067 L p .711 .304 .273 r
F P
0 g
s
.44758 .42358 m .44041 .42372 L .442 .43023 L p .727 .463 .527 r
F P
0 g
s
.442 .43023 m .44925 .42983 L .44758 .42358 L p .727 .463 .527 r
F P
0 g
s
.37024 .38841 m .34945 .37831 L .35007 .38545 L p .768 .312 .166 r
F P
0 g
s
.35007 .38545 m .37096 .39464 L .37024 .38841 L p .768 .312 .166 r
F P
0 g
s
.54351 .49565 m .54572 .5007 L .55144 .49854 L p .737 .556 .649 r
F P
0 g
s
.5542 .50362 m .55144 .49854 L .54572 .5007 L p .728 .529 .622 r
F P
0 g
s
.63515 .41053 m .65039 .40264 L .64417 .3979 L p .746 .901 .947 r
F P
0 g
s
.64417 .3979 m .62944 .40637 L .63515 .41053 L p .746 .901 .947 r
F P
0 g
s
.53353 .48816 m .5356 .49304 L .54153 .49068 L p .717 .584 .706 r
F P
0 g
s
.54153 .49068 m .53971 .48572 L .53353 .48816 L p .717 .584 .706 r
F P
0 g
s
.54351 .49565 m .54153 .49068 L .5356 .49304 L p .711 .563 .685 r
F P
0 g
s
.54343 .4565 m .54295 .46248 L .55072 .4621 L p .774 .696 .777 r
F P
0 g
s
.55072 .4621 m .55189 .45684 L .54343 .4565 L p .774 .696 .777 r
F P
0 g
s
.53139 .48327 m .53353 .48816 L .53971 .48572 L p .72 .602 .723 r
F P
0 g
s
.53971 .48572 m .53802 .48069 L .53139 .48327 L p .72 .602 .723 r
F P
0 g
s
.4824 .46831 m .47631 .46835 L .47608 .47538 L p .727 .681 .806 r
F P
0 g
s
.47036 .47602 m .47608 .47538 L .47631 .46835 L p .744 .691 .801 r
F P
0 g
s
.53498 .46991 m .53645 .47546 L .54361 .47354 L p .751 .649 .748 r
F P
0 g
s
.54361 .47354 m .54306 .46816 L .53498 .46991 L p .751 .649 .748 r
F P
0 g
s
.06236 .49426 m .06632 .48929 L .06668 .47984 L p 0 0 .331 r
F P
0 g
s
.06632 .48929 m .06236 .49426 L .06228 .49979 L p 0 0 .392 r
F P
0 g
s
.53191 .50047 m .53386 .50557 L .53977 .50308 L p .67 .522 .674 r
F P
0 g
s
.53977 .50308 m .53766 .49798 L .53191 .50047 L p .67 .522 .674 r
F P
0 g
s
.06621 .4993 m .06228 .49979 L .06236 .50536 L p 0 0 .431 r
F P
0 g
s
.06236 .50536 m .06636 .50943 L .06621 .4993 L p 0 0 .431 r
F P
0 g
s
.5356 .49304 m .53766 .49798 L .54351 .49565 L p .711 .563 .685 r
F P
0 g
s
.56339 .44796 m .56687 .44302 L .5593 .44057 L p .788 .758 .825 r
F P
0 g
s
.5593 .44057 m .55608 .44618 L .56339 .44796 L p .788 .758 .825 r
F P
0 g
s
.54572 .5007 m .54351 .49565 L .53766 .49798 L p .704 .54 .663 r
F P
0 g
s
.52912 .47825 m .53139 .48327 L .53802 .48069 L p .723 .616 .738 r
F P
0 g
s
.53802 .48069 m .53645 .47546 L .52912 .47825 L p .723 .616 .738 r
F P
0 g
s
.51912 .47713 m .52234 .48174 L .52912 .47825 L p .697 .611 .757 r
F P
0 g
s
.53139 .48327 m .52912 .47825 L .52234 .48174 L p .694 .6 .746 r
F P
0 g
s
.5098 .55259 m .50493 .56585 L .51246 .56295 L p .328 .126 .446 r
F P
0 g
s
.51246 .56295 m .51601 .55016 L .5098 .55259 L p .328 .126 .446 r
F P
0 g
s
.49973 .47214 m .50473 .4748 L .51037 .46783 L p .685 .622 .78 r
F P
0 g
s
.51526 .47246 m .51037 .46783 L .50473 .4748 L p .681 .619 .78 r
F P
0 g
s
.72744 .86805 m .72438 .87617 L .72925 .87309 L p .733 .99 .87 r
F P
0 g
s
.72925 .87309 m .73725 .86187 L .72744 .86805 L p .733 .99 .87 r
F P
0 g
s
.48485 .41652 m .48966 .41248 L .48517 .40618 L p .58 .412 .619 r
F P
0 g
s
.4891 .4016 m .48517 .40618 L .48966 .41248 L p .559 .406 .631 r
F P
0 g
s
.06228 .49979 m .06621 .4993 L .06632 .48929 L p 0 0 .392 r
F P
0 g
s
.70866 .88498 m .69551 .88585 L .68568 .89061 L p .573 .935 .923 r
F P
0 g
s
.69551 .88585 m .70866 .88498 L .71385 .88226 L p .64 .957 .928 r
F P
0 g
s
.53766 .49798 m .53977 .50308 L .54572 .5007 L p .704 .54 .663 r
F P
0 g
s
.47631 .46835 m .47014 .46894 L .47036 .47602 L p .744 .691 .801 r
F P
0 g
s
.46443 .47726 m .47036 .47602 L .47014 .46894 L p .761 .701 .795 r
F P
0 g
s
.5542 .50362 m .55755 .50888 L .56339 .50663 L p .748 .507 .566 r
F P
0 g
s
.56814 .51189 m .56339 .50663 L .55755 .50888 L p .733 .47 .531 r
F P
0 g
s
.45825 .47911 m .45175 .48164 L .45268 .48838 L p .807 .768 .817 r
F P
0 g
s
.44601 .49225 m .45268 .48838 L .45175 .48164 L p .826 .778 .807 r
F P
0 g
s
.52516 .52207 m .52536 .5291 L .532 .52637 L p .548 .376 .601 r
F P
0 g
s
.532 .52637 m .53104 .51959 L .52516 .52207 L p .548 .376 .601 r
F P
0 g
s
.51037 .46783 m .50417 .46381 L .49973 .47214 L p .685 .622 .78 r
F P
0 g
s
.49426 .47016 m .49972 .47214 L .50416 .46381 L p .693 .633 .784 r
F P
0 g
s
.53369 .46381 m .53498 .46991 L .54306 .46816 L p .748 .657 .761 r
F P
0 g
s
.54306 .46816 m .54295 .46248 L .53369 .46381 L p .748 .657 .761 r
F P
0 g
s
.44041 .42372 m .43255 .4231 L .43413 .43003 L p .75 .474 .514 r
F P
0 g
s
.43413 .43003 m .442 .43023 L .44041 .42372 L p .75 .474 .514 r
F P
0 g
s
.41269 .41272 m .40122 .40827 L .40253 .41549 L p .794 .43 .369 r
F P
0 g
s
.40253 .41549 m .41395 .41914 L .41269 .41272 L p .794 .43 .369 r
F P
0 g
s
.53386 .50557 m .53573 .51101 L .54196 .50843 L p .661 .495 .65 r
F P
0 g
s
.54196 .50843 m .53977 .50308 L .53386 .50557 L p .661 .495 .65 r
F P
0 g
s
.58911 .43051 m .59687 .42528 L .59 .42135 L p .763 .827 .902 r
F P
0 g
s
.59 .42135 m .58262 .42713 L .58911 .43051 L p .763 .827 .902 r
F P
0 g
s
.65751 .11333 m .67718 .11024 L .67092 .10791 L p .494 0 0 r
F P
0 g
s
.67092 .10791 m .64907 .11014 L .65751 .11333 L p .494 0 0 r
F P
0 g
s
.52661 .47294 m .52912 .47825 L .53645 .47546 L p .723 .627 .751 r
F P
0 g
s
.53645 .47546 m .53498 .46991 L .52661 .47294 L p .723 .627 .751 r
F P
0 g
s
.51526 .47246 m .51912 .47713 L .52661 .47294 L p .698 .619 .765 r
F P
0 g
s
.52912 .47825 m .52661 .47294 L .51912 .47713 L p .697 .611 .757 r
F P
0 g
s
.54822 .50593 m .54572 .5007 L .53977 .50308 L p .695 .513 .638 r
F P
0 g
s
.54572 .5007 m .54822 .50593 L .5542 .50362 L p .728 .529 .622 r
F P
0 g
s
.5298 .51354 m .53104 .51959 L .53752 .51689 L p .61 .443 .631 r
F P
0 g
s
.53752 .51689 m .53573 .51101 L .5298 .51354 L p .61 .443 .631 r
F P
0 g
s
.54466 .45032 m .54343 .4565 L .55189 .45684 L p .766 .7 .789 r
F P
0 g
s
.55189 .45684 m .55365 .45157 L .54466 .45032 L p .766 .7 .789 r
F P
0 g
s
.55755 .50888 m .5542 .50362 L .54822 .50593 L p .716 .498 .593 r
F P
0 g
s
.49962 .38312 m .50262 .37512 L .49695 .37057 L p .406 .304 .626 r
F P
0 g
s
.49915 .36136 m .49695 .37057 L .50262 .37512 L p .391 .305 .638 r
F P
0 g
s
.50467 .32438 m .50676 .30788 L .50046 .30439 L p .183 .14 .572 r
F P
0 g
s
.50267 .28501 m .50046 .30439 L .50676 .30788 L p .189 .136 .563 r
F P
0 g
s
.50416 .46381 m .497 .46122 L .49426 .47016 L p .693 .633 .784 r
F P
0 g
s
.48842 .46889 m .49426 .47016 L .497 .46122 L p .702 .638 .781 r
F P
0 g
s
.48966 .41248 m .4942 .40781 L .4891 .4016 L p .559 .406 .631 r
F P
0 g
s
.49285 .39627 m .4891 .4016 L .4942 .40781 L p .544 .406 .643 r
F P
0 g
s
.76311 .17686 m .75422 .15632 L .74887 .15187 L p .932 .556 .249 r
F P
0 g
s
.53977 .50308 m .54196 .50843 L .54822 .50593 L p .695 .513 .638 r
F P
0 g
s
.41247 .53101 m .39902 .54504 L .40095 .55282 L p .906 .938 .82 r
F P
0 g
s
.38359 .57134 m .40095 .55282 L .39902 .54504 L p .895 .935 .834 r
F P
0 g
s
.56687 .44302 m .57117 .43791 L .56336 .4348 L p .776 .76 .838 r
F P
0 g
s
.56336 .4348 m .5593 .44057 L .56687 .44302 L p .776 .76 .838 r
F P
0 g
s
.47014 .46894 m .46384 .47003 L .46443 .47726 L p .761 .701 .795 r
F P
0 g
s
.45825 .47911 m .46443 .47726 L .46384 .47003 L p .779 .711 .788 r
F P
0 g
s
.71689 .8743 m .71916 .87928 L .72438 .87617 L p .718 .983 .9 r
F P
0 g
s
.72438 .87617 m .72744 .86805 L .71689 .8743 L p .718 .983 .9 r
F P
0 g
s
.43876 .49723 m .4307 .50353 L .43214 .51073 L p .876 .857 .819 r
F P
0 g
s
.42318 .51973 m .43214 .51073 L .4307 .50353 L p .888 .861 .808 r
F P
0 g
s
.497 .46122 m .48976 .46005 L .48842 .46889 L p .702 .638 .781 r
F P
0 g
s
.4824 .46831 m .48842 .46889 L .48976 .46005 L p .713 .643 .777 r
F P
0 g
s
.71385 .88226 m .70608 .88033 L .69551 .88585 L p .64 .957 .928 r
F P
0 g
s
.70608 .88033 m .71385 .88226 L .71916 .87928 L p .687 .972 .92 r
F P
0 g
s
.62356 .53172 m .64509 .54193 L .65144 .53878 L p .684 .196 .084 r
F P
0 g
s
.68068 .55362 m .65144 .53878 L .64509 .54193 L p .723 .25 .126 r
F P
0 g
s
.65039 .40264 m .66795 .39274 L .66117 .38736 L p .761 .903 .939 r
F P
0 g
s
.66117 .38736 m .64417 .3979 L .65039 .40264 L p .761 .903 .939 r
F P
0 g
s
.76996 .8172 m .75305 .85078 L .75839 .84633 L p .891 .989 .746 r
F P
0 g
s
.75839 .84633 m .77883 .81 L .76996 .8172 L p .891 .989 .746 r
F P
0 g
s
.47419 .42302 m .46842 .42548 L .471 .43301 L p .671 .491 .634 r
F P
0 g
s
.46842 .42548 m .46238 .42743 L .46459 .43481 L p .688 .497 .623 r
F P
0 g
s
.46459 .43481 m .471 .43301 L .46842 .42548 L p .688 .497 .623 r
F P
0 g
s
.51037 .46783 m .51526 .47246 L .52371 .46711 L p .698 .622 .768 r
F P
0 g
s
.52661 .47294 m .52371 .46711 L .51526 .47246 L p .698 .619 .765 r
F P
0 g
s
.46238 .42743 m .45601 .42889 L .45799 .43623 L p .706 .504 .613 r
F P
0 g
s
.45799 .43623 m .46459 .43481 L .46238 .42743 L p .706 .504 .613 r
F P
0 g
s
.52371 .46711 m .52661 .47294 L .53498 .46991 L p .721 .634 .761 r
F P
0 g
s
.53498 .46991 m .53369 .46381 L .52371 .46711 L p .721 .634 .761 r
F P
0 g
s
.47967 .42004 m .47419 .42302 L .47728 .43078 L p .654 .487 .644 r
F P
0 g
s
.471 .43301 m .47728 .43078 L .47419 .42302 L p .671 .491 .634 r
F P
0 g
s
.48976 .46005 m .48282 .45978 L .4824 .46831 L p .713 .643 .777 r
F P
0 g
s
.47631 .46835 m .4824 .46831 L .48282 .45978 L p .726 .649 .772 r
F P
0 g
s
.56814 .51189 m .57414 .51749 L .58041 .51498 L p .741 .422 .442 r
F P
0 g
s
.58914 .52067 m .58041 .51498 L .57414 .51749 L p .72 .382 .406 r
F P
0 g
s
.71916 .87928 m .71689 .8743 L .70608 .88033 L p .687 .972 .92 r
F P
0 g
s
.53285 .45689 m .53369 .46381 L .54295 .46248 L p .742 .662 .771 r
F P
0 g
s
.54295 .46248 m .54343 .4565 L .53285 .45689 L p .742 .662 .771 r
F P
0 g
s
.59571 .13394 m .62319 .11832 L .61573 .11626 L p .318 0 .09 r
F P
0 g
s
.61573 .11626 m .58714 .13138 L .59571 .13394 L p .318 0 .09 r
F P
0 g
s
.53573 .51101 m .53752 .51689 L .54431 .51413 L p .649 .467 .623 r
F P
0 g
s
.54431 .51413 m .54196 .50843 L .53573 .51101 L p .649 .467 .623 r
F P
0 g
s
.55109 .51142 m .54822 .50593 L .54196 .50843 L p .684 .485 .611 r
F P
0 g
s
.54822 .50593 m .55109 .51142 L .55755 .50888 L p .716 .498 .593 r
F P
0 g
s
.43255 .4231 m .42382 .42162 L .42543 .42915 L p .772 .485 .501 r
F P
0 g
s
.42543 .42915 m .43413 .43003 L .43255 .4231 L p .772 .485 .501 r
F P
0 g
s
.55365 .45156 m .55608 .44618 L .54678 .44395 L p .765 .704 .794 r
F P
0 g
s
.54678 .44395 m .54466 .45032 L .55365 .45156 L p .765 .704 .794 r
F P
0 g
s
.4942 .40781 m .49854 .40236 L .49285 .39627 L p .544 .406 .643 r
F P
0 g
s
.49636 .39014 m .49285 .39627 L .49854 .40236 L p .529 .405 .656 r
F P
0 g
s
.51835 .53993 m .51601 .55016 L .52385 .54705 L p .448 .251 .52 r
F P
0 g
s
.52385 .54705 m .52495 .53727 L .51835 .53993 L p .448 .251 .52 r
F P
0 g
s
.45601 .42889 m .44925 .42983 L .4511 .43729 L p .725 .512 .602 r
F P
0 g
s
.4511 .43729 m .45799 .43623 L .45601 .42889 L p .725 .512 .602 r
F P
0 g
s
.48485 .41652 m .47967 .42004 L .48347 .42803 L p .639 .483 .655 r
F P
0 g
s
.47728 .43078 m .48347 .42803 L .47967 .42004 L p .654 .487 .644 r
F P
0 g
s
.78927 .75289 m .77883 .81 L .78429 .80447 L p .978 .91 .587 r
F P
0 g
s
.78429 .80447 m .79683 .74579 L .78927 .75289 L p .978 .91 .587 r
F P
0 g
s
.48282 .45978 m .47613 .46009 L .47631 .46835 L p .726 .649 .772 r
F P
0 g
s
.47014 .46894 m .47631 .46835 L .47613 .46009 L p .74 .656 .766 r
F P
0 g
s
.45175 .48164 m .44481 .48494 L .44601 .49225 L p .826 .778 .807 r
F P
0 g
s
.43876 .49723 m .44601 .49225 L .44481 .48494 L p .844 .787 .796 r
F P
0 g
s
.67005 .89695 m .62678 .89545 L .61811 .89768 L p .283 .764 .924 r
F P
0 g
s
.62678 .89545 m .67005 .89695 L .67705 .89437 L p .487 .843 .994 r
F P
0 g
s
.34945 .37831 m .32287 .36722 L .32326 .37534 L p .747 .292 .17 r
F P
0 g
s
.32326 .37534 m .35007 .38545 L .34945 .37831 L p .747 .292 .17 r
F P
0 g
s
.50262 .37512 m .50537 .36601 L .49915 .36136 L p .391 .305 .638 r
F P
0 g
s
.5011 .35077 m .49915 .36136 L .50537 .36601 L p .378 .306 .649 r
F P
0 g
s
.54196 .50843 m .54431 .51413 L .55109 .51142 L p .684 .485 .611 r
F P
0 g
s
.50417 .46381 m .51037 .46783 L .52004 .46017 L p .696 .615 .762 r
F P
0 g
s
.52371 .46711 m .52004 .46017 L .51037 .46783 L p .698 .622 .768 r
F P
0 g
s
.46384 .47003 m .45735 .47161 L .45825 .47911 L p .779 .711 .788 r
F P
0 g
s
.45175 .48164 m .45825 .47911 L .45735 .47161 L p .796 .72 .78 r
F P
0 g
s
.59687 .42528 m .60603 .41966 L .59867 .41514 L p .752 .825 .909 r
F P
0 g
s
.59867 .41514 m .59 .42135 L .59687 .42528 L p .752 .825 .909 r
F P
0 g
s
.77458 .24391 m .7744 .21017 L .76848 .20422 L p .996 .793 .512 r
F P
0 g
s
.76311 .17686 m .76848 .20422 L .7744 .21017 L p .976 .677 .311 r
F P
0 g
s
.55755 .50888 m .56165 .51444 L .56814 .51189 L p .733 .47 .531 r
F P
0 g
s
.57414 .51749 m .56814 .51189 L .56165 .51444 L p .716 .433 .497 r
F P
0 g
s
.56165 .51444 m .55755 .50888 L .55109 .51142 L p .702 .465 .562 r
F P
0 g
s
.69393 .11805 m .70356 .11622 L .69742 .11323 L p .659 .167 .07 r
F P
0 g
s
.69742 .11323 m .68496 .11366 L .69393 .11805 L p .659 .167 .07 r
F P
0 g
s
.53104 .51959 m .532 .52637 L .53928 .5234 L p .597 .412 .601 r
F P
0 g
s
.53928 .5234 m .53752 .51689 L .53104 .51959 L p .597 .412 .601 r
F P
0 g
s
.48221 .60947 m .4719 .64314 L .48189 .63973 L p .175 .018 .415 r
F P
0 g
s
.48189 .63973 m .49021 .60666 L .48221 .60947 L p .175 .018 .415 r
F P
0 g
s
.52536 .5291 m .52495 .53727 L .53264 .53417 L p .533 .343 .569 r
F P
0 g
s
.53264 .53417 m .532 .52637 L .52536 .5291 L p .533 .343 .569 r
F P
0 g
s
.57117 .43791 m .57639 .43263 L .5683 .42886 L p .764 .761 .85 r
F P
0 g
s
.5683 .42886 m .56336 .4348 L .57117 .43791 L p .764 .761 .85 r
F P
0 g
s
.50676 .30788 m .50965 .28863 L .50267 .28501 L p .189 .136 .563 r
F P
0 g
s
.50641 .2626 m .50267 .28501 L .50965 .28863 L p .201 .128 .545 r
F P
0 g
s
.48966 .41248 m .48485 .41652 L .48952 .42464 L p .625 .48 .665 r
F P
0 g
s
.48347 .42803 m .48952 .42464 L .48485 .41652 L p .639 .483 .655 r
F P
0 g
s
.73612 .13563 m .74179 .14666 L .74887 .15187 L p .86 .411 .11 r
F P
0 g
s
.74179 .14666 m .73612 .13563 L .73038 .13173 L p .851 .417 .187 r
F P
0 g
s
.47613 .46009 m .46954 .46082 L .47014 .46894 L p .74 .656 .766 r
F P
0 g
s
.46384 .47003 m .47014 .46894 L .46954 .46082 L p .755 .663 .76 r
F P
0 g
s
.58914 .52067 m .60052 .52719 L .60723 .52431 L p .711 .304 .273 r
F P
0 g
s
.62356 .53172 m .60723 .52431 L .60052 .52719 L p .702 .288 .259 r
F P
0 g
s
.52004 .46017 m .52371 .46711 L .53369 .46381 L p .717 .636 .767 r
F P
0 g
s
.44925 .42983 m .442 .43023 L .44381 .43798 L p .744 .521 .591 r
F P
0 g
s
.44381 .43798 m .4511 .43729 L .44925 .42983 L p .744 .521 .591 r
F P
0 g
s
.53369 .46381 m .53285 .45689 L .52004 .46017 L p .717 .636 .767 r
F P
0 g
s
.40122 .40827 m .3876 .40228 L .38897 .41051 L p .805 .437 .36 r
F P
0 g
s
.38897 .41051 m .40253 .41549 L .40122 .40827 L p .805 .437 .36 r
F P
0 g
s
.53312 .44908 m .53285 .45689 L .54343 .4565 L p .735 .662 .779 r
F P
0 g
s
.54343 .4565 m .54466 .45032 L .53312 .44908 L p .735 .662 .779 r
F P
0 g
s
.52004 .46017 m .51313 .44814 L .50417 .46381 L p .696 .615 .762 r
F P
0 g
s
.497 .46122 m .50416 .46381 L .51303 .44808 L p .698 .617 .762 r
F P
0 g
s
.06807 .4642 m .08057 .44214 L .08199 .43348 L p 0 0 .144 r
F P
0 g
s
.08057 .44214 m .06807 .4642 L .06727 .47136 L p .004 0 .317 r
F P
0 g
s
.49854 .40236 m .50263 .39612 L .49636 .39014 L p .529 .405 .656 r
F P
0 g
s
.49962 .38312 m .49636 .39014 L .50263 .39612 L p .514 .405 .668 r
F P
0 g
s
.51303 .44808 m .49848 .44845 L .497 .46122 L p .698 .617 .762 r
F P
0 g
s
.48976 .46005 m .497 .46122 L .49848 .44845 L p .702 .614 .755 r
F P
0 g
s
.55608 .44618 m .5593 .44057 L .54984 .4374 L p .756 .706 .805 r
F P
0 g
s
.54984 .4374 m .54678 .44395 L .55608 .44618 L p .756 .706 .805 r
F P
0 g
s
.66795 .39274 m .68777 .37988 L .68043 .37382 L p .786 .907 .925 r
F P
0 g
s
.68043 .37382 m .66117 .38736 L .66795 .39274 L p .786 .907 .925 r
F P
0 g
s
.55721 .8746 m .61811 .89768 L .62678 .89545 L p .333 .669 .975 r
F P
0 g
s
.1493 .37019 m .10957 .39702 L .10758 .40483 L p .205 0 .098 r
F P
0 g
s
.08199 .43348 m .10758 .40483 L .10957 .39702 L p 0 0 .012 r
F P
0 g
s
.49848 .44845 m .48976 .44914 L .48976 .46005 L p .702 .614 .755 r
F P
0 g
s
.48282 .45978 m .48976 .46005 L .48976 .44914 L p .71 .614 .748 r
F P
0 g
s
.50493 .56585 m .49833 .58314 L .50764 .5796 L p .325 .119 .438 r
F P
0 g
s
.50764 .5796 m .51246 .56295 L .50493 .56585 L p .325 .119 .438 r
F P
0 g
s
.48952 .42464 m .49526 .42054 L .48966 .41248 L p .625 .48 .665 r
F P
0 g
s
.4942 .40781 m .48966 .41248 L .49527 .42053 L p .607 .475 .675 r
F P
0 g
s
.48976 .44914 m .48222 .44999 L .48282 .45978 L p .71 .614 .748 r
F P
0 g
s
.47613 .46009 m .48282 .45978 L .48222 .44999 L p .72 .617 .741 r
F P
0 g
s
.47728 .43078 m .471 .43301 L .47341 .44168 L p .693 .54 .675 r
F P
0 g
s
.471 .43301 m .46459 .43481 L .4667 .44317 L p .708 .545 .666 r
F P
0 g
s
.4667 .44317 m .47341 .44168 L .471 .43301 L p .708 .545 .666 r
F P
0 g
s
.46954 .46082 m .46293 .46188 L .46384 .47003 L p .755 .663 .76 r
F P
0 g
s
.45735 .47161 m .46384 .47003 L .46293 .46188 L p .771 .671 .753 r
F P
0 g
s
.46459 .43481 m .45799 .43623 L .45993 .44448 L p .723 .551 .657 r
F P
0 g
s
.45993 .44448 m .4667 .44317 L .46459 .43481 L p .723 .551 .657 r
F P
0 g
s
.48347 .42803 m .47728 .43078 L .48021 .43994 L p .68 .537 .684 r
F P
0 g
s
.47341 .44168 m .48021 .43994 L .47728 .43078 L p .693 .54 .675 r
F P
0 g
s
.55446 .51729 m .55109 .51142 L .54431 .51413 L p .671 .454 .582 r
F P
0 g
s
.55109 .51142 m .55446 .51729 L .56165 .51444 L p .702 .465 .562 r
F P
0 g
s
.53752 .51689 m .53928 .5234 L .54689 .52032 L p .637 .437 .595 r
F P
0 g
s
.54689 .52032 m .54431 .51413 L .53752 .51689 L p .637 .437 .595 r
F P
0 g
s
.42382 .42162 m .41395 .41914 L .41563 .42747 L p .79 .495 .489 r
F P
0 g
s
.41563 .42747 m .42543 .42915 L .42382 .42162 L p .79 .495 .489 r
F P
0 g
s
.48222 .44999 m .47521 .45096 L .47613 .46009 L p .72 .617 .741 r
F P
0 g
s
.46954 .46082 m .47613 .46009 L .47521 .45096 L p .733 .621 .734 r
F P
0 g
s
.45735 .47161 m .45057 .47372 L .45175 .48164 L p .796 .72 .78 r
F P
0 g
s
.44481 .48494 m .45175 .48164 L .45057 .47372 L p .813 .728 .771 r
F P
0 g
s
.08035 .54521 m .06744 .52818 L .06831 .5359 L p .044 .17 .672 r
F P
0 g
s
.06831 .5359 m .08183 .55792 L .08035 .54521 L p .044 .17 .672 r
F P
0 g
s
.4307 .50353 m .42144 .51146 L .42318 .51973 L p .888 .861 .808 r
F P
0 g
s
.41247 .53101 m .42318 .51973 L .42144 .51146 L p .894 .863 .801 r
F P
0 g
s
.442 .43023 m .43413 .43003 L .43595 .43827 L p .764 .53 .58 r
F P
0 g
s
.43595 .43827 m .44381 .43798 L .442 .43023 L p .764 .53 .58 r
F P
0 g
s
.50537 .36601 m .50794 .35558 L .5011 .35077 L p .378 .306 .649 r
F P
0 g
s
.50288 .33855 m .5011 .35077 L .50794 .35558 L p .369 .307 .655 r
F P
0 g
s
.51313 .44814 m .52004 .46017 L .53285 .45689 L p .704 .629 .77 r
F P
0 g
s
.39902 .54504 m .38126 .56214 L .38359 .57134 L p .895 .935 .834 r
F P
0 g
s
.35958 .59292 m .38359 .57134 L .38126 .56214 L p .871 .927 .86 r
F P
0 g
s
.48952 .42464 m .48347 .42803 L .48726 .43781 L p .669 .535 .692 r
F P
0 g
s
.48021 .43994 m .48726 .43781 L .48347 .42803 L p .68 .537 .684 r
F P
0 g
s
.54431 .51413 m .54689 .52032 L .55446 .51729 L p .671 .454 .582 r
F P
0 g
s
.44481 .48494 m .43729 .48914 L .43876 .49723 L p .844 .787 .796 r
F P
0 g
s
.4307 .50353 m .43876 .49723 L .43729 .48914 L p .858 .793 .786 r
F P
0 g
s
.45799 .43623 m .4511 .43729 L .45297 .44564 L p .74 .558 .648 r
F P
0 g
s
.45297 .44564 m .45993 .44448 L .45799 .43623 L p .74 .558 .648 r
F P
0 g
s
.53285 .45689 m .53312 .44908 L .51313 .44814 L p .704 .629 .77 r
F P
0 g
s
.60603 .41966 m .61681 .41346 L .60885 .4083 L p .745 .823 .913 r
F P
0 g
s
.60885 .4083 m .59867 .41514 L .60603 .41966 L p .745 .823 .913 r
F P
0 g
s
.57639 .43263 m .58262 .42713 L .57417 .42272 L p .752 .761 .86 r
F P
0 g
s
.57417 .42272 m .5683 .42886 L .57639 .43263 L p .752 .761 .86 r
F P
0 g
s
.47521 .45096 m .4684 .45204 L .46954 .46082 L p .733 .621 .734 r
F P
0 g
s
.46293 .46188 m .46954 .46082 L .4684 .45204 L p .747 .627 .727 r
F P
0 g
s
.54466 .45032 m .54678 .44395 L .53516 .44095 L p .735 .662 .778 r
F P
0 g
s
.53516 .44095 m .53313 .44908 L .54466 .45032 L p .735 .662 .778 r
F P
0 g
s
.50965 .28863 m .51411 .26633 L .50641 .2626 L p .201 .128 .545 r
F P
0 g
s
.51281 .23716 m .50641 .2626 L .51411 .26633 L p .218 .114 .516 r
F P
0 g
s
.49527 .42053 m .50068 .41562 L .4942 .40781 L p .607 .475 .675 r
F P
0 g
s
.49854 .40236 m .4942 .40781 L .50068 .41562 L p .596 .475 .685 r
F P
0 g
s
.50263 .39612 m .50647 .38905 L .49962 .38312 L p .514 .405 .668 r
F P
0 g
s
.50262 .37512 m .49962 .38312 L .50647 .38905 L p .501 .405 .679 r
F P
0 g
s
.48021 .43994 m .47341 .44168 L .47521 .45096 L p .71 .581 .709 r
F P
0 g
s
.47341 .44168 m .4667 .44317 L .4684 .45204 L p .722 .585 .702 r
F P
0 g
s
.4684 .45204 m .47521 .45096 L .47341 .44168 L p .722 .585 .702 r
F P
0 g
s
.48726 .43781 m .48021 .43994 L .48222 .44999 L p .699 .579 .717 r
F P
0 g
s
.48222 .44999 m .48976 .44914 L .48726 .43781 L p .699 .579 .717 r
F P
0 g
s
.47521 .45096 m .48222 .44999 L .48021 .43994 L p .71 .581 .709 r
F P
0 g
s
.57414 .51749 m .58183 .52367 L .58914 .52067 L p .72 .382 .406 r
F P
0 g
s
.60052 .52719 m .58914 .52067 L .58183 .52367 L p .704 .353 .378 r
F P
0 g
s
.46293 .46188 m .45618 .46326 L .45735 .47161 L p .771 .671 .753 r
F P
0 g
s
.45057 .47372 m .45735 .47161 L .45618 .46326 L p .787 .679 .745 r
F P
0 g
s
.56673 .52046 m .56165 .51444 L .55446 .51729 L p .688 .433 .531 r
F P
0 g
s
.56165 .51444 m .56673 .52046 L .57414 .51749 L p .716 .433 .497 r
F P
0 g
s
.56986 .1566 m .59571 .13394 L .58714 .13138 L p .304 0 .232 r
F P
0 g
s
.58714 .13138 m .56068 .15356 L .56986 .1566 L p .304 0 .232 r
F P
0 g
s
.70369 .1232 m .71023 .11972 L .70356 .11622 L p .717 .257 .155 r
F P
0 g
s
.70356 .11622 m .69393 .11805 L .70369 .1232 L p .717 .257 .155 r
F P
0 g
s
.5593 .44057 m .56336 .4348 L .55378 .4308 L p .746 .707 .815 r
F P
0 g
s
.55378 .4308 m .54984 .4374 L .5593 .44057 L p .746 .707 .815 r
F P
0 g
s
.32287 .36722 m .2888 .35696 L .28878 .36603 L p .708 .256 .175 r
F P
0 g
s
.28878 .36603 m .32326 .37534 L .32287 .36722 L p .708 .256 .175 r
F P
0 g
s
.49526 .42054 m .48952 .42464 L .49467 .43495 L p .658 .533 .701 r
F P
0 g
s
.48726 .43781 m .49467 .43495 L .48952 .42464 L p .669 .535 .692 r
F P
0 g
s
.4667 .44317 m .45993 .44448 L .46162 .4532 L p .736 .591 .694 r
F P
0 g
s
.46162 .4532 m .4684 .45204 L .4667 .44317 L p .736 .591 .694 r
F P
0 g
s
.49467 .43495 m .48726 .43781 L .48976 .44914 L p .692 .58 .725 r
F P
0 g
s
.48976 .44914 m .49848 .44845 L .49467 .43495 L p .692 .58 .725 r
F P
0 g
s
.532 .52637 m .53264 .53417 L .54105 .53077 L p .584 .381 .572 r
F P
0 g
s
.54105 .53077 m .53928 .5234 L .532 .52637 L p .584 .381 .572 r
F P
0 g
s
.73038 .13173 m .73332 .14091 L .74179 .14666 L p .851 .417 .187 r
F P
0 g
s
.73332 .14091 m .73038 .13173 L .72395 .12766 L p .828 .4 .223 r
F P
0 g
s
.4684 .45204 m .46162 .4532 L .46293 .46188 L p .747 .627 .727 r
F P
0 g
s
.4511 .43729 m .44381 .43798 L .44568 .44664 L p .757 .566 .638 r
F P
0 g
s
.44568 .44664 m .45297 .44564 L .4511 .43729 L p .757 .566 .638 r
F P
0 g
s
.45618 .46326 m .46293 .46188 L .46162 .4532 L p .762 .634 .72 r
F P
0 g
s
.64509 .54193 m .67316 .55765 L .68068 .55362 L p .723 .25 .126 r
F P
0 g
s
.71668 .5783 m .68068 .55362 L .67316 .55765 L p .786 .343 .197 r
F P
0 g
s
.58183 .52367 m .57414 .51749 L .56673 .52046 L p .699 .4 .465 r
F P
0 g
s
.68777 .37988 m .70931 .36288 L .70148 .35616 L p .818 .91 .902 r
F P
0 g
s
.70148 .35616 m .68043 .37382 L .68777 .37988 L p .818 .91 .902 r
F P
0 g
s
.51601 .55016 m .51246 .56295 L .52198 .5592 L p .437 .228 .496 r
F P
0 g
s
.52198 .5592 m .52385 .54705 L .51601 .55016 L p .437 .228 .496 r
F P
0 g
s
.50216 .43078 m .49467 .43495 L .49848 .44845 L p .691 .586 .733 r
F P
0 g
s
.49848 .44845 m .51303 .44808 L .50216 .43078 L p .691 .586 .733 r
F P
0 g
s
.45993 .44448 m .45297 .44564 L .4547 .45445 L p .752 .598 .686 r
F P
0 g
s
.4547 .45445 m .46162 .4532 L .45993 .44448 L p .752 .598 .686 r
F P
0 g
s
.52495 .53727 m .52385 .54705 L .53296 .54341 L p .519 .313 .54 r
F P
0 g
s
.53296 .54341 m .53264 .53417 L .52495 .53727 L p .519 .313 .54 r
F P
0 g
s
.43413 .43003 m .42543 .42915 L .42732 .43809 L p .782 .54 .569 r
F P
0 g
s
.42732 .43809 m .43595 .43827 L .43413 .43003 L p .782 .54 .569 r
F P
0 g
s
.3876 .40228 m .37096 .39464 L .37236 .4041 L p .808 .439 .356 r
F P
0 g
s
.37236 .4041 m .38897 .41051 L .3876 .40228 L p .808 .439 .356 r
F P
0 g
s
.50068 .41562 m .50578 .40984 L .49854 .40236 L p .596 .475 .685 r
F P
0 g
s
.50263 .39612 m .49854 .40236 L .50578 .40984 L p .584 .475 .695 r
F P
0 g
s
.16018 .62064 m .11293 .59715 L .1157 .60708 L p .316 .566 .927 r
F P
0 g
s
.1157 .60708 m .16367 .63326 L .16018 .62064 L p .316 .566 .927 r
F P
0 g
s
.45057 .47372 m .44336 .47639 L .44481 .48494 L p .813 .728 .771 r
F P
0 g
s
.43729 .48914 m .44481 .48494 L .44336 .47639 L p .829 .736 .762 r
F P
0 g
s
.76667 .27931 m .77458 .24391 L .76754 .23698 L p .977 .858 .654 r
F P
0 g
s
.76848 .20422 m .76754 .23698 L .77458 .24391 L p .996 .793 .512 r
F P
0 g
s
.46162 .4532 m .4547 .45445 L .45618 .46326 L p .762 .634 .72 r
F P
0 g
s
.49467 .43495 m .50216 .43078 L .49526 .42054 L p .658 .533 .701 r
F P
0 g
s
.50068 .41562 m .49527 .42053 L .50217 .43078 L p .642 .528 .709 r
F P
0 g
s
.53313 .44908 m .53516 .44095 L .5209 .43519 L p .705 .624 .763 r
F P
0 g
s
.5209 .43519 m .51313 .44803 L .53313 .44908 L p .705 .624 .763 r
F P
0 g
s
.54678 .44395 m .54984 .4374 L .53857 .43312 L p .727 .662 .786 r
F P
0 g
s
.53857 .43312 m .53516 .44095 L .54678 .44395 L p .727 .662 .786 r
F P
0 g
s
.51411 .26633 m .52121 .24091 L .51281 .23716 L p .218 .114 .516 r
F P
0 g
s
.52325 .2093 m .51281 .23716 L .52121 .24091 L p .239 .094 .474 r
F P
0 g
s
.50794 .35558 m .51043 .34358 L .50288 .33855 L p .369 .307 .655 r
F P
0 g
s
.50467 .32438 m .50288 .33855 L .51043 .34358 L p .365 .307 .659 r
F P
0 g
s
.41395 .41914 m .40253 .41549 L .40432 .42488 L p .806 .504 .479 r
F P
0 g
s
.40432 .42488 m .41563 .42747 L .41395 .41914 L p .806 .504 .479 r
F P
0 g
s
.66805 .11805 m .68496 .11366 L .67718 .11024 L p .609 .162 .164 r
F P
0 g
s
.67718 .11024 m .65751 .11333 L .66805 .11805 L p .609 .162 .164 r
F P
0 g
s
.51313 .44803 m .5209 .43519 L .50898 .42504 L p .674 .58 .742 r
F P
0 g
s
.50898 .42504 m .50217 .43078 L .51313 .44803 L p .674 .58 .742 r
F P
0 g
s
.58262 .42713 m .59 .42135 L .58107 .41627 L p .742 .76 .868 r
F P
0 g
s
.58107 .41627 m .57417 .42272 L .58262 .42713 L p .742 .76 .868 r
F P
0 g
s
.5585 .52375 m .55446 .51729 L .54689 .52032 L p .658 .423 .553 r
F P
0 g
s
.55446 .51729 m .5585 .52375 L .56673 .52046 L p .688 .433 .531 r
F P
0 g
s
.71382 .12891 m .71713 .12359 L .71023 .11972 L p .761 .321 .206 r
F P
0 g
s
.71023 .11972 m .70369 .1232 L .71382 .12891 L p .761 .321 .206 r
F P
0 g
s
.44915 .46496 m .45618 .46326 L .4547 .45445 L p .777 .642 .712 r
F P
0 g
s
.45618 .46326 m .44915 .46496 L .45057 .47372 L p .787 .679 .745 r
F P
0 g
s
.53928 .5234 m .54105 .53077 L .54981 .52724 L p .624 .407 .566 r
F P
0 g
s
.54981 .52724 m .54689 .52032 L .53928 .5234 L p .624 .407 .566 r
F P
0 g
s
.72395 .12766 m .72385 .1349 L .73332 .14091 L p .828 .4 .223 r
F P
0 g
s
.72385 .1349 m .72395 .12766 L .71713 .12359 L p .797 .368 .228 r
F P
0 g
s
.10758 .40483 m .08199 .43348 L .08057 .44214 L p .162 0 .273 r
F P
0 g
s
.50647 .38905 m .51007 .38108 L .50262 .37512 L p .501 .405 .679 r
F P
0 g
s
.50537 .36601 m .50262 .37512 L .51007 .38108 L p .489 .406 .688 r
F P
0 g
s
.44336 .47639 m .45057 .47372 L .44915 .46496 L p .802 .687 .737 r
F P
0 g
s
.61681 .41346 m .62944 .40637 L .62077 .40048 L p .742 .822 .913 r
F P
0 g
s
.62077 .40048 m .60885 .4083 L .61681 .41346 L p .742 .822 .913 r
F P
0 g
s
.63375 .12246 m .65751 .11333 L .64907 .11014 L p .507 .086 .176 r
F P
0 g
s
.64907 .11014 m .62319 .11832 L .63375 .12246 L p .507 .086 .176 r
F P
0 g
s
.44381 .43798 m .43595 .43827 L .43789 .44746 L p .774 .574 .629 r
F P
0 g
s
.43789 .44746 m .44568 .44664 L .44381 .43798 L p .774 .574 .629 r
F P
0 g
s
.45297 .44564 m .44568 .44664 L .4475 .45578 L p .767 .605 .677 r
F P
0 g
s
.4475 .45578 m .4547 .45445 L .45297 .44564 L p .767 .605 .677 r
F P
0 g
s
.74887 .15187 m .75575 .17077 L .76311 .17686 L p .932 .556 .249 r
F P
0 g
s
.75575 .17077 m .74887 .15187 L .74179 .14666 L p .912 .557 .351 r
F P
0 g
s
.56336 .4348 m .5683 .42886 L .55853 .42412 L p .736 .707 .824 r
F P
0 g
s
.55853 .42412 m .55378 .4308 L .56336 .4348 L p .736 .707 .824 r
F P
0 g
s
.60052 .52719 m .61549 .53529 L .62356 .53172 L p .702 .288 .259 r
F P
0 g
s
.64509 .54193 m .62356 .53172 L .61549 .53529 L p .71 .301 .27 r
F P
0 g
s
.54689 .52032 m .54981 .52724 L .5585 .52375 L p .658 .423 .553 r
F P
0 g
s
.71713 .12359 m .71382 .12891 L .72385 .1349 L p .797 .368 .228 r
F P
0 g
s
.54832 .18397 m .56986 .1566 L .56068 .15356 L p .284 .028 .337 r
F P
0 g
s
.56068 .15356 m .53903 .18056 L .54832 .18397 L p .284 .028 .337 r
F P
0 g
s
.43729 .48914 m .42892 .49442 L .4307 .50353 L p .858 .793 .786 r
F P
0 g
s
.42144 .51146 m .4307 .50353 L .42892 .49442 L p .869 .798 .777 r
F P
0 g
s
.4547 .45445 m .4475 .45578 L .44915 .46496 L p .777 .642 .712 r
F P
0 g
s
.4719 .64314 m .46518 .69047 L .47739 .68646 L p .208 .104 .509 r
F P
0 g
s
.47739 .68646 m .48189 .63973 L .4719 .64314 L p .208 .104 .509 r
F P
0 g
s
.06727 .47136 m .07942 .45339 L .08057 .44214 L p .004 0 .317 r
F P
0 g
s
.07942 .45339 m .06727 .47136 L .06668 .47984 L p .117 .002 .433 r
F P
0 g
s
.50217 .43078 m .50898 .42504 L .50068 .41562 L p .642 .528 .709 r
F P
0 g
s
.50578 .40984 m .50068 .41562 L .50898 .42504 L p .634 .529 .718 r
F P
0 g
s
.70931 .36288 m .73128 .34058 L .72311 .33332 L p .857 .911 .869 r
F P
0 g
s
.72311 .33332 m .70148 .35616 L .70931 .36288 L p .857 .911 .869 r
F P
0 g
s
.42144 .51146 m .41037 .52138 L .41247 .53101 L p .894 .863 .801 r
F P
0 g
s
.39902 .54504 m .41247 .53101 L .41037 .52138 L p .893 .861 .802 r
F P
0 g
s
.76848 .20422 m .76311 .17686 L .75575 .17077 L p .959 .675 .455 r
F P
0 g
s
.52121 .24091 m .53222 .21295 L .52325 .2093 L p .239 .094 .474 r
F P
0 g
s
.53903 .18056 m .52325 .2093 L .53222 .21295 L p .262 .066 .416 r
F P
0 g
s
.50578 .40984 m .51051 .40332 L .50263 .39612 L p .584 .475 .695 r
F P
0 g
s
.50647 .38905 m .50263 .39612 L .51051 .40332 L p .573 .475 .705 r
F P
0 g
s
.75797 .82582 m .74591 .85603 L .75305 .85078 L p .897 .971 .819 r
F P
0 g
s
.75305 .85078 m .76996 .8172 L .75797 .82582 L p .897 .971 .819 r
F P
0 g
s
.2888 .35696 m .24642 .35104 L .24577 .36081 L p .646 .2 .177 r
F P
0 g
s
.24577 .36081 m .28878 .36603 L .2888 .35696 L p .646 .2 .177 r
F P
0 g
s
.53222 .21295 m .54832 .18397 L .53903 .18056 L p .262 .066 .416 r
F P
0 g
s
.38126 .56214 m .35678 .58209 L .35958 .59292 L p .871 .927 .86 r
F P
0 g
s
.32579 .61577 m .35958 .59292 L .35678 .58209 L p .829 .91 .894 r
F P
0 g
s
.19778 .35428 m .1493 .37019 L .14737 .3795 L p .412 .002 .147 r
F P
0 g
s
.10758 .40483 m .14737 .3795 L .1493 .37019 L p .205 0 .098 r
F P
0 g
s
.54984 .4374 m .55378 .4308 L .54276 .42566 L p .717 .662 .794 r
F P
0 g
s
.54276 .42566 m .53857 .43312 L .54984 .4374 L p .717 .662 .794 r
F P
0 g
s
.53516 .44095 m .53857 .43312 L .52615 .4268 L p .697 .622 .768 r
F P
0 g
s
.52615 .4268 m .5209 .43519 L .53516 .44095 L p .697 .622 .768 r
F P
0 g
s
.0792 .53049 m .06678 .51921 L .06744 .52818 L p .145 .207 .669 r
F P
0 g
s
.06744 .52818 m .08035 .54521 L .0792 .53049 L p .145 .207 .669 r
F P
0 g
s
.49833 .58314 m .49021 .60666 L .50184 .60226 L p .334 .137 .457 r
F P
0 g
s
.50184 .60226 m .50764 .5796 L .49833 .58314 L p .334 .137 .457 r
F P
0 g
s
.42543 .42915 m .41563 .42747 L .41765 .4374 L p .798 .548 .559 r
F P
0 g
s
.41765 .4374 m .42732 .43809 L .42543 .42915 L p .798 .548 .559 r
F P
0 g
s
.67705 .89437 m .63894 .89096 L .62678 .89545 L p .487 .843 .994 r
F P
0 g
s
.63894 .89096 m .67705 .89437 L .68568 .89061 L p .607 .863 .991 r
F P
0 g
s
.44169 .46699 m .44915 .46496 L .4475 .45578 L p .792 .649 .704 r
F P
0 g
s
.44915 .46496 m .44169 .46699 L .44336 .47639 L p .802 .687 .737 r
F P
0 g
s
.57315 .5272 m .56673 .52046 L .5585 .52375 L p .674 .403 .503 r
F P
0 g
s
.56673 .52046 m .57315 .5272 L .58183 .52367 L p .699 .4 .465 r
F P
0 g
s
.75138 .31244 m .76667 .27931 L .75883 .27183 L p .941 .891 .752 r
F P
0 g
s
.76754 .23698 m .75883 .27183 L .76667 .27931 L p .977 .858 .654 r
F P
0 g
s
.44568 .44664 m .43789 .44746 L .43984 .45719 L p .783 .613 .669 r
F P
0 g
s
.43984 .45719 m .4475 .45578 L .44568 .44664 L p .783 .613 .669 r
F P
0 g
s
.11031 .58248 m .08183 .55792 L .08358 .56795 L p .23 .392 .819 r
F P
0 g
s
.08358 .56795 m .11293 .59715 L .11031 .58248 L p .23 .392 .819 r
F P
0 g
s
.53264 .53417 m .53296 .54341 L .54292 .53941 L p .571 .353 .545 r
F P
0 g
s
.54292 .53941 m .54105 .53077 L .53264 .53417 L p .571 .353 .545 r
F P
0 g
s
.44336 .47639 m .43555 .47973 L .43729 .48914 L p .829 .736 .762 r
F P
0 g
s
.42892 .49442 m .43729 .48914 L .43555 .47973 L p .843 .743 .753 r
F P
0 g
s
.73128 .34058 m .75138 .31244 L .74318 .30488 L p .899 .907 .821 r
F P
0 g
s
.74318 .30488 m .72311 .33332 L .73128 .34058 L p .899 .907 .821 r
F P
0 g
s
.51007 .38108 m .51349 .37209 L .50537 .36601 L p .489 .406 .688 r
F P
0 g
s
.50794 .35558 m .50537 .36601 L .51349 .37209 L p .479 .406 .696 r
F P
0 g
s
.59 .42135 m .59867 .41514 L .58913 .40936 L p .733 .759 .873 r
F P
0 g
s
.58913 .40936 m .58107 .41627 L .59 .42135 L p .733 .759 .873 r
F P
0 g
s
.43595 .43827 m .42732 .43809 L .42939 .4481 L p .79 .582 .62 r
F P
0 g
s
.42939 .4481 m .43789 .44746 L .43595 .43827 L p .79 .582 .62 r
F P
0 g
s
.51043 .34358 m .51302 .32969 L .50467 .32438 L p .365 .307 .659 r
F P
0 g
s
.50676 .30788 m .50467 .32438 L .51302 .32969 L p .366 .306 .657 r
F P
0 g
s
.50898 .42504 m .51484 .41837 L .50578 .40984 L p .634 .529 .718 r
F P
0 g
s
.51051 .40332 m .50578 .40984 L .51484 .41837 L p .625 .529 .726 r
F P
0 g
s
.51484 .41837 m .50898 .42504 L .5209 .43519 L p .666 .578 .746 r
F P
0 g
s
.43555 .47973 m .44336 .47639 L .44169 .46699 L p .817 .694 .729 r
F P
0 g
s
.4475 .45578 m .43984 .45719 L .44169 .46699 L p .792 .649 .704 r
F P
0 g
s
.5683 .42886 m .57417 .42272 L .56407 .41728 L p .726 .707 .832 r
F P
0 g
s
.56407 .41728 m .55853 .42412 L .5683 .42886 L p .726 .707 .832 r
F P
0 g
s
.5209 .43519 m .52615 .4268 L .51484 .41837 L p .666 .578 .746 r
F P
0 g
s
.75883 .27183 m .74318 .30488 L .75138 .31244 L p .941 .891 .752 r
F P
0 g
s
.58183 .52367 m .5918 .53084 L .60052 .52719 L p .704 .353 .378 r
F P
0 g
s
.61549 .53529 m .60052 .52719 L .5918 .53084 L p .697 .34 .367 r
F P
0 g
s
.51051 .40332 m .51493 .3961 L .50647 .38905 L p .573 .475 .705 r
F P
0 g
s
.51007 .38108 m .50647 .38905 L .51493 .3961 L p .562 .475 .714 r
F P
0 g
s
.62944 .40637 m .64417 .3979 L .63468 .39122 L p .746 .821 .91 r
F P
0 g
s
.63468 .39122 m .62077 .40048 L .62944 .40637 L p .746 .821 .91 r
F P
0 g
s
.77779 .68503 m .78927 .75289 L .79683 .74579 L p .991 .767 .5 r
F P
0 g
s
.79683 .74579 m .78673 .67771 L .77779 .68503 L p .991 .767 .5 r
F P
0 g
s
.5918 .53084 m .58183 .52367 L .57315 .5272 L p .686 .374 .442 r
F P
0 g
s
.37096 .39464 m .35007 .38545 L .35143 .39635 L p .802 .433 .358 r
F P
0 g
s
.35143 .39635 m .37236 .4041 L .37096 .39464 L p .802 .433 .358 r
F P
0 g
s
.40253 .41549 m .38897 .41051 L .39087 .42124 L p .815 .509 .472 r
F P
0 g
s
.39087 .42124 m .40432 .42488 L .40253 .41549 L p .815 .509 .472 r
F P
0 g
s
.67316 .55765 m .70806 .58345 L .71668 .5783 L p .786 .343 .197 r
F P
0 g
s
.75561 .6188 m .71668 .5783 L .70806 .58345 L p .861 .466 .289 r
F P
0 g
s
.24642 .35104 m .19778 .35428 L .19639 .36422 L p .552 .118 .17 r
F P
0 g
s
.19639 .36422 m .24577 .36081 L .24642 .35104 L p .552 .118 .17 r
F P
0 g
s
.52385 .54705 m .52198 .5592 L .53302 .5548 L p .51 .292 .519 r
F P
0 g
s
.53302 .5548 m .53296 .54341 L .52385 .54705 L p .51 .292 .519 r
F P
0 g
s
.53857 .43312 m .54276 .42566 L .53108 .41907 L p .689 .62 .774 r
F P
0 g
s
.53108 .41907 m .52615 .4268 L .53857 .43312 L p .689 .62 .774 r
F P
0 g
s
.55378 .4308 m .55853 .42412 L .54752 .41831 L p .708 .662 .802 r
F P
0 g
s
.54752 .41831 m .54276 .42566 L .55378 .4308 L p .708 .662 .802 r
F P
0 g
s
.51246 .56295 m .50764 .5796 L .51939 .57499 L p .434 .222 .49 r
F P
0 g
s
.51939 .57499 m .52198 .5592 L .51246 .56295 L p .434 .222 .49 r
F P
0 g
s
.56348 .53111 m .5585 .52375 L .54981 .52724 L p .645 .395 .527 r
F P
0 g
s
.5585 .52375 m .56348 .53111 L .57315 .5272 L p .674 .403 .503 r
F P
0 g
s
.14737 .3795 m .19639 .36422 L .19778 .35428 L p .412 .002 .147 r
F P
0 g
s
.54105 .53077 m .54292 .53941 L .55325 .53524 L p .611 .379 .541 r
F P
0 g
s
.55325 .53524 m .54981 .52724 L .54105 .53077 L p .611 .379 .541 r
F P
0 g
s
.06668 .47984 m .07859 .46682 L .07942 .45339 L p .117 .002 .433 r
F P
0 g
s
.07859 .46682 m .06668 .47984 L .06632 .48929 L p .184 .095 .514 r
F P
0 g
s
.52003 .41127 m .51484 .41837 L .52615 .4268 L p .658 .577 .752 r
F P
0 g
s
.51484 .41837 m .52003 .41127 L .51051 .40332 L p .625 .529 .726 r
F P
0 g
s
.43789 .44746 m .42939 .4481 L .43152 .4587 L p .798 .62 .66 r
F P
0 g
s
.43152 .4587 m .43984 .45719 L .43789 .44746 L p .798 .62 .66 r
F P
0 g
s
.51493 .3961 m .51051 .40332 L .52003 .41127 L p .615 .529 .734 r
F P
0 g
s
.4336 .46941 m .44169 .46699 L .43984 .45719 L p .807 .656 .696 r
F P
0 g
s
.44169 .46699 m .4336 .46941 L .43555 .47973 L p .817 .694 .729 r
F P
0 g
s
.42892 .49442 m .41931 .50101 L .42144 .51146 L p .869 .798 .777 r
F P
0 g
s
.41037 .52138 m .42144 .51146 L .41931 .50101 L p .875 .799 .772 r
F P
0 g
s
.54981 .52724 m .55325 .53524 L .56348 .53111 L p .645 .395 .527 r
F P
0 g
s
.52615 .4268 m .53108 .41907 L .52003 .41127 L p .658 .577 .752 r
F P
0 g
s
.07843 .51451 m .06636 .50943 L .06678 .51921 L p .2 .212 .648 r
F P
0 g
s
.06678 .51921 m .0792 .53049 L .07843 .51451 L p .2 .212 .648 r
F P
0 g
s
.68027 .12409 m .69393 .11805 L .68496 .11366 L p .68 .277 .276 r
F P
0 g
s
.68496 .11366 m .66805 .11805 L .68027 .12409 L p .68 .277 .276 r
F P
0 g
s
.43984 .45719 m .43152 .4587 L .4336 .46941 L p .807 .656 .696 r
F P
0 g
s
.41563 .42747 m .40432 .42488 L .4065 .43609 L p .811 .555 .551 r
F P
0 g
s
.4065 .43609 m .41765 .4374 L .41563 .42747 L p .811 .555 .551 r
F P
0 g
s
.51349 .37209 m .51682 .36189 L .50794 .35558 L p .479 .406 .696 r
F P
0 g
s
.51043 .34358 m .50794 .35558 L .51682 .36189 L p .472 .406 .702 r
F P
0 g
s
.57417 .42272 m .58107 .41627 L .57047 .41012 L p .717 .707 .839 r
F P
0 g
s
.57047 .41012 m .56407 .41728 L .57417 .42272 L p .717 .707 .839 r
F P
0 g
s
.42732 .43809 m .41765 .4374 L .41989 .44851 L p .805 .59 .611 r
F P
0 g
s
.41989 .44851 m .42939 .4481 L .42732 .43809 L p .805 .59 .611 r
F P
0 g
s
.59867 .41514 m .60885 .4083 L .59854 .40174 L p .728 .758 .877 r
F P
0 g
s
.59854 .40174 m .58913 .40936 L .59867 .41514 L p .728 .758 .877 r
F P
0 g
s
.51493 .3961 m .51916 .38813 L .51007 .38108 L p .562 .475 .714 r
F P
0 g
s
.51349 .37209 m .51007 .38108 L .51916 .38813 L p .552 .475 .722 r
F P
0 g
s
.51302 .32969 m .51603 .3135 L .50676 .30788 L p .366 .306 .657 r
F P
0 g
s
.50965 .28863 m .50676 .30788 L .51603 .3135 L p .372 .303 .65 r
F P
0 g
s
.74179 .14666 m .74601 .16359 L .75575 .17077 L p .912 .557 .351 r
F P
0 g
s
.74601 .16359 m .74179 .14666 L .73332 .14091 L p .878 .536 .399 r
F P
0 g
s
.41037 .52138 m .39651 .53368 L .39902 .54504 L p .893 .861 .802 r
F P
0 g
s
.38126 .56214 m .39902 .54504 L .39651 .53368 L p .882 .856 .811 r
F P
0 g
s
.35678 .58209 m .32249 .60327 L .32579 .61577 L p .829 .91 .894 r
F P
0 g
s
.27964 .63515 m .32579 .61577 L .32249 .60327 L p .764 .878 .929 r
F P
0 g
s
.42686 .48384 m .43555 .47973 L .4336 .46941 L p .83 .7 .721 r
F P
0 g
s
.43555 .47973 m .42686 .48384 L .42892 .49442 L p .843 .743 .753 r
F P
0 g
s
.2188 .62922 m .16018 .62064 L .16367 .63326 L p .529 .728 .965 r
F P
0 g
s
.16367 .63326 m .22261 .64321 L .2188 .62922 L p .529 .728 .965 r
F P
0 g
s
.41931 .50101 m .42892 .49442 L .42686 .48384 L p .853 .747 .746 r
F P
0 g
s
.50179 .82147 m .55721 .8746 L .56959 .87129 L p .322 .506 .883 r
F P
0 g
s
.62678 .89545 m .56959 .87129 L .55721 .8746 L p .333 .669 .975 r
F P
0 g
s
.54276 .42566 m .54752 .41831 L .536 .41143 L p .68 .619 .78 r
F P
0 g
s
.536 .41143 m .53108 .41907 L .54276 .42566 L p .68 .619 .78 r
F P
0 g
s
.64417 .3979 m .66117 .38736 L .65077 .37983 L p .757 .821 .902 r
F P
0 g
s
.65077 .37983 m .63468 .39122 L .64417 .3979 L p .757 .821 .902 r
F P
0 g
s
.61549 .53529 m .63533 .54645 L .64509 .54193 L p .71 .301 .27 r
F P
0 g
s
.67316 .55765 m .64509 .54193 L .63533 .54645 L p .738 .346 .307 r
F P
0 g
s
.55853 .42412 m .56407 .41728 L .55281 .41085 L p .7 .661 .809 r
F P
0 g
s
.55281 .41085 m .54752 .41831 L .55853 .42412 L p .7 .661 .809 r
F P
0 g
s
.46518 .69047 m .47124 .75289 L .48532 .74854 L p .248 .217 .626 r
F P
0 g
s
.48532 .74854 m .47739 .68646 L .46518 .69047 L p .248 .217 .626 r
F P
0 g
s
.06632 .48929 m .07813 .48193 L .07859 .46682 L p .184 .095 .514 r
F P
0 g
s
.07813 .48193 m .06632 .48929 L .06621 .4993 L p .217 .157 .572 r
F P
0 g
s
.52489 .40379 m .52003 .41127 L .53108 .41907 L p .65 .576 .758 r
F P
0 g
s
.52003 .41127 m .52489 .40379 L .51493 .3961 L p .615 .529 .734 r
F P
0 g
s
.74328 .83551 m .73725 .86187 L .74591 .85603 L p .875 .94 .857 r
F P
0 g
s
.74591 .85603 m .75797 .82582 L .74328 .83551 L p .875 .94 .857 r
F P
0 g
s
.51916 .38813 m .51493 .3961 L .52489 .40379 L p .606 .529 .741 r
F P
0 g
s
.07808 .49806 m .06621 .4993 L .06636 .50943 L p .222 .195 .616 r
F P
0 g
s
.06636 .50943 m .07843 .51451 L .07808 .49806 L p .222 .195 .616 r
F P
0 g
s
.58143 .53514 m .57315 .5272 L .56348 .53111 L p .663 .38 .482 r
F P
0 g
s
.57315 .5272 m .58143 .53514 L .5918 .53084 L p .686 .374 .442 r
F P
0 g
s
.60797 .13898 m .63375 .12246 L .62319 .11832 L p .499 .156 .317 r
F P
0 g
s
.62319 .11832 m .59571 .13394 L .60797 .13898 L p .499 .156 .317 r
F P
0 g
s
.53108 .41907 m .536 .41143 L .52489 .40379 L p .65 .576 .758 r
F P
0 g
s
.70806 .58345 m .74636 .62522 L .75561 .6188 L p .861 .466 .289 r
F P
0 g
s
.78673 .67771 m .75561 .6188 L .74636 .62522 L p .936 .61 .393 r
F P
0 g
s
.53296 .54341 m .53302 .5548 L .54506 .54996 L p .562 .333 .526 r
F P
0 g
s
.54506 .54996 m .54292 .53941 L .53296 .54341 L p .562 .333 .526 r
F P
0 g
s
.68568 .89061 m .65398 .88444 L .63894 .89096 L p .607 .863 .991 r
F P
0 g
s
.65398 .88444 m .68568 .89061 L .69551 .88585 L p .681 .866 .969 r
F P
0 g
s
.06621 .4993 m .07808 .49806 L .07813 .48193 L p .217 .157 .572 r
F P
0 g
s
.77685 .76234 m .76996 .8172 L .77883 .81 L p .964 .885 .705 r
F P
0 g
s
.77883 .81 m .78927 .75289 L .77685 .76234 L p .964 .885 .705 r
F P
0 g
s
.38897 .41051 m .37236 .4041 L .37438 .41648 L p .818 .51 .469 r
F P
0 g
s
.37438 .41648 m .39087 .42124 L .38897 .41051 L p .818 .51 .469 r
F P
0 g
s
.42939 .4481 m .41989 .44851 L .42225 .46032 L p .812 .627 .652 r
F P
0 g
s
.42225 .46032 m .43152 .4587 L .42939 .4481 L p .812 .627 .652 r
F P
0 g
s
.74636 .62522 m .77779 .68503 L .78673 .67771 L p .936 .61 .393 r
F P
0 g
s
.35007 .38545 m .32326 .37534 L .32446 .38783 L p .784 .418 .363 r
F P
0 g
s
.32446 .38783 m .35143 .39635 L .35007 .38545 L p .784 .418 .363 r
F P
0 g
s
.42461 .47228 m .4336 .46941 L .43152 .4587 L p .82 .663 .688 r
F P
0 g
s
.4336 .46941 m .42461 .47228 L .42686 .48384 L p .83 .7 .721 r
F P
0 g
s
.76754 .23698 m .76848 .20422 L .75906 .19647 L p .947 .743 .596 r
F P
0 g
s
.75575 .17077 m .75906 .19647 L .76848 .20422 L p .959 .675 .455 r
F P
0 g
s
.51916 .38813 m .52329 .3793 L .51349 .37209 L p .552 .475 .722 r
F P
0 g
s
.51682 .36189 m .51349 .37209 L .52329 .3793 L p .544 .475 .728 r
F P
0 g
s
.58107 .41627 m .58913 .40936 L .57784 .40245 L p .71 .706 .844 r
F P
0 g
s
.57784 .40245 m .57047 .41012 L .58107 .41627 L p .71 .706 .844 r
F P
0 g
s
.51682 .36189 m .52019 .35023 L .51043 .34358 L p .472 .406 .702 r
F P
0 g
s
.51302 .32969 m .51043 .34358 L .52019 .35023 L p .469 .406 .704 r
F P
0 g
s
.49021 .60666 m .48189 .63973 L .49643 .63426 L p .355 .183 .505 r
F P
0 g
s
.49643 .63426 m .50184 .60226 L .49021 .60666 L p .355 .183 .505 r
F P
0 g
s
.43152 .4587 m .42225 .46032 L .42461 .47228 L p .82 .663 .688 r
F P
0 g
s
.51603 .3135 m .51992 .29459 L .50965 .28863 L p .372 .303 .65 r
F P
0 g
s
.51411 .26633 m .50965 .28863 L .51992 .29459 L p .383 .298 .636 r
F P
0 g
s
.08057 .44214 m .10591 .41669 L .10758 .40483 L p .162 0 .273 r
F P
0 g
s
.10591 .41669 m .08057 .44214 L .07942 .45339 L p .301 .097 .427 r
F P
0 g
s
.32249 .60327 m .27594 .62138 L .27964 .63515 L p .764 .878 .929 r
F P
0 g
s
.22261 .64321 m .27964 .63515 L .27594 .62138 L p .669 .822 .957 r
F P
0 g
s
.60885 .4083 m .62077 .40048 L .60953 .39307 L p .726 .757 .877 r
F P
0 g
s
.60953 .39307 m .59854 .40174 L .60885 .4083 L p .726 .757 .877 r
F P
0 g
s
.64703 .12854 m .66805 .11805 L .65751 .11333 L p .609 .244 .326 r
F P
0 g
s
.65751 .11333 m .63375 .12246 L .64703 .12854 L p .609 .244 .326 r
F P
0 g
s
.54752 .41831 m .55281 .41085 L .54108 .40358 L p .672 .618 .787 r
F P
0 g
s
.54108 .40358 m .536 .41143 L .54752 .41831 L p .672 .618 .787 r
F P
0 g
s
.60495 .53984 m .5918 .53084 L .58143 .53514 L p .681 .364 .432 r
F P
0 g
s
.5918 .53084 m .60495 .53984 L .61549 .53529 L p .697 .34 .367 r
F P
0 g
s
.69362 .1312 m .70369 .1232 L .69393 .11805 L p .73 .358 .346 r
F P
0 g
s
.69393 .11805 m .68027 .12409 L .69362 .1312 L p .73 .358 .346 r
F P
0 g
s
.52964 .39582 m .52489 .40379 L .536 .41143 L p .641 .575 .765 r
F P
0 g
s
.52489 .40379 m .52964 .39582 L .51916 .38813 L p .606 .529 .741 r
F P
0 g
s
.41765 .4374 m .4065 .43609 L .40896 .44867 L p .817 .596 .603 r
F P
0 g
s
.40896 .44867 m .41989 .44851 L .41765 .4374 L p .817 .596 .603 r
F P
0 g
s
.63533 .54645 m .61549 .53529 L .60495 .53984 L p .704 .352 .377 r
F P
0 g
s
.27594 .62138 m .2188 .62922 L .22261 .64321 L p .669 .822 .957 r
F P
0 g
s
.56983 .5399 m .56348 .53111 L .55325 .53524 L p .635 .375 .507 r
F P
0 g
s
.56348 .53111 m .56983 .5399 L .58143 .53514 L p .663 .38 .482 r
F P
0 g
s
.56407 .41728 m .57047 .41012 L .55872 .40304 L p .692 .66 .814 r
F P
0 g
s
.55872 .40304 m .55281 .41085 L .56407 .41728 L p .692 .66 .814 r
F P
0 g
s
.73332 .14091 m .73434 .15567 L .74601 .16359 L p .878 .536 .399 r
F P
0 g
s
.73434 .15567 m .73332 .14091 L .72385 .1349 L p .842 .504 .415 r
F P
0 g
s
.40432 .42488 m .39087 .42124 L .39324 .4341 L p .82 .559 .545 r
F P
0 g
s
.39324 .4341 m .4065 .43609 L .40432 .42488 L p .82 .559 .545 r
F P
0 g
s
.52329 .3793 m .51916 .38813 L .52964 .39582 L p .598 .529 .748 r
F P
0 g
s
.54292 .53941 m .54506 .54996 L .55752 .54492 L p .602 .36 .522 r
F P
0 g
s
.55752 .54492 m .55325 .53524 L .54292 .53941 L p .602 .36 .522 r
F P
0 g
s
.41931 .50101 m .40785 .50921 L .41037 .52138 L p .875 .799 .772 r
F P
0 g
s
.39651 .53368 m .41037 .52138 L .40785 .50921 L p .874 .798 .772 r
F P
0 g
s
.75906 .19647 m .75575 .17077 L .74601 .16359 L p .912 .642 .514 r
F P
0 g
s
.56959 .87129 m .62678 .89545 L .63894 .89096 L p .517 .712 .96 r
F P
0 g
s
.536 .41143 m .54108 .40358 L .52964 .39582 L p .641 .575 .765 r
F P
0 g
s
.41689 .4889 m .42686 .48384 L .42461 .47228 L p .84 .705 .714 r
F P
0 g
s
.42686 .48384 m .41689 .4889 L .41931 .50101 L p .853 .747 .746 r
F P
0 g
s
.52198 .5592 m .51939 .57499 L .53301 .56955 L p .507 .286 .513 r
F P
0 g
s
.53301 .56955 m .53302 .5548 L .52198 .5592 L p .507 .286 .513 r
F P
0 g
s
.66117 .38736 m .68043 .37382 L .66909 .36541 L p .774 .821 .889 r
F P
0 g
s
.66909 .36541 m .65077 .37983 L .66117 .38736 L p .774 .821 .889 r
F P
0 g
s
.14737 .3795 m .10758 .40483 L .10591 .41669 L p .392 .097 .341 r
F P
0 g
s
.55325 .53524 m .55752 .54492 L .56983 .5399 L p .635 .375 .507 r
F P
0 g
s
.40785 .50921 m .41931 .50101 L .41689 .4889 L p .858 .749 .741 r
F P
0 g
s
.50764 .5796 m .50184 .60226 L .51653 .59649 L p .442 .237 .505 r
F P
0 g
s
.51653 .59649 m .51939 .57499 L .50764 .5796 L p .442 .237 .505 r
F P
0 g
s
.72649 .84587 m .72744 .86805 L .73725 .86187 L p .844 .912 .881 r
F P
0 g
s
.73725 .86187 m .74328 .83551 L .72649 .84587 L p .844 .912 .881 r
F P
0 g
s
.108 .5639 m .08035 .54521 L .08183 .55792 L p .347 .421 .796 r
F P
0 g
s
.08183 .55792 m .11031 .58248 L .108 .5639 L p .347 .421 .796 r
F P
0 g
s
.47124 .75289 m .50179 .82147 L .51623 .81733 L p .288 .352 .755 r
F P
0 g
s
.51623 .81733 m .48532 .74854 L .47124 .75289 L p .288 .352 .755 r
F P
0 g
s
.39651 .53368 m .37827 .54865 L .38126 .56214 L p .882 .856 .811 r
F P
0 g
s
.35678 .58209 m .38126 .56214 L .37827 .54865 L p .861 .845 .827 r
F P
0 g
s
.69551 .88585 m .67115 .87622 L .65398 .88444 L p .681 .866 .969 r
F P
0 g
s
.67115 .87622 m .69551 .88585 L .70608 .88033 L p .733 .869 .944 r
F P
0 g
s
.70751 .13908 m .71382 .12891 L .70369 .1232 L p .77 .418 .389 r
F P
0 g
s
.70369 .1232 m .69362 .1312 L .70751 .13908 L p .77 .418 .389 r
F P
0 g
s
.52329 .3793 m .52747 .3694 L .51682 .36189 L p .544 .475 .728 r
F P
0 g
s
.52019 .35023 m .51682 .36189 L .52747 .3694 L p .539 .475 .732 r
F P
0 g
s
.72385 .1349 m .7213 .14737 L .73434 .15567 L p .842 .504 .415 r
F P
0 g
s
.7213 .14737 m .72385 .1349 L .71382 .12891 L p .806 .465 .411 r
F P
0 g
s
.56959 .87129 m .51623 .81733 L .50179 .82147 L p .322 .506 .883 r
F P
0 g
s
.41989 .44851 m .40896 .44867 L .4116 .46208 L p .823 .632 .645 r
F P
0 g
s
.4116 .46208 m .42225 .46032 L .41989 .44851 L p .823 .632 .645 r
F P
0 g
s
.58913 .40936 m .59854 .40174 L .58635 .394 L p .705 .705 .847 r
F P
0 g
s
.58635 .394 m .57784 .40245 L .58913 .40936 L p .705 .705 .847 r
F P
0 g
s
.52019 .35023 m .52381 .33675 L .51302 .32969 L p .469 .406 .704 r
F P
0 g
s
.51603 .3135 m .51302 .32969 L .52381 .33675 L p .47 .405 .702 r
F P
0 g
s
.55281 .41085 m .55872 .40304 L .54647 .39527 L p .664 .617 .792 r
F P
0 g
s
.54647 .39527 m .54108 .40358 L .55281 .41085 L p .664 .617 .792 r
F P
0 g
s
.51992 .29459 m .52543 .27259 L .51411 .26633 L p .383 .298 .636 r
F P
0 g
s
.52121 .24091 m .51411 .26633 L .52543 .27259 L p .399 .291 .614 r
F P
0 g
s
.53445 .38719 m .52964 .39582 L .54108 .40358 L p .634 .575 .77 r
F P
0 g
s
.52964 .39582 m .53445 .38719 L .52329 .3793 L p .598 .529 .748 r
F P
0 g
s
.41429 .4757 m .42461 .47228 L .42225 .46032 L p .83 .668 .681 r
F P
0 g
s
.42461 .47228 m .41429 .4757 L .41689 .4889 L p .84 .705 .714 r
F P
0 g
s
.71382 .12891 m .70751 .13908 L .7213 .14737 L p .806 .465 .411 r
F P
0 g
s
.62077 .40048 m .63468 .39122 L .62234 .38286 L p .729 .755 .874 r
F P
0 g
s
.62234 .38286 m .60953 .39307 L .62077 .40048 L p .729 .755 .874 r
F P
0 g
s
.57047 .41012 m .57784 .40245 L .56535 .39464 L p .685 .66 .819 r
F P
0 g
s
.56535 .39464 m .55872 .40304 L .57047 .41012 L p .685 .66 .819 r
F P
0 g
s
.52747 .3694 m .52329 .3793 L .53445 .38719 L p .591 .528 .753 r
F P
0 g
s
.58313 .16239 m .60797 .13898 L .59571 .13394 L p .481 .205 .417 r
F P
0 g
s
.59571 .13394 m .56986 .1566 L .58313 .16239 L p .481 .205 .417 r
F P
0 g
s
.42225 .46032 m .4116 .46208 L .41429 .4757 L p .83 .668 .681 r
F P
0 g
s
.54108 .40358 m .54647 .39527 L .53445 .38719 L p .634 .575 .77 r
F P
0 g
s
.37236 .4041 m .35143 .39635 L .35351 .41069 L p .812 .505 .47 r
F P
0 g
s
.35351 .41069 m .37438 .41648 L .37236 .4041 L p .812 .505 .47 r
F P
0 g
s
.32326 .37534 m .28878 .36603 L .28959 .38006 L p .753 .393 .371 r
F P
0 g
s
.28959 .38006 m .32446 .38783 L .32326 .37534 L p .753 .393 .371 r
F P
0 g
s
.68043 .37382 m .70148 .35616 L .68928 .3469 L p .797 .82 .87 r
F P
0 g
s
.68928 .3469 m .66909 .36541 L .68043 .37382 L p .797 .82 .87 r
F P
0 g
s
.59235 .54517 m .58143 .53514 L .56983 .5399 L p .659 .372 .474 r
F P
0 g
s
.58143 .53514 m .59235 .54517 L .60495 .53984 L p .681 .364 .432 r
F P
0 g
s
.7083 .85644 m .71689 .8743 L .72744 .86805 L p .81 .891 .902 r
F P
0 g
s
.72744 .86805 m .72649 .84587 L .7083 .85644 L p .81 .891 .902 r
F P
0 g
s
.63533 .54645 m .66144 .5634 L .67316 .55765 L p .738 .346 .307 r
F P
0 g
s
.70806 .58345 m .67316 .55765 L .66144 .5634 L p .783 .419 .368 r
F P
0 g
s
.70608 .88033 m .68956 .86673 L .67115 .87622 L p .733 .869 .944 r
F P
0 g
s
.68956 .86673 m .70608 .88033 L .71689 .8743 L p .774 .877 .922 r
F P
0 g
s
.4065 .43609 m .39324 .4341 L .39597 .44857 L p .824 .599 .598 r
F P
0 g
s
.39597 .44857 m .40896 .44867 L .4065 .43609 L p .824 .599 .598 r
F P
0 g
s
.53302 .5548 m .53301 .56955 L .54783 .56356 L p .559 .327 .52 r
F P
0 g
s
.54783 .56356 m .54506 .54996 L .53302 .5548 L p .559 .327 .52 r
F P
0 g
s
.1567 .6019 m .11031 .58248 L .11293 .59715 L p .463 .578 .885 r
F P
0 g
s
.11293 .59715 m .16018 .62064 L .1567 .6019 L p .463 .578 .885 r
F P
0 g
s
.75883 .27183 m .76754 .23698 L .75631 .22785 L p .919 .781 .691 r
F P
0 g
s
.75906 .19647 m .75631 .22785 L .76754 .23698 L p .947 .743 .596 r
F P
0 g
s
.71689 .8743 m .7083 .85644 L .68956 .86673 L p .774 .877 .922 r
F P
0 g
s
.39087 .42124 m .37438 .41648 L .37695 .43138 L p .822 .559 .543 r
F P
0 g
s
.37695 .43138 m .39324 .4341 L .39087 .42124 L p .822 .559 .543 r
F P
0 g
s
.52543 .27259 m .53352 .24738 L .52121 .24091 L p .399 .291 .614 r
F P
0 g
s
.53222 .21295 m .52121 .24091 L .53352 .24738 L p .417 .279 .584 r
F P
0 g
s
.40501 .49511 m .41689 .4889 L .41429 .4757 L p .846 .707 .71 r
F P
0 g
s
.41689 .4889 m .40501 .49511 L .40785 .50921 L p .858 .749 .741 r
F P
0 g
s
.52747 .3694 m .53184 .35816 L .52019 .35023 L p .539 .475 .732 r
F P
0 g
s
.52381 .33675 m .52019 .35023 L .53184 .35816 L p .536 .474 .734 r
F P
0 g
s
.55872 .40304 m .56535 .39464 L .55233 .38625 L p .658 .617 .796 r
F P
0 g
s
.55233 .38625 m .54647 .39527 L .55872 .40304 L p .658 .617 .796 r
F P
0 g
s
.53948 .37767 m .53445 .38719 L .54647 .39527 L p .628 .574 .775 r
F P
0 g
s
.53445 .38719 m .53948 .37767 L .52747 .3694 L p .591 .528 .753 r
F P
0 g
s
.40785 .50921 m .39353 .51932 L .39651 .53368 L p .874 .798 .772 r
F P
0 g
s
.37827 .54865 m .39651 .53368 L .39353 .51932 L p .864 .792 .778 r
F P
0 g
s
.59854 .40174 m .60953 .39307 L .59623 .38439 L p .704 .703 .847 r
F P
0 g
s
.59623 .38439 m .58635 .394 L .59854 .40174 L p .704 .703 .847 r
F P
0 g
s
.52381 .33675 m .52797 .32105 L .51603 .3135 L p .47 .405 .702 r
F P
0 g
s
.51992 .29459 m .51603 .3135 L .52797 .32105 L p .476 .403 .695 r
F P
0 g
s
.6625 .13634 m .68027 .12409 L .66805 .11805 L p .672 .346 .414 r
F P
0 g
s
.66805 .11805 m .64703 .12854 L .6625 .13634 L p .672 .346 .414 r
F P
0 g
s
.07942 .45339 m .10463 .43229 L .10591 .41669 L p .301 .097 .427 r
F P
0 g
s
.10463 .43229 m .07942 .45339 L .07859 .46682 L p .379 .211 .524 r
F P
0 g
s
.5782 .55108 m .56983 .5399 L .55752 .54492 L p .632 .368 .5 r
F P
0 g
s
.56983 .5399 m .5782 .55108 L .59235 .54517 L p .659 .372 .474 r
F P
0 g
s
.54647 .39527 m .55233 .38625 L .53948 .37767 L p .628 .574 .775 r
F P
0 g
s
.53184 .35816 m .52747 .3694 L .53948 .37767 L p .586 .528 .756 r
F P
0 g
s
.56183 .19026 m .58313 .16239 L .56986 .1566 L p .46 .238 .489 r
F P
0 g
s
.56986 .1566 m .54832 .18397 L .56183 .19026 L p .46 .238 .489 r
F P
0 g
s
.62249 .55218 m .60495 .53984 L .59235 .54517 L p .687 .375 .442 r
F P
0 g
s
.60495 .53984 m .62249 .55218 L .63533 .54645 L p .704 .352 .377 r
F P
0 g
s
.39353 .51932 m .40785 .50921 L .40501 .49511 L p .858 .748 .741 r
F P
0 g
s
.48189 .63973 m .47739 .68646 L .49521 .67979 L p .387 .255 .577 r
F P
0 g
s
.49521 .67979 m .49643 .63426 L .48189 .63973 L p .387 .255 .577 r
F P
0 g
s
.57784 .40245 m .58635 .394 L .57288 .38536 L p .681 .659 .821 r
F P
0 g
s
.57288 .38536 m .56535 .39464 L .57784 .40245 L p .681 .659 .821 r
F P
0 g
s
.70148 .35616 m .72311 .33332 L .7103 .3234 L p .825 .818 .843 r
F P
0 g
s
.7103 .3234 m .68928 .3469 L .70148 .35616 L p .825 .818 .843 r
F P
0 g
s
.54506 .54996 m .54783 .56356 L .56313 .5573 L p .599 .353 .515 r
F P
0 g
s
.56313 .5573 m .55752 .54492 L .54506 .54996 L p .599 .353 .515 r
F P
0 g
s
.74601 .16359 m .74656 .18728 L .75906 .19647 L p .912 .642 .514 r
F P
0 g
s
.74656 .18728 m .74601 .16359 L .73434 .15567 L p .868 .603 .535 r
F P
0 g
s
.63468 .39122 m .65077 .37983 L .63722 .37045 L p .737 .754 .867 r
F P
0 g
s
.63722 .37045 m .62234 .38286 L .63468 .39122 L p .737 .754 .867 r
F P
0 g
s
.40896 .44867 m .39597 .44857 L .39894 .46403 L p .829 .635 .641 r
F P
0 g
s
.39894 .46403 m .4116 .46208 L .40896 .44867 L p .829 .635 .641 r
F P
0 g
s
.66144 .5634 m .63533 .54645 L .62249 .55218 L p .726 .39 .41 r
F P
0 g
s
.53352 .24738 m .54534 .21945 L .53222 .21295 L p .417 .279 .584 r
F P
0 g
s
.54832 .18397 m .53222 .21295 L .54534 .21945 L p .438 .262 .543 r
F P
0 g
s
.55752 .54492 m .56313 .5573 L .5782 .55108 L p .632 .368 .5 r
F P
0 g
s
.402 .4798 m .41429 .4757 L .4116 .46208 L p .836 .67 .677 r
F P
0 g
s
.41429 .4757 m .402 .4798 L .40501 .49511 L p .846 .707 .71 r
F P
0 g
s
.37827 .54865 m .35328 .56613 L .35678 .58209 L p .861 .845 .827 r
F P
0 g
s
.32249 .60327 m .35678 .58209 L .35328 .56613 L p .826 .827 .849 r
F P
0 g
s
.54534 .21945 m .56183 .19026 L .54832 .18397 L p .438 .262 .543 r
F P
0 g
s
.6235 .14635 m .64703 .12854 L .63375 .12246 L p .594 .298 .435 r
F P
0 g
s
.63375 .12246 m .60797 .13898 L .6235 .14635 L p .594 .298 .435 r
F P
0 g
s
.51939 .57499 m .51653 .59649 L .53353 .58966 L p .514 .299 .526 r
F P
0 g
s
.53353 .58966 m .53301 .56955 L .51939 .57499 L p .514 .299 .526 r
F P
0 g
s
.28878 .36603 m .24577 .36081 L .24591 .37599 L p .705 .354 .378 r
F P
0 g
s
.24591 .37599 m .28959 .38006 L .28878 .36603 L p .705 .354 .378 r
F P
0 g
s
.10609 .54243 m .0792 .53049 L .08035 .54521 L p .408 .421 .762 r
F P
0 g
s
.08035 .54521 m .108 .5639 L .10609 .54243 L p .408 .421 .762 r
F P
0 g
s
.4116 .46208 m .39894 .46403 L .402 .4798 L p .836 .67 .677 r
F P
0 g
s
.19639 .36422 m .14737 .3795 L .14592 .39383 L p .539 .217 .371 r
F P
0 g
s
.10591 .41669 m .14592 .39383 L .14737 .3795 L p .392 .097 .341 r
F P
0 g
s
.74318 .30488 m .75883 .27183 L .74637 .26183 L p .888 .801 .758 r
F P
0 g
s
.75631 .22785 m .74637 .26183 L .75883 .27183 L p .919 .781 .691 r
F P
0 g
s
.75989 .77382 m .75797 .82582 L .76996 .8172 L p .917 .843 .755 r
F P
0 g
s
.76996 .8172 m .77685 .76234 L .75989 .77382 L p .917 .843 .755 r
F P
0 g
s
.72311 .33332 m .74318 .30488 L .73022 .29465 L p .855 .813 .807 r
F P
0 g
s
.73022 .29465 m .7103 .3234 L .72311 .33332 L p .855 .813 .807 r
F P
0 g
s
.35143 .39635 m .32446 .38783 L .32645 .40435 L p .796 .493 .476 r
F P
0 g
s
.32645 .40435 m .35351 .41069 L .35143 .39635 L p .796 .493 .476 r
F P
0 g
s
.75631 .22785 m .75906 .19647 L .74656 .18728 L p .892 .689 .621 r
F P
0 g
s
.50184 .60226 m .49643 .63426 L .5148 .627 L p .461 .277 .544 r
F P
0 g
s
.5148 .627 m .51653 .59649 L .50184 .60226 L p .461 .277 .544 r
F P
0 g
s
.54491 .36698 m .53948 .37767 L .55233 .38625 L p .623 .574 .778 r
F P
0 g
s
.53948 .37767 m .54491 .36698 L .53184 .35816 L p .586 .528 .756 r
F P
0 g
s
.56535 .39464 m .57288 .38536 L .55882 .3762 L p .654 .616 .799 r
F P
0 g
s
.55882 .3762 m .55233 .38625 L .56535 .39464 L p .654 .616 .799 r
F P
0 g
s
.53184 .35816 m .53663 .34524 L .52381 .33675 L p .536 .474 .734 r
F P
0 g
s
.52797 .32105 m .52381 .33675 L .53663 .34524 L p .538 .473 .732 r
F P
0 g
s
.74637 .26183 m .73022 .29465 L .74318 .30488 L p .888 .801 .758 r
F P
0 g
s
.39324 .4341 m .37695 .43138 L .37995 .44821 L p .825 .599 .597 r
F P
0 g
s
.37995 .44821 m .39597 .44857 L .39324 .4341 L p .825 .599 .597 r
F P
0 g
s
.52797 .32105 m .53314 .30266 L .51992 .29459 L p .476 .403 .695 r
F P
0 g
s
.52543 .27259 m .51992 .29459 L .53314 .30266 L p .486 .4 .684 r
F P
0 g
s
.60953 .39307 m .62234 .38286 L .60774 .37315 L p .706 .702 .844 r
F P
0 g
s
.60774 .37315 m .59623 .38439 L .60953 .39307 L p .706 .702 .844 r
F P
0 g
s
.55233 .38625 m .55882 .3762 L .54491 .36698 L p .623 .574 .778 r
F P
0 g
s
.76311 .69501 m .77685 .76234 L .78927 .75289 L p .939 .747 .617 r
F P
0 g
s
.78927 .75289 m .77779 .68503 L .76311 .69501 L p .939 .747 .617 r
F P
0 g
s
.53663 .34524 m .53184 .35816 L .54491 .36698 L p .584 .527 .757 r
F P
0 g
s
.58635 .394 m .59623 .38439 L .58154 .37481 L p .68 .658 .821 r
F P
0 g
s
.58154 .37481 m .57288 .38536 L .58635 .394 L p .68 .658 .821 r
F P
0 g
s
.37438 .41648 m .35351 .41069 L .35622 .42802 L p .816 .555 .544 r
F P
0 g
s
.35622 .42802 m .37695 .43138 L .37438 .41648 L p .816 .555 .544 r
F P
0 g
s
.66144 .5634 m .6944 .59074 L .70806 .58345 L p .783 .419 .368 r
F P
0 g
s
.74636 .62522 m .70806 .58345 L .6944 .59074 L p .835 .514 .444 r
F P
0 g
s
.63894 .89096 m .58723 .86477 L .56959 .87129 L p .517 .712 .96 r
F P
0 g
s
.58723 .86477 m .63894 .89096 L .65398 .88444 L p .613 .723 .923 r
F P
0 g
s
.67948 .14553 m .69362 .1312 L .68027 .12409 L p .718 .418 .469 r
F P
0 g
s
.68027 .12409 m .6625 .13634 L .67948 .14553 L p .718 .418 .469 r
F P
0 g
s
.39022 .50271 m .40501 .49511 L .402 .4798 L p .845 .706 .709 r
F P
0 g
s
.40501 .49511 m .39022 .50271 L .39353 .51932 L p .858 .748 .741 r
F P
0 g
s
.65077 .37983 m .66909 .36541 L .65426 .35498 L p .75 .753 .855 r
F P
0 g
s
.65426 .35498 m .63722 .37045 L .65077 .37983 L p .75 .753 .855 r
F P
0 g
s
.24577 .36081 m .19639 .36422 L .19567 .37966 L p .637 .297 .38 r
F P
0 g
s
.19567 .37966 m .24591 .37599 L .24577 .36081 L p .637 .297 .38 r
F P
0 g
s
.07859 .46682 m .10383 .45112 L .10463 .43229 L p .379 .211 .524 r
F P
0 g
s
.10383 .45112 m .07859 .46682 L .07813 .48193 L p .423 .288 .591 r
F P
0 g
s
.73434 .15567 m .73159 .17709 L .74656 .18728 L p .868 .603 .535 r
F P
0 g
s
.73159 .17709 m .73434 .15567 L .7213 .14737 L p .828 .563 .538 r
F P
0 g
s
.60705 .5589 m .59235 .54517 L .5782 .55108 L p .664 .383 .484 r
F P
0 g
s
.59235 .54517 m .60705 .5589 L .62249 .55218 L p .687 .375 .442 r
F P
0 g
s
.14592 .39383 m .19567 .37966 L .19639 .36422 L p .539 .217 .371 r
F P
0 g
s
.14592 .39383 m .10591 .41669 L .10463 .43229 L p .483 .244 .475 r
F P
0 g
s
.39353 .51932 m .37478 .5316 L .37827 .54865 L p .864 .792 .778 r
F P
0 g
s
.35328 .56613 m .37827 .54865 L .37478 .5316 L p .845 .781 .79 r
F P
0 g
s
.53301 .56955 m .53353 .58966 L .55199 .5821 L p .565 .339 .531 r
F P
0 g
s
.55199 .5821 m .54783 .56356 L .53301 .56955 L p .565 .339 .531 r
F P
0 g
s
.10468 .51924 m .07843 .51451 L .0792 .53049 L p .438 .406 .725 r
F P
0 g
s
.0792 .53049 m .10609 .54243 L .10468 .51924 L p .438 .406 .725 r
F P
0 g
s
.39597 .44857 m .37995 .44821 L .38327 .46626 L p .83 .635 .639 r
F P
0 g
s
.38327 .46626 m .39894 .46403 L .39597 .44857 L p .83 .635 .639 r
F P
0 g
s
.37478 .5316 m .39353 .51932 L .39022 .50271 L p .849 .742 .746 r
F P
0 g
s
.35328 .56613 m .31853 .58477 L .32249 .60327 L p .826 .827 .849 r
F P
0 g
s
.27594 .62138 m .32249 .60327 L .31853 .58477 L p .775 .797 .871 r
F P
0 g
s
.55098 .35473 m .54491 .36698 L .55882 .3762 L p .622 .573 .778 r
F P
0 g
s
.54491 .36698 m .55098 .35473 L .53663 .34524 L p .584 .527 .757 r
F P
0 g
s
.57288 .38536 m .58154 .37481 L .56619 .36476 L p .653 .615 .799 r
F P
0 g
s
.56619 .36476 m .55882 .3762 L .57288 .38536 L p .653 .615 .799 r
F P
0 g
s
.38675 .48473 m .402 .4798 L .39894 .46403 L p .836 .67 .676 r
F P
0 g
s
.402 .4798 m .38675 .48473 L .39022 .50271 L p .845 .706 .709 r
F P
0 g
s
.53314 .30266 m .53998 .28116 L .52543 .27259 L p .486 .4 .684 r
F P
0 g
s
.53352 .24738 m .52543 .27259 L .53998 .28116 L p .499 .394 .666 r
F P
0 g
s
.21472 .60842 m .1567 .6019 L .16018 .62064 L p .608 .686 .898 r
F P
0 g
s
.16018 .62064 m .2188 .62922 L .21472 .60842 L p .608 .686 .898 r
F P
0 g
s
.53663 .34524 m .54214 .33019 L .52797 .32105 L p .538 .473 .732 r
F P
0 g
s
.53314 .30266 m .52797 .32105 L .54214 .33019 L p .543 .472 .725 r
F P
0 g
s
.69721 .1557 m .70751 .13908 L .69362 .1312 L p .756 .474 .505 r
F P
0 g
s
.69362 .1312 m .67948 .14553 L .69721 .1557 L p .756 .474 .505 r
F P
0 g
s
.51623 .81733 m .56959 .87129 L .58723 .86477 L p .494 .57 .861 r
F P
0 g
s
.39894 .46403 m .38327 .46626 L .38675 .48473 L p .836 .67 .676 r
F P
0 g
s
.7213 .14737 m .71487 .16639 L .73159 .17709 L p .828 .563 .538 r
F P
0 g
s
.71487 .16639 m .7213 .14737 L .70751 .13908 L p .792 .521 .527 r
F P
0 g
s
.07813 .48193 m .10355 .4725 L .10383 .45112 L p .423 .288 .591 r
F P
0 g
s
.10355 .4725 m .07813 .48193 L .07808 .49806 L p .444 .341 .643 r
F P
0 g
s
.55882 .3762 m .56619 .36476 L .55098 .35473 L p .622 .573 .778 r
F P
0 g
s
.62234 .38286 m .63722 .37045 L .62115 .35962 L p .713 .701 .837 r
F P
0 g
s
.62115 .35962 m .60774 .37315 L .62234 .38286 L p .713 .701 .837 r
F P
0 g
s
.60003 .17076 m .6235 .14635 L .60797 .13898 L p .575 .333 .512 r
F P
0 g
s
.60797 .13898 m .58313 .16239 L .60003 .17076 L p .575 .333 .512 r
F P
0 g
s
.58963 .56635 m .5782 .55108 L .56313 .5573 L p .637 .379 .51 r
F P
0 g
s
.5782 .55108 m .58963 .56635 L .60705 .5589 L p .664 .383 .484 r
F P
0 g
s
.47739 .68646 m .48532 .74854 L .50584 .74088 L p .423 .345 .664 r
F P
0 g
s
.50584 .74088 m .49521 .67979 L .47739 .68646 L p .423 .345 .664 r
F P
0 g
s
.54214 .33019 m .53663 .34524 L .55098 .35473 L p .586 .526 .755 r
F P
0 g
s
.70751 .13908 m .69721 .1557 L .71487 .16639 L p .792 .521 .527 r
F P
0 g
s
.32446 .38783 m .28959 .38006 L .29123 .39873 L p .768 .472 .484 r
F P
0 g
s
.29123 .39873 m .32645 .40435 L .32446 .38783 L p .768 .472 .484 r
F P
0 g
s
.64588 .57068 m .62249 .55218 L .60705 .5589 L p .705 .409 .472 r
F P
0 g
s
.62249 .55218 m .64588 .57068 L .66144 .5634 L p .726 .39 .41 r
F P
0 g
s
.59623 .38439 m .60774 .37315 L .5916 .36251 L p .682 .656 .819 r
F P
0 g
s
.5916 .36251 m .58154 .37481 L .59623 .38439 L p .682 .656 .819 r
F P
0 g
s
.54783 .56356 m .55199 .5821 L .57099 .57421 L p .605 .364 .526 r
F P
0 g
s
.57099 .57421 m .56313 .5573 L .54783 .56356 L p .605 .364 .526 r
F P
0 g
s
.66909 .36541 m .68928 .3469 L .67327 .3355 L p .768 .751 .838 r
F P
0 g
s
.67327 .3355 m .65426 .35498 L .66909 .36541 L p .768 .751 .838 r
F P
0 g
s
.10383 .49555 m .07808 .49806 L .07843 .51451 L p .449 .379 .686 r
F P
0 g
s
.07843 .51451 m .10468 .51924 L .10383 .49555 L p .449 .379 .686 r
F P
0 g
s
.6944 .59074 m .66144 .5634 L .64588 .57068 L p .76 .451 .462 r
F P
0 g
s
.15341 .57814 m .108 .5639 L .11031 .58248 L p .528 .563 .834 r
F P
0 g
s
.11031 .58248 m .1567 .6019 L .15341 .57814 L p .528 .563 .834 r
F P
0 g
s
.07808 .49806 m .10383 .49555 L .10355 .4725 L p .444 .341 .643 r
F P
0 g
s
.64167 .15576 m .6625 .13634 L .64703 .12854 L p .655 .389 .505 r
F P
0 g
s
.64703 .12854 m .6235 .14635 L .64167 .15576 L p .655 .389 .505 r
F P
0 g
s
.56313 .5573 m .57099 .57421 L .58963 .56635 L p .637 .379 .51 r
F P
0 g
s
.6944 .59074 m .73141 .63414 L .74636 .62522 L p .835 .514 .444 r
F P
0 g
s
.77779 .68503 m .74636 .62522 L .73141 .63414 L p .89 .623 .529 r
F P
0 g
s
.74637 .26183 m .75631 .22785 L .74141 .21693 L p .866 .716 .694 r
F P
0 g
s
.74656 .18728 m .74141 .21693 L .75631 .22785 L p .892 .689 .621 r
F P
0 g
s
.37695 .43138 m .35622 .42802 L .35947 .44769 L p .819 .595 .599 r
F P
0 g
s
.35947 .44769 m .37995 .44821 L .37695 .43138 L p .819 .595 .599 r
F P
0 g
s
.73141 .63414 m .76311 .69501 L .77779 .68503 L p .89 .623 .529 r
F P
0 g
s
.73894 .78693 m .74328 .83551 L .75797 .82582 L p .872 .807 .783 r
F P
0 g
s
.75797 .82582 m .75989 .77382 L .73894 .78693 L p .872 .807 .783 r
F P
0 g
s
.74141 .21693 m .74656 .18728 L .73159 .17709 L p .846 .641 .625 r
F P
0 g
s
.51653 .59649 m .5148 .627 L .53604 .61835 L p .531 .335 .559 r
F P
0 g
s
.53604 .61835 m .53353 .58966 L .51653 .59649 L p .531 .335 .559 r
F P
0 g
s
.53998 .28116 m .54934 .25635 L .53352 .24738 L p .499 .394 .666 r
F P
0 g
s
.54534 .21945 m .53352 .24738 L .54934 .25635 L p .516 .386 .642 r
F P
0 g
s
.35351 .41069 m .32645 .40435 L .32917 .42442 L p .8 .544 .55 r
F P
0 g
s
.32917 .42442 m .35622 .42802 L .35351 .41069 L p .8 .544 .55 r
F P
0 g
s
.31853 .58477 m .27172 .60091 L .27594 .62138 L p .775 .797 .871 r
F P
0 g
s
.2188 .62922 m .27594 .62138 L .27172 .60091 L p .706 .753 .889 r
F P
0 g
s
.55797 .34049 m .55098 .35473 L .56619 .36476 L p .623 .572 .776 r
F P
0 g
s
.55098 .35473 m .55797 .34049 L .54214 .33019 L p .586 .526 .755 r
F P
0 g
s
.37096 .51191 m .39022 .50271 L .38675 .48473 L p .837 .701 .713 r
F P
0 g
s
.39022 .50271 m .37096 .51191 L .37478 .5316 L p .849 .742 .746 r
F P
0 g
s
.58154 .37481 m .5916 .36251 L .57472 .35144 L p .655 .614 .796 r
F P
0 g
s
.57472 .35144 m .56619 .36476 L .58154 .37481 L p .655 .614 .796 r
F P
0 g
s
.54214 .33019 m .54882 .31251 L .53314 .30266 L p .543 .472 .725 r
F P
0 g
s
.53998 .28116 m .53314 .30266 L .54882 .31251 L p .552 .469 .715 r
F P
0 g
s
.27172 .60091 m .21472 .60842 L .2188 .62922 L p .706 .753 .889 r
F P
0 g
s
.49643 .63426 m .49521 .67979 L .51771 .6708 L p .489 .338 .602 r
F P
0 g
s
.51771 .6708 m .5148 .627 L .49643 .63426 L p .489 .338 .602 r
F P
0 g
s
.65398 .88444 m .60919 .85538 L .58723 .86477 L p .613 .723 .923 r
F P
0 g
s
.60919 .85538 m .65398 .88444 L .67115 .87622 L p .674 .728 .89 r
F P
0 g
s
.57911 .19923 m .60003 .17076 L .58313 .16239 L p .555 .357 .568 r
F P
0 g
s
.58313 .16239 m .56183 .19026 L .57911 .19923 L p .555 .357 .568 r
F P
0 g
s
.68928 .3469 m .7103 .3234 L .69342 .31125 L p .789 .748 .815 r
F P
0 g
s
.69342 .31125 m .67327 .3355 L .68928 .3469 L p .789 .748 .815 r
F P
0 g
s
.56619 .36476 m .57472 .35144 L .55797 .34049 L p .623 .572 .776 r
F P
0 g
s
.63722 .37045 m .65426 .35498 L .63666 .343 L p .724 .699 .826 r
F P
0 g
s
.63666 .343 m .62115 .35962 L .63722 .37045 L p .724 .699 .826 r
F P
0 g
s
.54882 .31251 m .54214 .33019 L .55797 .34049 L p .591 .525 .749 r
F P
0 g
s
.37478 .5316 m .34928 .54595 L .35328 .56613 L p .845 .781 .79 r
F P
0 g
s
.31853 .58477 m .35328 .56613 L .34928 .54595 L p .815 .764 .805 r
F P
0 g
s
.54934 .25635 m .56216 .22859 L .54534 .21945 L p .516 .386 .642 r
F P
0 g
s
.56183 .19026 m .54534 .21945 L .56216 .22859 L p .535 .374 .61 r
F P
0 g
s
.37995 .44821 m .35947 .44769 L .36312 .46888 L p .823 .63 .642 r
F P
0 g
s
.36312 .46888 m .38327 .46626 L .37995 .44821 L p .823 .63 .642 r
F P
0 g
s
.60774 .37315 m .62115 .35962 L .60337 .34783 L p .688 .655 .812 r
F P
0 g
s
.60337 .34783 m .5916 .36251 L .60774 .37315 L p .688 .655 .812 r
F P
0 g
s
.56216 .22859 m .57911 .19923 L .56183 .19026 L p .535 .374 .61 r
F P
0 g
s
.34928 .54595 m .37478 .5316 L .37096 .51191 L p .832 .732 .754 r
F P
0 g
s
.10463 .43229 m .14504 .41286 L .14592 .39383 L p .483 .244 .475 r
F P
0 g
s
.14504 .41286 m .10463 .43229 L .10383 .45112 L p .532 .335 .559 r
F P
0 g
s
.36701 .49064 m .38675 .48473 L .38327 .46626 L p .829 .665 .679 r
F P
0 g
s
.38675 .48473 m .36701 .49064 L .37096 .51191 L p .837 .701 .713 r
F P
0 g
s
.73022 .29465 m .74637 .26183 L .72987 .24979 L p .839 .732 .746 r
F P
0 g
s
.74141 .21693 m .72987 .24979 L .74637 .26183 L p .866 .716 .694 r
F P
0 g
s
.28959 .38006 m .24591 .37599 L .24686 .39627 L p .728 .441 .492 r
F P
0 g
s
.24686 .39627 m .29123 .39873 L .28959 .38006 L p .728 .441 .492 r
F P
0 g
s
.62704 .57923 m .60705 .5589 L .58963 .56635 L p .681 .414 .512 r
F P
0 g
s
.60705 .5589 m .62704 .57923 L .64588 .57068 L p .705 .409 .472 r
F P
0 g
s
.48532 .74854 m .51623 .81733 L .5371 .80958 L p .46 .449 .76 r
F P
0 g
s
.5371 .80958 m .50584 .74088 L .48532 .74854 L p .46 .449 .76 r
F P
0 g
s
.19567 .37966 m .14592 .39383 L .14504 .41286 L p .596 .336 .493 r
F P
0 g
s
.38327 .46626 m .36312 .46888 L .36701 .49064 L p .829 .665 .679 r
F P
0 g
s
.7103 .3234 m .73022 .29465 L .71308 .28222 L p .813 .742 .785 r
F P
0 g
s
.71308 .28222 m .69342 .31125 L .7103 .3234 L p .813 .742 .785 r
F P
0 g
s
.66172 .16684 m .67948 .14553 L .6625 .13634 L p .699 .455 .55 r
F P
0 g
s
.6625 .13634 m .64167 .15576 L .66172 .16684 L p .699 .455 .55 r
F P
0 g
s
.58723 .86477 m .5371 .80958 L .51623 .81733 L p .494 .57 .861 r
F P
0 g
s
.53353 .58966 m .53604 .61835 L .55904 .60875 L p .581 .371 .561 r
F P
0 g
s
.55904 .60875 m .55199 .5821 L .53353 .58966 L p .581 .371 .561 r
F P
0 g
s
.73159 .17709 m .72357 .20475 L .74141 .21693 L p .846 .641 .625 r
F P
0 g
s
.72357 .20475 m .73159 .17709 L .71487 .16639 L p .807 .597 .618 r
F P
0 g
s
.72987 .24979 m .71308 .28222 L .73022 .29465 L p .839 .732 .746 r
F P
0 g
s
.54882 .31251 m .55723 .29171 L .53998 .28116 L p .552 .469 .715 r
F P
0 g
s
.54934 .25635 m .53998 .28116 L .55723 .29171 L p .565 .464 .699 r
F P
0 g
s
.7148 .80113 m .72649 .84587 L .74328 .83551 L p .831 .779 .803 r
F P
0 g
s
.74328 .83551 m .73894 .78693 L .7148 .80113 L p .831 .779 .803 r
F P
0 g
s
.56629 .32369 m .55797 .34049 L .57472 .35144 L p .629 .57 .77 r
F P
0 g
s
.55797 .34049 m .56629 .32369 L .54882 .31251 L p .591 .525 .749 r
F P
0 g
s
.5916 .36251 m .60337 .34783 L .58477 .33566 L p .66 .612 .79 r
F P
0 g
s
.58477 .33566 m .57472 .35144 L .5916 .36251 L p .66 .612 .79 r
F P
0 g
s
.6199 .1814 m .64167 .15576 L .6235 .14635 L p .635 .417 .569 r
F P
0 g
s
.6235 .14635 m .60003 .17076 L .6199 .1814 L p .635 .417 .569 r
F P
0 g
s
.35622 .42802 m .32917 .42442 L .33253 .4473 L p .804 .584 .604 r
F P
0 g
s
.33253 .4473 m .35947 .44769 L .35622 .42802 L p .804 .584 .604 r
F P
0 g
s
.74303 .70736 m .75989 .77382 L .77685 .76234 L p .884 .719 .673 r
F P
0 g
s
.77685 .76234 m .76311 .69501 L .74303 .70736 L p .884 .719 .673 r
F P
0 g
s
.65426 .35498 m .67327 .3355 L .65422 .32248 L p .739 .697 .811 r
F P
0 g
s
.65422 .32248 m .63666 .343 L .65426 .35498 L p .739 .697 .811 r
F P
0 g
s
.57472 .35144 m .58477 .33566 L .56629 .32369 L p .629 .57 .77 r
F P
0 g
s
.15049 .55077 m .10609 .54243 L .108 .5639 L p .559 .54 .789 r
F P
0 g
s
.108 .5639 m .15341 .57814 L .15049 .55077 L p .559 .54 .789 r
F P
0 g
s
.64588 .57068 m .67606 .59993 L .6944 .59074 L p .76 .451 .462 r
F P
0 g
s
.73141 .63414 m .6944 .59074 L .67606 .59993 L p .8 .528 .526 r
F P
0 g
s
.55723 .29171 m .54882 .31251 L .56629 .32369 L p .6 .522 .739 r
F P
0 g
s
.67115 .87622 m .6343 .84365 L .60919 .85538 L p .674 .728 .89 r
F P
0 g
s
.6343 .84365 m .67115 .87622 L .68956 .86673 L p .719 .735 .863 r
F P
0 g
s
.32645 .40435 m .29123 .39873 L .29368 .42151 L p .775 .526 .558 r
F P
0 g
s
.29368 .42151 m .32917 .42442 L .32645 .40435 L p .775 .526 .558 r
F P
0 g
s
.60565 .58871 m .58963 .56635 L .57099 .57421 L p .653 .409 .538 r
F P
0 g
s
.58963 .56635 m .60565 .58871 L .62704 .57923 L p .681 .414 .512 r
F P
0 g
s
.67606 .59993 m .64588 .57068 L .62704 .57923 L p .733 .462 .518 r
F P
0 g
s
.24591 .37599 m .19567 .37966 L .19566 .40027 L p .673 .397 .496 r
F P
0 g
s
.19566 .40027 m .24686 .39627 L .24591 .37599 L p .673 .397 .496 r
F P
0 g
s
.72987 .24979 m .74141 .21693 L .72357 .20475 L p .822 .663 .686 r
F P
0 g
s
.62115 .35962 m .63666 .343 L .61715 .33005 L p .697 .653 .802 r
F P
0 g
s
.61715 .33005 m .60337 .34783 L .62115 .35962 L p .697 .653 .802 r
F P
0 g
s
.68272 .17908 m .69721 .1557 L .67948 .14553 L p .736 .507 .581 r
F P
0 g
s
.67948 .14553 m .66172 .16684 L .68272 .17908 L p .736 .507 .581 r
F P
0 g
s
.55199 .5821 m .55904 .60875 L .58262 .5987 L p .62 .395 .554 r
F P
0 g
s
.58262 .5987 m .57099 .57421 L .55199 .5821 L p .62 .395 .554 r
F P
0 g
s
.14504 .41286 m .19566 .40027 L .19567 .37966 L p .596 .336 .493 r
F P
0 g
s
.71487 .16639 m .70368 .19193 L .72357 .20475 L p .807 .597 .618 r
F P
0 g
s
.70368 .19193 m .71487 .16639 L .69721 .1557 L p .771 .553 .603 r
F P
0 g
s
.34498 .52269 m .37096 .51191 L .36701 .49064 L p .821 .691 .72 r
F P
0 g
s
.37096 .51191 m .34498 .52269 L .34928 .54595 L p .832 .732 .754 r
F P
0 g
s
.57099 .57421 m .58262 .5987 L .60565 .58871 L p .653 .409 .538 r
F P
0 g
s
.34928 .54595 m .31412 .56136 L .31853 .58477 L p .815 .764 .805 r
F P
0 g
s
.27172 .60091 m .31853 .58477 L .31412 .56136 L p .772 .737 .821 r
F P
0 g
s
.69721 .1557 m .68272 .17908 L .70368 .19193 L p .771 .553 .603 r
F P
0 g
s
.55723 .29171 m .56808 .26748 L .54934 .25635 L p .565 .464 .699 r
F P
0 g
s
.56216 .22859 m .54934 .25635 L .56808 .26748 L p .58 .458 .678 r
F P
0 g
s
.68848 .81579 m .7083 .85644 L .72649 .84587 L p .794 .759 .822 r
F P
0 g
s
.72649 .84587 m .7148 .80113 L .68848 .81579 L p .794 .759 .822 r
F P
0 g
s
.2106 .58204 m .15341 .57814 L .1567 .6019 L p .64 .646 .841 r
F P
0 g
s
.1567 .6019 m .21472 .60842 L .2106 .58204 L p .64 .646 .841 r
F P
0 g
s
.10383 .45112 m .14478 .43605 L .14504 .41286 L p .532 .335 .559 r
F P
0 g
s
.14478 .43605 m .10383 .45112 L .10355 .4725 L p .559 .398 .619 r
F P
0 g
s
.68956 .86673 m .6612 .83021 L .6343 .84365 L p .719 .735 .863 r
F P
0 g
s
.6612 .83021 m .68956 .86673 L .7083 .85644 L p .758 .745 .841 r
F P
0 g
s
.5148 .627 m .51771 .6708 L .54366 .65997 L p .556 .388 .609 r
F P
0 g
s
.54366 .65997 m .53604 .61835 L .5148 .627 L p .556 .388 .609 r
F P
0 g
s
.35947 .44769 m .33253 .4473 L .3364 .47207 L p .808 .62 .648 r
F P
0 g
s
.3364 .47207 m .36312 .46888 L .35947 .44769 L p .808 .62 .648 r
F P
0 g
s
.5371 .80958 m .58723 .86477 L .60919 .85538 L p .585 .599 .832 r
F P
0 g
s
.57644 .30376 m .56629 .32369 L .58477 .33566 L p .637 .568 .76 r
F P
0 g
s
.56629 .32369 m .57644 .30376 L .55723 .29171 L p .6 .522 .739 r
F P
0 g
s
.67327 .3355 m .69342 .31125 L .6733 .29747 L p .757 .693 .79 r
F P
0 g
s
.6733 .29747 m .65422 .32248 L .67327 .3355 L p .757 .693 .79 r
F P
0 g
s
.7083 .85644 m .68848 .81579 L .6612 .83021 L p .758 .745 .841 r
F P
0 g
s
.49521 .67979 m .50584 .74088 L .53169 .73035 L p .52 .413 .672 r
F P
0 g
s
.53169 .73035 m .51771 .6708 L .49521 .67979 L p .52 .413 .672 r
F P
0 g
s
.60337 .34783 m .61715 .33005 L .59674 .31675 L p .669 .61 .781 r
F P
0 g
s
.59674 .31675 m .58477 .33566 L .60337 .34783 L p .669 .61 .781 r
F P
0 g
s
.59949 .21054 m .6199 .1814 L .60003 .17076 L p .616 .436 .615 r
F P
0 g
s
.60003 .17076 m .57911 .19923 L .59949 .21054 L p .616 .436 .615 r
F P
0 g
s
.31412 .56136 m .34928 .54595 L .34498 .52269 L p .805 .715 .766 r
F P
0 g
s
.34062 .49762 m .36701 .49064 L .36312 .46888 L p .814 .655 .685 r
F P
0 g
s
.36701 .49064 m .34062 .49762 L .34498 .52269 L p .821 .691 .72 r
F P
0 g
s
.56808 .26748 m .55723 .29171 L .57644 .30376 L p .612 .519 .724 r
F P
0 g
s
.56808 .26748 m .58206 .24003 L .56216 .22859 L p .58 .458 .678 r
F P
0 g
s
.57911 .19923 m .56216 .22859 L .58206 .24003 L p .597 .449 .651 r
F P
0 g
s
.58477 .33566 m .59674 .31675 L .57644 .30376 L p .637 .568 .76 r
F P
0 g
s
.36312 .46888 m .3364 .47207 L .34062 .49762 L p .814 .655 .685 r
F P
0 g
s
.14809 .52135 m .10468 .51924 L .10609 .54243 L p .574 .513 .749 r
F P
0 g
s
.10609 .54243 m .15049 .55077 L .14809 .52135 L p .574 .513 .749 r
F P
0 g
s
.63666 .343 m .65422 .32248 L .63309 .30847 L p .71 .65 .788 r
F P
0 g
s
.63309 .30847 m .61715 .33005 L .63666 .343 L p .71 .65 .788 r
F P
0 g
s
.64189 .19387 m .66172 .16684 L .64167 .15576 L p .68 .478 .607 r
F P
0 g
s
.64167 .15576 m .6199 .1814 L .64189 .19387 L p .68 .478 .607 r
F P
0 g
s
.71308 .28222 m .72987 .24979 L .71012 .23628 L p .799 .677 .73 r
F P
0 g
s
.72357 .20475 m .71012 .23628 L .72987 .24979 L p .822 .663 .686 r
F P
0 g
s
.58206 .24003 m .59949 .21054 L .57911 .19923 L p .597 .449 .651 r
F P
0 g
s
.67606 .59993 m .71111 .64532 L .73141 .63414 L p .8 .528 .526 r
F P
0 g
s
.76311 .69501 m .73141 .63414 L .71111 .64532 L p .842 .617 .597 r
F P
0 g
s
.29123 .39873 m .24686 .39627 L .24864 .4211 L p .74 .499 .566 r
F P
0 g
s
.24864 .4211 m .29368 .42151 L .29123 .39873 L p .74 .499 .566 r
F P
0 g
s
.69342 .31125 m .71308 .28222 L .69261 .2682 L p .777 .687 .764 r
F P
0 g
s
.69261 .2682 m .6733 .29747 L .69342 .31125 L p .777 .687 .764 r
F P
0 g
s
.71012 .23628 m .72357 .20475 L .70368 .19193 L p .785 .617 .673 r
F P
0 g
s
.32917 .42442 m .29368 .42151 L .29687 .44762 L p .78 .568 .612 r
F P
0 g
s
.29687 .44762 m .33253 .4473 L .32917 .42442 L p .78 .568 .612 r
F P
0 g
s
.10355 .4725 m .1452 .4626 L .14478 .43605 L p .559 .398 .619 r
F P
0 g
s
.1452 .4626 m .10355 .4725 L .10383 .49555 L p .573 .444 .667 r
F P
0 g
s
.19566 .40027 m .14504 .41286 L .14478 .43605 L p .626 .411 .57 r
F P
0 g
s
.71111 .64532 m .74303 .70736 L .76311 .69501 L p .842 .617 .597 r
F P
0 g
s
.31412 .56136 m .26722 .57499 L .27172 .60091 L p .772 .737 .821 r
F P
0 g
s
.21472 .60842 m .27172 .60091 L .26722 .57499 L p .716 .7 .834 r
F P
0 g
s
.65365 .61072 m .62704 .57923 L .60565 .58871 L p .705 .463 .555 r
F P
0 g
s
.62704 .57923 m .65365 .61072 L .67606 .59993 L p .733 .462 .518 r
F P
0 g
s
.71012 .23628 m .69261 .2682 L .71308 .28222 L p .799 .677 .73 r
F P
0 g
s
.26722 .57499 m .2106 .58204 L .21472 .60842 L p .716 .7 .834 r
F P
0 g
s
.14631 .49146 m .10383 .49555 L .10468 .51924 L p .578 .482 .709 r
F P
0 g
s
.10468 .51924 m .14809 .52135 L .14631 .49146 L p .578 .482 .709 r
F P
0 g
s
.58893 .28028 m .57644 .30376 L .59674 .31675 L p .649 .565 .746 r
F P
0 g
s
.57644 .30376 m .58893 .28028 L .56808 .26748 L p .612 .519 .724 r
F P
0 g
s
.58206 .24003 m .56808 .26748 L .58893 .28028 L p .626 .513 .705 r
F P
0 g
s
.10383 .49555 m .14631 .49146 L .1452 .4626 L p .573 .444 .667 r
F P
0 g
s
.61715 .33005 m .63309 .30847 L .61096 .29417 L p .681 .607 .767 r
F P
0 g
s
.61096 .29417 m .59674 .31675 L .61715 .33005 L p .681 .607 .767 r
F P
0 g
s
.53604 .61835 m .54366 .65997 L .57167 .64792 L p .604 .421 .607 r
F P
0 g
s
.57167 .64792 m .55904 .60875 L .53604 .61835 L p .604 .421 .607 r
F P
0 g
s
.71817 .72164 m .73894 .78693 L .75989 .77382 L p .837 .695 .706 r
F P
0 g
s
.75989 .77382 m .74303 .70736 L .71817 .72164 L p .837 .695 .706 r
F P
0 g
s
.665 .20761 m .68272 .17908 L .66172 .16684 L p .717 .529 .634 r
F P
0 g
s
.66172 .16684 m .64189 .19387 L .665 .20761 L p .717 .529 .634 r
F P
0 g
s
.30952 .5344 m .34498 .52269 L .34062 .49762 L p .796 .675 .73 r
F P
0 g
s
.34498 .52269 m .30952 .5344 L .31412 .56136 L p .805 .715 .766 r
F P
0 g
s
.65422 .32248 m .6733 .29747 L .65095 .28272 L p .726 .646 .769 r
F P
0 g
s
.65095 .28272 m .63309 .30847 L .65422 .32248 L p .726 .646 .769 r
F P
0 g
s
.59674 .31675 m .61096 .29417 L .58893 .28028 L p .649 .565 .746 r
F P
0 g
s
.70368 .19193 m .68813 .22199 L .71012 .23628 L p .785 .617 .673 r
F P
0 g
s
.68813 .22199 m .70368 .19193 L .68272 .17908 L p .751 .574 .656 r
F P
0 g
s
.71111 .64532 m .67606 .59993 L .65365 .61072 L p .766 .529 .575 r
F P
0 g
s
.62212 .22373 m .64189 .19387 L .6199 .1814 L p .661 .494 .648 r
F P
0 g
s
.6199 .1814 m .59949 .21054 L .62212 .22373 L p .661 .494 .648 r
F P
0 g
s
.68272 .17908 m .665 .20761 L .68813 .22199 L p .751 .574 .656 r
F P
0 g
s
.24686 .39627 m .19566 .40027 L .19641 .42551 L p .692 .463 .571 r
F P
0 g
s
.19641 .42551 m .24864 .4211 L .24686 .39627 L p .692 .463 .571 r
F P
0 g
s
.50584 .74088 m .5371 .80958 L .56327 .79865 L p .553 .499 .749 r
F P
0 g
s
.56327 .79865 m .53169 .73035 L .50584 .74088 L p .553 .499 .749 r
F P
0 g
s
.62802 .62267 m .60565 .58871 L .58262 .5987 L p .676 .456 .58 r
F P
0 g
s
.60565 .58871 m .62802 .62267 L .65365 .61072 L p .705 .463 .555 r
F P
0 g
s
.33253 .4473 m .29687 .44762 L .30068 .47602 L p .785 .604 .656 r
F P
0 g
s
.30068 .47602 m .3364 .47207 L .33253 .4473 L p .785 .604 .656 r
F P
0 g
s
.26722 .57499 m .31412 .56136 L .30952 .5344 L p .767 .691 .778 r
F P
0 g
s
.58893 .28028 m .60418 .25328 L .58206 .24003 L p .626 .513 .705 r
F P
0 g
s
.59949 .21054 m .58206 .24003 L .60418 .25328 L p .643 .505 .68 r
F P
0 g
s
.14478 .43605 m .19641 .42551 L .19566 .40027 L p .626 .411 .57 r
F P
0 g
s
.20669 .5517 m .15049 .55077 L .15341 .57814 L p .653 .61 .794 r
F P
0 g
s
.15341 .57814 m .2106 .58204 L .20669 .5517 L p .653 .61 .794 r
F P
0 g
s
.60919 .85538 m .56327 .79865 L .5371 .80958 L p .585 .599 .832 r
F P
0 g
s
.69261 .2682 m .71012 .23628 L .68813 .22199 L p .764 .631 .713 r
F P
0 g
s
.55904 .60875 m .57167 .64792 L .60026 .63527 L p .643 .442 .597 r
F P
0 g
s
.60026 .63527 m .58262 .5987 L .55904 .60875 L p .643 .442 .597 r
F P
0 g
s
.60418 .25328 m .62212 .22373 L .59949 .21054 L p .643 .505 .68 r
F P
0 g
s
.60418 .25328 m .58893 .28028 L .61096 .29417 L p .663 .56 .728 r
F P
0 g
s
.30497 .50543 m .34062 .49762 L .3364 .47207 L p .79 .639 .694 r
F P
0 g
s
.34062 .49762 m .30497 .50543 L .30952 .5344 L p .796 .675 .73 r
F P
0 g
s
.56327 .79865 m .60919 .85538 L .6343 .84365 L p .644 .617 .807 r
F P
0 g
s
.6733 .29747 m .69261 .2682 L .66985 .25328 L p .744 .64 .744 r
F P
0 g
s
.66985 .25328 m .65095 .28272 L .6733 .29747 L p .744 .64 .744 r
F P
0 g
s
.58262 .5987 m .60026 .63527 L .62802 .62267 L p .676 .456 .58 r
F P
0 g
s
.3364 .47207 m .30068 .47602 L .30497 .50543 L p .79 .639 .694 r
F P
0 g
s
.63309 .30847 m .65095 .28272 L .62752 .26774 L p .696 .603 .748 r
F P
0 g
s
.62752 .26774 m .61096 .29417 L .63309 .30847 L p .696 .603 .748 r
F P
0 g
s
.51771 .6708 m .53169 .73035 L .56144 .71752 L p .584 .454 .67 r
F P
0 g
s
.56144 .71752 m .54366 .65997 L .51771 .6708 L p .584 .454 .67 r
F P
0 g
s
.29368 .42151 m .24864 .4211 L .25121 .44966 L p .747 .544 .62 r
F P
0 g
s
.25121 .44966 m .29687 .44762 L .29368 .42151 L p .747 .544 .62 r
F P
0 g
s
.68813 .22199 m .66985 .25328 L .69261 .2682 L p .764 .631 .713 r
F P
0 g
s
.19641 .42551 m .14478 .43605 L .1452 .4626 L p .644 .465 .627 r
F P
0 g
s
.61096 .29417 m .62752 .26774 L .60418 .25328 L p .663 .56 .728 r
F P
0 g
s
.64596 .23821 m .665 .20761 L .64189 .19387 L p .698 .543 .674 r
F P
0 g
s
.64189 .19387 m .62212 .22373 L .64596 .23821 L p .698 .543 .674 r
F P
0 g
s
.66985 .25328 m .68813 .22199 L .665 .20761 L p .731 .587 .695 r
F P
0 g
s
.62212 .22373 m .60418 .25328 L .62752 .26774 L p .68 .553 .704 r
F P
0 g
s
.665 .20761 m .64596 .23821 L .66985 .25328 L p .731 .587 .695 r
F P
0 g
s
.65095 .28272 m .66985 .25328 L .64596 .23821 L p .713 .596 .724 r
F P
0 g
s
.64596 .23821 m .62752 .26774 L .65095 .28272 L p .713 .596 .724 r
F P
0 g
s
.30952 .5344 m .2627 .54518 L .26722 .57499 L p .767 .691 .778 r
F P
0 g
s
.2106 .58204 m .26722 .57499 L .2627 .54518 L p .719 .657 .788 r
F P
0 g
s
.68945 .73729 m .7148 .80113 L .73894 .78693 L p .798 .675 .729 r
F P
0 g
s
.73894 .78693 m .71817 .72164 L .68945 .73729 L p .798 .675 .729 r
F P
0 g
s
.62752 .26774 m .64596 .23821 L .62212 .22373 L p .68 .553 .704 r
F P
0 g
s
.65365 .61072 m .6861 .65838 L .71111 .64532 L p .766 .529 .575 r
F P
0 g
s
.74303 .70736 m .71111 .64532 L .6861 .65838 L p .801 .606 .638 r
F P
0 g
s
.6861 .65838 m .65365 .61072 L .62802 .62267 L p .734 .524 .608 r
F P
0 g
s
.2627 .54518 m .30952 .5344 L .30497 .50543 L p .762 .652 .74 r
F P
0 g
s
.2627 .54518 m .20669 .5517 L .2106 .58204 L p .719 .657 .788 r
F P
0 g
s
.6861 .65838 m .71817 .72164 L .74303 .70736 L p .801 .606 .638 r
F P
0 g
s
.20317 .51917 m .14809 .52135 L .15049 .55077 L p .659 .577 .752 r
F P
0 g
s
.15049 .55077 m .20669 .5517 L .20317 .51917 L p .659 .577 .752 r
F P
0 g
s
.29687 .44762 m .25121 .44966 L .2545 .48082 L p .752 .581 .664 r
F P
0 g
s
.2545 .48082 m .30068 .47602 L .29687 .44762 L p .752 .581 .664 r
F P
0 g
s
.24864 .4211 m .19641 .42551 L .19794 .45454 L p .703 .511 .626 r
F P
0 g
s
.19794 .45454 m .25121 .44966 L .24864 .4211 L p .703 .511 .626 r
F P
0 g
s
.1452 .4626 m .19794 .45454 L .19641 .42551 L p .644 .465 .627 r
F P
0 g
s
.19794 .45454 m .1452 .4626 L .14631 .49146 L p .654 .508 .673 r
F P
0 g
s
.6343 .84365 m .59327 .78516 L .56327 .79865 L p .644 .617 .807 r
F P
0 g
s
.59327 .78516 m .6343 .84365 L .6612 .83021 L p .689 .631 .786 r
F P
0 g
s
.54366 .65997 m .56144 .71752 L .59342 .70313 L p .631 .481 .661 r
F P
0 g
s
.59342 .70313 m .57167 .64792 L .54366 .65997 L p .631 .481 .661 r
F P
0 g
s
.25839 .5132 m .30497 .50543 L .30068 .47602 L p .757 .616 .703 r
F P
0 g
s
.30497 .50543 m .25839 .5132 L .2627 .54518 L p .762 .652 .74 r
F P
0 g
s
.30068 .47602 m .2545 .48082 L .25839 .5132 L p .757 .616 .703 r
F P
0 g
s
.20022 .48623 m .14631 .49146 L .14809 .52135 L p .658 .544 .713 r
F P
0 g
s
.14809 .52135 m .20317 .51917 L .20022 .48623 L p .658 .544 .713 r
F P
0 g
s
.65805 .75364 m .68848 .81579 L .7148 .80113 L p .762 .659 .749 r
F P
0 g
s
.7148 .80113 m .68945 .73729 L .65805 .75364 L p .762 .659 .749 r
F P
0 g
s
.53169 .73035 m .56327 .79865 L .59327 .78516 L p .614 .529 .735 r
F P
0 g
s
.59327 .78516 m .56144 .71752 L .53169 .73035 L p .614 .529 .735 r
F P
0 g
s
.14631 .49146 m .20022 .48623 L .19794 .45454 L p .654 .508 .673 r
F P
0 g
s
.6573 .6728 m .62802 .62267 L .60026 .63527 L p .703 .515 .631 r
F P
0 g
s
.62802 .62267 m .6573 .6728 L .6861 .65838 L p .734 .524 .608 r
F P
0 g
s
.6612 .83021 m .62544 .76987 L .59327 .78516 L p .689 .631 .786 r
F P
0 g
s
.62544 .76987 m .6612 .83021 L .68848 .81579 L p .727 .645 .767 r
F P
0 g
s
.20669 .5517 m .2627 .54518 L .25839 .5132 L p .718 .62 .748 r
F P
0 g
s
.68848 .81579 m .65805 .75364 L .62544 .76987 L p .727 .645 .767 r
F P
0 g
s
.57167 .64792 m .59342 .70313 L .62592 .68796 L p .669 .501 .648 r
F P
0 g
s
.62592 .68796 m .60026 .63527 L .57167 .64792 L p .669 .501 .648 r
F P
0 g
s
.25839 .5132 m .20317 .51917 L .20669 .5517 L p .718 .62 .748 r
F P
0 g
s
.25121 .44966 m .19794 .45454 L .20022 .48623 L p .71 .55 .67 r
F P
0 g
s
.20022 .48623 m .2545 .48082 L .25121 .44966 L p .71 .55 .67 r
F P
0 g
s
.60026 .63527 m .62592 .68796 L .6573 .6728 L p .703 .515 .631 r
F P
0 g
s
.71817 .72164 m .6861 .65838 L .6573 .6728 L p .765 .594 .666 r
F P
0 g
s
.6573 .6728 m .68945 .73729 L .71817 .72164 L p .765 .594 .666 r
F P
0 g
s
.20317 .51917 m .25839 .5132 L .2545 .48082 L p .715 .586 .71 r
F P
0 g
s
.2545 .48082 m .20022 .48623 L .20317 .51917 L p .715 .586 .71 r
F P
0 g
s
.56144 .71752 m .59327 .78516 L .62544 .76987 L p .659 .551 .721 r
F P
0 g
s
.62544 .76987 m .59342 .70313 L .56144 .71752 L p .659 .551 .721 r
F P
0 g
s
.68945 .73729 m .6573 .6728 L .62592 .68796 L p .731 .581 .687 r
F P
0 g
s
.62592 .68796 m .65805 .75364 L .68945 .73729 L p .731 .581 .687 r
F P
0 g
s
.59342 .70313 m .62544 .76987 L .65805 .75364 L p .697 .567 .705 r
F P
0 g
s
.65805 .75364 m .62592 .68796 L .59342 .70313 L p .697 .567 .705 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
      ImageSize->{288, 288},
      ImageMargins->{{0, 0}, {0, 0}},
      ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ROooo`d0002:
oooo001ooooo2P0000goool:0000P?ooo`00NOooo`H0000Qoooo1P0007[oool007Coool50000;Ooo
o`D0001eoooo001aoooo0`0003Ooool30000L_ooo`00KOooo`@0000moooo100006koool006[oool3
0000AOooo`<0001[oooo001Woooo0`0004_oool30000J?ooo`00I?ooo`<0001Aoooo0`0006Goool0
067oool30000Eoooo`<0001Roooo001Noooo0`0005goool30000Goooo`00Foooo`<0001Soooo0`00
05coool005Woool20000JOooo`80001Joooo001Goooo0P0006;oool800000oooo`80001Hoooo001E
oooo0P0005koool800000Wh000X0001Goooo001Coooo0P0005coool700000h4F;@@00003VbTY2P00
05Coool0057oool20000Foooo`H00005PAH]0P0000>K?U<400001:i6APP0001Boooo001@oooo00<0
003oooooool0FOooo`<0000015405`00000007lWD@800002PAH]0P0000>K?U<200000jaHJ@800000
0ji6AP0000000002^U]H00<0002g@BL000001@00053oool004koool20000F_ooo`<000000e405`00
00000005ObMA0`0000:K?U<200001jaHJ@800004^U]H0P0000;2DS@40000Coooo`00COooo`030000
oooooooo05Soool300000U405`030000ObMAObMA00=o9e4200000iQ<K`800008[5QY00<0002gJgRg
JgP00P000004^U]H0000aF]SaF]S0P0000;<GSX30000C_ooo`00Boooo`80001Joooo0`000003D@0G
0000000000Ao9e4200001IQ<K`040000Yf>1000000001:aHJ@800005]f]h0P0000?5Jf<4000000?C
IST000000000COooo`00BOooo`80001Koooo0P00009=03/300000WlWD@800006V4a_00<0002WHh6W
Hh400ZMSP@8000000jaHJ@000;M[N005]f]h00<00031NH71NH400`0000?>MfT010000==V>@000=UZ
;`80001;oooo0018oooo00<0003oooooool0F_ooo`800002C@0k00@0001k=6Yk=6Yk=6X200001YQ<
K`800007Yf>10P0000FgJgP00`000<5iPL5iP@03`GV100@0003>MfW>MfW>MfT80000BOooo`00A_oo
o`80001Koooo0`00009=03/00`0007/dJW/dJP02NcAZ00@0002CEH<000000003V4a_00<0002WHh6W
Hh401ZMSP@030000/WB</WB<00800002]f]h00<00031NH71NH400l5iP@060000bXF600000000cWMY
00000]N1JP8000000maY70000?ooo`020000Aoooo`00AOooo`030000oooooooo05[oool200000Td0
>`800004NcAZ00<0002CEH>CEH<00Y=EP`030000V4a_000000NWHh4200001K9dS0800006`GV100@0
003:QHK:QHK:QHH200000]N1JPD00002oooo00<0003oooooool0A?ooo`00A?ooo`030000oooooooo
05[oool200000Td0>`030000NcAZNcAZ00=k=6X00`0009=EPi=EP`04TeF30P0000JWHh400`000;9d
S;9dS005/WB<00@0002lPI@000000003`GV100<0003:QHK:QHH00lZ5QP050000eh5Zeh5Z0000h8UV
008000001MAM00000?ooooooo`000015oooo0013oooo00<0003oooooool0F_ooo`800002C@0k00<0
001k=6Yk=6X00g/dJP030000TeF3TeF300BCEH<00`000:9ZTJ9ZT@0300000ZMSP@030000/WB</WB<
00FbM8`00`000;b1U;b1U002_86D0P000003`GV10000bXF600C:QHH4000000?PRFH0003YSUT00P00
00?oool00`000?ooooooo`12oooo0012oooo00<0003oooooool0F_ooo`H00004NcAZ00<0002CEH>C
EH<019=EP`030000XVZAXVZA00BRJY4200001k9dS0030000_86D_86D00FlPI@00`000<Z5Q/Z5QP03
bXF600@0003CT8WCT8WCT8T2000000GPRFH00000003^SSl000000oooo`030000oooooooo047oool0
043oool20000G?ooo`800002B0MF00<0001e?7ee?7d00P000003NcAZ0000TeF300FCEH<00`000:9Z
TJ9ZT@05XVZA00@0002^NY/000000004/WB<00<0002lPIBlPI@01Kb1U0040000aHfJ000000000lZ5
QP060000di29di29di290000gYZ80P000004jHiI0000000000000oooo`800011oooo000ooooo00<0
003oooooool0Foooo`800003B0MF00<0001e?7ee?7d00WDlO@030000TeF3TeF300FCEH<00`000:9Z
TJ9ZT@04XVZA00<0002^NY^^NY/00ZijV`8000000k9dS0000;b1U007_86D00@00035SI[5SI[5SIX3
00001=>@R@040000gYZ8gYZ8gYZ80P000003kXho0000oooo00Coool00`000?ooooooo`0noooo000n
oooo00<0003oooooool0Foooo`800003B0MF00<0001e?7ee?7d00WDlO@040000SU^A0000000019=E
P`030000XVZAXVZA00BRJY400`000:ijVjijV`05[WZK00<0002lPIBlPI@01[b1U0030000aHfJaHfJ
00C5SIX00`000=>@RM>@R@02di2900@0003NVXSNVXSNVXP2000000?^SSl0000000001Oooo`030000
oooooooo03goool003goool00`000?ooooooo`1Loooo0P0000981eH00`0007DlOGDlO@03MCam00@0
002>Fi6>Fi6>Fi42000000>CEH<0002RJY401Z9ZT@030000[WZK[WZK00B^NY/010000;N7XP000000
00FlPI@00`000<F=V/F=VP05aHfJ0`000003di290000gYZ800?NVXP3000000?^SSl0003oool01Ooo
o`030000oooooooo03coool003coool00`000?ooooooo`1Loooo0P0000981eH00`0007DlOGDlO@03
MCam00<0002>Fi6>Fi4018iKT@030000XVZAXVZA00FRJY400`000:ijVjijV`05[WZK00D0002gQj:g
Qj:gQj8000000kb1U0030000aHfJaHfJ00G5SIX010000<jHW/jHW/jHWP800004gYZ800H0003YY8<0
0000003^SSl00006oooo00<0003oooooool0>oooo`00>oooo`030000oooooooo05coool200000dP7
EP030000MCamMCam009e?7d00`0008iKTHiKT@04SU^A00@0002MKid000000004XVZA00<0002^NY^^
NY/01JijV`030000]hNR]hNR00>gQj82000000>lPI@00035SIX01/F=VP030000cYRNcYRN00;>V9h0
0`000=jJR=jJR002gYZ800@0003YY8<0003e[7@200001oooo`030000oooooooo03[oool003[oool0
0`000?ooooooo`1Loooo0`0000981eH00`0007DlOGDlO@02MCam00<0002>Fi6>Fi401HiKT@040000
WFnMWFnMWFnM0P000003XVZA0000[WZK00N^NY/00`000;N7X[N7XP05]hNR00<00035SI[5SIX01LF=
VP030000cYRNcYRN00?>V9h300000]jJR0030000jJB3000000;e[7@200001oooo`030000oooooooo
03Woool003Woool00`000?ooooooo`1Loooo00@0000001i346Y346X3000017DlO@030000SU^ASU^A
00B>Fi400`0009e_WIe_W@04WFnM0P0000N^NY/00`000;N7X[N7XP05]hNR00@00030TZL000000005
aHfJ00<0003>V9k>V9h00ljHWP030000f:BOf:BO00<000001>VTP`000?F/M?F/M0800008oooo00<0
003oooooool0>?ooo`00>?ooo`030000oooooooo05goool200000T<@JP030000L4>;L4>;00800000
0gDlO@0008iKT@05SU^A00<0002MKifMKid019e_W@030000ZGjUZGjU00800004[WZK00<0002gQj:g
Qj801[N7XP050000`9:W`9:W`9:W000000?5SIX00`000<jHW/jHWP03cYRN00<0003HY9oHY9l00mRT
W`050000jJB3jJB30000mJad00800009oooo00<0003oooooool0=oooo`00=oooo`030000oooooooo
05goool00`0000007P000002@a1Z00<0001`@h]`@h/00W13R`030000SU^ASU^A00B>Fi400`0009e_
WIe_W@05WFnM00<0002YOZFYOZD00ZUnY@800002[WZK00<0002gQj:gQj801KN7XP030000`9:W`9:W
00?0TZL2000000?5SIX0003>V9h01<jHWP030000f:BOf:BO00?HY9l2000000GYY8<0003e[7@0003i
[Dl02_ooo`030000oooooooo03Koool003Koool00`000?ooooooo`1Noooo0P00009346X00`000713
Rg13R`02L4>;00@00028Gi`000000004SU^A00<0002MKifMKid019e_W@030000ZGjUZGjU00FYOZD2
00002;N7XP030000`9:W`9:W00G0TZL200001LjHWP030000f:BOf:BO00?HY9l010000>B`WP000000
00;e[7@200002_ooo`030000oooooooo03Goool003Goool00`000?ooooooo`1Noooo00<0000001h0
00000T<@JP030000L4>;L4>;009`@h/0100008QOW8QOW8QOW08000000hiKT@0009e_W@06WFnM00<0
002YOZFYOZD01JUnY@040000/X^/000000001KN7XP030000`9:W`9:W00K0TZL010000<RM[0000000
00?>V9h00`000=RTWmRTW`02f:BO00D0003T/9kT/9kT/9h000000_F/M080000;oooo00<0003ooooo
ool0=?ooo`00=?ooo`030000oooooooo05koool00`0000007P000002@a1Z00<0001`@h]`@h/00W13
R`030000R5nLR5nL00B8Gi`200001Ye_W@030000ZGjUZGjU00JYOZD01@000;:;[;:;[;:;[0000003
]hNR00<00030TZO0TZL01/2BY`030000b9f/b9f/00;8WJ`300001MRTW`040000i;2Ni;2Ni;2N1000
0003nJe?oooooooo00[oool00`000?ooooooo`0coooo000coooo00<0003oooooool0Goooo`030000
000N0000009346X00`000713Rg13R`02L4>;00<00028Gib8Gi`00hQOW0030000V7:VV7:V00800003
WFnM00<0002YOZFYOZD01ZUnY@030000/X^//X^/00>bRj`2000000>gQj800030TZL01l2BY`030000
b9f/b9f/00C8WJ`00`000=RTWmRTW`03f:BO00D0003T/9kT/9kT/9h000000_:nV0030000nJe?oooo
00coool00`000?ooooooo`0boooo000boooo00<0003oooooool0Goooo`<00002@a1Z00<0001`@h]`
@h/00W13R`030000R5nLR5nL00B8Gi`00`0009QbYYQbYP02V7:V0P000003WFnM0000ZGjU00JYOZD0
0`000;:;[;:;[006/X^/00<00030TZO0TZL01/2BY`030000b9f/b9f/00G8WJ`200001=RTW`050000
i;2Ni;2Ni;2N000000;b_YP300003Oooo`030000oooooooo037oool0037oool00`000?ooooooo`1P
oooo0P00=P8000000d<@JP000713R`02L4>;00<00028Gib8Gi`018QOW0030000V7:VV7:V00FHLZH0
0`000:UnYJUnY@06ZGjU00<0002bRjbbRj`01K:;[0040000^iJa000000001/2BY`030000b9f/b9f/
00C8WJ`00`000=:Y[m:Y[`02000000?HY9l0003T/9h00nB`WP060000l[jHl[jH0000o/^300003_oo
o`030000oooooooo033oool0033oool00`000?ooooooo`1Poooo00<0000003H003H00SdHN@<00002
L4>;00<00028Gib8Gi`018QOW0030000V7:VV7:V00BHLZH010000:B1[P00000000FYOZD00`000;:;
[;:;[006/X^/00@0002kU[6kU[6kU[4200000l2BY`030000b9f/b9f/00G8WJ`00`000=:Y[m:Y[`02
dZV_0P0000CT/9h01P000?:nV?:nV0000?k;P`0000ooool00`000?ooooooo`0_oooo000_oooo00<0
003oooooool0HOooo`030000000f0000008m67T00`0006Y7UFY7U@0200001XQOW0030000V7:VV7:V
00FHLZH01@000:B1[ZB1[ZB1[P000003ZGjU00<0002bRjbbRj`01[:;[0030000^iJa^iJa00BkU[42
000000?0TZL00038WJ`01LRM[0030000dZV_dZV_00CBZJl00`000>B`W^B`WP02i;2N00H0003b_YSb
_YP0003nbh<0000@oooo00<0003oooooool0;_ooo`00;_ooo`030000oooooooo06;oool01@000000
=P0003dHN@000004JTNE0`0000>8Gi`00`0009QbYYQbYP05V7:V00<0002TPJjTPJh00jB1[P800000
0jUnY@000;:;[007/X^/00<0002kU[6kU[401[^F/@030000b9f/b9f/00G8WJ`00`000=:Y[m:Y[`04
dZV_0`0000;T/9h01P000?:nV?:nV0000?k;P`00017oool00`000?ooooooo`0]oooo000^oooo00<0
003oooooool0HOooo`060000000f000f0000?AQi00000fY7U@040000Q6:TQ6:TQ6:T0P000003R5nL
0000V7:V00JHLZH00`000:B1[ZB1[P05Y86^00<0002bRjbbRj`01[:;[0030000^iJa^iJa00JkU[40
10000<>Q]P00000000C8WJ`00`000=:Y[m:Y[`04dZV_00@0003M]k7M]k7M]k4300000_:nV0030000
o/^30000017oool00`000?ooooooo`0]oooo000]oooo00<0003oooooool0H_ooo`030000000f0000
008m67T01@0006Y7UFY7UFY7U@000005Q6:T0P0000JHLZH00`000:B1[ZB1[P05Y86^00@0002^SK@0
00000006/X^/00<0002kU[6kU[401[^F/@050000`j6f`j6f`j6f000000?8WJ`00`000=:Y[m:Y[`04
dZV_00<0003M]k7M]k400mfg/@060000l[jHl[jH0000o/^300004_ooo`030000oooooooo02coool0
02coool00`000?ooooooo`1Roooo00H0000003H003H0000m67T00004JTNE00<00024HZB4HZ@00hAR
Y0040000U7F]000000000iQbYP030000Y86^Y86^00JTPJh010000:j=]:j=]:j=]0800003/X^/00<0
002kU[6kU[401[^F/@030000`j6f`j6f00?3XKH300001m:Y[`030000gKNagKNa00?M]k42000000Cb
_YP0003nbh<0000Coooo00<0003oooooool0:oooo`00:oooo`030000oooooooo06?oool300000SdH
N@050000JTNEJTNEJTNE000000F4HZ@00`0009Ae[IAe[@02U7F]0P000003V7:V0000Y86^00JTPJh0
0`000:j=]:j=]004[Xfd0P000003/X^/0000^iJa00NkU[400`000<>Q]/>Q]P05`j6f00<0003BZJoB
ZJl01=:Y[`030000gKNagKNa00?M]k400`000>_7/>_7/002000000?nbh<0000000004oooo`030000
oooooooo02[oool002[oool00`000?ooooooo`1Toooo0P00B0<00004JTNE00<00024HZB4HZ@00hAR
Y0030000U7F]U7F]00BDMJd00`000:B1[ZB1[P06Y86^00<0002^SKB^SK@01Zj=]0030000^iJa^iJa
00JkU[400`000<>Q]/>Q]P05`j6f00@0003<[KX000000004dZV_00<0003M]k7M]k400mfg/@060000
jlN`jlN`jlN`0000o/^30P0001Coool00`000?ooooooo`0Yoooo000Yoooo00<0003oooooool0IOoo
o`8004P2=af40`000003JTNE0000Q6:T00B4HZ@00`0009Ae[IAe[@05U7F]0`0000FTPJh00`000:j=
]:j=]006[Xfd00@0002fV;T000000006^iJa00<00033XKK3XKH01L>Q]P050000c:fjc:fjc:fj0000
00?BZJl00`000=fg/Mfg/@03gKNa00@0003[ak3[ak3[ak0400005Oooo`030000oooooooo02Soool0
02Soool00`000?ooooooo`1Voooo00D004P0000g7H@g7H@000000VI:W@800005Q6:T00<0002DMJfD
MJd019Ae[@050000X8>dX8>dX8>d000000>TPJh00`000:j=]:j=]007[Xfd00@0002fV;VfV;VfV;T2
00000k^F/@030000`j6f`j6f00G3XKH00`000<b]^/b]^P03c:fj0`0000KM]k4010000>_7/>_7/000
00;jfjL200005_ooo`030000oooooooo02Ooool002Soool00`000?ooooooo`1Voooo00@004P0000g
7H@00004ITZM0`0000:4HZ@00`0009Ae[IAe[@05U7F]00<0002PPkBPPk@00Z23]08000000jB1[P00
0:j=]007[Xfd00<0002fV;VfV;T01;JH^@8000000k^F/@000<>Q]P06`j6f00<0003<[K[<[KX01Lb]
^P030000gKNagKNa00?M]k401@000>_7/>_7/>_7/0000002n]^W0P0001Koool00`000?ooooooo`0W
oooo000Woooo00<0003oooooool0I_ooo`05000000180000=af4000000=VBYd01`0007mTZWmTZWmT
ZP0008ARY0000006U7F]00<0002PPkBPPk@01J23]0030000[Xfd[Xfd00N^SK@00`000;JH^KJH^@06
]YRi00<00033XKK3XKH01L>Q]P030000c:fjc:fj00G<[KX00`000=Jk_P000004gKNa00D0003[ak3[
ak3[ak0000000_[KY`80000Goooo00<0003oooooool09_ooo`009_ooo`030000oooooooo06Ooool0
1@000000B00003LMQ0000003ITZM00<0001oI:YoI:X00WmTZP800006U7F]00<0002PPkBPPk@01J23
]0<00006[Xfd00<0002fV;VfV;T01[JH^@040000_Z>n000000001L>Q]P030000c:fjc:fj00G<[KX0
0`000=Jk_]Jk_P0200000]fg/@060000jlN`jlN`jlN`0000n]^W0P0001Woool00`000?ooooooo`0U
oooo000Voooo00<0003oooooool0Ioooo`800002=af400D0001VBYeVBYeVBYd0000017mTZP040000
T7Jb000000000iAe[@030000X8>dX8>d00FPPk@010000:V?^ZV?^ZV?^P800003[Xfd00<0002fV;Vf
V;T01kJH^@050000_Z>n_Z>n_Z>n000000?3XKH00`000<b]^/b]^P05c:fj00<0003F^kkF^kh00mJk
_P800003jlN`00<0003jfjOjfjL00P0001Woool00`000?ooooooo`0Uoooo000Uoooo00<0003ooooo
ool0J?ooo`@00003ITZM00<0001oI:YoI:X00WmTZP030000T7JbT7Jb00:@M[82000000>DMJd0002P
Pk@01Z23]0030000ZHnjZHnj00>YSkX2000000>^SK@0002fV;T01kJH^@030000_Z>n_Z>n00>nXkh2
000000?3XKH0003<[KX01/b]^P030000e[^ne[^n00CF^kh01@000>_7/>_7/>_7/0000002n]^W0P00
01[oool00`000?ooooooo`0Toooo000Uoooo00<0003oooooool0J?ooo`04001C0000<b2;00000fI:
W@030000OfBZOfBZ009oI:X00`00091f/Y1f/P04T7Jb00<0002PPkBPPk@01J23]0030000ZHnjZHnj
00JYSkX00`000;JH^KJH^@06]YRi00<0002nXkjnXkh01[jS_P030000c:fjc:fj00G<[KX00`000=Jk
_]Jk_P04e[^n00<0003ScL8000000^_7/0030000n]^Wn]^W0080000Joooo00<0003oooooool09?oo
o`009?ooo`030000oooooooo06Woool00`00D`0003<PR`04000017mTZP030000T7JbT7Jb00B@M[80
100009b4^@00000000FPPk@00`000:V?^ZV?^P05ZHnj00<0002bV[l000001kJH^@030000_Z>n_Z>n
00FnXkh010000<J_``00000000G<[KX00`000=Jk_]Jk_P04e[^n00<0003ScL;ScL800P0000?jfjL0
0`000?ooooooo`0Joooo00<0003oooooool08oooo`008oooo`030000oooooooo06[oool01000D`00
03<PR`00009RC:8200000gmTZP030000T7JbT7Jb00B@M[801@0009b4^Ib4^Ib4^@000003X8>d00<0
002YSkZYSkX01ZV?^P030000/YZo/YZo00800004]YRi00<0002nXkjnXkh01[jS_P050000aZo3aZo3
aZo3000000?<[KX00`000=Jk_]Jk_P04e[^n00<0003ScL;ScL800^?=`P030000n]^Wn]^W0080000M
oooo00<0003oooooool08_ooo`008oooo`030000oooooooo06Woool200000S<PR`050000HTbRHTbR
0000O6J_00<00006T7Jb00<0002LQ;VLQ;T00ib4^@8000000j23]0000:V?^P06ZHnj00<0002bV[nb
V[l00k:J_`040000]YRi]YRi00002;jS_P030000aZo3aZo300?6[l<2000000?<[KX0003F^kh01MJk
_P030000hlg2hlg200;ScL8500007Oooo`030000oooooooo02;oool002;oool00`000?ooooooo`1Z
oooo0P000003<b2;0000HTbR009RC:801@0007aV[gaV[gaV[`000006T7Jb00<0002LQ;VLQ;T01Ib4
^@030000ZHnjZHnj00JYSkX00`000;:J_k:J_`04/YZo00<0002fV;T000002;jS_P030000aZo3aZo3
00G6[l<00`000=Jk_]Jk_P04e[^n00<0003ScL;ScL800^?=`P050000l>C0l>C0l>C0000001ooool0
0`000?ooooooo`0Qoooo000Roooo00<0003oooooool0J_ooo`@00003HTbR00@0001lIZmlIZmlIZl3
00000i1f/P030000W8BiW8Bi00FLQ;T010000:J@_P00000000FYSkX00`000;:J_k:J_`06/YZo00<0
002nXkjnXkh01[jS_P030000aZo3aZo300G6[l<00`000=2mb0000005e[^n00<0003ScL;ScL800^?=
`P030000l>C0l>C00080000Ooooo00<0003oooooool08Oooo`008Oooo`030000oooooooo06_oool0
1000F`00030RT000009RC:800`0007aV[gaV[`02O6J_00<0002=N;N=N;L00P000003T7Jb0000W8Bi
00JLQ;T01@000:J@_ZJ@_ZJ@_P000003ZHnj00<0002bV[nbV[l01[:J_`040000^JG4000000001[jS
_P030000aZo3aZo300G6[l<00`000=2mb=2mb00200000]Jk_P030000hlg2hlg200;ScL8010000?3T
`?3T`?3T`080000Poooo00<0003oooooool08?ooo`008Oooo`030000oooooooo06_oool00`00F`00
030RT004000017aV[`030000SGRgSGRg00:=N;L00`0009b4^Ib4^@05W8Bi00<0002VT;jVT;h00jJ@
_P8000000jV?^P000;:J_`07/YZo00@0002iYLBiYLBiYL@200000kjS_P030000aZo3aZo300G6[l<0
0`000=2mb=2mb003d;g800<0003F^kh000001>?=`P030000l>C0l>C00080000Qoooo00<0003ooooo
ool08?ooo`008?ooo`030000oooooooo06coool01000F`00030RT000009OCJH200000WaV[`030000
SGRgSGRg00>=N;L300001Ib4^@030000YY2nYY2n00FVT;h00`000;:J_k:J_`06/YZo00<0002iYLBi
YL@01;VUa08000000kjS_P000<J_``06aZo300<0003@_LS@_LP01=2mb0030000hlg2hlg200;ScL80
10000?3T`?3T`?3T`080000Roooo00<0003oooooool07oooo`008?ooo`030000oooooooo06_oool2
00000S0RT0050000GdfVGdfV0000NFNa00<00004SGRg00D0002IQKfIQKfIQKd000000ib4^@030000
YY2nYY2n00FVT;h010000:jKa000000000FbV[l00`000;VUa;VUa007^JG400<00036[l?6[l<01LJ_
``030000d;g8d;g800C@_LP010000=[@cP00000000;ScL800`000?3T`?3T`00200008oooo`030000
oooooooo01ooool001ooool00`000?ooooooo`1/oooo0P000003<2:@0000GdfV009OCJH01@0007UW
/GUW/GUW/@000004SGRg00<0002IQKfIQKd00YV5_@8000000ib4^@000:J@_P06YY2n00D0002^VlB^
VlB^Vl@000000k:J_`030000^JG4^JG400NiYL@010000<6abP00000000G6[l<00`000=2mb=2mb004
d;g800H0003Jd<kJd<kJd<h0003ScL83l>C00P0002Coool00`000?ooooooo`0Noooo000Ooooo00<0
003oooooool0K?ooo`@00002GdfV00<0001iIk5iIk400WUW/@<00002SGRg00<0002IQKfIQKd019V5
_@800006YY2n00<0002^VlB^Vl@00jjKa08000000k:J_`000;VUa007^JG400<00031/L[1/LX00/6a
bP050000aZo3aZo3aZo3000000K@_LP00`000=[@c][@cP03f]3>00D0003`i<3`i<00003^m:<09Ooo
o`030000oooooooo01koool001koool00`000?ooooooo`1]oooo0P000005;R>B00000000GdfV0000
00=iIk40100008]h^H]h^H]h^@800006VHFm00<0002STL:STL800P0000>VT;h00`000:jKa:jKa006
[Y_400<0002iYLBiYL@01[VUa0030000`K7:`K7:00C1/LX2000000?6[l<0003@_LP01=2mb0030000
f]3>f]3>00?Jd<h010000>KXdP000?3T`080000Voooo00<0003oooooool07Oooo`007_ooo`030000
oooooooo06goool2000000<^8i80001MCZP00P0000=iIk400`0008]h^H]h^@02RgRi00<0002IQKfI
QKd019V5_@030000Xi72Xi7200:STL82000000>VT;h0002^Vl@01ZjKa0040000]JK9000000001[VU
a0030000`K7:`K7:00K1/LX00`000=2mb=2mb003d;g800<0003Jd<kJd<h01=[@cP050000i^SBi^SB
0000k_BS02Ooool00`000?ooooooo`0Moooo000Moooo00<0003oooooool0K_ooo`80000012hSTP00
05e>Z5e>Z0800002NFNa00<0002;N;V;N;T00X]h^@<00003VHFm00<0002STL:STL801J>A`P030000
[Y_4[Y_400J^Vl@01@000;FVbKFVbKFVb@000004^JG400<00031/L[1/LX01/6abP040000bKo@0000
00000m2mb0030000f]3>f]3>00?Jd<h01P000>KXd^KXdP000>;m`@0002Soool00`000?ooooooo`0L
oooo000Moooo00<0003oooooool0K_ooo`<00003GDjX00@0001hIk<000000004RgRi00@0002GQ[nG
Q[nGQ[l2000000>IQKd0002STL801J>A`P040000Zic7000000001JjKa0030000]JK9]JK900>eY/T2
000000>iYL@00031/LX01l6abP030000bKo@bKo@00;9_m000`000=2mb0000005f]3>00@0003Vj=;V
j=;Vj=820000:Oooo`030000oooooooo01coool001coool00`000?ooooooo`1_oooo00<005l00000
00000Ue>Z0040000N6NcN6NcN6Nc0P0000>;N;T00`0009N6_iN6_`03UhJo00<0002STL:STL801J>A
`P050000Zic7Zic7Zic7000000>^Vl@00`000;FVbKFVb@06]JK900<00031/L[1/LX01/6abP030000
bKo@bKo@00C9_m000`000=[@c][@cP03f]3>00L0003Vj=;Vj=;Vj=80003RoL400000:_ooo`030000
oooooooo01_oool001coool00`000?ooooooo`1_oooo00H005l000000000001MCZP00003N6Nc00<0
0029NK/000000P0000JGQ[l200001J>A`P030000Zic7Zic700>[W<L2000000>^Vl@0002eY/T01[FV
b@040000_K;?000000001/6abP030000bKo@bKo@00?9_m0010000=?Ae`00000000?Jd<h01P000>KX
d^KXdP000>;m`@0002_oool00`000?ooooooo`0Koooo000Koooo00<0003oooooool0L?ooo`04001O
00000000GDjX0P0000=hIk<01@0008Ui^hUi^hUi^`000005UhJo00<0002QTLFQTLD00P0000:STL80
0`000:^Laj^La`06Zic700<0002eY/VeY/T01KFVb@030000_K;?_K;?00:m//l00`000<6ab/6abP02
`K7:00<00039_m39_m000lVod0030000dm7Gdm7G00;CdML00`000=[@cP000002i^SB00<0003RoL40
0000;Oooo`030000oooooooo01[oool001_oool00`000?ooooooo`1`oooo00<0000^998000000Ue>
Z0@00004RGVk0`0000>GQ[l00`000:6AaJ6Aa@02XI7500<0002STL8000001j^La`030000/ZO=0000
00JeY/T00`000;fbckfbc`03_K;?0P000003`K7:0000bKo@00C9_m000`000=?Aem?Ae`04dm7G00@0
003Vj=;Vj=;Vj=830000;Oooo`030000oooooooo01[oool001_oool00`000?ooooooo`1`oooo0`00
009MCZP0100007QW]7QW]00000B9NK/00`0009J6`IJ6`@0300001Z6Aa@800006Zic700@0002bYlfb
YlfbYld200000kFVb@030000_K;?_K;?00Jm//l00`000<Vod<Vod004bKo@00<0003CdMOCdML00m?A
e`070000fnWN0000i^SB0000h_g1000002koool00`000?ooooooo`0Joooo000Joooo00<0003ooooo
ool0LOooo`030000<2>A000000800003N6Nd0`000003RGVk0000UXK100BFQ/400`000:6AaJ6Aa@03
XI7500<0002XW<ZXW<X00P0000B[W<L00`000;:WcK:Wc@03/ZO=00<0002eY/T000002;fbc`040000
a<3F000000000lVod0030000dm7Gdm7G00?CdML01`000=_Yg]_Yg]_YgP000>;m`@00000`oooo00<0
003oooooool06Oooo`006_ooo`030000oooooooo073oool2000000@`8i40001NCZL00003N6Nd00<0
0029NK^9NK/00P0000FFQ/4300000j6Aa@030000Z9c:Z9c:00:XW<X2000000>[W<L0002bYld01[:W
c@030000_K;?_K;?00Fm//l200001<C0eP030000bKo@000000GCdML01P000=_Yg]_Yg]_YgP000=?o
e080000`oooo00<0003oooooool06Oooo`006_ooo`030000oooooooo02?oool;0000@_ooo`<00002
GTjW100000B9NK/200000iJ6`@070000Wi;6Wi;6Wi;60000XI75000000NXW<X00`000;:WcK:Wc@05
/ZO=00@0002i/]<000000004_K;?00<00034`=K4`=H01LC0eP030000dm7Gdm7G00CCdML01@000=_Y
g]_YgP000=?oe0020000<Oooo`030000oooooooo01Woool001Woool00`000?ooooooo`0Loooo4P00
0003MP000000000000@0000loooo0`00009NCZL0100007QW/gQW/`0000>9NK/00`0009F6`IF6`@02
000000>FQ/40002OT/H00inBaP030000Z9c:Z9c:00FXW<X00`000;2Wc`000005/ZO=00<0002i/]>i
/]<00[Vbd`8000000kfbc`000<C0eP06a<3F00@0003<dMh000000003dm7G00D0003KjMkKjMh0003C
om@00P0003?oool00`000?ooooooo`0Hoooo000Ioooo00<0003oooooool06Oooo`X00007SAh[00@0
002U<bfU<bfU<bd600000gH00080000hoooo1@0000=hIk<3000000>9NK/0002EQ/400iF6`@030000
Wi;6Wi;600>OT/H200001JRLbP040000/:O?/:O?/:O?0P0000>bYld00`000;VbdkVbd`04^K;C00<0
0034`=K4`=H01LC0eP030000c=7Nc=7N00;<dMh00`000=?Ae`000003fnWN0`0003Coool00`000?oo
ooooo`0Hoooo000Ioooo00<0003oooooool05_ooo`@00002J@0U00<0002=7R^=7R/02hdN:`030000
YC<]YC<]00NU<bd4000000>>0000000000000P0003Coool3000000EPCZH00000001hIk<000000hUi
^`030000UHK1UHK100>EQ/4300000YnBaP030000Yig;Yig;00800003Z9c:00<0002`Yln`Yll00k2W
c`030000/ZO=000000Ji/]<010000;o0fP00000000C4`=H00`000<cAg/cAgP04c=7N00L0003KjMkK
jMkKjMh0003Com@00000=Oooo`030000oooooooo01Soool001Soool00`000?ooooooo`0Eoooo1000
00AY02D00`0008dN:hdN:`04SAh[2`0000RU<bd00`000;E1;00000070000<Oooo`06001C=R:;0000
H4jV0000NVNb0P0000>9NK/300000YF6`@070000Wi;7Wi;7Wi;70000Wi;6000000BWWL/00`000:RL
bP000007/:O?00<0002i/]>i/]<01;Vbd`030000_l3J_l3J00:o`=X2000000?4`=H0003<dMh01LcA
gP070000dNSV0000fnWN0000dooD000003Ooool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool04_ooo`@00006J@0U200000NSC64010000;AJH;AJH;AJH0H00002YC<]00<0002e@Bbe@B`00kE1
;0<0000018h000000000000002goool2000000@f8X/0000000000002NVNb0P0000:9NK/01P0009J7
`IJ7`@0009F6`@0000BOT/L00`000:NMbjNMb`04Yig;00<0002`Yln`Yll01K2Wc`040000][?F0000
00000kVbd`030000_l3J_l3J00Fo`=X00`000<cAg/cAgP03c=7N0P0000?Aj>H00`000=?oe000000h
oooo00<0003oooooool05oooo`006?ooo`030000oooooooo013oool4000016T09@@000000hTgGP00
0:=<H@0<XdaQ00<0002dFV2dFV001kAJH0D00006]D4/1P0002_oool300000VA>X`<00002RgVj0P00
00BFQl4200000inBa`040000Yig<000000000jNMb`040000[ZOA000000001;2Wc`030000][?F][?F
00:f/mH00`000;Vbd`000007_l3J00<00036d^<000000lcAgP030000dNSVdNSV00;Aj>H00`000<Gn
h@00000ioooo00<0003oooooool05oooo`005oooo`030000oooooooo00ooool3000016T09@<00005
RCMN00<0002SC66SC6402j=<H@030000]5YP]5YP00VdFV000`000<1TG/1TGP0500000[E1;0030000
_dX[000000@0000Yoooo00P004`k8HL00000001TCZ<0001mIk000003RgVj00D0002FQl6FQl6FQl40
00000YnBa`8000000inBa`000:NMc002Yig<00<0002WWL/000001:jWd@8000000k2Wc`000;JceP05
][?F00<0002o`=Zo`=X01;o0fP800003a];S00<0003<dMh000000m7XiP8000000lGnh@000?ooo`0j
oooo00<0003oooooool05_ooo`005oooo`030000oooooooo00koool0100003@06@0006T09@@00008
RCMN00<0002SC66SC6401:=<H@/00008]5YP00<00030I5k0I5h01L1TGP@00003_dX[0P000003W0`0
0000000002Koool01@0003/QQ`0006M=X0000002OFN`0`000006RgVj000000000000UXO1000019nB
a`030000Yig<Yig<00>WWL`00`000:jWdJjWd@05[ZOA0P0000Bf/mH2000000>l`Md0000000000ko0
fP030000a];Sa];S00C6d^<01P000=7Xi]7Xi]7XiP000<Gnh@80000loooo00<0003oooooool05_oo
o`005oooo`030000oooooooo00coool200000S@06@80000;RCMN200000N/IGh010000;Y`OKY`OKY`
O@H00003]5YP00<00030I5k0I5h01/1TGP030000b6]L000000800003_dX[100002Coool3000000AW
CJ00000000000003SGVh00@0002GQl2GQl2GQl0200000inBa`040000Yig<000000000ZNMc0040000
[ZSB000000001:jWd@030000];?H];?H008000000kJceP000;c1g@04_<7M00<0002o`=X000001LKB
h`8000001/WXk0000=7XiP000<Gnh@0003koool00`000?ooooooo`0Foooo000Foooo00<0003ooooo
ool02oooo`<0000013@06@0006@HE`0000V9=eh3000000>HEWh0002/IGh03:aUOP030000^W1m^W1m
00NjL7d600001/1TGP030000b6]Lb6]L00;8Je`2000000>oBR/00034CbX01000027oool3000000E/
CI`00020Ijf0Ijd000000hei^0800002UhO000H0002PT/H00000002OT/L00003Yig<00<0002WWL`0
00000jjXdP8000000jjWd@000;Bcf004];?H00<0002l`Mfl`Md01Kc1g@030000a];Sa];S00?6d^<0
10000<WXk<WXk<WXk08000000lGnh@000?ooo`0ooooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo00[oool200000S@06@040000I1QGI1QG00001XTgGP<00004V5In00<0002/IGj/IGh02jaU
OP030000^W1m^W1m00ZjL7d00`000<AhNlAhN`0500000/1TGP030000b6]Lb6]L00?8Je`300000/A?
:P<0000Poooo00@003Y887`0001/CI`2000000>0Ijd0000000000P0000:IQkl200001:2BaP030000
Yig<Yig<00>WWL`00`000:jXdZjXdP04[ZSB00<0002d/mRd/mP00[Bcf08000000k[1g`0000000003
_<7M0P000004`M;V00000000a];S0P0000;9j>`2000000>innP000000000@Oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`08oooo0P00008d01T200000V@HE`030000RCMNRCMN00:9=eh3
00001iQFOP030000[6En[6En00^/IGh00`000;Y`OKY`O@0:^W1m00<00034N7_4N7/01LAhN`@00005
b6]L00@0003=KU/000000002a4lZ0`0001koool0100004PPO75=V00000:3Ij/01@0008mi]Xmi]Xmi
]P000003VHNo00H0002PT/JPT/JPT/H0002XWL/200000ZNMc0040000[ZSB000000000jjXdP060000
];?H00000000];?H00001K[1g`030000_<7M000000G1d^H2000000C9j>`00000002innP20000@ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`07oooo0P00008d01T00`0006@HEf@HE`02
I1QG00<00029=eh000000P0000ZHEWh00`000:aUOZaUOP0;[6En00<0002jL7fjL7d02[Y`O@030000
a7Qka7Qk00O4N7/00`000<]nN@000003000000?8Je`0003=KU/00/e^F`<000001<IA:P0000000000
01_oool0100004lPMP00075=V08000001X=WZ`00000008mi]P0009^7_@8000001YV7_`0000000000
0:2BaP0000>XWL/00`000:NMc0000003[ZSB00<0002^Z=8000001;Bcf0800005^/7O0P0000C1d^H2
00000/;Wl0040000^O_X^O_X0000AOooo`030000oooooooo01Goool001Goool00`000?ooooooo`07
oooo00<0000d01Td01T00P0000ET65L200003IQFOP030000[6En[6En00B/IGh>00001[Y`O@030000
a7Qka7Qk00O4N7/00`000<]nNL]nN@03bgii0`0000C=KU/200000/IA:P80000Ioooo0`000005MTfD
0000QfNWQfNW000000:BNK@00`0009^7_I^7_@02VhNm00@0002RTlFRTlFRTlD200001:RMb`030000
[ZSB[ZSB00>^Z=800`000;Bcf;Bcf002];?H00<0002i`N2i`N000P000003^/7O0000000000:nd^P0
10000<7BiP00000000;2io02000000>`n>d0003oool0Aoooo`030000oooooooo01Coool001Goool0
0`000?ooooooo`06oooo0P000003=00I0000I1QG00AT65L00`0007/nN@00000=V5In200000NaMY80
0`000;eoT;eoT004_Gn@2@0000O4N7/00`000<]nNL]nN@04bgii00<0003?PGP000000P000003cFiK
0000cW1K008000001<IA:P000000000001Ooool01`0005HQL00007I=U8]WY00008MWY`02000000NB
NK@000000000002KQkd0002TTl<00P000003XY?50000ZIg:008000000jRMb`000:nXd@02000000B^
Z=800000002d]=P2000000>d/mP0002i`N001;W1h0030000_];X_];X00:nd^P3000000C2io000000
002`n>d20000BOooo`030000oooooooo01Coool001Goool00`000?ooooooo`05oooo100000AT65L2
00000W/nN@030000V5InV5In00NHEWh4000000>PJI40002aMY803;5fTP030000_Gn@_Gn@00ZmOi00
0`000<J6S/J6SP0500000/AhN`030000bgiibgii00C;OWT00`000<n1N<n1N002ch5h0`0000;>L5/3
000000C5D2/000000000000Coooo00D0001O8V/0001kCY0000000X]WY0040000UGVaUGVa00000if7
^`030000Y9?3Y9?300:TTl<00`000:VMbZVMbP02ZIg:00<0002_Z=6_Z=400ZnXd@800004];CH00<0
002i`N2i`N000[W1h08000000kgBj@000;kBj00200000[kVlP8000000k3hk@000000001;oooo00<0
003oooooool05?ooo`005?ooo`030000oooooooo00Goool00`0000000`000004I1QG0P0000Ak?WT0
0`0009QFOYQFOP03V5In100000FPJI400`000;5fT[5fTP0;/GJB00<0002mOi2mOi002[eoT0030000
aXJ>aXJ>00G6QXh700000l]nN@030000ch5hch5h00;?PGP01`000=62N00000000<i`F`000<i_G002
000000?1CRd0000000000P0000ooool3000000R2Ch`00000002;Ij@0002HNJl0002ENK4200000Yf7
^`800002Y9?300L0002/W/T00000002YWLX0002aZ=000P000004[jSA0000]KCH]KCH0P000003];CH
0000^/;P008000000kW1h0000;gBj@03_M;Y0P000004_^Kb00000000Z_K_0P0004koool00`000?oo
ooooo`0Coooo000Doooo00<0003oooooool01?ooo`0400000003000000000V@HE`800006Ncii00<0
002HEWh000000`0000VPJI400`000;5fT[5fTP0</GJB00<0002mOi2mOi002KeoT0030000aXJ>aXJ>
00O6QXh00`000<b;S<b;S002c8^<1@0000??PGP010000=62N=62N=62N0<00002cVmL0P000003`Dh]
0000000000<00009oooo10000006R568000000000000SfNQ00000iQi[`030000WhNiWhNi00800002
YY?200<0002TTl<000000jbNb@030000/JS@/JS@00:aZ=000`000;Fdf;Fdf003]KCH00<0002j`^2j
`^000[[2h0800002_M;Y0P000004_NKc00000000Z_K_0P00053oool00`000?ooooooo`0Coooo000D
oooo00<0003oooooool01?ooo`80000012T0A@000000000000Qk?WT200003J1YT@030000/GJB/GJB
00baMY800`000;eoT;eoT00:_Gn@00<00036QXk6QXh01/J6SP030000c8^<c8^<00G<Rh`00`000=2>
R`000002000000??PGP0003APWP00]62N0030000d89h0000008000000l]^GP000000000>000000ik
:EP0002?DX<0002IJY/0002DJIh0002KNJ`0002HNJl0002RQkL00002WhNi00@0002VTl:VTl:VTl82
00000jbNb@<000000k6Xd0000;NdeP02000000Je]=P00000002k`]l0002j`^0200000[kBj@800000
1;gVl`0000000:Sek`80001Boooo00<0003oooooool04oooo`005?ooo`030000oooooooo00?oool2
00000RT0A@030000NciiNcii00Ik?WT00`0008QES`00000>X6VA00<0002aMY:aMY803;5fTP030000
_Gn@_Gn@00ZmOi000`000<J6S/J6SP07aXJ>00<0003<Rhc<Rh`01<b;S0030000d8j;d8j;00;@SX/4
00000]62N0030000d89hd89h008000000l]^GP000<I[H@0A000000NIJY/00000002ONZX0002KNJ`0
00000Z:7]`040000WhNi0000Z9?00P000003YY?20000[Yk700<00003/jW?00<0002g]=Jg]=H00[Nd
eP800002^l;O0`000003_];Y0000000000:ni_8010000:Sek`00000005Coool00`000?ooooooo`0C
oooo000Doooo00<0003oooooool00_ooo`04000000030000:@150P0000Ik?WT200000XQES`030000
X6VAX6VA00bPJI400`000;5fT[5fTP09/GJB5P0000C6QXh00`000<b;S<b;S005c8^<00<0003@SX_@
SX/00]2>R`030000dXn;dXn;00H000002Lj1NP00000000000<I[H@000<1XI@000;YTJ@05000000^T
FWH000000000002SKI@0002NJiL0002SNjL0002ONZX00P000004Y8Ne00000000XXNg0P0000>XTl00
0`000:jNajjNa`02[Yk70P0000:cZLl3000000Bg]=H0002m`]jm`]h200000l3Cj08000000kkVlP00
000000020000E_ooo`030000oooooooo01?oool001?oool00`000?ooooooo`02oooo00L0000000<0
000Y04D0001=66d0000017/nN@800004R5F?00<0002PJI6PJI403:1YT@040000/GJB/GJB/GJB2000
00>cPZ000`000;n;W[n;WP0:_h^N00<00037TIc7TI`00lNAW0T00003c8^<00<0003@SX_@SX/00]2>
R`030000dXn;dXn;00;BSh/00`000=6?Rm6?R`04000000?:OWd0000000002@000004[W6=00000000
XffD0`000003Xg^W0000000000:XR;<010000:B7]JB7]@0000:ZTkh2000000JXTl0000000000002^
W/L00002]JW=0P0000>i]=@200000[g2gP060000`m?V0000`=?X0000`>Oa0`0005[oool00`000?oo
ooooo`0Boooo000Coooo00T0003oooooooooool0000000<0000Y04D000000TdHK@030000NciiNcii
00800006R5F?00<0002PJI6PJI402Z1YT@H0000;/h:P00<0002oRijoRih02[n;WP030000ai6Lai6L
00O7TI`00`000<fEV/fEVP02cIFJ1`0000;@SX/01@000=:?Rm:?Rm:?R`000003dHn;00<0003?SXd0
00000`0000;5O8001P000;miP`000;YfQP000;AcRPD000001Z]mXP00000000000:^8/@0000:XR;<0
1@000:B7]@000:bD_@000003ZY>n00@0002`W/J`W/J`W/H200000[FYc@070000_;CB00000000^KCD
0000`<;L00<000000l?CiP00000000030000G?ooo`030000oooooooo01;oool001?oool010000?oo
ooooooooo`8000000bT0A@0004dHK@02CAQ]0`0000R8EHl00`000:1YTJ1YT@05X6VA1@0000:TMj00
0`000;>2X;>2X00</h:P00<0002oRijoRih02[n;WP030000ai6Lai6L00O7TI`00`000<fEV/fEVP05
cIFJ00@0003AV9WAV9WAV9T5000000?BSh/0003ASh/00]6?R`050000chj=chj=0000c8b?00X00000
2;B1W0000;1oW`000:]mXP000:j9[`0000:[R;4010000:R8/`00000000>/U;d010000:ZC_P000;:O
a08000000k2NaP000;NYb`0300000[bddP<000000l32g0000<KCi002000000C4j>l000000000001M
oooo00<0003oooooool04_ooo`004oooo`030000oooooooo008000000bT0A@0004dHK@03CAQ]00<0
0028EHn8EHl028QES`030000X6VAX6VA00D00007Y7NP00<0002cPZ2cPZ003;>2X0030000_h^N_h^N
00ZoRih00`000<NAW<NAW007ai6L00<0003=UI[=UIX01LfEVP030000dIRIdIRI00?AV9T00`000=>I
V=>IV004000000GASh/0003?SXg?SXd000000/b<S`0:0000b8ZA0000`hND0000_XFG0000^H>J0000
]86L1@0000:^RJl400000[2F^`040000[9Bm[9Bm[9Bm0P0000>bWl@200000[NYb`030000_[C@0000
008000000l?2f@0000000002000000C9jN`000000000001Ooooo00<0003oooooool04_ooo`004ooo
o`030000oooooooo00<00003CAQ]0`0000V8EHl400003:AgX0030000/h:P/h:P00fcPZ000`000;n;
W[n;WP0:_h^N00<00037TIc7TI`01lNAW0030000cIFJcIFJ00C=UIX00`000=6HVM6HV@03dIRI00D0
003CVISCVISCVIP000000]:IVA4000001KV=Z0000;F;ZP000;6:[003000000>aU;T0002`U[/00[2F
^`060000[9Bm[9Bm[9Bm0000]9o30P000003/Yo40000^ZW900<00002_[C@00D00036`]H00000003:
dn400`0006;oool00`000?ooooooo`0Boooo000Coooo00<0003oooooool00P0000==66d01000064f
QV4fQP0000J8EHl3000000>?IIh0002TMj003JAgX0030000/h:P/h:P00fcPZ000`000;n;W[n;WP0:
_h^N00<00037TIc7TI`01lNAW0030000cIFJcIFJ00G=UIX00`000=6HVM6HV@03dIRI00@0003CVISC
VIP00003dYVI00@0003AV9[AV9X00002cYNL00/0003:U9k:U9h00036TZ400031T:<0002mSZD0002i
SJP01@000005/YBg0000/IBi/IBi000000>`U[/00`000:bD_@000004]9o30P0000:jZLT00`000<6d
cP000002000000?6`]H0003>dmd00P000003`_gR0000oooo067oool00`000?ooooooo`0Boooo000B
oooo00<0003oooooool00`00009=66d01000064fQV4fQP0000B8EHl3000018mUWP030000Y7NPY7NP
00bTMj000`000;>2X;>2X00=/h:P00<0002oRijoRih02[n;WP030000ai6Lai6L00O7TI`00`000<fE
V/fEVP05cIFJ00<0003AV9WAV9T00m6HV@050000diVHdiVHdiVH000000?BVIT010000=6HV]6HVP00
00;>Ui`01P000<ZDWP000<JBX@000<6@X`D000001;RE/`000;FD]@0000:bU;L00`000;6D^@000003
/9Jk00<0002/U;d000001;BO``030000_:W7000000800002`KC>00<00039`]<000000P000003eN[T
0000000006Coool00`000?ooooooo`0Aoooo000Boooo00<0003oooooool01@0000=Q=XH00`0008QE
S`00000200001hmUWP030000Y7NPY7NP00bTMj000`000;>2X;>2X00=/h:P00<0002oRijoRih01;n;
WS8000000lBJ[@000<2I[`0200000[RE/`030000]IBe0000010000000kbYa`000<>db`06000000?K
jMh0003oool0IOooo`030000oooooooo017oool001;oool00`000?ooo`00000300001F4fQP80000:
SfFN00<0002TMj2TMj003:AgX0030000/h:P/h:P00FcPZ0?00001/2DZ@030000b9ZWb9ZW00O8VZL0
0`000<jNYLjNY@05cYjU00<0003BXJCBXJ@00m:QY0050000e::Se::Se::S000000?DXZ@010000=:Q
YM:QY@0000;?X:H01@000<bNZ0000<RLZ`000002a9Z]00<00030VJl000001P000005]Ifo0000/ig1
/ig1000000:bWL<200001KBQa@030000_:W7000000H000000mKAe0000000001Woooo00<0003ooooo
ool04Oooo`004_ooo`030000oooo000000800004HCJ60`0000^?IIh00`000:AgX:AgX009Y7NP2`00
00ReS:/00`000<2DZL2DZ@0:`9BY00<00038VZO8VZL01lRJY`030000cYjUcYjU00G>WZD00`000=:Q
Y=:QY003dZ6T00D0003DXZ?DXZ?DXZ<000000mBRY0040000dZ6UdZ6U00000/nPYP030000c9jXc9jX
00L000002;nP^P000;^N^`000;RM_@000;FM_`0000:cWL401P000;:M`k:M``000;:M``0000>dXLD0
2P000;bYakbYakbYa`000<Bcb@000<foc@000=S?d0<0001Woooo00<0003oooooool04Oooo`004_oo
o`D00002HCJ60P00009/BIL00`0008mUWXmUWP09SfFN00@0002TMj2TMj2TMj0800000jN2[0030000
]Hb[]Hb[00feS:/00`000<2DZL2DZ@0:`9BY00<00038VZO8VZL01lRJY`030000cYjUcYjU00G>WZD0
0`000=:QY=:QY004dZ6T00D0003DXZ?DXZ?DXZ<000000mBRY0030000dZ6UdZ6U00H000002LZV]000
0<JT]P000<>R^0000;nP^P000;^N^`05000000FcWL40002bWL>bWL<000000[:M``030000]:75]:75
00d0001Xoooo00<0003oooooool04Oooo`004_ooo`L00004K4VG00<0002?IIj?IIh01hmUWPH0000;
Yh:/00<0002eS:^eS:/03KF<Z`030000`9BY`9BY00[0U:T00`000<RJYlRJY`08b9ZW00<0003>WZG>
WZD01LjNY@030000dZ6TdZ6T00?BXJ@01P000=BRXmBRXmBRX`000=BRY0H000001]6Y/0000<jW//jW
/P000<ZV]0T000000kVVa@000;JTaP04000000>bWL<0002bWL<00[:M``8000000kNRa0000;fYa@09
0000JOooo`030000oooooooo017oool001;oool3000000<M06h0001/BIL01Fa9U`030000SfFNSfFN
00>?IIh400000Y9aZP030000Yh:/Yh:/00bWPZ`00`000;F<ZkF<Z`0=]Hb[00<00030U:W0U:T02l2D
Z@030000b9ZWb9ZW00O8VZL00`000<jNYLjNY@05cYjU00<0003BXJCBXJ@02@0000;FZjd010000=B[
[]B[[P0000;AZK000`000<jW/P000002000000o9[Kh00035Zl000031ZL80002mYl@0002iY/D0002f
Y<H0002cXlL0002aX/P00P000004/Yg30000000000000[NRa08000001;nX`P000<N``lN```D0001Y
oooo00<0003oooooool04Oooo`004_ooo`D00006K4VG00<0002?IIh000000`0000JBLJX00`000:N2
[:N2[00<Yh:/00<0002eS:^eS:/03[F<Z`030000`9BY`9BY00[0U:T00`000<RJYlRJY`07b9ZW00@0
003>WZG>WZG>WZD700000mBZ[@050000eZ^]eZ^]eZ^]000000?FZjd01@000=B[[]B[[P000=6Y/004
000000C=[k`00039[Kk9[Kh<000000BaX/P0002_WlL00003/Yo40P000003^:;20000000000<00000
0m>g_P00000000020000JOooo`030000oooooooo017oool001;oool2000000<M06h0000000001Fa9
U`<0000:TW6Z00<0002WPZbWPZ`03JN2[0030000]Hb[]Hb[00feS:/00`000<2DZL2DZ@0:`9BY00<0
0038VZO8VZL00/RJY`T00004d:N_00<0003DZZgDZZd00mBZ[@050000eZ^]eZ^]eZ^]000000?FZjd0
0`000=B[[P000002000000GD/kP0003A/KX0003=[k`010000008akK900000000_[3=0000^Zk>0000
]Z_?0P000005[ZK?0000[io70000[Yk700800002/Yk300@0002iX<000030Y[l70000J_ooo`030000
oooooooo017oool001;oool3000000<_68<0001/BIL00Va9U`8000000g5GY000099aZP0:TW6Z00<0
002WPZbWPZ`03JN2[0030000]Hb[]Hb[00feS:/00`000<2DZL2DZ@04`9BY2`0000G:Xk400`000=2W
[m2W[`05d:N_00<0003DZZgDZZd00mBZ[@030000eZ^]eZ^]00;FZjd00`000=J[[@000002000000?G
];H0003D/kP00]Bc^0<000000m2ja@000<^ha`0;000000F^Y/l000000000002^W/L00`000003/Yc1
00000000008000000l2S^`00000000040000J_ooo`030000oooooooo017oool001;oool200000RlH
P`040000K4VG000000000g5GY0030000TW6ZTW6Z00VBLJX00`000:N2[:N2[00=Yh:/00<0002eS:^e
S:/02KF<Z`/00006`Ifc00<0003:Xk7:Xk401lZS/@030000d:N_d:N_00G@Yjl00`000=BZ[MBZ[@03
e:Z]00@0003FZjgFZjgFZjd3000000?H];D0003G];H00]Nd]P070000e;>h00000000e;c30000d;[5
00<000001<W1d`0000000;jke`@000001:j`f@000000000000:XWld010000:fLaP000;:L`@800002
^Ifl10000004e:fa000000000000Joooo`030000oooooooo013oool001;oool200000RlHP`800005
LENT00<0002BLJZBLJX02I9aZP030000Yh:/Yh:/00fWPZ`010000;F<ZkF<ZkF<Z`P00004]iJe00<0
0031WK?1WK<02/6M/`030000bZ>abZ>a00O:Xk400`000=2W[m2W[`06d:N_00<0003DZZgDZZd00]BZ
[@060000eZ^]00000000f;Be00000]Rd]@040000ekBfekBfekBf0P000003ekk00000e;c300<00000
0lk4d@0000000005000000F^_^D000000000002UYMH00P0000:VW</00`000:^Ia0000002/IVn00<0
002hV[T00000200006[oool00`000?ooooooo`0@oooo000Aoooo00<0000005@000000`0000IaEj@0
0`00099aZY9aZP09TW6Z00<0002WPZbWPZ`02JN2[0P0000<]iJe00<00031WK?1WK<02/6M/`030000
bZ>abZ>a00S:Xk400`000=2W[m2W[`05d:N_00<0003DZZgDZZd0100000?H];D010000=Rd]MRd]MRd
]@@00002ekk00`000005dlO>000000000000b]7O00d00002XiS900X0002ZU/80002`UK/0002hV[T0
002oV[400038Wjh40000Joooo`030000oooooooo013oool0017oool300000SLXTP030000LENTLENT
00AaEj@00`00099aZY9aZP09TW6Z00@0002WPZbWPZbWPZ`800001:R;]P030000]iJe]iJe00fgU[D0
0`000<6M/l6M/`0:`Ifc00<0003:Xk7:Xk402<ZS/@030000d:N_d:N_00?@Yjl500000]Jc]P030000
f;Bef;Be00?H];D010000=Rd]MRd]@0000?J_kh3000000GHbL/0003Calh0003@e=`020000003KLKo
00000000008000000hnLf`0000000002XI?500<0002XTKh000001`000004dYnR000000000000J_oo
o`030000oooooooo013oool0017oool00`000000I0000002=bRB00<0001aEjAaEj@0175GY0030000
TW6ZTW6Z00>BLJX:00003:R;]P030000]iJe]iJe00fgU[D00`000<6M/l6M/`0;`Ifc00<0003:Xk7:
Xk401lZS/@030000d:N_000000<00002d[2h00<0003F/kKF/kH00]Jc]P030000f;Bef;Be00?H];D4
00000mZo_P040000fl_90000f<W;1`0000Soool03@0007FIi`00000009J?b`0009j=`@000:J<^@00
0:n@]`000;J@[`06000000?KVX`000000000JOooo`030000oooooooo013oool0017oool010000000
I00003LXTPh00006Tg^e00<0002XRkJXRkH03JR;]P030000]iJe]iJe00fgU[D00`000<6M/l6M/`0;
`Ifc00<0003:Xk7:Xk401/ZS/@<00006d[2h00<0003F/kKF/kH00mJc]P040000f;Bef;Bef;Be0P00
00?K_kd4000000KKblT00000003LfM@0003Hk>8300002oooo`<000000i:8aP0009b7_006000000>l
SZH00035TZ401P0006Soool00`000?ooooooo`0@oooo000Aoooo10000003>36M0000LV6_00EbHJl0
0`0009=k]I=k]@09Tg^e00<0002XRkJXRkH03JR;]P030000]iJe]iJe00jgU[D00`000<6M/l6M/`0:
`Ifc00<0003:Xk7:Xk400/ZS/@@000000l^/^P000=:`^006d[2h00<0003F/kKF/kH00mJc]P060000
f;Be00000000fknm00000m^o_@030000g/c6g/c600<000000mcIe0000000000200003_ooo`<00000
1Xj1`00000000:B6]0000:^5[0D000000l::V@00000000030000J?ooo`030000oooooooo013oool0
017oool00`000000KP000002>36M00<0001bHJmbHJl0179Q[`030000Tg^eTg^e00VCNkD00`000:R;
]ZR;]P0>Z8^f00<0002gU[FgU[D03KNF]@030000`Ifc`Ifc00[1WK<00`000<ZS/@00000200001L^/
^P030000d[2hd[2h00KB/;P010000=Jc]]Jc]]Jc]P<00003fknm00<0003K_kgK_kd00P0000;Nc<H0
0`000>3KdN3Kd@0300004?ooo`P000001J^5[0000;63X`000;Z7W`03000000?8PXH0000000000`00
06Koool00`000?ooooooo`0@oooo000Aoooo0`00008h<Id00`00079Q[g9Q[`04LV6_00<0002CNkFC
NkD02I=k]@030000Z8^fZ8^f00jXRkH00`000;NF]KNF]@0=]iJe00<00031WK?1WK<01l6M/`D00009
bjbj00<0003B/;SB/;P01M:`^0060000e[>f00000000fKfn00001M^o_@8000000mo<a@0000000002
000000CPfm4000000000000Boooo10000003UWV`0000000000D000000kMoU`000;n1T003000000?:
LVH0000000000P0006Coool00`000?ooooooo`0@oooo000Aoooo00H0000007800000000h<Id00007
LV6_00<0002CNkFCNkD02I=k]@030000Z8^fZ8^f00fXRkH00`000;NF]KNF]@0=]iJe00@00031WK?1
WK?1WK<600000l>V_@030000bjbjbjbj00S;[;X00`000=:`^=:`^005d[2h0P0000?I_Kh00`000=^o
_M^o_@03fknm00@0003Oc<GOc<D00003hmc>0`0001?oool6000000FONJP0002VMil0002_O9`01000
0003^gR70000000000<000000l=?;P000000001Soooo00<0003oooooool04?ooo`004Oooo`<00000
0c<fY@000000000200001G9Q[`030000Tg^eTg^e00VCNkD00`000:R;]ZR;]P0=Z8^f00<0002gU[Fg
U[D01KNF]@`00009`jJm00<0003;[;[;[;X02<^/^P030000d[2hd[2h00?B/;P300001MVm_P030000
fknmfknm00<000000mo<a@0000000002hmc>0`0001Goool2000000>3IZT0000000000P000006YWNO
00000000ZgBD0000/gN?0P000003]fio0000_Faa00L0001Qoooo00<0003oooooool04?ooo`004Ooo
o`<00002<cJU00<0001`IkU`IkT010000003LV6_0000Tg^e00ZCNkD00`000:R;]ZR;]P05Z8^f4000
00RgW[l00`000<>V_L>V_@0:`jJm00<0003;[;[;[;X02<^/^P040000d[2hd[2hd[2h0P0000;D^l40
0`000=Vm_]Vm_P03fKfn0`0000;Oc<D200000^CLc@@0000Foooo10000007SfRR000000000000XfnH
0000ZgBD008000000k1^Q`000;M^O`0200000[QQI`8000000k]GCP00000000030000G_ooo`030000
oooooooo013oool001;oool200000S<fY@030000L6NiL6Ni00A`IkTE00002:RC`0030000]ijo]ijo
00fgW[l00`000<>V_L>V_@0:`jJm00<0003;[;[;[;X02L^/^P<00004e;_100<0003I_KkI_Kh00mVm
_P030000glc5glc500;Oc<D010000>CLcNCLcNCLc@<0000Goooo1P000003V6VI0000000000800000
0jQ/S@000;1^Q`0200000[9VM`030000^65W^65W00800002]Te50P000004[c<F000000000000Fooo
o`030000oooooooo013oool001;oool3000000<c=ZD0001`IkT01W1W^@030000TX>oTX>o00VBPkl0
0`000:RC`:RC`00=Z9?000<0002gW[ngW[l03KNN_`030000`jJm`jJm00_3Y[d00`000<^/^/^/^P07
bjbj0P0000OD^l400`000=Vm_]Vm_P0300000mo<a@800002i=c=0P000003f_o70000oooo01Koool4
000000J<H9T000000000002OJ9000002Z6b=0P0000:/Ih000`000;9VM`00000200000[AJH0800000
1KI=A@00000000000:`^4P030000F?ooo`030000oooooooo017oool001;oool2000000<U=:/00000
00001g1W^@030000TX>oTX>o00VBPkl00`000:RC`:RC`00=Z9?000<0002gW[ngW[l03KNN_`030000
`jJm`jJm00_3Y[d00`000<^/^/^/^P03bjbj10000003c[O40000e;_100KD^l4300000]g:a`040000
glc5glc500000^CLc@<000000mcna0000?ooo`0Foooo1`000003UF6B0000WfR@00<000001:EUQP00
0:aWP:aWP0800002[ema0P0000:dFV0300000[=9@P8000000j`^4P00000000020000EOooo`030000
oooooooo017oool001;oool3000000<U=:/0000000001W1W^@030000TX>oTX>o00VBPkl00`000:RC
`:RC`00=Z9?000<0002gW[ngW[l03[NN_`030000`jJm`jJm00[3Y[d00`000<^/^P00000300001Ljg
a0030000e;_1e;_100GD^l400`000=g:amg:a`03gL[70P0000?Tg<d010000>S`d@00000001Soool0
0`00B`0000000002000000>8Ei40002EHI800P000004W66:0000YFF6YFF60`0000:YHG/00`000:mO
LJmOL@0300000k9GG@8000001;=9@P000000000000:_<QD30000Doooo`030000oooooooo017oool0
01;oool2000000@;:j`00000001XJl<300000g1W^@030000TX>oTX>o00VBPkl00`000:RC`:RC`00=
Z9?000<0002gW[ngW[l03[NN_`030000`jJm`jJm00S3Y[d400002Ljga0030000e;_1e;_100?D^l43
00001Mg:a`040000i=c=i=c=i=c=0`000003g?k40000oooo01Ooool2000000=K<8<0000000000`00
0003TUZ;0000W66:00<00002XUn100<0002YHG^YHG/00`0000>^GFh200000[9GG@<00002]De50P00
00:_<QD30000DOooo`030000oooooooo017oool001;oool5000016Q[``8000000g1W^@0009:3_`0;
TX>o00<0002XTl2XTl003JRC`0030000]ijo]ijo00fgW[l00`000<>V_L>V_@04`jJm100000;4/<L0
0`000<jga<jga009c[O400<0003D^l7D^l400P0000;HalX00`000=g:amg:a`02gL[70P0000;Tg<d0
1@000>O`d@000=cna000000Ioooo1@000003Q52:0000TUZ;00<00002VUb500@0002RGh6RGh6RGh42
00000ZQON@800004[Ue^0P0000>dFV0200000[E=A@800002[c8E0`0004ooool00`000?ooooooo`0A
oooo000Boooo0`0000032b^/0000000000EXJl<400002Y:3_`030000Z9?0Z9?000fXTl000`000;NN
_kNN_`0=]ijo00<00033Y[g3Y[d0100000K4/<L00`000<jga<jga009c[O40`0000GHalX010000=g:
a`00000000;Qfll2000000CWl=40003Lo/D0000Ioooo10000003LT250000Q52:008000000hmEQP00
09YLQ@02VUb500<0002RGh4000000P0000FXGgT01P000:iMKP0000000:mOL@0000FdFV0200000[E=
A@800002^ClP0`0004goool00`000?ooooooo`0Aoooo000Boooo00H0003oool00000000;:j`00006
J6_300<0002?R/V?R/T0100000JBPkl00`000:RC`:RC`00=Z9?000<0002gW[ngW[l02KNN_`L0000;
a;3700<0003>]lC>]l@01ljga0800007f<O:0P0000CQfll00`000>O`dNO`d@0200006_ooo`050000
:01O00000000LT2500<00003SeF600<0002JG8D000000P0000>QGWl00`000:QONJQON@02Z5mi0P00
00B_Gg4200001;AJH0<00002_5Q>0P0000:i?b030000Boooo`030000oooooooo017oool001;oool0
1@000?ooo`00000000/[[003000016Q[``030000Sh[9Sh[900B?R/T400000Y:3_`030000Z9?0Z9?0
00fXTl0010000;NN_kNN_kNN_`P00004^:S900<00034/<O4/<L02lB`a`030000c[O4c[O400G>]l@2
000000?@`lh0003HalX01]S7bP030000hM_?hM_?00;Qfll2000000?Wl=40000000006oooo`03000W
0000000000<00000189:Q00008mEQXmEQP<00002VEZ300D0002QGWnQGWnQGWl000000ZQON@800002
ZF9k00<0002_Gg6_Gg400jmOL@040000]5YP000000000[USJ0800003_5Q>0P0000:i?b030000BOoo
o`030000oooooooo017oool001;oool00`000?ooooooo`0300000UQ[b`050000J6_3J6_3J6_30000
00Z?R/TF00003;RXb@030000a;37a;3700_4/<L00`000<jga<jga003c[O40P0000?@`lh00`000=S7
b]S7bP03f<O:0`0000?Qfll00`000>G_eNG_e@0200006oooo`<000001E<PLP0006ljOP00089:Q003
000000>?DhD0002IFX<00iUJP`030000XEio000000<00005ZF9k00<0002_Gg6_Gg400ZmOL@800006
^F=X00<0002lF4jlF4h00[aHCP030000^ClP^ClP00:i?b020000Aoooo`030000oooooooo017oool0
01;oool00`000?ooooooo`0300000eQ[b`040000J6_3J6_3000038n:b@030000Yic;Yic;00fWW</0
0`000;RXbKRXb@0=^:S900<00034/<O4/<L02lB`a`040000c[O4c[O4c[O40P0000G@`lh00`000=S7
b]S7bP02f<O:00@0003Lf=?Lf=<00002hM_?00<0003UkmGUkmD00P0001coool3000000AC87800000
0022BX@200000hmCQ@040000VEZ3VEZ3VEZ30`0000>SHH800`000:URNjURN`04ZF9k00@0002_Gg40
00000002]6Qh0P0000FiHfP00`000;aHC[aHCP02_5Q>0P000003^ClP0000bELb00<00015oooo00<0
003oooooool04Oooo`004oooo`030000oooooooo00800004F6_;0`0000b?R/T00`000:NLbjNLb`0=
Yic;00<0002hZ<VhZ<T03KRXb@030000a;37a;3700c4/<L300002=33cP040000f<O:f<O:00001=cH
d`800002iNoE0P0001goool2000000=C8780000000000P000003PDV30000Se>500>?DhD3000000>J
GHH0002SHH801:=QPP030000ZF9kZF9k00>YHW/200001[AXN0030000^F=X^F=X00>iHfP200000[aH
CP<00004bELb0P0004?oool00`000?ooooooo`0Boooo000Coooo00<0003oooooool00`0000EHJl/2
00002hn:b@030000Yic;Yic;00fWW</00`000;RXbKRXb@0>^:S900<00034/<O4/<L02/B`a`80000:
d<?>0`0000GLf=<00`000>G_eNG_e@0200007Oooo`D000001FlhO@000859Ph59P`000003Se>50P00
00BJGHH00`000:=QPZ=QPP03Xf6200<0002YHW^YHW/00P0000:^JH<00`000;AXN;AXN004]6Qh00<0
002iHfRiHfP00kUSJ0<00003b6]N0P0000?9Ec830000@Oooo`030000oooooooo01;oool001?oool0
1`000?ooooooooooo`0003YTd@000004F6_;00<00027T=D000000`0000R?R/T00`000:NLbjNLb`0<
Yic;00<0002hZ<VhZ<T03[RXb@030000a;37a;3700K4/<L4000000?5_=80003@`lh02=33cP800006
g=SC0P000004iNoE0000fOo:00007Oooo`<0000015<NL00006lhO@0000:1BH<01P0008mCQ@000000
091FQ`0000BJGHH00`000:=QPZ=QPP03Xf620`0000F^JH<00`000;AXN;AXN004]6Qh0P000003^F=X
0000000000;2LgH00`000<Q[G/Q[GP03b6]N00<00039Ec;9Ec800/UG<P<0000ooooo00<0003ooooo
ool04_ooo`004oooo`040000oooooooooooo0P000003>VCA00000000009HJl/00`0008N@eHN@e@03
Qi3E0`0000F?R/T00`000:NLbjNLb`0=Yic;00<0002hZ<VhZ<T03KRXb@030000a;37a;3700?4/<L3
00001LFldP030000d<?>d<?>00G@`lh2000000?CdmT0003Lf=<01=cHd`060000g^gLg^gL0000fOo:
00007Oooo`050000901D0000Dai`0000009_>7d00`000859Ph59P`0200000i1FQ`030000VUf6VUf6
00>JGHH00`000:=QPP00000200000ZMXR@030000[VV3[VV300>^JH<00`000;AXN;AXN005]6Qh0P00
00G2LgH200001<Q[GP800003bELb100003goool00`000?ooooooo`0Boooo000Coooo00<0003ooooo
ool00_ooo`800002>VCA00<0001HJl/0000028N@e@@000000hn:b@000:NLb`0>Yic;00<0002hZ<Vh
Z<T03KRXb@030000a;37000000<00008aKcB00<0003@`lk@`lh00m33cP800003dm?I00@0003Lf=?L
f=?Lf=<200000]k]g0<0000Noooo00D0000T05@0001C7W0000000VlhO@@00004T5J700<0002JGHJJ
GHH00iYMQP800005YfR900<0002^JH>^JH<01:iYP`030000]6Qh]6Qh00:dJ7P200000[]fQ0030000
`W=f`W=f00C2LgH00`000<Q[G/Q[GP03b6]N00@00039Ec;9Ec;9Ec840000??ooo`030000oooooooo
01;oool001?oool00`000?ooooooo`03oooo0P00008jI=400`0005Q[b`00000;Qi3E1P0000^WW</0
0`000;RXbKRXb@09^:S91P0000g5_=800`000=33c]33cP0200001]?Cf@030000g=SC000000?NkM`0
0`000=;oe@00000Noooo0`000003Dai`0000KcQm00<00002Pdb600<0002@EXN@EXL00i1FQ`030000
VUf6VUf6008000000iiUS@000:MXR@05YfR900<0002^JH>^JH<01:iYP`040000]6Qh000000001K]f
Q0030000`W=f`W=f00C2LgH00`000<Q[G/Q[GP03b6]N00<00039Ec;9Ec800/UG<P<0000koooo00<0
003oooooool04_ooo`005?ooo`030000oooooooo00?oool200000SYTd@80000<Qi3E00<0002SYMNS
YML00Z>Ue`P00003Yic;00@0002hZ<VhZ<VhZ<T800001;Nce@030000aKcBaKcB00c5_=8300002=?C
f@800003g^gL00<0003BomD000007oooo`H00002LCb100@00023C8J3C8H00005T5J70`0000>NIHd0
0`000:MXRJMXR@05YfR900<0002^JH>^JH<00jiYP`800008^gJ400<00032LgK2LgH01<9cMP030000
b6]Nb6]N00?8Jeh2000000?9Ec80003LMdT00`0003Woool00`000?ooooooo`0Coooo000Doooo00<0
003oooooool01?ooo`800002>VCA0P0000^7T=D00`000:>Uej>Ue`0:XjGG1`0000bg/mD00`000<Fl
d/FldP0;aKcB0P0000[CdmT01`000=k]g=k]g=k]g0000=;oe@00000Ooooo10000003EB=d0000LCb1
009a?8401@0008=<QX=<QX=<QP000003T5J70P0000JNIHd00`000:MXRJMXR@04YfR900<0002^JH>^
JH<00`0000:dMXh00`000;]fQ;]fQ006^gJ400<00032LgK2LgH01<9cMP800004b6]N0P0000?LMdT3
0000>?ooo`030000oooooooo01?oool001Coool00`000?ooooooo`05oooo0P000003>VCA0000MY?R
00800009Qi3E00<0002SYMNSYML03J>Ue`030000]k?E]k?E00fg/mD00`000<Fld/FldP08aKcB0`00
0003a/cN0000dm?I00OCdmT300000]k]g0<0000Poooo0P0000049P1J0000EB=d00000g4lP@060000
Pdb6Pdb6Pdb60000T5J70P000003U5j?0000WVF=00FNIHd00`000:MXRJMXR@04YfR90`0000JdMXh0
0`000;]fQ;]fQ006^gJ400<00032LgK2LgH01L9cMP040000b6]N000000000]F3L@040000g7M9g7M9
g7M90`0003Ooool00`000?ooooooo`0Coooo000Doooo00<0003oooooool01Oooo`04000004c;0000
00000gJChP<00006Qi3E00<0002SYMNSYML03J>Ue`030000]k?E]k?E00jg/mD00`000<Fld/FldP04
aKcB0`0000C6c=h00`000=?CfM?Cf@04dm?I0P0000?Dj>@400008Oooo`03000Q9P1J0000009E8g@0
1000074lPG4lP@0000>3C8H3000019ANS`030000WVF=WVF=00BNIHd010000:MXRJMXRJMXR@800002
[GBD00<0002dMXjdMXh01KAfSP030000^gJ4^gJ400JkMX@00`000<9cM/9cMP05`W=f00<0003EPg7E
Pg400mF3L@040000g7M9g7M9g7M90`0003Koool00`000?ooooooo`0Coooo000Doooo00<0003ooooo
ool01_ooo`04000004c;000000001GJChP<00003Qi3E00<0002SYMNSYML03J>Ue`030000]k?E]k?E
00jg/mD00`000<Fld/FldP02aKcB0P0000O6c=h00`000=?CfM?Cf@03dm?I00<0003Dj>CDj>@00mCX
i0<0000Qoooo0P0000049P1J0000EB=d00000g4lP@060000Pdb600000000QeF?00001IANS`030000
WVF=WVF=00BNIHd010000:MXR@00000000B]M9@00`000;AfS[AfSP06]7J>00<0002kMXBkMX@01[]f
Q0030000`W=f`W=f00;2LgH2000000?<QhH0003EPg401=F3L@040000g7M9g7M9g7M90P0003Koool0
0`000?ooooooo`0Coooo000Eoooo00<0003oooooool01_ooo`03000004c;000000QfTn82000000>7
T=D0002SYML03j>Ue`030000]k?E]k?E00fg/mD00`000<FldP00000200002/K<gP030000dm?Idm?I
00800004e>ST100002;oool00`008@0000000002EB=d00<0001a?84000000`0000>7EHl00`0009AN
SiANS`03U5j?00<0002NIHfNIHd019iUS@800007[GBD00<0002dMXjdMXh01KAfSP030000^gJ4^gJ4
00NkMX@010000<9cMP00000000C<QhH00`000=F3LMF3L@03eH=a00H0003LMdWLMdT0003=C`00000d
oooo00<0003oooooool05?ooo`005Oooo`030000oooooooo00Ooool4000027JChPH0000<XjGG00<0
002g/mFg/mD02KNce@H0000=a/cN0`0000CDj>@2000000?4oN@0000000008_ooo`8000000bH0FP00
05DSM00300000WI6R`030000QeF?QeF?00:7EHl00`0009ANSiANS`03U5j?00<0002NIHfNIHd00YiU
S@8000000jAaV0000:edU007[GBD00<0002dMXjdMXh01KAfSP030000^gJ4^gJ400JkMX@200001/b7
QP030000eH=aeH=a00CEPg401P000=agBMagB@000<e?000003?oool00`000?ooooooo`0Doooo000E
oooo00<0003oooooool02?ooo`8000000e2@k@0000000007MY?R00<0002K[nFK[nD00Y^_i@P00004
XjGG00@0002g/mFg/mFg/mD800001;C0h`030000a/cNa/cN00_6c=h200001MCXi0040000a?gT0000
00009?ooo`D000000eX^P@0007I6R`02MTJ;00<00027EHn7EHl00XMES`030000U5j?U5j?00BDGXl0
100009iUS@00000000BTLIP00`000:edU:edU005[GBD00<0002dMXjdMXh01[AfSP030000^gJ4^gJ4
00>kMX@200000/B7T`030000c8N6c8N600C<QhH00`000=F3LMF3L@03eH=a00L0003LMdWLMdWLMdT0
003=C`000000<_ooo`030000oooooooo01Coool001Koool00`000?ooooooo`08oooo00@0001@T>e@
T>e@T>d200001GJChP030000VjoUVjoU00ZK[nD800003KC0h`030000a/cNa/cN00S6c=h2000000?3
h>d0003Dj>@00]CXi08000000lCmi0000000000Toooo100000=J;X401@0007I6RgI6RgI6R`000004
QeF?00<0002DGXnDGXl00iANS`<00006Y76H00<0002]M9B]M9@01ZedU0030000]7J>]7J>00JdMXh0
0`000;]fQ;]fQ00200001LB7T`030000c8N6c8N600C<QhH00`000=F3LMF3L@03eH=a00L0003LMdWL
MdWLMdT0003=C`000000<?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`09oooo0P00
00=@T>d200000gJChP030000VjoUVjoU00jK[nD00`000;C0hkC0h`0>]<3S00<00036c=k6c=h01LK<
gP<00004`n3]0`0000;4oN@00`000?ooooooo`0Toooo00@0000/16X/16X00002FRj100<0001fAX]f
AX/00WI6R`030000QeF?QeF?00:7EHl0100009ANSiANSiANS`8000000iY[V`000:AaV007Y76H00<0
002]M9B]M9@01ZedU0030000]7J>]7J>00FdMXh300001lB7T`030000c8N6c8N600G<QhH00`000=F3
LMF3L@03eH=a00L0003LMdWLMdWLMdT0003=C`000000;oooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0:oooo0`0000=@T>d200000WJChP030000VjoUVjoU00fK[nD00`000;C0hkC0h`0>
]<3S00<00036c=k6c=h00/K<gP<00006`n3]0P0000?4oN@00`000?ooooooo`0Uoooo00@0000/16X/
16X00002FRj100D0001fAX]fAX]fAX/000001HMES`040000U5j?0000000019Y[V`030000Y76HY76H
00FTLIP00`000:edU:edU007[GBD00<0002dMXjdMXh00[AfSP800002^hJK00<00034Qi?4Qi<01/B7
T`030000c8N6c8N600G<QhH00`000=F3LMF3L@03eH=a00L0003LMdWLMdWLMdT0003=C`000000;_oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0<oooo0`0000=@T>d300003i^_i@030000
]<3S]<3S00nd`><010000<K<gP00000000O3h>d2000000F/m?800034oNC4oN@000009oooo`800000
0b`4JP0005X^P@02FRj100D0001fAX]fAX]fAX/0000018MES`<00006VV^K00<0002TLIRTLIP01ZAa
V0030000[GBD[GBD00J]M9@00`000;AfS[AfSP0200001;^6V`030000a8NCa8NC00O4Qi<00`000<b7
Q/b7QP05c8N600<0003EPg7EPg400mF3L@070000g7M9g7M9g7M90000iH0C000002goool00`000?oo
ooooo`0Eoooo000Goooo00<0003oooooool03Oooo`<00003D93]1@0000bK[nD00`000;C0hkC0h`0:
]<3S1P0000O3h>d200000jcdlP80000Yoooo0P000003;0AZ0000FRj1009J;X401P0007I6RgI6RgI6
R`0008MES`<000000hiSV`0009Y[V`06VV^K00<0002TLIRTLIP01ZAaV0030000[GBD[GBD00J]M9@3
00001k^6V`030000a8NCa8NC00O4Qi<00`000<b7Q/b7QP04c8N600<0003EPg7EPg401=F3L@040000
g7M90000kiaT0P0002coool00`000?ooooooo`0Foooo000Goooo00<0003oooooool03_ooo`@00000
0e2@k@0008Njm`03Qk[g200000BK[nD00`000;C0hkC0h`02]<3S200000B[d_@00`000<?PkL?Pk@04
`n3]0P0000>/m?820000:oooo`8000000b`4JP0005X^P@02FRj100@0001fAX]fAX]fAX/2000018iS
V`030000VV^KVV^K00JJJi/00`000:AaV:AaV006Y76H00<0002]M9B]M9@00jedU0800002/h>Q00<0
002kQY^kQY/01[^6V`030000a8NCa8NC00K4Qi<00`000<b7Q/b7QP05c8N600<0003EPg7EPg400mF3
L@800002kiaT00<0003UP1<00000:oooo`030000oooooooo01Koool001Ooool00`000?ooooooo`0@
oooo00<00000K]T000000P0000^7^_L900003:_Bm0030000`n3]`n3]00;3h>d200000jcdlP80000/
oooo0P00008/16X0100005X^PEX^P@00009fAX/300001XiSV`030000VV^KVV^K00FJJi/00`000:Aa
V:AaV006Y76H00@0002]M9B]M9B]M9@200001;>3X@030000^hJK^hJK00JkQY/00`000<B7TlB7T`07
a8NC00<0003<QhK<QhH01Lb7QP030000eH=aeH=a00800002hin700<0003_W6C_W6@00P0002_oool0
0`000?ooooooo`0Foooo000Hoooo00<0003oooooool04?ooo`800000101^f@000000000000f7^_L0
0`000:_Bm:_Bm00?Zm;d00@00033h>d000000003[?Cb0P0002koool2000000</16X0001J;X400UX^
P@<00002OEJJ00<0002>Hi^>Hi/018iSV`030000VV^KVV^K00JJJi/00`000:AaV:AaV006Y76H0`00
00NcPj400`000;^6Vk^6V`06^hJK00<00034Qi?4Qi<01lB7T`030000c8N6c8N600G<QhH200001>>O
Q`060000kiaTkiaT0000iH0C0000:Oooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0B
oooo0P000099]?P600001hNjm`030000Zm;dZm;d00^[d_@600000jcdlP80000`oooo0P000003;0AZ
0000FRj100<00004OEJJ00<0002>Hi^>Hi/018iSV`030000VV^KVV^K00JJJi/00`000:AaV:AaV005
Y76H0P0000VcPj400`000;^6Vk^6V`07^hJK00<00034Qi?4Qi<01lB7T`030000c8N6c8N600?<QhH0
0`000=NMV0000005hin700<0003_W6C_W6@00P0002Woool00`000?ooooooo`0Goooo000Hoooo00<0
003oooooool05?ooo`<00005BKCh1P0000:7^_L00`000:_Bm:_Bm002Zm;d200000B5g_`00`000:cd
lZcdlP020000<Oooo`80000012`4JP0000000000009S@I<00`0007eFVWeFVP02OEJJ00<0002>Hi^>
Hi/018iSV`030000VV^KVV^K00JJJi/00`000:AaV:AaV002Y76H0`000003Zh2U0000/h>Q00VcPj40
0`000;^6Vk^6V`07^hJK00<00034Qi?4Qi<01/B7T`040000c8N6c8N6c8N60P0000;GWIP00`000>>O
Qn>OQ`03hin700H0003_W6C_W6@0003UP1<0000Xoooo00<0003oooooool05oooo`006Oooo`030000
oooooooo01Koool600001DVdn0L00009QMkl1P0003?oool3000000<e6X80001S@I<00V=1T`030000
OEJJOEJJ009mEYX00`0008iSVhiSV`05SV>K00<0002JJi^JJi/01YY[V`040000Y76H000000001J^0
Y@030000/h>Q/h>Q00NcPj400`000;^6Vk^6V`07^hJK00<00034Qi?4Qi<01lB7T`030000c8N60000
00GGWIP00`000>>OQn>OQ`03hin700<0003_W6C_W6@00P0002Ooool00`000?ooooooo`0Hoooo000I
oooo00<0003oooooool07?ooo`H000000dVdn00008GNo004QMkl200003Woool01@00D@0003DJPSDJ
PP000003Hd6C00<0001mEYYmEYX00WeFVP030000SV>KSV>K00F>Hi/00`0009Y[ViY[V`05VV^K0`00
00N[P:D00`000;>3XK>3X@08/h>Q00<0002kQY^kQY/01k^6V`030000a8NCa8NC00K4Qi<200001]NM
V0030000hin7hin700?SWhL01P000>nLI>nLI0000>F04`0002Koool00`000?ooooooo`0Hoooo000I
oooo00<0003oooooool08_ooo`L00011oooo00D00540000e6X8e6X8000000f=1T`030000OEJJOEJJ
00=mEYX00`0008iSVhiSV`04SV>K00<0002JJi^JJi/00iY[V`8000000j5kZ@000:^0Y@08Zh2U00<0
002cPj6cPj401k>3X@030000^hJK^hJK00RkQY/00`000<B7TlB7T`02a8NC0`000003cI^S0000eifH
00KGWIP00`000>>OQn>OQ`03hin700<0003_W6C_W6@00P0002Koool00`000?ooooooo`0Hoooo000J
oooo00<0003oooooool0J?ooo`030000001A0000008e6X801@0006=1Tf=1Tf=1T`000005OEJJ00<0
002>Hi^>Hi/018iSV`040000VV^KVV^KVV^K0P0000BQNjT00`000:^0YJ^0Y@06Zh2U00<0002cPj6c
Pj402;>3X@030000^hJK^hJK00NkQY/00`000<B7TlB7T`0200001LfKX`030000eifHeifH00CGWIP0
0`000>>OQn>OQ`03hin700H0003_W6C_W6@0003UP1<0000Toooo00<0003oooooool06Oooo`006_oo
o`030000oooooooo06Soool200000cDJPP050000Hd6CHd6CHd6C000000EmEYX00`0008iSVhiSV`05
SV>K0`0000JQNjT00`000:^0YJ^0Y@07Zh2U00<0002cPj6cPj401k>3X@030000^hJK^hJK00RkQY/2
00001lfKX`030000eifHeifH00GGWIP00`000>>OQn>OQ`03hin700<0003_W6C_W6@00P0002Coool0
0`000?ooooooo`0Ioooo000Joooo00<0003oooooool0J?ooo`800003=AZ200D0001S@I=S@I=S@I<0
00001GeFVP030000SV>KSV>K00B>Hi/200002:5kZ@030000Zh2UZh2U00N[P:D00`000;>3XK>3X@08
/h>Q00<0002kQY^kQY/01K^6V`8000000l>HZP000<fKX`07cI^S00<0003GWISGWIP01=NMV0030000
hin7hin700?SWhL01P000>nLI>nLI0000>F04`0002?oool00`000?ooooooo`0Ioooo000Koooo00<0
003oooooool0Ioooo`800003=AZ200D0001S@I=S@I=S@I<000001GeFVP040000SV>KSV>KSV>K0`00
0003UGB[0000XG^Y00RQNjT00`000:^0YJ^0Y@07Zh2U00<0002cPj6cPj401k>3X@030000^hJK^hJK
00>kQY/200000l>HZP030000cI^ScI^S00K=Vj<00`000=NMV=NMV005eifH00<0003SWhOSWhL00n>O
Q`050000kiaTkiaT0000iH0C02;oool00`000?ooooooo`0Joooo000Koooo00<0003oooooool0I_oo
o`<00002=AZ200<0001S@I=S@I<00V=1T`030000OEJJOEJJ00=mEYX0100008iSV`00000000FEM:/0
0`000:5kZJ5kZ@06XG^Y00<0002[P:F[P:D01j^0Y@030000/h>Q/h>Q00RcPj401@000;^6Vk^6Vk^6
V`000006`iRZ00<0003=Vj?=Vj<01/fKX`030000eifHeifH00GGWIP00`000>>OQn>OQ`02hin700H0
003_W6C_W6@0003UP1<0000Qoooo00<0003oooooool06_ooo`006oooo`030000oooooooo06Koool0
0`000000D@000002=AZ200<0001S@I=S@I<00V=1T`030000OEJJOEJJ009mEYX300001iEdZ`030000
XG^YXG^Y00NQNjT00`000:^0YJ^0Y@07Zh2U00<0002cPj6cPj401k>3X@040000^hJK000000001l>H
ZP030000cI^ScI^S00K=Vj<00`000=NMV=NMV005eifH00<0003SWhOSWhL00n>OQ`050000kiaTkiaT
0000iH0C027oool00`000?ooooooo`0Joooo000Loooo00<0003oooooool0IOooo`030000001A0000
008e6X800`0006=1Tf=1T`02Hd6C00<0001mEYYmEYX00P000003QFV/0000UGB[00NEM:/00`000:5k
ZJ5kZ@07XG^Y00<0002[P:F[P:D01j^0Y@030000/h>Q/h>Q00NcPj4200002/>HZP030000cI^ScI^S
00K=Vj<00`000=NMV=NMV005eifH00<0003SWhOSWhL00^>OQ`060000kiaTkiaTkiaTiH0C00007ooo
o`030000oooooooo01_oool001coool00`000?ooooooo`1Uoooo00<00000054000000SDJPP030000
Hd6CHd6C009S@I<300000hEY[0030000UGB[UGB[00NEM:/00`000:5kZJ5kZ@06XG^Y00<0002[P:F[
P:D02:^0Y@030000/h>Q/h>Q00BcPj42000000>kU:l00033V:X02L>HZP030000cI^ScI^S00K=Vj<0
0`000=NMV=NMV005eifH00<0003SWhOSWhL00n>OQ`030000kiaTkiaT0080000Ooooo00<0003ooooo
ool06oooo`007?ooo`030000oooooooo06Coool300000cDJPP040000Hd6CHd6CHd6C0P0000J5JJ`0
0`0009EdZiEdZ`06UGB[00<0002QNjVQNjT01j5kZ@030000Zh2UZh2U00N[P:D00`000;>3XK>3X@02
/h>Q0P0000BkU:l00`000<>HZ/>HZP08`iRZ00<0003=Vj?=Vj<01/fKX`030000eifHeifH00GGWIP0
0`000>>OQn>OQ`03hin700C_W6@000000000000Ooooo00<0003oooooool06oooo`007Oooo`030000
oooooooo06?oool00`000000D@000003=AZ200H0001S@I<00000001/F:T00006QFV/00<0002EM:^E
M:/01YEdZ`030000XG^YXG^Y00NQNjT00`000:^0YJ^0Y@08Zh2U00@0002cPj4000000006^iB_00<0
0033V:[3V:X02<>HZP030000cI^ScI^S00K=Vj<00`000=NMV=NMV005eifH00<0003SWhOSWhL00n>O
Q`040000oLAo000000007_ooo`030000oooooooo01coool001goool00`000?ooooooo`1Soooo00@0
00000540000e6X8400000faHZ@030000QFV/QFV/00B5JJ`00`0009EdZiEdZ`06UGB[00<0002QNjVQ
NjT01j5kZ@030000Zh2UZh2U00N[P:D300002K^D[`030000`iRZ`iRZ00S3V:X00`000<fKXlfKX`06
cI^S00<0003GWISGWIP01MNMV0030000hin7hin700<000001?g4O`000>j`=00001goool00`000?oo
ooooo`0Loooo000Noooo00<0003oooooool0H_ooo`@00002?cNP00<0001/F:U/F:T00faHZ@030000
QFV/QFV/00>5JJ`00`0009EdZiEdZ`07UGB[00<0002QNjVQNjT01j5kZ@030000Zh2UZh2U00B[P:D2
000000>bTK@0002kU:l02K^D[`030000`iRZ`iRZ00S3V:X00`000<fKXlfKX`06cI^S00<0003GWISG
WIP01MNMV0030000hin7000000;`_id00`000?g4Oog4O`0200007?ooo`030000oooooooo01goool0
01koool00`000?ooooooo`1Roooo00<0000007T000000clgX0030000K5RYK5RY00=/F:T00`0008EY
[8EY[004QFV/00<0002EM:^EM:/01YEdZ`030000XG^YXG^Y00NQNjT00`000:^0YJ^0Y@02Zh2U0P00
00BbTK@00`000;^D[k^D[`08^iB_00<00033V:[3V:X02<>HZP030000cI^ScI^S00K=Vj<00`000=NM
V=NMV005eifH00D0003`_ig`_ig`_id000000_g4O`80000Loooo00<0003oooooool07Oooo`007ooo
o`030000oooooooo067oool00`000000N@000003?cNP00<0001/F:U/F:T00faHZ@030000QFV/QFV/
00B5JJ`00`0009EdZiEdZ`06UGB[00<0002QNjVQNjT02:5kZ@040000Zh2U000000001[:A]0030000
^iB_^iB_00RkU:l00`000<>HZ/>HZP08`iRZ00<0003=Vj?=Vj<01/fKX`030000eifHeifH00?GWIP3
00001?2oW@040000oLAo000000006oooo`030000oooooooo01koool001ooool00`000?ooooooo`1Q
oooo00<0000007T000000clgX0030000K5RYK5RY00=/F:T00`0008EY[8EY[004QFV/00<0002EM:^E
M:/01iEdZ`030000XG^YXG^Y00JQNjT300002K:A]0030000^iB_^iB_00RkU:l00`000<>HZ/>HZP08
`iRZ00<0003=Vj?=Vj<01/fKX`050000eifHeifHeifH000000;R^:`00`000?2oWO2oW@02l;nM00@0
003ma7l00000000Koooo00<0003oooooool07_ooo`008?ooo`030000oooooooo063oool00`000000
N@000004?cNP00<0001/F:U/F:T00VaHZ@030000QFV/QFV/00B5JJ`00`0009EdZiEdZ`07UGB[00<0
002QNjVQNjT01:5kZ@8000000jR=^0000;:A]009/Y6d00<0002kU:nkU:l02;^D[`030000`iRZ`iRZ
00S3V:X00`000<fKXlfKX`06cI^S00@0003GWIP000000003h[R/00<0003`_ig`_id00_2oW@040000
oLAo000000006_ooo`030000oooooooo01ooool0023oool00`000?ooooooo`1Qoooo00<0000007T0
00000clgX0030000K5RYK5RY009/F:T00`0008EY[8EY[005QFV/00<0002EM:^EM:/01YEdZ`030000
XG^YXG^Y00:QNjT200001:R=^0030000/Y6d/Y6d00RbTK@00`000;^D[k^D[`08^iB_00<00033V:[3
V:X02<>HZP030000cI^ScI^S00K=Vj<00`000>:h[>:h[004h[R/00T0003`_ig`_ig`_id0003ma7l0
003^/3@000006Oooo`030000oooooooo01ooool0027oool00`000?ooooooo`1Poooo00<0000007T0
00000clgX0030000K5RYK5RY00=/F:T00`0008EY[8EY[004QFV/00<0002EM:^EM:/01iEdZ`040000
XG^Y000000001ZR=^0030000/Y6d/Y6d00RbTK@00`000;^D[k^D[`08^iB_00<00033V:[3V:X02<>H
ZP030000cI^ScI^S00C=Vj<300001^:h[0090000l;nMl;nMl;nM0000oLAo0000k[0d000001Soool0
0`000?ooooooo`0Poooo000Qoooo00<0003oooooool0H?ooo`030000001i000000<o=j000`0006aH
ZFaHZ@03K5RY00<00025JJb5JJ`018EY[0030000UGB[UGB[00JEM:/300002JR=^0030000/Y6d/Y6d
00RbTK@00`000;^D[k^D[`08^iB_00<00033V:[3V:X02<>HZP040000cI^ScI^ScI^S0P0000?F/K@0
0`000>:h[>:h[003h[R/00D0003`_ig`_ig`_id000000_g4O`80000Hoooo00<0003oooooool08?oo
o`008_ooo`030000oooooooo05ooool00`000000N@000003?cNP00<0001/F:U/F:T00faHZ@030000
QFV/QFV/00B5JJ`00`0009EdZiEdZ`04UGB[0P000003WHNl0000Z8fh00VXSKP00`000;:A];:A]008
/Y6d00<0002kU:nkU:l02;^D[`030000`iRZ`iRZ00S3V:X010000<fKX`00000000GF/K@00`000>:h
[>:h[003h[R/00D0003`_ig`_ig`_id000000_g4O`80000Goooo00<0003oooooool08Oooo`008ooo
o`030000oooooooo05koool00`000000N@000003?cNP00<0001/F:U/F:T00faHZ@030000QFV/QFV/
00F5JJ`0100009EdZiEdZiEdZ`800004WHNl00<0002XSKRXSKP02:R=^0030000/Y6d/Y6d00RbTK@0
0`000;^D[k^D[`08^iB_00<00033V:[3V:X01l>HZP800007e[6d00<0003R^:cR^:`00n:h[0030000
l;nMl;nM00;`_id010000?g4O`00000001Koool00`000?ooooooo`0Roooo000Soooo00<0003ooooo
ool0G_ooo`030000001i000000<o=j000`0006aHZFaHZ@03K5RY00<00025JJb5JJ`01HEY[0040000
UGB[000000001Yf7_0030000Z8fhZ8fh00RXSKP00`000;:A];:A]008/Y6d00<0002kU:nkU:l02;^D
[`030000`iRZ`iRZ00G3V:X2000000?<[;X0003F/K@01]Ja]0030000h[R/h[R/00?R^:`00`000?2o
WO2oW@02l;nM00@0003ma7l00000000Foooo00<0003oooooool08_ooo`009?ooo`030000oooooooo
05goool00`000000N@000003?cNP00<0001/F:U/F:T00faHZ@030000QFV/QFV/00B5JJ`300002If7
_0030000Z8fhZ8fh00RXSKP00`000;:A];:A]008/Y6d00<0002kU:nkU:l02;^D[`030000`iRZ`iRZ
00;3V:X200001<b/^P030000e[6de[6d00GF/K@00`000>:h[>:h[003h[R/00T0003`_ig`_ig`_id0
003ma7l0003^/3@000005?ooo`030000oooooooo02?oool002Goool00`000?ooooooo`1Loooo00<0
000007T0000013lgX0030000K5RYK5RY00=/F:T0100008EY[8EY[8EY[08000000heo_`0009f7_009
WHNl00<0002XSKRXSKP02:R=^0030000/Y6d/Y6d00RbTK@00`000;^D[k^D[`08^iB_00<00033V:[3
V:X00P0000K<[;X00`000=Ja]=Ja]005e[6d00<0003R^:cR^:`00n:h[0090000l;nMl;nMl;nM0000
oLAo0000k[0d000001?oool00`000?ooooooo`0Toooo000Uoooo00<0003oooooool0G?ooo`030000
001i000000@o=j000`0006aHZFaHZ@03K5RY00@00025JJ`000000004SGno00<0002MQkbMQk`029f7
_0030000Z8fhZ8fh00RXSKP00`000;:A];:A]008/Y6d00<0002kU:nkU:l02;^D[`800008c:bj00<0
003F/KCF/K@01MJa]0030000h[R/h[R/00?R^:`01@000?2oWO2oWO2oW@000002oLAo0P0001?oool0
0`000?ooooooo`0Toooo000Voooo00<0003oooooool0G?ooo`030000001i000000<o=j000`0006aH
ZFaHZ@02K5RY0`0000J=Okl00`0009f7_9f7_008WHNl00<0002XSKRXSKP02:R=^0030000/Y6d/Y6d
00RbTK@00`000;^D[k^D[`06^iB_0`0000[<[;X00`000=Ja]=Ja]004e[6d00<0003R^:cR^:`00n:h
[0050000l;nMl;nMl;nM000000;ma7l200004_ooo`030000oooooooo02Goool002Koool00`000?oo
ooooo`1Loooo00<0000007T000000clgX0030000K5RY0000008000000gEb`P0008eo_`07SGno00<0
002MQkbMQk`029f7_0030000Z8fhZ8fh00RXSKP00`000;:A];:A]008/Y6d00<0002kU:nkU:l00k^D
[`800003`jRo00<0003<[;[<[;X01lb/^P030000e[6de[6d00GF/K@00`000>:h[>:h[002h[R/00<0
003`_ig`_id00_2oW@040000oLAo000000004_ooo`030000oooooooo02Goool002Ooool00`000?oo
ooooo`1Koooo00<0000007T000000SlgX0<00005MG;200<0002=Okn=Okl01Heo_`030000WHNlWHNl
00RMQk`00`000:R=^:R=^008Z8fh00<0002bTKBbTK@02;:A]0040000^iB_^iB_^iB_0P0000G3Z;l0
0`000<b/^/b/^P07c:bj00<0003F/KCF/K@01MJa]0030000h[R/h[R/00;R^:`00`000?2oWO2oW@02
l;nM00@0003ma7l00000000Aoooo00<0003oooooool09_ooo`00:?ooo`030000oooooooo05[oool0
0`000000N@000002000000=9F/40001eL/801GEb`P030000SGnoSGno00J=Okl00`0009f7_9f7_007
WHNl00<0002XSKRXSKP02JR=^0030000/Y6d/Y6d00RbTK@300002<>X_`030000c:bjc:bj00O<[;X0
0`000=Ja]=Ja]004e[6d00<0003R^:cR^:`00n:h[0040000l;nMl;nMl;nM0`00017oool00`000?oo
ooooo`0Woooo000Xoooo00<0003oooooool0F_ooo`<00004BE[100<0001eL/9eL/8017Eb`P030000
SGnoSGno00F=Okl00`0009f7_9f7_008WHNl00<0002XSKRXSKP02:R=^0030000/Y6d/Y6d00NbTK@2
00002/>X_`030000c:bjc:bj00O<[;X00`000=Ja]=Ja]004e[6d00<0003R^:cR^:`00n:h[0030000
l;nMl;nM008000000o[XUP000?ooo`0@oooo00<0003oooooool09oooo`00:Oooo`030000oooooooo
05Woool00`00000LYP000004BE[100<0001eL/9eL/8017Eb`P030000SGnoSGno00J=Okl00`0009f7
_9f7_007WHNl00<0002XSKRXSKP02JR=^0030000/Y6d/Y6d00BbTK@2000000>jYL@00033Z;l02/>X
_`030000c:bjc:bj00K<[;X00`000=Ja]=Ja]005e[6d00<0003R^:cR^:`00^:h[0<000001?KR]000
00000000013oool00`000?ooooooo`0Xoooo000Zoooo00<0003oooooool0FOooo`03000001bV0000
00A9F/400`0007Eb`WEb`P04MG;200<0002=Okn=Okl01Heo_`030000WHNlWHNl00RMQk`00`000:R=
^:R=^008Z8fh00<0002bTKBbTK@00[:A]0800004^ZG400<00033Z;o3Z;l02<>X_`030000c:bjc:bj
00O<[;X00`000=Ja]=Ja]004e[6d00<0003R^:cR^:`00^:h[0040000m^:dm^:dm^:d0`0000ooool0
0`000?ooooooo`0Yoooo000[oooo00<0003oooooool0F?ooo`03000001bV000000A9F/400`0007Eb
`WEb`P04MG;200<0002=Okn=Okl01Heo_`030000WHNlWHNl00RMQk`00`000:R=^:R=^009Z8fh00@0
002bTK@000000006^ZG400<00033Z;o3Z;l02L>X_`030000c:bjc:bj00K<[;X00`000=Ja]=Ja]004
e[6d00@0003R^:cR^:cR^:`200000_KR]0030000n^RF000000ooool00`000?ooooooo`0Zoooo000/
oooo00<0003oooooool0F?ooo`03000001bV000000A9F/400`0007Eb`WEb`P04MG;200<0002=Okn=
Okl01Heo_`030000WHNlWHNl00RMQk`00`000:R=^:R=^008Z8fh0P0000VjYL@00`000<>X_l>X_`08
`jRo00<0003<[;[<[;X01/b/^P030000e[6de[6d00CF/K@01P000>:h[>:h[0000>[G`@0000;fh[@0
0`000?[XUP00000>oooo00<0003oooooool0:oooo`00;Oooo`030000oooooooo05Ooool00`00000L
YP000004BE[100<0001eL/9eL/8017Eb`P030000SGnoSGno00F=Okl00`0009f7_9f7_008WHNl00<0
002XSKRXSKP01ZR=^08000000k2Qb@000;ZUa008^ZG400<00033Z;o3Z;l02<>X_`030000c:bjc:bj
00O<[;X00`000=Ja]=Ja]004e[6d0P0000;Zel401P000?KR]?KR]0000?[XUP0000goool00`000?oo
ooooo`0/oooo000]oooo00<0003oooooool0F?ooo`03000001bV000000A9F/400`0007Eb`WEb`P03
MG;200<0002=Okn=Okl01Xeo_`030000WHNlWHNl00RMQk`00`000:R=^:R=^003Z8fh0P0000>`XLT0
0`000;ZUa;ZUa008^ZG400<00033Z;o3Z;l02<>X_`030000c:bjc:bj00K<[;X00`000=Ja]=Ja]003
e[6d0P0000?Zel401P000?KR]?KR]0000?[XUP0000goool00`000?ooooooo`0/oooo000^oooo00<0
003oooooool0Eoooo`03000001bV000000A9F/400`0007Eb`WEb`P04MG;200<0002=Okn=Okl01Heo
_`030000WHNlWHNl00RMQk`010000:R=^:R=^:R=^0800006/:7900<0002jYLBjYL@01kZUa0030000
`jRo`jRo00S3Z;l00`000<b/^/b/^P06c:bj00@0003F/KCF/KCF/K@2000000GOc/P0003Zel7Zel40
00000oKR]080000=oooo00<0003oooooool0;Oooo`00;oooo`030000oooooooo05Koool01000000L
YP0LYP0000=9F/400`0007Eb`WEb`P04MG;200<0002=Okn=Okl01Xeo_`030000WHNlWHNl00RMQk`3
00002;2Qb@030000^ZG4^ZG400RjYL@00`000<>X_l>X_`08`jRo00<0003<[;[<[;X01/b/^P<00003
glk800@0003Zel7Zel400003m^:d0P0000coool00`000?ooooooo`0^oooo000`oooo00<0003ooooo
ool0E_ooo`03000001bV000000A9F/400`0007Eb`WEb`P04MG;200<0002=Okn=Okl01Heo_`030000
WHNlWHNl00NMQk`200002k2Qb@030000^ZG4^ZG400NjYL@00`000<>X_l>X_`08`jRo00<0003<[;[<
[;X01/b/^P030000glk8glk800?Oc/P010000>[G`N[G`@0000;fh[@00`000?[XUP00000;oooo00<0
003oooooool0;oooo`00<Oooo`030000oooooooo05Goool01000000LYP0LYP0000=9F/400`0007Eb
`WEb`P04MG;200<0002=Okn=Okl01Xeo_`030000WHNlWHNl00BMQk`200000ZBMcP030000/:79/:79
00R`XLT00`000;ZUa;ZUa008^ZG400<00033Z;o3Z;l02<>X_`030000c:bjc:bj00?<[;X300001Mo>
b0040000j]O1j]O100000_KR]0030000n^RF000000[oool00`000?ooooooo`0`oooo000boooo00<0
003oooooool0EOooo`03000001bV000000A9F/400`0007Eb`WEb`P04MG;200<0002=Okn=Okl01Heo
_`030000WHNlWHNl00:MQk`200001:BMcP030000/:79/:7900V`XLT00`000;ZUa;ZUa007^ZG400<0
0033Z;o3Z;l02<>X_`040000c:bjc:bjc:bj0P0000;Dald00`000=o>b=o>b003glk800@0003Zel7Z
el400002m^:d00<0003jj9H000002Oooo`030000oooooooo037oool003?oool00`000?ooooooo`1D
oooo00@000007:H07:H00003BE[100<0001eL/9eL/8017Eb`P030000SGnoSGno00J=Okl0100009f7
_000000000NTWLh00`000;2QbK2Qb@08/:7900<0002jYLBjYL@02;ZUa0030000`jRo`jRo00S3Z;l3
00001=C7c@030000glk8glk800?Oc/P010000>[G`N[G`@0000;fh[@200002Oooo`030000oooooooo
03;oool003Coool00`000?ooooooo`1Coooo00@000007:H07:H00004BE[100<0001eL/9eL/8017Eb
`P030000SGnoSGno00B=Okl300002ZBMcP030000/:79/:7900R`XLT00`000;ZUa;ZUa007^ZG400<0
0033Z;o3Z;l02<>X_`030000e<O=e<O=00CDald00`000=o>b=o>b003glk800@0003Zel7Zel400002
m^:d0P0000Soool00`000?ooooooo`0coooo000eoooo00<0003oooooool0Doooo`04000001bV01bV
00000dUJ`@030000MG;2MG;200AeL/800`0008eo_heo_`02SGno0P0000:EVM@00`000:BMcZBMcP09
Y9g>00<0002`XLV`XLT02;2Qb@030000^ZG4^ZG400NjYL@00`000<>X_l>X_`05`jRo0`0000KDald0
0`000=o>b=o>b002glk800T0003Zel7Zel7Zel40003fh[@0003jj9H000001oooo`030000oooooooo
03Coool003Koool00`000?ooooooo`1Boooo00@000007:H07:H00004BE[100<0001eL/9eL/8017Eb
`P040000SGno000000001IFIe0030000Y9g>Y9g>00RTWLh00`000;2QbK2Qb@08/:7900<0002jYLBj
YL@01kZUa0030000`jRo`jRo00?3Z;l200000/_2dP030000e<O=e<O=00CDald00`000=o>b=o>b002
glk800@0003Zel7Zel400002m^:d0P0000Ooool00`000?ooooooo`0eoooo000goooo00<0003ooooo
ool0D_ooo`04000001bV01bV00000dUJ`@030000MG;2MG;200=eL/8300001iFIe0030000Y9g>Y9g>
00VTWLh00`000;2QbK2Qb@08/:7900<0002jYLBjYL@01kZUa0050000`jRo`jRo`jRo000000G;`]80
0`000=C7cMC7c@03e<O=00<0003Oc/SOc/P00]o>b0040000j]O1j]O100000_KR]0800006oooo00<0
003oooooool0=_ooo`00>?ooo`030000oooooooo057oool01000000LYP0LYP0000A9F/400`0007Eb
`P00000200000WjAg0030000UIWDUIWD00JEVM@00`000:BMcZBMcP09Y9g>00<0002`XLV`XLT01k2Q
b@030000^ZG4^ZG400NjYL@010000<>X_`00000000K;`]800`000=C7cMC7c@04e<O=00D0003Oc/SO
c/SOc/P000000^[G`@@00006oooo00<0003oooooool0=oooo`00>Oooo`030000oooooooo057oool0
1@00000LYP0LYP0004UJ`@0400001WjAg0030000UIWDUIWD00JEVM@00`000:BMcZBMcP08Y9g>00<0
002`XLV`XLT02;2Qb@030000^ZG4^ZG400JjYL@200002<_2dP030000e<O=e<O=00CDald01@000=o>
b=o>b=o>b0000002j]O100<0003ToKh000001_ooo`030000oooooooo03Soool003[oool00`000?oo
ooooo`1@oooo1@0000=BPN800`0007jAg7jAg005OY7L00<0002EVMBEVM@01YFIe0030000Y9g>Y9g>
00RTWLh00`000;2QbK2Qb@07/:7900<0002jYLBjYL@01;ZUa0800002`[kG00<0003;`];;`]801L_2
dP030000e<O=e<O=00CDald01P000=o>b=o>b=o>b0000>[G`@@00005oooo00<0003oooooool0>Ooo
o`00>oooo`030000oooooooo053oool01000001@c@1@c@0000ABPN800`0007jAg7jAg004OY7L00<0
002EVMBEVM@01iFIe0030000Y9g>Y9g>00RTWLh00`000;2QbK2Qb@07/:7900@0002jYLBjYLBjYL@2
00001<:ne`030000bl;Bbl;B00K;`]800`000=C7cMC7c@03e<O=00@0003Oc/SOc/SOc/P3000000?T
oKh0003oool01?ooo`030000oooooooo03[oool003coool00`000?ooooooo`1@oooo00@00000D<d0
D<d00004DX7R00<0001nTManTM`017jAg0030000UIWDUIWD00JEVM@00`000:BMcZBMcP08Y9g>00<0
002`XLV`XLT01k2Qb@040000^ZG4000000001l:ne`030000bl;Bbl;B00G;`]800`000=C7cMC7c@03
e<O=00<0003Oc/SOc/P00P000004iOSA0000000000001?ooo`030000oooooooo03_oool003goool0
0`000?ooooooo`1@oooo00@00000D<d0D<d00004DX7R00<0001nTManTM`017jAg0030000UIWDUIWD
00JEVM@00`000:BMcZBMcP08Y9g>00<0002`XLV`XLT01k2Qb@030000`[kG`[kG00O2_]L00`000<_2
d/_2dP05bl;B00<0003DalgDald00mC7c@<000000mo`f`000000000200001?ooo`030000oooooooo
03coool003koool00`000?ooooooo`1@oooo00@00000D<d0D<d00004DX7R00<0001nTManTM`017jA
g0030000UIWDUIWD00JEVM@00`000:BMcZBMcP08Y9g>00<0002`XLV`XLT01;2Qb@8000000kRlg000
0<:ne`08`[kG00<0003;`];;`]801<_2dP030000e<O=e<O=00?Dald01@000=o`fmo`f`000>Ghd@02
00001?ooo`030000oooooooo03goool003ooool20000D_ooo`80D<d00`0005:1hU:1hP02DX7R00<0
001nTManTM`017jAg0030000UIWDUIWD00JEVM@00`000:BMcZBMcP08Y9g>00@0002`XLV`XLV`XLT2
00001;Rlg0030000`[kG`[kG00K2_]L00`000<_2d/_2dP05bl;B00<0003DalgDald00`0000;Ol=/0
10000>Ghd@00000000;oool20000@?ooo`00@Oooo`030000oooooooo053oool2053=00<0001BPN9B
PN800U:1hP030000OY7LOY7L00AnTM`00`0009FIe9FIe006UIWD00<0002TWLjTWLh01jBMcP040000
/:79000000001[Rlg0030000`[kG`[kG00O2_]L00`000<_2d/_2dP04bl;B0`0000;HjN400`000=o`
fmo`f`0300000_ooo`030000oooooooo043oool004;oool00`000?ooooooo`1@oooo0P1@c@050000
DX7RDX7RDX7R000000MnTM`00`0009FIe9FIe006UIWD00<0002TWLjTWLh01ZBMcP800009^;cL00<0
0032_]O2_]L01/:ne`030000bl;Bbl;B00C;`]801@000=SYhMSYhMSYh@000002go3K00<0003Un=40
00000_ooo`030000oooooooo047oool004?oool00`000?ooooooo`1@oooo00<0D<d0001BPN800e:1
hP030000OY7LOY7L00EnTM`00`0009FIe9FIe005UIWD00<0002TWLjTWLh00jBMcP<00002[;[S00<0
002h_=bh_=`01kRlg0030000`[kG`[kG00K2_]L010000<_2d/_2d/_2dP<00003f>WQ00<0003Ol=_O
l=/00`000003oooo0000oooo04?oool004Coool00`000?ooooooo`1@oooo0P0000ABPN800`0007jA
g7jAg004OY7L00<0002EVMBEVM@01YFIe0030000Y9g>Y9g>00800006[;[S00<0002h_=bh_=`01kRl
g0030000`[kG`[kG00G2_]L010000<_2dP00000000;?i>H01P000=SYhMSYhMSYh@000=o`f`<00000
0oooo`000?ooo`14oooo0015oooo00<0003oooooool0D?ooo`800004DX7R00<0001nTManTM`017jA
g0030000UIWDUIWD00FEVM@300002Jbjh`030000^;cL^;cL00Nh_=`00`000<:nel:ne`04`[kG0P00
00C?i>H01P000=SYhMSYhMSYh@000=o`f`@00016oooo0016oooo0P00057oool2000015:1hP030000
OY7LOY7L00AnTM`00`0009FIe9FIe002UIWD0P0000:L^N`200002Jbjh`800007^;cL00<00032_]O2
_]L00/:ne`8000000lKPk0000<oTiP03cnCV00<0003HjN7HjN401@0004Soool004Soool00`000?oo
ooooo`1?oooo0P0000ABPN800`0007jAg7jAg004OY7L00@0002EVM@000000006W;W/0P0000V/^^<0
0`000;Rlg;Rlg005^;cL00@00032_]L000000004a^3/00D0003?i>K?i>K?i>H000000]SYh@<0001:
oooo0019oooo0P00053oool2000015:1hP030000OY7LOY7L00=nTM`200002Ybik0030000[;[S[;[S
00N/^^<00`000;Rlg;Rlg005^;cL00<00036h>c6h>`01<KPk0040000cnCVcnCVcnCV1@0004_oool0
04_oool20000Coooo`800004DX7R00<0001nTManTM`00P0000>4]_D2000029bik0800008[;[S00<0
002h_=bh_=`00[Rlg08000000k_Nl@000<KPk005a^3/00H0003?i>H00000002koMh0001=oooo001=
oooo00<0003oooooool0COooo`800002DX7R100000N4]_D2000029bik0030000[;[S[;[S00J/^^<0
10000;Rlg000000000Bkg_4200001<KPk08000000kOkiP000000001>oooo001>oooo0P0004ooool2
000015F[n@800007Q;Ke0P0000NL^N`200001Zbjh`800008^mka00<00036h>`000000P000003]o_V
0000000004ooool0053oool20000Coooo`800005EJ_i0P0000J4]_D200001ibik0800002[;[S0P00
00>^gOP200001[_Nl@040000[oS[[oS[[oS[0P00053oool005;oool20000D?ooo`<00003EJ_i0`00
00F4]_D200001Ybik0<00007[]gh0P0000:kg_4200000Z?dk@80001Boooo001Doooo0P00057oool3
00000eF[n@<00004Q;Ke0P0000:L^N`2000019_Lo@@00004[]gh1@0005Goool005Koool20000D_oo
o`<00003EJ_i0P0000>4]_D300002Y_Lo@L0001Goooo001Hoooo0P0005?oool300000UF[n@<00008
O=On2P0005Woool005[oool20000Doooo`<00008B<?/20000003oooo0000000005_oool005coool2
0000Hoooo`80001Moooo001Noooo0`0005goool30000Goooo`00HOooo`<0001Goooo0`0006;oool0
06Coool30000DOooo`<0001Uoooo001Woooo0`0004_oool30000J?ooo`00J_ooo`<00015oooo0`00
06_oool006goool40000?Oooo`@0001^oooo001aoooo0`0003Ooool30000L_ooo`00M?ooo`D0000]
oooo1@0007Goool007Woool600008Oooo`H0001joooo001ooooo2P0000goool:0000P?ooo`00ROoo
o`d0002:oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
      ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}]}], "Input",
  Editable->False,
  CellDingbat->None,
  Background->GrayLevel[1]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
ScreenStyleEnvironment->"Working",
CellGrouping->Manual,
WindowSize->{732, 664},
WindowMargins->{{29, Automatic}, {26, Automatic}},
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 3190, 95, 189, "Input",
  Evaluatable->False],
Cell[4910, 146, 696, 19, 68, "Input",
  Evaluatable->False],
Cell[5609, 167, 4882, 100, 460, "Input"],
Cell[10494, 269, 9723, 270, 139, "Input",
  Evaluatable->False],
Cell[20220, 541, 34802, 678, 5195, "Input"],
Cell[55025, 1221, 447, 10, 59, "Input",
  Evaluatable->False],
Cell[55475, 1233, 2338, 43, 315, "Input"],

Cell[CellGroupData[{
Cell[57838, 1280, 587, 17, 53, "Input"],

Cell[CellGroupData[{
Cell[58450, 1301, 456, 14, 43, "Input"],
Cell[58909, 1317, 476016, 22674, 420, "Input"],
Cell[534928, 23993, 476740, 22439, 420, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1011705, 46437, 463, 14, 40, "Input"],
Cell[1012171, 46453, 325725, 13977, 471, "Input"],
Cell[1337899, 60432, 388106, 16176, 471, "Input"],
Cell[1726008, 76610, 385129, 15937, 420, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2111174, 92552, 2388, 71, 40, "Input"],
Cell[2113565, 92625, 473231, 22379, 420, "Input"],
Cell[2586799, 115006, 477008, 22565, 420, "Input"]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

